/******************************************************************************
**+-------------------------------------------------------------------------+**
**|                            ****                                         |**
**|                            ****                                         |**
**|                            ******o***                                   |**
**|                      ********_///_****                                  |**
**|                      ***** /_//_/ ****                                  |**
**|                       ** ** (__/ ****                                   |**
**|                           *********                                     |**
**|                            ****                                         |**
**|                            ***                                          |**
**|                                                                         |**
**|         Copyright (c) 2006-2010 Texas Instruments Incorporated          |**
**|                        ALL RIGHTS RESERVED                              |**
**|                                                                         |**
**| Permission is hereby granted to licensees of Texas Instruments          |**
**| Incorporated (TI) products to use this computer program for the sole    |**
**| purpose of implementing a licensee product based on TI products.        |**
**| No other rights to reproduce, use, or disseminate this computer         |**
**| program, whether in part or in whole, are granted.                      |**
**|                                                                         |**
**| TI makes no representation or warranties with respect to the            |**
**| performance of this computer program, and specifically disclaims        |**
**| any responsibility for any damages, special or consequential,           |**
**| connected with the use of this program.                                 |**
**|                                                                         |**
**+-------------------------------------------------------------------------+**
******************************************************************************/

/**
 *  \file   psp_aew.h
 *
 *  \brief  AEW interface definition
 *
 *  This file contains the interfaces, data types and symbolic definitions
 *  that are needed by the application to utilize the serivces of the AEW module
 *  of H3A device driver.
 *
 *  (C) Copyright 2006, Texas Instruments, Inc
 *
 *  \author     EI4
 *
 *  \version    1.0     Created
 */

#ifndef _PSP_AEW_H_
#define _PSP_AEW_H_

/******************************************************************************
                            Header File Inclusion
******************************************************************************/
#include <ti/sdo/pspdrivers/soc/dm6437/dsp/tistdtypes.h>
#include <ti/sdo/pspdrivers/common/psp_common.h>
/**
 * PSP Common header provides standard driver return codes, operation modes
 * and other generic defines required by all PSP drivers
 */
#ifdef __cplusplus
extern "C" {
#endif

/******************************************************************************
                                  Macros
******************************************************************************/
#define PSP_AEW_WIN_SIZE          (18u)

/******************************************************************************
                                Enumerations
******************************************************************************/
/**
 *  \brief  Enumeration defintion for status of A law
 *
 *  Enumeration defintion for status of A law
 */
typedef enum _PSP_AEW_Alaw
{
    PSP_AEW_ALAW_DISABLE    = 0,
    /**< Disable A Law      */
    PSP_AEW_ALAW_ENABLE     = 1
    /**< Enable A Law       */
} PSP_AEW_Alaw;

/******************************************************************************
                             Data-Structures
******************************************************************************/
/**
 *  \brief _PSP_AEWWindow
 *
 *  Structure defintion for Window Structure in AEW Engine
 */
typedef struct _PSP_AEWWindow
{
    Uint32    width;
    /**< Width of the window                */
    Uint32    height;
    /**< Height of the window               */
    Uint32    hzStart;
    /**< Horizontal Start of the window     */
    Uint32    vtStart;
    /**< Vertical Start of the window       */
    Uint32    hzCnt;
    /**< Horizontal Count                   */
    Uint32    vtCnt;
    /**< Vertical Count                     */
    Uint32    hzLineIncr;
    /**< Horizontal Line Increment          */
    Uint32    vtLineIncr;
    /**< Vertical Line Increment            */
} PSP_AEWWindow;

/**
 *  \brief _PSP_AEWBlkWindow
 *
 *  Structure defintion for AEW Black Window
 */
typedef struct _PSP_AEWBlkWindow
{
    Uint32    height;
    /**< Height of the Black Window         */
    Uint32    vtStart;
    /**< Vertical Start of the black Window */
} PSP_AEWBlkWindow;

/**
 *  \brief _PSP_AEWParams
 *
 *  Structure defintion for AEW engine configuration
 */
typedef struct _PSP_AEWParams
{
    PSP_AEW_Alaw            enable;
    /**< A-law status                       */
    Int32                   satLimit;
    /**< Saturation Limit                   */
    PSP_AEWWindow           winConfig;
    /**< Window for AEW Engine              */
    PSP_AEWBlkWindow        blkWinConfig;
    /**< Black Window                       */
} PSP_AEWParams;

#ifdef __cplusplus
}
#endif

#endif  /* _PSP_AEW_H_ */
