/*******************************************************************************
**+--------------------------------------------------------------------------+**
**|                            ****                                          |**
**|                            ****                                          |**
**|                            ******o***                                    |**
**|                      ********_///_****                                   |**
**|                      ***** /_//_/ ****                                   |**
**|                       ** ** (__/ ****                                    |**
**|                           *********                                      |**
**|                            ****                                          |**
**|                            ***                                           |**
**|                                                                          |**
**|         Copyright (c) 2006-2010 Texas Instruments Incorporated           |**
**|                        ALL RIGHTS RESERVED                               |**
**|                                                                          |**
**| Permission is hereby granted to licensees of Texas Instruments           |**
**| Incorporated (TI) products to use this computer program for the sole     |**
**| purpose of implementing a licensee product based on TI products.         |**
**| No other rights to reproduce, use, or disseminate this computer          |**
**| program, whether in part or in whole, are granted.                       |**
**|                                                                          |**
**| TI makes no representation or warranties with respect to the             |**
**| performance of this computer program, and specifically disclaims         |**
**| any responsibility for any damages, special or consequential,            |**
**| connected with the use of this program.                                  |**
**|                                                                          |**
**+--------------------------------------------------------------------------+**
*******************************************************************************/

/**
 *  \file   dda_h3a.c
 *
 *  \brief  H3A implementation at DDA Layer
 *
 *  This file contains the implementation of the H3A driver to utilize the
 *  serivces of the H3A device driver.
 *
 *  (C) Copyright 2010, Texas Instruments, Inc
 *
 *  \author     EI4
 *
 *  \version    0.1             Created
 *              1.0             First Release
 */
/******************************************************************************
                            Header File Inclusion
******************************************************************************/
#include <ti/sdo/pspdrivers/soc/dm6437/dsp/tistdtypes.h>
#include <ti/sdo/pspdrivers/drivers/h3a/psp_h3a.h>
#include <ti/sdo/pspdrivers/drivers/h3a/src/dda_h3aIOM_BIOS.h>
#include <ti/sdo/pspdrivers/drivers/h3a/src/ddc_h3a.h>

/******************************************************************************
                                Functions
******************************************************************************/
/**
  * \brief PSP_H3ACreate
  * Create the given H3A driver (instance)
  */
PSP_Handle PSP_H3ACreate(Uint32 instanceId)
{
    DDC_H3ADeviceObject *ddcH3aDevHandleCreate = NULL;

    /* Validate instance ID */
    if(PSP_H3A_NUM_INSTANCES <= instanceId)
    {
        ddcH3aDevHandleCreate = NULL;
    }
    else
    {
        ddcH3aDevHandleCreate
            = (DDC_H3ADeviceObject *)DDC_H3AInitializeModule (instanceId);
        DDC_H3ARegisterOverlaying();
        DDC_H3ASetInterruptNumber();
    }

    /* Register the interrupt handler */
    if(NULL != ddcH3aDevHandleCreate)
    {
        DDA_H3ARegisterIntrHandler(ddcH3aDevHandleCreate->intNum);
    }

    /* Return the device Handle */
    return (PSP_Handle)ddcH3aDevHandleCreate;
}

/**
  * \brief PSP_H3ADelete
  * Delete a given driver (instance)
  */
PSP_Result PSP_H3ADelete(Uint32 instanceId)
{
    PSP_Result resultDL = PSP_E_INVAL_PARAM;
    DDC_H3ADeviceObject *ddcH3aDevHandleDelete = NULL;

    /* Validate instance ID */
    if(PSP_H3A_NUM_INSTANCES <= instanceId)
    {
        resultDL = PSP_E_INVAL_PARAM;
    }
    else
    {
        /* set state to deleted */
        ddcH3aDevHandleDelete
            = (DDC_H3ADeviceObject *)DDC_H3ARemoveModule(instanceId);
        /* Unregister the interrupt Handler */
        if( NULL != ddcH3aDevHandleDelete )
        {
            DDA_H3AUnregisterIntrHandler(ddcH3aDevHandleDelete->intNum);
        }
    }
    return resultDL;
}

/**
  * \brief PSP_H3AOpen
  * Open Instance of the H3A device
  */
PSP_Handle PSP_H3AOpen(PSP_H3AChannelType channelId)
{
    PSP_Handle handleToReturn = NULL;

    /* Get the Channel Handle */
    handleToReturn = (PSP_Handle)DDC_H3AOpenHandle((Uint32)channelId);

    return handleToReturn;
}

/**
  * \brief PSP_H3AClose
  * Close the H3A channel with the specified handle
  */
PSP_Result PSP_H3AClose(PSP_Handle handle)
{
    PSP_Result resultCL = PSP_E_INVAL_PARAM;

    if((NULL == handle))
    {
        resultCL = PSP_E_INVAL_PARAM;
    }
    else
    {
        if(DDC_H3A_SOK == DDC_H3ACloseHandle(handle))
        {
            resultCL = PSP_SOK;
        }
        else
        {
            resultCL = PSP_E_INVAL_PARAM;
        }
    }
    return resultCL;
}

/**
  * \brief PSP_H3ASubmit
  * Submit the request sent by H3A Handle
  */
PSP_Result PSP_H3ASubmit(PSP_Handle handle, PSP_VPSSSubmitCommand cmd,
                            Ptr cmdArg)
{
    PSP_Result resultSBMT = PSP_SOK;

    /* Check the Parameters and check if Channel handle is closed */
    if ((NULL == handle) || (NULL == cmdArg))
    {
        resultSBMT = PSP_E_INVAL_PARAM;
    }
    else if (DDC_H3A_SOK != DDC_H3AIsChannelHandleClosed(handle))
    {
        resultSBMT = PSP_E_INVAL_PARAM;
    }
    else
    {
        resultSBMT = DDC_H3ASubmit(handle, cmd, cmdArg);
        if(DDC_H3A_SOK  == resultSBMT)
        {
            resultSBMT = PSP_SOK;
        }
        else if (DDC_H3A_INVALID_PARAM == resultSBMT )
        {
            resultSBMT = PSP_E_INVAL_PARAM;
        }
        else
        {
            resultSBMT = PSP_E_IO_CANCEL_FAIL;
        }
    }
    return resultSBMT;
}

/**
  * \brief PSP_H3AIoctl
  * I/O Control of the H3A device
  */
/* ARGSUSED */
PSP_Result PSP_H3AIoctl( PSP_Handle handle, PSP_H3AIoctlCmd cmd, Ptr cmdArg,
                         Ptr params)
{
    PSP_Result resultIOCTL = PSP_E_INVAL_PARAM;
    /* Check if the Channel Handle is Closed */
    if ((NULL == handle) || (NULL == cmdArg))
    {
        resultIOCTL = PSP_E_INVAL_PARAM;
    }
    else if (DDC_H3A_SOK != DDC_H3AIsChannelHandleClosed(handle))
    {
        resultIOCTL = PSP_E_INVAL_PARAM;
    }
    else
    {
        if(DDC_H3A_SOK  == DDC_H3AIoctl(handle, cmd, cmdArg, params))
        {
            resultIOCTL = PSP_SOK;
        }
    }
    return resultIOCTL;
}
