/*******************************************************************************
**+--------------------------------------------------------------------------+**
**|                            ****                                          |**
**|                            ****                                          |**
**|                            ******o***                                    |**
**|                      ********_///_****                                   |**
**|                      ***** /_//_/ ****                                   |**
**|                       ** ** (__/ ****                                    |**
**|                           *********                                      |**
**|                            ****                                          |**
**|                            ***                                           |**
**|                                                                          |**
**|         Copyright (c) 2006-2010 Texas Instruments Incorporated           |**
**|                        ALL RIGHTS RESERVED                               |**
**|                                                                          |**
**| Permission is hereby granted to licensees of Texas Instruments           |**
**| Incorporated (TI) products to use this computer program for the sole     |**
**| purpose of implementing a licensee product based on TI products.         |**
**| No other rights to reproduce, use, or disseminate this computer          |**
**| program, whether in part or in whole, are granted.                       |**
**|                                                                          |**
**| TI makes no representation or warranties with respect to the             |**
**| performance of this computer program, and specifically disclaims         |**
**| any responsibility for any damages, special or consequential,            |**
**| connected with the use of this program.                                  |**
**|                                                                          |**
**+--------------------------------------------------------------------------+**
*******************************************************************************/

/**
 *  \file   dda_h3aBios.c
 *
 *  \brief  H3A Driver Adaptation for BIOS
 *
 *  This file contains adaptation of H3A driver for BIOS
 *
 *  (C) Copyright 2010, Texas Instruments, Inc
 *
 *  \author     EI4
 *
 *  \version    0.1             Created
 *              1.0             First Release
 */
/******************************************************************************
  Header File Inclusion
 ******************************************************************************/
#include <std.h>
#include <C64.h>
#include <ti/sdo/pspdrivers/soc/dm6437/dsp/soc.h>
#include <ecm.h>
#include <ti/sdo/pspdrivers/drivers/h3a/src/ddc_h3a.h>

/******************************************************************************
  Macros
 *****************************************************************************/
#define HWI_H3A_INTR_NUM        (HWI_EVT01_CMB_IRQ)

/******************************************************************************
  Functions
 *****************************************************************************/
/******************************************************************************
  Register interrrupt with BIOS and enable it
 *****************************************************************************/
/**
 * \brief DDA_H3ARegisterIntrHandler
 * Register interrrupt with BIOS and enable it
 */
void DDA_H3ARegisterIntrHandler(Uint32 IntNum)
{
    ECM_Attrs ecmattrs = ECM_ATTRS;

    ECM_disableEvent((Uns)IntNum);

    /* Mapping the eventid to the ECM Dispatch of the DSP/BIOS */
    ecmattrs.unmask = (int)1;
    ECM_dispatchPlug(IntNum, (ECM_Fxn)&DDC_H3Aisr, &ecmattrs);

    /* Enabling the event */
    ECM_enableEvent(IntNum);

    /* Enabling Interrupt of CPU */
    C64_enableIER(HWI_H3A_INTR_NUM);
}

/******************************************************************************
  Un-Register all the interrrupt with BIOS and disable these
  *****************************************************************************/
/**
 * \brief DDA_H3AUnregisterIntrHandler
 * Un-Register Front End interrupt with BIOS.
 */
void DDA_H3AUnregisterIntrHandler(Uint32 intrNum)
{
    /* Disabling CCDC interrupt */
    ECM_disableEvent(intrNum);
}

