/*******************************************************************************
**+--------------------------------------------------------------------------+**
**|                            ****                                          |**
**|                            ****                                          |**
**|                            ******o***                                    |**
**|                      ********_///_****                                   |**
**|                      ***** /_//_/ ****                                   |**
**|                       ** ** (__/ ****                                    |**
**|                           *********                                      |**
**|                            ****                                          |**
**|                            ***                                           |**
**|                                                                          |**
**|         Copyright (c) 2006-2010 Texas Instruments Incorporated           |**
**|                        ALL RIGHTS RESERVED                               |**
**|                                                                          |**
**| Permission is hereby granted to licensees of Texas Instruments           |**
**| Incorporated (TI) products to use this computer program for the sole     |**
**| purpose of implementing a licensee product based on TI products.         |**
**| No other rights to reproduce, use, or disseminate this computer          |**
**| program, whether in part or in whole, are granted.                       |**
**|                                                                          |**
**| TI makes no representation or warranties with respect to the             |**
**| performance of this computer program, and specifically disclaims         |**
**| any responsibility for any damages, special or consequential,            |**
**| connected with the use of this program.                                  |**
**|                                                                          |**
**+--------------------------------------------------------------------------+**
*******************************************************************************/

/**
 *  \file   ddc_h3a.c
 *
 *  \brief  H3A implementation
 *
 *  This file contains the implementation of the H3A driver to utilize the
 *  serivces of the H3A device driver.
 *
 *  (C) Copyright 2010, Texas Instruments, Inc
 *
 *  \author     EI4
 *
 *  \version    0.1             Created
 *              1.0             First Release
 */

/******************************************************************************
  Header File Inclusion
 *****************************************************************************/
#include <ti/sdo/pspdrivers/pal_os/pal_osSem.h>
#include <ti/sdo/pspdrivers/pal_os/pal_osMem.h>
#include <ti/sdo/pspdrivers/pal_os/pal_osProtect.h>
#include <clk.h>
#include <ti/sdo/pspdrivers/common/psp_common.h>
#include <ti/sdo/pspdrivers/soc/dm6437/dsp/csl_error.h>
#include <ti/sdo/pspdrivers/soc/dm6437/dsp/cslr_h3a.h>
#include <ti/sdo/pspdrivers/soc/dm6437/dsp/soc.h>
#include <ti/sdo/pspdrivers/drivers/h3a/psp_h3a.h>
#include <ti/sdo/pspdrivers/drivers/h3a/src/ddc_h3a.h>
#include <ti/sdo/pspdrivers/drivers/h3a/src/ddc_af.h>
#include <ti/sdo/pspdrivers/drivers/h3a/src/ddc_aew.h>
#include <ti/sdo/pspdrivers/drivers/h3a/src/llc_h3a.h>
#ifdef H3A_INSTRUMENTATION_ENABLED
#include <ti/sdo/pspdrivers/pal_os/bios/psp_log.h>
#endif /* H3A_INSTRUMENTATION_ENABLED */
/******************************************************************************
  Data-Structures
 *****************************************************************************/
/**
 * \brief H3A device object handle
 */
/* It is not required to initialize the rest of the members of the Structure*/

DDC_H3ADeviceObject ddcH3aDevObj = {DDC_H3A_ID_RESET_VAL,
                                DDC_H3A_INT_RESET_VAL, PSP_H3A_DELETED, NULL};

/******************************************************************************
  Internal Function declaration
 *****************************************************************************/
/**
 * \brief DDC_H3AGetDeviceHandle
 * Return H3A Device Object
 *
 * \param  void
 *
 * \return Returns          [OUT]   the handle for H3A
 */
static inline PSP_Handle DDC_H3AGetDeviceHandle(void);

/**
 * \brief DDC_AFGetChannelHandle
 * Return AF channel Object
 *
 * \param  void
 *
 * \return Returns          [OUT]   the handle for AF channel
 */
static inline PSP_Handle DDC_AFGetChannelHandle(void);


/**
 * \brief DDC_AEWGetChannelHandle
 * Return AEW channel Object
 *
 * \param  void
 *
 * \return Returns          [OUT]   the handle for AEW channel
 */
static inline PSP_Handle DDC_AEWGetChannelHandle(void);

/******************************************************************************
  Functions
 *****************************************************************************/
/**
 * \brief DDC_H3AOpenHandle
 * It will return the Channel handle
 */
PSP_Handle DDC_H3AOpenHandle(Uint32 id)
{
    DDC_H3ADeviceObject *ddcH3aDevHandleOpen;
    PSP_Handle handleToReturnH3AOH = NULL;
    /* Get the Device Handle */
    ddcH3aDevHandleOpen  = (DDC_H3ADeviceObject*)DDC_H3AGetDeviceHandle();
    if (NULL != ddcH3aDevHandleOpen)
    {
        /* Check the Device State */
        if (((PSP_H3A_CREATED != ddcH3aDevHandleOpen ->state)
                && (PSP_H3A_CLOSED   != ddcH3aDevHandleOpen->state))
            && (PSP_H3A_OPENED   != ddcH3aDevHandleOpen->state))
        {
            DDC_H3A_DEBUG_PRINT("Error: Open Failed ");
            handleToReturnH3AOH = NULL;
        }
        else
        {
            if (PSP_H3A_AF == id)
            {
                handleToReturnH3AOH = DDC_AFOpenHandle();
            }
            else if (PSP_H3A_AEW == id)
            {
                handleToReturnH3AOH = DDC_AEWOpenHandle();
            }
            else
            {
                DDC_H3A_DEBUG_PRINT(
                    "DDC_H3AOpenHandle Error : Invalid Channel Type ");
                handleToReturnH3AOH = NULL;
            }
            if (NULL != handleToReturnH3AOH)
            {
                /* Update the state of the driver to open */
                ddcH3aDevHandleOpen->state = PSP_H3A_OPENED;
            }
        }
    }
    else
    {
        DDC_H3A_DEBUG_PRINT(
            "DDC_H3AOpenHandle Error : Channel Creation Failed ");
        handleToReturnH3AOH = NULL;
    }
    return handleToReturnH3AOH;
}

/**
 * \brief DDC_AFOpenHandle
 * It will return the Channel handle and update the state of AF channel
 */
PSP_Handle DDC_AFOpenHandle(void)
{
    DDC_H3ADeviceObject *ddcH3aDevHandleAFOpen
        = (DDC_H3ADeviceObject *)DDC_H3AGetDeviceHandle();
    DDC_AFChannelObject *ddcHandleReturnAFOH = NULL;
    ddcHandleReturnAFOH = (DDC_AFChannelObject *)DDC_AFGetChannelHandle();
    if ((NULL != ddcHandleReturnAFOH)&& (NULL != ddcH3aDevHandleAFOpen))
    {
        /* Create the channel Semaphore */
        if (PAL_SOK != PAL_osSemCreate("channelSemAF", DDC_H3A_INIT_CHAN_SEM,
                NULL, &ddcHandleReturnAFOH->sem))
        {
            ddcHandleReturnAFOH = NULL;
            DDC_H3A_DEBUG_PRINT(
                "DDC_AFOpenHandle Error : Unable to create Semaphore");
        }
        else
        {
            /* Create the ISR Semaphore */
            if (PAL_SOK != PAL_osSemCreate("channelSemAFISR",
                    DDC_H3A_INIT_ISR_SEM, NULL, &ddcHandleReturnAFOH->semISR))
            {
                /* Delete the previous Semaphore */
                PAL_osSemDelete(ddcHandleReturnAFOH->sem);
                ddcHandleReturnAFOH = NULL;
                DDC_H3A_DEBUG_PRINT(
                    "DDC_AFOpenHandle Error: Unable to create Semaphore");
            }
            else
            {
                /* Initialize the Param structure to 0 */
                if ( PAL_SOK != PAL_osMemSet(&(ddcHandleReturnAFOH->params),
                        DDC_H3A_MEM_INIT , sizeof(PSP_AFParams)))
                {
                    /* Delete the previous Semaphore */
                    PAL_osSemDelete(ddcHandleReturnAFOH->sem);
                    PAL_osSemDelete(ddcHandleReturnAFOH->semISR);
                    ddcHandleReturnAFOH = NULL;
                    DDC_H3A_DEBUG_PRINT("DDC_AFOpenHandle Error: Memset Fail");
                }
                else
                {
                    /* STATE_NOT_CONFIGURED */
                    ddcHandleReturnAFOH->configFlag = STATE_NOT_CONFIGURED;
                    /* Update the channel State */
                    ddcHandleReturnAFOH->state = DDC_H3ACHANOPENED;
                    /* Set the channel type */
                    ddcHandleReturnAFOH->channelId = PSP_H3A_AF;
                    /* Initialize semaphore time out */
                    ddcHandleReturnAFOH->semTimeOut = PAL_OSSEM_NO_TIMEOUT;

                    /* Initialize the queues */
                    PAL_OSLIST_MKNODE(&ddcHandleReturnAFOH->buffObj.enQueue);
                    PAL_OSLIST_MKNODE(&ddcHandleReturnAFOH->buffObj.deQueue);
                    /* Initialize the index */
                    ddcHandleReturnAFOH->buffObj.indexEnQueue
                        = (Uint32)(DDC_H3A_QUEUE_EMPTY);
                    ddcHandleReturnAFOH->buffObj.indexDeQueue
                        = (Uint32)(DDC_H3A_QUEUE_EMPTY);
                    if (NULL != ddcH3aDevHandleAFOpen->regs)
                    {
                        if (CSL_SOK !=
                            LLC_AFInitRegister(ddcH3aDevHandleAFOpen->regs))
                        {
                            /* Delete the previous Semaphore */
                            PAL_osSemDelete(ddcHandleReturnAFOH->sem);
                            PAL_osSemDelete(ddcHandleReturnAFOH->semISR);
                            DDC_H3A_DEBUG_PRINT("DDC_AFOpenHandle:Open Fail");
                            ddcHandleReturnAFOH = NULL;
                        }
                    }
                    else
                    {
                        /* Delete the previous Semaphore */
                        PAL_osSemDelete(ddcHandleReturnAFOH->sem);
                        PAL_osSemDelete(ddcHandleReturnAFOH->semISR);
                        DDC_H3A_DEBUG_PRINT("DDC_AFOpenHandle Error:Open Fail");
                        ddcHandleReturnAFOH = NULL;
                    }
                }
            }
        }
    }
    else
    {
        DDC_H3A_DEBUG_PRINT("DDC_AFOpenHandle Error : Open Failed");
        ddcHandleReturnAFOH = NULL;
    }
    return (PSP_Handle)ddcHandleReturnAFOH;
}

/**
 * \brief DDC_AEWOpenHandle
 * It will return the Channel handle and update the state of AEW channel
 */
PSP_Handle DDC_AEWOpenHandle(void)
{
    DDC_AEWChannelObject *ddcHandleReturnAEWOH = NULL;
    DDC_H3ADeviceObject *ddcH3aDevHandleAEWOpen
        = (DDC_H3ADeviceObject *)DDC_H3AGetDeviceHandle();
    ddcHandleReturnAEWOH = (DDC_AEWChannelObject *)DDC_AEWGetChannelHandle();

    if ((NULL != ddcHandleReturnAEWOH) && (NULL != ddcH3aDevHandleAEWOpen))
    {
        /* Create channel Semaphore */
        if (PAL_SOK != PAL_osSemCreate("channelSemAEW", DDC_H3A_INIT_CHAN_SEM,
                NULL, &ddcHandleReturnAEWOH->sem))
        {
            DDC_H3A_DEBUG_PRINT(
                "DDC_AEWOpenHandle Error : Unable to create Semaphore");
            ddcHandleReturnAEWOH = NULL;
        }
        else
        {
            /* Create ISR Semaphore */
            if (PAL_SOK != PAL_osSemCreate("channelSemAEWISR",
                    DDC_H3A_INIT_ISR_SEM, NULL, &ddcHandleReturnAEWOH->semISR))

            {
                /* Delete the previous Semaphore */
                PAL_osSemDelete(ddcHandleReturnAEWOH->sem);
                DDC_H3A_DEBUG_PRINT(
                    "DDC_AEWOpenHandle Error: Unable to create Semaphore");
                ddcHandleReturnAEWOH = NULL;
            }
            else
            {
                /* Initialize param structure to zero */
                if ( PAL_SOK != PAL_osMemSet(&(ddcHandleReturnAEWOH->params),
                        DDC_H3A_MEM_INIT, sizeof(PSP_AEWParams)))
                {
                    /* Delete the previous Semaphore */
                    PAL_osSemDelete(ddcHandleReturnAEWOH->sem);
                    PAL_osSemDelete(ddcHandleReturnAEWOH->semISR);
                    DDC_H3A_DEBUG_PRINT("DDC_AEWOpenHandle Error: Memset Fail");
                    ddcHandleReturnAEWOH = NULL;
                }
                else
                {
                    ddcHandleReturnAEWOH->configFlag = STATE_NOT_CONFIGURED;
                    /* Update the channel State */
                    ddcHandleReturnAEWOH->state = DDC_H3ACHANOPENED;
                    /* Set the channel type */
                    ddcHandleReturnAEWOH->channelId = PSP_H3A_AEW;
                    /* Initialize semaphore time out */
                    ddcHandleReturnAEWOH->semTimeOut = PAL_OSSEM_NO_TIMEOUT;

                    /* Initialize the queues */
                    PAL_OSLIST_MKNODE(&ddcHandleReturnAEWOH->buffObj.enQueue);
                    PAL_OSLIST_MKNODE(&ddcHandleReturnAEWOH->buffObj.deQueue);
                    /* Initialize the index */
                    ddcHandleReturnAEWOH->buffObj.indexEnQueue
                        = (Uint32)(DDC_H3A_QUEUE_EMPTY);
                    ddcHandleReturnAEWOH->buffObj.indexDeQueue
                        = (Uint32)(DDC_H3A_QUEUE_EMPTY);

                    if (NULL != ddcH3aDevHandleAEWOpen->regs)
                    {
                        if (CSL_SOK !=
                            LLC_AEWInitRegister(ddcH3aDevHandleAEWOpen->regs))
                        {
                            /* Delete the previous Semaphore */
                            PAL_osSemDelete(ddcHandleReturnAEWOH->sem);
                            PAL_osSemDelete(ddcHandleReturnAEWOH->semISR);
                            DDC_H3A_DEBUG_PRINT("DDC_AEWOpenHandle:OpenFail");
                            ddcHandleReturnAEWOH = NULL;
                        }
                    }
                    else
                    {
                        /* Delete the previous Semaphore */
                        PAL_osSemDelete(ddcHandleReturnAEWOH->sem);
                        PAL_osSemDelete(ddcHandleReturnAEWOH->semISR);
                        DDC_H3A_DEBUG_PRINT("DDC_AEWOpenHandle Error:OpenFail");
                        ddcHandleReturnAEWOH = NULL;
                    }
                }
            }
        }
    }
    else
    {
        DDC_H3A_DEBUG_PRINT("DDC_AEWOpenHandle Error : Open Failed");
        ddcHandleReturnAEWOH = NULL;
    }

    return (PSP_Handle)ddcHandleReturnAEWOH;
}

/**
 * \brief DDC_H3ACloseHandle
 * This function valdiates H3A Channel handle and updates the H3A Device State.
 */
DDC_H3AStatus DDC_H3ACloseHandle(PSP_Handle const handle)
{
    Uint32 idCH;
    DDC_H3AStatus resultH3ACH = DDC_H3A_SOK;
    DDC_H3ADeviceObject *ddcH3aDevHandleClose = NULL;
    ddcH3aDevHandleClose = (DDC_H3ADeviceObject*)DDC_H3AGetDeviceHandle();
    if (NULL != ddcH3aDevHandleClose)
    {
        /* Check the Device State */
        if (((PSP_H3A_CREATED == ddcH3aDevHandleClose->state)
                || (PSP_H3A_CLOSED == ddcH3aDevHandleClose->state))
            || (PSP_H3A_DELETED == ddcH3aDevHandleClose->state))
        {
            DDC_H3A_DEBUG_PRINT("DDC_H3ACloseHandle Error: Close Failed");
            resultH3ACH = DDC_H3A_INVALID_STATE;
        }
        if (DDC_H3A_SOK == resultH3ACH)
        {
            if (NULL != handle)
            {
                /* Get ID*/
                idCH = *(Uint32 *)handle;
                /* Verify ID*/
                if (PSP_H3A_AF == idCH)
                {
                    resultH3ACH = DDC_AFCloseHandle(handle);
                }
                else if (PSP_H3A_AEW == idCH)
                {
                    resultH3ACH = DDC_AEWCloseHandle(handle);
                }
                else
                {
                    DDC_H3A_DEBUG_PRINT("DDC_H3ACloseHandle Error: Invalid ID");
                    resultH3ACH = DDC_H3A_INVALID_PARAM;
                }
                /* If both AF and AEW Channels are closed
                   update the state of Device */
                if (DDC_H3A_SOK == resultH3ACH)
                {
                    if ((DDC_H3ACHANCLOSED
                            == ddcH3aDevHandleClose->chanAF.state)
                        && (DDC_H3ACHANCLOSED
                            == ddcH3aDevHandleClose->chanAEW.state))
                    {
                        /* Update the device state
                           if both the channels are closed */
                        ddcH3aDevHandleClose->state = PSP_H3A_CLOSED;
                    }
                }
            }
            else
            {
                DDC_H3A_DEBUG_PRINT("DDC_H3ACloseHandle Error: Close Failed");
                resultH3ACH = DDC_H3A_INVALID_PARAM;
            }
        }
    }
    else
    {
        DDC_H3A_DEBUG_PRINT("DDC_H3ACloseHandle Error: Close Failed");
        resultH3ACH = DDC_H3A_INVALID_PARAM;
    }
    return resultH3ACH;
}

/**
 * \brief DDC_AFCloseHandle
 * This function closes the AF Channel handle once created.
 */
DDC_H3AStatus DDC_AFCloseHandle(PSP_Handle const handleAF)
{
    DDC_H3ADeviceObject *ddcH3aDevHandleAFCH
        = (DDC_H3ADeviceObject *)DDC_H3AGetDeviceHandle();
    DDC_H3AStatus resultAFCH = DDC_H3A_SOK;

    if (NULL != handleAF)
    {
        DDC_AFChannelObject *ddcAFhandleClose = (DDC_AFChannelObject *)handleAF;
        /* Acquire the Lock */
        if (PAL_SOK
            != PAL_osSemTake (ddcAFhandleClose->sem,
                              ddcAFhandleClose->semTimeOut))
        {
            DDC_H3A_DEBUG_PRINT(
                "DDC_AFCloseHandle Error:Unable to get Semaphore");
            resultAFCH = DDC_H3A_E_FAIL;
        }
        if ((DDC_H3A_SOK == resultAFCH) && (NULL != ddcH3aDevHandleAFCH))
        {
            if (DDC_H3ACHANOPENED == ddcAFhandleClose->state)
            {
                ddcAFhandleClose->state = DDC_H3ACHANCLOSED;
                /* Reset the queues */
                ddcAFhandleClose->buffObj.enQueue.next = NULL;
                ddcAFhandleClose->buffObj.deQueue.next = NULL;
                ddcAFhandleClose->buffObj.indexEnQueue  = DDC_H3A_RESET_INDEX;
                ddcAFhandleClose->buffObj.indexDeQueue  = DDC_H3A_RESET_INDEX;
                /* Disable the engine */
                if (NULL != ddcH3aDevHandleAFCH->regs)
                {
                    if (CSL_SOK != LLC_SetAFEngine(DDC_H3A_ENGINE_DISABLE,
                        ddcH3aDevHandleAFCH->regs))
                    {
                        resultAFCH = DDC_H3A_E_FAIL;
                    }
                }
                /* Release the Lock */
                if (PAL_SOK != PAL_osSemGive(ddcAFhandleClose->sem))
                {
                    resultAFCH = DDC_H3A_E_FAIL;
                }
                if ((PAL_SOK != PAL_osSemDelete(ddcAFhandleClose->sem)) ||
                    (PAL_SOK != PAL_osSemDelete(ddcAFhandleClose->semISR)))
                {
                    resultAFCH = DDC_H3A_E_FAIL;
                }
            }
            else
            {
                DDC_H3A_DEBUG_PRINT("DDC_AFCloseHandle Error: Close Failed");
                resultAFCH = DDC_H3A_INVALID_PARAM;
            }
        }
        else
        {
            DDC_H3A_DEBUG_PRINT("DDC_AFCloseHandle Error: Close Failed");
            resultAFCH = DDC_H3A_INVALID_PARAM;
        }
    }
    else
    {
        DDC_H3A_DEBUG_PRINT("DDC_AFCloseHandle Error: Close Failed");
        resultAFCH = DDC_H3A_INVALID_PARAM;
    }
    return resultAFCH;
}

/**
 * \brief DDC_AEWCloseHandle
 * This function closes the AEW Channel handle once created.
 */
DDC_H3AStatus DDC_AEWCloseHandle(PSP_Handle const handleAEW)
{
    DDC_H3ADeviceObject *ddcH3aDevHandleAEWCH
        = (DDC_H3ADeviceObject *)DDC_H3AGetDeviceHandle();
    DDC_H3AStatus resultAEWCH = DDC_H3A_SOK;

    if (NULL != handleAEW)
    {
        DDC_AEWChannelObject *ddcAEWhandleClose
            = (DDC_AEWChannelObject *)handleAEW;
        /* Acquire the Lock */
        if (PAL_SOK != PAL_osSemTake (ddcAEWhandleClose->sem,
                                      ddcAEWhandleClose->semTimeOut))
        {
            DDC_H3A_DEBUG_PRINT(
                "DDC_AEWCloseHandle Error:Unable to get Semaphore");
            resultAEWCH = DDC_H3A_E_FAIL;
        }
        if ((DDC_H3A_SOK == resultAEWCH) && (NULL != ddcH3aDevHandleAEWCH))
        {
            if (DDC_H3ACHANOPENED == ddcAEWhandleClose->state)
            {
                ddcAEWhandleClose->state = DDC_H3ACHANCLOSED;
                /* Reset the queues */
                ddcAEWhandleClose->buffObj.enQueue.next = NULL;
                ddcAEWhandleClose->buffObj.deQueue.next = NULL;
                ddcAEWhandleClose->buffObj.indexEnQueue = DDC_H3A_RESET_INDEX;
                ddcAEWhandleClose->buffObj.indexDeQueue = DDC_H3A_RESET_INDEX;
                /* Disable the engine */
                if (NULL != ddcH3aDevHandleAEWCH->regs)
                {
                    if (CSL_SOK != LLC_SetAEWEngine(DDC_H3A_ENGINE_DISABLE,
                        ddcH3aDevHandleAEWCH->regs))
                    {
                        resultAEWCH = DDC_H3A_E_FAIL;
                    }
                }
                /* Release the Lock */
                if (PAL_SOK != PAL_osSemGive(ddcAEWhandleClose->sem))
                {
                    resultAEWCH = DDC_H3A_E_FAIL;
                }
                if ((PAL_SOK != PAL_osSemDelete(ddcAEWhandleClose->sem)) ||
                    (PAL_SOK != PAL_osSemDelete(ddcAEWhandleClose->semISR)))
                {
                    resultAEWCH = DDC_H3A_E_FAIL;
                }
            }
            else
            {
                DDC_H3A_DEBUG_PRINT("DDC_AEWCloseHandle Error: Close Failed");
                resultAEWCH = DDC_H3A_INVALID_PARAM;
            }
        }
        else
        {
            DDC_H3A_DEBUG_PRINT("DDC_AEWCloseHandle Error: Close Failed");
            resultAEWCH = DDC_H3A_INVALID_PARAM;
        }
    }
    else
    {
        DDC_H3A_DEBUG_PRINT("DDC_AEWCloseHandle Error: Close Failed");
        resultAEWCH = DDC_H3A_INVALID_PARAM;
    }
    return resultAEWCH;
}

/**
 * \brief DDC_H3AIsChannelHandleClosed
 * It will return the status of the handle
 */
DDC_H3AStatus DDC_H3AIsChannelHandleClosed(PSP_Handle const handle)
{
    Uint32 idICHC;
    DDC_H3AStatus resultIH3ACH = DDC_H3A_SOK;

    if (NULL == handle)
    {
        DDC_H3A_DEBUG_PRINT("DDC_H3AIsChannelHandleClosed Error: \
            Invalid Params Channel Checking Failed\n");
        resultIH3ACH = DDC_H3A_INVALID_PARAM;
    }
    else
    {
        idICHC = *(Uint32 *)handle;
        /* Verify ID */
        if (PSP_H3A_AF == idICHC)
        {
            resultIH3ACH = DDC_AFIsChannelHandleClosed(handle);
        }
        else if (PSP_H3A_AEW == idICHC)
        {
            resultIH3ACH = DDC_AEWIsChannelHandleClosed(handle);
        }
        else
        {
            DDC_H3A_DEBUG_PRINT(
                "DDC_H3AIsChannelHandleClosed Error: Invalid Params\n");
            resultIH3ACH = DDC_H3A_INVALID_PARAM;
        }
    }
    return resultIH3ACH;
}

/**
 * \brief DDC_AFIsChannelHandleClosed
 * Check if the Auto Focus handle is in closed state
 */
DDC_H3AStatus DDC_AFIsChannelHandleClosed(PSP_Handle const handleAF)
{
    DDC_H3AStatus resultIAFCH = DDC_H3A_SOK;
    DDC_AFChannelObject *ddcAFhandleISH;
    if (NULL != handleAF)
    {
        ddcAFhandleISH = (DDC_AFChannelObject *)handleAF;

        if (PAL_SOK
            != PAL_osSemTake (ddcAFhandleISH->sem, ddcAFhandleISH->semTimeOut))
        {
            resultIAFCH = DDC_H3A_E_FAIL;
        }

        if (DDC_H3A_SOK == resultIAFCH)
        {
            if (DDC_H3ACHANCLOSED == ddcAFhandleISH->state)
            {
                DDC_H3A_DEBUG_PRINT(
                    "DDC_AFIsChannelHandleClosed Error: Channel is closed\n");
                resultIAFCH = DDC_H3A_INVALID_PARAM;
            }
        }

        /* Release the Lock */
        if ( PAL_SOK != PAL_osSemGive(ddcAFhandleISH->sem))
        {
            resultIAFCH = DDC_H3A_E_FAIL;
        }
    }
    else
    {
        resultIAFCH = DDC_H3A_INVALID_PARAM;
        DDC_H3A_DEBUG_PRINT(
            "DDC_AFIsChannelHandleClosed Error: Invalid Param\n");
    }
    return resultIAFCH;
}

/**
 * \brief DDC_AEWIsChannelHandleClosed
 * Check if the AEW handle is in closed state
 */
DDC_H3AStatus DDC_AEWIsChannelHandleClosed(PSP_Handle  const handleAEW)
{
    DDC_H3AStatus resultIAEWCH = DDC_H3A_SOK;
    DDC_AEWChannelObject *ddcAEWhandleISH;

    if (NULL != handleAEW)
    {
        ddcAEWhandleISH = (DDC_AEWChannelObject *)handleAEW;
        /* Acquire the Lock */
        if (PAL_SOK
            != PAL_osSemTake (ddcAEWhandleISH->sem, ddcAEWhandleISH->semTimeOut))
        {
            resultIAEWCH = DDC_H3A_E_FAIL;
        }
        if (DDC_H3A_SOK == resultIAEWCH)
        {
            if (DDC_H3ACHANCLOSED == ddcAEWhandleISH->state)
            {
                DDC_H3A_DEBUG_PRINT(
                    "DDC_AEWIsChannelHandleClosed Error: Channel is closed\n");
                resultIAEWCH = DDC_H3A_INVALID_PARAM;
            }
        }

        /* Release the Lock */
        if ( PAL_SOK != PAL_osSemGive(ddcAEWhandleISH->sem))
        {
            resultIAEWCH = DDC_H3A_E_FAIL;
        }
    }
    else
    {
        resultIAEWCH = DDC_H3A_INVALID_PARAM;
        DDC_H3A_DEBUG_PRINT(
            "DDC_AEWIsChannelHandleClosed Error: Invalid Param\n");
    }
    return resultIAEWCH;
}

/**
 * \brief DDC_H3ASubmit
 * Validate the channel Handle and call corresponding function to
 * handle Submit Request
 */
DDC_H3AStatus DDC_H3ASubmit(PSP_Handle const handle, PSP_VPSSSubmitCommand cmd,
    Ptr cmdArg)
{
    Uint32 idSBT;
    DDC_H3AStatus resultH3ASBT = DDC_H3A_SOK;
    /* Check the buffer parameters */
    resultH3ASBT = DDC_H3AValidateBuffer(cmdArg, cmd);
    if (((NULL != handle) && (NULL != cmdArg)) && (DDC_H3A_SOK == resultH3ASBT))
    {
        idSBT = *(Uint32 *)handle;
        /* Check the channeld id */
        if (PSP_H3A_AF == idSBT)
        {
            resultH3ASBT = DDC_AFSubmit(handle, cmd, cmdArg);
        }
        else if (PSP_H3A_AEW == idSBT)
        {
            resultH3ASBT = DDC_AEWSubmit(handle, cmd, cmdArg);
        }
        else
        {
            DDC_H3A_DEBUG_PRINT("DDC_H3ASubmit Error: Invalid ChannelId\n");
            resultH3ASBT = DDC_H3A_INVALID_PARAM;
        }
    }
    else
    {
        DDC_H3A_DEBUG_PRINT("DDC_H3ASubmit Error: Submit Failed\n");
        resultH3ASBT = DDC_H3A_INVALID_PARAM;
    }
    return resultH3ASBT;
}

/**
 * \brief DDC_H3AGetDeviceHandle
 * Return H3A Device Object
 */
static inline PSP_Handle DDC_H3AGetDeviceHandle(void)
{
    return(&ddcH3aDevObj);
}

/**
 * \brief DDC_AFSubmit
 * Proccess the request submitted by AF channel
 */
DDC_H3AStatus DDC_AFSubmit(PSP_Handle const handleAF, PSP_VPSSSubmitCommand cmd,
    Ptr cmdArg)
{
    Uint32  imask;
    DDC_AFChannelObject *ddcAFhandleSBMT = (DDC_AFChannelObject *)handleAF;
    DDC_H3ADeviceObject *ddcH3aDevObjAFSBMT
        = (DDC_H3ADeviceObject *)DDC_H3AGetDeviceHandle();
    PSP_H3ABuffer *elementAFSBMT;
    DDC_H3AStatus resultAFSBMT = DDC_H3A_SOK;
    if ((NULL != ddcAFhandleSBMT) &&( NULL != cmdArg))
    {
        /* Acquire the Lock */
        if (PAL_SOK
            != PAL_osSemTake (ddcAFhandleSBMT->sem, ddcAFhandleSBMT->semTimeOut))
        {
            resultAFSBMT = DDC_H3A_E_FAIL;
        }
        if (DDC_H3A_SOK == resultAFSBMT)
        {
            switch(cmd)
            {
                case PSP_VPSS_QUEUE:
                    if (NULL == cmdArg)
                    {
                        DDC_H3A_DEBUG_PRINT(
                            "DDC_AFSubmit Error : Invalid Argument\n");
                        elementAFSBMT=NULL;
                        resultAFSBMT = DDC_H3A_E_FAIL;
                    }
                    else
                    {
                        elementAFSBMT = (PSP_H3ABuffer *)cmdArg;
                    }
                    if ((DDC_H3A_SOK == resultAFSBMT)
                        && (DDC_H3A_ADD_CHECK
                            == ((Uint32)(elementAFSBMT->ramIpAddr)
                                & DDC_H3A_ADDRESS_MASK)))
                    {
                        if ((elementAFSBMT->size < ddcAFhandleSBMT->buffSize)
                            ||( STATE_NOT_CONFIGURED
                                == ddcAFhandleSBMT->configFlag)
                            )
                        {
                            DDC_H3A_DEBUG_PRINT("DDC_AFSubmit Error : \
                                \nBuffer Size is Invalid or State \
                                not configured\n");
                            resultAFSBMT = DDC_H3A_INVALID_PARAM;
                        }
                        if (DDC_H3A_SOK == resultAFSBMT)
                        {
                            /* Enqueue the elemnt */
                            PAL_osListEnqueue(&ddcAFhandleSBMT->buffObj.enQueue,
                                elementAFSBMT);

                            PAL_osProtectEntry(PAL_OSPROTECT_INTERRUPT, &imask);
                            ddcAFhandleSBMT->buffObj.indexEnQueue++;
                            PAL_osProtectExit(PAL_OSPROTECT_INTERRUPT, imask);

                            /* Enable the AF engine and set buffer address */
                            if (((DDC_H3A_QUEUE_FILLED
                                    == ddcAFhandleSBMT->buffObj.indexEnQueue)
                                && (NULL != ddcH3aDevObjAFSBMT))
                                && (NULL != elementAFSBMT->ramIpAddr))
                            {
#ifdef H3A_INSTRUMENTATION_ENABLED
                                PSP_LOG_EVENT(  &DVTEvent_Log,
                                                "H3A",
                                                PSP_DVT_DESC(
                                                PSP_DVT_eDATA_SND_START,
                                                PSP_DVT_dCHANNEL_ID_INST,
                                                PSP_DVT_dPACKET_ID,
                                                PSP_DVT_dNONE),
                                                CHANNELID_INSTANCEID(0,0),
                                                elementAFSBMT
                                            );
#endif /* H3A_INSTRUMENTATION_ENABLED */
                                LLC_AFClearWriteBuffer(
                                    (Ptr)CSL_VPSS_0_REGS);
                                LLC_SetAFBUFST(ddcH3aDevObjAFSBMT->regs,
                                    (Uint32)elementAFSBMT->ramIpAddr);
                                LLC_SetAFEngine((DDC_H3A_ENGINE_ENABLE),
                                    ddcH3aDevObjAFSBMT->regs);
                            }
                        }
                    }
                    else
                    {
                        DDC_H3A_DEBUG_PRINT("DDC_AFSubmit Error : \
                            Address should be 64 bit aligned\n");
                        resultAFSBMT = DDC_H3A_INVALID_PARAM;
                    }
                    break;

                case PSP_VPSS_DEQUEUE:
                    /* Check if queue is not empty */
                    if (( ddcAFhandleSBMT->buffObj.indexEnQueue
                            > DDC_H3A_QUEUE_EMPTY)
                        || (ddcAFhandleSBMT->buffObj.indexDeQueue
                            > DDC_H3A_QUEUE_EMPTY))
                    {
                        if ( PAL_SOK == PAL_osSemTake (ddcAFhandleSBMT->semISR,
                                DDC_H3A_TIMEOUT))
                        {
                            /* Set the adddress of the packet in the buffer
                               passsed by the application*/
                            elementAFSBMT = (PSP_H3ABuffer *)PAL_osListDequeue(
                                &ddcAFhandleSBMT->buffObj.deQueue);

                            if (PAL_SOK != PAL_osMemCopy(cmdArg, elementAFSBMT,
                                    sizeof(PSP_H3ABuffer)))
                            {
                                DDC_H3A_DEBUG_PRINT("DDC_AFSubmit Error : \
                                    Memory Copy Failed \n");
                                resultAFSBMT = DDC_H3A_NO_DATA;
                            }
                            else
                            {
                                PAL_osProtectEntry(PAL_OSPROTECT_INTERRUPT,
                                    &imask);
                                ddcAFhandleSBMT->buffObj.indexDeQueue--;
                                PAL_osProtectExit(PAL_OSPROTECT_INTERRUPT,
                                    imask);
                            }
                        }
                        else
                        {
                            resultAFSBMT = DDC_H3A_NO_DATA;
                        }
                    }
                    else
                    {
                        resultAFSBMT = DDC_H3A_NO_DATA;
                    }
                    break;

                default :
                    resultAFSBMT = DDC_H3A_E_FAIL;
                    break;
            }
        }

        /* Release the Lock */
        if ( PAL_SOK != PAL_osSemGive(ddcAFhandleSBMT->sem))
        {
            resultAFSBMT = DDC_H3A_E_FAIL;
        }
    }
    else
    {
        resultAFSBMT = DDC_H3A_INVALID_PARAM;
    }
    return resultAFSBMT;
}

/**
 * \brief DDC_AEWSubmit
 * Proccess the request submitted by AEW channel
 */
DDC_H3AStatus DDC_AEWSubmit(PSP_Handle const handleAEW,
    PSP_VPSSSubmitCommand cmd, Ptr cmdArg)
{
    Uint32  imask;
    DDC_AEWChannelObject *ddcAEWhandleSBMT = (DDC_AEWChannelObject *)handleAEW;
    DDC_H3ADeviceObject *ddcH3aDevObjAEWSBMT
        = (DDC_H3ADeviceObject *)DDC_H3AGetDeviceHandle();
    PSP_H3ABuffer *elementAEWSBMT;
    DDC_H3AStatus resultAEWSBMT = DDC_H3A_SOK;
    if ((NULL != ddcAEWhandleSBMT) && (NULL!= cmdArg))
    {
        /* Acquire the Lock */
        if (PAL_SOK
            != PAL_osSemTake (ddcAEWhandleSBMT->sem,
                              ddcAEWhandleSBMT->semTimeOut))
        {
            resultAEWSBMT = DDC_H3A_E_FAIL;
        }
        if (DDC_H3A_SOK == resultAEWSBMT)
        {
            switch(cmd)
            {
                case PSP_VPSS_QUEUE:
                    if (NULL == cmdArg)
                    {
                        elementAEWSBMT=NULL;
                        DDC_H3A_DEBUG_PRINT("DDC_AEWSubmit Error : \
                            Invalid Argument\n");
                        resultAEWSBMT = DDC_H3A_E_FAIL;
                    }
                    else
                    {
                        elementAEWSBMT = (PSP_H3ABuffer *)cmdArg;
                    }
                    if ((DDC_H3A_SOK == resultAEWSBMT)
                        && (DDC_H3A_ADD_CHECK
                            == ((Uint32)(elementAEWSBMT->ramIpAddr)
                                & DDC_H3A_ADDRESS_MASK)))
                    {
                        if ((elementAEWSBMT->size < ddcAEWhandleSBMT->buffSize)
                            || ( STATE_NOT_CONFIGURED
                                == ddcAEWhandleSBMT->configFlag)
                            )
                        {
                            DDC_H3A_DEBUG_PRINT("DDC_AEWSubmit Error : \
                                \nBuffer Size is Invalid or \
                                state not configured\n");
                            resultAEWSBMT = DDC_H3A_INVALID_PARAM;
                        }
                        if (DDC_H3A_SOK == resultAEWSBMT)
                        {
                            /* Enqueue the elemnt */
                            PAL_osListEnqueue(
                                &ddcAEWhandleSBMT->buffObj.enQueue,
                                elementAEWSBMT);

                            PAL_osProtectEntry(PAL_OSPROTECT_INTERRUPT, &imask);
                            ddcAEWhandleSBMT->buffObj.indexEnQueue++;
                            PAL_osProtectExit(PAL_OSPROTECT_INTERRUPT, imask);

                            /* Enable the AEW engine and set buffer address */
                            if (((DDC_H3A_QUEUE_FILLED
                                    == ddcAEWhandleSBMT->buffObj.indexEnQueue)
                                && (NULL != ddcH3aDevObjAEWSBMT))
                                && (NULL != elementAEWSBMT->ramIpAddr))
                            {
#ifdef H3A_INSTRUMENTATION_ENABLED
                                PSP_LOG_EVENT(  &DVTEvent_Log,
                                                "H3A",
                                                PSP_DVT_DESC(
                                                PSP_DVT_eDATA_SND_START,
                                                PSP_DVT_dCHANNEL_ID_INST,
                                                PSP_DVT_dPACKET_ID,
                                                PSP_DVT_dNONE),
                                                CHANNELID_INSTANCEID(1,0),
                                                elementAEWSBMT
                                            );
#endif /* H3A_INSTRUMENTATION_ENABLED */
                                LLC_AEWClearWriteBuffer(
                                    (Ptr)CSL_VPSS_0_REGS);
                                LLC_SetAEWBUFST(ddcH3aDevObjAEWSBMT->regs,
                                    (Uint32)elementAEWSBMT->ramIpAddr);
                                LLC_SetAEWEngine((DDC_H3A_ENGINE_ENABLE),
                                    ddcH3aDevObjAEWSBMT->regs);
                            }
                        }
                    }
                    else
                    {
                        DDC_H3A_DEBUG_PRINT("DDC_AEWSubmit Error : \
                            Address should be 64 bit aligned\n");
                        resultAEWSBMT = DDC_H3A_INVALID_PARAM;
                    }
                    break;

                case PSP_VPSS_DEQUEUE:
                    /* Check if queue is empty */
                    if (( ddcAEWhandleSBMT->buffObj.indexEnQueue
                            > DDC_H3A_QUEUE_EMPTY)
                        || (ddcAEWhandleSBMT->buffObj.indexDeQueue
                            > DDC_H3A_QUEUE_EMPTY))
                    {
                        if ( PAL_SOK == PAL_osSemTake (ddcAEWhandleSBMT->semISR,
                                DDC_H3A_TIMEOUT))
                        {
                            /* Set the adddress of the packet in the buffer
                               passsed by the application */
                            elementAEWSBMT = (PSP_H3ABuffer *)PAL_osListDequeue(
                                &ddcAEWhandleSBMT->buffObj.deQueue);
                            if (PAL_SOK != PAL_osMemCopy(cmdArg, elementAEWSBMT,
                                    sizeof(PSP_H3ABuffer)))
                            {
                                DDC_H3A_DEBUG_PRINT("DDC_AEWSubmit Error : \
                                    Memory Copy Failed \n");
                                resultAEWSBMT = DDC_H3A_NO_DATA;
                            }
                            else
                            {
                                PAL_osProtectEntry(PAL_OSPROTECT_INTERRUPT,
                                    &imask);
                                ddcAEWhandleSBMT->buffObj.indexDeQueue--;
                                PAL_osProtectExit(PAL_OSPROTECT_INTERRUPT,
                                    imask);
                            }
                        }
                        else
                        {
                            resultAEWSBMT = DDC_H3A_NO_DATA;
                        }
                    }
                    else
                    {
                        resultAEWSBMT = DDC_H3A_NO_DATA;
                    }
                    break;

                default :
                    resultAEWSBMT = DDC_H3A_E_FAIL;
                    break;
            }
        }
        /* Release the Lock */
        if ( PAL_SOK != PAL_osSemGive(ddcAEWhandleSBMT->sem))
        {
            resultAEWSBMT = DDC_H3A_E_FAIL;
        }
    }
    else
    {
        resultAEWSBMT = DDC_H3A_INVALID_PARAM;
    }
    return resultAEWSBMT;
}

/**
 * \brief DDC_H3AValidateBuffer
 * Validate the buffer sent by the application
 */
DDC_H3AStatus DDC_H3AValidateBuffer(Ptr const cmdArg,
    PSP_VPSSSubmitCommand cmd)
{
    DDC_H3AStatus resultVB = DDC_H3A_SOK;

    /* Check the packet is not NULL */
    if (NULL == cmdArg)
    {
        DDC_H3A_DEBUG_PRINT("DDC_H3AValidateBuffer Error : \
            Invalid Parameters\n ");
        resultVB = DDC_H3A_INVALID_PARAM;
    }
    else
    {
        if ((PSP_VPSS_QUEUE != cmd) && (PSP_VPSS_DEQUEUE != cmd))
        {
            DDC_H3A_DEBUG_PRINT("DDC_H3AValidateBuffer Error : \
                Invalid Command \n ");
            resultVB = DDC_H3A_INVALID_PARAM;
        }
    }
    return resultVB;
}

/**
 * \brief DDC_H3AIoctl
 * Validate the channel Handle and call corresponding function to handle I/O
 * Request
 */
DDC_H3AStatus DDC_H3AIoctl(PSP_Handle const chanhandle, PSP_H3AIoctlCmd cmd,
    Ptr const cmdArg, Ptr const params)
{
    Uint32 idIOCTL;
    DDC_H3AStatus resultIOTCL = DDC_H3A_SOK;
    if ( (NULL == cmdArg) || (NULL == chanhandle))
    {
        resultIOTCL =  DDC_H3A_INVALID_PARAM;
    }
    else
    {
        idIOCTL = *(Uint32 *)chanhandle;
        if (PSP_H3A_AF == idIOCTL)
        {
            resultIOTCL = DDC_AFIoctl(chanhandle, cmd, cmdArg, params);
        }
        else if (PSP_H3A_AEW == idIOCTL)
        {
            resultIOTCL = DDC_AEWIoctl(chanhandle, cmd, cmdArg, params);
        }
        else
        {
            DDC_H3A_DEBUG_PRINT("DDC_H3AIoctl Error : Invalid channel Id \n ");
            resultIOTCL = DDC_H3A_INVALID_PARAM;
        }
    }
    return resultIOTCL;
}

/**
 * \brief DDC_AFIoctl
 * Handle I/O Request sent by the AF Channel
 */
/* ARGSUSED */
DDC_H3AStatus DDC_AFIoctl(PSP_Handle const handleAF, PSP_H3AIoctlCmd cmd,
    Ptr const cmdArg, Ptr const OptParams)
{
    DDC_H3ADeviceObject *ddcH3aDevHandleAFIOCTL
        = (DDC_H3ADeviceObject *)DDC_H3AGetDeviceHandle();
    DDC_AFChannelObject *ddcAFhandleIOCTL = (DDC_AFChannelObject *)handleAF;
    DDC_H3AStatus resultAFIOCTL = DDC_H3A_SOK;
    Int hwStatusAF;
    if (((NULL != ddcAFhandleIOCTL) && (NULL != cmdArg))
        && (NULL != ddcH3aDevHandleAFIOCTL))
    {
        /* Acquire the Lock */
        if (PAL_SOK
            != PAL_osSemTake (ddcAFhandleIOCTL->sem,
                              ddcAFhandleIOCTL->semTimeOut))
        {
            resultAFIOCTL = DDC_H3A_E_FAIL;
        }

        switch(cmd)
        {
            case PSP_H3A_IOCTL_SET_PARAM:
                /* registers cannot be updated while engine is busy */
                hwStatusAF = LLC_GetBusyAF(ddcH3aDevHandleAFIOCTL->regs);

                if ((DDC_H3A_SOK == resultAFIOCTL)
                    && (DDC_H3A_ENGINE_NOTBUSY == hwStatusAF))
                {
                    resultAFIOCTL
                        = DDC_AFValidateParameters((PSP_AFParams *)cmdArg);

                    if (DDC_H3A_SOK == resultAFIOCTL)
                    {
                        if (PAL_SOK
                            != PAL_osMemCopy(&(ddcAFhandleIOCTL->params),
                                cmdArg, sizeof(PSP_AFParams)))
                        {
                            DDC_H3A_DEBUG_PRINT("DDC_AFIoctl Error : \
                                MemCopy Failed\n AF IOCTL Failed\n ");
                            resultAFIOCTL = DDC_H3A_E_FAIL;
                        }
                        if (DDC_H3A_SOK == resultAFIOCTL)
                        {
                            ddcAFhandleIOCTL->buffSize
                                = ddcAFhandleIOCTL->params.paxelConfig.vtCnt
                                * ddcAFhandleIOCTL->params.paxelConfig.hzCnt
                                * PSP_AF_PAXEL_SIZE;
                            ddcAFhandleIOCTL->configFlag = STATE_CONFIGURED;
                        }
                    }
                }
                else
                {
                    DDC_H3A_DEBUG_PRINT("DDC_AFIoctl Error: Engine is busy \n");
                }
                break;

            case PSP_H3A_IOCTL_GET_PARAM:
                resultAFIOCTL = DDC_AFGetParameters(ddcAFhandleIOCTL,
                    (PSP_AFParams *)cmdArg);
                break;

            case PSP_H3A_IOCTL_SET_SEM_TIMEOUT:
                {
                    if (NULL != cmdArg)
                    {
                        /* Change the semTimeOut value */
                        ddcAFhandleIOCTL->semTimeOut = *(Int32 *)cmdArg;
                        resultAFIOCTL = DDC_H3A_SOK;
                    }
                    else
                    {
                        resultAFIOCTL = DDC_H3A_INVALID_PARAM;
                    }
                }
                break;

            default:
                DDC_H3A_DEBUG_PRINT("DDC_AFIoctl Error : Invalid Command \n");
                resultAFIOCTL = DDC_H3A_INVALID_PARAM;
                break;
        }
        /* release the lock */
        if (PAL_SOK != PAL_osSemGive(ddcAFhandleIOCTL->sem))
        {
            resultAFIOCTL = DDC_H3A_E_FAIL;
        }
    }
    else
    {
        DDC_H3A_DEBUG_PRINT("DDC_AFIoctl Error : IOCTL Failed\n ");
        resultAFIOCTL = DDC_H3A_INVALID_PARAM;
    }
    return resultAFIOCTL;
}

/**
 * \brief DDC_AEWIoctl
 * Handle I/O Request sent by the AEW Channel
 */
/* ARGSUSED */
DDC_H3AStatus DDC_AEWIoctl(PSP_Handle const handleAEW, PSP_H3AIoctlCmd cmd,
    Ptr const cmdArg, Ptr const OptParams)
{
    DDC_H3ADeviceObject *ddcH3aDevHandleAEWIOCTL
        = (DDC_H3ADeviceObject *)DDC_H3AGetDeviceHandle();
    DDC_AEWChannelObject *ddcAEWhandleIOCTL = (DDC_AEWChannelObject *)handleAEW;
    DDC_H3AStatus resultAEWIOCTL = DDC_H3A_SOK;
    Int hwStatusAEW;
    if (((NULL != ddcAEWhandleIOCTL) && (NULL != cmdArg))
        && (NULL != ddcH3aDevHandleAEWIOCTL))
    {
        /* Acquire the Lock */
        if (PAL_SOK != PAL_osSemTake (ddcAEWhandleIOCTL->sem,
                                      ddcAEWhandleIOCTL->semTimeOut))
        {
            resultAEWIOCTL = DDC_H3A_E_FAIL;
        }
        switch(cmd)
        {
            case PSP_H3A_IOCTL_SET_PARAM:
                /* registers cannot be updated while engine is busy */
                hwStatusAEW = LLC_GetBusyAEW(ddcH3aDevHandleAEWIOCTL->regs);

                if ((DDC_H3A_SOK == resultAEWIOCTL)
                    && (DDC_H3A_ENGINE_NOTBUSY == hwStatusAEW))
                {
                    resultAEWIOCTL
                        = DDC_AEWValidateParameters((PSP_AEWParams *)cmdArg);

                    if (DDC_H3A_SOK == resultAEWIOCTL)
                    {
                        if (PAL_SOK
                            != PAL_osMemCopy(&(ddcAEWhandleIOCTL->params),
                                cmdArg, sizeof(PSP_AEWParams)))
                        {
                            DDC_H3A_DEBUG_PRINT("DDC_AEWIoctl Error : \
                                MemCopy Failed\n AEW IOCTL Failed\n ");
                            resultAEWIOCTL = DDC_H3A_E_FAIL;
                        }
                        if (DDC_H3A_SOK == resultAEWIOCTL)
                        {
                            ddcAEWhandleIOCTL->configFlag = STATE_CONFIGURED;
                            ddcAEWhandleIOCTL->buffSize
                                = ddcAEWhandleIOCTL->params.winConfig.vtCnt
                                * ddcAEWhandleIOCTL->params.winConfig.hzCnt
                                * PSP_AEW_WIN_SIZE;
                        }
                    }
                }
                else
                {
                    DDC_H3A_DEBUG_PRINT("DDC_AEWIoctl Error: Engine is busy\n");
                }
                break;

            case PSP_H3A_IOCTL_GET_PARAM:
                resultAEWIOCTL = DDC_AEWGetParameters(ddcAEWhandleIOCTL,
                    (PSP_AEWParams *)cmdArg);
                break;

            case PSP_H3A_IOCTL_SET_SEM_TIMEOUT:
                {
                    if (NULL != cmdArg)
                    {
                        /* Change the semTimeOut value */
                        ddcAEWhandleIOCTL->semTimeOut = *(Int32 *)cmdArg;
                        resultAEWIOCTL = DDC_H3A_SOK;
                    }
                    else
                    {
                        resultAEWIOCTL = DDC_H3A_INVALID_PARAM;
                    }
                }
                break;

            default:
                DDC_H3A_DEBUG_PRINT("DDC_AEWIoctl Error : Invalid Command \n");
                resultAEWIOCTL = DDC_H3A_INVALID_PARAM;
                break;
        }
        /* release the lock */
        if (PAL_SOK != PAL_osSemGive(ddcAEWhandleIOCTL->sem))
        {
            resultAEWIOCTL = DDC_H3A_E_FAIL;
        }
    }
    else
    {
        DDC_H3A_DEBUG_PRINT("DDC_AEWIoctl Error : IOCTL Failed\n ");
        resultAEWIOCTL = DDC_H3A_INVALID_PARAM;
    }
    return resultAEWIOCTL;
}

/**
 * \brief DDC_AFGetChannelHandle
 * Get AF channel Handle
 */
static inline PSP_Handle DDC_AFGetChannelHandle(void)
{
    return (PSP_Handle)&ddcH3aDevObj.chanAF;
}

/**
 * \brief DDC_AEWGetChannelHandle
 * Get AEW channel Handle
 */
static inline PSP_Handle DDC_AEWGetChannelHandle(void)
{
    return (PSP_Handle)&ddcH3aDevObj.chanAEW;
}

/**
 * \brief DDC_H3ARegisterOverlaying
 * Perform the register Overlaying function for AF and AEW
 */
void DDC_H3ARegisterOverlaying(void)
{
    DDC_H3ADeviceObject *ddcH3aDevHandleRO
        = (DDC_H3ADeviceObject *)DDC_H3AGetDeviceHandle();

    if (NULL == ddcH3aDevHandleRO)
    {
        DDC_H3A_DEBUG_PRINT("DDC_H3ARegisterOverlaying Error: \
            Device Handle NULL");
    }
    else
    {
        ddcH3aDevHandleRO->regs = (Ptr)CSL_VPSS_H3A_0_REGS;
        /* Reset the registers */
        if (CSL_SOK != LLC_H3AResetPCRRegister(ddcH3aDevHandleRO->regs))
        {
            DDC_H3A_DEBUG_PRINT("\n DDC_H3ARegisterOverlaying: \
                Error: Failed to initialize the register");
        }
        if ( CSL_SOK !=  LLC_AEWInitRegister(ddcH3aDevHandleRO->regs))
        {
            DDC_H3A_DEBUG_PRINT("\n DDC_H3ARegisterOverlaying: Error: \
                Failed to initialize the register");
        }
        if ( CSL_SOK != LLC_AFInitRegister(ddcH3aDevHandleRO->regs))
        {
            DDC_H3A_DEBUG_PRINT("\n DDC_H3ARegisterOverlaying: Error: \
                Failed to initialize the register");
        }
        /* Clear Write Buffer Overflow Bit */
        LLC_AFClearWriteBuffer((Ptr)CSL_VPSS_0_REGS);
        LLC_AEWClearWriteBuffer((Ptr)CSL_VPSS_0_REGS);
    }
}

/**
 * \brief DDC_AFIsr
 * Interrupt service routine for AF Channel
 */
void DDC_AFIsr(void)
{
    PSP_H3ABuffer *elementAFISR, *elementAFISRNextBuffer;
    DDC_H3ADeviceObject *ddcH3aDevObjAFISR
        = (DDC_H3ADeviceObject *)DDC_H3AGetDeviceHandle();
    DDC_AFChannelObject *ddcAFchanHandleISR
        = (DDC_AFChannelObject *)DDC_AFGetChannelHandle();
    if ((NULL != ddcAFchanHandleISR) && (NULL != ddcH3aDevObjAFISR))
    {
        if ((NULL != ddcH3aDevObjAFISR->regs)
            && ((ddcAFchanHandleISR->buffObj.indexEnQueue)
                > DDC_H3A_QUEUE_EMPTY))
        {
            /* check if queue is empty */
            /* Here (ddcAFchanHandleISR->buffObj.indexEnQueue - (1u))
             * will indicate whether element is the last element in
             * the queue or not*/
            if ( DDC_H3A_QUEUE_EMPTY
                == (ddcAFchanHandleISR->buffObj.indexEnQueue - (1u)))
            {
                /* Disable the engine */
                LLC_SetAFEngine(DDC_H3A_ENGINE_DISABLE,
                    ddcH3aDevObjAFISR->regs);
            }
            else
            {
                /* Remove the next buffer Address from Enqueue */
                elementAFISR = (PSP_H3ABuffer *)
                    (ddcAFchanHandleISR->buffObj.enQueue.next);
                if (NULL != elementAFISR)
                {
                    elementAFISRNextBuffer = (elementAFISR->nodeEntry.next);
                    if ((NULL != elementAFISRNextBuffer)
                        && (NULL != elementAFISRNextBuffer->ramIpAddr))
                    {
                        /* Set address of next buffer in the register */
                        LLC_SetAFBUFST(ddcH3aDevObjAFISR->regs,
                            (Uint32)elementAFISRNextBuffer->ramIpAddr);
                    }
                }
            }
            /* Remove the buffer containing statistics */
            elementAFISR = (PSP_H3ABuffer *)PAL_osListDequeue(
                &(ddcAFchanHandleISR->buffObj.enQueue));
            elementAFISR->timeStamp = CLK_getltime();
            ddcAFchanHandleISR->buffObj.indexEnQueue--;
            if (NULL != elementAFISR)
            {
                if (NULL != elementAFISR->ramIpAddr)
                {
                    /* Socrates Implementation For AF Channel */
#ifdef H3A_INSTRUMENTATION_ENABLED
                    PSP_LOG_EVENT( &DVTEvent_Log, "H3A", PSP_DVT_DESC
                                    (   PSP_DVT_eDATA_SND_END,
                                        PSP_DVT_dCHANNEL_ID_INST,
                                        PSP_DVT_dPACKET_ID,
                                        PSP_DVT_dNONE),
                                    CHANNELID_INSTANCEID(0,0),
                                    elementAFISR); /* channel 0 for AF */
#endif /* H3A_INSTRUMENTATION_ENABLED */

                    if (PSP_H3A_BUFFER_DATA_VALID
                        == LLC_AFGetWriteBufferStatus((Ptr)CSL_VPSS_0_REGS))
                    {
                        elementAFISR->buffStatus = PSP_H3A_BUFFER_DATA_VALID;
                    }
                    else
                    {
                        elementAFISR->buffStatus
                            = PSP_H3A_BUFFER_DATA_CORRUPTED;
                        LLC_AFClearWriteBuffer ((Ptr)CSL_VPSS_0_REGS);
                    }

                    /* push the buffer into dequeue */
                    PAL_osListEnqueue(&(ddcAFchanHandleISR->buffObj.deQueue),
                        elementAFISR);
                    ddcAFchanHandleISR->buffObj.indexDeQueue++;

                    if (PAL_SOK != PAL_osSemGive (ddcAFchanHandleISR->semISR))
                    {
                        DDC_H3A_DEBUG_PRINT(
                                "DDC_AFIsr Error: Error giving semaphore");
                    }
                }
            }
        }
    }
}

/**
 * \brief DDC_AEWIsr
 * Interrupt service routine for AEW Channel
 */
void DDC_AEWIsr(void)
{
    PSP_H3ABuffer *elementAEWISR, *elementAEWISRNextBuffer;
    DDC_H3ADeviceObject *ddcH3aDevObjAEWISR
        = (DDC_H3ADeviceObject *)DDC_H3AGetDeviceHandle();
    DDC_AEWChannelObject *ddcAEWchanHandleISR
        = (DDC_AEWChannelObject *)DDC_AEWGetChannelHandle();
    if ((NULL != ddcAEWchanHandleISR) && (NULL != ddcH3aDevObjAEWISR))
    {
        if ((NULL != ddcH3aDevObjAEWISR->regs)
            && ((ddcAEWchanHandleISR->buffObj.indexEnQueue)
                > DDC_H3A_QUEUE_EMPTY))
        {
            /* check if queue is empty */
            /* Here (ddcAFchanHandleISR->buffObj.indexEnQueue - (1u))
             * will indicate whether element is the last element in the
             * queue or not*/
            if (DDC_H3A_QUEUE_EMPTY
                == (ddcAEWchanHandleISR->buffObj.indexEnQueue - (1u)))
            {
                /* Disable the engine */
                LLC_SetAEWEngine(DDC_H3A_ENGINE_DISABLE,
                    ddcH3aDevObjAEWISR->regs);
            }
            else
            {
                /* Remove the next buffer Address from Enqueue */
                elementAEWISR = (PSP_H3ABuffer *)
                    (ddcAEWchanHandleISR->buffObj.enQueue.next);
                if (NULL != elementAEWISR)
                {
                    elementAEWISRNextBuffer = (elementAEWISR->nodeEntry.next);
                    if ((NULL != elementAEWISRNextBuffer)
                        && (NULL != elementAEWISRNextBuffer->ramIpAddr))
                    {
                        /* Set address of next buffer in the register */
                        LLC_SetAEWBUFST(ddcH3aDevObjAEWISR->regs,
                            (Uint32)elementAEWISRNextBuffer->ramIpAddr);
                    }
                }
            }
            /* Remove the buffer containing statistics */
            elementAEWISR = (PSP_H3ABuffer *)PAL_osListDequeue(
                &(ddcAEWchanHandleISR->buffObj.enQueue));
            elementAEWISR->timeStamp = CLK_getltime();
            ddcAEWchanHandleISR->buffObj.indexEnQueue--;

            if (NULL != elementAEWISR)
            {
                if (NULL != elementAEWISR->ramIpAddr)
                {
                    /* Socrates Implementation For AEW Channel */
#ifdef H3A_INSTRUMENTATION_ENABLED
                    PSP_LOG_EVENT( &DVTEvent_Log, "H3A", PSP_DVT_DESC
                                    (   PSP_DVT_eDATA_SND_END,
                                        PSP_DVT_dCHANNEL_ID_INST,
                                        PSP_DVT_dPACKET_ID,
                                        PSP_DVT_dNONE),
                                    CHANNELID_INSTANCEID(1,0),
                                    elementAEWISR); /* channel 0 for AF */
#endif /* H3A_INSTRUMENTATION_ENABLED */
                    if (PSP_H3A_BUFFER_DATA_VALID
                        == LLC_AEWGetWriteBufferStatus((Ptr)CSL_VPSS_0_REGS))
                    {
                        elementAEWISR->buffStatus = PSP_H3A_BUFFER_DATA_VALID;
                    }
                    else
                    {
                        elementAEWISR->buffStatus
                            = PSP_H3A_BUFFER_DATA_CORRUPTED;
                        LLC_AEWClearWriteBuffer ((Ptr)CSL_VPSS_0_REGS);
                    }

                    /* push the buffer into dequeue */
                    PAL_osListEnqueue(&(ddcAEWchanHandleISR->buffObj.deQueue),
                        elementAEWISR);
                    ddcAEWchanHandleISR->buffObj.indexDeQueue++;

                    if (PAL_SOK != PAL_osSemGive (ddcAEWchanHandleISR->semISR))
                    {
                        DDC_H3A_DEBUG_PRINT(
                                "DDC_AEWIsr Error: Error giving semaphore");
                    }

                }
            }
        }
    }
}

/**
 * \brief DDC_AFGetParameters
 * Returns the configurations of AF engine
 */
DDC_H3AStatus DDC_AFGetParameters(DDC_AFChannelObject * const handleAF,
    PSP_AFParams *const params)
{
    DDC_H3AStatus resultAFGP = DDC_H3A_SOK;
    if ((NULL != handleAF) && (NULL != params))
    {
        if ( STATE_NOT_CONFIGURED == handleAF->configFlag)
        {
            DDC_H3A_DEBUG_PRINT("DDC_AFGetParameters Error : \
                Hardware is not Configured \n");
            resultAFGP = DDC_H3A_INVALID_STATE;
        }
        else
        {
            if (PAL_SOK != PAL_osMemCopy(params, &handleAF->params,
                    sizeof(PSP_AFParams)))
            {
                DDC_H3A_DEBUG_PRINT("DDC_AFGetParameters Error : \
                    get Paramters Failed\n");
                resultAFGP = DDC_H3A_E_FAIL;
            }
        }
    }
    else
    {
        DDC_H3A_DEBUG_PRINT("DDC_AFGetParameters Error : \
            Get Parameters Failed\n");
        resultAFGP = DDC_H3A_INVALID_PARAM;
    }
    return resultAFGP;
}

/**
 * \brief DDC_AEWGetParameters
 * Returns the configurations of AEW engine
 */
DDC_H3AStatus DDC_AEWGetParameters(DDC_AEWChannelObject *const handleAEW,
    PSP_AEWParams *const params)
{
    DDC_H3AStatus resultAEWGP = DDC_H3A_SOK;
    if ((NULL != handleAEW) && (NULL != params))
    {
        if ( STATE_NOT_CONFIGURED == handleAEW->configFlag)
        {
            DDC_H3A_DEBUG_PRINT("DDC_AEWGetParameters Error : \
                Hardware is not Configured\n");
            resultAEWGP = DDC_H3A_INVALID_STATE;
        }
        else
        {
            if (PAL_SOK != PAL_osMemCopy(params, &handleAEW->params,
                    sizeof(PSP_AEWParams)))
            {
                DDC_H3A_DEBUG_PRINT("DDC_AEWGetParameters Error: \
                    get Paramters Failed\n");
                resultAEWGP = DDC_H3A_E_FAIL;
            }
        }
    }
    else
    {
        resultAEWGP = DDC_H3A_INVALID_PARAM;
    }
    return resultAEWGP;
}

/**
 * \brief DDC_H3AInitializeModule
 * Initialize the driver instance parameters.
 */
/* ARGSUSED */
PSP_Handle DDC_H3AInitializeModule (Uint32 instance)
{
    DDC_H3ADeviceObject *ddcH3aDevHandleIM
        = (DDC_H3ADeviceObject *)DDC_H3AGetDeviceHandle();
    if (NULL != ddcH3aDevHandleIM)
    {
        if (PSP_H3A_DELETED != ddcH3aDevHandleIM->state)
        {
            DDC_H3A_DEBUG_PRINT("DDC_H3AInitializeModule Error :  \
                Device already exists\n");
            ddcH3aDevHandleIM = NULL;
        }
        if (NULL != ddcH3aDevHandleIM)
        {
            ddcH3aDevHandleIM->state = PSP_H3A_CREATED;
            /* Update Channel State to Closed */
            ddcH3aDevHandleIM->chanAF.state = DDC_H3ACHANCLOSED;
            ddcH3aDevHandleIM->chanAEW.state = DDC_H3ACHANCLOSED;
        }
    }
    else
    {
        DDC_H3A_DEBUG_PRINT("DDC_H3AInitializeModule Error : \
            Device creation Failed\n");
    }
    return (PSP_Handle)ddcH3aDevHandleIM;
}

/**
 * \brief DDC_H3ASetInterruptNumber
 * Set the interrupt number
 */
void DDC_H3ASetInterruptNumber(void)
{
    DDC_H3ADeviceObject *ddcH3aDevHandleSIN
        = (DDC_H3ADeviceObject *)DDC_H3AGetDeviceHandle();
    if (NULL != ddcH3aDevHandleSIN)
    {
        ddcH3aDevHandleSIN->intNum = CSL_INTC_EVENTID_H3AINT;
    }
}

/**
 * \brief DDC_H3ARemoveModule
 * Deinitialize the device
 */
/* ARGSUSED */
PSP_Handle DDC_H3ARemoveModule (Uint32 instance)
{
    DDC_H3ADeviceObject *ddcH3aDevHandleRM
        = (DDC_H3ADeviceObject *)DDC_H3AGetDeviceHandle();
    if (NULL != ddcH3aDevHandleRM)
    {
        if ((PSP_H3A_CREATED != ddcH3aDevHandleRM->state)
            && (PSP_H3A_CLOSED  != ddcH3aDevHandleRM->state))
        {
            DDC_H3A_DEBUG_PRINT("DDC_H3ARemoveModule Error : Device in use \n");
        }
        else
        {
            /* set state to deleted */
            ddcH3aDevHandleRM = NULL;
            ddcH3aDevHandleRM->state = PSP_H3A_DELETED;
        }
    }
    else
    {
        DDC_H3A_DEBUG_PRINT("DDC_H3ARemoveModule Error : \
            Device deletion failed \n");
    }
    return (PSP_Handle)ddcH3aDevHandleRM;
}
/**
 * \brief DDC_H3Aisr
 * Interrupt Service Routine
 */
void DDC_H3Aisr(void)
{
    Int32  afStatus, aewStatus, busyaf, busyaew ;
    DDC_H3ADeviceObject *ddcH3aDevObjH3AISR
        = (DDC_H3ADeviceObject *)DDC_H3AGetDeviceHandle();

#ifdef H3A_INSTRUMENTATION_ENABLED
    PSP_LOG_EVENT( &DVTEvent_Log, "H3A", PSP_DVT_DESC
                    (   PSP_DVT_eINT_START,
                        PSP_DVT_dNONE,
                        PSP_DVT_dNONE,
                        PSP_DVT_dNONE));
#endif

    if (NULL != ddcH3aDevObjH3AISR)
    {
        if (NULL != ddcH3aDevObjH3AISR->regs)
        {
            /* Get busy bit for AEW */
            busyaew = LLC_GetBusyAEW(ddcH3aDevObjH3AISR->regs);
            /* Get busy bit for AF */
            busyaf = LLC_GetBusyAF(ddcH3aDevObjH3AISR->regs);

            /* Get AF Engine Status */
            afStatus = LLC_GetAFHWStatus(ddcH3aDevObjH3AISR->regs);
            /* Get AEW Engine Status */
            aewStatus = LLC_GetAEWHWStatus(ddcH3aDevObjH3AISR->regs);

            /* The interrupt is generated by AF Engine */
            if ((DDC_H3A_ENGINE_NOTBUSY == busyaf)
                && (DDC_H3A_ENGINE_ENABLE == afStatus))
            {
                /* Call Interrupt service routine of Af */
                DDC_AFIsr();
            }

            /* The interrupt is generated by AEW Engine */
            if ((DDC_H3A_ENGINE_NOTBUSY == busyaew)
                && (DDC_H3A_ENGINE_ENABLE == aewStatus))
            {
                /* Call Interrupt service routine of AEW */
                DDC_AEWIsr();
            }
        }
    }

#ifdef H3A_INSTRUMENTATION_ENABLED
    PSP_LOG_EVENT( &DVTEvent_Log, "H3A", PSP_DVT_DESC
                    (   PSP_DVT_eINT_END,
                        PSP_DVT_dNONE,
                        PSP_DVT_dNONE,
                        PSP_DVT_dNONE));
#endif

}

/**
 * \brief DDC_AFValidateParameters
 * Validate the paramters for AF
 */
DDC_H3AStatus DDC_AFValidateParameters(PSP_AFParams *const paramsaf)
{
    DDC_H3AStatus resultAFVP = DDC_H3A_SOK;
    Int32 count=0;
    DDC_H3ADeviceObject *ddcH3aDevHandleAFVP = DDC_H3AGetDeviceHandle();
    if ((NULL != paramsaf) && (NULL != ddcH3aDevHandleAFVP))
    {
        /* Check horizontal and vertical Count */
        if ((paramsaf->paxelConfig.hzCnt > DDC_AF_MAX_HZCOUNT)
            || (paramsaf->paxelConfig.hzCnt < DDC_AF_MIN_HZCOUNT))
        {
            DDC_H3A_DEBUG_PRINT("DDC_AFValidateParameters Error : \
                Invalid params (incorrect horizontal count) \n");
            resultAFVP = DDC_H3A_INVALID_PARAM;
        }
        if ((paramsaf->paxelConfig.vtCnt > DDC_AF_MAX_VTCOUNT)
            || (paramsaf->paxelConfig.vtCnt < DDC_AF_MIN_VTCOUNT))
        {
            DDC_H3A_DEBUG_PRINT("DDC_AFValidateParameters Error : \
                Invalid params (incorrect vertical count) \n");
            resultAFVP = DDC_H3A_INVALID_PARAM;
        }

        /* Check Widht Height Which are required to be even */
        if ((DDC_H3A_NOT_EVEN == DDC_H3A_ISEVEN(paramsaf->paxelConfig.height))
            || ((paramsaf->paxelConfig.height < DDC_AF_MIN_HEIGHT)
                || (paramsaf->paxelConfig.height > DDC_AF_MAX_HEIGHT)))
        {
            DDC_H3A_DEBUG_PRINT("DDC_AFValidateParameters Error: \
                Invalid params (invalid height)\n");
            resultAFVP =  DDC_H3A_INVALID_PARAM;
        }
        if ((DDC_H3A_NOT_EVEN == DDC_H3A_ISEVEN(paramsaf->paxelConfig.width))
            || ((paramsaf->paxelConfig.width < DDC_AF_MIN_WIDTH)
                || (paramsaf->paxelConfig.width > DDC_AF_MAX_WIDTH)))
        {
            DDC_H3A_DEBUG_PRINT("DDC_AFValidateParameters Error : \
                Invalid params invalid width \n");
            resultAFVP =  DDC_H3A_INVALID_PARAM;
        }
        /* Check horizontal Start */
        if (((paramsaf->paxelConfig.hzStart < DDC_AF_MIN_HZSTART)
                || (paramsaf->paxelConfig.hzStart
                    < (paramsaf->iirConfig.hzStarPos + (DDC_H3A_HZ_START_OFF))))
            || ((DDC_H3A_NOT_EVEN
                    == DDC_H3A_ISEVEN(paramsaf->paxelConfig.hzStart))
                || (paramsaf->paxelConfig.hzStart > DDC_AF_MAX_HZSTART)))
        {
            DDC_H3A_DEBUG_PRINT("DDC_AFValidateParameters Error : \
                Invalid params (incorrect horizontal Start)\n");
            resultAFVP =  DDC_H3A_INVALID_PARAM;
        }

        /* check vertical start */
        if (paramsaf->paxelConfig.vtStart > DDC_AF_MAX_VTSTART)
        {
            DDC_H3A_DEBUG_PRINT("DDC_AFValidateParameters Error: \
                Invalid params (incorrect vertical Start)\n");
            resultAFVP =  DDC_H3A_INVALID_PARAM;
        }

        /* check IIR Filter horixontal Start Position */
        if ((DDC_H3A_NOT_EVEN == DDC_H3A_ISEVEN(paramsaf->iirConfig.hzStarPos))
            || (paramsaf->iirConfig.hzStarPos > DDC_AF_MAX_IIRSH))
        {
            DDC_H3A_DEBUG_PRINT("DDC_AFValidateParameters Error: \
                Invalid params (incorrect IIR \
                    Filter horixontal Start Position)\n");
            resultAFVP =  DDC_H3A_INVALID_PARAM;
        }

        /* check line increment value */
        if ((DDC_H3A_NOT_EVEN == DDC_H3A_ISEVEN(paramsaf->paxelConfig.lineIncr))
            || ((paramsaf->paxelConfig.lineIncr < DDC_AF_MIN_LINE_INCR)
                || (paramsaf->paxelConfig.lineIncr > DDC_AF_MAX_LINE_INCR)))
        {
            DDC_H3A_DEBUG_PRINT("DDC_AFValidateParameters Error: \
                Invalid params (incorrect Line increment)\n");
            resultAFVP =  DDC_H3A_INVALID_PARAM;
        }
        /* Check IIR FILTER Threshold Filter */
        if ((paramsaf->hmfConfig.threshold > DDC_AF_HMF_MEDTH_MAX)
            && (paramsaf->hmfConfig.enable == PSP_AF_HMF_ENABLE))
        {
            DDC_H3A_DEBUG_PRINT("DDC_AFValidateParameters Error: \
                Invalid params (incorrect Median Fitler threshold)\n");
            resultAFVP =  DDC_H3A_INVALID_PARAM;
        }

        /* Check Filter Coefficient for filter 0 */
        for(count=0;count<PSP_AF_NUMBER_OF_COEF;count++)
        {
            /* Check whether coefficients are in range of -2^11 to 2^11-1*/
            if ((paramsaf->iirConfig.coeffSet0[count]
                    < DDC_AF_MIN_COEF)
                || (paramsaf->iirConfig.coeffSet0[count]
                    > DDC_AF_MAX_COEF))
            {
                DDC_H3A_DEBUG_PRINT("DDC_AFValidateParameters Error: \
                    Invalid params (incorrect coeffient for filter 0 )\n");
                resultAFVP =  DDC_H3A_INVALID_PARAM;
                break;
            }
        }
        /* Check Filter Coefficient for filter 1 */
        for(count=0;count<PSP_AF_NUMBER_OF_COEF;count++)
        {
            /* Check whether coefficients are in range of -2^11 to 2^11-1*/
            if ((paramsaf->iirConfig.coeffSet1[count]
                    < DDC_AF_MIN_COEF)
                || (paramsaf->iirConfig.coeffSet1[count]
                    > DDC_AF_MAX_COEF))
            {
                DDC_H3A_DEBUG_PRINT("DDC_AFValidateParameters Error: \
                    Invalid params (incorrect coeffient for filter1 )\n");
                resultAFVP =  DDC_H3A_INVALID_PARAM;
                break;
            }
        }
        /* Check A Law value */
        if ((paramsaf->enable < PSP_AF_ALAW_DISABLE)
            || (paramsaf->enable > PSP_AF_ALAW_ENABLE))
        {
            DDC_H3A_DEBUG_PRINT("DDC_AFValidateParameters Error: \
                Invalid params (incorrect ALaw Setting)\n");
            resultAFVP =  DDC_H3A_INVALID_PARAM;
        }
        /* Check RGBPOSITION VALUE */
        if ((paramsaf->rgbPos < PSP_AF_GR_GB_BAYER)
            || (paramsaf->rgbPos > PSP_AF_RB_GG_CUSTOM))
        {
            DDC_H3A_DEBUG_PRINT("DDC_AFValidateParameters Error: \
                Invalid params (incorrect RGBPOS Value)\n");
            resultAFVP =  DDC_H3A_INVALID_PARAM;
        }
        /* Check Horizontal Median Filter value */
        if ((paramsaf->hmfConfig.enable < PSP_AF_HMF_DISABLE)
            || (paramsaf->hmfConfig.enable > PSP_AF_HMF_ENABLE))
        {
            DDC_H3A_DEBUG_PRINT("DDC_AFValidateParameters Error: \
                Invalid params (incorrect Median Filter  Setting)\n");
            resultAFVP =  DDC_H3A_INVALID_PARAM;
        }
        /* Check Accumulator Mode */
        if ((paramsaf->mode < PSP_AF_ACCUMULATOR_SUMMED)
            || (paramsaf->mode > PSP_AF_ACCUMULATOR_PEAK))
        {
            DDC_H3A_DEBUG_PRINT("DDC_AFValidateParameters Error: \
                Invalid params (incorrect Accumulator Mode)\n");
            resultAFVP =  DDC_H3A_INVALID_PARAM;
        }
        if ((NULL != ddcH3aDevHandleAFVP->regs)
            && (DDC_H3A_SOK == resultAFVP))
        {
            /* configure hardware registers */
            if ( CSL_SOK != LLC_AFHardwareSetup(paramsaf,
                    ddcH3aDevHandleAFVP->regs))
            {
                DDC_H3A_DEBUG_PRINT("DDC_AFValidateParameters Error : \
                    Failed to set register \n");
                resultAFVP = DDC_H3A_E_FAIL;
            }
        }
        else
        {
            DDC_H3A_DEBUG_PRINT("DDC_AFValidateParameters Error : \
                Failed to set register \n");
            resultAFVP = DDC_H3A_E_FAIL;
        }
    }
    else
    {
        DDC_H3A_DEBUG_PRINT("DDC_AFValidateParameters Error : \
            Invalid Paramters \n");
        resultAFVP = DDC_H3A_INVALID_PARAM;
    }
    return resultAFVP;
}

/**
 * \brief DDC_AEWValidateParameters
 * Validate the paramters for AEW
 */
DDC_H3AStatus DDC_AEWValidateParameters(PSP_AEWParams *const paramsaew)
{
    DDC_H3AStatus resultAEWVP = DDC_H3A_SOK;
    DDC_H3ADeviceObject *ddcH3aDevHandleAEWVP = DDC_H3AGetDeviceHandle();
    if ((NULL != paramsaew) && (NULL != ddcH3aDevHandleAEWVP))
    {
        /* Check horizontal and vertical Count */
        if ((paramsaew->winConfig.hzCnt > DDC_AEW_MAX_HZCOUNT)
            || (paramsaew->winConfig.hzCnt < DDC_AEW_MIN_HZCOUNT))
        {
            DDC_H3A_DEBUG_PRINT("DDC_AEWValidateParameters Error : \
                Invalid params (horizontal count) \n");
            resultAEWVP = DDC_H3A_INVALID_PARAM;
        }
        if ((paramsaew->winConfig.vtCnt > DDC_AEW_MAX_VTCOUNT)
            || (paramsaew->winConfig.vtCnt < DDC_AEW_MIN_VTCOUNT))
        {
            DDC_H3A_DEBUG_PRINT("DDC_AEWValidateParameters Error : \
                Invalid params ( vertical count) \n");
            resultAEWVP = DDC_H3A_INVALID_PARAM;
        }
        /* Check Widht Height Which are required to be even */
        if ((DDC_H3A_NOT_EVEN == DDC_H3A_ISEVEN(paramsaew->winConfig.height))
            || ((paramsaew->winConfig.height < DDC_AEW_MIN_HEIGHT)
                || (paramsaew->winConfig.height > DDC_AEW_MAX_HEIGHT)))
        {
            DDC_H3A_DEBUG_PRINT("DDC_AEWValidateParameters Error : \
                Invalid params invalid  height\n");
            resultAEWVP =  DDC_H3A_INVALID_PARAM;
        }
        if ((DDC_H3A_NOT_EVEN == DDC_H3A_ISEVEN(paramsaew->winConfig.width))
            || ((paramsaew->winConfig.width < DDC_AEW_MIN_WIDTH)
                || (paramsaew->winConfig.width > DDC_AEW_MAX_WIDTH)))
        {
            DDC_H3A_DEBUG_PRINT("DDC_AEWValidateParameters Error : \
                Invalid params invalid width \n");
            resultAEWVP =  DDC_H3A_INVALID_PARAM;
        }
        /* Check horizontal Start */
        if ((DDC_H3A_NOT_EVEN == DDC_H3A_ISEVEN(paramsaew->winConfig.hzStart))
            || (paramsaew->winConfig.hzStart > DDC_AEW_MAX_HZSTART))
        {
            DDC_H3A_DEBUG_PRINT("DDC_AEWValidateParameters Error : \
                Invalid params (horizontal start)\n");
            resultAEWVP =  DDC_H3A_INVALID_PARAM;
        }
        /* Check Vertical Start*/
        if ( (paramsaew->winConfig.vtStart > DDC_AEW_MAX_VTSTART))
        {
            DDC_H3A_DEBUG_PRINT("DDC_AEWValidateParameters Error: \
                Invalid params (vertical start)\n");
            resultAEWVP =  DDC_H3A_INVALID_PARAM;
        }
        /* Check Vertical Line Increment*/
        if ((DDC_H3A_NOT_EVEN
                == DDC_H3A_ISEVEN(paramsaew->winConfig.vtLineIncr))
            || ((paramsaew->winConfig.vtLineIncr < DDC_AEW_MIN_VTLINEINCR)
                || (paramsaew->winConfig.vtLineIncr > DDC_AEW_MAX_VTLINEINCR)))
        {
            DDC_H3A_DEBUG_PRINT("DDC_AEWValidateParameters Error: \
                Invalid params (vertical increment)\n");
            resultAEWVP =  DDC_H3A_INVALID_PARAM;
        }
        /* Check Horizontal Line Increment*/
        if ((DDC_H3A_NOT_EVEN
                == DDC_H3A_ISEVEN(paramsaew->winConfig.hzLineIncr))
            || ((paramsaew->winConfig.hzLineIncr < DDC_AEW_MIN_HZLINEINCR)
                || (paramsaew->winConfig.hzLineIncr > DDC_AEW_MAX_HZLINEINCR)))
        {
            DDC_H3A_DEBUG_PRINT("DDC_AEWValidateParameters Error : \
                Invalid params (horizontal increment)\n");
            resultAEWVP =  DDC_H3A_INVALID_PARAM;
        }
        /* Check Black window Height */
        if ((DDC_H3A_NOT_EVEN
                == DDC_H3A_ISEVEN(paramsaew->blkWinConfig.height))
            || ((paramsaew->blkWinConfig.height < DDC_AEW_MIN_BLKWIN_HEIGHT)
                || (paramsaew->blkWinConfig.height
                    > DDC_AEW_MAX_BLKWIN_HEIGHT)))
        {
            DDC_H3A_DEBUG_PRINT("DDC_AEWValidateParameters Error: \
                Invalid params (Black Window height)\n");
            resultAEWVP =  DDC_H3A_INVALID_PARAM;
        }

        /* Check Black window Vertical Start */
        if ((paramsaew->blkWinConfig.vtStart > DDC_AEW_MAX_BLKWIN_VTSTART))
        {
            DDC_H3A_DEBUG_PRINT("DDC_AEWValidateParameters Error: \
                Invalid params (Black Window vertical Start)\n");
            resultAEWVP =  DDC_H3A_INVALID_PARAM;
        }

        /* Check Saturation Limit */
        if ((paramsaew->satLimit > DDC_AEW_AVE2LMT_MAX)
            || (paramsaew->satLimit < DDC_AEW_AVE2LMT_MIN))
        {
            DDC_H3A_DEBUG_PRINT("DDC_AEWValidateParameters Error: \
                Invalid params (Saturation Limit)\n");
            resultAEWVP =  DDC_H3A_INVALID_PARAM;
        }
        /* Check A ALaw Value */
        if ((paramsaew->enable < PSP_AEW_ALAW_DISABLE)
            || (paramsaew->enable > PSP_AEW_ALAW_ENABLE))
        {
            DDC_H3A_DEBUG_PRINT("DDC_AEWValidateParameters Error: \
                Invalid params (A Law Value)\n");
            resultAEWVP =  DDC_H3A_INVALID_PARAM;
        }
        if ((NULL != ddcH3aDevHandleAEWVP->regs)
            && (DDC_H3A_SOK == resultAEWVP))
        {
            /* configure hardware registers */
            if ( CSL_SOK != LLC_AEWHardwareSetup(paramsaew,
                    ddcH3aDevHandleAEWVP->regs))
            {
                DDC_H3A_DEBUG_PRINT("DDC_AEWValidateParameters Error : \
                    Failed to set register \n");
                resultAEWVP = DDC_H3A_E_FAIL;
            }
        }
        else
        {
            DDC_H3A_DEBUG_PRINT("DDC_AEWValidateParameters Error : \
                Failed to set register \n");
            resultAEWVP = DDC_H3A_E_FAIL;
        }
    }
    else
    {
        DDC_H3A_DEBUG_PRINT("DDC_AEWValidateParameters Error : \
            Invalid Paramters \n");
        resultAEWVP = DDC_H3A_INVALID_PARAM;
    }
    return resultAEWVP;
}

