/*******************************************************************************
**+--------------------------------------------------------------------------+**
**|                            ****                                          |**
**|                            ****                                          |**
**|                            ******o***                                    |**
**|                      ********_///_****                                   |**
**|                      ***** /_//_/ ****                                   |**
**|                       ** ** (__/ ****                                    |**
**|                           *********                                      |**
**|                            ****                                          |**
**|                            ***                                           |**
**|                                                                          |**
**|         Copyright (c) 2006-2010 Texas Instruments Incorporated           |**
**|                        ALL RIGHTS RESERVED                               |**
**|                                                                          |**
**| Permission is hereby granted to licensees of Texas Instruments           |**
**| Incorporated (TI) products to use this computer program for the sole     |**
**| purpose of implementing a licensee product based on TI products.         |**
**| No other rights to reproduce, use, or disseminate this computer          |**
**| program, whether in part or in whole, are granted.                       |**
**|                                                                          |**
**| TI makes no representation or warranties with respect to the             |**
**| performance of this computer program, and specifically disclaims         |**
**| any responsibility for any damages, special or consequential,            |**
**| connected with the use of this program.                                  |**
**|                                                                          |**
**+--------------------------------------------------------------------------+**
*******************************************************************************/

/**
 *  \file   ddc_h3a.h
 *
 *  \brief  H3A interface definition
 *
 *  This file contains the interfaces, data types and symbolic definitions
 *  that are needed by the application to utilize the serivces of the H3A
 *  device driver.
 *
 *  (C) Copyright 2006, Texas Instruments, Inc
 *
 *  \author     EI4
 *
 *  \version    0.1             Created
 *              1.0             First Release
 */
#ifndef _DDC_H3A_H_
#define _DDC_H3A_H_

/******************************************************************************
  Header File Inclusion
 ******************************************************************************/
#include <ti/sdo/pspdrivers/pal_os/pal_osSem.h>
#include <ti/sdo/pspdrivers/pal_os/pal_osList.h>
#include <ti/sdo/pspdrivers/soc/dm6437/dsp/tistdtypes.h>
#include <ti/sdo/pspdrivers/drivers/h3a/psp_h3a.h>
#include <ti/sdo/pspdrivers/drivers/h3a/psp_af.h>
#include <ti/sdo/pspdrivers/drivers/h3a/psp_aew.h>
#ifdef H3A_DEBUG
#include <ti/sdo/pspdrivers/pal_os/bios/psputils.h>
#endif

#ifdef __cplusplus
extern "C" {
#endif

/******************************************************************************
  Macros
 ******************************************************************************/
#define DDC_H3A_ENGINE_DISABLE  (0u)
#define DDC_H3A_ENGINE_ENABLE   (1u)
#define DDC_H3A_ENGINE_BUSY     (1u)
#define DDC_H3A_ENGINE_NOTBUSY  (0u)
#define DDC_H3A_ISEVEN(x)       ((x) % (2u))
#define DDC_H3A_ADDRESS_MASK    (0x3Fu)
#define DDC_H3A_TIMEOUT         (2000)
#define DDC_H3A_QUEUE_EMPTY     (1u)
#define DDC_H3A_QUEUE_FILLED    (2u)
#define DDC_H3A_NOT_EVEN        (1u)
#define DDC_H3A_HZ_START_OFF    (2u)
#define DDC_H3A_INIT_CHAN_SEM   (1)
#define DDC_H3A_INIT_ISR_SEM    (0u)
#define DDC_H3A_MEM_INIT        (0u)
#define DDC_H3A_RESET_INDEX     (0u)
#define DDC_H3A_ADD_CHECK       (0u)
#define DDC_H3A_ID_RESET_VAL    (0u)
#define DDC_H3A_INT_RESET_VAL   (0u)
#ifdef H3A_DEBUG
#define DDC_H3A_DEBUG_PRINT(x)    PSP_DEBUG(x)
#else
#define DDC_H3A_DEBUG_PRINT(x)
#endif

/******************************************************************************
  Enumerations
 ******************************************************************************/
/**
 * \brief _DDC_ParamsConfigDone
 * This enum describes state of configuration of AF device
 */
typedef enum _DDC_ParamsConfigDone
{
    STATE_NOT_CONFIGURED = 0,
    /**< State is not configured    */
    STATE_CONFIGURED
        /**< State is configured        */
} DDC_ParamsConfigDone;

/**
 * \brief _DDC_H3AChanState
 * This enum describes state of channel
 */
typedef enum _DDC_H3AChanState
{
    DDC_H3ACHANCLOSED = 0,
    /**< Channel is in closed state */
    DDC_H3ACHANOPENED
        /**< Channel is in opened state */
} DDC_H3AChanState;

/******************************************************************************
  Error Codes
 ******************************************************************************/
/**
 * \brief _DDC_H3AStatus
 * This enum contains DDC related error codes that will be passed
 * to the DDA layer.
 */
typedef enum _DDC_H3AStatus
{
    DDC_H3A_SOK = 0,
    /**< Operation passed code for DDC related functionality            */
    DDC_H3A_E_FAIL,
    /**< Operation failed code for DDC related functionality            */
    DDC_H3A_INVALID_STATE,
    /**< Invalid state error code for DDC related functionality         */
    DDC_H3A_INVALID_PARAM,
    /**< Invalid param error code for DDC related functionality         */
    DDC_H3A_NOT_SUPPORTED,
    /**< Unsupported error code for DDC related functionality           */
    DDC_H3A_NO_DATA
        /**< Data not available error code for DDC related functionality    */
} DDC_H3AStatus;

/******************************************************************************
  Data-Structures
 ******************************************************************************/
/**
 * \brief _DDC_H3ABufferobject
 * This structure describes buffer onject for H3A
 */
typedef struct _DDC_H3ABufferobject
{
    Uint32       indexEnQueue;
    /**< Index indicating the no of buffer pushed on the queue           */
    Uint32       indexDeQueue;
    /**< Index indicating the no of buffers containing statistics        */
    PAL_OsListNodeHeader    enQueue;
    /**< Queue which keeps track of the buffer sent by the application   */
    PAL_OsListNodeHeader    deQueue;
    /**< Queue which keeps track of the buffer containing  statistics    */
} DDC_H3ABufferObject;

/******************************************************************************
  Data-Structures
 ******************************************************************************/
#include <ti/sdo/pspdrivers/drivers/h3a/src/ddc_af.h>
#include <ti/sdo/pspdrivers/drivers/h3a/src/ddc_aew.h>

/**
 * \brief _DDC_H3ADeviceObject
 * This structure describes the H3A Device Object
 */
typedef struct _DDC_H3ADeviceObject
{
    Uint32          instanceId;
    /**< Instance Id                        */
    Uint32          intNum;
    /**< Interrupt Number                   */
    PSP_H3AState    state;
    /**< State of device                    */
    Ptr             regs;
    /**< Pointer to register configuration  */
    struct _DDC_AFChannelObject     chanAF;
    /**< AF channel object                  */
    struct _DDC_AEWChannelObject    chanAEW;
    /**< AEW channel object                 */
} DDC_H3ADeviceObject;

/******************************************************************************
  Functions
 ******************************************************************************/
/**
 * \brief DDC_H3AInitializeModule
 * perform the register overlaying and set the interrupt number
 * and update the state of device
 *
 * \param  instance         [IN]    Instance id
 *
 * \return Returns          [OUT]   Pointer to DDC layer device structure
 *
 */
PSP_Handle DDC_H3AInitializeModule (Uint32);

/**
 * \brief DDC_H3ARemoveModule
 * It will update the state of device.
 *
 * \param  instance         [IN]    Instance id
 *
 * \return Returns          [OUT]   Pointer to DDC layer device structure
 *
 */
PSP_Handle DDC_H3ARemoveModule (Uint32);

/**
 * \brief DDC_H3AValidateBuffer
 * Validate buffer passed by application.
 *
 * \param  CmdArg           [IN]    Pointer to Command Argument
 * \return Cmd              [IN]    Submit Command
 *
 * \return Returns          [OUT]   NULL
 */
DDC_H3AStatus DDC_H3AValidateBuffer(Ptr cmdArg, PSP_VPSSSubmitCommand cmd);


/**
 * \brief DDC_H3AOpenHandle
 * Returs the Channel handle
 *
 * \param  id               [IN]    Channel id
 *
 * \return Returns          [OUT]   PSP Handle
 */
PSP_Handle DDC_H3AOpenHandle(Uint32);

/**
 * \brief DDC_H3ARegisterOverlaying
 * Perform register overlaying
 *
 * \param  void
 *
 * \return void
 */
void DDC_H3ARegisterOverlaying(void);

/**
 * \brief DDC_H3ACloseHandle
 * closes the channel
 *
 * \param  handle           [IN]    PSP handle
 *
 * \return Returns          [OUT]   DDC status
 */
DDC_H3AStatus DDC_H3ACloseHandle(PSP_Handle handle);

/**
 * \brief DDC_H3ASetInterruptNumber
 * assign the interrupt number to the H3A driver
 *
 * \param  void
 *
 * \return void
 */
void DDC_H3ASetInterruptNumber(void);

/**
 * \brief DDC_H3Aisr
 * Interrupt Service Routine
 *
 * \param  void
 *
 * \return void
 */
void DDC_H3Aisr(void);

/**
 * \brief DDC_H3AIoctl
 * execute the control command
 *
 * \param handle            [IN]    PSP handle
 *
 * \param cmd               [IN]    IOCTL command
 *
 * \param cmdArg            [IN]    Command Arguments to be passed.
 *                                  ConfigParams to be passed as cmdArg
 *                                  depending upon the channel
 *
 * \param Params            [IN]    pointer to params structure
 *
 * \return Returns          [OUT]   DDC status
 */
DDC_H3AStatus DDC_H3AIoctl(PSP_Handle handle, PSP_H3AIoctlCmd cmd,
    Ptr cmdArg, Ptr params);

/**
 * \brief DDC_H3ASubmit
 * execute the Submit Command
 *
 * \param handle            [IN]    PSP handle
 *
 * \param cmd               [IN]    IOCTL command
 *
 * \param cmdArg            [IN]    Command Arguments to be passed.
 *                                  ConfigParams to be passed as cmdArg
 *                                  depending upon the channel
 *
 * \return Returns          [OUT]   DDC status
 */
DDC_H3AStatus DDC_H3ASubmit(PSP_Handle handle, PSP_VPSSSubmitCommand cmd,
    Ptr cmdArg);

/**
 * \brief DDC_H3AIsChannelHandleClosed
 * Returns status of the handle
 *
 * \param  handle           [IN]    Channel handle
 *
 * \return Returns          [OUT]   DDC status
 */
DDC_H3AStatus DDC_H3AIsChannelHandleClosed (PSP_Handle handle);

#ifdef __cplusplus
}
#endif

#endif  /* _DDC_H3A_H_ */

