/*******************************************************************************
**+--------------------------------------------------------------------------+**
**|                            ****                                          |**
**|                            ****                                          |**
**|                            ******o***                                    |**
**|                      ********_///_****                                   |**
**|                      ***** /_//_/ ****                                   |**
**|                       ** ** (__/ ****                                    |**
**|                           *********                                      |**
**|                            ****                                          |**
**|                            ***                                           |**
**|                                                                          |**
**|         Copyright (c) 2006-2010 Texas Instruments Incorporated           |**
**|                        ALL RIGHTS RESERVED                               |**
**|                                                                          |**
**| Permission is hereby granted to licensees of Texas Instruments           |**
**| Incorporated (TI) products to use this computer program for the sole     |**
**| purpose of implementing a licensee product based on TI products.         |**
**| No other rights to reproduce, use, or disseminate this computer          |**
**| program, whether in part or in whole, are granted.                       |**
**|                                                                          |**
**| TI makes no representation or warranties with respect to the             |**
**| performance of this computer program, and specifically disclaims         |**
**| any responsibility for any damages, special or consequential,            |**
**| connected with the use of this program.                                  |**
**|                                                                          |**
**+--------------------------------------------------------------------------+**
*******************************************************************************/

/**
 *  \file   llc_h3a.c
 *
 *  \brief  H3A LLC layer Function dependencies
 *
 *  This file contains the dependencies of LLC layer functions
 *
 *  (C) Copyright 2010, Texas Instruments, Inc
 *
 *  \author     EI4
 *
 *  \version    0.1             Created
 *              1.0             First Release
 */
/******************************************************************************
  Header File Inclusion
 ******************************************************************************/
#include <ti/sdo/pspdrivers/soc/dm6437/dsp/tistdtypes.h>
#include <ti/sdo/pspdrivers/soc/dm6437/dsp/cslr.h>
#include <ti/sdo/pspdrivers/soc/dm6437/dsp/cslr_vpss.h>
#include <ti/sdo/pspdrivers/soc/dm6437/dsp/cslr_h3a.h>
#include <ti/sdo/pspdrivers/soc/dm6437/dsp/csl_error.h>
#include <ti/sdo/pspdrivers/soc/dm6437/dsp/soc.h>
#include <ti/sdo/pspdrivers/drivers/h3a/psp_af.h>
#include <ti/sdo/pspdrivers/drivers/h3a/psp_aew.h>
#include <ti/sdo/pspdrivers/drivers/h3a/src/llc_h3a.h>

/******************************************************************************
  Data-Structures
 ******************************************************************************/
/**
 * \brief to access h3a registers
 */
CSL_H3aRegsOvly h3aRegs;

/******************************************************************************
  Functions
 ******************************************************************************/
/**
 * \brief LLC_AFHardwareSetup
 * performs register configuration
 */
CSL_Status LLC_AFHardwareSetup(PSP_AFParams *params, Ptr regs)
{
    CSL_Status returnAFHS = CSL_SOK;
    if ((NULL == regs ) || (NULL == params))
    {
        LLC_H3A_DEBUG_PRINT("LLC_AFHardwareSetup: \
            Error: Unable to set registers\n");
        returnAFHS = CSL_ESYS_INVPARAMS;
    }
    else
    {
        h3aRegs = (CSL_H3aRegsOvly)regs;
        CSL_FINS( h3aRegs->PCR, H3A_PCR_AF_ALAW_EN, params->enable );
        CSL_FINS( h3aRegs->PCR, H3A_PCR_AF_MED_EN, params->hmfConfig.enable );
        if( PSP_AF_HMF_ENABLE == params->hmfConfig.enable)
        {
            CSL_FINS( h3aRegs->PCR, H3A_PCR_MED_TH,
                params->hmfConfig.threshold );
        }
        CSL_FINS( h3aRegs->PCR, H3A_PCR_RGBPOS, params->rgbPos );
        CSL_FINS( h3aRegs->PCR, H3A_PCR_FVMODE, params->mode );

        CSL_FINS( h3aRegs->AFIIRSH, H3A_AFIIRSH_IIRSH,
            params->iirConfig.hzStarPos );

        /* initializing the coefficient of IIR Filter 0 */
        /* coeffSet0[index] = index represents the coefficients number
        of IIR Filter 0  */
        /* Every Register has 2 coefficient*/
        CSL_FINS( h3aRegs->AFCOEF010, H3A_AFCOEF010_COEFF0,
            params->iirConfig.coeffSet0[0] );
        CSL_FINS( h3aRegs->AFCOEF010, H3A_AFCOEF010_COEFF1,
            params->iirConfig.coeffSet0[1] );

        CSL_FINS( h3aRegs->AFCOEF032, H3A_AFCOEF032_COEFF2,
            params->iirConfig.coeffSet0[2] );
        CSL_FINS( h3aRegs->AFCOEF032, H3A_AFCOEF032_COEFF3,
            params->iirConfig.coeffSet0[3] );

        CSL_FINS( h3aRegs->AFCOEFF054, H3A_AFCOEFF054_COEFF4,
            params->iirConfig.coeffSet0[4] );
        CSL_FINS( h3aRegs->AFCOEFF054, H3A_AFCOEFF054_COEFF5,
            params->iirConfig.coeffSet0[5] );

        CSL_FINS( h3aRegs->AFCOEFF076, H3A_AFCOEFF076_COEFF6,
            params->iirConfig.coeffSet0[6] );
        CSL_FINS( h3aRegs->AFCOEFF076, H3A_AFCOEFF076_COEFF7,
            params->iirConfig.coeffSet0[7] );

        CSL_FINS( h3aRegs->AFCOEFF098, H3A_AFCOEFF098_COEFF8,
            params->iirConfig.coeffSet0[8] );
        CSL_FINS( h3aRegs->AFCOEFF098, H3A_AFCOEFF098_COEFF9,
            params->iirConfig.coeffSet0[9] );
        /* Coefficient 10 is contained in single register */
        CSL_FINS( h3aRegs->AFCOEFF0010, H3A_AFCOEFF0010_COEFF10,
            params->iirConfig.coeffSet0[10] );

        /* initializing the coefficient of IIR Filter 1 */
        /* coeffSet1[index] = index represents the coefficients number
        of IIR Filter 1  */
        /* Every Register has 2 coefficient*/
        CSL_FINS( h3aRegs->AFCOEF110, H3A_AFCOEF110_COEFF0,
            params->iirConfig.coeffSet1[0] );
        CSL_FINS( h3aRegs->AFCOEF110, H3A_AFCOEF110_COEFF1,
            params->iirConfig.coeffSet1[1] );

        CSL_FINS( h3aRegs->AFCOEF132, H3A_AFCOEF132_COEFF2,
            params->iirConfig.coeffSet1[2] );
        CSL_FINS( h3aRegs->AFCOEF132, H3A_AFCOEF132_COEFF3,
            params->iirConfig.coeffSet1[3] );

        CSL_FINS( h3aRegs->AFCOEFF154, H3A_AFCOEFF154_COEFF4,
            params->iirConfig.coeffSet1[4] );
        CSL_FINS( h3aRegs->AFCOEFF154, H3A_AFCOEFF154_COEFF5,
            params->iirConfig.coeffSet1[5] );

        CSL_FINS( h3aRegs->AFCOEFF176, H3A_AFCOEFF176_COEFF6,
            params->iirConfig.coeffSet1[6] );
        CSL_FINS( h3aRegs->AFCOEFF176, H3A_AFCOEFF176_COEFF7,
            params->iirConfig.coeffSet1[7] );

        CSL_FINS( h3aRegs->AFCOEFF198, H3A_AFCOEFF198_COEFF8,
            params->iirConfig.coeffSet1[8] );
        CSL_FINS( h3aRegs->AFCOEFF198, H3A_AFCOEFF198_COEFF9,
            params->iirConfig.coeffSet1[9] );

        /* Coefficient 10 is contained in single register */
        CSL_FINS( h3aRegs->AFCOEFF1010, H3A_AFCOEFF1010_COEFF10,
            params->iirConfig.coeffSet1[10] );

        CSL_FINS( h3aRegs->AFPAX1, H3A_AFPAX1_PAXW,
            LLC_H3A_SETREG(params->paxelConfig.width ));
        CSL_FINS( h3aRegs->AFPAX1, H3A_AFPAX1_PAXH,
            LLC_H3A_SETREG(params->paxelConfig.height) );

        /* Hardware increments horizontal and vertical count by 1 internally
        as result the horizontal and vertical count is decremented by 1*/
        CSL_FINS( h3aRegs->AFPAX2, H3A_AFPAX2_PAXHC,
            (params->paxelConfig.hzCnt-(1u)) );
        CSL_FINS( h3aRegs->AFPAX2, H3A_AFPAX2_PAXVC,
            (params->paxelConfig.vtCnt-(1u)) );

        /* Setting Line increment*/
        CSL_FINS( h3aRegs->AFPAX2, H3A_AFPAX2_AFINCV,
            LLC_H3A_SETREG(params->paxelConfig.lineIncr) );

        /* Setting horizontal and vertical start */
        CSL_FINS( h3aRegs->AFPAXSTART, H3A_AFPAXSTART_PAXSH,
            params->paxelConfig.hzStart );
        CSL_FINS( h3aRegs->AFPAXSTART, H3A_AFPAXSTART_PAXSV,
            params->paxelConfig.vtStart );
    }
    return returnAFHS;
}

/**
 * \brief LLC_AEWHardwareSetup
 * performs register configuration
 */
CSL_Status LLC_AEWHardwareSetup(PSP_AEWParams * const params, Ptr const regs)
{
    CSL_Status returnAEWHS = CSL_SOK;
    if ((NULL == regs) || (NULL == params))
    {
        LLC_H3A_DEBUG_PRINT("LLC_AEWHardwareSetup: \
            Error: Unable to set registers\n");
        returnAEWHS = CSL_ESYS_INVPARAMS;
    }
    else
    {
        h3aRegs = (CSL_H3aRegsOvly)regs;
        CSL_FINS( h3aRegs->PCR, H3A_PCR_AEW_ALAW_EN, params->enable );
        CSL_FINS( h3aRegs->PCR, H3A_PCR_AVE2LMT, params->satLimit );

        CSL_FINS( h3aRegs->AEWWIN1, H3A_AEWWIN1_WINW,
            LLC_H3A_SETREG(params->winConfig.width ));
        CSL_FINS( h3aRegs->AEWWIN1, H3A_AEWWIN1_WINH,
            LLC_H3A_SETREG(params->winConfig.height ));

        /* Hardware increments horizontal and vertical count by 1 internally
        as result the horizontal and vertical count is decremented by 1*/
        CSL_FINS( h3aRegs->AEWWIN1, H3A_AEWWIN1_WINHC,
            (params->winConfig.hzCnt-(1u)) );
        CSL_FINS( h3aRegs->AEWWIN1, H3A_AEWWIN1_WINVC,
            (params->winConfig.vtCnt -(1u)) );
        /* Configuring line increments*/
        CSL_FINS( h3aRegs->AEWSUBWIN, H3A_AEWSUBWIN_AEWINCH,
            LLC_H3A_SETREG(params->winConfig.hzLineIncr ));
        CSL_FINS( h3aRegs->AEWSUBWIN, H3A_AEWSUBWIN_AEWINCV,
            LLC_H3A_SETREG(params->winConfig.vtLineIncr) );
        /* Configuring horizontal start*/
        CSL_FINS( h3aRegs->AEWINSTART, H3A_AEWINSTART_WINSH,
            params->winConfig.hzStart );
        /* Configuring vertical start*/
        CSL_FINS( h3aRegs->AEWINSTART, H3A_AEWINSTART_WINSV,
            params->winConfig.vtStart );
        /* configuring the black window*/
        CSL_FINS( h3aRegs->AEWINBLK, H3A_AEWINBLK_WINH,
            LLC_H3A_SETREG(params->blkWinConfig.height ));

        CSL_FINS( h3aRegs->AEWINBLK, H3A_AEWINBLK_WINSV,
            params->blkWinConfig.vtStart );
    }
    return returnAEWHS;
}

/**
 * \brief LLC_SetAFEngine
 * enable the AF engine by writing the enable bit to hardware register
 */
CSL_Status LLC_SetAFEngine(Uint32 value, Ptr regs)
{
    CSL_Status returnSetAF = CSL_SOK;

    if (NULL == regs)
    {
        LLC_H3A_DEBUG_PRINT("LLC_SetAFEngine: Error: \
            Unable to set registers\n");
        returnSetAF = CSL_ESYS_INVPARAMS;
    }
    else
    {
        h3aRegs = (CSL_H3aRegsOvly)regs;
        CSL_FINS ( h3aRegs->PCR, H3A_PCR_AF_EN, value );
    }
    return returnSetAF;
}

/**
 * \brief LLC_SetAEWEngine
 * enable the AEW engine by writing the enable bit to hardware register
 */
CSL_Status LLC_SetAEWEngine(Uint32 value, Ptr const regs)
{
    CSL_Status returnSetAEW = CSL_SOK;

    if (NULL == regs)
    {
        LLC_H3A_DEBUG_PRINT("LLC_SetAEWEngine: Error: \
            Unable to set registers\n");
        returnSetAEW = CSL_ESYS_INVPARAMS;
    }
    else
    {
        h3aRegs = (CSL_H3aRegsOvly)regs;
        CSL_FINS( h3aRegs->PCR, H3A_PCR_AEW_EN, value );
    }
    return returnSetAEW;
}

/**
 * \brief LLC_SetAFBUFST
 * set the address of buffer in the register.
 * Hardware will fill the statistics of AF in the this buffer
 */
CSL_Status LLC_SetAFBUFST (Ptr regs, Uint32 address)
{
    CSL_Status returnAFBuf = CSL_SOK;

    if (NULL == regs)
    {
        LLC_H3A_DEBUG_PRINT("LLC_SetAFBUFST: Error: Unable to set registers\n");
        returnAFBuf = CSL_ESYS_INVPARAMS;
    }
    else
    {
        h3aRegs = (CSL_H3aRegsOvly)regs;
        CSL_FINS ( h3aRegs->AFBUFST, H3A_AFBUFST_AFBUFST, address );
    }
    return returnAFBuf;
}

/**
 * \brief LLC_SetAEWBUFST
 * set the address of buffer in the register.
 * Hardware will fill the statistics of AEW in the this buffer
 */
CSL_Status LLC_SetAEWBUFST (Ptr const regs, Uint32 const address)
{
    CSL_Status returnAEWBuf = CSL_SOK;
    if (NULL == regs)
    {
        LLC_H3A_DEBUG_PRINT("LLC_SetAEWBUFST: Error: \
            Unable to set registers\n");
        returnAEWBuf = CSL_ESYS_INVPARAMS;
    }
    else
    {
        h3aRegs = (CSL_H3aRegsOvly)regs;
        CSL_FINS( h3aRegs->AEWBUFST, H3A_AEWBUFST_AEWBUFST, address );
    }
    return returnAEWBuf;
}

/**
 * \brief LLC_GetBusyAF
 * gets the Busy Bit for AF engine
 */
Int32 LLC_GetBusyAF (Ptr const regs)
{
    Int32 returnBusyAF = CSL_SOK;

    if (NULL == regs)
    {
        LLC_H3A_DEBUG_PRINT("LLC_GetBusyAF: Error: \
            Unable to get AF busy status\n");
        returnBusyAF = CSL_ESYS_INVPARAMS;
    }
    else
    {
        h3aRegs = (CSL_H3aRegsOvly)regs;
        returnBusyAF = CSL_FEXT( h3aRegs->PCR, H3A_PCR_BUSYAF );
    }
    return returnBusyAF;
}

/**
 * \brief LLC_GetBusyAEW
 * gets the Busy Bit for AEW engine
 */
Int32 LLC_GetBusyAEW (Ptr const regs)
{
    Int32 returnBusyAEW = CSL_SOK;

    if (NULL == regs)
    {
        LLC_H3A_DEBUG_PRINT("LLC_GetBusyAEW: Error: \
            Unable to get AEW busy status\n");
        returnBusyAEW = CSL_ESYS_INVPARAMS;
    }
    else
    {
        h3aRegs = (CSL_H3aRegsOvly)regs;
        returnBusyAEW = CSL_FEXT( h3aRegs->PCR, H3A_PCR_BUSYAEAWB );
    }
    return returnBusyAEW;
}

/**
 * \brief LLC_GetAFHWStatus
 * Checks AF Engine Status
 */
Int32 LLC_GetAFHWStatus (Ptr const regs)
{
    Int32 returnStatusAF = CSL_SOK;

    if (NULL == regs)
    {
        LLC_H3A_DEBUG_PRINT("LLC_GetAFHWStatus: Error: \
            Unable to get AF status\n");
        returnStatusAF = CSL_ESYS_INVPARAMS;
    }
    else
    {
        h3aRegs = (CSL_H3aRegsOvly)regs;
        returnStatusAF = CSL_FEXT( h3aRegs->PCR, H3A_PCR_AF_EN );
    }
    return returnStatusAF;
}

/**
 * \brief LLC_GetAEWHWStatus
 * Checks AEW Engine Status
 */
Int32 LLC_GetAEWHWStatus (Ptr const regs)
{
    Int32 returnStatusAEW = CSL_SOK;

    if (NULL == regs)
    {
        LLC_H3A_DEBUG_PRINT("LLC_GetAEWHWStatus: Error: \
            Unable to get AEW status\n");
        returnStatusAEW = CSL_ESYS_INVPARAMS;
    }
    else
    {
        h3aRegs = (CSL_H3aRegsOvly)regs;
        returnStatusAEW = CSL_FEXT( h3aRegs->PCR, H3A_PCR_AEW_EN );
    }
    return returnStatusAEW;
}

/**
 * \brief LLC_AFGetWriteBufferStatus
 * Checks Buffer Overflow bit status of VPSS shared buffer for AF
 */
Int32 LLC_AFGetWriteBufferStatus (Ptr const regs)
{
    Int32 returnWBAF = CSL_SOK;
    CSL_VpssRegsOvly vpssRegs;

    if (NULL == regs)
    {
        LLC_H3A_DEBUG_PRINT("LLC_AFGetWriteBufferStatus: Error: \
            Unable to get AF write buffer status\n");
        returnWBAF = CSL_ESYS_INVPARAMS;
    }
    else
    {
        vpssRegs = (CSL_VpssRegsOvly)regs;
        returnWBAF = CSL_FEXT(vpssRegs->PCR, VPSS_PCR_AF_WBL_O);
    }
    return (returnWBAF);
}

/**
 * \brief LLC_AEWGetWriteBufferStatus
 * Checks Buffer Overflow bit status of VPSS shared buffer for AEW
 */
Int32 LLC_AEWGetWriteBufferStatus (Ptr const regs)
{
    Int32 returnWBAEW = CSL_SOK;
    CSL_VpssRegsOvly vpssRegs;

    if (NULL == regs)
    {
        LLC_H3A_DEBUG_PRINT("LLC_AEWGetWriteBufferStatus: Error: \
            Unable to get AEW write buffer status\n");
        returnWBAEW = CSL_ESYS_INVPARAMS;
    }
    else
    {
        vpssRegs = (CSL_VpssRegsOvly)regs;
        returnWBAEW = CSL_FEXT(vpssRegs->PCR, VPSS_PCR_AEW_WBL_O);
    }
    return (returnWBAEW);
}

/**
 * \brief LLC_AFClearWriteBuffer
 * Clears Buffer Overflow bit status of VPSS shared buffer for AF
 */
CSL_Status LLC_AFClearWriteBuffer (Ptr const regs)
{
    CSL_Status returnClrWBAF = CSL_SOK;
    CSL_VpssRegsOvly vpssRegs;

    if (NULL == regs)
    {
        LLC_H3A_DEBUG_PRINT("LLC_AFClearWriteBuffer: Error: \
            Unable to clear over flow bit\n");
        returnClrWBAF = CSL_ESYS_INVPARAMS;
    }
    else
    {
        vpssRegs = (CSL_VpssRegsOvly)regs;
        CSL_FINS( vpssRegs->PCR, VPSS_PCR_AF_WBL_O, 0 );
    }
    return (returnClrWBAF);
}

/**
 * \brief LLC_AEWClearWriteBuffer
 * Clears Buffer Overflow bit status of VPSS shared buffer for AEW
 */
CSL_Status LLC_AEWClearWriteBuffer (Ptr const regs)
{
    CSL_Status returnClrWBAEW = CSL_SOK;
    CSL_VpssRegsOvly vpssRegs;

    if (NULL == regs)
    {
        LLC_H3A_DEBUG_PRINT("LLC_AEWClearWriteBuffer: Error: \
            Unable to clear over flow bit\n");
        returnClrWBAEW = CSL_ESYS_INVPARAMS;
    }
    else
    {
        vpssRegs = (CSL_VpssRegsOvly)regs;
        CSL_FINS( vpssRegs->PCR, VPSS_PCR_AEW_WBL_O, 0 );
    }
    return (returnClrWBAEW);
}

/**
 * \brief LLC_AFInitRegister
 * Initializes AF registers with their reset values
 */
CSL_Status LLC_AFInitRegister(Ptr const regs)
{
    CSL_Status returnAFInit = CSL_SOK;
    if (NULL == regs)
    {
        LLC_H3A_DEBUG_PRINT("LLC_AFInitRegister: Error: \
            AF Register initialization failed\n");
        returnAFInit = CSL_ESYS_INVPARAMS;
    }
    else
    {
        h3aRegs = (CSL_H3aRegsOvly)regs;
        h3aRegs->AFPAX1         = CSL_H3A_AFPAX1_RESETVAL;
        h3aRegs->AFPAX2         = CSL_H3A_AFPAX2_RESETVAL;
        h3aRegs->AFPAXSTART     = CSL_H3A_AFPAXSTART_RESETVAL;
        h3aRegs->AFIIRSH        = CSL_H3A_AFIIRSH_RESETVAL;
        h3aRegs->AFBUFST        = CSL_H3A_AFBUFST_RESETVAL;
        h3aRegs->AFCOEF010      = CSL_H3A_AFCOEF010_RESETVAL;
        h3aRegs->AFCOEF032      = CSL_H3A_AFCOEF032_RESETVAL;
        h3aRegs->AFCOEFF054     = CSL_H3A_AFCOEFF054_RESETVAL;
        h3aRegs->AFCOEFF076     = CSL_H3A_AFCOEFF076_RESETVAL;
        h3aRegs->AFCOEFF098     = CSL_H3A_AFCOEFF098_RESETVAL;
        h3aRegs->AFCOEFF0010    = CSL_H3A_AFCOEFF0010_RESETVAL;
        h3aRegs->AFCOEF110      = CSL_H3A_AFCOEF110_RESETVAL;
        h3aRegs->AFCOEF132      = CSL_H3A_AFCOEF132_RESETVAL;
        h3aRegs->AFCOEFF154     = CSL_H3A_AFCOEFF154_RESETVAL;
        h3aRegs->AFCOEFF176     = CSL_H3A_AFCOEFF176_RESETVAL;
        h3aRegs->AFCOEFF198     = CSL_H3A_AFCOEFF198_RESETVAL;
        h3aRegs->AFCOEFF1010    = CSL_H3A_AFCOEFF1010_RESETVAL;
    }
    return returnAFInit;
}

/**
 * \brief LLC_AEWInitRegister
 * Initializes AEW registers with their reset values
 */
CSL_Status LLC_AEWInitRegister(Ptr const regs)
{
    CSL_Status returnAEWInit = CSL_SOK;

    if (NULL == regs)
    {
        LLC_H3A_DEBUG_PRINT("LLC_AEWInitRegister: Error: \
            AEW Register initialization failed\n");
        returnAEWInit = CSL_ESYS_INVPARAMS;
    }
    else
    {
        h3aRegs = (CSL_H3aRegsOvly)regs;
        h3aRegs->AEWWIN1    = CSL_H3A_AEWWIN1_RESETVAL;
        h3aRegs->AEWINSTART = CSL_H3A_AEWINSTART_RESETVAL;
        h3aRegs->AEWINBLK   = CSL_H3A_AEWINBLK_RESETVAL;
        h3aRegs->AEWSUBWIN  = CSL_H3A_AEWSUBWIN_RESETVAL;
        h3aRegs->AEWBUFST   = CSL_H3A_AEWBUFST_RESETVAL;
    }
    return returnAEWInit;
}

/**
 * \brief LLC_H3AResetPCRRegister
 * Resets PCR register of H3A
 */
CSL_Status LLC_H3AResetPCRRegister(Ptr const regs)
{
    CSL_Status returnResetPCR = CSL_SOK;
    if (NULL == regs)
    {
        LLC_H3A_DEBUG_PRINT("LLC_H3AResetPCRRegister: Error: \
            PCR Reset failed\n");
        returnResetPCR = CSL_ESYS_INVPARAMS;
    }
    else
    {
        h3aRegs = (CSL_H3aRegsOvly)regs;
        h3aRegs->PCR = CSL_H3A_PCR_RESETVAL;
    }
    return returnResetPCR;
}

