/*******************************************************************************
**+--------------------------------------------------------------------------+**
**|                            ****                                          |**
**|                            ****                                          |**
**|                            ******o***                                    |**
**|                      ********_///_****                                   |**
**|                      ***** /_//_/ ****                                   |**
**|                       ** ** (__/ ****                                    |**
**|                           *********                                      |**
**|                            ****                                          |**
**|                            ***                                           |**
**|                                                                          |**
**|         Copyright (c) 2006-2010 Texas Instruments Incorporated           |**
**|                        ALL RIGHTS RESERVED                               |**
**|                                                                          |**
**| Permission is hereby granted to licensees of Texas Instruments           |**
**| Incorporated (TI) products to use this computer program for the sole     |**
**| purpose of implementing a licensee product based on TI products.         |**
**| No other rights to reproduce, use, or disseminate this computer          |**
**| program, whether in part or in whole, are granted.                       |**
**|                                                                          |**
**| TI makes no representation or warranties with respect to the             |**
**| performance of this computer program, and specifically disclaims         |**
**| any responsibility for any damages, special or consequential,            |**
**| connected with the use of this program.                                  |**
**|                                                                          |**
**+--------------------------------------------------------------------------+**
*******************************************************************************/

/**
 *  \file   psp_h3aApi.h
 *
 *  \brief  File contains defination of API used by DDA layer
 *
 *  This file contains APIs defination of APIs that are wrapper APIs for DDC
 *  layer. These APIs will be called by DDA layer.
 *
 *  (C) Copyright 2006, Texas Instruments, Inc
 *
 *  \author     EI4
 *
 *  \version    1.0     Created
 */

#ifndef _PSP_H3A_API_H_
#define _PSP_H3A_API_H_

#ifdef __cplusplus
extern "C" {
#endif

/******************************************************************************
  Functions
 ******************************************************************************/
/**
 * \brief PSP_H3ACreate
 * This function is the first to be called and is used for driver
 * initialization.
 *
 * It performs register map overlaying and software book-keeping.
 * It register the interrupt Handler.
 *
 * \param   instanceId      [IN]    Instance id.
 *
 * \returns Returns         [OUT]   SUCCESS/FAILURE status.
 */
PSP_Handle PSP_H3ACreate(Uint32 instanceId);

/**
 * \brief PSP_H3ADelete
 * This function is called last and is used for driver deletion.
 *
 * \param   instanceId      [IN]    Instance id.
 *
 * \returns Returns         [OUT]   SUCCESS/FAILURE status.
 */
PSP_Result PSP_H3ADelete(Uint32 instanceId);

/**
 * \brief PSP_H3ADelete
 * This function creates  the channel handle for AF and AEW depending
 * upon the channel instance.
 *
 * \param      ChannelType     [IN]    Channel Type
 *
 * \returns    Returns         Channel handle of AF or AEW or NULL
 */
PSP_Handle PSP_H3AOpen(PSP_H3AChannelType channelId);

/**
 * \brief PSP_H3AClose
 * This function close individual Channel handle for AF Module
 *
 * \param      handle          [IN]    Individual channel Handle to be closed.
 *
 * \Returns    Returns         SUCCESS/FAILURE status.
 */
PSP_Result PSP_H3AClose(PSP_Handle handle);

/**
 * \brief PSP_H3AIoctl
 * This function makes runtime changes for the individual H3A
 *
 * \param      handle          [IN]    Channel Handle for which contol
 *                                     operation is to be performed.
 *
 * \param      cmd             [IN]    IOCTL command
 *
 * \param      cmdArg          [IN]    Command Arguments to be passed.
 *                                     ConfigParams to be passed as cmdArg
 *                                     depending upon the channel
 *
 * \param      params          [IN]    Reserved for Future Use.
 *
 * \Returns    Returns         SUCCESS/FAILURE status.
 */
PSP_Result PSP_H3AIoctl(PSP_Handle handle, PSP_H3AIoctlCmd cmd,
    Ptr cmdArg, Ptr params);

/**
 * \brief PSP_H3ASubmit
 * acts as wrapper, which provides the information as per command
 *
 * \param      handle          [IN]    Channel Handle for which contol
 *                                     operation is to be performed.
 *
 * \param      cmd             [IN]    IOCTL command
 *
 * \param      cmdArg          [IN]    Command Arguments to be passed.
 *                                     ConfigParams to be passed as cmdArg
 *                                     depending upon the channel
 *
 * \Returns    Returns         SUCCESS/FAILURE status.
 */
PSP_Result PSP_H3ASubmit(PSP_Handle handle, PSP_VPSSSubmitCommand cmd,
    Ptr cmdArg);

#ifdef __cplusplus
}
#endif

#endif  /* _PSP_H3A_API_H_ */

