/*******************************************************************************
**+--------------------------------------------------------------------------+**
**|                            ****                                          |**
**|                            ****                                          |**
**|                            ******o***                                    |**
**|                      ********_///_****                                   |**
**|                      ***** /_//_/ ****                                   |**
**|                       ** ** (__/ ****                                    |**
**|                           *********                                      |**
**|                            ****                                          |**
**|                            ***                                           |**
**|                                                                          |**
**|         Copyright (c) 2006-2010 Texas Instruments Incorporated           |**
**|                        ALL RIGHTS RESERVED                               |**
**|                                                                          |**
**| Permission is hereby granted to licensees of Texas Instruments           |**
**| Incorporated (TI) products to use this computer program for the sole     |**
**| purpose of implementing a licensee product based on TI products.         |**
**| No other rights to reproduce, use, or disseminate this computer          |**
**| program, whether in part or in whole, are granted.                       |**
**|                                                                          |**
**| TI makes no representation or warranties with respect to the             |**
**| performance of this computer program, and specifically disclaims         |**
**| any responsibility for any damages, special or consequential,            |**
**| connected with the use of this program.                                  |**
**|                                                                          |**
**+--------------------------------------------------------------------------+**
*******************************************************************************/
/**
 * \file   dda_hist.c
 *
 * \brief  DDA layer source file for Histogram
 *
 * This file contains the implementation of the Histogram driver to utilize the
 * serivces of the Histogram device driver.
 *
 * (C) Copyright 2010, Texas Instruments, Inc
 *
 * \author     EI5
 *
 * \version    0.1             Created
 *             1.0             First Release
 */

/******************************************************************************
  Header File Inclusion
 ******************************************************************************/

#include <ti/sdo/pspdrivers/drivers/histogram/src/dda_hist.h>
#include <ti/sdo/pspdrivers/drivers/histogram/src/ddc_hist.h>
#include <ti/sdo/pspdrivers/drivers/histogram/psp_histogram.h>

/******************************************************************************
  Functions
 ******************************************************************************/
/**
 * \brief   PSP_HISTCreate
 *          This function calls DDC layer function to create the device
 *          instance.
 */
PSP_Handle  PSP_HISTCreate(Uint32 instanceId)
{
    PSP_Handle returnHandleC = NULL;
    DDC_HISTdeviceobject *histDeviceObjectCreate = (DDC_HISTdeviceobject*)
        DDC_HISTInitializeModule( instanceId);

    /* Validate instance ID */
    if (instanceId >= PSP_HIST_NUM_INSTANCES )
    {
        DDA_DEBUG_PRINTF("PSP_HISTCreate : Invalid instance ID");
    }
    else if (NULL == histDeviceObjectCreate)
    {
        DDA_DEBUG_PRINTF("PSP_HISTCreate : Device handle is NULL");
    }
    else if (DDC_HIST_SOK != DDC_HISTSetDeviceEventNumber())
    {
        DDA_DEBUG_PRINTF("PSP_HISTCreate : Set device event number failed.");
    }
    else if (DDC_HIST_SOK != DDC_HISTPerformRegOverlaying())
    {
        DDA_DEBUG_PRINTF("PSP_HISTCreate : Register overlaying failed.");
    }
    else
    {
        returnHandleC = histDeviceObjectCreate;
    }
    return (returnHandleC);
}

/**
 * \brief   PSP_HISTDelete
 *          This function calls DDC layer function to remove the device
 *          instance.
 */
PSP_Result PSP_HISTDelete(Uint32 instanceId)
{
    PSP_Result resultD = PSP_SOK;
    DDC_HISTdeviceobject* histDeviceHandleD;

    /* Validate instance ID */
    if (instanceId >= PSP_HIST_NUM_INSTANCES )
    {
        resultD = PSP_E_INVAL_PARAM;
        DDA_DEBUG_PRINTF("PSP_HISTDelete : Invalid instance ID");
    }
    else
    {
        /* set state to deleted */
        histDeviceHandleD = DDC_HISTRemoveModule();
        if (NULL != histDeviceHandleD)
        {
            resultD = PSP_E_INVAL_PARAM;
            DDA_DEBUG_PRINTF("PSP_HISTDelete : Invalid parameter");
        }
    }
    return (resultD);
}

/**
 * \brief   PSP_HISTOpen
 *          This function calls DDC layer function to open the channel handle.
 */
PSP_Handle  PSP_HISTOpen(PSP_Handle edmaHandleDDA)
{
    PSP_Handle handleToReturn = NULL;

    if (NULL != edmaHandleDDA)
    {
        /*Get the Channel Handle */
        handleToReturn = (PSP_Handle)DDC_HISTOpenHandle(edmaHandleDDA);
        if (NULL == handleToReturn)
        {
            DDA_DEBUG_PRINTF("PSP_HISTOpen : Channel handle open failed");
        }
    }
    else
    {
        DDA_DEBUG_PRINTF("PSP_HISTOpen : Edma handle is NULL");
    }

    return (handleToReturn);
}

/**
 * \brief   PSP_HISTClose
 *          This function calls DDC layer function to close the channel handle.
 */
PSP_Result PSP_HISTClose(PSP_Handle handle)
{
    PSP_Result resultC = PSP_SOK;

    DDC_HISTdeviceobject* histDeviceHandleC
        = (DDC_HISTdeviceobject *)DDC_HISTGetDeviceHandle();

    if ((NULL == handle) || (NULL == histDeviceHandleC))
    {
        resultC = PSP_E_INVAL_PARAM;
        DDA_DEBUG_PRINTF("PSP_HISTOpen : Invalid parameter");
    }
    else
    {
        if (DDC_HIST_SOK == DDC_HISTCloseHandle(handle))
        {
            resultC = PSP_SOK;
        }
        else
        {
            resultC = PSP_E_INVAL_PARAM;
            DDA_DEBUG_PRINTF("PSP_HISTClose : channel handle close failed");
        }
    }
    return (resultC);
}

/**
 * \brief   PSP_HISTIoctl
 *          This function calls DDC layer function to perform I/O Control
 *          operation.
 */
PSP_Result  PSP_HISTIoctl(PSP_Handle handle, PSP_HISTIoctlCmd cmd, Ptr cmdArg)
{
    PSP_Result resultI = PSP_SOK;
    DDC_HISTstatus statusI;

    /*Check the Parameters */
    if ((NULL == handle) || (NULL == cmdArg))
    {
        resultI = PSP_E_INVAL_PARAM;
        DDA_DEBUG_PRINTF("PSP_HISTIoctl : Invalid parameter");
    }
    /*Check the Channel Handle is Closed */
    else if (DDC_HIST_SOK == DDC_HISTIsChannelHandleClosed(handle))
    {
        resultI = PSP_E_INVAL_STATE;
        DDA_DEBUG_PRINTF("PSP_HISTIoctl : Invalid state");
    }
    else
    {
        statusI = DDC_HISTIoctl(handle, cmd, cmdArg);
        if (DDC_HIST_SOK == statusI)
        {
            resultI = PSP_SOK;
        }
        else if (DDC_HIST_NOT_SUPPORTED == statusI)
        {
            resultI = PSP_E_INVALID_CMD;
            DDA_DEBUG_PRINTF("PSP_HISTIoctl : Invalid command");
        }
        else if (DDC_HIST_E_FAIL == statusI)
        {
            resultI = PSP_E_INVAL_PARAM;
            DDA_DEBUG_PRINTF("PSP_HISTIoctl : Invalid parameter");
        }
        else if (DDC_HIST_INVALID_PARAM == statusI)
        {
            resultI = PSP_E_INVAL_PARAM;
            DDA_DEBUG_PRINTF("PSP_HISTIoctl : Invalid parameter");
        }
        else if (DDC_HIST_INVALID_STATE == statusI)
        {
            resultI = PSP_E_INVAL_STATE;
            DDA_DEBUG_PRINTF("PSP_HISTIoctl : Invalid state");
        }
    }
    return (resultI);
}

/**
 * \brief   PSP_HISTSubmit
 *          This function calls DDC layer function to perform submit command
 *          operation.
 */
PSP_Result PSP_HISTSubmit(PSP_Handle chnlHandle,
    PSP_VPSSSubmitCommand cmd,
    Ptr cmdArg)
{
    PSP_Result resultS = PSP_SOK;
    DDC_HISTstatus statusS;

    /* Check the Parameters */
    if ((NULL == chnlHandle) || (NULL == cmdArg))
    {
        resultS = PSP_E_INVAL_PARAM;
        DDA_DEBUG_PRINTF("PSP_HISTSubmit : Invalid parameter");
    }
    /* Channel handle should not be closed */
    else if (DDC_HIST_SOK == DDC_HISTIsChannelHandleClosed(chnlHandle))
    {
        resultS = PSP_E_INVAL_STATE;
        DDA_DEBUG_PRINTF("PSP_HISTSubmit : Invalid state");
    }
    else
    {
        statusS = DDC_HISTSubmit(chnlHandle, cmd, cmdArg);
        if (DDC_HIST_SOK == statusS)
        {
            resultS = PSP_SOK;
        }
        else if (DDC_HIST_NO_DATA == statusS)
        {
            resultS = PSP_E_IO_CANCEL_FAIL;
            DDA_DEBUG_PRINTF("PSP_HISTSubmit : No data available to Dequeue");
        }
        else if (DDC_HIST_INVALID_STATE == statusS)
        {
            resultS = PSP_E_INVAL_STATE;
            DDA_DEBUG_PRINTF("PSP_HISTSubmit : Invalid parameter");
        }
        else
        {
            resultS = PSP_E_INVAL_PARAM;
            DDA_DEBUG_PRINTF("PSP_HISTSubmit : Invalid parameter");
        }
    }
    return resultS;
}

