/*******************************************************************************
**+--------------------------------------------------------------------------+**
**|                            ****                                          |**
**|                            ****                                          |**
**|                            ******o***                                    |**
**|                      ********_///_****                                   |**
**|                      ***** /_//_/ ****                                   |**
**|                       ** ** (__/ ****                                    |**
**|                           *********                                      |**
**|                            ****                                          |**
**|                            ***                                           |**
**|                                                                          |**
**|         Copyright (c) 2006-2010 Texas Instruments Incorporated           |**
**|                        ALL RIGHTS RESERVED                               |**
**|                                                                          |**
**| Permission is hereby granted to licensees of Texas Instruments           |**
**| Incorporated (TI) products to use this computer program for the sole     |**
**| purpose of implementing a licensee product based on TI products.         |**
**| No other rights to reproduce, use, or disseminate this computer          |**
**| program, whether in part or in whole, are granted.                       |**
**|                                                                          |**
**| TI makes no representation or warranties with respect to the             |**
**| performance of this computer program, and specifically disclaims         |**
**| any responsibility for any damages, special or consequential,            |**
**| connected with the use of this program.                                  |**
**|                                                                          |**
**+--------------------------------------------------------------------------+**
*******************************************************************************/
/**
 * \file   ddc_hist.c
 *
 * \brief  DDC layer source file
 *
 * This file contains the implementation of the Histogram device driver
 *
 * (C) Copyright 2010, Texas Instruments, Inc
 *
 * \author     EI5
 *
 * \version    0.1             Created
 *             1.0             First Release
 */

/******************************************************************************
  Header File Inclusion
 ******************************************************************************/
#include <ti/sdo/edma3/drv/edma3_drv.h>
#include <ti/sdo/pspdrivers/pal_os/pal_osSem.h>
#include <ti/sdo/pspdrivers/pal_os/pal_osMem.h>
#include <ti/sdo/pspdrivers/pal_os/pal_oslist.h>
#include <ti/sdo/pspdrivers/pal_os/pal_osProtect.h>
#include <ti/sdo/pspdrivers/drivers/histogram/src/ddc_hist.h>
#include <ti/sdo/pspdrivers/drivers/histogram/psp_histogram.h>
#include <ti/sdo/pspdrivers/drivers/histogram/src/llc_hist.h>
#include <ti/sdo/pspdrivers/soc/dm6437/dsp/soc.h>
#include <ti/sdo/pspdrivers/soc/dm6437/dsp/csl_error.h>
#include <clk.h>

#ifdef HIST_INSTRUMENTATION_ENABLED
#include <ti/sdo/pspdrivers/pal_os/bios/psp_log.h>
#endif /* HIST_INSTRUMENTATION_ENABLED */

/******************************************************************************
  Globals
 ******************************************************************************/
DDC_HISTdeviceobject histDeviceObject =
{   DDC_HIST_INSTANCE_ID, DDC_HIST_DELETED, DDC_HIST_EDMA_CHNL_INITVAL, NULL,
    {   DDC_HIST_CHAN_CLOSED,
        { PSP_HIST_CLEAR_AFTER_READ, PSP_HIST_32BINS,
            PSP_HIST_DATA_RSHIFT_ZERO,
            { DDC_HIST_WBGAIN_INITVAL, DDC_HIST_WBGAIN_INITVAL,
                DDC_HIST_WBGAIN_INITVAL, DDC_HIST_WBGAIN_INITVAL },
            {
                { DDC_HIST_REG_BNDRY_INITVAL, DDC_HIST_REG_BNDRY_INITVAL,
                    DDC_HIST_REG_BNDRY_INITVAL, DDC_HIST_REG_BNDRY_INITVAL },
                { DDC_HIST_REG_BNDRY_INITVAL, DDC_HIST_REG_BNDRY_INITVAL,
                    DDC_HIST_REG_BNDRY_INITVAL, DDC_HIST_REG_BNDRY_INITVAL },
                { DDC_HIST_REG_BNDRY_INITVAL, DDC_HIST_REG_BNDRY_INITVAL,
                    DDC_HIST_REG_BNDRY_INITVAL, DDC_HIST_REG_BNDRY_INITVAL },
                { DDC_HIST_REG_BNDRY_INITVAL, DDC_HIST_REG_BNDRY_INITVAL,
                    DDC_HIST_REG_BNDRY_INITVAL, DDC_HIST_REG_BNDRY_INITVAL }
            },
        },
        DDC_STATE_CONFIGURED,
        { DDC_HIST_QUEUE_IDX_INITVAL, DDC_HIST_QUEUE_IDX_INITVAL,
            { NULL, NULL},
            { NULL, NULL}
        },
        NULL, NULL, DDC_HIST_EDMA_TCC_INITVAL, NULL
    }
};

static EDMA3_DRV_PaRAMRegs histEdmaConfigParam;

/******************************************************************************
  Functions
 ******************************************************************************/
/**
 * \brief   DDC_HISTOpenHandle
 *          This function opens the channel handle, initializes the Enqueue and
 *          Dequeue & creates the semaphore. It also creates & opens the edma
 *          handle if it is not provided by the application and request the
 *          edma channel.
 */
PSP_Handle DDC_HISTOpenHandle(PSP_Handle edmaHandleDDC)
{
    DDC_HISTdeviceobject *histDeviceHandleOpen = NULL;
    DDC_HISTchannelobject *handleToReturnOH = NULL;

    /*Get the Device Handle */
    histDeviceHandleOpen = (DDC_HISTdeviceobject* )DDC_HISTGetDeviceHandle();

    if (NULL == edmaHandleDDC)
    {
        handleToReturnOH = NULL;
        DDC_DEBUG_PRINTF("DDC_HISTOpenHandle : Invalid parameter");
    }
    else if (NULL == histDeviceHandleOpen)
    {
        handleToReturnOH = NULL;
        DDC_DEBUG_PRINTF("DDC_HISTOpenHandle : Device handle is NULL");
    }
    else
    {
        if (DDC_HIST_OPENED == histDeviceHandleOpen->stateDVC)
        {
            handleToReturnOH = NULL;
            DDC_DEBUG_PRINTF("DDC_HISTOpenHandle : Invalid state");
        }
        else
        {
            /*Get the Channel Handle */
            handleToReturnOH = DDC_HISTGetChannelHandle();
            /*Check params and Channel Handle not NULL */
            if (NULL != handleToReturnOH)
            {
                if (PAL_SOK != PAL_osMemSet(&(handleToReturnOH->regParam),
                        DDC_HIST_REGPARAM_INITVAL, sizeof(PSP_HISTparam)))
                {
                    handleToReturnOH = NULL;
                    DDC_DEBUG_PRINTF("DDC_HISTOpenHandle : Memset failed");
                }
                else
                {
                    handleToReturnOH->paramConfigState
                        = DDC_STATE_NOT_CONFIGURED;
                    handleToReturnOH->stateCH = DDC_HIST_CHAN_OPENED;
                    handleToReturnOH->semTimeOut = PAL_OSSEM_NO_TIMEOUT;
                    histDeviceHandleOpen->stateDVC = DDC_HIST_OPENED;
                    handleToReturnOH->bufferObj = handleToReturnOH->bufferObj;

                    PAL_OSLIST_MKNODE(&(handleToReturnOH->bufferObj.enQueue));
                    PAL_OSLIST_MKNODE(&(handleToReturnOH->bufferObj.deQueue));
                    handleToReturnOH->bufferObj.indexEnQueue
                        = DDC_HIST_MIN_ENQUEUE_ELEMENT;
                    handleToReturnOH->bufferObj.indexDeQueue
                        = DDC_HIST_MIN_DEQUEUE_ELEMENT;
                    if (PAL_SOK != PAL_osSemCreate("channelSem",
                            DDC_HIST_CHNLSEM_COUNT, NULL,
                            &(handleToReturnOH->channelSem)))
                    {
                        handleToReturnOH = NULL;
                        DDC_DEBUG_PRINTF(
                            "DDC_HISTOpenHandle : Channel Sem creation failed");
                    }
                    else if (PAL_SOK != PAL_osSemCreate("semIsr",
                            DDC_HIST_ISRSEM_COUNT, NULL,
                            &(handleToReturnOH->semIsr)))
                    {
                        PAL_osSemDelete(&(handleToReturnOH->channelSem));
                        handleToReturnOH = NULL;
                        DDC_DEBUG_PRINTF(
                            "DDC_HISTOpenHandle : Isr Sem creation failed");
                    }
                    else
                    {
                        handleToReturnOH->edmaHandle = edmaHandleDDC;
                        if (NULL != handleToReturnOH->edmaHandle)
                        {
                            handleToReturnOH->tcc = (EDMA3_DRV_TCC_ANY);
                            if (EDMA3_DRV_SOK != EDMA3_DRV_requestChannel (
                                    handleToReturnOH->edmaHandle,
                                    &histDeviceHandleOpen->edmaChannelNo,
                                    &handleToReturnOH->tcc,
                                    (EDMA3_RM_EventQueue)
                                    DDC_HIST_EDMA_EVNT_QUEUE,
                                    &DDC_HISTEdmaisr,
                                    handleToReturnOH))
                            {
                                PAL_osSemDelete(
                                    &(handleToReturnOH->channelSem));
                                PAL_osSemDelete(&(handleToReturnOH->semIsr));
                                handleToReturnOH = NULL;
                                DDC_DEBUG_PRINTF(
                                    "DDC_HISTOpenHandle : EDMA chnl rqst failed"
                                    );
                            }
                        }
                    }
                }
            }
            else
            {
                DDC_DEBUG_PRINTF("DDC_HISTOpenHandle : channel handle is NULL");
            }
        }
    }
    return ((PSP_Handle)handleToReturnOH);
}

/**
 * \brief   DDC_HISTCloseHandle
 *          This function closes the channel handle & deletes the semaphore.
 *          It also delete & close the edma handle if it is created & opened
 *          by the driver and make the edma channel free.
 */
DDC_HISTstatus DDC_HISTCloseHandle(PSP_Handle handle)
{
    DDC_HISTstatus resultCH = DDC_HIST_E_FAIL;
    DDC_HISTdeviceobject *handleDeviceCH = NULL;
    DDC_HISTchannelobject *handleChannelCH = NULL;

    /*Get the Device Handle */
    handleDeviceCH = (DDC_HISTdeviceobject* )DDC_HISTGetDeviceHandle();

    /*Check Device handle not NULL */
    if (NULL == handle)
    {
        resultCH = DDC_HIST_INVALID_PARAM;
        DDC_DEBUG_PRINTF("DDC_HISTCloseHandle : Invalid parameter");
    }
    else if (NULL == handleDeviceCH)
    {
        resultCH = DDC_HIST_INVALID_PARAM;
        DDC_DEBUG_PRINTF("DDC_HISTCloseHandle : Device handle is NULL");
    }
    else
    {
        handleChannelCH = (DDC_HISTchannelobject *)handle;
        if (DDC_HIST_CHAN_OPENED == handleChannelCH->stateCH)
        {
            if (NULL != handleChannelCH->edmaHandle)
            {
                if (EDMA3_DRV_SOK == EDMA3_DRV_disableTransfer (
                        handleChannelCH->edmaHandle,
                        handleDeviceCH->edmaChannelNo,
                        EDMA3_DRV_TRIG_MODE_EVENT))
                {
                    if (EDMA3_DRV_SOK == EDMA3_DRV_freeChannel(
                            handleChannelCH->edmaHandle,
                            handleDeviceCH->edmaChannelNo))
                    {
                        if (CSL_SOK == LLC_HISTDisableHistogram(
                                handleDeviceCH->regs))
                        {
                            if (PAL_SOK == PAL_osSemDelete(
                                    &(handleChannelCH->channelSem)))
                            {
                                if (PAL_SOK == PAL_osSemDelete(
                                        &(handleChannelCH->semIsr)))
                                {
                                    resultCH = DDC_HIST_SOK;
                                    handleDeviceCH->stateDVC = DDC_HIST_CLOSED;
                                    handleChannelCH->stateCH
                                        = DDC_HIST_CHAN_CLOSED;
                                }
                                else
                                {
                                    resultCH = DDC_HIST_E_FAIL;
                                    DDC_DEBUG_PRINTF(
                                        "HISTCloseHndl:Isr Sem delete failed");
                                }
                            }
                            else
                            {
                                resultCH = DDC_HIST_E_FAIL;
                                DDC_DEBUG_PRINTF(
                                    "DDC_HISTCloseHandle : Sem delete failed");
                            }

                        }
                        else
                        {
                            resultCH = DDC_HIST_E_FAIL;
                            DDC_DEBUG_PRINTF(
                                "DDC_HISTCloseHandle: Hist disable fail");
                        }
                    }
                    else
                    {
                        resultCH = DDC_HIST_E_FAIL;
                        DDC_DEBUG_PRINTF(
                            "DDC_HISTCloseHandle : EDMA chnl free failed");
                    }
                }
                else
                {
                    resultCH = DDC_HIST_E_FAIL;
                    DDC_DEBUG_PRINTF(
                        "DDC_HISTCloseHandle : EDMA disable failed");
                }
            }
            else
            {
                resultCH = DDC_HIST_E_FAIL;
                DDC_DEBUG_PRINTF(
                    "DDC_HISTCloseHandle : EDMA handle is NULL");
            }
        }
        else
        {
            resultCH = DDC_HIST_INVALID_STATE;
            DDC_DEBUG_PRINTF("DDC_HISTCloseHandle : Invalid state");
        }
    }
    return resultCH;
}

/**
 * \brief   DDC_HISTIsChannelHandleClosed
 *          This function checks weather the channel handle is closed or not.
 */
DDC_HISTstatus DDC_HISTIsChannelHandleClosed(PSP_Handle handle)
{
    DDC_HISTstatus resultCHC = DDC_HIST_INVALID_STATE;
    DDC_HISTchannelobject *handleLocal = NULL;

    /*Check Channel handle not NULL */
    if (NULL != handle)
    {
        handleLocal = (DDC_HISTchannelobject*) handle;
        /*Check the State of CCDC Channel if Closed */
        if (DDC_HIST_CHAN_CLOSED == handleLocal->stateCH)
        {
            resultCHC = DDC_HIST_SOK;
            DDC_DEBUG_PRINTF(
                "DDC_HISTIsChannelHandleClosed : Channel handled is closed");
        }
    }
    else
    {
        resultCHC = DDC_HIST_SOK;
        DDC_DEBUG_PRINTF("DDC_HISTIsChannelHandleClosed : Invalid handle");
    }
    return(resultCHC);
}

/**
 * \brief   DDC_HISTGetDeviceHandle
 *          Get the histogram device handle.
 */
PSP_Handle DDC_HISTGetDeviceHandle()
{
    return(&histDeviceObject);
}

/**
 * \brief   DDC_HISTGetChannelHandle
 *          Get the histogram channel handle.
 */
PSP_Handle DDC_HISTGetChannelHandle()
{
    return((Ptr)&histDeviceObject.histChannelObj);
}

/**
 * \brief   DDC_HISTEdmaisr
 *          EDMA Interrupt service routine, it extracts the buffer containing
 *          statistics from the Enqueue queue & put that Into the Dequeuue
 *          queue. It also configures the EDMA parameters based on the next
 *          empty buffer. If no any empty buffer is there then it disables the
 *          Histogram module.
 */
/* ARGSUSED */
void DDC_HISTEdmaisr(Uint32 tcc, EDMA3_RM_TccStatus status, PSP_Handle data)
{
    DDC_HISTdeviceobject *histDeviceHandleED = (DDC_HISTdeviceobject *)
        DDC_HISTGetDeviceHandle();
    DDC_HISTchannelobject *channelED;
    PSP_HISTbuffer *elementED;
    Uint32 bytesToTransferED;

    if (EDMA3_RM_XFER_COMPLETE == status)
    {
        if (NULL != data)
        {
            channelED = (DDC_HISTchannelobject *)data;
            if ((NULL != channelED) && (NULL != histDeviceHandleED))
            {
                if (tcc == channelED->tcc)
                {
                    if (EDMA3_DRV_SOK == EDMA3_DRV_disableTransfer (
                            channelED->edmaHandle,
                            histDeviceHandleED->edmaChannelNo,
                            EDMA3_DRV_TRIG_MODE_EVENT))
                    {
                        if (channelED->bufferObj.indexEnQueue
                            >= DDC_HIST_MIN_QUEUE_ELEMENT)
                        {
                            if (channelED->bufferObj.indexEnQueue
                                > DDC_HIST_MIN_QUEUE_ELEMENT)
                            {
                                elementED = (PSP_HISTbuffer*)PAL_osList_NP_Dequeue(
                                    (PAL_OsListNodeHeader*)(&(
                                            channelED->bufferObj.enQueue)));
                                channelED->bufferObj.indexEnQueue--;
                                if (NULL != elementED)
                                {
/* Socrates Transfer Complete */
#ifdef HIST_INSTRUMENTATION_ENABLED
                                    PSP_LOG_EVENT( &DVTEvent_Log, "HISTOGRAM",
                                        PSP_DVT_DESC(   PSP_DVT_eDATA_SND_END,
                                            PSP_DVT_dCHANNEL_ID_INST,
                                            PSP_DVT_dPACKET_ID,
                                            PSP_DVT_dNONE
                                            ),
                                        CHANNELID_INSTANCEID(0,0),
                                        elementED
                                        );
#endif /* HIST_INSTRUMENTATION_ENABLED */

                                    elementED->timeStmp = CLK_getltime();

                                    PAL_osList_NP_Enqueue((PAL_OsListNodeHeader*)
                                        (&(channelED->bufferObj.deQueue)),
                                        (Ptr)elementED);
                                    channelED->bufferObj.indexDeQueue++;

                                    if (PAL_SOK !=
                                        PAL_osSemGive(channelED->semIsr))
                                    {
                                        DDC_DEBUG_PRINTF(
                                        "DDC_HISTEdmaisr : Error in semgive");
                                    }
                                }
                            }

                            if(FALSE == PAL_osList_NP_IsEmpty((PAL_OsListNodeHeader*)
                                    (&(channelED->bufferObj.enQueue))))
                            {
                                elementED = (PSP_HISTbuffer *)
                                    (channelED->bufferObj.enQueue.next);

                                bytesToTransferED = DDC_HIST_MAX_OP_BUFF_SIZE;
                                if (elementED->bufferSize < bytesToTransferED)
                                {
                                    bytesToTransferED = elementED->bufferSize;
                                }

/* Socrates Starting another one */
#ifdef HIST_INSTRUMENTATION_ENABLED
                                PSP_LOG_EVENT( &DVTEvent_Log, "HISTOGRAM",
                                    PSP_DVT_DESC(   PSP_DVT_eDATA_SND_START,
                                        PSP_DVT_dCHANNEL_ID_INST,
                                        PSP_DVT_dPACKET_ID,
                                        PSP_DVT_dNONE
                                        ),
                                    CHANNELID_INSTANCEID(0,0),
                                    elementED
                                    );
#endif /* HIST_INSTRUMENTATION_ENABLED */

                                EDMA3_DRV_setPaRAM(
                                    channelED->edmaHandle,
                                    histDeviceHandleED->edmaChannelNo,
                                    &histEdmaConfigParam);

                                EDMA3_DRV_setDestParams(
                                    channelED->edmaHandle,
                                    histDeviceHandleED->edmaChannelNo,
                                    (Uint32)(elementED->ramIpAddr),
                                    EDMA3_DRV_ADDR_MODE_INCR,
                                    EDMA3_DRV_W8BIT);

                                EDMA3_DRV_setTransferParams(
                                    channelED->edmaHandle,
                                    histDeviceHandleED->edmaChannelNo,
                                    DDC_HIST_EDMA_A_CNT,
                                    bytesToTransferED,
                                    DDC_HIST_EDMA_C_CNT,
                                    DDC_HIST_EDMA_B_CNT_RLD,
                                    EDMA3_DRV_SYNC_AB);

                                EDMA3_DRV_enableTransfer (
                                    channelED->edmaHandle,
                                    histDeviceHandleED->edmaChannelNo,
                                    EDMA3_DRV_TRIG_MODE_EVENT);
                            }
                        }
                    }
                }
            }
        }
    }
}

/**
 * \brief   DDC_HISTPerformRegOverlaying
 *          Gets the register base address.
 */
DDC_HISTstatus DDC_HISTPerformRegOverlaying()
{
    DDC_HISTstatus returnRO = DDC_HIST_SOK;
    DDC_HISTdeviceobject *histDeviceObjectCreateRO
        = (DDC_HISTdeviceobject *)DDC_HISTGetDeviceHandle();
    if (NULL != histDeviceObjectCreateRO)
    {
        histDeviceObjectCreateRO->regs = (Ptr)(CSL_VPSS_HIST_0_REGS);
    }
    else
    {
        returnRO = DDC_HIST_E_FAIL;
        DDC_DEBUG_PRINTF(
            "DDC_HISTPerformRegOverlaying : Device handle is NULL");
    }
    return (returnRO);
}

/**
 * \brief   DDC_HISTSetDeviceEventNumber
 *          Get the EDMA channel number.
 */
DDC_HISTstatus DDC_HISTSetDeviceEventNumber()
{
    DDC_HISTstatus returnDEN = DDC_HIST_SOK;
    DDC_HISTdeviceobject *histDeviceObjectCreateDEN
        = (DDC_HISTdeviceobject *)DDC_HISTGetDeviceHandle();
    if (NULL != histDeviceObjectCreateDEN)
    {
        histDeviceObjectCreateDEN->edmaChannelNo
            = CSL_EDMA3_CHA_HISTEVT;
    }
    else
    {
        returnDEN = DDC_HIST_E_FAIL;
        DDC_DEBUG_PRINTF(
            "DDC_HISTSetDeviceEventNumber : Device handle is NULL");
    }
    return (returnDEN);
}

/**
 * \brief   DDC_HISTValidateParameters
 *          This function Validates the configuration parameters provided by
 *          application. If all parameters are valid & if Histogram module is
 *          not busy then it calls LLC_HISTWritereg() function to write
 *          registers of Histogram module.
 */
DDC_HISTstatus DDC_HISTValidateParameters(
    DDC_HISTchannelobject * const histConfChanVP,
    PSP_HISTparam  * const params)
{
    Uint32 loopCounterVP;
    Int retVP;
    Int maxRegionVP;
    Uint32 srcAdrsVP;
    DDC_HISTchannelobject *channelVP;
    DDC_HISTdeviceobject *histDeviceHandleVP = (DDC_HISTdeviceobject* )
        DDC_HISTGetDeviceHandle();
    DDC_HISTstatus resultVP = DDC_HIST_SOK;

    if ((NULL == histConfChanVP) || (NULL == params))
    {
        resultVP = DDC_HIST_E_FAIL;
        DDC_DEBUG_PRINTF("DDC_HISTValidateParameters : Invalid parameter");
    }
    else if (params->clearOpDataAfterRead > PSP_HIST_CLEAR_AFTER_READ)
    {
        resultVP = DDC_HIST_INVALID_PARAM;
        DDC_DEBUG_PRINTF("DDC_HISTValidateParameters : Invalid parameter");
    }
    else if (params->bins > PSP_HIST_256BINS)
    {
        resultVP = DDC_HIST_INVALID_PARAM;
        DDC_DEBUG_PRINTF("DDC_HISTValidateParameters : Invalid parameter");
    }
    else if (params->shift > PSP_HIST_DATA_RSHIFT_SEVEN)
    {
        resultVP = DDC_HIST_INVALID_PARAM;
        DDC_DEBUG_PRINTF("DDC_HISTValidateParameters : Invalid parameter");
    }
    else
    {
        if (PSP_HIST_256BINS == params->bins)
        {
            maxRegionVP = DDC_HIST_256BINS_MAXREGION;
        }
        else if (PSP_HIST_128BINS == params->bins)
        {
            maxRegionVP = DDC_HIST_128BINS_MAXREGION;
        }
        else
        {
            maxRegionVP = DDC_HIST_64BINS_MAXREGION;
        }

        for(loopCounterVP = 0; loopCounterVP < maxRegionVP;
            loopCounterVP++)
        {
            if (((params->region[loopCounterVP].hStart
                        >= PSP_HIST_REGION_MAX_HPOS)
                    || (params->region[loopCounterVP].hEnd
                        >= PSP_HIST_REGION_MAX_HPOS) )
                || ((params->region[loopCounterVP].vStart
                        >= PSP_HIST_REGION_MAX_VPOS)
                    || (params->region[loopCounterVP].vEnd
                        >= PSP_HIST_REGION_MAX_VPOS)))
            {
                resultVP = DDC_HIST_INVALID_PARAM;
                DDC_DEBUG_PRINTF(
                    "DDC_HISTValidateParameters : Invalid parameter");
            }
            if (DDC_HIST_SOK == resultVP)
            {
                if ((params->region[loopCounterVP].hStart
                        == params->region[loopCounterVP].hEnd)
                    || (params->region[loopCounterVP].vStart
                        == params->region[loopCounterVP].vEnd))
                {
                    resultVP = DDC_HIST_INVALID_PARAM;
                    DDC_DEBUG_PRINTF(
                        "DDC_HISTValidateParameters : Invalid parameter");
                }
            }
            if (DDC_HIST_INVALID_PARAM == resultVP)
            {
                break;
            }
        }
        if (DDC_HIST_SOK == resultVP)
        {
            if (NULL != histDeviceHandleVP)
            {
                retVP = LLC_HISTGetHWStatus(histDeviceHandleVP->regs);
                if (DDC_HIST_BUSY == retVP)
                {
                    resultVP = DDC_HIST_INVALID_STATE;
                    DDC_DEBUG_PRINTF(
                        "DDC_HISTValidateParameters : Hardware is busy");
                }
                else if (CSL_ESYS_FAIL == retVP)
                {
                    resultVP = DDC_HIST_E_FAIL;
                    DDC_DEBUG_PRINTF(
                        "DDC_HISTValidateParameters : Parameter update failed");
                }
                if (DDC_HIST_SOK == resultVP)
                {
                    if (PAL_SOK != PAL_osMemCopy(
                            (Ptr)(&(histConfChanVP->regParam)),
                            (Ptr)(params), sizeof(PSP_HISTparam)))
                    {
                        resultVP = DDC_HIST_E_FAIL;
                        DDC_DEBUG_PRINTF(
                            "DDC_HISTValidateParameters : Memcpy failed");
                    }
                    else
                    {
                        if (CSL_SOK == LLC_HISTWritereg(
                                (PSP_HISTparam*)(&(histConfChanVP->regParam)),
                                histDeviceHandleVP->regs))
                        {
                            histConfChanVP->paramConfigState
                                = DDC_STATE_CONFIGURED;
                        }
                        else
                        {
                            resultVP = DDC_HIST_E_FAIL;
                            DDC_DEBUG_PRINTF(
                                "DDC_HISTValidateParameters:Reg writing failed."
                                );
                        }
                    }
                }
            }
            else
            {
                resultVP = DDC_HIST_E_FAIL;
                DDC_DEBUG_PRINTF(
                    "DDC_HISTValidateParameters : Device handle is NULL");
            }
        }
    }

    if (DDC_HIST_SOK == resultVP)
    {
        channelVP = (DDC_HISTchannelobject *)histConfChanVP;

        srcAdrsVP = LLC_HISTGetHistDataAdrs(histDeviceHandleVP->regs);

        if (NULL ==  srcAdrsVP)
        {
            resultVP = DDC_HIST_E_FAIL;
            DDC_DEBUG_PRINTF(
                "DDC_HISTValidateParameters : Source address is NULL");
        }
        else if ( EDMA3_DRV_SOK != EDMA3_DRV_setSrcParams(
                channelVP->edmaHandle,
                histDeviceHandleVP->edmaChannelNo,
                srcAdrsVP,
                EDMA3_DRV_ADDR_MODE_INCR,
                EDMA3_DRV_W8BIT))
        {
            resultVP = DDC_HIST_E_FAIL;
            DDC_DEBUG_PRINTF(
                "DDC_HISTValidateParameters : EDMA set source parameter failed"
                );
        }
        else if (EDMA3_DRV_SOK != EDMA3_DRV_setSrcIndex(
                channelVP->edmaHandle,
                histDeviceHandleVP->edmaChannelNo,
                DDC_HIST_EDMA_SRC_BINDEX,
                DDC_HIST_EDMA_SRC_CINDEX))
        {
            resultVP = DDC_HIST_E_FAIL;
            DDC_DEBUG_PRINTF(
                "DDC_HISTValidateParameters : EDMA set source index failed");
        }
        else if (EDMA3_DRV_SOK != EDMA3_DRV_setDestIndex(
                channelVP->edmaHandle,
                histDeviceHandleVP->edmaChannelNo,
                DDC_HIST_EDMA_DEST_BINDEX,
                DDC_HIST_EDMA_DEST_CINDEX))
        {
            resultVP = DDC_HIST_E_FAIL;
            DDC_DEBUG_PRINTF(
                "DDC_HISTValidateParameters : EDMA set destination index failed"
                );
        }
        else if (EDMA3_DRV_SOK != EDMA3_DRV_setOptField(
                channelVP->edmaHandle,
                histDeviceHandleVP->edmaChannelNo,
                EDMA3_DRV_OPT_FIELD_TCC,
                channelVP->tcc))
        {
            resultVP = DDC_HIST_E_FAIL;
            DDC_DEBUG_PRINTF(
                "DDC_HISTValidateParameters : EDMA set opt parameter failed");
        }
        else if (EDMA3_DRV_SOK != EDMA3_DRV_setOptField(
                channelVP->edmaHandle,
                histDeviceHandleVP->edmaChannelNo,
                EDMA3_DRV_OPT_FIELD_TCINTEN,
                TRUE))
        {
            resultVP = DDC_HIST_E_FAIL;
            DDC_DEBUG_PRINTF(
                "DDC_HISTValidateParameters : EDMA set opt parameter failed");
        }
        else if (EDMA3_DRV_SOK != EDMA3_DRV_getPaRAM(
                channelVP->edmaHandle,
                histDeviceHandleVP->edmaChannelNo,
                (EDMA3_DRV_PaRAMRegs *)(&histEdmaConfigParam)))
        {
            resultVP = DDC_HIST_E_FAIL;
            DDC_DEBUG_PRINTF(
                "DDC_HISTValidateParameters : EDMA get parameter failed");
        }
    }

    return resultVP;
}

/**
 * \brief   DDC_HISTGetParameters
 *          This function provides the configuration parameters to application.
 *
 */
DDC_HISTstatus DDC_HISTGetParameters(DDC_HISTchannelobject * const histConfChan,
    PSP_HISTparam  * const params)
{
    DDC_HISTstatus statusGP = DDC_HIST_SOK;

    if ((NULL == histConfChan) || (NULL == params))
    {
        statusGP = DDC_HIST_E_FAIL;
        DDC_DEBUG_PRINTF("DDC_HISTGetParameters : Invalid parameter");
    }
    else if (DDC_STATE_CONFIGURED != histConfChan->paramConfigState)
    {
        statusGP = DDC_HIST_INVALID_STATE;
        DDC_DEBUG_PRINTF("DDC_HISTGetParameters : Invalid state");
    }
    else
    {
        if (PAL_SOK != PAL_osMemCopy((Ptr)(params),
                (Ptr)(&(histConfChan->regParam)),
                sizeof(PSP_HISTparam)))
        {
            statusGP = DDC_HIST_E_FAIL;
            DDC_DEBUG_PRINTF("DDC_HISTGetParameters : Memcpy failed");
        }
    }
    return statusGP;
}

/**
 * \brief  DDC_HISTIoctl
 *         This function performs the control operation depending on the ioctl.
 *
 */
DDC_HISTstatus  DDC_HISTIoctl(PSP_Handle handle, PSP_HISTIoctlCmd cmd,
    Ptr cmdArg)
{
    DDC_HISTstatus resultI;
    switch (cmd)
    {
        case PSP_HIST_IOCTL_SET_PARAMS:
            {
                /*Configure and validate the histogram Parameters */
                resultI = DDC_HISTValidateParameters(handle, cmdArg);
            }
            break;
        case PSP_HIST_IOCTL_GET_PARAMS:
            {
                /* Get the Histogram Paremeters */
                resultI =  DDC_HISTGetParameters(handle, cmdArg);
            }
            break;
        case PSP_HIST_IOCTL_SET_SEM_TIMEOUT:
            {
                if (NULL != cmdArg)
                {
                    /* Change the semTimeOut value */
                    ((DDC_HISTchannelobject *)handle)->semTimeOut
                                                    = *(Int32 *)cmdArg;
                    resultI = DDC_HIST_SOK;
                }
                else
                {
                    resultI = DDC_HIST_INVALID_PARAM;
                }
            }
            break;
        default:
            {
                resultI = DDC_HIST_NOT_SUPPORTED;
                DDC_DEBUG_PRINTF("DDC_HISTIoctl : Invalid IOCLT");
            }
            break;
    }
    return resultI;
}

/**
 * \brief   DDC_HISTRemoveModule
 *          Removes the device.
 *
 */
PSP_Handle DDC_HISTRemoveModule(void)
{
    DDC_HISTdeviceobject * histDeviceHandleDelete
        = (DDC_HISTdeviceobject * )DDC_HISTGetDeviceHandle();

    if (NULL != histDeviceHandleDelete)
    {
        if ((DDC_HIST_CREATED == histDeviceHandleDelete->stateDVC)
            || (DDC_HIST_CLOSED == histDeviceHandleDelete->stateDVC))
        {
            histDeviceHandleDelete = NULL;
        }
        else
        {
            DDC_DEBUG_PRINTF("DDC_HISTRemoveModule : Invalid state");
        }
    }
    else
    {
        DDC_DEBUG_PRINTF("DDC_HISTRemoveModule : Device Handle is NULL");
    }
    return ((Ptr)(histDeviceHandleDelete));
}

/**
 * \brief   DDC_HISTInitializeModule
 *          Creates the device handle.
 *
 */
PSP_Handle DDC_HISTInitializeModule(Uint32 instanceId)
{
    DDC_HISTdeviceobject *histDeviceObjectCreateIM = (DDC_HISTdeviceobject *)
        DDC_HISTGetDeviceHandle();

    if (NULL != histDeviceObjectCreateIM)
    {
        if (DDC_HIST_CREATED == histDeviceObjectCreateIM->stateDVC)
        {
            histDeviceObjectCreateIM = NULL;
            DDC_DEBUG_PRINTF("DDC_HISTInitializeModule : Invalid state");
        }
        else
        {
            histDeviceObjectCreateIM->stateDVC = DDC_HIST_CREATED;
            histDeviceObjectCreateIM->histInstanceId = instanceId;
        }
    }
    else
    {
        DDC_DEBUG_PRINTF("DDC_HISTInitializeModule : Device Handle is NULL");
    }
    return ((Ptr)histDeviceObjectCreateIM);
}

/**
 * \brief   DDC_HISTEnquebuffer
 *          This function queues the buffer provided by application Into the
 *          Enqueue and if it is the first buffer it will configure the EDMA
 *          parameters & Enables the Histogram module.
 */
DDC_HISTstatus  DDC_HISTEnquebuffer(PSP_Handle chnlHandle, Ptr cmdArg)
{
    DDC_HISTstatus resultEB = DDC_HIST_SOK;
    Uint32 bytesToTransferEB;
    DDC_HISTdeviceobject *histDeviceHandleEB = (DDC_HISTdeviceobject *)
        DDC_HISTGetDeviceHandle();
    PSP_HISTbuffer *elementEB;
    DDC_HISTchannelobject *channelEB;
    Uint32 cookieEB = DDC_HIST_HWISTATUS_INITVAL;

    if ((NULL == cmdArg) || (NULL == chnlHandle))
    {
        resultEB = DDC_HIST_E_FAIL;
        DDC_DEBUG_PRINTF("DDC_HISTEnquebuffer : Invalid parameter");
    }
    else
    {
        elementEB = (PSP_HISTbuffer *)cmdArg;
        channelEB = (DDC_HISTchannelobject *)chnlHandle;

        if (((NULL != elementEB) && (NULL != channelEB))
            && (NULL != histDeviceHandleEB))
        {
            PAL_osProtectEntry(PAL_OSPROTECT_INTERRUPT, &cookieEB);

            /* Enqueue the elemnt */
            PAL_osListEnqueue((PAL_OsListNodeHeader*)
                (&(channelEB->bufferObj.enQueue)), (Ptr)elementEB);
            channelEB->bufferObj.indexEnQueue++;

            PAL_osProtectExit(PAL_OSPROTECT_INTERRUPT, cookieEB);

            /* If this is the first buffer, then configure EDMA and
               enable histogram module */
            if (DDC_HIST_MIN_QUEUE_ELEMENT == channelEB->bufferObj.indexEnQueue)
            {

                /* Socrates Starting Transfer */
#ifdef HIST_INSTRUMENTATION_ENABLED
                PSP_LOG_EVENT( &DVTEvent_Log, "HISTOGRAM",
                    PSP_DVT_DESC(   PSP_DVT_eDATA_SND_START,
                        PSP_DVT_dCHANNEL_ID_INST,
                        PSP_DVT_dPACKET_ID,
                        PSP_DVT_dNONE
                        ),
                    CHANNELID_INSTANCEID(0,0),
                    elementEB
                    );
#endif /* HIST_INSTRUMENTATION_ENABLED */

                bytesToTransferEB = DDC_HIST_MAX_OP_BUFF_SIZE;
                if (elementEB->bufferSize < bytesToTransferEB)
                {
                    bytesToTransferEB = elementEB->bufferSize;
                }

                if (EDMA3_DRV_SOK != EDMA3_DRV_setPaRAM(
                        channelEB->edmaHandle,
                        histDeviceHandleEB->edmaChannelNo,
                        &histEdmaConfigParam))
                {
                    resultEB = DDC_HIST_E_FAIL;
                    DDC_DEBUG_PRINTF(
                        "DDC_HISTEnquebuffer : EDMA set parameter failed");
                }
                else if (EDMA3_DRV_SOK != EDMA3_DRV_setDestParams(
                        channelEB->edmaHandle,
                        histDeviceHandleEB->edmaChannelNo,
                        (Uint32)(elementEB->ramIpAddr),
                        EDMA3_DRV_ADDR_MODE_INCR,
                        EDMA3_DRV_W8BIT))
                {
                    resultEB = DDC_HIST_E_FAIL;
                    DDC_DEBUG_PRINTF(
                        "DDC_HISTEnquebuffer : EDMA set dest parameter failed");
                }
                else if (EDMA3_DRV_SOK != EDMA3_DRV_setTransferParams(
                        channelEB->edmaHandle,
                        histDeviceHandleEB->edmaChannelNo,
                        DDC_HIST_EDMA_A_CNT,
                        bytesToTransferEB,
                        DDC_HIST_EDMA_C_CNT,
                        DDC_HIST_EDMA_B_CNT_RLD,
                        EDMA3_DRV_SYNC_AB))
                {
                    resultEB = DDC_HIST_E_FAIL;
                    DDC_DEBUG_PRINTF(
                        "DDC_HISTEnquebuffer:EDMA set transfer param failed");
                }
                else if (EDMA3_DRV_SOK != EDMA3_DRV_enableTransfer (
                        channelEB->edmaHandle,
                        histDeviceHandleEB->edmaChannelNo,
                        EDMA3_DRV_TRIG_MODE_EVENT))
                {
                    resultEB = DDC_HIST_E_FAIL;
                    DDC_DEBUG_PRINTF(
                        "DDC_HISTEnquebuffer : EDMA enable transfer failed");
                }
                else if (CSL_SOK != LLC_HISTEnableHistogram(
                        histDeviceHandleEB->regs))
                {
                    resultEB = DDC_HIST_E_FAIL;
                    DDC_DEBUG_PRINTF(
                        "DDC_HISTEnquebuffer : Histogram enable failed");
                }
            }
        }
        else
        {
            resultEB = DDC_HIST_E_FAIL;
            DDC_DEBUG_PRINTF("DDC_HISTEnquebuffer : Invalid parameter");
        }
    }

    return (resultEB);
}

/**
 * \brief   DDC_HISTDequebuffer
 *          This function extract buffer containing statistics from the Dequeue
 *          and provide it to the application.
 */
DDC_HISTstatus  DDC_HISTDequebuffer(PSP_Handle chnlHandle, Ptr cmdArg)
{
    DDC_HISTstatus resultDB = DDC_HIST_SOK;
    Uint32 cookieDB = DDC_HIST_HWISTATUS_INITVAL;

    if ((NULL != cmdArg) || (NULL != chnlHandle))
    {
        PSP_HISTbuffer *elementDB;
        DDC_HISTchannelobject *channelDB = (DDC_HISTchannelobject *)chnlHandle;
        if (NULL != channelDB)
        {
            if ((channelDB->bufferObj.indexDeQueue >
                    DDC_HIST_MIN_DEQUEUE_ELEMENT)
                || (channelDB->bufferObj.indexEnQueue >
                    DDC_HIST_MIN_QUEUE_ELEMENT))
            {
                if (PAL_SOK != PAL_osSemTake (channelDB->semIsr,
                        DDC_HIST_ISRSEM_TMOUT))
                {
                    resultDB = DDC_HIST_NO_DATA;
                    DDC_DEBUG_PRINTF(
                        "DDC_HISTDequebuffer : Isr Sem take failed");
                }
                else
                {
                    PAL_osProtectEntry(PAL_OSPROTECT_INTERRUPT, &cookieDB);

                    elementDB = (PSP_HISTbuffer*) PAL_osListDequeue(
                        (PAL_OsListNodeHeader*)&(channelDB->bufferObj.deQueue));
                    channelDB->bufferObj.indexDeQueue--;
                    *(PSP_HISTbuffer **)cmdArg = elementDB;

                    PAL_osProtectExit(PAL_OSPROTECT_INTERRUPT, cookieDB);
                }
            }
            else
            {
                resultDB = DDC_HIST_INVALID_STATE;
                DDC_DEBUG_PRINTF("DDC_HISTDequebuffer : No buffer in Dequeue");
            }
        }
        else
        {
            resultDB = DDC_HIST_E_FAIL;
            DDC_DEBUG_PRINTF("DDC_HISTDequebuffer : Invalid parameter");
        }
    }
    else
    {
        resultDB = DDC_HIST_E_FAIL;
        DDC_DEBUG_PRINTF("DDC_HISTDequebuffer : Invalid parameter");
    }

    return resultDB;
}

/**
 * \brief  DDC_HISTSubmit
 *         This function calls the function for Enqueue/Dequeue operation based
 *         on the command.
 */
DDC_HISTstatus  DDC_HISTSubmit(PSP_Handle chnlHandle, PSP_VPSSSubmitCommand cmd,
    Ptr cmdArg)
{
    DDC_HISTstatus resultS = DDC_HIST_SOK;

    if ((NULL != chnlHandle) || (NULL != cmdArg))
    {
        PSP_HISTbuffer *elementS = (PSP_HISTbuffer *)cmdArg;
        DDC_HISTchannelobject *channelS = (DDC_HISTchannelobject *)chnlHandle;
        if ((NULL != channelS) && (NULL != elementS))
        {
            if (DDC_STATE_CONFIGURED != channelS->paramConfigState)
            {
                resultS = DDC_HIST_INVALID_STATE;
                DDC_DEBUG_PRINTF(
                    "DDC_HISTSubmit : Parameters are not configured");
            }
            else if ((PSP_VPSS_DEQUEUE != cmd) && (PSP_VPSS_QUEUE != cmd) )
            {
                resultS = DDC_HIST_INVALID_PARAM;
                DDC_DEBUG_PRINTF("DDC_HISTSubmit : Invalid command");
            }
            else if (PAL_SOK != PAL_osSemTake (channelS->channelSem,
                                               channelS->semTimeOut))
            {
                resultS = DDC_HIST_E_FAIL;
                DDC_DEBUG_PRINTF("DDC_HISTSubmit : Sem take failed");
            }
            else
            {
                switch (cmd)
                {
                    case PSP_VPSS_DEQUEUE:
                        {
                            resultS = DDC_HISTDequebuffer( chnlHandle, cmdArg);
                        }
                        break;
                    case PSP_VPSS_QUEUE:
                        {
                            /* Check the buffer Address is not NULL */
                            if (NULL == elementS->ramIpAddr)
                            {
                                resultS = DDC_HIST_INVALID_PARAM;
                                DDC_DEBUG_PRINTF(
                                    "DDC_HISTSubmit : Invalid parameter");
                            }
                            else
                            {
                                resultS = DDC_HISTEnquebuffer(
                                    chnlHandle, cmdArg);
                            }
                        }
                        break;
                    default:
                        {
                            resultS = DDC_HIST_INVALID_PARAM;
                            DDC_DEBUG_PRINTF(
                                "DDC_HISTSubmit : Invalid command");
                        }
                        break;
                }

                /* Release the Lock */
                if (PAL_SOK != PAL_osSemGive(channelS->channelSem))
                {
                    resultS = DDC_HIST_E_FAIL;
                    DDC_DEBUG_PRINTF("DDC_HISTSubmit : Sem give failed");
                }
            }
        }
        else
        {
            resultS = DDC_HIST_E_FAIL;
            DDC_DEBUG_PRINTF("DDC_HISTSubmit : Invalid parameter");
        }
    }
    else
    {
        resultS = DDC_HIST_E_FAIL;
        DDC_DEBUG_PRINTF("DDC_HISTSubmit : Invalid parameter");
    }

    return resultS;
}
