/*******************************************************************************
**+--------------------------------------------------------------------------+**
**|                            ****                                          |**
**|                            ****                                          |**
**|                            ******o***                                    |**
**|                      ********_///_****                                   |**
**|                      ***** /_//_/ ****                                   |**
**|                       ** ** (__/ ****                                    |**
**|                           *********                                      |**
**|                            ****                                          |**
**|                            ***                                           |**
**|                                                                          |**
**|         Copyright (c) 2006-2010 Texas Instruments Incorporated           |**
**|                        ALL RIGHTS RESERVED                               |**
**|                                                                          |**
**| Permission is hereby granted to licensees of Texas Instruments           |**
**| Incorporated (TI) products to use this computer program for the sole     |**
**| purpose of implementing a licensee product based on TI products.         |**
**| No other rights to reproduce, use, or disseminate this computer          |**
**| program, whether in part or in whole, are granted.                       |**
**|                                                                          |**
**| TI makes no representation or warranties with respect to the             |**
**| performance of this computer program, and specifically disclaims         |**
**| any responsibility for any damages, special or consequential,            |**
**| connected with the use of this program.                                  |**
**|                                                                          |**
**+--------------------------------------------------------------------------+**
*******************************************************************************/
/**
 * \file   llc_hist.c
 *
 * \brief  LLC layer source file
 *
 * This file contains the dependencies of LLC layer functions
 *
 * (C) Copyright 2010, Texas Instruments, Inc
 *
 * \author     EI5
 *
 * \version    0.1             Created
 *             1.0             First Release
 */

/******************************************************************************
  Header File Inclusion
 ******************************************************************************/
#include <ti/sdo/pspdrivers/soc/dm6437/dsp/cslr_hist.h>
#include <ti/sdo/pspdrivers/soc/dm6437/dsp/cslr.h>
#include <ti/sdo/pspdrivers/soc/dm6437/dsp/csl_error.h>
#include <ti/sdo/pspdrivers/drivers/histogram/psp_histogram.h>
#include <ti/sdo/pspdrivers/drivers/histogram/src/llc_hist.h>

/******************************************************************************
  Functions
 ******************************************************************************/
/**
 * \brief  LLC_HISTEnableHistogram
 *         This function sets the corresponding bit to enable Histogram module.
 */
Int LLC_HISTEnableHistogram(PSP_Handle regs)
{
    Int returnEH = CSL_SOK;
    CSL_HistRegsOvly regsOvlyEH;
    if (NULL != regs)
    {
        regsOvlyEH = (CSL_HistRegsOvly )regs;
        if (NULL != regsOvlyEH)
        {
            CSL_FINS(regsOvlyEH->PCR, HIST_PCR_ENABLE,
                CSL_HIST_PCR_ENABLE_ENABLE);
        }
        else
        {
            returnEH = CSL_ESYS_FAIL;
            LLC_DEBUG_PRINTF("LLC_HISTEnableHistogram : Invalid parameter");
        }
    }
    else
    {
        returnEH = CSL_ESYS_FAIL;
        LLC_DEBUG_PRINTF("LLC_HISTEnableHistogram : Invalid parameter");
    }
    return (returnEH);
}

/**
 * \brief   LLC_HISTDisableHistogram
 *          This function sets the corresponding bit to disable Histogram
 *          module.
 */
Int LLC_HISTDisableHistogram(PSP_Handle regs)
{
    Int returnDH = CSL_SOK;
    CSL_HistRegsOvly regsOvlyDH;
    if (NULL != regs)
    {
        regsOvlyDH = (CSL_HistRegsOvly )regs;
        if (NULL != regsOvlyDH)
        {
            CSL_FINS(regsOvlyDH->PCR, HIST_PCR_ENABLE,
                CSL_HIST_PCR_ENABLE_DISABLE);
        }
        else
        {
            returnDH = CSL_ESYS_FAIL;
            LLC_DEBUG_PRINTF("LLC_HISTDisableHistogram : Invalid parameter");
        }
    }
    else
    {
        returnDH = CSL_ESYS_FAIL;
        LLC_DEBUG_PRINTF("LLC_HISTDisableHistogram : Invalid parameter");
    }
    return (returnDH);
}

/**
 * \brief   LLC_HISTGetHWStatus
 *          This function returns the status of the histogram module.
 *          1 - busy
 *          0 - not busy
 */
Int LLC_HISTGetHWStatus(PSP_Handle regs)
{
    CSL_HistRegsOvly regsOvlyGS;
    Int returnGW;
    if (NULL != regs)
    {
        regsOvlyGS = (CSL_HistRegsOvly )regs;
        if (NULL != regsOvlyGS)
        {
            returnGW = CSL_FEXT(regsOvlyGS->PCR, HIST_PCR_BUSY);
        }
        else
        {
            returnGW = CSL_ESYS_FAIL;
            LLC_DEBUG_PRINTF("LLC_HISTGetHWStatus : Invalid parameter");
        }
    }
    else
    {
        returnGW = CSL_ESYS_FAIL;
        LLC_DEBUG_PRINTF("LLC_HISTGetHWStatus : Invalid parameter");
    }
    return (returnGW);
}

/**
 * \brief  LLC_HISTWritereg
 *         This function configures the Histogram module by writing parameter's
 *         value to the H/W registers.
 */
Int LLC_HISTWritereg(PSP_HISTparam * const param, PSP_Handle regs)
{
    CSL_HistRegsOvly regsOvlyW;
    Int returnW = CSL_SOK;
    Int i;

    if ((NULL != regs) && (NULL != param))
    {
        regsOvlyW = (CSL_HistRegsOvly )regs;
        if (NULL != regsOvlyW)
        {
            /* input data width. it will be 10 bits as input is CCDC only */
            CSL_FINS(regsOvlyW->HIST_CNT, HIST_HIST_CNT_DATSIZ,
                CSL_HIST_HIST_CNT_DATSIZ_9TO14_BITS);

            LLC_DEBUG_REG_PRINTF("Input data width",
                (CSL_FEXT(regsOvlyW->HIST_CNT, HIST_HIST_CNT_DATSIZ)) );

            /* clear content after read */
            CSL_FINS(regsOvlyW->HIST_CNT, HIST_HIST_CNT_CLR,
                (param->clearOpDataAfterRead));

            LLC_DEBUG_REG_PRINTF("Clear data after read",
                (CSL_FEXT(regsOvlyW->HIST_CNT, HIST_HIST_CNT_CLR)) );

            /* CFA pattern */
            CSL_FINS(regsOvlyW->HIST_CNT, HIST_HIST_CNT_CFA,
                CSL_HIST_HIST_CNT_CFA_2D_2X2_CONVENTIONAL);

            LLC_DEBUG_REG_PRINTF("CFA pattern",
                (CSL_FEXT(regsOvlyW->HIST_CNT, HIST_HIST_CNT_CFA)) );

            /* Bins per histogram */
            CSL_FINS(regsOvlyW->HIST_CNT, HIST_HIST_CNT_BINS,
                param->bins);

            LLC_DEBUG_REG_PRINTF("No of bins per Histogram",
                (CSL_FEXT(regsOvlyW->HIST_CNT, HIST_HIST_CNT_BINS)) );

            /* input source for histogram */
            CSL_FINS(regsOvlyW->HIST_CNT, HIST_HIST_CNT_SOURCE,
                CSL_HIST_HIST_CNT_SOURCE_CCDC);

            LLC_DEBUG_REG_PRINTF("Input source",
                (CSL_FEXT(regsOvlyW->HIST_CNT, HIST_HIST_CNT_SOURCE)) );

            /* shifting ammount for binning */
            CSL_FINS(regsOvlyW->HIST_CNT, HIST_HIST_CNT_SHIFT,
                param->shift);

            LLC_DEBUG_REG_PRINTF("No of bits to right shift for bins",
                (CSL_FEXT(regsOvlyW->HIST_CNT, HIST_HIST_CNT_SHIFT)) );

            /* white balance gain for color 0 */
            CSL_FINS(regsOvlyW->WB_GAIN, HIST_WB_GAIN_WG00, param->wbGain[0]);

            LLC_DEBUG_REG_PRINTF("WB Gain00",
                (CSL_FEXT(regsOvlyW->WB_GAIN, HIST_WB_GAIN_WG00)) );

            /* white balance gain for color 1 */
            CSL_FINS(regsOvlyW->WB_GAIN, HIST_WB_GAIN_WG01, param->wbGain[1]);

            LLC_DEBUG_REG_PRINTF("WB Gain01",
                (CSL_FEXT(regsOvlyW->WB_GAIN, HIST_WB_GAIN_WG01)) );

            /* white balance gain for color 2 */
            CSL_FINS(regsOvlyW->WB_GAIN, HIST_WB_GAIN_WG02, param->wbGain[2]);

            LLC_DEBUG_REG_PRINTF("WB Gain02",
                (CSL_FEXT(regsOvlyW->WB_GAIN, HIST_WB_GAIN_WG02)) );

            /* white balance gain for color 3 */
            CSL_FINS(regsOvlyW->WB_GAIN, HIST_WB_GAIN_WG03, param->wbGain[3]);

            LLC_DEBUG_REG_PRINTF("WB Gain03",
                (CSL_FEXT(regsOvlyW->WB_GAIN, HIST_WB_GAIN_WG03)) );

            /* region 0 boundries */
            CSL_FINS(regsOvlyW->R0_HORZ, HIST_R0_HORZ_HSTART,
                param->region[0].hStart);
            LLC_DEBUG_REG_PRINTF("Region0 Horizontal start position",
                (CSL_FEXT(regsOvlyW->R0_HORZ, HIST_R0_HORZ_HSTART)) );

            CSL_FINS(regsOvlyW->R0_HORZ, HIST_R0_HORZ_HEND,
                param->region[0].hEnd);
            LLC_DEBUG_REG_PRINTF("Region0 Horizontal end position",
                (CSL_FEXT(regsOvlyW->R0_HORZ, HIST_R0_HORZ_HEND)) );

            CSL_FINS(regsOvlyW->R0_VERT, HIST_R0_VERT_VSTART,
                param->region[0].vStart);
            LLC_DEBUG_REG_PRINTF("Region0 Vertical start position",
                (CSL_FEXT(regsOvlyW->R0_VERT, HIST_R0_VERT_VSTART)) );

            CSL_FINS(regsOvlyW->R0_VERT, HIST_R0_VERT_VEND,
                param->region[0].vEnd);
            LLC_DEBUG_REG_PRINTF("Region0 Vertical end position",
                (CSL_FEXT(regsOvlyW->R0_VERT, HIST_R0_VERT_VEND)) );

            if (param->bins < CSL_HIST_HIST_CNT_BINS_256BINS)
            {
                /* region 1 boundries */
                CSL_FINS(regsOvlyW->R1_HORZ, HIST_R1_HORZ_HSTART,
                    param->region[1].hStart);
                LLC_DEBUG_REG_PRINTF("Region1 Horizontal start position",
                    (CSL_FEXT(regsOvlyW->R1_HORZ, HIST_R1_HORZ_HSTART)) );

                CSL_FINS(regsOvlyW->R1_HORZ, HIST_R1_HORZ_HEND,
                    param->region[1].hEnd);
                LLC_DEBUG_REG_PRINTF("Region1 Horizontal end position",
                    (CSL_FEXT(regsOvlyW->R1_HORZ, HIST_R1_HORZ_HEND)) );

                CSL_FINS(regsOvlyW->R1_VERT, HIST_R1_VERT_VSTART,
                    param->region[1].vStart);
                LLC_DEBUG_REG_PRINTF("Region1 Vertical start position",
                    (CSL_FEXT(regsOvlyW->R1_VERT, HIST_R1_VERT_VSTART)) );

                CSL_FINS(regsOvlyW->R1_VERT, HIST_R1_VERT_VEND,
                    param->region[1].vEnd);
                LLC_DEBUG_REG_PRINTF("Region1 Vertical end position",
                    (CSL_FEXT(regsOvlyW->R1_VERT, HIST_R1_VERT_VEND)) );

                if (param->bins < CSL_HIST_HIST_CNT_BINS_128BINS)
                {
                    /* region 2 boundries */
                    CSL_FINS(regsOvlyW->R2_HORZ, HIST_R2_HORZ_HSTART,
                        param->region[2].hStart);
                    LLC_DEBUG_REG_PRINTF("Region2 Horizontal start position",
                        (CSL_FEXT(regsOvlyW->R2_HORZ, HIST_R2_HORZ_HSTART)) );

                    CSL_FINS(regsOvlyW->R2_HORZ, HIST_R2_HORZ_HEND,
                        param->region[2].hEnd);
                    LLC_DEBUG_REG_PRINTF("Region2 Horizontal end position",
                        (CSL_FEXT(regsOvlyW->R2_HORZ, HIST_R2_HORZ_HEND)) );

                    CSL_FINS(regsOvlyW->R2_VERT, HIST_R2_VERT_VSTART,
                        param->region[2].vStart);
                    LLC_DEBUG_REG_PRINTF("Region2 Vertical start position",
                        (CSL_FEXT(regsOvlyW->R2_VERT, HIST_R2_VERT_VSTART)) );

                    CSL_FINS(regsOvlyW->R2_VERT, HIST_R2_VERT_VEND,
                        param->region[2].vEnd);
                    LLC_DEBUG_REG_PRINTF("Region2 Vertical end position",
                        (CSL_FEXT(regsOvlyW->R2_VERT, HIST_R2_VERT_VEND)) );

                    /* region 3 boundries */
                    CSL_FINS(regsOvlyW->R3_HORZ, HIST_R3_HORZ_HSTART,
                        param->region[3].hStart);
                    LLC_DEBUG_REG_PRINTF("Region3 Horz start position",
                        (CSL_FEXT(regsOvlyW->R3_HORZ, HIST_R3_HORZ_HSTART)));

                    CSL_FINS(regsOvlyW->R3_HORZ, HIST_R3_HORZ_HEND,
                        param->region[3].hEnd);
                    LLC_DEBUG_REG_PRINTF("Region3 Horizontal end position",
                        (CSL_FEXT(regsOvlyW->R3_HORZ, HIST_R3_HORZ_HEND)) );

                    CSL_FINS(regsOvlyW->R3_VERT, HIST_R3_VERT_VSTART,
                        param->region[3].vStart);
                    LLC_DEBUG_REG_PRINTF("Region3 Vertical start position",
                        (CSL_FEXT(regsOvlyW->R3_VERT, HIST_R3_VERT_VSTART)) );

                    CSL_FINS(regsOvlyW->R3_VERT, HIST_R3_VERT_VEND,
                        param->region[3].vEnd);
                    LLC_DEBUG_REG_PRINTF("Region3 Vertical end position",
                        (CSL_FEXT(regsOvlyW->R3_VERT, HIST_R3_VERT_VEND)) );
                }
            }

            /* Histogram output memory address offset */
            CSL_FINS(regsOvlyW->HIST_ADDR, HIST_HIST_ADDR_ADDR,
                CSL_HIST_HIST_ADDR_RESETVAL);

            /* reset the data */
            for(i = 0; i < LLC_HIST_MEM_SIZE; i++)
            {
                CSL_FINS(regsOvlyW->HIST_DATA, HIST_HIST_DATA_RDATA,
                    CSL_HIST_HIST_DATA_RESETVAL);
            }

            /* Histogram output memory address offset */
            CSL_FINS(regsOvlyW->HIST_ADDR, HIST_HIST_ADDR_ADDR,
                CSL_HIST_HIST_ADDR_RESETVAL);
            LLC_DEBUG_REG_PRINTF("Histogram output memory address offset",
                (CSL_FEXT(regsOvlyW->HIST_ADDR, HIST_HIST_ADDR_ADDR)) );

        }
        else
        {
            returnW = CSL_ESYS_FAIL;
            LLC_DEBUG_PRINTF("LLC_HISTWritereg : Invalid parameter");
        }
    }
    else
    {
        returnW = CSL_ESYS_FAIL;
        LLC_DEBUG_PRINTF("LLC_HISTWritereg : Invalid parameter");
    }
    return (returnW);
}

/**
 * \brief   LLC_HISTGetHistDataAdrs
 *          This function returns the address of the HIST_DATA register.
 */
Uint32 LLC_HISTGetHistDataAdrs(PSP_Handle regs)
{
    CSL_HistRegsOvly regsOvlyHD;
    Uint32 histDataAdrsHD = NULL;
    if (NULL != regs)
    {
        regsOvlyHD = (CSL_HistRegsOvly )regs;
        if (NULL != regsOvlyHD)
        {
            histDataAdrsHD = (Uint32)(&(regsOvlyHD->HIST_DATA));
        }
    }
    return (histDataAdrsHD);
}

