/*******************************************************************************
**+--------------------------------------------------------------------------+**
**|                            ****                                          |**
**|                            ****                                          |**
**|                            ******o***                                    |**
**|                      ********_///_****                                   |**
**|                      ***** /_//_/ ****                                   |**
**|                       ** ** (__/ ****                                    |**
**|                           *********                                      |**
**|                            ****                                          |**
**|                            ***                                           |**
**|                                                                          |**
**|         Copyright (c) 2006-2010 Texas Instruments Incorporated           |**
**|                        ALL RIGHTS RESERVED                               |**
**|                                                                          |**
**| Permission is hereby granted to licensees of Texas Instruments           |**
**| Incorporated (TI) products to use this computer program for the sole     |**
**| purpose of implementing a licensee product based on TI products.         |**
**| No other rights to reproduce, use, or disseminate this computer          |**
**| program, whether in part or in whole, are granted.                       |**
**|                                                                          |**
**| TI makes no representation or warranties with respect to the             |**
**| performance of this computer program, and specifically disclaims         |**
**| any responsibility for any damages, special or consequential,            |**
**| connected with the use of this program.                                  |**
**|                                                                          |**
**+--------------------------------------------------------------------------+**
*******************************************************************************/
/**
 * \file   llc_hist.h
 *
 * \brief  LLC layer header file for Histogram
 *
 * This file contains the decleration of LLC layer functions
 *
 * (C) Copyright 2010, Texas Instruments, Inc
 *
 * \author     EI5
 *
 * \version    0.1             Created
 *             1.0             First Release
 */

#ifndef _LLC_HIST_H
#define _LLC_HIST_H

/******************************************************************************
  Header File Inclusion
 ******************************************************************************/
#ifdef DEBUG_HIST
#include <ti/sdo/pspdrivers/pal_os/bios/psputils.h>
#endif

#ifdef __cplusplus
extern "C" {
#endif

/******************************************************************************
  Defines
 ******************************************************************************/
#define LLC_HIST_MEM_SIZE   1024

#ifdef DEBUG_HIST
#define LLC_DEBUG_PRINTF(STR) PSP_DEBUG1("LLC : %s\n", (STR))
#define LLC_DEBUG_REG_PRINTF(STR, VAL) PSP_DEBUG2("%s : %d\n", (STR), (VAL))
#else
#define LLC_DEBUG_PRINTF(STR)
#define LLC_DEBUG_REG_PRINTF(STR, VAL)
#endif

/******************************************************************************
  Functions
 ******************************************************************************/
/**
 * \brief  LLC_HISTEnableHistogram
 *         This function sets the corresponding bit to enable Histogram module.
 *
 * \param  regs        [IN]    Handle to register overlaying structure
 *
 * \return Succes/Error code.
 */
Int LLC_HISTEnableHistogram(PSP_Handle regs);

/**
 * \brief  LLC_HISTDisableHistogram
 *         This function sets the corresponding bit to disable Histogram
 *         module.
 * \param  regs        [IN]    Handle to register overlaying structure
 *
 * \return Succes/Error code.
 */
Int LLC_HISTDisableHistogram(PSP_Handle regs);

/**
 * \brief   LLC_HISTGetHWStatus
 *          This function returns the status of the histogram module.
 *
 * \param   regs        [IN]    Handle to register overlaying structure
 *
 * \return  1 - busy
 *          0 - not busy
 *          or Error code.
 */
Int LLC_HISTGetHWStatus(PSP_Handle regs);

/**
 * \brief  LLC_HISTWritereg
 *         This function configures the Histogram module by writing parameter's
 *         value to the H/W registers.
 *
 * \param  param       [IN]    Pointer to parameter configuration
 *                             structure
 * \param  regs        [IN]    Handle to register overlaying structure
 *
 * \return Succes/Error code.
 */
Int LLC_HISTWritereg(PSP_HISTparam *param, PSP_Handle regs);

/**
 * \brief   LLC_HISTGetHistDataAdrs
 *          This function returns the address of the HIST_DATA register.
 *
 * \param  regs        [IN]    Handle to register overlaying structure
 *
 * \return returns the address of HIST_DATA register.
 */
Uint32 LLC_HISTGetHistDataAdrs(PSP_Handle regs);

#ifdef __cplusplus
}
#endif

#endif /*_LLC_HIST_H */

