/*******************************************************************************
**+--------------------------------------------------------------------------+**
**|                            ****                                          |**
**|                            ****                                          |**
**|                            ******o***                                    |**
**|                      ********_///_****                                   |**
**|                      ***** /_//_/ ****                                   |**
**|                       ** ** (__/ ****                                    |**
**|                           *********                                      |**
**|                            ****                                          |**
**|                            ***                                           |**
**|                                                                          |**
**|         Copyright (c) 2006-2010 Texas Instruments Incorporated           |**
**|                        ALL RIGHTS RESERVED                               |**
**|                                                                          |**
**| Permission is hereby granted to licensees of Texas Instruments           |**
**| Incorporated (TI) products to use this computer program for the sole     |**
**| purpose of implementing a licensee product based on TI products.         |**
**| No other rights to reproduce, use, or disseminate this computer          |**
**| program, whether in part or in whole, are granted.                       |**
**|                                                                          |**
**| TI makes no representation or warranties with respect to the             |**
**| performance of this computer program, and specifically disclaims         |**
**| any responsibility for any damages, special or consequential,            |**
**| connected with the use of this program.                                  |**
**|                                                                          |**
**+--------------------------------------------------------------------------+**
*******************************************************************************/
/**
 * \file   psp_histApi.h
 *
 * \brief  File contains defination of API used by DDA layer
 *
 * This file contains defination of APIs that are wrapper APIs for DDC layer.
 * These APIs will be called by DDA layer.
 *
 * (C) Copyright 2010, Texas Instruments, Inc
 *
 * \author     EI5
 *
 * \version    0.1             Created
 *             1.0             First Release
 */

#ifndef _PSP_HISTAPI_H
#define _PSP_HISTAPI_H

#ifdef __cplusplus
extern "C" {
#endif

/******************************************************************************
  Functions
 ******************************************************************************/
/**
 * \brief    PSP_HISTCreate
 *           This function calls DDC layer function to create the device
 *           instance.
 *
 * \param    instanceId  [IN]    device instance number
 *
 * \returns  Returns     Device handle.
 *
 */
PSP_Handle  PSP_HISTCreate(Uint32 instanceId);

/**
 * \brief    PSP_HISTDelete
 *           This function calls DDC layer function to remove the device
 *           instance.
 *
 * \param    instanceId  [IN]    device instance number
 *
 * \returns  Returns     SUCCESS/ERROR code.
 */
PSP_Result PSP_HISTDelete(Uint32 instanceId);

/**
 * \brief    PSP_HISTOpen
 *           This function calls DDC layer function to open the channel handle.
 *
 * \param    edmaHandleDDA   [IN]    Handle to EDMA device
 *
 * \returns  Returns         Channel handle for Histogram module
 */
PSP_Handle  PSP_HISTOpen(PSP_Handle edmaHandleDDA);

/**
 * \brief   PSP_HISTClose
 *          This function calls DDC layer function to close the channel handle.
 *
 * \param   handle      [IN]    Device Handle
 *
 * \returns Returns     SUCCESS/ERROR code
 */
PSP_Result PSP_HISTClose(PSP_Handle handle);

/**
 * \brief    PSP_HISTIoctl
 *           This function calls DDC layer function to perform I/O Control
 *           operation.
 *
 * \param    handle      [IN]    Channel handle for Histogram module
 *
 * \param    cmd         [IN]    IOCTL command
 *
 * \param    cmdArg      [IN]    Command Arguments to be passed.
 *
 * \Returns  Returns     SUCCESS/ERROR code
 */
PSP_Result  PSP_HISTIoctl( PSP_Handle handle, PSP_HISTIoctlCmd cmd,
    Ptr cmdArg );

/**
 * \brief    PSP_HISTSubmit
 *           This function calls DDC layer function to perform submit command
 *           operation.
 *
 * \param    handle      [IN]    Channel handle for Histogram module
 *
 * \param    cmd         [IN]    EnQueue/DeQueue command
 *
 * \param    cmdArg      [IN]    Command Arguments to be passed.
 *
 * \Returns  Returns     SUCCESS/ERROR code
 */
PSP_Result PSP_HISTSubmit(PSP_Handle chnlHandle, PSP_VPSSSubmitCommand cmd,
    Ptr cmdArg );

#ifdef __cplusplus
}
#endif

#endif /*_PSP_HISTAPI_H*/
