/******************************************************************************
**+-------------------------------------------------------------------------+**
**|                            ****                                         |**
**|                            ****                                         |**
**|                            ******o***                                   |**
**|                      ********_///_****                                  |**
**|                      ***** /_//_/ ****                                  |**
**|                       ** ** (__/ ****                                   |**
**|                           *********                                     |**
**|                            ****                                         |**
**|                            ***                                          |**
**|                                                                         |**
**|         Copyright (c) 1998-2006 Texas Instruments Incorporated          |**
**|                        ALL RIGHTS RESERVED                              |**
**|                                                                         |**
**| Permission is hereby granted to licensees of Texas Instruments          |**
**| Incorporated (TI) products to use this computer program for the sole    |**
**| purpose of implementing a licensee product based on TI products.        |**
**| No other rights to reproduce, use, or disseminate this computer         |**
**| program, whether in part or in whole, are granted.                      |**
**|                                                                         |**
**| TI makes no representation or warranties with respect to the            |**
**| performance of this computer program, and specifically disclaims        |**
**| any responsibility for any damages, special or consequential,           |**
**| connected with the use of this program.                                 |**
**|                                                                         |**
**+-------------------------------------------------------------------------+**
******************************************************************************/
/*!
    @{

*/
/*!
 *  \file   dda_i2cBios.h
 *
 *  \brief  I2C BIOS layer definition
 *
 *  This file contains the interfaces, data types and symbolic definitions
 *  that are needed by the application to utilize the serivces of the I2C
 *  device driver.
 *
 *  (C) Copyright 2006, Texas Instruments, Inc
 *
 *  \author     PSG
 *
 *  \version    0.3
 */
#ifndef _DDA_I2CIOM_H
#define _DDA_I2CIOM_H

/* Header File Included */
#include <std.h>
#include <iom.h>

#include <ti/sdo/pspdrivers/common/psp_common.h>
#include <ti/sdo/pspdrivers/drivers/i2c/psp_i2c.h>
#include <ti/sdo/pspdrivers/drivers/i2c/src/psp_i2cApi.h>
#include <ti/sdo/pspdrivers/drivers/i2c/src/ddc_i2c.h>

#ifdef __cplusplus
extern "C" {
#endif

/** Number of channels allowed per I2C                   */
#define IOM_I2C_NUMCHANS        PSP_I2C_NUM_OPENS
/** Number of i2c instances supported on the board       */
#define IOM_I2C_NUMPORTS        PSP_I2C_NUM_INSTANCES


/* Driver function table to be used by applications     */
extern IOM_Fxns I2CMD_FXNS;

/*!
 *  \brief  channel structure
 *
 */
typedef struct I2cChanObj_t
{
    Uns                     mode;           /**<  INPUT or OUTPUT or INOUT    */
    struct I2cPortObj_t     *port;          /**<  Handle for I2C ports        */
    IOM_TiomCallback        cbFxn;          /**<  Callback Function for GIO   */
    Ptr                     cbArg;          /**<  argument for cbFxn()        */
    PSP_Handle              ddc_Handle;     /**<  DDC layer i2c Handle        */
} I2cChanObj , *I2cChanHandle;

/*!
 *  \brief  port structure
 *
 *  There is one I2cPortObj per I2C.
 *
 */
typedef struct I2cPortObj_t
{
    Uns               i2cPortNumber;            /**<  Instance number for back
                                                      reference               */
    I2cChanObj        chans[IOM_I2C_NUMCHANS];  /**<  channels for the I2C    */
    DDC_I2CState      i2cState;                 /**<  state of the I2C        */
} I2cPortObj, *I2cPortHandle;

/*!
 *  \brief  global port structure
 *
 */
extern I2cPortObj  ports[IOM_I2C_NUMPORTS];

/* These set of functions are implemented in DDA and are called by the DDC */

/*!
 *  ======== _DDA_i2cRegisterIntrHandler ========
 *  \brief  Register interrrupt with BIOS and enable it
 *
 *  \param  instNum     Instanse number
 *  \param  intNum      Interrupt number
 *  \param  isrFunc     Function Pointer to ISR function
 *  \param  i2cObj      Handle to be passed to ISR function
 *
 *  \return void
 */
void DDA_i2cRegisterIntrHandler(Uint32     instNum,
                                 Uint32     intNum,
                                 pspI2cIsr   isrFunc,
                                 PSP_Handle i2cObj);

/*!
 * Function used to un-register the interrupt handler
 *
 *  \param  instNum [IN]        i2cInstance number
 *  \param  intNum  [IN]        Interrupt Number
 */
void DDA_i2cUnregisterIntrHandler(Uint32 instNum, Uint32 intNum);


#ifdef __cplusplus
}
#endif /* extern "C" */

#endif /* I2CMD_ */

/*!
 * Revision History
 * ================
 *  \version    0.1     created                          Nagarjuna Kristam
 *  \version    0.2     cleanup effort                   Nagarjuna Kristam
 *  \version    0.3     Implementing review commnets     Nagarjuna Kristam
 *  \version    0.4     cleaning up the code             Nagarjuna Kristam
 */

