/******************************************************************************
**+-------------------------------------------------------------------------+**
**|                            ****                                         |**
**|                            ****                                         |**
**|                            ******o***                                   |**
**|                      ********_///_****                                  |**
**|                      ***** /_//_/ ****                                  |**
**|                       ** ** (__/ ****                                   |**
**|                           *********                                     |**
**|                            ****                                         |**
**|                            ***                                          |**
**|                                                                         |**
**|         Copyright (c) 1998-2006 Texas Instruments Incorporated          |**
**|                        ALL RIGHTS RESERVED                              |**
**|                                                                         |**
**| Permission is hereby granted to licensees of Texas Instruments          |**
**| Incorporated (TI) products to use this computer program for the sole    |**
**| purpose of implementing a licensee product based on TI products.        |**
**| No other rights to reproduce, use, or disseminate this computer         |**
**| program, whether in part or in whole, are granted.                      |**
**|                                                                         |**
**| TI makes no representation or warranties with respect to the            |**
**| performance of this computer program, and specifically disclaims        |**
**| any responsibility for any damages, special or consequential,           |**
**| connected with the use of this program.                                 |**
**|                                                                         |**
**+-------------------------------------------------------------------------+**
******************************************************************************/

/** \file     dda_mcasp_bios.h
 *
 *  \brief    Header file for McASP mini-driver
 *
 *  This file has the globally visible data structures and definitions
 *  for the McASP mini-driver.
 *
 *  (C) Copyright 2006, Texas Instruments, Inc
 *
 *  \author Platform Support Group
 *
 *  \Revision
 *          0.1  Created  Khanapuri / vichu
 *          0.2  Created  Khanapuri / vichu : Dynamic mode start/stop implemented
 */

#ifndef _DDA_MCASP_BIOS_H
#define _DDA_MCASP_BIOS_H




#ifdef __cplusplus
extern "C" {
#endif


/*
 * DSP/BIOS header
 */
#include <iom.h>

/*
DDC Layer
*/

#include <ti/sdo/pspdrivers/drivers/mcasp/psp_mcasp.h>
/*
 * CSL headers
 */

struct McASPPortObj_t;

/*
 * Channel function definitions
 */

/**
 * \brief Channel Object
 *
 * This structure maintains the current channel state. It also holds
 * information on DMA channel being used and holds the application
 * callback function to be called in case of an interrupt.
 *
 * This structure is initialized by mdCreateChan and a pointer to this
 * is passed down to all other channel related functions. Lifetime of
 * the data structure is from its creation by mdCreateChan till it
 * is invalidated by mdDeleteChan.
 */

typedef struct McASPChannelObj_t
{
    PSP_McaspChannelStatus      status;
    /**< Keeps tab of whether channel is already in use
     *  - takes value of UNALLOCATED or ALLOCATED          */

    Uint16                      mode;
    /**< mode for channel                                 */

    Uint16                       inUse;
    /**< mode for cache                                     */

    PSP_mcaspMode           channelOpMode;
    /**< Mode of operation: Transmit or Receive             */

    struct McASPPortObj_t        *portHandle;
    /**< Pointer to McASP device
     *  - Back pointer to device configuration structure   */

    PSP_Handle                  ioHandle;       
    /**< ddc channel Handle */

    IOM_Packet                  *dataPacket;
    /**<  current active I/O packet          */

    IOM_TiomCallback            cbFxn;
    /**<  Notify client when I/O complete    */

    Ptr                         cbArg;
    /**< Callback Function                                              */

} McASPChannelObj, *McASPChannelHandle;



/**
  * Default Initialization of channel object
  */

#define CHANOBJINIT { \
    /* .status              = */    PSP_MCASP_UNALLOCATED,        \
    /* .mode                = */    NULL,                         \
    /* .inUse               = */    FALSE,                         \
    /* .channelMode         = */    PSP_MCASP_RX,          \
    /* ._PortObj            = */    NULL,                         \
    /* .DDC_mcaspChanHandle = */    NULL,\
    /* .datapacket          = */    NULL,\
    /* .cbFxn               = */    NULL,\
    /* .cbArg               = */    NULL\
}

/**
 * \brief Port Object
 *
 * This data structure holds the current device state. It also
 * holds the handle to the McASP. The data structure is
 * initialized during mcasp_mdBindDev, which is called during DSP-
 * BIOS initialization, and is persistent till it is
 * invalidated by mcasp_mdUnBindDev.
 */
typedef struct McASPPortObj_t
{
    Bool                        inUse;
    /**< Marks if port is currently in use                 */

    Uint16                      instNum;
    /**< Preserve  instance number in port                 */

    Bool                        isDataBufferPayloadStructure;
    /**< Input request is a flat data buffer or a 
     *   payload structure                                 */

    McASPChannelObj             XmtObj; 
    /**< Holds transmit channel to the McASP.              */

    McASPChannelObj             RcvObj;
    /**< Holds receive channel to the McASP.               */
        
}McASPPortObj , *McASPPortHandle;


/**
  * Default Initialization of port object
  */
#define PORTOBJINIT { \
    /* .inUse     = */          FALSE,\
    /* .InstNum = */            0,\
    /* .isDataBufferPayloadStructure = */ FALSE,                  \
    /* .RcvObj,XmtObj= */      CHANOBJINIT,\
                               CHANOBJINIT\
}




/**
 *  \brief _DDA_McASP_RegisterInt
 *
 *
 *  \brief   register interrupt handler for channel mode
 *
 *  \param    chanp        [IN]    Pointer to channel
 *  \param    instNum      [IN]    instance number
 *  \param    evt          [IN]    interrupt number
 *  \param    mode         [IN]    input or output
 *
 *  \return  void
 */
PSP_Result _DDA_McASP_RegisterInt(Ptr chanp, Uint32 instNum, Uint16 evt, pspMcaspIsr intIsr);



/**
 *  \brief _DDA_McASP_UnRegisterInt
 *
 *
 *  \brief   unregister interrupt handler for channel mode
 *
 *  \param    chanp        [IN]    Pointer to channel
 *  \param    devid        [IN]    instance number
 *  \param    evt          [IN]    interrupt number
 *  \param    mode         [IN]    input or output
 *
 *  \return  void
 */
PSP_Result _DDA_McASP_UnRegisterInt (Uint16 devid, Uint16 evt,Int mode);





#ifdef __cplusplus
}
#endif /* extern "C" */


#endif /*_DDA_MCASP_BIOS_H*/

