/******************************************************************************
**+-------------------------------------------------------------------------+**
**|                            ****                                         |**
**|                            ****                                         |**
**|                            ******o***                                   |**
**|                      ********_///_****                                  |**
**|                      ***** /_//_/ ****                                  |**
**|                       ** ** (__/ ****                                   |**
**|                           *********                                     |**
**|                            ****                                         |**
**|                            ***                                          |**
**|                                                                         |**
**|         Copyright (c) 1998-2006 Texas Instruments Incorporated          |**
**|                        ALL RIGHTS RESERVED                              |**
**|                                                                         |**
**| Permission is hereby granted to licensees of Texas Instruments          |**
**| Incorporated (TI) products to use this computer program for the sole    |**
**| purpose of implementing a licensee product based on TI products.        |**
**| No other rights to reproduce, use, or disseminate this computer         |**
**| program, whether in part or in whole, are granted.                      |**
**|                                                                         |**
**| TI makes no representation or warranties with respect to the            |**
**| performance of this computer program, and specifically disclaims        |**
**| any responsibility for any damages, special or consequential,           |**
**| connected with the use of this program.                                 |**
**|                                                                         |**
**+-------------------------------------------------------------------------+**
******************************************************************************/
/** ===========================================================================
 *   @file  llc_mcasp.h
 *
 *   @path  $(CSLPATH)\mcasp\src
 *
 *   @desc  API header file for multi channel audio serial port CSL
 *
 *  Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005, 2006
 *
 *  Use of this software is controlled by the terms and conditions found in the
 *  license agreement under which this software has been supplied.
 *
 *  03-May-2006 File Created.
 * ============================================================================
 */

#ifndef _LLC_MCASP_H_
#define _LLC_MCASP_H_

#ifdef __cplusplus
extern "C" {
#endif

#ifdef CHIP_DM648
#include <ti/sdo/pspdrivers/soc/dm648/dsp/soc.h>
#include <ti/sdo/pspdrivers/soc/dm648/dsp/cslr_mcasp.h>
#include <ti/sdo/pspdrivers/soc/dm648/dsp/tistdtypes.h>
#endif

#ifdef CHIP_DM6437
#include <ti/sdo/pspdrivers/soc/dm6437/dsp/soc.h>
#include <ti/sdo/pspdrivers/soc/dm6437/dsp/cslr_mcasp.h>
#include <ti/sdo/pspdrivers/soc/dm6437/dsp/tistdtypes.h>
#endif

#ifdef CHIP_C6424
#include <ti/sdo/pspdrivers/soc/c6424/dsp/soc.h>
#include <ti/sdo/pspdrivers/soc/c6424/dsp/cslr_mcasp.h>
#include <ti/sdo/pspdrivers/soc/c6424/dsp/tistdtypes.h>
#endif


#ifdef CHIP_C6452
#include <ti/sdo/pspdrivers/soc/c6452/dsp/soc.h>
#include <ti/sdo/pspdrivers/soc/c6452/dsp/cslr_mcasp.h>
#include <ti/sdo/pspdrivers/soc/c6452/dsp/tistdtypes.h>
#endif

#include <ti/sdo/pspdrivers/common/psp_common.h>
#include <ti/sdo/pspdrivers/drivers/mcasp/psp_mcasp.h>
#include <ti/sdo/edma3/drv/edma3_drv.h>



/** The Mcasp0 has eight serializers */
#define PSP_MCASP0_NUM_SERS                (8u)

/** @brief Base address of MCASP0 peripheral registers */
#define MCASP0_CNTRL_ADDR               (CSL_MCASP_0_REGS)
#define MCASP0_DATA_ADDR                (CSL_MCASP_TXBUF_ADDR)
/** Edma channel event numbers for Mcasp */
#define MCASP0TXEVT                     (CSL_EDMA3_CHA_AXEVT0)
#define MCASP0RXEVT                     (CSL_EDMA3_CHA_AREVT0)

/** @brief Peripheral Instances of MCASP*/
#define    LLC_MCASP1                   (0)   /** Instance 1 of McASP */


/**
 *  Enumeration for DIT channel index
 */
typedef enum {
    /* 1st DIT (channel/user data), (left/right) Register */
    DIT_REGISTER_0 = 0,
    /* 2nd DIT (channel/user data), (left/right) Register */
    DIT_REGISTER_1 = 1,
    /* 3rd DIT (channel/user data), (left/right) Register */
    DIT_REGISTER_2 = 2,
    /* 4th DIT (channel/user data), (left/right) Register */
    DIT_REGISTER_3 = 3,
    /* 5th DIT (channel/user data), (left/right) Register */
    DIT_REGISTER_4 = 4,
    /* 6th DIT (channel/user data), (left/right) Register */
    DIT_REGISTER_5 = 5
} LLC_McaspDITRegIndex;

/** Enumeration for the serializer mode */
typedef enum {
    SERIALIZER_INACTIVE = 0,
    /**< Serializer is inactive */
    SERIALIZER_XMT = 1,
    /**< Serializer is transmitter */
    SERIALIZER_RCV = 2
    /**< Serializer is receiver */
} LLC_McaspSerMode;


/**
 *  Enumeration for hardware control commands
 */
typedef enum {
    /**
     * @brief   Configure transmitter global control register  with parameters
     *          passed
     * @param   (Uint32 *)
     */
    LLC_MCASP_CMD_SET_XMT               = 1,

    /**
     * @brief   Configure receiver global control register  with parameters
     *          passed
     * @param   (Uint32 *)
     */
    LLC_MCASP_CMD_SET_RCV               = 2,

    /**
     * @brief   Reset transmit frame sync generator
     * @param   (None)
     */
    LLC_MCASP_CMD_RESET_FSYNC_XMT       = 3,

    /**
     * @brief   Reset receive frame sync generator
     * @param   (None)
     */
    LLC_MCASP_CMD_RESET_FSYNC_RCV       = 4,

    /**
     * @brief   Reset all registers
     * @param   (None)
     */
    LLC_MCASP_CMD_REG_RESET             = 5,

    /**
     * @brief   Mute enable
     * @param   (Uint32 *)
     */
    LLC_MCASP_CMD_AMUTE_CNTRL           = 6,

    /**
     * @brief   Enable digital loopback mode
     * @param   (Uint32 *)
     */
    LLC_MCASP_CMD_DLB_ON                = 7,

    /**
     * @brief   Configures receive slots
     * @param   (Uint32 *)
     */
    LLC_MCASP_CMD_CONFIG_RTDM_SLOT      = 8,

    /**
     * @brief   Configures transmit slots
     * @param   (Uint32 *)
     */
    LLC_MCASP_CMD_CONFIG_XTDM_SLOT      = 9,

    /**
     * @brief   Configures the interrupts on the receive side
     * @param   (Uint32 *)
     */
    LLC_MCASP_CMD_CONFIG_INTERRUPT_RCV  = 10,

    /**
     * @brief   Configures the interrupts on the transmit side
     * @param   (Uint32 *)
     */
    LLC_MCASP_CMD_CONFIG_INTERRUPT_XMT  = 11,

    /**
     * @brief   Reset clock circuitry for receive
     * @param   (None)
     */
    LLC_MCASP_CMD_CLK_RESET_RCV         = 12,

    /**
     * @brief   Reset clock circuitry for transmit
     * @param   (None)
     */
    LLC_MCASP_CMD_CLK_RESET_XMT         = 13,

    /**
     * @brief   Set receive clock registers with value
     *          (PSP_McaspHwSetupDataClk*) passed
     * @param   (PSP_McaspHwSetupDataClk *)
     */
    LLC_MCASP_CMD_CLK_SET_RCV           = 14,

    /**
     * @brief   Set transmit clock registers with value
     *          (PSP_McaspHwSetupDataClk*) passed
     * @param   (PSP_McaspHwSetupDataClk *)
     */
    LLC_MCASP_CMD_CLK_SET_XMT           = 15,

    /**
     * @brief   Configure the format, frame sync, and other parameters related
     *          to the transmit section
     * @param   (PSP_McaspHwSetupData *)
     */
    LLC_MCASP_CMD_CONFIG_XMT_SECTION    = 16,

    /**
     * @brief   Configure the format, frame sync, and other parameters related
     *          to the receive section
     * @param   (PSP_McaspHwSetupData *)
     */
    LLC_MCASP_CMD_CONFIG_RCV_SECTION    = 17,

    /**
     * @brief   Sets a particular serializer to act as transmitter
     * @param   (LLC_McaspSerializerNum *)
     */
    LLC_MCASP_CMD_SET_SER_XMT           = 18,

    /**
     * @brief   Sets a particular serializer to act as receiver
     * @param   (LLC_McaspSerializerNum *)
     */
    LLC_MCASP_CMD_SET_SER_RCV           = 19,

    /**
     * @brief   Sets a particular serializer as inactivated
     * @param   (LLC_McaspSerializerNum *)
     */
    LLC_MCASP_CMD_SET_SER_INA           = 20,

    /**
     * @brief   Writes to the channel status RAM
     * @param   (PSP_McaspChStatusRam *)
     */
    LLC_MCASP_CMD_WRITE_CHAN_STAT_RAM   = 21,

    /**
     * @brief   Writes to the user data RAM
     * @param   (PSP_McaspUserDataRam *)
     */
    LLC_MCASP_CMD_WRITE_USER_DATA_RAM   = 22,

    /**
     * @brief   Resets the bits related to transmit in transmitter global
     *          control register
     * @param   (None)
     */
    LLC_MCASP_CMD_RESET_XMT             = 23,

    /**
     * @brief   Resets the bits related to receive in transmitter global
     *          control register
     * @param   (None)
     */
    LLC_MCASP_CMD_RESET_RCV             = 24,

    /**
     * @brief   Resets transmit frame sync generator and transmit state
     *          machine in transmitter global control register
     * @param   (None)
     */
    LLC_MCASP_CMD_RESET_SM_FS_XMT       = 25,

    /**
     * @brief   Resets receive frame sync generator and receive state
     *          machine in receiver global control register
     * @param   (None)
     */
    LLC_MCASP_CMD_RESET_SM_FS_RCV       = 26,

    /**
     * @brief   Sets the bits related to transmit in transmitter global
     *          control register
     * @param   (None)
     */
    LLC_MCASP_CMD_ACTIVATE_XMT_CLK_SER  = 27,

    /**
     * @brief   Sets the bits related to receive in receiver global control
     *          register
     * @param   (None)
     */
    LLC_MCASP_CMD_ACTIVATE_RCV_CLK_SER  = 28,

    /**
     * @brief   Activates receive and transmit state
     *          machine in global control register
     * @param   (None)
     */
    LLC_MCASP_CMD_ACTIVATE_SM_RCV_XMT   = 29,

    /**
     * @brief   Activates receive and transmit frame sync
     *          generator in global control register
     * @param   (None)
     */
    LLC_MCASP_CMD_ACTIVATE_FS_RCV_XMT   = 30,

    /**
     * @brief   Enables/disables the DIT mode
     * @param   (Bool *)
     */
    LLC_MCASP_CMD_SET_DIT_MODE          = 31,
    /**
     * @brief   Enables the clocks
     * @param   (Bool *)
     */
    LLC_MCASP_CMD_ACTIVATE_CLK_RCV_XMT  = 32

} LLC_McaspHwControlCmd;

/**
 *  Enumeration for hardware status query commands
 */
typedef enum {
    /**
     * @brief   Return current transmit slot being transmitted
     * @param   (Uint16 *)
     */
    LLC_MCASP_QUERY_CURRENT_XSLOT   = 1,

    /**
     * @brief   Return current receive slot being received
     * @param   (Uint16 *)
     */
    LLC_MCASP_QUERY_CURRENT_RSLOT   = 2,

    /**
     * @brief   Return transmit error status bit
     * @param   (Bool *)
     */
    LLC_MCASP_QUERY_XSTAT_XERR      = 3,

    /**
     * @brief   Return transmit clock failure flag status
     * @param   (Bool *)
     */
    LLC_MCASP_QUERY_XSTAT_XCLKFAIL  = 4,

    /**
     * @brief   Return unexpected transmit frame sync flag status
     * @param   (Bool *)
     */
    LLC_MCASP_QUERY_XSTAT_XSYNCERR  = 5,

    /**
     * @brief   Return transmit underrun flag status
     * @param   (Bool *)
     */
    LLC_MCASP_QUERY_XSTAT_XUNDRN    = 6,

    /**
     * @brief   Return transmit data ready flag status
     * @param   (Bool *)
     */
    LLC_MCASP_QUERY_XSTAT_XDATA     = 7,

    /**
     * @brief   Return receive error status bit
     * @param   (Bool *)
     */
    LLC_MCASP_QUERY_RSTAT_RERR      = 8,

    /**
     * @brief   Return receive clock failure flag status
     * @param   (Bool *)
     */
    LLC_MCASP_QUERY_RSTAT_RCLKFAIL  = 9,

    /**
     * @brief   Return unexpected receive frame sync flag status
     * @param   (Bool *)
     */
    LLC_MCASP_QUERY_RSTAT_RSYNCERR  = 10,

    /**
     * @brief   Return receive overrun flag status
     * @param   (Bool *)
     */
    LLC_MCASP_QUERY_RSTAT_ROVRN     = 11,

    /**
     * @brief   Return receive data ready flag status
     * @param   (Bool *)
     */
    LLC_MCASP_QUERY_RSTAT_RDATA     = 12,

    /**
     * @brief   Return status whether the serializer is ready to receive or not
     * @param   (LLC_McaspSerQuery *)
     */
    LLC_MCASP_QUERY_SRCTL_RRDY      = 13,

    /**
     * @brief   Return status whether the serializer is ready to transmit
     *          or not
     * @param   (LLC_McaspSerQuery *)
     */
    LLC_MCASP_QUERY_SRCTL_XRDY      = 14,

    /**
     * @brief   Return status whether serializer is configured to
     *          transmit/receive/inactive
     * @param   (LLC_McaspSerQuery *)
     */
    LLC_MCASP_QUERY_SRCTL_SRMOD     = 15,

    /**
     * @brief   Return the value of transmitter status register.
     * @param   (Uint16 *)
     */
    LLC_MCASP_QUERY_XSTAT           = 16,

    /**
     * @brief   Return the value of receiver status register.
     * @param   (Uint16 *)
     */
    LLC_MCASP_QUERY_RSTAT           = 17,

    /**
     * @brief   Return the transmit state machine and transmit frame sync
     *          generator values in transmitter global control register
     * @param   (Uint8 *)
     * @li          0x00 - Both transmit frame generator sync and transmit
     *                     state machine are reset.
     * @li          0x1  - Only transmit state machine is active.
     * @li          0x10 - Only transmit frame sync generator is active.
     * @li          0x11 - Both transmit frame generator sync and transmit
     *                     state machine are active.
     */
    LLC_MCASP_QUERY_SM_FS_XMT       = 18,

    /**
     * @brief   Return the receive state machine and receive frame sync
     *          generator values in receiver global control register
     * @param   (Uint8 *)
     * @li          0x00 - Both receive frame generator sync and receive state
     *                     machine are reset.
     * @li          0x1  - Only receive state machine is active.
     * @li          0x10 - Only receive frame sync generator is active.
     * @li          0x11 - Both receive frame generator sync and receive state
     *                     machine are active.
     */
    LLC_MCASP_QUERY_SM_FS_RCV       = 19,

    /**
     * @brief   Queries whether DIT mode is set or not
     * @param   (Bool *)
     */
    LLC_MCASP_QUERY_DIT_MODE        = 20,

    /**
     * @brief   Queries and returns the value in AMUTE register
     * @param   (Bool *)
     */
    LLC_MCASP_QUERY_AMUTE           = 21
} LLC_McaspHwStatusQuery;


/** McASP object structure */
typedef struct _LLC_McaspObj {

    Bool                ditStatus;
    /**< Support for DIT mode */
    CSL_McaspRegsOvly   regs;
    /**< Pointer to the register overlay structure for the peripheral */
    Int16               perNo;
    /**< Specifies a particular instance of McASP */
    Uint16              numOfSerializers;
    /**< Number of serializers */
    volatile Uint32     *dataAddr;
    /**< Instance Data Address */
    Uint32              edmaTxEventNum;
    /**< edma Transmit event number */
    Uint32              edmaRxEventNum;
    /**< edma Receive event number */
    Uint32              cpuTxEventNum;
    /**< This holds the CPU event no. of Rx*/
    Uint32              cpuRxEventNum;
    /**< This holds the CPU event no. of Tx*/

} LLC_McaspObj;


/**
 *  Module specific parameters. Present implementation doesn't have
 *  any module specific parameters.
 */
typedef struct _LLC_McaspParam {
    /**
     *  Bit mask to be used for module specific parameters.
     *  The below declaration is just a place-holder for future
     *  implementation.
     */
    Uint16   flags;
} LLC_McaspParam;

/**
 *  The following stcruture will be used in LLC_MCASP_QUERY_SRCTL_RRDY,
 *  and LLC_MCASP_QUERY_SRCTL_XRDY
 */
typedef struct _LLC_McaspSerQuery {
    PSP_McaspSerializerNum  serNum;
    /**< Serializer number */
    Bool                    serStatus;
    /**< Return value of the query */
} LLC_McaspSerQuery;

/**
 *  The following stcruture will be used in LLC_MCASP_QUERY_SRCTL_SRMOD
 */
typedef struct _LLC_McaspSerModeQuery {
    PSP_McaspSerializerNum  serNum;
    /**< Serializer number */
    LLC_McaspSerMode        serMode;
    /**< Serializer mode */
} LLC_McaspSerModeQuery;

/**
 * This will have the base-address information for the peripheral
 * instance
 */
typedef struct _LLC_McaspChipContext {

    Bool                ditStatus;
    /**< Support for DIT mode */

    CSL_McaspRegsOvly   regs;
    /**< Base-address of the configuration registers of the peripheral */

    Uint16               numOfSerializers;
    /**< Number of serializers */

    volatile Uint32     *dataAddr;
    /**< Instance Data Address */

    Uint32              edmaTxEventNum;
    /**< edma Transmit event number */

    Uint32              edmaRxEventNum;
    /**< edma Receive event number */

    Uint32              cpuTxEventNum;
    /**< CPU Transmit event number */

    Uint32              cpuRxEventNum;
    /**< CPU Receive event number */


} LLC_McaspChipContext;

/**
 *  Module specific context information. Present implementation doesn't
 *  have any context information.
 */
typedef struct _LLC_McaspContext {
    /**
     *  Context information of McASP.
     *  The below declaration is just a place-holder for future
     *  implementation.
     */
    Uint16  contextInfo;
} LLC_McaspContext;

/**
 * This data type is used to return the handle to an
 * instance of McASP
 */
typedef struct _LLC_McaspObj    *LLC_McaspHandle;

/** Default values for hardware setup structure */
#define CSL_MCASP_HWSETUP_DEFAULTS {\
    {\
    0,\
    0,\
    0,\
    0,\
    {\
    0,\
    0,\
    0,\
    0,\
    0,\
    0\
    }\
    },\
    {\
    0,\
    0,\
    0,\
    0,\
    0,\
    0,\
    0,\
    {\
    0x20,\
    0x8000,\
    0\
    }\
    },\
    {\
    0,\
    0,\
    0,\
    0,\
    0,\
    0,\
    0,\
    {\
    0x20,\
    0x8000,\
    0\
    }\
    },\
    0\
}

/** Default values for config structure */
#define CSL_MCASP_CONFIG_DEFAULTS {\
    CSL_MCASP_PWREMUMGT_RESETVAL,\
    CSL_MCASP_PFUNC_RESETVAL,\
    CSL_MCASP_PDIR_RESETVAL,\
    CSL_MCASP_PDOUT_RESETVAL,\
    CSL_MCASP_PDIN_PDSET_RESETVAL,\
    CSL_MCASP_PDCLR_RESETVAL,\
    CSL_MCASP_GBLCTL_RESETVAL,\
    CSL_MCASP_AMUTE_RESETVAL,\
    CSL_MCASP_DLBCTL_RESETVAL,\
    CSL_MCASP_DITCTL_RESETVAL,\
    CSL_MCASP_RMASK_RESETVAL,\
    CSL_MCASP_RFMT_RESETVAL,\
    CSL_MCASP_AFSRCTL_RESETVAL,\
    CSL_MCASP_ACLKRCTL_RESETVAL,\
    CSL_MCASP_AHCLKRCTL_RESETVAL,\
    CSL_MCASP_RTDM_RESETVAL,\
    CSL_MCASP_RINTCTL_RESETVAL,\
    CSL_MCASP_RSTAT_RESETVAL,\
    CSL_MCASP_RCLKCHK_RESETVAL,\
    CSL_MCASP_REVTCTL_RESETVAL,\
    CSL_MCASP_XMASK_RESETVAL,\
    CSL_MCASP_XFMT_RESETVAL,\
    CSL_MCASP_AFSXCTL_RESETVAL,\
    CSL_MCASP_ACLKXCTL_RESETVAL,\
    CSL_MCASP_AHCLKXCTL_RESETVAL,\
    CSL_MCASP_XTDM_RESETVAL,\
    CSL_MCASP_XINTCTL_RESETVAL,\
    CSL_MCASP_XSTAT_RESETVAL,\
    CSL_MCASP_XCLKCHK_RESETVAL,\
    CSL_MCASP_XEVTCTL_RESETVAL,\
    CSL_MCASP_SRCTL0_RESETVAL,\
    CSL_MCASP_SRCTL1_RESETVAL,\
    CSL_MCASP_SRCTL2_RESETVAL,\
    CSL_MCASP_SRCTL3_RESETVAL,\
    CSL_MCASP_XRSRCTL4_RESETVAL,\
    CSL_MCASP_XRSRCTL5_RESETVAL,\
    CSL_MCASP_XRSRCTL6_RESETVAL,\
    CSL_MCASP_XRSRCTL7_RESETVAL,\
    CSL_MCASP_XRSRCTL8_RESETVAL,\
    CSL_MCASP_XRSRCTL9_RESETVAL,\
    CSL_MCASP_XRSRCTL10_RESETVAL,\
    CSL_MCASP_XRSRCTL11_RESETVAL,\
    CSL_MCASP_XRSRCTL12_RESETVAL,\
    CSL_MCASP_XRSRCTL13_RESETVAL,\
    CSL_MCASP_XRSRCTL14_RESETVAL,\
    CSL_MCASP_XRSRCTL15_RESETVAL\
}

/******************************************************************************
 * Multi channel audio serial port global function declarations
 *****************************************************************************/
/**
 * \brief   LLC_mcaspInit
 *
 *   This is the initialization function for McASP CSL. This function
 *   needs to be called before any McASP CSL functions are to be called.
 *   This function is idem-potent. Currently, this function does not
 *   perform anything.
 *
 * \param   pContext     [IN]    Context information for McASP
 * \return
 *      PSP_SOK - Always returns
 */

extern Int16  LLC_mcaspInit(
    LLC_McaspContext *pContext
);

/**
 *  \brief LLC_mcaspOpen
 *
 *   This Function populates the peripheral data object for the instance and
 *   returns handle to it. Updates hMcasp parameter to handler
 *
 * \param   *pMcaspObj      [IN]    Pointer to the data object for McASP instance
 * \param    mcaspNum       [IN]    Specifies the instance of the McASP to be opened.
 *                                  There are 4 instances of the McASP.
 * \param   *pMcaspParam    [IN]    Module specific parameter for McASP instance
 * \param   *pStatus        [OUT]   Status of the function call
 *
 * \return
 *      PSP_SOK                 Open call is successful
 *      CSL_ESYS_FAIL           The McASP instance is invalid
 */

extern LLC_McaspHandle LLC_mcaspOpen (
    LLC_McaspObj      *const pMcaspObj,
    Int16             mcaspNum,
    LLC_McaspParam    *pMcaspParam,
    Int16             *pStatus
);

/**
 * \brief   LLC_mcaspClose
 *
 *   This function closes the McASP instance
 *
 * \param   hMcasp     [IN]    Handle to the McASP instance
 * \return
 *      PSP_SOK            - Close successful
 *      CSL_ESYS_BADHANDLE - Invalid handle
 */

extern Int16 LLC_mcaspClose (
    LLC_McaspHandle    hMcasp
);

/**
 * \brief   LLC_mcaspHwSetup
 *
 *   It configures the  McASP instance registers as per the values passed
 *   in the hardware setup structure.
 *
 * \param   hMcasp     [IN]    Handle to the McASP instance
 * \param   *myHwSetup [IN]    Pointer to hardware setup structure
 * \return
 *          PSP_SOK             - Hardware setup successful
 *          CSL_ESYS_BADHANDLE  - Invalid handle
 *          CSL_ESYS_INVPARAMS  - Hardware structure is not properly initialized
 *
 */
extern Int16 LLC_mcaspHwSetup (
    LLC_McaspHandle   hMcasp,
    PSP_McaspHwSetup  *const myHwSetup
);

/**
 * \brief   LLC_mcaspGetHwSetup
 *
 *   It retrieves the hardware setup parameters.
 *
 * \param   hMcasp     [IN]    Handle to the McASP instance
 * \param   myHwSetup  [IN]    Pointer to hardware setup structure
 * \return
 *      PSP_SOK             - Hardware setup successfully retrieved
 *      CSL_ESYS_BADHANDLE  - Invalid handle
 */

extern Int16 LLC_mcaspGetHwSetup (
    LLC_McaspHandle   hMcasp,
    PSP_McaspHwSetup  *myHwSetup
);

/**
 * \brief   LLC_mcaspHwControl
 *
 *   This function performs various control operations on the McASP
 *   instance, based on the command passed.
 *
 * \param   cmd     [IN]    Operation to be performed on the McASP instance
 * \param   arg     [IN]    Argument specific to the command
 * \return
 *      PSP_SOK            - Command execution successful.
 *      CSL_ESYS_BADHANDLE - Invalid handle
 *      CSL_ESYS_INVCMD    - Invalid command
 */

extern Int16 LLC_mcaspHwControl (
    LLC_McaspHandle           hMcasp,
    LLC_McaspHwControlCmd     cmd,
    void                      *const arg
);

/**
 * \brief   LLC_mcaspGetHwStatus
 *
 *   This function is used to get the value of various parameters of the
 *   McASP instance. The value returned depends on the query passed.
 *
 * \param   hMcasp     [IN]    Handle to the McASP instance
 * \param   myQuery    [IN]    Query to be performed
 * \param   *response  [IN]    Pointer to buffer to return the data requested by
 *                             the query passed
 * \return
 *      PSP_SOK            - Successful completion of the query
 *      CSL_ESYS_BADHANDLE - Invalid handle
 *      CSL_ESYS_INVQUERY  - Query command not supported
 *      CSL_ESYS_FAIL      - Generic failure
 */

extern Int16 LLC_mcaspGetHwStatus (
    LLC_McaspHandle           hMcasp,
    LLC_McaspHwStatusQuery    myQuery,
    void                      *const response
);

/**
 * \brief   LLC_mcaspRead
 *
 *   This reads the data from McASP. 32 bits of data will be read in the
 *   data object (variable); the pointer passed as a first argument.
 *
 * \param   hMcasp   [IN]    Handle to the McASP instance
 * \param   serNum   [IN]    Serailizer number
 * \param   wordLen  [IN]    word length
 * \param   *data    [IN]    data to be written
 *
 *  \return
 *           PSP_SOK             - Successful completion of read
 *           CSL_ESYS_INVPARAMS  - Invalid parameters
 *           CSL_ESYS_BADHANDLE  - Invalid handle
 */

extern Int16 LLC_mcaspRead (
    LLC_McaspHandle         hMcasp,
    Uint32                  serNum,
    Uint16                  wordLen,
    Uint8                  *data
);

/**
 * \brief   LLC_mcaspWrite
 *
 *   This transmits the data from McASP. 32 bits of data will be transmitted
 *   in the data object (variable); the pointer is passed as the
 *   a first argument.
 *
 * \param   hMcasp   [IN]    Handle to the McASP instance
 * \param   serNum   [IN]    Serailizer number
 * \param   wordLen  [IN]    word length
 * \param   *data    [IN]    data to be written
 *
 *  \return
 *           PSP_SOK             - Successful completion of read
 *           CSL_ESYS_INVPARAMS  - Invalid parameters
 *           CSL_ESYS_BADHANDLE  - Invalid handle
 */

extern Int16 LLC_mcaspWrite (
    LLC_McaspHandle         hMcasp,
    Uint32                  serNum,
    Uint16                  wordLen,
    Uint8                  *const data
);


/**
 *  \brief LLC_mcaspReadXmtConfig
 *
 *  Mcasp Configuration related functions, Updates xmtData pointer
 *
 *  \param    hMcasp        [IN]    port  Handler
 *  \param    xmtData       [IN]    configured data is passed to user
 *  \return  void
 */

PAL_Result LLC_mcaspReadXmtConfig (LLC_McaspHandle hMcasp,
                                    PSP_McaspHwSetupData *const xmtData);

/**
 *  \brief    LLC_mcaspReadRcvConfig
 *
 *  configures receiver section of McAsp
 *  clock, high clock, mask bit,interrupts mode are configured
 *
 *  \param    hMcasp         [IN]    port  Handler
 *  \param    rcvData        [IN]    Input data tobe configured by user
 *  \return void
 */

PAL_Result LLC_mcaspReadRcvConfig (LLC_McaspHandle hMcasp,
                                    PSP_McaspHwSetupData *const rcvData);

/**
 *   \brief LLC_mcaspConfigGpio
 *
 *   This function enables/disables the GPIO mode (configure GPIO mode).
 *
 *  \param        hMcasp  [IN]  Handle to the McASP instance
 *  \param        setVal  [IN]  Value to loaded into the GPIO register
 *  \return
 *          PSP_SOK             - Successuful return
 *          PSP_E_INVAL_PARAM   - Invalide Parameter
 */

PAL_Result LLC_mcaspConfigGpio (LLC_McaspHandle hMcasp, Uint32 setVal);


/**
 * \brief   LLC_mcaspWriteChanStatRam
 *
 *  This function writes to the Channel status RAM (DITCSRA/B0-5)
 *
 * \param     hMcasp      [IN]     Handle to the McASP instance
 * \param     chanStatRam [IN]     status to be written
 * \return
 *          None
 */


PAL_Result LLC_mcaspWriteChanStatRam (LLC_McaspHandle             hMcasp,
                                PSP_McaspChStatusRam       *const chanStatRam);

/**
 * \brief   LLC_mcaspWriteUserDataRam
 *
 *  This function writes to the User Data RAM (DITUDRA/B0-5)
 *
 * \param     hMcasp      [IN]     Handle to the McASP instance
 * \param     userDataRam [IN]     data to be written
 * \return
 *          None
 */


PAL_Result LLC_mcaspWriteUserDataRam (LLC_McaspHandle             hMcasp,
                                PSP_McaspUserDataRam       *const userDataRam);

/**
 * \brief   LLC_mcaspConfigXmtSection
 *
 *  This function configures format, frame sync, and other parameters
 *  related to the xmt section. Also configures the xmt clk section.
 *
 * \param     hMcasp      [IN]     Handle to the McASP instance
 * \param     xmtData     [IN]     transmit related parameters
 * \return
 *          None
 */


PAL_Result LLC_mcaspConfigXmtSection (LLC_McaspHandle hMcasp,
                                PSP_McaspHwSetupData  *const xmtData);

/**
 * \brief   LLC_mcaspConfigRcvSection
 *
 *  Configure the format, frame sync, and other parameters related to the
 *  rcv section. Also configures the rcv clk section.
 *
 * \param     hMcasp      [IN]     Handle to the McASP instance
 * \param     rcvData     [IN]     Receive related parameters
 * \return
 *          None
 */

PAL_Result LLC_mcaspConfigRcvSection (LLC_McaspHandle             hMcasp,
                                 PSP_McaspHwSetupData        *const rcvData);

/**
 * \brief   LLC_mcaspConfigLoopBack
 *
 *  This function sets the digital loopback mode
 *
 * \param     hMcasp      [IN]     Handle to the McASP instance
 * \param     loopBack    [IN]     Value to be loaded into the bit filed
 * \return
 *          None
 */

PAL_Result LLC_mcaspConfigLoopBack (LLC_McaspHandle hMcasp,Bool loopBack);

/**
 * \brief   LLC_mcaspConfigAudioMute
 *
 *  This function configures the AMUTE register with specified values
 *
 * \param     hMcasp      [IN]     Handle to the McASP instance
 * \param     audioMute   [IN]     Value to be loaded to the register
 * \return
 *          None
 */

PAL_Result LLC_mcaspConfigAudioMute (LLC_McaspHandle hMcasp,Uint32 audioMute);

/**
 * \brief   LLC_mcaspRegReset
 *
 *   This Function fills the registers for the McAsp instance with
 *   default reset values
 *
 * \param   hMcasp   [IN]    Pointer to the McASP instance
 * \return
 *          none
 */

PAL_Result  LLC_mcaspRegReset (LLC_McaspHandle     hMcasp);

/**
 * \brief   LLC_mcaspActivateClkRcvXmt
 *
 *   This Function activate Receive Transmit clk
 *
 * \param   hMcasp   [IN]    Pointer to the McASP instance
 * \return
 *          success or failure
 */

PAL_Result  LLC_mcaspActivateClkRcvXmt(LLC_McaspHandle hMcasp);


/**
 * \brief   LLC_mcaspActivateRcvClkSer
 *
 *  This function sets the bits related to receive in RGBLCTL.
 *
 * \param     hMcasp      [IN]     Handle to the McASP instance
 * \return
 *          None
 */

PAL_Result LLC_mcaspActivateRcvClkSer (LLC_McaspHandle     hMcasp);


/**
 * \brief   LLC_mcaspActivateXmtClkSer
 *
 *  This function sets the bits related to transmit in XGBLCTL.
 *
 * \param     hMcasp      [IN]     Handle to the McASP instance
 * \return
 *          None
 */

PAL_Result LLC_mcaspActivateXmtClkSer (LLC_McaspHandle     hMcasp);

/**
 * \brief   LLC_mcaspResetRcvFSRst
 *
 *  This function resets the receive frame sync generator reset enable bit
 *  of receive global control register
 *
 * \param     hMcasp      [IN]     Handle to the McASP instance
 * \return
 *          None
 */

void LLC_mcaspResetRcvFSRst (LLC_McaspHandle  hMcasp);


/**
 * \brief   LLC_mcaspResetXmt
 *
 *  This function resets the bits related to transmit in XGBLCTL.
 *
 * \param     hMcasp      [IN]     Handle to the McASP instance
 * \return
 *          None
 */

PAL_Result LLC_mcaspResetXmt (LLC_McaspHandle     hMcasp);

/**
 * \brief   LLC_mcaspResetRcv
 *
 *  This function resets the bits related to receive in RGBLCTL.
 *
 * \param     hMcasp      [IN]     Handle to the McASP instance
 * \return
 *          None
 */

PAL_Result LLC_mcaspResetRcv (LLC_McaspHandle     hMcasp);


/**
 * \brief   LLC_mcaspSetDitMode
 *
 *  This function enables/disables the DIT mode.
 *
 * \param     hMcasp      [IN]     Handle to the McASP instance
 * \param     ditFlag     [IN]     Value to loaded into the DITCTL register
 * \return
 *          None
 */

PAL_Result LLC_mcaspSetDitMode (LLC_McaspHandle     hMcasp,
                          Bool ditFlag);

/**
 * \brief   LLC_mcaspSetSerRcv
 *
 *  This function sets a particular serializer to act as receiver
 *
 * \param     hMcasp      [IN]     Handle to the McASP instance
 * \param     serNum      [IN]     serializer number
 * \return
 *          None
 */

PAL_Result LLC_mcaspSetSerRcv (LLC_McaspHandle         hMcasp,
                                 PSP_McaspSerializerNum  serNum);

/**
 * \brief   LLC_mcaspResetSmFsRcv
 *
 *  This function resets the RFRST and RSMRST bits in RGBLCTL.
 *
 * \param     hMcasp      [IN]     Handle to the McASP instance
 * \return
 *          None
 */

PAL_Result LLC_mcaspResetSmFsRcv (LLC_McaspHandle     hMcasp);

/**
 * \brief   LLC_mcaspSetSerXmt
 *
 *  This function sets a particular serializer to act as transmitter
 *
 * \param     hMcasp      [IN]     Handle to the McASP instance
 * \param     serNum      [IN]     serializer number
 * \return
 *          None
 */

PAL_Result LLC_mcaspSetSerXmt (LLC_McaspHandle hMcasp,
                                 PSP_McaspSerializerNum  serNum);

/**
 * \brief   LLC_mcaspResetSmFsXmt
 *
 *  This function resets the XFRST and XSMRST bits in XGBLCTL.
 *
 * \param     hMcasp      [IN]     Handle to the McASP instance
 * \return
 *          None
 */

PAL_Result LLC_mcaspResetSmFsXmt (LLC_McaspHandle     hMcasp);


#ifdef __cplusplus
}
#endif

#endif  /* _CSL_MCASP_H_ */




