/******************************************************************************
**+-------------------------------------------------------------------------+**
**|                            ****                                         |**
**|                            ****                                         |**
**|                            ******o***                                   |**
**|                      ********_///_****                                  |**
**|                      ***** /_//_/ ****                                  |**
**|                       ** ** (__/ ****                                   |**
**|                           *********                                     |**
**|                            ****                                         |**
**|                            ***                                          |**
**|                                                                         |**
**|         Copyright (c) 1998-2006 Texas Instruments Incorporated          |**
**|                        ALL RIGHTS RESERVED                              |**
**|                                                                         |**
**| Permission is hereby granted to licensees of Texas Instruments          |**
**| Incorporated (TI) products to use this computer program for the sole    |**
**| purpose of implementing a licensee product based on TI products.        |**
**| No other rights to reproduce, use, or disseminate this computer         |**
**| program, whether in part or in whole, are granted.                      |**
**|                                                                         |**
**| TI makes no representation or warranties with respect to the            |**
**| performance of this computer program, and specifically disclaims        |**
**| any responsibility for any damages, special or consequential,           |**
**| connected with the use of this program.                                 |**
**|                                                                         |**
**+-------------------------------------------------------------------------+**
******************************************************************************/

/**
 *  \file    llc_mcbspIf.h
 *
 *  \brief   LLC layer header of McBSP
 *
 *  This file contains llc layer macros and APIs declaration for McBSP
 *
 *  (C) Copyright 2006, Texas Instruments, Inc
 *
 *  \version 0.1    -   First release
 *           0.2 - Pre silicon release
 */

#ifndef _LLC_MCBSPIF_H
#define _LLC_MCBSPIF_H

 /* Include files  */
#include <ti/sdo/pspdrivers/drivers/mcbsp/src/llc_mcbspTypes.h>

#ifdef CHIP_C6424
#include <ti/sdo/pspdrivers/soc/c6424/dsp/csl_types.h>
#endif

#ifdef CHIP_DM6437
#include <ti/sdo/pspdrivers/soc/dm6437/dsp/csl_types.h>
#endif

#ifdef __cplusplus
extern "C" {
#endif

/**
 * \defgroup LLC_MCBSP_IO_SYMBOL General purpose IO pin selection
 * \ingroup LLC_MCBSP_SYMBOL
 *
 * Use this symbol as pin mask for LLC_mcbspIoRead() and
 * LLC_mcbspIoWrite() functions
 * @{
 */

#define LLC_MCBSP_IO_CLKX                             (1u)
/**< I/O Pin Input/Output configuration for CLKX Pin       */
#define LLC_MCBSP_IO_FSX                              (2u)
/**< I/O Pin Input/Output configuration for FSX  Pin       */
#define LLC_MCBSP_IO_DX                               (4u)
/**< Not Configurable. Always Output.                      */
#define LLC_MCBSP_IO_CLKR                             (8u)
/**< I/O Pin Input/Output configuration for CLKR Pin       */
#define LLC_MCBSP_IO_FSR                              (16u)
/**< I/O Pin Input/Output configuration for FSR Pin        */
#define LLC_MCBSP_IO_DR                               (32u)
/**< Not Configurable. Always Input.                        */

/**
@} LLC_MCBSP_IO_SYMBOL */

/**
 * \defgroup LLC_MCBSP_CTRL_SYMBOL Enable/Disable Controls
 * \ingroup LLC_MCBSP_SYMBOL
 *
 * Use this symbol as enable/disable control bitmask for
 *  LLC_mcbspHwControl() function
 *
 * @{
 */

#define LLC_MCBSP_CTRL_RX_ENABLE                      (1u)
/**< To enable Receiver in resetControl Function             */
#define LLC_MCBSP_CTRL_TX_ENABLE                      (2u)
/**< To enable Transmitter in resetControl Function          */
#define LLC_MCBSP_CTRL_RX_DISABLE                     (4u)
/**< To disable Receiver in resetControl Function            */
#define LLC_MCBSP_CTRL_TX_DISABLE                     (8u)
/**< To disable Transmitter in resetControl Function         */
#define LLC_MCBSP_CTRL_FSYNC_ENABLE                   (16u)
/**< To enable Frame Sync Generation in resetControl Function */
#define LLC_MCBSP_CTRL_SRG_ENABLE                     (32u)
/**< To enable Sample Rate Generator in resetControl Function */
#define LLC_MCBSP_CTRL_FSYNC_DISABLE                  (64u)
/**< To disable Frame Sync Generation in resetControl Function */
#define LLC_MCBSP_CTRL_SRG_DISABLE                    (128u)
/**< To disable Sample Rate Generator in resetControl Function */

/**
@} LLC_MCBSP_CTRL_SYMBOL */

/**
 * \defgroup LLC_DEVSTATUS_SYMBOL RCV/XMT status symbols
 * \ingroup LLC_MCBSP_SYMBOL
 *
 * Use this symbol to compare the return value of   LLC_mcbspGetHwStatus()
 * function for   LLC_MCBSP_QUERY_DEV_STATUS query
 * \n For eg:- On RFULL event, (response & LLC_MCBSP_RFULL) == 0x0004
 *
 * @{
 */
#define LLC_MCBSP_RRDY        (0x0001u)
/**< RCV ready status */
#define LLC_MCBSP_XRDY        (0x0002u)
/**< XMT ready status */

#define LLC_MCBSP_RFULL       (0x0004u)
/**< RCV full status */
#define LLC_MCBSP_XEMPTY      (0x0008u)
/**< XMT empty status */
#define LLC_MCBSP_RSYNCERR    (0x0010u)
/**< RCV frame sync error status */
#define LLC_MCBSP_XSYNCERR    (0x0020u)
/**< XMT frame sync error status */
/**
@} LLC_DEVSTATUS_SYMBOL */

/**
 * \defgroup LLC_EMCBSP_SYMBOL Error codes
 * \ingroup LLC_MCBSP_SYMBOL
 *
 * @{
 */
#define LLC_EMCBSP_INVCNTLCMD                         (LLC_EMCBSP_FIRST - 0)
/**< Invalid Control Command */
#define LLC_EMCBSP_INVQUERY                           (LLC_EMCBSP_FIRST - 1)
/**< Invalid Query */
#define LLC_EMCBSP_INVPARAMS                          (LLC_EMCBSP_FIRST - 2)
/**< Invalid Parameter */
#define LLC_EMCBSP_INVSIZE                            (LLC_EMCBSP_FIRST - 3)
/**< Invalid Size */
#define LLC_EMCBSP_NOTEXIST                           (LLC_EMCBSP_FIRST - 4)
/**< 'Does not exist' */
#define LLC_EMCBSP_INVMODE                            (LLC_EMCBSP_FIRST - 5)
/**< Invalid mode to conduct operation */
/**
@}  LLC_EMCBSP_SYMBOL */

/**
 * \defgroup LLC_MCBSP_SHIFT Shifting Macros
 * \ingroup LLC_MCBSP_SYMBOL
 *
 * @{
 */
/* spcr Macros */
#define LLC_MCBSP_SPCR_RRST_SHIFT           (0u)
#define LLC_MCBSP_SPCR_RRDY_SHIFT           ( LLC_MCBSP_SPCR_RRST_SHIFT + (1u) )
#define LLC_MCBSP_SPCR_RFULL_SHIFT          ( LLC_MCBSP_SPCR_RRDY_SHIFT + (1u) )
#define LLC_MCBSP_SPCR_RSYNCERR_SHIFT       ( LLC_MCBSP_SPCR_RFULL_SHIFT + (1u) )
#define LLC_MCBSP_SPCR_RINTM_SHIFT          ( LLC_MCBSP_SPCR_RSYNCERR_SHIFT + (1u) )
#define LLC_MCBSP_SPCR_ABIS_SHIFT           ( LLC_MCBSP_SPCR_RINTM_SHIFT + (2u) )
#define LLC_MCBSP_SPCR_DX_SHIFT             ( LLC_MCBSP_SPCR_ABIS_SHIFT + (1u))
#define LLC_MCBSP_SPCR_CLKSTP_SHIFT         ( LLC_MCBSP_SPCR_DX_SHIFT + (3u)  )
#define LLC_MCBSP_SPCR_RJUST_SHIFT          ( LLC_MCBSP_SPCR_CLKSTP_SHIFT + (2u) )
#define LLC_MCBSP_SPCR_DLB_SHIFT            ( LLC_MCBSP_SPCR_RJUST_SHIFT + (2u) )

#define LLC_MCBSP_SPCR_XRST_SHIFT           (16u)
#define LLC_MCBSP_SPCR_XRDY_SHIFT           ( LLC_MCBSP_SPCR_XRST_SHIFT + (1u) )
#define LLC_MCBSP_SPCR_XEMPTY_SHIFT         ( LLC_MCBSP_SPCR_XRDY_SHIFT + (1u) )
#define LLC_MCBSP_SPCR_XSYNCERR_SHIFT       ( LLC_MCBSP_SPCR_XEMPTY_SHIFT + (1u) )
#define LLC_MCBSP_SPCR_XINTM_SHIFT          ( LLC_MCBSP_SPCR_XSYNCERR_SHIFT + (1u) )
#define LLC_MCBSP_SPCR_GRST_SHIFT           (LLC_MCBSP_SPCR_XINTM_SHIFT + (2u) )
#define LLC_MCBSP_SPCR_FRST_SHIFT           (LLC_MCBSP_SPCR_GRST_SHIFT + (1u) )
#define LLC_MCBSP_SPCR_SOFT_SHIFT           (LLC_MCBSP_SPCR_FRST_SHIFT + (1u) )
#define LLC_MCBSP_SPCR_FREE_SHIFT           (LLC_MCBSP_SPCR_SOFT_SHIFT + (1u) )

/* PCR macros */
#define LLC_MCBSP_PCR_CLKRP_SHIFT           (0u)
#define LLC_MCBSP_PCR_CLKXP_SHIFT           ( LLC_MCBSP_PCR_CLKRP_SHIFT + (1u) )
#define LLC_MCBSP_PCR_FSRP_SHIFT            ( LLC_MCBSP_PCR_CLKXP_SHIFT + (1u) )
#define LLC_MCBSP_PCR_FSXP_SHIFT            ( LLC_MCBSP_PCR_FSRP_SHIFT  + (1u) )
#define LLC_MCBSP_PCR_DRSTAT_SHIFT          ( LLC_MCBSP_PCR_FSXP_SHIFT + (1u) )
#define LLC_MCBSP_PCR_DXSTAT_SHIFT          ( LLC_MCBSP_PCR_DRSTAT_SHIFT + (1u) )
#define LLC_MCBSP_PCR_CLKS_SHIFT            ( LLC_MCBSP_PCR_DXSTAT_SHIFT  + (1u) )
#define LLC_MCBSP_PCR_SCLKME_SHIFT          ( LLC_MCBSP_PCR_CLKS_SHIFT + (1u) )
#define LLC_MCBSP_PCR_CLKRM_SHIFT           ( LLC_MCBSP_PCR_SCLKME_SHIFT + (1u) )
#define LLC_MCBSP_PCR_CLKXM_SHIFT           ( LLC_MCBSP_PCR_CLKRM_SHIFT + (1u) )
#define LLC_MCBSP_PCR_FSRM_SHIFT            ( LLC_MCBSP_PCR_CLKXM_SHIFT + (1u) )
#define LLC_MCBSP_PCR_FSXM_SHIFT            ( LLC_MCBSP_PCR_FSRM_SHIFT + (1u) )
#define LLC_MCBSP_PCR_RIOEN_SHIFT           ( LLC_MCBSP_PCR_FSXM_SHIFT + (1u) )
#define LLC_MCBSP_PCR_XIOEN_SHIFT           ( LLC_MCBSP_PCR_RIOEN_SHIFT + (1u) )
#define LLC_MCBSP_PCR_IDLEEN_SHIFT          ( LLC_MCBSP_PCR_XIOEN_SHIFT + (1u) )

/* RCR/XCR macros */
#define LLC_MCBSP_DATA_WDRVRS_SHIFT         (4u)
#define LLC_MCBSP_DATA_WDLEN1_SHIFT         ( LLC_MCBSP_DATA_WDRVRS_SHIFT + (1u))
#define LLC_MCBSP_DATA_FRLEN1_SHIFT         ( LLC_MCBSP_DATA_WDLEN1_SHIFT + (3u))
#define LLC_MCBSP_DATA_RSVD_SHIFT           (LLC_MCBSP_DATA_FRLEN1_SHIFT + (7u))

#define LLC_MCBSP_DATA_DELAY_SHIFT          (16u)
#define LLC_MCBSP_DATA_FSYNCIG_SHIFT        ( LLC_MCBSP_DATA_DELAY_SHIFT + (2u))
#define LLC_MCBSP_DATA_COMPAND_SHIFT        ( LLC_MCBSP_DATA_FSYNCIG_SHIFT + (1u))
#define LLC_MCBSP_DATA_WDLEN2_SHIFT         ( LLC_MCBSP_DATA_COMPAND_SHIFT + (2u))
#define LLC_MCBSP_DATA_FRLEN2_SHIFT         ( LLC_MCBSP_DATA_WDLEN2_SHIFT + (3u))
#define LLC_MCBSP_DATA_PHASE_SHIFT          ( LLC_MCBSP_DATA_FRLEN2_SHIFT + (7u))


/* SRGR macros */
#define LLC_MCBSP_SRGR_CLKGDV_SHIFT         (0u)
#define LLC_MCBSP_SRGR_FWID_SHIFT           ( LLC_MCBSP_SRGR_CLKGDV_SHIFT + (8u))
#define LLC_MCBSP_SRGR_FPER_SHIFT           ( LLC_MCBSP_SRGR_FWID_SHIFT + (8u))
#define LLC_MCBSP_SRGR_FSGM_SHIFT           ( LLC_MCBSP_SRGR_FPER_SHIFT + (12u))
#define LLC_MCBSP_SRGR_CLKSM_SHIFT          ( LLC_MCBSP_SRGR_FSGM_SHIFT + (1u))
#define LLC_MCBSP_SRGR_CLKSP_SHIFT          ( LLC_MCBSP_SRGR_CLKSM_SHIFT + (1u))
#define LLC_MCBSP_SRGR_GSYNC_SHIFT          ( LLC_MCBSP_SRGR_CLKSP_SHIFT + (1u))
/**
@} LLC_MCBSP_SHIFT */

/**
 * \defgroup LLC_MCBSP_MASK Masking Macros
 * \ingroup LLC_MCBSP_SYMBOL
 *
 * @{
 */
/* spcr  Macros */
#define LLC_MCBSP_SPCR_FREE_MASK         (0x02000000u)
#define LLC_MCBSP_SPCR_SOFT_MASK         (0x01000000u)
#define LLC_MCBSP_SPCR_FRST_MASK         (0x00800000u)
#define LLC_MCBSP_SPCR_GRST_MASK         (0x00400000u)
#define LLC_MCBSP_SPCR_XINTM_MASK        (0x00300000u)
#define LLC_MCBSP_SPCR_XSYNCERR_MASK     (0x00080000u)
#define LLC_MCBSP_SPCR_XEMPTY_MASK       (0x00040000u)
#define LLC_MCBSP_SPCR_XRDY_MASK         (0x00020000u)
#define LLC_MCBSP_SPCR_XRST_MASK         (0x00010000u)
#define LLC_MCBSP_SPCR_DLB_MASK          (0x00008000u)
#define LLC_MCBSP_SPCR_RJUST_MASK        (0x00006000u)
#define LLC_MCBSP_SPCR_RINTM_MASK        (0x00000030u)
#define LLC_MCBSP_SPCR_RSYNCERR_MASK     (0x00000008u)
#define LLC_MCBSP_SPCR_RSYNCERR_CLEAR    (0x00000000u)
#define LLC_MCBSP_SPCR_RFULL_MASK        (0x00000004u)
#define LLC_MCBSP_SPCR_RRDY_MASK         (0x00000002u)
#define LLC_MCBSP_SPCR_RRST_MASK         (0x00000001u)
/* RCR macros */
#define LLC_MCBSP_RCR_RPHASE_MASK        (0x80000000u)
#define LLC_MCBSP_RCR_RFRLEN2_MASK       (0x7F000000u)
#define LLC_MCBSP_RCR_RWDLEN2_MASK       (0x00E00000u)
#define LLC_MCBSP_RCR_RCOMPAND_MASK      (0x00180000u)
#define LLC_MCBSP_RCR_RFIG_MASK          (0x00040000u)
#define LLC_MCBSP_RCR_RDATDLY_MASK       (0x00030000u)
#define LLC_MCBSP_RCR_RFRLEN1_MASK       (0x00007F00u)
#define LLC_MCBSP_RCR_RWDLEN1_MASK       (0x000000E0u)
#define LLC_MCBSP_RCR_RWDREVRS_MASK      (0x00000010u)

/* XCR */

#define LLC_MCBSP_XCR_XPHASE_MASK        (0x80000000u)
#define LLC_MCBSP_XCR_XFRLEN2_MASK       (0x7F000000u)
#define LLC_MCBSP_XCR_XWDLEN2_MASK       (0x00E00000u)
#define LLC_MCBSP_XCR_XCOMPAND_MASK      (0x00180000u)
#define LLC_MCBSP_XCR_XFIG_MASK          (0x00040000u)
#define LLC_MCBSP_XCR_XDATDLY_MASK       (0x00030000u)
#define LLC_MCBSP_XCR_XFRLEN1_MASK       (0x00007F00u)
#define LLC_MCBSP_XCR_XWDLEN1_MASK       (0x000000E0u)
#define LLC_MCBSP_XCR_XWDREVRS_MASK      (0x00000010u)
/* SRGR */

#define LLC_MCBSP_SRGR_CLKSM_MASK        (0x20000000u)
#define LLC_MCBSP_SRGR_FSGM_MASK         (0x10000000u)
#define LLC_MCBSP_SRGR_FPER_MASK         (0x0FFF0000u)
#define LLC_MCBSP_SRGR_FWID_MASK         (0x0000FF00u)
#define LLC_MCBSP_SRGR_CLKGDV_MASK       (0x000000FFu)
/* PCR */
#define LLC_MCBSP_PCR_FSXM_MASK          (0x00000800u)
#define LLC_MCBSP_PCR_FSRM_MASK          (0x00000400u)
#define LLC_MCBSP_PCR_CLKXM_MASK         (0x00000200u)
#define LLC_MCBSP_PCR_CLKRM_MASK         (0x00000100u)
#define LLC_MCBSP_PCR_SCLKME_MASK        (0x00000080u)
#define LLC_MCBSP_PCR_DXSTAT_MASK        (0x00000020u)
#define LLC_MCBSP_PCR_DRSTAT_MASK        (0x00000010u)
#define LLC_MCBSP_PCR_FSXP_MASK          (0x00000008u)
#define LLC_MCBSP_PCR_FSRP_MASK          (0x00000004u)
#define LLC_MCBSP_PCR_CLKXP_MASK         (0x00000002u)
#define LLC_MCBSP_PCR_CLKRP_MASK         (0x00000001u)


#define LLC_MCBSP_DRR_DRR_MASK           (0xFFFFFFFFu)
#define LLC_MCBSP_DXR_DXR_MASK           (0xFFFFFFFFu)

/**
@} LLC_MCBSP_MASK */

/* XSYNCERROR set */
#define LLC_MCBSP_SPCR_XSYNCERR_SET     (1u)
/* XSYNCERROR reset */
#define LLC_MCBSP_SPCR_XSYNCERR_CLEAR   (0)
/* RSYNCERROR set */
#define LLC_MCBSP_SPCR_RSYNCERR_SET     (1u)
/* RSYNCERROR reset */
#define LLC_MCBSP_SPCR_RSYNCERROR_CLEAR   (0)


/**< CLKXM as output */
#define LLC_MCBSP_PCR_CLKXM_OUTPUT  (1u)
/**< FSXM as output */
#define LLC_MCBSP_PCR_FSXM_OUTPUT   (1u)
/**< CLKRM as output */
#define LLC_MCBSP_PCR_CLKRM_OUTPUT  (1u)
/**< FSRM as output */
#define LLC_MCBSP_PCR_FSRM_OUTPUT   (1u)
/**< CLKXM as input */
#define LLC_MCBSP_PCR_CLKXM_INPUT   (0)
/**< FSXM as input */
#define LLC_MCBSP_PCR_FSXM_INPUT    (0)
/**< CLKRM as iput */
#define LLC_MCBSP_PCR_CLKRM_INPUT   (0)
/**< FSRM as input */
#define LLC_MCBSP_PCR_FSRM_INPUT    (0)

/**
 * \defgroup LLC_MCBSP_FUNCTION  Functions
 * \ingroup  LLC_MCBSP_API
 *
 * @{
 */
extern CSL_Status  LLC_mcbspInit(const Int32 * pContext);

extern CSL_Status LLC_mcbspGetBaseAddress(
                                Uint32 InstanceId,
                                Ptr param,
                                LLC_McbspBaseAddress * const baseAddr
                                );

extern LLC_McbspHandle  LLC_mcbspOpen(
                                LLC_McbspObj * const pMcbspObj,
                                Uint32 InstanceId,
                                Int *pMcbspParam,
                                CSL_Status *pStatus
                                );/*LLC_McbspHandle*/

extern CSL_Status  LLC_mcbspHwControl(
                                LLC_McbspHandle hMcbsp,
                                LLC_McbspControlCmd cmd,
                                const void *arg
                                );

extern CSL_Status  LLC_mcbspHwSetupRaw (
                                LLC_McbspHandle  hMcbsp,
                                const LLC_McbspConfig     *config
                                );

extern CSL_Status LLC_mcbspHwSetup(
                                LLC_McbspHandle hMcbsp,
                                const LLC_McbspHwSetup *setup
                                );

extern CSL_Status  LLC_mcbspClose(LLC_McbspHandle    hMcbsp);

extern CSL_Status  LLC_mcbspRcvConfigWordLength(
                                LLC_McbspHandle hMcbsp,
                                Uint32 wordLen
                                );
extern CSL_Status  LLC_mcbspXmtConfigWordLength(
                                LLC_McbspHandle hMcbsp,
                                Uint32 wordLen
                                );

/**
@} LLC_MCBSP_FUNCTION */

#ifdef __cplusplus
}
#endif

#endif /* _LLC_MCBSPIF_H */
