/******************************************************************************
**+-------------------------------------------------------------------------+**
**|                            ****                                         |**
**|                            ****                                         |**
**|                            ******o***                                   |**
**|                      ********_///_****                                  |**
**|                      ***** /_//_/ ****                                  |**
**|                       ** ** (__/ ****                                   |**
**|                           *********                                     |**
**|                            ****                                         |**
**|                            ***                                          |**
**|                                                                         |**
**|         Copyright (c) 1998-2006 Texas Instruments Incorporated          |**
**|                        ALL RIGHTS RESERVED                              |**
**|                                                                         |**
**| Permission is hereby granted to licensees of Texas Instruments          |**
**| Incorporated (TI) products to use this computer program for the sole    |**
**| purpose of implementing a licensee product based on TI products.        |**
**| No other rights to reproduce, use, or disseminate this computer         |**
**| program, whether in part or in whole, are granted.                      |**
**|                                                                         |**
**| TI makes no representation or warranties with respect to the            |**
**| performance of this computer program, and specifically disclaims        |**
**| any responsibility for any damages, special or consequential,           |**
**| connected with the use of this program.                                 |**
**|                                                                         |**
**+-------------------------------------------------------------------------+**
******************************************************************************/
/**
 *  \file    llc_mcbspTypes.h
 *
 *  \brief   LLC layer header of McBSP
 *
 *  This file contains llc layer structures
 *
 *  (C) Copyright 2006, Texas Instruments, Inc
 *
 *  \version 0.1    -   First release
 *            0.2 - Pre silicon release
 */


/**
 * \defgroup LLC_MCBSP_API MCBSP
 */

/**
 * \defgroup LLC_MCBSP_DATASTRUCT MCBSP Data Structures
 * \ingroup  LLC_MCBSP_API
 */
/**
 * \defgroup LLC_MCBSP_SYMBOL  Symbols
 * \ingroup  LLC_MCBSP_API
 */
/**
 * \defgroup LLC_MCBSP_ENUM  Enumerated Data Types
 * \ingroup  LLC_MCBSP_API
 */

#ifndef _LLC_MCBSPTYPES_H
#define _LLC_MCBSPTYPES_H

#ifdef CHIP_C6424
#include <ti/sdo/pspdrivers/soc/c6424/dsp/cslr_mcbsp.h>
#endif

#ifdef CHIP_DM6437
#include <ti/sdo/pspdrivers/soc/dm6437/dsp/cslr_mcbsp.h>
#endif

#ifdef __cplusplus
extern "C" {
#endif

/**
 * \defgroup LLC_MCBSP_DLBMODE_ENUM Digital Loopback mode selection
 * \ingroup LLC_MCBSP_ENUM
 *
 * \brief Digital Loopback mode selection
 *
 * Use this symbol to enable/disable digital loopback mode
 * @{
 */
typedef enum _LLC_McbspDlbMode
{
    /**< disable digital loopback mode */
    LLC_MCBSP_DLBMODE_OFF                  =            (0),
    /**< enable digital loopback mode */
    LLC_MCBSP_DLBMODE_ON                   =            (1u)
} LLC_McbspDlbMode;
/**
@} LLC_MCBSP_DLBMODE_ENUM */

/**
 * \defgroup LLC_MCBSP_EMU_ENUM Emulation mode setting
 * \ingroup LLC_MCBSP_ENUM
 *
 * \brief Emulation mode setting
 *
 * Use this symbol to set the Emulation Mode
 * @{
 */
typedef enum _LLC_McbspEmu
{
    /**< Emulation mode stop */
    LLC_MCBSP_EMU_STOP             =                  (0),
    /**< Emulation mode TX stop */
    LLC_MCBSP_EMU_TX_STOP          =                  (1u),
    /**< Emulation free run mode */
    LLC_MCBSP_EMU_FREERUN          =                  (2u)
} LLC_McbspEmu;
/**
@} LLC_MCBSP_EMU_ENUM */

/**
 * \defgroup LLC_MCBSP_DXSTATE_ENUM DX Pin State
 * \ingroup LLC_MCBSP_ENUM
 *
 * \brief Transmit pin mode configuration
 *
 * @{
 */
typedef enum _LLC_McbspDxState
{
    /**< High Z */
    LLC_MCBSP_DX_HIGHZ   = (0),
    /**< Driven as 1 */
    LLC_MCBSP_DX_LOGIC_1 = (1u),
    /**< Driven as 0 */
    LLC_MCBSP_DX_LOGIC_0 = (2u)
} LLC_McbspDxState;
/**
@} LLC_MCBSP_DXSTATE_ENUM */

/**
 * \defgroup LLC_MCBSP_PHASE_ENUM Phase count selection
 * \ingroup LLC_MCBSP_ENUM
 *
 * \brief Phase count selection
 *
 * Use this symbol to select number of phases per frame
 * @{
 */
typedef enum _LLC_McbspPhase
{
    /**< Single phase for frame */
    LLC_MCBSP_PHASE_SINGLE                =             (0u),
    /**< Dual phase for frame */
    LLC_MCBSP_PHASE_DUAL                  =             (1u)
} LLC_McbspPhase;
/**
@} LLC_MCBSP_PHASE_ENUM */
/**
 * \defgroup LLC_MCBSP_WORDLEN_ENUM Word length
 * \ingroup LLC_MCBSP_ENUM
 *
 * \brief Word lengths supported on MCBSP
 *
 * Use this symbol for setting Word Length in each Phase for every Frame
 * @{
 */
typedef enum _LLC_McbspWordLen
{
    /**< Word Length for Frame is 8 */
    LLC_MCBSP_WORDLEN_8        =                  (0u),
    /**< Word Length for Frame is 12 */
    LLC_MCBSP_WORDLEN_12       =                  (1u),
    /**< Word Length for Frame is 16 */
    LLC_MCBSP_WORDLEN_16       =                  (2u),
    /**< Word Length for Frame is 20 */
    LLC_MCBSP_WORDLEN_20       =                  (3u),
    /**< Word Length for Frame is 24 */
    LLC_MCBSP_WORDLEN_24       =                  (4u),
    /**< Word Length for Frame is 32 */
    LLC_MCBSP_WORDLEN_32       =                  (5u)
} LLC_McbspWordLen;
/**
@} LLC_MCBSP_WORDLEN_ENUM */

/**
 * \defgroup LLC_MCBSP_FRMSYNC_ENUM Frame sync ignore status
 * \ingroup LLC_MCBSP_ENUM
 *
 * \brief Frame sync ignore status
 *
 * Use this symbol to detect or ignore frame synchronisation
 * @{
 */
typedef enum _LLC_McbspFrmSync
{
    /**< detect frame synchronisation */
    LLC_MCBSP_FRMSYNC_DETECT                  =         (0u),
    /**< ignore frame synchronisation */
    LLC_MCBSP_FRMSYNC_IGNORE                  =         (1u)
} LLC_McbspFrmSync;

typedef enum _LLC_McbspCompand
{
    /**< no companding for msb */
    LLC_MCBSP_COMPAND_OFF_MSB_FIRST =                 (0u),
    /**< no companding for lsb */
    LLC_MCBSP_COMPAND_OFF_LSB_FIRST =                 (1u),
    /**< mu-law comapanding enable for channel */
    LLC_MCBSP_COMPAND_MULAW         =                 (2u),
    /**< A-law comapanding enable for channel */
    LLC_MCBSP_COMPAND_ALAW          =                 (3u)
} LLC_McbspCompand;
/**
@} LLC_MCBSP_FRMSYNC_ENUM */

/**
 * \defgroup LLC_MCBSP_RJUSTDXENA_ENUM RJUST or DXENA settings
 * \ingroup LLC_MCBSP_ENUM
 *
 * \brief RJUST or DXENA settings
 *
 * Use this symbol for setting up RCV sign-extension and justification mode
 * or enabling/disabling XMT DX pin delay
 * @{
 */
typedef enum _LLC_McbspRjustDxena
{
    /**< RCV setting - right justify, fill MSBs with zeros */
    LLC_MCBSP_RJUSTDXENA_RJUST_RZF                 =    (0u),
    /**< RCV setting - right justify, sign-extend the data into MSBs */
    LLC_MCBSP_RJUSTDXENA_RJUST_RSE                 =    (1u),
    /**< RCV setting - left justify, fill LSBs with zeros */
    LLC_MCBSP_RJUSTDXENA_RJUST_LZF                 =    (2u)
} LLC_McbspRjustDxena;
/**
@} LLC_MCBSP_RJUSTDXENA_ENUM */

/**
 * \defgroup LLC_MCBSP_DATADELAY_ENUM Data delay
 * \ingroup LLC_MCBSP_ENUM
 *
 * \brief Data delay in bits
 *
 * Use this symbol to set XMT/RCV Data Delay (in bits)
 * @{ */
typedef enum _LLC_McbspDataDelay
{
    /**< sets XMT/RCV Data Delay is 0 */
    LLC_MCBSP_DATADELAY_0_BIT      =                 (0u),
    /**< sets XMT/RCV Data Delay is 1 */
    LLC_MCBSP_DATADELAY_1_BIT      =                 (1u),
    /**< sets XMT/RCV Data Delay is 2 */
    LLC_MCBSP_DATADELAY_2_BITS     =                 (2u)
} LLC_McbspDataDelay;
/**
@} LLC_MCBSP_DATADELAY_ENUM */

/**
 * \defgroup LLC_MCBSP_EVENT_ENUM Interrupt mode
 * \ingroup LLC_MCBSP_ENUM
 *
 * \brief MCBSP Interrupt mode
 *
 * Use this symbol to set Interrupt mode (i.e. source of interrupt generation).
 * This symbol is used on both RCV and XMT for RINT and XINT generation mode.
 * @{
 */
typedef enum _LLC_McbspIntMode
{
    /**< Interrupt generated on RRDY of RCV or XRDY of XMT */
    LLC_MCBSP_INTMODE_ON_READY         =                  (0u),
    /**< Interrupt generated on end of 16-channel block transfer
     *  in multichannel mode */
    LLC_MCBSP_INTMODE_ON_EOB           =                  (1u),
    /**< Interrupt generated on frame sync */
    LLC_MCBSP_INTMODE_ON_FSYNC         =                  (2u),
    /**< Interrupt generated on synchronisation error */
    LLC_MCBSP_INTMODE_ON_SYNCERR       =                  (3u)
} LLC_McbspIntMode;
/**
@} LLC_MCBSP_EVENT_ENUM */

/**
 * \defgroup LLC_MCBSP_BITREVERS_ENUM 32-bit Reversal
 * \ingroup LLC_MCBSP_ENUM
 *
 * \brief McBSP512 32-bit reversal feature
 *
 *
 * @{
 */
typedef enum _LLC_McbspBitReversal
{

    LLC_MCBSP_32BIT_REVERS_DISABLE  = 0,/**< 32-bit reversal disabled */
    LLC_MCBSP_32BIT_REVERS_ENABLE    = 1 /**< 32-bit reversal enabled. 32-bit
          data is received LSB first. Word length should be set for
          32-bit operation; else operation undefined  */
} LLC_McbspBitReversal;
/**
@} LLC_MCBSP_BITREVERS_ENUM */

/**
 * \defgroup LLC_MCBSP_FSCLKMODE_ENUM Frame sync clock source
 * \ingroup LLC_MCBSP_ENUM
 *
 * \brief Frame sync clock source
 *
 * Use this symbol to set the frame sync clock source as internal or external
 * @{
 */
typedef enum _LLC_McbspFsClkMode
{
    /**< frame sync clock source as internal */
    LLC_MCBSP_FSCLKMODE_EXTERNAL    =                  (0u),
    /**< frame sync clock source as external */
    LLC_MCBSP_FSCLKMODE_INTERNAL    =                  (1u)
} LLC_McbspFsClkMode;
/**
@} LLC_MCBSP_FSCLKMODE_ENUM */

/**
 * \defgroup LLC_MCBSP_CLKMODE_ENUM Clock Mode
 * \ingroup LLC_MCBSP_ENUM
 *
 * \brief Clock source
 *
 * Use this symbol to set the clock source as internal or external
 * @{
 */
typedef enum _LLC_McbspTxRxClkMode
{
    /**< clock source as internal */
    LLC_MCBSP_TXRXCLKMODE_EXTERNAL    =                  (0u),
    /**< clock source as external */
    LLC_MCBSP_TXRXCLKMODE_INTERNAL    =                  (1u)
} LLC_McbspTxRxClkMode;
/**
@} LLC_MCBSP_CLKMODE_ENUM */


/**
 * \defgroup LLC_MCBSP_FSPOLAR_ENUM Frame sync polarity
 * \ingroup LLC_MCBSP_ENUM
 *
 * \brief Frame sync polarity
 *
 * Use this symbol to set frame sync polarity as active-high or active-low
 * @{ */
typedef enum _LLC_McbspFsPol
{
    /**< frame sync polarity is active-high */
    LLC_MCBSP_FSPOL_ACTIVE_HIGH      =                  (0u),
    /**< frame sync polarity is active-low */
    LLC_MCBSP_FSPOL_ACTIVE_LOW       =                  (1u)
} LLC_McbspFsPol;
/**
@} LLC_MCBSP_FSPOLAR_ENUM */

/**
 * \defgroup LLC_MCBSP_CLKPOLAR_ENUM Clock polarity
 * \ingroup LLC_MCBSP_ENUM
 *
 * \brief Clock polarity
 *
 * Use this symbol to set XMT or RCV clock polarity as rising or falling edge
 * @{ */
typedef enum _LLC_McbspClkPol
{
    /**< XMT clock polarity is rising edge */
    LLC_MCBSP_CLKPOL_TX_RISING_EDGE      =                 (0u),
    /**< RCV clock polarity is falling edge */
    LLC_MCBSP_CLKPOL_RX_FALLING_EDGE     =                 (0u),
    /**< SRG clock polarity is rising edge */
    LLC_MCBSP_CLKPOL_SRG_RISING_EDGE     =                 (0u),
    /**< XMT clock polarity is falling edge */
    LLC_MCBSP_CLKPOL_TX_FALLING_EDGE     =                 (1u),
    /**< RCV clock polarity is rising edge */
    LLC_MCBSP_CLKPOL_RX_RISING_EDGE      =                 (1u),
    /**< SRG clock polarity Is falling edge */
    LLC_MCBSP_CLKPOL_SRG_FALLING_EDGE    =                 (1u)
} LLC_McbspClkPol;
/**
@} LLC_MCBSP_CLKPOLAR_ENUM */

/**
 * \defgroup LLC_MCBSP_SRGCLK_ENUM SRG clock source
 * \ingroup LLC_MCBSP_ENUM
 *
 * \brief SRG clock source
 *
 * Use this symbol to select input clock source for Sample Rate Generator
 * @{ */
typedef enum _LLC_McbspSrgClk
{
    /**< input clock source for Sample Rate Generator is CLKS pin */
    LLC_MCBSP_SRGCLK_CLKS                 =                  (0u),
    /**< input clock source for Sample Rate Generator is CPU */
    LLC_MCBSP_SRGCLK_CLKCPU               =                  (1u),
    /**< input clock source for Sample Rate Generator is BCLKR pin */
    LLC_MCBSP_SRGCLK_CLKR                 =                  (2u),
    /**< input clock source for Sample Rate Generator is BCLKX pin */
    LLC_MCBSP_SRGCLK_CLKX                 =                  (3u)
} LLC_McbspSrgClk;
/**
@} LLC_MCBSP_SRGCLK_ENUM */

/**
 * \defgroup LLC_MCBSP_TXFSMODE_ENUM XMT Frame Sync generation mode
 * \ingroup LLC_MCBSP_ENUM
 *
 * \brief XMT Frame Sync generation mode
 *
 * Use this symbol to set XMT Frame Sync generation mode
 * @{ */
typedef enum _LLC_McbspTxFsMode
{
    /**< Disables the frame sync generation mode */
    LLC_MCBSP_TXFSMODE_DXRCOPY  =                  (0u),
    /**< Enables the frame sync generation mode */
    LLC_MCBSP_TXFSMODE_SRG      =                  (1u)
} LLC_McbspTxFsMode;
/**
@} LLC_MCBSP_TXFSMODE_ENUM */

/**
 * \defgroup LLC_MCBSP_CHANTYPE_ENUM Channel type: TX, RX or both
 * \ingroup LLC_MCBSP_ENUM
 *
 * \brief Channel type: TX, RX ot both
 *
 * Use this symbol to select the channel type for   LLC_mcbspHwControl()
 *   LLC_MCBSP_CMD_CLEAR_FRAME_SYNC command
 * @{ */
typedef enum _LLC_McbspChType
{
    /**< Channel type is RX */
    LLC_MCBSP_CHTYPE_RX                   =             (1u),
    /**< Channel type is TX */
    LLC_MCBSP_CHTYPE_TX                   =             (2u),
    /**< Channel type is TXRX */
    LLC_MCBSP_CHTYPE_TXRX                 =             (4u)
} LLC_McbspChType;

/**
 * This is the set of control commands that are passed to
 *  LLC_mcbspHwControl()
 *
 * The arguments, if any, to be passed with each command are specified
 * next to that command.
 */
typedef enum
{
    /*<Clears frame sync error for XMT or RCV */
    LLC_MCBSP_CMD_CLEAR_FRAME_SYNC =                  0,
    /*<Configures selected MCBSP pins for Input/Output */
    LLC_MCBSP_CMD_IO_MODE_CONTROL  =                  (1u),
    /*< Resets all the registers to their power-on default values */
    LLC_MCBSP_CMD_REG_RESET        =                  (2u),
    /*< Enable/Disable - Frame Sync, Sample Rate Generator and XMT/RCV Operation */
    LLC_MCBSP_CMD_RESET_CONTROL    =                  (3u)

} LLC_McbspControlCmd;
/**
@} LLC_MCBSP_CHANTYPE_ENUM */

/**
 * This is the set of query commands to get the status of various
 * operations in MCBSP
 *
 * The arguments, if any, to be passed with each command are specified
 * next to that command. */

typedef enum _LLC_McbspHwStatusQuery
{
    /*< Queries the status of RRDY, XRDY, RFULL, XEMPTY, RSYNCERR and XSYNCERR*/
    LLC_MCBSP_QUERY_DEV_STATUS =                     (1u),
    /*< Queries XMT reset status */
    LLC_MCBSP_QUERY_TX_RST_STAT =                    (2u),
    /*< Queries RCV reset status */
    LLC_MCBSP_QUERY_RX_RST_STAT =                    (3u)
} LLC_McbspHwStatusQuery;


typedef struct  LLC_McbspConfig_t
{
    /**
     * Config structure of MCBSP. This is used to configure MCBSP
     * using CSL_HwSetupRaw function
     */
    /**< Serial Port Control Register */
    Uint32 SPCR;
    /**< Receive Control Register */
    Uint32 RCR;
    /**< Transmit Control Register */
    Uint32 XCR;
    /**< Sample Rate Generator Register */
    Uint32 SRGR;
    /**< Pin Control Register */
    Uint32 PCR;
} LLC_McbspConfig;

/**
 *\addtogroup LLC_MCBSP_DATASTRUCT
 *
 * @{
 */
/**
 * \brief Pointer to this structure is used as the third argument in
 *        LLC_mcbspHwControl() for IO mode control operations (selecting the pins
 *        to use as input and output.
 */
typedef struct _LLC_McbspIoControl
{

    /**< Pinmask to select one or more output pins */
    Uint32           outputsel;

    /**< Pinmask to select one or more input pins */
    Uint32           inputsel;

} LLC_McbspIoControl;
/**
@} LLC_MCBSP_DATASTRUCT */


typedef struct _LLC_RcvDataSetup
{

    LLC_McbspPhase          phaseNum;
    /**< Phasenumber */
    LLC_McbspWordLen        wordLength1;
    /**< wordLength1 */
    Int32                       frmLength1;
    /**< frmLength1 */
    LLC_McbspWordLen        wordLength2;
    /**< wordLength2 */
    Int32                       frmLength2;
    /**< frmLength2 */
    LLC_McbspFrmSync        frmSyncIgn;
    /**< frmSyncIgn */
    LLC_McbspCompand        compand;
    /**< comapanding */
    LLC_McbspDataDelay      dataDelay;
    /**< dataDelay */
    LLC_McbspRjustDxena     rjust_dxenable;
    /**< rjust_dxenable*/
    LLC_McbspIntMode        IntEvent;
    /**< IntEvent*/
    LLC_McbspBitReversal    wordReverse;
    /**< wordReverse*/
}LLC_RcvDataSetup;

typedef struct _LLC_XmitDataSetup
{

    LLC_McbspPhase          phaseNum;
    /**< Phasenumber */
    LLC_McbspWordLen        wordLength1;
    /**< wordLength1 */
    Uint32                  frmLength1;
    /**< frmLength1 */
    LLC_McbspWordLen        wordLength2;
    /**< wordLength2 */
    Uint32                  frmLength2;
    /**< frmLength2 */
    LLC_McbspFrmSync        frmSyncIgn;
    /**< frmSyncIgn */
    LLC_McbspCompand        compand;
    /**< comapanding */
    LLC_McbspDataDelay      dataDelay;
    /**< dataDelay */
    LLC_McbspRjustDxena     rjust_dxenable;
    /**< rjust_dxenable*/
    LLC_McbspIntMode        IntEvent;
    /**< IntEvent*/
    LLC_McbspBitReversal    wordReverse;
    /**< wordReverse*/
}LLC_XmitDataSetup;

typedef struct _LLC_mcbspClkSetup
{

    LLC_McbspFsClkMode        frmSyncTxMode;
    /**< frmSyncTxMode*/

    /** RCV frame sync mode */
    LLC_McbspFsClkMode        frmSyncRxMode;
    /**< frmSyncRxMode*/

    /** XMT clock mode */
    LLC_McbspTxRxClkMode      clkTxMode;
    /**< clkTxMode*/

    /** RCV clock mode */
    LLC_McbspTxRxClkMode      clkRxMode;
    /**< clkRxMode*/

    /** XMT frame sync polarity */
    LLC_McbspFsPol            frmSyncTxPolarity;
    /**< frmSyncTxPolarity*/

    /** RCV frame sync polarty */
    LLC_McbspFsPol            frmSyncRxPolarity;
    /**< frmSyncRxPolarity*/

    /** XMT clock polarity */
    LLC_McbspClkPol           clkTxPolarity;
    /**< clkTxPolarity*/

    /** RCV clock polarity */
    LLC_McbspClkPol           clkRxPolarity;
    /**< clkRxPolarity*/

    /** SRG frame sync pulse width */
    Uint32                    srgFrmPulseWidth;
    /**< srgFrmPulseWidth*/

    /** SRG frame sync period */
    Uint32                    srgFrmPeriod;
    /**< srgFrmPeriod*/

    /** SRG divide-down ratio */
    Uint32                    srgClkDivide;
    /**< srgClkDivide*/

    /** SRG input clock mode */
    LLC_McbspSrgClk           srgInputClkMode;
    /**< srgInputClkMode*/

    /** SRG XMT frame-synchronisatoin mode */
    LLC_McbspTxFsMode         srgTxFrmSyncMode;
    /**< srgTxFrmSyncMode*/

}LLC_mcbspClkSetup;

typedef struct _LLC_McbspBaseAddress
{
    CSL_McbspRegsOvly    regs;
    /**< reigster base address */
}LLC_McbspBaseAddress;

typedef struct _LLC_McbspHwSetup
{

    LLC_McbspDlbMode        dlbMode;
    /**< dlb mode */
    LLC_RcvDataSetup        *rxdataset;
    /**< receiver data set */
    LLC_XmitDataSetup       *txdataset;
    /**< transmitter data set */
    LLC_mcbspClkSetup       *clkset;
    /**< clock setting*/
    LLC_McbspEmu            emumode;
    /**< emulation mode */
    LLC_McbspDxState        dxState;
    /**< dxState*/
    void                    *extendSetup;
    /**< miscellenous parameter*/
}LLC_McbspHwSetup;

/**  \addtogroup LLC_MCBSP_DATASTRUCT
*
* @{ */
/**
 * /brief This structure/object holds the context of the instance of MCBSP
 * opened using   LLC_mcbspOpen() function.
 *
 * Pointer to this object is passed as MCBSP Handle to all MCBSP LLC APIs.
 *
 * parameters passed
 */
typedef struct _LLC_McbspObj
{
    /**< Pointer to the register overlay structure of the MCBSP */
    CSL_McbspRegsOvly    regs;

    /**< Instance of MCBSP being referred by this object  */
    Uint32          perNum;

    /* edma Transmit event number                         */
    Uint32          edmaTxEventNum;

    /* edma Receive event number                          */
    Uint32          edmaRxEventNum;

    /**< Transmit interrupt number                        */
    Uint32          cpuTxEventNum;

    /**< Transmit interrupt number                        */
    Uint32          cpuRxEventNum;


} LLC_McbspObj;

/** /brief This is a pointer to   LLC_McbspObj and is passed as the first
 * parameter to all MCBSP CSL APIs
 */
typedef struct _LLC_McbspObj *LLC_McbspHandle;
/**
@} LLC_MCBSP_DATASTRUCT */
#ifdef __cplusplus
}
#endif

#endif /* _LLC_MCBSPTYPES_H */
