/*******************************************************************************
**+--------------------------------------------------------------------------+**
**|                            ****                                          |**
**|                            ****                                          |**
**|                            ******o***                                    |**
**|                      ********_///_****                                   |**
**|                      ***** /_//_/ ****                                   |**
**|                       ** ** (__/ ****                                    |**
**|                           *********                                      |**
**|                            ****                                          |**
**|                            ***                                           |**
**|                                                                          |**
**|         Copyright (c) 2006-2010 Texas Instruments Incorporated           |**
**|                        ALL RIGHTS RESERVED                               |**
**|                                                                          |**
**| Permission is hereby granted to licensees of Texas Instruments           |**
**| Incorporated (TI) products to use this computer program for the sole     |**
**| purpose of implementing a licensee product based on TI products.         |**
**| No other rights to reproduce, use, or disseminate this computer          |**
**| program, whether in part or in whole, are granted.                       |**
**|                                                                          |**
**| TI makes no representation or warranties with respect to the             |**
**| performance of this computer program, and specifically disclaims         |**
**| any responsibility for any damages, special or consequential,            |**
**| connected with the use of this program.                                  |**
**|                                                                          |**
**+--------------------------------------------------------------------------+**
*******************************************************************************/
/**
 *  \file   psp_previewer.h
 *
 *  \brief  64LC previewer interface definition
 *
 *  This file contains the interfaces, data types and symbolic definitions
 *  that will be utilize by application and CCDC to utilize the serivces of
 *  64LC previewer.
 *
 *  (C) Copyright 2010, Texas Instruments, Inc
 *
 *
 *  \author     EI2
 *
 *  \version    0.1             Created
 *              1.0             First Release
 *
 *  <b>Compiler Switch Used</b>
 *
 *  <b>_DEBUG</b><br>
 *    This is used as a flag to compiler whether to include the debug statements
 *    inserted in the code into the final image. This flag helps to build DEBUG
 *    image of the program. For RELEASE images this is not passed to the compiler.
 *
 *  <b>CHIP_XXXX</b><br>
 *    The CSL layer is written in a common file for all the variants of a SOC.
 *    This flag differentiates the variant we are compiling for, for eg 
 *    CHIP_DM648, and the CSL definitions for that variant appropriately gets
 *    defined for regs base addresses, num of ports of a peripheral etc.
 *
 *  <b>PREVIEWER_DEBUG</b><br>
 *    All these macros are used to the select the debug statements included in
 *    the image/lib. The level of detailing differs with each macro.
 *
 *  <b>DDA_PREVIEWER_DEBUG_PRINTF</b><br>
 *    They are the macros used to print debug messages. These expand to NULL
 *    or a valid print statement depending on the definitions mention above.
 *
 *  <b>DDA_PREVIEWER_DEBUG_ALL_TRACE</b><br>
 *    All these macros are used to the select the debug statements included
 *    in the image/lib. The level of detailing differs with each macro.
 *
 *  <b>DDC_PREVIEWER_DEBUG_PRINTF</b><br>
 *    They are the macros used to print debug messages. These expand to NULL
 *    or a valid print statement depending on the definitions mention above.
 *
 *  <b>DDC_PREVIEWER_DEBUG_ALL_TRACE</b><br>
 *    All these macros are used to the select the debug statements included in
 *    the image/lib. The level of detailing differs with each macro
 *
 *  <b>PREV_INSTRUMENTATION_ENABLED</b><br>
 *    This flag is passed to the compiler to include the instrumentation code
 *    parts into the final image/lib of the program. This helps build the
 *    iRelease/iDebug versions of the image/lib with a common code base
 *
 */

#ifndef _PSP_PREVIEWER_H
#define _PSP_PREVIEWER_H
/******************************************************************************
  Header File Inclusion
 ******************************************************************************/
#include <ti/sdo/pspdrivers/soc/dm6437/dsp/tistdtypes.h>
#include <std.h>
#include <gio.h>
#include <ti/sdo/pspdrivers/common/psp_common.h>

#ifdef __cplusplus
extern "C" {
#endif

/******************************************************************************
  Macros
 ******************************************************************************/

/* Previewer Feature lists */
#define PSP_PREVIEWER_INVERSE_ALAW          ((Uint32)0x0002u)
#define PSP_PREVIEWER_HMF                   ((Uint32)0x0004u)
#define PSP_PREVIEWER_NOISE_FILTER          ((Uint32)0x0008u)
#define PSP_PREVIEWER_CFA                   ((Uint32)0x0010u)
#define PSP_PREVIEWER_GAMMA                 ((Uint32)0x0020u)
#define PSP_PREVIEWER_LUMA_ENHANCE          ((Uint32)0x0040u)
#define PSP_PREVIEWER_CHROMA_SUPPRESS       ((Uint32)0x0080u)
#define PSP_PREVIEWER_DARK_FRAME_SUBTRACT   ((Uint32)0x0100u)
#define PSP_PREVIEWER_LENS_SHADING          ((Uint32)0x0200u)



/* down sampling rate */
#define PSP_PREVIEWER_DOWN_SAMPLE_RATE1       ((Uint8)1u)
#define PSP_PREVIEWER_DOWN_SAMPLE_RATE2       ((Uint8)2u)
#define PSP_PREVIEWER_DOWN_SAMPLE_RATE4       ((Uint8)4u)
#define PSP_PREVIEWER_DOWN_SAMPLE_RATE8       ((Uint8)8u)

/* table size for different modules */
#define PSP_PREVIEWER_LUMA_TABLE_SIZE            128
#define PSP_PREVIEWER_GAMMA_TABLE_SIZE           1024
#define PSP_PREVIEWER_CFA_COEFF_TABLE_SIZE       576
#define PSP_PREVIEWER_NOISE_FILTER_TABLE_SIZE    256

/* number of coefficients for while balanced gain */
#define PSP_PREVIEWER_WB_GAIN_MAX     4u
/* matrix size for RGB2RGB blending */
#define PSP_PREVIEWER_RGB_MAX         3u
/* max image width in pixels */
#define PSP_PREVIEWER_MAX_IMAGE_WIDTH   1280u
/* max image height in pixels */
#define PSP_PREVIEWER_MAX_IMAGE_HEIGHT  1920u
/* previewer source */
#define PSP_PREVIEWER_CHANNEL_CCDC       ((Uint8)0u)
#define PSP_PREVIEWER_CHANNEL_SDRAM      ((Uint8)1u)

/* pixel width of 8 bits */
#define PSP_PREVIEWER_INWIDTH_8BIT   ((Uint8)0u)
/* pixel width of 10 bits */
#define PSP_PREVIEWER_INWIDTH_10BIT  ((Uint8)1u)

/* previewer channel busy status */
#define PSP_PREVIEWER_CHANNEL_FREE     ((Uint8)0u)
#define PSP_PREVIEWER_CHANNEL_BUSY     ((Uint8)1u)

/* previewer dark frame subtract failure status */
#define PSP_PREVIEWER_DARK_FRAME_FAILED     ((Uint8)0u)
#define PSP_PREVIEWER_DARK_FRAME_WORKING    ((Uint8)1u)


/* dark frame capture feature state */
#define PSP_PREVIEWER_DARK_FRAME_CAPTURE_DISABLE ((Uint8)0u)
#define PSP_PREVIEWER_DARK_FRAME_CAPTURE_ENABLE ((Uint8)1u)

/******************************************************************************
  Enumerations
 ******************************************************************************/

/**
 * \brief PSP_previewerControlCmd
 *
 * enum for IOCTL commands. Here they are used as cmd parameter to
 * GIO_control_channel API.
 */
typedef enum _PSP_previewerControlCmd
{
    PSP_PREVIEWER_IOCTL_MIN = IOM_USER - 1,
    /**< MIN Value for IOCTLs, used for internal checking */
    PSP_PREVIEWER_IOCTL_SET_PARAMS,
    /**< To set PSP_previewerParams parameters */
    PSP_PREVIEWER_IOCTL_GET_PARAMS,
    /**< To get PSP_previewerParams parameters */
    PSP_PREVIEWER_IOCTL_GET_STATUS,
    /**< To get the status of channel */
    PSP_PREVIEWER_IOCTL_GET_DARK_FRAME_STATUS,
    /**< To get dark frame subtract fail status */
    PSP_PREVIEWER_IOCTL_PREVIEW,
    /**< To trigger previewer when source is SDRAM */
    PSP_PREVIEWER_IOCTL_GET_CROPSIZE,
    /**< To get crop size */
    PSP_PREVIEWER_IOCTL_SET_EXP,
    /**< To set read request expand */
    PSP_PREVIEWER_GET_INFO_FOR_CCDC,
    /**< To get the information required for CCDC continous mode */
    PSP_PREVIEWER_SET_DARK_FRAME_CAPTURE,
    /**< To enable/disable dark frame capture feature */
    PSP_PREVIEWER_GET_DARK_FRAME_CAPTURE,
    /**< To get current dark frame capture feature state */
    PSP_PREVIEWER_IOCTL_SET_SEM_TIMEOUT,
    /**< Change the timeout value used in semaphore pending operation.
         Command Argument:  Timeout values<Int32>                           */
    PSP_PREVIEWER_IOCTL_MAX
    /**< MAX Value for IOCTLs, used for internal checking */
}PSP_previewerControlCmd;

/**
 * \brief PSP_previewerOutPixelOrder
 *
 * enum data type for output pixel order
 */
typedef enum _PSP_previewerOutPixelOrder
{
    PSP_PREVIEWER_PIXELORDER_YCBYCR,
    /**< LSB Y0 Cb0 Y1 Cr0 MSB */
    PSP_PREVIEWER_PIXELORDER_YCRYCB,
    /**< LSB Y0 Cr0 Y1 Cb0 MSB */
    PSP_PREVIEWER_PIXELORDER_CBYCRY,
    /**< LSB Cb0 Y0 Cr0 Y1 MSB */
    PSP_PREVIEWER_PIXELORDER_CRYCBY
        /**< LSB Cr0 Y0 Cb0 Y1 MSB */
}PSP_previewerOutPixelOrder;


/******************************************************************************
  Data-Structures
 ******************************************************************************/

/**
 * \brief PSP_previewerChannelSource
 *
 * This structure is used as a member element of _PSP_previewerChannelCreateMode
 * strcture.
 */
typedef struct _PSP_previewerChannelSource
{
    Uint8 source;
    /**< Value: PSP_PREVIEWER_CHANNEL_CCDC or PSP_PREVIEWER_CHANNEL_SDRAM */
}PSP_previewerChannelSource;

/**
 * \brief PSP_previewerChannelCreateMode
 *
 * This strcture is filled at the time of channel creation.
 */
typedef struct _PSP_previewerChannelCreateMode
{
    PSP_previewerChannelSource chanSource;
    /**< Channel Source */
    Int32 segId;
    /**< Segment Id passed by applicaion, will be used to allocate memory */

}PSP_previewerChannelCreateMode;


/**
 * \brief PSP_previewerGetInfoForCCDC
 *
 * This strcuture is used to get an info of previwer,required by CCDC.\n
 * This structure is passed as an argument when ioctl is:\n
 * 1. PSP_PREVIEWER_GET_INFO_FOR_CCDC : as an output parameter.
 */
typedef struct _PSP_previewerGetInfoForCCDC
{
    Uint8 source;
    /**< Inetrrupt source */
    Uint8 intNo;
    /**< Interrupt number */
}PSP_previewerGetInfoForCCDC;



/**
 * \brief PSP_previewerSize
 *
 * This structure contains size parameters of previewer.
 */
typedef struct _PSP_previewerSize
{
    Uint16  inPitch;
    /**< Line Offset of Input Image - used when source is SDRAM */
    Uint16  outPitch;
    /**< Line Offset of Output Image */

    Uint16 sph;
    /**< Start Pixel Horizontal */
    Uint16 eph;
    /**< End Pixel Horizontal */

    Uint16 slv;
    /**< Start Line Vertical */
    Uint16 elv;
    /**< End Line Vertical */

    Uint8   pixelSize;
    /**< Pixel size value can be PSP_PREVIEWER_INWIDTH_8BIT or
         PSP_PREVIEWER_INWIDTH_10BIT - used when source is SDRAM */
}PSP_previewerSize;

/**
 * \brief PSP_previewerWhiteBalance
 *
 * This structure contains white balance parameters of previewer.
 */
typedef struct _PSP_previewerWhiteBalance
{
    Uint8    position[PSP_PREVIEWER_WB_GAIN_MAX][PSP_PREVIEWER_WB_GAIN_MAX];
    /**< white Balance Co-efficient selection values */
    Uint16  wbDgain;
    /**< White Balance Common(Digital) Gain */
    Uint8  wbGain[PSP_PREVIEWER_WB_GAIN_MAX];
    /**< Individual Color Gains */

}PSP_previewerWhiteBalance;

/**
 * \brief PSP_previewerBlackAdj
 *
 * This structure contains Black Adjustment parameters.
 */
typedef struct _PSP_previewerBlackAdj
{
    Int8 redAdj;
    /**< Black Adjustment Offset for Red Color */
    Int8 greenAdj;
    /**< Black Adjustment Offset for Green Color */
    Int8 blueAdj;
    /**< Black Adjustment Offset for Blue Color */

}PSP_previewerBlackAdj;

/**
 * \brief PSP_previewerRgbBlending
 *
 * This structure contains RGB2RGB blending parameters of previewer.
 */
typedef struct _PSP_previewerRgbBlending
{
    Uint16 blending[PSP_PREVIEWER_RGB_MAX][PSP_PREVIEWER_RGB_MAX];
    /**< Color Correlation 3x3 matrix */
    Int16 offset[PSP_PREVIEWER_RGB_MAX];
    /**< Color Correlation offsets */
}PSP_previewerRgbBlending;

/**
 * \brief PSP_previewerRgb2ycbcrCoeffs
 *
 * This structure contains RGB to YCbCr conversion parameters of previewer.
 */
typedef struct _PSP_previewerRgb2ycbcrCoeffs
{
    Uint16 coeff[PSP_PREVIEWER_RGB_MAX][PSP_PREVIEWER_RGB_MAX];
    /**< Color Conversion Gains in 3x3 matrix */
    Uint16 yOffset;
    /**< Y Color Conversion Offsets */
    Int8 cbOffset;
    /**< Cb Color Conversion Offsets */
    Int8 crOffset;
    /**< Cr Color Conversion Offsets */
}PSP_previewerRgb2ycbcrCoeffs;

/**
 * \brief PSP_previewerCfaCoeffs
 *
 * This structure contains CFA interpolation parameters of previewer.
 */
typedef struct _PSP_previewerCfaCoeffs
{
    Uint8    hThreshold;
    /**< Horizontal Threshold */
    Uint8    vThreshold;
    /**< Vertical Threshold */

    Int32 coeffs[PSP_PREVIEWER_CFA_COEFF_TABLE_SIZE];
    /**< cfa coefficients */
}PSP_previewerCfaCoeffs;

/**
 * \brief PSP_previewerCfaCoeffs
 *
 * This structure contains Gamma correction parameters of previewer.
 */
typedef struct _PSP_previewerGammaCoeffs
{
    Uint8 red[PSP_PREVIEWER_GAMMA_TABLE_SIZE];
    /**< Table of Gamma Correction  values for Red */
    Uint8 green[PSP_PREVIEWER_GAMMA_TABLE_SIZE];
    /**< Table of Gamma Correction  values for green */
    Uint8 blue[PSP_PREVIEWER_GAMMA_TABLE_SIZE];
    /**< Table of Gamma Correction  values for Blue */
}PSP_previewerGammaCoeffs;

/**
 * \brief PSP_previewerNoiseFilterCoeffs
 *
 * This structure contains Noise filter parameters of previewer.
 */
typedef struct _PSP_previewerNoiseFilterCoeffs
{
    Uint8 noise[PSP_PREVIEWER_NOISE_FILTER_TABLE_SIZE];
    /**< Noise Filter Table */

    Uint8 strength;
    /**< Weighted Average */
}PSP_previewerNoiseFilterCoeffs;

/**
 * \brief PSP_previewerChromaSuppression
 *
 * This structure contains Chroma Suppression parameters of previewer.
 */
typedef struct _PSP_previewerChromaSuppression
{
    Uint8 hpfy;
    /**< Decision Factor for High Passed Version of Y or normal Y */
    Int8 threshold;
    /**< Threshold for Chroma Suppress */
    Uint8 gain;
    /**< Chroma Suppression Gain */

}PSP_previewerChromaSuppression;


/**
 * \brief PSP_previewerParams
 *
 * This structure contains all configuration detail for all type of
 * configuration.\n
 * This structure is passed as an argument when ioctl is:\n
 * 1. PSP_PREVIEWER_IOCTL_SET_PARAMS : as an input parameter.\n
 * 2. PSP_PREVIEWER_IOCTL_GET_PARAMS : as an output parameter.\n
 * 3. PSP_PREVIEWER_IOCTL_VALIDATE_PARAMS : as an input parameter.
 */
typedef struct _PSP_previewerParams
{
    Uint32                         features;
    /**< Set of Features Enabled */
    PSP_previewerSize              sizeParam;
    /**< Size Parameters */
    PSP_previewerWhiteBalance      whiteBalanceParam;
    /**< White Balancing Parameters */
    PSP_previewerBlackAdj          blackAdjParam;
    /**< Black Adjustment Parameters */
    PSP_previewerRgbBlending       rgbBlendingParam;
    /**< RGB Blending Parameters */
    PSP_previewerRgb2ycbcrCoeffs   rgb2ycbcrParam;
    /**< RGB to YCbCr Parameters */
    PSP_previewerCfaCoeffs         cfaCoeffsParam;
    /**< CFA Coefficients */
    PSP_previewerGammaCoeffs       gammaCoeffsParam;
    /**< Gamma Coefficients */
    PSP_previewerNoiseFilterCoeffs noiseFilterCoeffsParam;
    /**< Noise Filter Coefficients */
    PSP_previewerChromaSuppression chromaSuppressionParam;
    /**< Chroma Suppression Coefficients */
    PSP_previewerOutPixelOrder     outPixelOrderParam;
    /**< Output Pixel Format */
    Uint32                         lumaEnhance[PSP_PREVIEWER_LUMA_TABLE_SIZE];
    /**< Luma Enhancement Coeffs */
    Ptr                            darkFrameAddr;
    /**< Dark Frame Address */
    Uint16                         darkFrameOffset;
    /**< Dark Frame Offset */
    Int16                          hmfThreshold;
    /**< Horizontal Median Filter Threshold */
    Uint8                           contrast;
    /**< Contrast */
    Uint8                           brightness;
    /**< Brightness */
    Uint8                          downSampleRate;
    /**< Down Sampling Rate for Averager */
    Uint8                          lensShadingShift;
    /**< Number of bits to be shifted for Lens Shading */

}PSP_previewerParams;

/**
 * \brief PSP_previewerStatus
 *
 * This structure is used to know status of the channel.\n
 * This structure is passed as an argument when ioctl is:\n
 * 1. PSP_PREVIEWER_IOCTL_GET_STATUS : as an output parameter.
 */
typedef struct _PSP_previewerStatus
{
    Uint8 channelStatus;
    /**< value can be PSP_PREVIEWER_CHANNEL_BUSY or
      PSP_PREVIEWER_CHANNEL_FREE */
}PSP_previewerStatus;

/**
 * \brief PSP_previewerDarkFrameStatus
 *
 * This structure is used to know dark frame failure status.\n
 * This structure is passed as an argument when ioctl is:\n
 * 1. PSP_PREVIEWER_IOCTL_GET_DARK_FRAME_STATUS : as an output parameter.
 */
typedef struct _PSP_previewerDarkFrameStatus
{
    Uint8 status;
    /**< value can be PSP_PREVIEWER_DARK_FRAME_FAILED
      or PSP_PREVIEWER_DARK_FRAME_WORKING */
}PSP_previewerDarkFrameStatus;

/**
 * \brief PSP_preview
 *
 * This structure is used to trigger previewer when source is SDRAM.\n
 * This structure is passed as an argument when ioctl is:\n
 * 1. PSP_PREVIEWER_IOCTL_PREVIEW : as an input parameter.
 */
typedef struct _PSP_preview
{
    Ptr inBuf;
    /**< Address of the Input Buffer */
    Ptr outBuf;
    /**< Address of the Output Buffer */
    Int32 inBufSize;
    /**< Input Buffer Size */
    Int32 outBufSize;
    /**< Output Buffer Size */
}PSP_preview;

/**
 * \brief PSP_previewerCropSize
 *
 * This structure contains crop size parameters of previewer.\n
 * This structure is passed as an argument when ioctl is:\n
 * 1. PSP_PREVIEWER_IOCTL_GET_CROPSIZE : as an output parameter.
 */
typedef struct _PSP_previewerCropSize
{
    Int32 hCrop;
    /**< Horizontal Crop Size */
    Int32 vCrop;
    /**< Vertical Crop Size */
}PSP_previewerCropSize;

/**
 * \brief PSP_previewerReadReqExp
 *
 * This structure is used to set read request expand value of previewer.\n
 * This structure is passed as an argument when ioctl is:\n
 * 1. PSP_PREVIEWER_IOCTL_SET_EXP : as an input parameter.
 */
typedef struct _PSP_previewerReadReqExp
{
    Int16 prevExp;
    /**< Previewer Read Request Expand value */
}PSP_previewerReadReqExp;

/**
 * \brief _PSP_previewerDarkFrameCapture
 *
 * This structure is used to get/set dark frame capture feature.\n
 * This structure is passed as an argument when ioctl is:\n
 * 1. PSP_PREVIEWER_SET_DARK_FRAME_CAPTURE : as an input parameter.\n
 * 2. PSP_PREVIEWER_GET_DARK_FRAME_CAPTURE : as an output parameter.\n
 */
typedef struct _PSP_previewerDarkFrameCapture
{
    Uint8 darkFrameState;
    /**< Value can be PSP_PREVIEWER_DARK_FRAME_CAPTURE_DISABLE or
     PSP_PREVIEWER_DARK_FRAME_CAPTURE_ENABLE  */
    Uint16 outPitch;
    /**< offset in dark image for each row. Value is only relevant when
     flag is PSP_PREVIEWER_DARK_FRAME_CAPTURE_ENABLE */
}PSP_previewerDarkFrameCapture;

/**
 * \brief PREVMD_FXNS
 *
 * This is used by application as function table pointer.
 */
    extern far IOM_Fxns PREVMD_FXNS;
#ifdef __cplusplus
}
#endif /* extern "C" */

#endif /* End of _PSP_PREVIEWER_H */

