/*******************************************************************************
**+--------------------------------------------------------------------------+**
**|                            ****                                          |**
**|                            ****                                          |**
**|                            ******o***                                    |**
**|                      ********_///_****                                   |**
**|                      ***** /_//_/ ****                                   |**
**|                       ** ** (__/ ****                                    |**
**|                           *********                                      |**
**|                            ****                                          |**
**|                            ***                                           |**
**|                                                                          |**
**|         Copyright (c) 2006-2010 Texas Instruments Incorporated           |**
**|                        ALL RIGHTS RESERVED                               |**
**|                                                                          |**
**| Permission is hereby granted to licensees of Texas Instruments           |**
**| Incorporated (TI) products to use this computer program for the sole     |**
**| purpose of implementing a licensee product based on TI products.         |**
**| No other rights to reproduce, use, or disseminate this computer          |**
**| program, whether in part or in whole, are granted.                       |**
**|                                                                          |**
**| TI makes no representation or warranties with respect to the             |**
**| performance of this computer program, and specifically disclaims         |**
**| any responsibility for any damages, special or consequential,            |**
**| connected with the use of this program.                                  |**
**|                                                                          |**
**+--------------------------------------------------------------------------+**
*******************************************************************************/
/**
 *  \file   dda_previewer.h
 *
 *  \brief  DDA header file for Previewer
 *
 *  This file contains the interfaces, data types and symbolic definitions at
 *  DDA layer, which are needed by DDA/DDC layer source files.
 *
 *  (C) Copyright 2010, Texas Instruments, Inc
 *
 *  \author     EI2
 *
 *  \version    0.1             Created
 *              1.0             First Release
 */


#ifndef _DDA_PREVIEWER_H
#define _DDA_PREVIEWER_H

/******************************************************************************
  Header File Inclusion
 ******************************************************************************/
#include <ti/sdo/pspdrivers/soc/dm6437/dsp/tistdtypes.h>
#include <std.h>
#include <ecm.h>
#include <ti/sdo/pspdrivers/common/psp_common.h>

#include <ti/sdo/pspdrivers/drivers/previewer/psp_previewer.h>
#include <ti/sdo/pspdrivers/drivers/previewer/src/ddc_previewer.h>

#ifdef __cplusplus
extern "C" {
#endif

/******************************************************************************
  Macros
 ******************************************************************************/

/**< Previewer Device State */
#define DDA_PREVIEWER_DEVICE_CREATED   ((Uint32)0u)
#define DDA_PREVIEWER_DEVICE_DELETED   ((Uint32)1u)


/******************************************************************************
  Data-Structures
 ******************************************************************************/

struct _DDA_prevChannelObject;

/**
 * \brief DDA_prevPortObject
 *
 * This structure is filled at the time of device binding.
 */
typedef struct _DDA_prevPortObject
{
    struct _DDA_prevChannelObject* channelHandle;
    /**< channel handle at DDA layer */
    Uint32 state;
    /**< state of device at DDC layer - values can be
      DDA_PREVIEWER_DEVICE_CREATED or DDA_PREVIEWER_DEVICE_DELETED */
    PSP_Handle ddcDeviceHandle;
    /**< device handle at DDC layer */
}DDA_prevPortObject, *DDA_prevPortHandle;

/**
 * \brief DDA_prevChannelObject
 *
 *  It is initialised at the time of channel creation.
 */
typedef struct _DDA_prevChannelObject
{
    DDA_prevPortHandle portHandle;
    /**< handle of port structure for back tracking */
    PSP_Handle ddcChannelHandle;
    /**< channel handle at DDC layer */
}DDA_prevChannelObject, *DDA_prevChannelHandle;


/******************************************************************************
  BIOS SPECIFIC FUNCTIONS
 ******************************************************************************/

/**
 * \brief PREV_mdBindDev
 *
 * It binds previewer device.
 *
 *  \param  devp       [OUT]   previewer port structure
 *  \param  devid      [IN]    device instance id - will be ignored in case of
 *                             previewer.
 *  \param  devParams  [IN]    device parameters structure - contains version
 *                             Id of driver.
 *  return  success            IOM_COMPLETED
 *          failure            IOM error code
 */
Int PREV_mdBindDev(Ptr *devp, Int devid, Ptr devParams);



/**
 * \brief PREV_mdCreateChan
 *
 * It creates previewer channel.
 *
 *  \param  chanp    [OUT]      previewer channel structure
 *  \param  devp     [IN/OUT]   previewer port structure
 *  \param  name     [IN]    name of hardware - will be ignored in case of
 *                             previewer.
 *  \param  mode     [IN]    IOM channel mode - will be IOM_INOUT.
 *  \param  chanParams  [IN]    channel specific parameters.
 *  \param  cbFxn  [IN]      call back function - will be ignored in case of
 *                           previewer.
 *  \param  cbArg  [IN]      call back function arguments - will be ignored
 *                           in case of previewer.
 *  return  success            IOM_COMPLETED
 *          failure            IOM error code
 */
Int PREV_mdCreateChan(Ptr *chanp, Ptr devp, String name, Int mode,
    Ptr chanParams, IOM_TiomCallback cbFxn, Ptr cbArg);



/**
 * \brief PREV_mdControlChan
 *
 * It is used to control previewer channel.
 *
 *  \param  chanp    [IN]      previewer channel structure
 *  \param  cmd      [IN]      previewer channel ioctl command
 *  \param  arg      [IN/OUT]  previewer ioctl command arguments
 *  return  success            IOM_COMPLETED
 *          failure            IOM error code
 */
Int PREV_mdControlChan(Ptr chanp, Uns cmd, Ptr arg);


/**
 * \brief PREV_mdDeleteChan
 *
 * It is used to delete previewer channel.
 *
 *  \param  chanp    [IN]      previewer channel structure
 *  return  success            IOM_COMPLETED
 *          failure            IOM error code
 */
Int PREV_mdDeleteChan(Ptr chanp);

/**
 * \brief PREV_mdUnBindDev
 *
 * It is used to unbind previewer device.
 *
 *  \param  devp    [IN]      previewer port structure
 *  return  success            IOM_COMPLETED
 *          failure            IOM error code
 */
Int PREV_mdUnBindDev(Ptr devp);
#ifdef __cplusplus
}
#endif

#endif /* End of _DDA_PREVIEWER_H */
