/*******************************************************************************
**+--------------------------------------------------------------------------+**
**|                            ****                                          |**
**|                            ****                                          |**
**|                            ******o***                                    |**
**|                      ********_///_****                                   |**
**|                      ***** /_//_/ ****                                   |**
**|                       ** ** (__/ ****                                    |**
**|                           *********                                      |**
**|                            ****                                          |**
**|                            ***                                           |**
**|                                                                          |**
**|         Copyright (c) 2006-2010 Texas Instruments Incorporated           |**
**|                        ALL RIGHTS RESERVED                               |**
**|                                                                          |**
**| Permission is hereby granted to licensees of Texas Instruments           |**
**| Incorporated (TI) products to use this computer program for the sole     |**
**| purpose of implementing a licensee product based on TI products.         |**
**| No other rights to reproduce, use, or disseminate this computer          |**
**| program, whether in part or in whole, are granted.                       |**
**|                                                                          |**
**| TI makes no representation or warranties with respect to the             |**
**| performance of this computer program, and specifically disclaims         |**
**| any responsibility for any damages, special or consequential,            |**
**| connected with the use of this program.                                  |**
**|                                                                          |**
**+--------------------------------------------------------------------------+**
*******************************************************************************/

/**
 *  \file   llc_previewer.c
 *
 *  \brief  Peviewer LLC layer Function dependencies
 *
 *  This file contains the implementation of LLC layer of the previewer driver.
 *
 *  (C) Copyright 2010, Texas Instruments, Inc
 *
 *
 *  \author     EI2
 *
 *  \version    0.1             Created
 *              1.0             First Release
 */

/******************************************************************************
  Header File Inclusion
 ******************************************************************************/
#include <std.h>
#include <ti/sdo/pspdrivers/common/psp_common.h>

#include <ti/sdo/pspdrivers/drivers/previewer/psp_previewer.h>
#include <ti/sdo/pspdrivers/drivers/previewer/src/llc_previewer.h>

#include <ti/sdo/pspdrivers/soc/dm6437/dsp/cslr.h>
#include <ti/sdo/pspdrivers/soc/dm6437/dsp/tistdtypes.h>
#include <ti/sdo/pspdrivers/soc/dm6437/dsp/soc.h>
#include <ti/sdo/pspdrivers/soc/dm6437/dsp/cslr_prev.h>
#include <ti/sdo/pspdrivers/soc/dm6437/dsp/csl_types.h>
#include <ti/sdo/pspdrivers/soc/dm6437/dsp/csl_error.h>
#include <ti/sdo/pspdrivers/soc/dm6437/dsp/cslr_vpss.h>

/******************************************************************************
  Data-Structures
 ******************************************************************************/
/**
 * \brief to access previewer registers
 */
CSL_PrevRegsOvly prevRegs;

/**
 * \brief to access vpss registers
 */
CSL_VpssRegsOvly vpssRegs;

#ifdef PREVIEWER_DEBUG
Uint32 llcPrevDebugErrorStatus = 0;
#endif /* PREVIEWER_DEBUG */

/******************************************************************************
  Functions
 ******************************************************************************/

/**
 *  LLC_prevResetPreviewer
 *  It will reset all register values in previewer.
 */
CSL_Status LLC_prevResetPreviewer(Ptr regs)
{
    CSL_Status resetPrevReturnCode = CSL_ESYS_INVPARAMS;

    /* parameter validation */
    if (NULL == regs)
    {
        resetPrevReturnCode = CSL_ESYS_INVPARAMS;
    }
    else
    {
        prevRegs = (CSL_PrevRegsOvly)regs;
        prevRegs->PCR = (Uint32)CSL_PREV_PCR_RESETVAL;
        prevRegs->HORZ_INFO = (Uint32)CSL_PREV_HORZ_INFO_RESETVAL;
        prevRegs->VERT_INFO = (Uint32)CSL_PREV_VERT_INFO_RESETVAL;
        prevRegs->RSDR_ADDR = (Uint32)CSL_PREV_RSDR_ADDR_RESETVAL;
        prevRegs->RADR_OFFSET = (Uint32)CSL_PREV_RADR_OFFSET_RESETVAL;
        prevRegs->DSDR_ADDR = (Uint32)CSL_PREV_DSDR_ADDR_RESETVAL;
        prevRegs->DRKF_OFFSET = (Uint32)CSL_PREV_DRKF_OFFSET_RESETVAL;
        prevRegs->WSDR_ADDR = (Uint32)CSL_PREV_WSDR_ADDR_RESETVAL;
        prevRegs->WADD_OFFSET = (Uint32)CSL_PREV_WADD_OFFSET_RESETVAL;
        prevRegs->AVE = (Uint32)CSL_PREV_AVE_RESETVAL;
        prevRegs->HMED = (Uint32)CSL_PREV_HMED_RESETVAL;
        prevRegs->NF = (Uint32)CSL_PREV_NF_RESETVAL;
        prevRegs->WB_DGAIN = (Uint32)CSL_PREV_WB_DGAIN_RESETVAL;
        prevRegs->WBGAIN = (Uint32)CSL_PREV_WBGAIN_RESETVAL;
        prevRegs->WBSEL = (Uint32)CSL_PREV_WBSEL_RESETVAL;
        prevRegs->CFA = (Uint32)CSL_PREV_CFA_RESETVAL;
        prevRegs->BLKADJOFF = (Uint32)CSL_PREV_BLKADJOFF_RESETVAL;
        prevRegs->RGB_MAT1 = (Uint32)CSL_PREV_RGB_MAT1_RESETVAL;
        prevRegs->RGB_MAT2 = (Uint32)CSL_PREV_RGB_MAT2_RESETVAL;
        prevRegs->RGB_MAT3 = (Uint32)CSL_PREV_RGB_MAT3_RESETVAL;
        prevRegs->RGB_MAT4 = (Uint32)CSL_PREV_RGB_MAT4_RESETVAL;
        prevRegs->RGB_MAT5 = (Uint32)CSL_PREV_RGB_MAT5_RESETVAL;
        prevRegs->RGB_OFF1 = (Uint32)CSL_PREV_RGB_OFF1_RESETVAL;
        prevRegs->RGB_OFF2 = (Uint32)CSL_PREV_RGB_OFF2_RESETVAL;
        prevRegs->CSC0 = (Uint32)CSL_PREV_CSC0_RESETVAL;
        prevRegs->CSC1 = (Uint32)CSL_PREV_CSC1_RESETVAL;
        prevRegs->CSC2 = (Uint32)CSL_PREV_CSC2_RESETVAL;
        prevRegs->CSC_OFFSET = (Uint32)CSL_PREV_CSC_OFFSET_RESETVAL;
        prevRegs->CNT_BRT = (Uint32)CSL_PREV_CNT_BRT_RESETVAL;
        prevRegs->CSUP = (Uint32)CSL_PREV_CSUP_RESETVAL;
        prevRegs->SETUP_YC = (Uint32)CSL_PREV_SETUP_YC_RESETVAL;

        resetPrevReturnCode = CSL_SOK;
    }
    return resetPrevReturnCode;
}



/**
 *  LLC_prevHardwareSetup
 *  It configure previewer parameters in previewer registers.
 */
CSL_Status LLC_prevHardwareSetup(
    PSP_previewerChannelCreateMode *prevChannelCreateMode,
    PSP_previewerParams *prevConfigParams,
    Ptr regs
    )
{
    CSL_Status hwSetupReturnCode = CSL_ESYS_INVPARAMS;
    Uint32 i = 0;
    Uint32 tempVar = 0;
#ifdef PREVIEWER_DEBUG
    Uint32 x;
#endif /* PREVIEWER_DEBUG */

    /* parameter validation */
    if (((NULL == regs) || (NULL == prevChannelCreateMode))
        || (NULL == prevConfigParams))
    {
        hwSetupReturnCode = CSL_ESYS_INVPARAMS;
    }
    else
    {
        prevRegs = (CSL_PrevRegsOvly)regs;

        /* Set previewer source */
        CSL_FINS(prevRegs->PCR, PREV_PCR_SOURCE,
            (Uint32)(prevChannelCreateMode->chanSource.source));
#ifdef PREVIEWER_DEBUG
        x = CSL_FEXT(prevRegs->PCR, PREV_PCR_SOURCE);
        if ((Uint32)(prevChannelCreateMode->chanSource.source) != x)
        {
            llcPrevDebugErrorStatus = 2;
        }
#endif /* PREVIEWER_DEBUG */

        /* set channel mode */
        if (PSP_PREVIEWER_CHANNEL_CCDC
            == prevChannelCreateMode->chanSource.source)
        {
            /* Set continuous mode */
            CSL_FINS(prevRegs->PCR, PREV_PCR_ONESHOT,
                (Uint32)CSL_PREV_PCR_ONESHOT_CONTINUOUS_VIA_VPORT);
#ifdef PREVIEWER_DEBUG
            x = CSL_FEXT(prevRegs->PCR, PREV_PCR_ONESHOT);
            if ((Uint32)CSL_PREV_PCR_ONESHOT_CONTINUOUS_VIA_VPORT != x)
            {
                llcPrevDebugErrorStatus = 3;
            }
#endif /* PREVIEWER_DEBUG */
        }
        else
        {
            /* Set one shot mode */
            CSL_FINS(prevRegs->PCR, PREV_PCR_ONESHOT,
                (Uint32)CSL_PREV_PCR_ONESHOT_ONESHOTMODE);
#ifdef PREVIEWER_DEBUG
            x = CSL_FEXT(prevRegs->PCR, PREV_PCR_ONESHOT);
            if ((Uint32)CSL_PREV_PCR_ONESHOT_ONESHOTMODE != x)
            {
                llcPrevDebugErrorStatus = 4;
            }
#endif /* PREVIEWER_DEBUG */
        }

        /* Set pixel width */
        if (PSP_PREVIEWER_INWIDTH_8BIT == prevConfigParams->sizeParam.pixelSize)
        {
            CSL_FINS(prevRegs->PCR, PREV_PCR_WIDTH,
                (Uint32)(CSL_PREV_PCR_WIDTH_8_BITWIDE));
#ifdef PREVIEWER_DEBUG
            x = CSL_FEXT(prevRegs->PCR, PREV_PCR_WIDTH);
            if ((Uint32)(CSL_PREV_PCR_WIDTH_8_BITWIDE) != x)
            {
                llcPrevDebugErrorStatus = 5;
            }
#endif /* PREVIEWER_DEBUG */
        }
        else
        {
            CSL_FINS(prevRegs->PCR, PREV_PCR_WIDTH,
                (Uint32)CSL_PREV_PCR_WIDTH_10_BITWIDE);
#ifdef PREVIEWER_DEBUG
            x = CSL_FEXT(prevRegs->PCR, PREV_PCR_WIDTH);
            if ((Uint32)CSL_PREV_PCR_WIDTH_10_BITWIDE != x)
            {
                llcPrevDebugErrorStatus = 6;
            }
#endif /* PREVIEWER_DEBUG */
        }

        /* set offset value for input image */
        if (PSP_PREVIEWER_CHANNEL_SDRAM
            == prevChannelCreateMode->chanSource.source)
        {
            CSL_FINS(prevRegs->RADR_OFFSET, PREV_RADR_OFFSET_OFFSET,
                (Uint32)prevConfigParams->sizeParam.inPitch);
#ifdef PREVIEWER_DEBUG
            x = CSL_FEXT(prevRegs->RADR_OFFSET, PREV_RADR_OFFSET_OFFSET);
            if ((Uint32)prevConfigParams->sizeParam.inPitch != x)
            {
                llcPrevDebugErrorStatus = 7;
            }
#endif /* PREVIEWER_DEBUG */
        }

        /* set offset value for output image */
        CSL_FINS(prevRegs->WADD_OFFSET, PREV_WADD_OFFSET_OFFSET,
            (Uint32)prevConfigParams->sizeParam.outPitch);
#ifdef PREVIEWER_DEBUG
        x = CSL_FEXT(prevRegs->WADD_OFFSET, PREV_WADD_OFFSET_OFFSET);
        if ((Uint32)prevConfigParams->sizeParam.outPitch != x)
        {
            llcPrevDebugErrorStatus = 8;
        }
#endif /* PREVIEWER_DEBUG */
        /* set horizontal info */
        CSL_FINS(prevRegs->HORZ_INFO, PREV_HORZ_INFO_SPH,
            (Uint32)prevConfigParams->sizeParam.sph);
#ifdef PREVIEWER_DEBUG
        x = CSL_FEXT(prevRegs->HORZ_INFO, PREV_HORZ_INFO_SPH);
        if ((Uint32)prevConfigParams->sizeParam.sph != x)
        {
            llcPrevDebugErrorStatus = 9;
        }
#endif /* PREVIEWER_DEBUG */
        CSL_FINS(prevRegs->HORZ_INFO, PREV_HORZ_INFO_EPH,
            (Uint32)prevConfigParams->sizeParam.eph);
#ifdef PREVIEWER_DEBUG
        x = CSL_FEXT(prevRegs->HORZ_INFO, PREV_HORZ_INFO_EPH);
        if ((Uint32)prevConfigParams->sizeParam.eph != x)
        {
            llcPrevDebugErrorStatus = 10;
        }
#endif /* PREVIEWER_DEBUG */
        /* set vertical info */
        CSL_FINS(prevRegs->VERT_INFO, PREV_VERT_INFO_SLV,
            (Uint32)prevConfigParams->sizeParam.slv);
#ifdef PREVIEWER_DEBUG
        x = CSL_FEXT(prevRegs->VERT_INFO, PREV_VERT_INFO_SLV);
        if ((Uint32)prevConfigParams->sizeParam.slv != x)
        {
            llcPrevDebugErrorStatus = 11;
        }
#endif /* PREVIEWER_DEBUG */
        CSL_FINS(prevRegs->VERT_INFO, PREV_VERT_INFO_ELV,
            (Uint32)prevConfigParams->sizeParam.elv);
#ifdef PREVIEWER_DEBUG
        x = CSL_FEXT(prevRegs->VERT_INFO, PREV_VERT_INFO_ELV);
        if ((Uint32)prevConfigParams->sizeParam.elv != x)
        {
            llcPrevDebugErrorStatus = 12;
        }
#endif /* PREVIEWER_DEBUG */
        /* Enable writing to DDRAM */
        CSL_FINS(prevRegs->PCR, PREV_PCR_SDRPORT,
            (Uint32)CSL_PREV_PCR_SDRPORT_ENABLE);
#ifdef PREVIEWER_DEBUG
        x = CSL_FEXT(prevRegs->PCR, PREV_PCR_SDRPORT);
        if ((Uint32)CSL_PREV_PCR_SDRPORT_ENABLE != x)
        {
            llcPrevDebugErrorStatus = 13;
        }
#endif /* PREVIEWER_DEBUG */
        /* diable RSZPORT port */
        CSL_FINS(prevRegs->PCR, PREV_PCR_RSZPORT,
            CSL_PREV_PCR_RSZPORT_DISABLE);
#ifdef PREVIEWER_DEBUG
        x = CSL_FEXT(prevRegs->PCR, PREV_PCR_RSZPORT);
        if (CSL_PREV_PCR_RSZPORT_DISABLE != x)
        {
            llcPrevDebugErrorStatus = 14;
        }
#endif /* PREVIEWER_DEBUG */

        /* set contrast and brightness */
        CSL_FINS(prevRegs->CNT_BRT, PREV_CNT_BRT_CNT,
            (Uint32)prevConfigParams->contrast);
#ifdef PREVIEWER_DEBUG
        x = CSL_FEXT(prevRegs->CNT_BRT, PREV_CNT_BRT_CNT);
        if ((Uint32)prevConfigParams->contrast != x)
        {
            llcPrevDebugErrorStatus = 15;
        }
#endif /* PREVIEWER_DEBUG */
        CSL_FINS(prevRegs->CNT_BRT, PREV_CNT_BRT_BRT,
            (Uint32)prevConfigParams->brightness);
#ifdef PREVIEWER_DEBUG
        x = CSL_FEXT(prevRegs->CNT_BRT, PREV_CNT_BRT_BRT);
        if ((Uint32)prevConfigParams->brightness != x)
        {
            llcPrevDebugErrorStatus = 16;
        }
#endif /* PREVIEWER_DEBUG */


        /* set output format in PCR */
        switch(prevConfigParams->outPixelOrderParam)
        {
            case PSP_PREVIEWER_PIXELORDER_YCBYCR:
                tempVar = (Uint32)CSL_PREV_PCR_YCPOS_YCBYCR;
                break;
            case PSP_PREVIEWER_PIXELORDER_YCRYCB:
                tempVar = (Uint32)CSL_PREV_PCR_YCPOS_YCRYCB;
                break;
            case PSP_PREVIEWER_PIXELORDER_CBYCRY:
                tempVar = (Uint32)CSL_PREV_PCR_YCPOS_CBYCRY;
                break;
            case PSP_PREVIEWER_PIXELORDER_CRYCBY:
                tempVar = (Uint32)CSL_PREV_PCR_YCPOS_CRYCBY;
                break;
            default:
                break;
        }
        CSL_FINS(prevRegs->PCR, PREV_PCR_YCPOS,
            tempVar);
#ifdef PREVIEWER_DEBUG
        x = CSL_FEXT(prevRegs->PCR, PREV_PCR_YCPOS);
        if (tempVar != x)
        {
            llcPrevDebugErrorStatus = 17;
        }
#endif /* PREVIEWER_DEBUG */


        /* configure averager */
        CSL_FINS(prevRegs->AVE, PREV_AVE_ODDDIST,
            (Uint32)CSL_PREV_AVE_ODDDIST_2PIXELS);
#ifdef PREVIEWER_DEBUG
        x = CSL_FEXT(prevRegs->AVE, PREV_AVE_ODDDIST);
        if ((Uint32)CSL_PREV_AVE_ODDDIST_2PIXELS != x)
        {
            llcPrevDebugErrorStatus = 18;
        }
#endif /* PREVIEWER_DEBUG */
        CSL_FINS(prevRegs->AVE, PREV_AVE_EVENDIST,
            (Uint32)CSL_PREV_AVE_EVENDIST_2PIXELS);
#ifdef PREVIEWER_DEBUG
        x = CSL_FEXT(prevRegs->AVE, PREV_AVE_EVENDIST);
        if ((Uint32)CSL_PREV_AVE_EVENDIST_2PIXELS != x)
        {
            llcPrevDebugErrorStatus = 19;
        }
#endif /* PREVIEWER_DEBUG */
        switch(prevConfigParams->downSampleRate)
        {
            case PSP_PREVIEWER_DOWN_SAMPLE_RATE1:
                tempVar = CSL_PREV_AVE_COUNT_NOAVERAGING;
                break;
            case PSP_PREVIEWER_DOWN_SAMPLE_RATE2:
                tempVar = CSL_PREV_AVE_COUNT_2PIXEL_AVG;
                break;
            case PSP_PREVIEWER_DOWN_SAMPLE_RATE4:
                tempVar = CSL_PREV_AVE_COUNT_4PIXEL_AVG;
                break;
            case PSP_PREVIEWER_DOWN_SAMPLE_RATE8:
                tempVar = CSL_PREV_AVE_COUNT_8PIXEL_AVG;
                break;
            default:
                tempVar = CSL_PREV_AVE_COUNT_NOAVERAGING;
                break;
        }
        CSL_FINS(prevRegs->AVE, PREV_AVE_COUNT,
            (Uint32)tempVar);
#ifdef PREVIEWER_DEBUG
        x = CSL_FEXT(prevRegs->AVE, PREV_AVE_COUNT);
        if ((Uint32)tempVar != x)
        {
            llcPrevDebugErrorStatus = 20;
        }
#endif /* PREVIEWER_DEBUG */


        /* Enable Inverse A-Law if it is enabled in configuration */
        if ((Uint32)0 != (prevConfigParams->features
                & PSP_PREVIEWER_INVERSE_ALAW))
        {
            CSL_FINS(prevRegs->PCR, PREV_PCR_INVALAW,
                (Uint32)CSL_PREV_PCR_INVALAW_ENABLE);
#ifdef PREVIEWER_DEBUG
            x = CSL_FEXT(prevRegs->PCR, PREV_PCR_INVALAW);
            if ((Uint32)CSL_PREV_PCR_INVALAW_ENABLE != x)
            {
                llcPrevDebugErrorStatus = 22;
            }
#endif /* PREVIEWER_DEBUG */
        }

        /* enable dark frame subtract if it is enabled in configuration */
        if ((Uint32)0 != (prevConfigParams->features
                & PSP_PREVIEWER_DARK_FRAME_SUBTRACT))
        {
            /* enable dark frame subtract in PCR */
            CSL_FINS(prevRegs->PCR, PREV_PCR_DRKFEN,
                (Uint32)CSL_PREV_PCR_DRKFEN_ENABLE);
#ifdef PREVIEWER_DEBUG
            x = CSL_FEXT(prevRegs->PCR, PREV_PCR_DRKFEN);
            if ((Uint32)CSL_PREV_PCR_DRKFEN_ENABLE != x)
            {
                llcPrevDebugErrorStatus = 23;
            }
#endif /* PREVIEWER_DEBUG */
        }

        /* enable lens shading if it is enabled in configuration */
        if ((Uint32)0 != (prevConfigParams->features
                & PSP_PREVIEWER_LENS_SHADING))
        {
            /* enable lens shading in PCR */
            CSL_FINS(prevRegs->PCR, PREV_PCR_SHADE_COMP,
                (Uint32)CSL_PREV_PCR_SHADE_COMP_ENABLE);
#ifdef PREVIEWER_DEBUG
            x = CSL_FEXT(prevRegs->PCR, PREV_PCR_SHADE_COMP);
            if ((Uint32)CSL_PREV_PCR_SHADE_COMP_ENABLE != x)
            {
                llcPrevDebugErrorStatus = 24;
            }
#endif /* PREVIEWER_DEBUG */
            /* set lens shading shift parameter */
            CSL_FINS(prevRegs->PCR, PREV_PCR_SHADE_SFT,
                (Uint32)prevConfigParams->lensShadingShift);
#ifdef PREVIEWER_DEBUG
            x = CSL_FEXT(prevRegs->PCR, PREV_PCR_SHADE_SFT);
            if ((Uint32)prevConfigParams->lensShadingShift != x)
            {
                llcPrevDebugErrorStatus = 25;
            }
#endif /* PREVIEWER_DEBUG */
            /* enable dark frame subtract in PCR */
            CSL_FINS(prevRegs->PCR, PREV_PCR_DRKFEN,
                (Uint32)CSL_PREV_PCR_DRKFEN_ENABLE);
#ifdef PREVIEWER_DEBUG
            x = CSL_FEXT(prevRegs->PCR, PREV_PCR_DRKFEN);
            if ((Uint32)CSL_PREV_PCR_DRKFEN_ENABLE != x)
            {
                llcPrevDebugErrorStatus = 26;
            }
#endif /* PREVIEWER_DEBUG */
        }
        if (((Uint32)0 != (prevConfigParams->features
                    & PSP_PREVIEWER_DARK_FRAME_SUBTRACT))
            || ((Uint32)0 != (prevConfigParams->features
                    & PSP_PREVIEWER_LENS_SHADING)))
        {
            /* set the dark frame address and line offset */
            CSL_FINS(prevRegs->DSDR_ADDR, PREV_DSDR_ADDR_DRKF,
                (Uint32)prevConfigParams->darkFrameAddr);
#ifdef PREVIEWER_DEBUG
            x = CSL_FEXT(prevRegs->DSDR_ADDR, PREV_DSDR_ADDR_DRKF);
            if ((Uint32)prevConfigParams->darkFrameAddr != x)
            {
                llcPrevDebugErrorStatus = 27;
            }
#endif /* PREVIEWER_DEBUG */
            CSL_FINS(prevRegs->DRKF_OFFSET, PREV_DRKF_OFFSET_OFFSET,
                (Uint32)prevConfigParams->darkFrameOffset);
#ifdef PREVIEWER_DEBUG
            x = CSL_FEXT(prevRegs->DRKF_OFFSET, PREV_DRKF_OFFSET_OFFSET);
            if ((Uint32)prevConfigParams->darkFrameOffset != x)
            {
                llcPrevDebugErrorStatus = 28;
            }
#endif /* PREVIEWER_DEBUG */
        }

        /* Enable HMF and set its threshold if it is enabled in
         * configuration */
        if ((Uint32)0 != (prevConfigParams->features
                & PSP_PREVIEWER_HMF))
        {
            CSL_FINS(prevRegs->PCR, PREV_PCR_HMEDEN,
                (Uint32)CSL_PREV_PCR_HMEDEN_ENABLE);
#ifdef PREVIEWER_DEBUG
            x = CSL_FEXT(prevRegs->PCR, PREV_PCR_HMEDEN);
            if ((Uint32)CSL_PREV_PCR_HMEDEN_ENABLE != x)
            {
                llcPrevDebugErrorStatus = 29;
            }
#endif /* PREVIEWER_DEBUG */
            CSL_FINS(prevRegs->HMED, PREV_HMED_ODDDIST,
                (Uint32)CSL_PREV_HMED_ODDDIST_2PIXELS);
#ifdef PREVIEWER_DEBUG
            x = CSL_FEXT(prevRegs->HMED, PREV_HMED_ODDDIST);
            if ((Uint32)CSL_PREV_HMED_ODDDIST_2PIXELS != x)
            {
                llcPrevDebugErrorStatus = 30;
            }
#endif /* PREVIEWER_DEBUG */
            CSL_FINS(prevRegs->HMED, PREV_HMED_EVENDIST,
                (Uint32)CSL_PREV_HMED_EVENDIST_2PIXELS);
#ifdef PREVIEWER_DEBUG
            x = CSL_FEXT(prevRegs->HMED, PREV_HMED_EVENDIST);
            if ((Uint32)CSL_PREV_HMED_EVENDIST_2PIXELS != x)
            {
                llcPrevDebugErrorStatus = 31;
            }
#endif /* PREVIEWER_DEBUG */
            CSL_FINS(prevRegs->HMED, PREV_HMED_THRESHOLD,
                (Uint32)prevConfigParams->hmfThreshold);
#ifdef PREVIEWER_DEBUG
            x = CSL_FEXT(prevRegs->HMED, PREV_HMED_THRESHOLD);
            if ((Uint32)prevConfigParams->hmfThreshold != x)
            {
                llcPrevDebugErrorStatus = 32;
            }
#endif /* PREVIEWER_DEBUG */
        }

        /* Enable Noise filter and set its coefficients if it is enabled in
         * configuration */
        if ((Uint32)0 != (prevConfigParams->features
                & PSP_PREVIEWER_NOISE_FILTER))
        {
            CSL_FINS(prevRegs->PCR, PREV_PCR_NFEN,
                (Uint32)CSL_PREV_PCR_NFEN_ENABLE);
#ifdef PREVIEWER_DEBUG
            x = CSL_FEXT(prevRegs->PCR, PREV_PCR_NFEN);
            if ((Uint32)CSL_PREV_PCR_NFEN_ENABLE != x)
            {
                llcPrevDebugErrorStatus = 33;
            }
#endif /* PREVIEWER_DEBUG */
            /* Set coefficients of NF */
            /* Set table address */
            CSL_FINS(prevRegs->SET_TBL_ADDRESS, PREV_SET_TBL_ADDRESS_ADDR,
                (Uint32)LLC_PREVIEWER_NOISE_FILTER_START_ADDR);
#ifdef PREVIEWER_DEBUG
            x = CSL_FEXT(prevRegs->SET_TBL_ADDRESS,
                PREV_SET_TBL_ADDRESS_ADDR);
            if ((Uint32)LLC_PREVIEWER_NOISE_FILTER_START_ADDR != x)
            {
                llcPrevDebugErrorStatus = 34;
            }
#endif /* PREVIEWER_DEBUG */
            /* set data */
            for(i=0; i <= (LLC_PREVIEWER_NOISE_FILTER_END_ADDR
                    - LLC_PREVIEWER_NOISE_FILTER_START_ADDR); i++)
            {
                prevRegs->SET_TBL_DATA = (Uint32)prevConfigParams
                    ->noiseFilterCoeffsParam.noise[i];
                /* Address is auto incremented */
            }
#ifdef PREVIEWER_DEBUG
            CSL_FINS(prevRegs->SET_TBL_ADDRESS, PREV_SET_TBL_ADDRESS_ADDR,
                (Uint32)LLC_PREVIEWER_NOISE_FILTER_START_ADDR);
            /* get data */
            for(i=0; i <= (LLC_PREVIEWER_NOISE_FILTER_END_ADDR
                    - LLC_PREVIEWER_NOISE_FILTER_START_ADDR); i++)
            {
                x = prevRegs->SET_TBL_DATA;
                if ((Uint8)prevConfigParams->noiseFilterCoeffsParam.noise[i]
                    != x)
                {
                    llcPrevDebugErrorStatus = 35;
                }
                /* Address is auto incremented */
            }
#endif /* PREVIEWER_DEBUG */

            /* write the strength of the weighted average */
            CSL_FINS(prevRegs->NF, PREV_NF_STRNGTH,
                (Uint32)prevConfigParams->noiseFilterCoeffsParam.strength);
#ifdef PREVIEWER_DEBUG
            x = CSL_FEXT(prevRegs->NF, PREV_NF_STRNGTH);
            if ((Uint32)prevConfigParams->noiseFilterCoeffsParam.strength
                != x)
            {
                llcPrevDebugErrorStatus = 36;
            }
#endif /* PREVIEWER_DEBUG */
        }

        /* Setting white balancing parameters */
        /* Set the common gain for white balancing in register */
        CSL_FINS(prevRegs->WB_DGAIN, PREV_WB_DGAIN_DGAIN,
            (Uint32)((prevConfigParams->whiteBalanceParam).wbDgain));
#ifdef PREVIEWER_DEBUG
        x = CSL_FEXT(prevRegs->WB_DGAIN, PREV_WB_DGAIN_DGAIN);
        if ((Uint32)((prevConfigParams->whiteBalanceParam).wbDgain) != x)
        {
            llcPrevDebugErrorStatus = 37;
        }
#endif /* PREVIEWER_DEBUG */
        /* Set individual color gains in register for white balancing */
        CSL_FINS(prevRegs->WBGAIN, PREV_WBGAIN_COEF0,
            (Uint32)prevConfigParams->whiteBalanceParam.wbGain[0]);
#ifdef PREVIEWER_DEBUG
        x = CSL_FEXT(prevRegs->WBGAIN, PREV_WBGAIN_COEF0);
        if ((Uint32)prevConfigParams->whiteBalanceParam.wbGain[0] != x)
        {
            llcPrevDebugErrorStatus = 38;
        }
#endif /* PREVIEWER_DEBUG */
        CSL_FINS(prevRegs->WBGAIN, PREV_WBGAIN_COEF1,
            (Uint32)prevConfigParams->whiteBalanceParam.wbGain[1]);
#ifdef PREVIEWER_DEBUG
        x = CSL_FEXT(prevRegs->WBGAIN, PREV_WBGAIN_COEF1);
        if ((Uint32)prevConfigParams->whiteBalanceParam.wbGain[1] != x)
        {
            llcPrevDebugErrorStatus = 39;
        }
#endif /* PREVIEWER_DEBUG */
        CSL_FINS(prevRegs->WBGAIN, PREV_WBGAIN_COEF2,
            (Uint32)prevConfigParams->whiteBalanceParam.wbGain[2]);
#ifdef PREVIEWER_DEBUG
        x = CSL_FEXT(prevRegs->WBGAIN, PREV_WBGAIN_COEF2);
        if ((Uint32)prevConfigParams->whiteBalanceParam.wbGain[2] != x)
        {
            llcPrevDebugErrorStatus = 40;
        }
#endif /* PREVIEWER_DEBUG */
        CSL_FINS(prevRegs->WBGAIN, PREV_WBGAIN_COEF3,
            (Uint32)prevConfigParams->whiteBalanceParam.wbGain[3]);
#ifdef PREVIEWER_DEBUG
        x = CSL_FEXT(prevRegs->WBGAIN, PREV_WBGAIN_COEF3);
        if ((Uint32)prevConfigParams->whiteBalanceParam.wbGain[3] != x)
        {
            llcPrevDebugErrorStatus = 41;
        }
#endif /* PREVIEWER_DEBUG */
        /* Setting position of the colors in 4x4 grid */
        CSL_FINS(prevRegs->WBSEL, PREV_WBSEL_0_0,
            (Uint32)prevConfigParams->whiteBalanceParam.position[0][0]);
#ifdef PREVIEWER_DEBUG
        x = CSL_FEXT(prevRegs->WBSEL, PREV_WBSEL_0_0);
        if ((Uint32)prevConfigParams->whiteBalanceParam.position[0][0] != x)
        {
            llcPrevDebugErrorStatus = 42;
        }
#endif /* PREVIEWER_DEBUG */
        CSL_FINS(prevRegs->WBSEL, PREV_WBSEL_0_1,
            (Uint32)prevConfigParams->whiteBalanceParam.position[0][1]);
#ifdef PREVIEWER_DEBUG
        x = CSL_FEXT(prevRegs->WBSEL, PREV_WBSEL_0_1);
        if ((Uint32)prevConfigParams->whiteBalanceParam.position[0][1] != x)
        {
            llcPrevDebugErrorStatus = 43;
        }
#endif /* PREVIEWER_DEBUG */
        CSL_FINS(prevRegs->WBSEL, PREV_WBSEL_0_2,
            (Uint32)prevConfigParams->whiteBalanceParam.position[0][2]);
#ifdef PREVIEWER_DEBUG
        x = CSL_FEXT(prevRegs->WBSEL, PREV_WBSEL_0_2);
        if ((Uint32)prevConfigParams->whiteBalanceParam.position[0][2] != x)
        {
            llcPrevDebugErrorStatus = 44;
        }
#endif /* PREVIEWER_DEBUG */
        CSL_FINS(prevRegs->WBSEL, PREV_WBSEL_0_3,
            (Uint32)prevConfigParams->whiteBalanceParam.position[0][3]);
#ifdef PREVIEWER_DEBUG
        x = CSL_FEXT(prevRegs->WBSEL, PREV_WBSEL_0_3);
        if ((Uint32)prevConfigParams->whiteBalanceParam.position[0][3] != x)
        {
            llcPrevDebugErrorStatus = 45;
        }
#endif /* PREVIEWER_DEBUG */
        CSL_FINS(prevRegs->WBSEL, PREV_WBSEL_1_0,
            (Uint32)prevConfigParams->whiteBalanceParam.position[1][0]);
#ifdef PREVIEWER_DEBUG
        x = CSL_FEXT(prevRegs->WBSEL, PREV_WBSEL_1_0);
        if ((Uint32)prevConfigParams->whiteBalanceParam.position[1][0] != x)
        {
            llcPrevDebugErrorStatus = 46;
        }
#endif /* PREVIEWER_DEBUG */
        CSL_FINS(prevRegs->WBSEL, PREV_WBSEL_1_1,
            (Uint32)prevConfigParams->whiteBalanceParam.position[1][1]);
#ifdef PREVIEWER_DEBUG
        x = CSL_FEXT(prevRegs->WBSEL, PREV_WBSEL_1_1);
        if ((Uint32)prevConfigParams->whiteBalanceParam.position[1][1] != x)
        {
            llcPrevDebugErrorStatus = 47;
        }
#endif /* PREVIEWER_DEBUG */
        CSL_FINS(prevRegs->WBSEL, PREV_WBSEL_1_2,
            (Uint32)prevConfigParams->whiteBalanceParam.position[1][2]);
#ifdef PREVIEWER_DEBUG
        x = CSL_FEXT(prevRegs->WBSEL, PREV_WBSEL_1_2);
        if ((Uint32)prevConfigParams->whiteBalanceParam.position[1][2] != x)
        {
            llcPrevDebugErrorStatus = 48;
        }
#endif /* PREVIEWER_DEBUG */
        CSL_FINS(prevRegs->WBSEL, PREV_WBSEL_1_3,
            (Uint32)prevConfigParams->whiteBalanceParam.position[1][3]);
#ifdef PREVIEWER_DEBUG
        x = CSL_FEXT(prevRegs->WBSEL, PREV_WBSEL_1_3);
        if ((Uint32)prevConfigParams->whiteBalanceParam.position[1][3] != x)
        {
            llcPrevDebugErrorStatus = 49;
        }
#endif /* PREVIEWER_DEBUG */

        CSL_FINS(prevRegs->WBSEL, PREV_WBSEL_2_0,
            (Uint32)prevConfigParams->whiteBalanceParam.position[2][0]);
#ifdef PREVIEWER_DEBUG
        x = CSL_FEXT(prevRegs->WBSEL, PREV_WBSEL_2_0);
        if ((Uint32)prevConfigParams->whiteBalanceParam.position[2][0] != x)
        {
            llcPrevDebugErrorStatus = 50;
        }
#endif /* PREVIEWER_DEBUG */
        CSL_FINS(prevRegs->WBSEL, PREV_WBSEL_2_1,
            (Uint32)prevConfigParams->whiteBalanceParam.position[2][1]);
#ifdef PREVIEWER_DEBUG
        x = CSL_FEXT(prevRegs->WBSEL, PREV_WBSEL_2_1);
        if ((Uint32)prevConfigParams->whiteBalanceParam.position[2][1] != x)
        {
            llcPrevDebugErrorStatus = 51;
        }
#endif /* PREVIEWER_DEBUG */
        CSL_FINS(prevRegs->WBSEL, PREV_WBSEL_2_2,
            (Uint32)prevConfigParams->whiteBalanceParam.position[2][2]);
#ifdef PREVIEWER_DEBUG
        x = CSL_FEXT(prevRegs->WBSEL, PREV_WBSEL_2_2);
        if ((Uint32)prevConfigParams->whiteBalanceParam.position[2][2] != x)
        {
            llcPrevDebugErrorStatus = 52;
        }
#endif /* PREVIEWER_DEBUG */
        CSL_FINS(prevRegs->WBSEL, PREV_WBSEL_2_3,
            (Uint32)prevConfigParams->whiteBalanceParam.position[2][3]);
#ifdef PREVIEWER_DEBUG
        x = CSL_FEXT(prevRegs->WBSEL, PREV_WBSEL_2_3);
        if ((Uint32)prevConfigParams->whiteBalanceParam.position[2][3] != x)
        {
            llcPrevDebugErrorStatus = 53;
        }
#endif /* PREVIEWER_DEBUG */
        CSL_FINS(prevRegs->WBSEL, PREV_WBSEL_3_0,
            (Uint32)prevConfigParams->whiteBalanceParam.position[3][0]);
#ifdef PREVIEWER_DEBUG
        x = CSL_FEXT(prevRegs->WBSEL, PREV_WBSEL_3_0);
        if ((Uint32)prevConfigParams->whiteBalanceParam.position[3][0] != x)
        {
            llcPrevDebugErrorStatus = 54;
        }
#endif /* PREVIEWER_DEBUG */
        CSL_FINS(prevRegs->WBSEL, PREV_WBSEL_3_1,
            (Uint32)prevConfigParams->whiteBalanceParam.position[3][1]);
#ifdef PREVIEWER_DEBUG
        x = CSL_FEXT(prevRegs->WBSEL, PREV_WBSEL_3_1);
        if ((Uint32)prevConfigParams->whiteBalanceParam.position[3][1] != x)
        {
            llcPrevDebugErrorStatus = 55;
        }
#endif /* PREVIEWER_DEBUG */
        CSL_FINS(prevRegs->WBSEL, PREV_WBSEL_3_2,
            (Uint32)prevConfigParams->whiteBalanceParam.position[3][2]);
#ifdef PREVIEWER_DEBUG
        x = CSL_FEXT(prevRegs->WBSEL, PREV_WBSEL_3_2);
        if ((Uint32)prevConfigParams->whiteBalanceParam.position[3][2] != x)
        {
            llcPrevDebugErrorStatus = 56;
        }
#endif /* PREVIEWER_DEBUG */
        CSL_FINS(prevRegs->WBSEL, PREV_WBSEL_3_3,
            (Uint32)prevConfigParams->whiteBalanceParam.position[3][3]);
#ifdef PREVIEWER_DEBUG
        x = CSL_FEXT(prevRegs->WBSEL, PREV_WBSEL_3_3);
        if ((Uint32)prevConfigParams->whiteBalanceParam.position[3][3] != x)
        {
            llcPrevDebugErrorStatus = 57;
        }
#endif /* PREVIEWER_DEBUG */

        /*  Set CFA Coefficients */
        if ((Uint32)0 != (prevConfigParams->features
                & PSP_PREVIEWER_CFA))
        {
            /* enable CFA interpolation in pcr */
            CSL_FINS(prevRegs->PCR, PREV_PCR_CFAEN,
                (Uint32)CSL_PREV_PCR_CFAEN_ENABLE);
#ifdef PREVIEWER_DEBUG
            x = CSL_FEXT(prevRegs->PCR, PREV_PCR_CFAEN);
            if ((Uint32)CSL_PREV_PCR_CFAEN_ENABLE != x)
            {
                llcPrevDebugErrorStatus = 58;
            }
#endif /* PREVIEWER_DEBUG */

            /* Set coefficients of Gamma correction */
            /* Set table address for red gamma */
            CSL_FINS(prevRegs->SET_TBL_ADDRESS, PREV_SET_TBL_ADDRESS_ADDR,
                (Uint32)LLC_PREVIEWER_CFA_COEFF_START_ADDR);
#ifdef PREVIEWER_DEBUG
            x = CSL_FEXT(prevRegs->SET_TBL_ADDRESS,
                PREV_SET_TBL_ADDRESS_ADDR);
            if ((Uint32)LLC_PREVIEWER_CFA_COEFF_START_ADDR != x)
            {
                llcPrevDebugErrorStatus = 59;
            }
#endif /* PREVIEWER_DEBUG */
            /* set data */
            for(i=0; i <= (LLC_PREVIEWER_CFA_COEFF_END_ADDR
                    - LLC_PREVIEWER_CFA_COEFF_START_ADDR); i++)
            {
                prevRegs->SET_TBL_DATA
                    = (Uint32)prevConfigParams->cfaCoeffsParam.coeffs[i];
                /* Address is auto incremented */
            }
#ifdef PREVIEWER_DEBUG
            CSL_FINS(prevRegs->SET_TBL_ADDRESS, PREV_SET_TBL_ADDRESS_ADDR,
                (Uint32)LLC_PREVIEWER_CFA_COEFF_START_ADDR);
            /* get data */
            for(i=0; i <= (LLC_PREVIEWER_CFA_COEFF_END_ADDR
                    - LLC_PREVIEWER_CFA_COEFF_START_ADDR); i++)
            {
                x = prevRegs->SET_TBL_DATA;
                if ((Uint8)prevConfigParams->cfaCoeffsParam.coeffs[i] != x)
                {
                    llcPrevDebugErrorStatus = 60;
                }
                /* Address is auto incremented */
            }
#endif /* PREVIEWER_DEBUG */

            /* set horizontal and vertical threshold */
            CSL_FINS(prevRegs->CFA, PREV_CFA_GRADTH_HOR,
                (Uint32)prevConfigParams->cfaCoeffsParam.hThreshold);
#ifdef PREVIEWER_DEBUG
            x = CSL_FEXT(prevRegs->CFA, PREV_CFA_GRADTH_HOR);
            if ((Uint32)prevConfigParams->cfaCoeffsParam.hThreshold != x)
            {
                llcPrevDebugErrorStatus = 61;
            }
#endif /* PREVIEWER_DEBUG */
            CSL_FINS(prevRegs->CFA, PREV_CFA_GRADTH_VER,
                (Uint32)prevConfigParams->cfaCoeffsParam.vThreshold);
#ifdef PREVIEWER_DEBUG
            x = CSL_FEXT(prevRegs->CFA, PREV_CFA_GRADTH_VER);
            if ((Uint32)prevConfigParams->cfaCoeffsParam.vThreshold != x)
            {
                llcPrevDebugErrorStatus = 62;
            }
#endif /* PREVIEWER_DEBUG */
        }

        /* Setting black adjustment offsets */
        CSL_FINS(prevRegs->BLKADJOFF, PREV_BLKADJOFF_B,
            (Uint32)prevConfigParams->blackAdjParam.blueAdj);
#ifdef PREVIEWER_DEBUG
        x = CSL_FEXT(prevRegs->BLKADJOFF, PREV_BLKADJOFF_B);
        if ((Uint32)prevConfigParams->blackAdjParam.blueAdj != x)
        {
            llcPrevDebugErrorStatus = 63;
        }
#endif /* PREVIEWER_DEBUG */
        CSL_FINS(prevRegs->BLKADJOFF, PREV_BLKADJOFF_G,
            (Uint32)prevConfigParams->blackAdjParam.greenAdj);
#ifdef PREVIEWER_DEBUG
        x = CSL_FEXT(prevRegs->BLKADJOFF, PREV_BLKADJOFF_G);
        if ((Uint32)prevConfigParams->blackAdjParam.greenAdj != x)
        {
            llcPrevDebugErrorStatus = 64;
        }
#endif /* PREVIEWER_DEBUG */
        CSL_FINS(prevRegs->BLKADJOFF, PREV_BLKADJOFF_R,
            (Uint32)prevConfigParams->blackAdjParam.redAdj);
#ifdef PREVIEWER_DEBUG
        x = CSL_FEXT(prevRegs->BLKADJOFF, PREV_BLKADJOFF_R);
        if ((Uint32)prevConfigParams->blackAdjParam.redAdj != x)
        {
            llcPrevDebugErrorStatus = 65;
        }
#endif /* PREVIEWER_DEBUG */

        /* setting RGB2RGB blending */
        CSL_FINS(prevRegs->RGB_MAT1, PREV_RGB_MAT1_MTX_RR,
            (Uint32)prevConfigParams->rgbBlendingParam.blending[0][0]);
#ifdef PREVIEWER_DEBUG
        x = CSL_FEXT(prevRegs->RGB_MAT1, PREV_RGB_MAT1_MTX_RR);
        if ((Uint32)prevConfigParams->rgbBlendingParam.blending[0][0] != x)
        {
            llcPrevDebugErrorStatus = 66;
        }
#endif /* PREVIEWER_DEBUG */
        CSL_FINS(prevRegs->RGB_MAT1, PREV_RGB_MAT1_MTX_GR,
            (Uint32)prevConfigParams->rgbBlendingParam.blending[0][1]);
#ifdef PREVIEWER_DEBUG
        x = CSL_FEXT(prevRegs->RGB_MAT1, PREV_RGB_MAT1_MTX_GR);
        if ((Uint32)prevConfigParams->rgbBlendingParam.blending[0][1] != x)
        {
            llcPrevDebugErrorStatus = 67;
        }
#endif /* PREVIEWER_DEBUG */
        CSL_FINS(prevRegs->RGB_MAT2, PREV_RGB_MAT2_MTX_BR,
            (Uint32)prevConfigParams->rgbBlendingParam.blending[0][2]);
#ifdef PREVIEWER_DEBUG
        x = CSL_FEXT(prevRegs->RGB_MAT2, PREV_RGB_MAT2_MTX_BR);
        if ((Uint32)prevConfigParams->rgbBlendingParam.blending[0][2] != x)
        {
            llcPrevDebugErrorStatus = 68;
        }
#endif /* PREVIEWER_DEBUG */
        CSL_FINS(prevRegs->RGB_MAT2, PREV_RGB_MAT2_MTX_RG,
            (Uint32)prevConfigParams->rgbBlendingParam.blending[1][0]);
#ifdef PREVIEWER_DEBUG
        x = CSL_FEXT(prevRegs->RGB_MAT2, PREV_RGB_MAT2_MTX_RG);
        if ((Uint32)prevConfigParams->rgbBlendingParam.blending[1][0] != x)
        {
            llcPrevDebugErrorStatus = 69;
        }
#endif /* PREVIEWER_DEBUG */
        CSL_FINS(prevRegs->RGB_MAT3, PREV_RGB_MAT3_MTX_GG,
            (Uint32)prevConfigParams->rgbBlendingParam.blending[1][1]);
#ifdef PREVIEWER_DEBUG
        x = CSL_FEXT(prevRegs->RGB_MAT3, PREV_RGB_MAT3_MTX_GG);
        if ((Uint32)prevConfigParams->rgbBlendingParam.blending[1][1] != x)
        {
            llcPrevDebugErrorStatus = 70;
        }
#endif /* PREVIEWER_DEBUG */
        CSL_FINS(prevRegs->RGB_MAT3, PREV_RGB_MAT3_MTX_BG,
            (Uint32)prevConfigParams->rgbBlendingParam.blending[1][2]);
#ifdef PREVIEWER_DEBUG
        x = CSL_FEXT(prevRegs->RGB_MAT3, PREV_RGB_MAT3_MTX_BG);
        if ((Uint32)prevConfigParams->rgbBlendingParam.blending[1][2] != x)
        {
            llcPrevDebugErrorStatus = 71;
        }
#endif /* PREVIEWER_DEBUG */
        CSL_FINS(prevRegs->RGB_MAT4, PREV_RGB_MAT4_MTX_RB,
            (Uint32)prevConfigParams->rgbBlendingParam.blending[2][0]);
#ifdef PREVIEWER_DEBUG
        x = CSL_FEXT(prevRegs->RGB_MAT4, PREV_RGB_MAT4_MTX_RB);
        if ((Uint32)prevConfigParams->rgbBlendingParam.blending[2][0] != x)
        {
            llcPrevDebugErrorStatus = 72;
        }
#endif /* PREVIEWER_DEBUG */
        CSL_FINS(prevRegs->RGB_MAT4, PREV_RGB_MAT4_MTX_GB,
            (Uint32)prevConfigParams->rgbBlendingParam.blending[2][1]);
#ifdef PREVIEWER_DEBUG
        x = CSL_FEXT(prevRegs->RGB_MAT4, PREV_RGB_MAT4_MTX_GB);
        if ((Uint32)prevConfigParams->rgbBlendingParam.blending[2][1] != x)
        {
            llcPrevDebugErrorStatus = 73;
        }
#endif /* PREVIEWER_DEBUG */
        CSL_FINS(prevRegs->RGB_MAT5, PREV_RGB_MAT5_MTX_BB,
            (Uint32)prevConfigParams->rgbBlendingParam.blending[2][2]);
#ifdef PREVIEWER_DEBUG
        x = CSL_FEXT(prevRegs->RGB_MAT5, PREV_RGB_MAT5_MTX_BB);
        if ((Uint32)prevConfigParams->rgbBlendingParam.blending[2][2] != x)
        {
            llcPrevDebugErrorStatus = 74;
        }
#endif /* PREVIEWER_DEBUG */
        /* Writing offset of RGB2RGB blending */
        CSL_FINS(prevRegs->RGB_OFF1, PREV_RGB_OFF1_MTX_OFFR,
            (Uint32)prevConfigParams->rgbBlendingParam.offset[0]);
#ifdef PREVIEWER_DEBUG
        x = CSL_FEXT(prevRegs->RGB_OFF1, PREV_RGB_OFF1_MTX_OFFR);
        if ((Uint32)prevConfigParams->rgbBlendingParam.offset[0] != x)
        {
            llcPrevDebugErrorStatus = 75;
        }
#endif /* PREVIEWER_DEBUG */

        CSL_FINS(prevRegs->RGB_OFF1, PREV_RGB_OFF1_MTX_OFFG,
            (Uint32)prevConfigParams->rgbBlendingParam.offset[1]);
#ifdef PREVIEWER_DEBUG
        x = CSL_FEXT(prevRegs->RGB_OFF1, PREV_RGB_OFF1_MTX_OFFG);
        if ((Uint32)prevConfigParams->rgbBlendingParam.offset[1] != x)
        {
            llcPrevDebugErrorStatus = 76;
        }
#endif /* PREVIEWER_DEBUG */

        CSL_FINS(prevRegs->RGB_OFF2, PREV_RGB_OFF2_MTX_OFFB,
            (Uint32)prevConfigParams->rgbBlendingParam.offset[2]);
#ifdef PREVIEWER_DEBUG
        x = CSL_FEXT(prevRegs->RGB_OFF2, PREV_RGB_OFF2_MTX_OFFB);
        if ((Uint32)prevConfigParams->rgbBlendingParam.offset[2] != x)
        {
            llcPrevDebugErrorStatus = 77;
        }
#endif /* PREVIEWER_DEBUG */

        /* Set gamma correction Coefficients if it is enabled in
         * configuration */
        if ((Uint32)0 != (prevConfigParams->features
                & PSP_PREVIEWER_GAMMA))
        {
            CSL_FINS(prevRegs->PCR, PREV_PCR_GAMMA_BYPASS,
                (Uint32)CSL_PREV_PCR_GAMMA_BYPASS_NO_BYPASS);
#ifdef PREVIEWER_DEBUG
            x = CSL_FEXT(prevRegs->PCR, PREV_PCR_GAMMA_BYPASS);
            if ((Uint32)CSL_PREV_PCR_GAMMA_BYPASS_NO_BYPASS != x)
            {
                llcPrevDebugErrorStatus = 78;
            }
#endif /* PREVIEWER_DEBUG */
            /* Set coefficients of Gamma correction */
            /* Set table address for red gamma */
            CSL_FINS(prevRegs->SET_TBL_ADDRESS, PREV_SET_TBL_ADDRESS_ADDR,
                (Uint32)LLC_PREVIEWER_RED_GAMMA_START_ADDR);
#ifdef PREVIEWER_DEBUG
            x = CSL_FEXT(prevRegs->SET_TBL_ADDRESS,
                PREV_SET_TBL_ADDRESS_ADDR);
            if ((Uint32)LLC_PREVIEWER_RED_GAMMA_START_ADDR != x)
            {
                llcPrevDebugErrorStatus = 79;
            }
#endif /* PREVIEWER_DEBUG */
            /* set data */
            for(i=0; i <= (LLC_PREVIEWER_RED_GAMMA_END_ADDR
                    - LLC_PREVIEWER_RED_GAMMA_START_ADDR); i++)
            {
                prevRegs->SET_TBL_DATA
                    = (Uint32)prevConfigParams->gammaCoeffsParam.red[i];
                /* Address is auto incremented */
            }
#ifdef PREVIEWER_DEBUG
            CSL_FINS(prevRegs->SET_TBL_ADDRESS, PREV_SET_TBL_ADDRESS_ADDR,
                (Uint32)LLC_PREVIEWER_RED_GAMMA_START_ADDR);
            /* get data */
            for(i=0; i <= (LLC_PREVIEWER_RED_GAMMA_END_ADDR
                    - LLC_PREVIEWER_RED_GAMMA_START_ADDR); i++)
            {
                x = prevRegs->SET_TBL_DATA;
                if ((Uint8)prevConfigParams->gammaCoeffsParam.red[i] != x)
                {
                    llcPrevDebugErrorStatus = 80;
                }
                /* Address is auto incremented */
            }
#endif /* PREVIEWER_DEBUG */

            /* Set table start address for green gamma */
            CSL_FINS(prevRegs->SET_TBL_ADDRESS, PREV_SET_TBL_ADDRESS_ADDR,
                (Uint32)LLC_PREVIEWER_GREEN_GAMMA_START_ADDR);
#ifdef PREVIEWER_DEBUG
            x = CSL_FEXT(prevRegs->SET_TBL_ADDRESS,
                PREV_SET_TBL_ADDRESS_ADDR);
            if ((Uint32)LLC_PREVIEWER_GREEN_GAMMA_START_ADDR != x)
            {
                llcPrevDebugErrorStatus = 81;
            }
#endif /* PREVIEWER_DEBUG */
            /* set data */
            for(i=0; i <= (LLC_PREVIEWER_GREEN_GAMMA_END_ADDR
                    - LLC_PREVIEWER_GREEN_GAMMA_START_ADDR); i++)
            {
                prevRegs->SET_TBL_DATA
                    = (Uint32)prevConfigParams->gammaCoeffsParam.green[i];
                /* Address is auto incremented */
            }
#ifdef PREVIEWER_DEBUG
            CSL_FINS(prevRegs->SET_TBL_ADDRESS, PREV_SET_TBL_ADDRESS_ADDR,
                (Uint32)LLC_PREVIEWER_GREEN_GAMMA_START_ADDR);
            /* get data */
            for(i=0; i <= (LLC_PREVIEWER_GREEN_GAMMA_END_ADDR
                    - LLC_PREVIEWER_GREEN_GAMMA_START_ADDR); i++)
            {
                x = prevRegs->SET_TBL_DATA;
                if ((Uint8)prevConfigParams->gammaCoeffsParam.green[i] != x)
                {
                    llcPrevDebugErrorStatus = 82;
                }
                /* Address is auto incremented */
            }
#endif /* PREVIEWER_DEBUG */

            /* Set table address for blue gamma */
            CSL_FINS(prevRegs->SET_TBL_ADDRESS, PREV_SET_TBL_ADDRESS_ADDR,
                (Uint32)LLC_PREVIEWER_BLUE_GAMMA_START_ADDR);
#ifdef PREVIEWER_DEBUG
            x = CSL_FEXT(prevRegs->SET_TBL_ADDRESS,
                PREV_SET_TBL_ADDRESS_ADDR);
            if ((Uint32)LLC_PREVIEWER_BLUE_GAMMA_START_ADDR != x)
            {
                llcPrevDebugErrorStatus = 83;
            }
#endif /* PREVIEWER_DEBUG */
            /* set data */
            for(i=0; i <= (LLC_PREVIEWER_BLUE_GAMMA_END_ADDR
                    - LLC_PREVIEWER_BLUE_GAMMA_START_ADDR); i++)
            {
                prevRegs->SET_TBL_DATA
                    = (Uint32)prevConfigParams->gammaCoeffsParam.blue[i];
                /* Address is auto incremented */
            }
#ifdef PREVIEWER_DEBUG
            CSL_FINS(prevRegs->SET_TBL_ADDRESS, PREV_SET_TBL_ADDRESS_ADDR,
                (Uint32)LLC_PREVIEWER_BLUE_GAMMA_START_ADDR);
            /* get data */
            for(i=0; i <= (LLC_PREVIEWER_BLUE_GAMMA_END_ADDR
                    - LLC_PREVIEWER_BLUE_GAMMA_START_ADDR); i++)
            {
                x = prevRegs->SET_TBL_DATA;
                if ((Uint8)prevConfigParams->gammaCoeffsParam.blue[i] != x)
                {
                    llcPrevDebugErrorStatus = 84;
                }
                /* Address is auto incremented */
            }
#endif /* PREVIEWER_DEBUG */
        }
        else
        {
            /* else enable gamma bypassing */
            CSL_FINS(prevRegs->PCR, PREV_PCR_GAMMA_BYPASS,
                (Uint32)CSL_PREV_PCR_GAMMA_BYPASS_BYPASS);
#ifdef PREVIEWER_DEBUG
            x = CSL_FEXT(prevRegs->PCR, PREV_PCR_GAMMA_BYPASS);
            if ((Uint32)CSL_PREV_PCR_GAMMA_BYPASS_BYPASS != x)
            {
                llcPrevDebugErrorStatus = 85;
            }
#endif /* PREVIEWER_DEBUG */
        }

        /* Setting RGB 2 YCbCr matrix gains and offsets */
        CSL_FINS(prevRegs->CSC0, PREV_CSC0_CSCRY,
            (Uint32)prevConfigParams->rgb2ycbcrParam.coeff[0][0]);
#ifdef PREVIEWER_DEBUG
        x = CSL_FEXT(prevRegs->CSC0, PREV_CSC0_CSCRY);
        if ((Uint32)prevConfigParams->rgb2ycbcrParam.coeff[0][0] != x)
        {
            llcPrevDebugErrorStatus = 86;
        }
#endif /* PREVIEWER_DEBUG */
        CSL_FINS(prevRegs->CSC0, PREV_CSC0_CSCGY,
            (Uint32)prevConfigParams->rgb2ycbcrParam.coeff[0][1]);
#ifdef PREVIEWER_DEBUG
        x = CSL_FEXT(prevRegs->CSC0, PREV_CSC0_CSCGY);
        if ((Uint32)prevConfigParams->rgb2ycbcrParam.coeff[0][1] != x)
        {
            llcPrevDebugErrorStatus = 87;
        }
#endif /* PREVIEWER_DEBUG */
        CSL_FINS(prevRegs->CSC0, PREV_CSC0_CSCBY,
            (Uint32)prevConfigParams->rgb2ycbcrParam.coeff[0][2]);
#ifdef PREVIEWER_DEBUG
        x = CSL_FEXT(prevRegs->CSC0, PREV_CSC0_CSCBY);
        if ((Uint32)prevConfigParams->rgb2ycbcrParam.coeff[0][2] != x)
        {
            llcPrevDebugErrorStatus = 88;
        }
#endif /* PREVIEWER_DEBUG */
        CSL_FINS(prevRegs->CSC1, PREV_CSC1_CSCRCB,
            (Uint32)prevConfigParams->rgb2ycbcrParam.coeff[1][0]);
#ifdef PREVIEWER_DEBUG
        x = CSL_FEXT(prevRegs->CSC1, PREV_CSC1_CSCRCB);
        if ((Uint32)prevConfigParams->rgb2ycbcrParam.coeff[1][0] != x)
        {
            llcPrevDebugErrorStatus = 89;
        }
#endif /* PREVIEWER_DEBUG */
        CSL_FINS(prevRegs->CSC1, PREV_CSC1_CSCGCB,
            (Uint32)prevConfigParams->rgb2ycbcrParam.coeff[1][1]);
#ifdef PREVIEWER_DEBUG
        x = CSL_FEXT(prevRegs->CSC1, PREV_CSC1_CSCGCB);
        if ((Uint32)prevConfigParams->rgb2ycbcrParam.coeff[1][1] != x)
        {
            llcPrevDebugErrorStatus = 90;
        }
#endif /* PREVIEWER_DEBUG */
        CSL_FINS(prevRegs->CSC1, PREV_CSC1_CSCBCB,
            (Uint32)prevConfigParams->rgb2ycbcrParam.coeff[1][2]);
#ifdef PREVIEWER_DEBUG
        x = CSL_FEXT(prevRegs->CSC1, PREV_CSC1_CSCBCB);
        if ((Uint32)prevConfigParams->rgb2ycbcrParam.coeff[1][2] != x)
        {
            llcPrevDebugErrorStatus = 91;
        }
#endif /* PREVIEWER_DEBUG */
        CSL_FINS(prevRegs->CSC2, PREV_CSC2_CSCRCR,
            (Uint32)prevConfigParams->rgb2ycbcrParam.coeff[2][0]);
#ifdef PREVIEWER_DEBUG
        x = CSL_FEXT(prevRegs->CSC2, PREV_CSC2_CSCRCR);
        if ((Uint32)prevConfigParams->rgb2ycbcrParam.coeff[2][0] != x)
        {
            llcPrevDebugErrorStatus = 92;
        }
#endif /* PREVIEWER_DEBUG */
        CSL_FINS(prevRegs->CSC2, PREV_CSC2_CSCGCR,
            (Uint32)prevConfigParams->rgb2ycbcrParam.coeff[2][1]);
#ifdef PREVIEWER_DEBUG
        x = CSL_FEXT(prevRegs->CSC2, PREV_CSC2_CSCGCR);
        if ((Uint32)prevConfigParams->rgb2ycbcrParam.coeff[2][1] != x)
        {
            llcPrevDebugErrorStatus = 93;
        }
#endif /* PREVIEWER_DEBUG */
        CSL_FINS(prevRegs->CSC2, PREV_CSC2_CSCBCR,
            (Uint32)prevConfigParams->rgb2ycbcrParam.coeff[2][2]);
#ifdef PREVIEWER_DEBUG
        x = CSL_FEXT(prevRegs->CSC2, PREV_CSC2_CSCBCR);
        if ((Uint32)prevConfigParams->rgb2ycbcrParam.coeff[2][2] != x)
        {
            llcPrevDebugErrorStatus = 94;
        }
#endif /* PREVIEWER_DEBUG */
        CSL_FINS(prevRegs->CSC_OFFSET, PREV_CSC_OFFSET_OFSTCR,
            (Uint32)prevConfigParams->rgb2ycbcrParam.crOffset);
#ifdef PREVIEWER_DEBUG
        x = CSL_FEXT(prevRegs->CSC_OFFSET, PREV_CSC_OFFSET_OFSTCR);
        if ((Uint32)prevConfigParams->rgb2ycbcrParam.crOffset != x)
        {
            llcPrevDebugErrorStatus = 95;
        }
#endif /* PREVIEWER_DEBUG */
        CSL_FINS(prevRegs->CSC_OFFSET, PREV_CSC_OFFSET_OFSTCB,
            (Uint32)prevConfigParams->rgb2ycbcrParam.cbOffset);
#ifdef PREVIEWER_DEBUG
        x = CSL_FEXT(prevRegs->CSC_OFFSET, PREV_CSC_OFFSET_OFSTCB);
        if ((Uint32)prevConfigParams->rgb2ycbcrParam.cbOffset != x)
        {
            llcPrevDebugErrorStatus = 96;
        }
#endif /* PREVIEWER_DEBUG */
        CSL_FINS(prevRegs->CSC_OFFSET, PREV_CSC_OFFSET_YOFST,
            (Uint32)prevConfigParams->rgb2ycbcrParam.yOffset);
#ifdef PREVIEWER_DEBUG
        x = CSL_FEXT(prevRegs->CSC_OFFSET, PREV_CSC_OFFSET_YOFST);
        if ((Uint32)prevConfigParams->rgb2ycbcrParam.yOffset != x)
        {
            llcPrevDebugErrorStatus = 97;
        }
#endif /* PREVIEWER_DEBUG */

        /* Set luma enhancement Coefficients if it is enabled in
         * configuration */
        {
            if ((Uint32)0x0
                != (prevConfigParams->features
                    & PSP_PREVIEWER_LUMA_ENHANCE))
            {
                /* enable Luma enhancement in PCR */
                CSL_FINS(prevRegs->PCR, PREV_PCR_YNENHEN,
                    (Uint32)CSL_PREV_PCR_YNENHEN_ENABLE);
#ifdef PREVIEWER_DEBUG
                x = CSL_FEXT(prevRegs->PCR, PREV_PCR_YNENHEN);
                if ((Uint32)CSL_PREV_PCR_YNENHEN_ENABLE != x)
                {
                    llcPrevDebugErrorStatus = 98;
                }
#endif /* PREVIEWER_DEBUG */
                /* Set the start address for luma enhancement */
                CSL_FINS(prevRegs->SET_TBL_ADDRESS,
                    PREV_SET_TBL_ADDRESS_ADDR,
                    (Uint32)LLC_PREVIEWER_LUMA_ENHANCE_START_ADDR);
#ifdef PREVIEWER_DEBUG
                x = CSL_FEXT(prevRegs->SET_TBL_ADDRESS,
                    PREV_SET_TBL_ADDRESS_ADDR);
                if ((Uint32)LLC_PREVIEWER_LUMA_ENHANCE_START_ADDR != x)
                {
                    llcPrevDebugErrorStatus = 99;
                }
#endif /* PREVIEWER_DEBUG */
                /* set data */
                for(i=0; i <= (LLC_PREVIEWER_LUMA_ENHANCE_END_ADDR
                        - LLC_PREVIEWER_LUMA_ENHANCE_START_ADDR); i++)
                {
                    prevRegs->SET_TBL_DATA
                        =     (Uint32)prevConfigParams->lumaEnhance[i];
                    /* Address is auto incremented */
                }
            }
        }

        /* Set chroma suppress feature if it is enabled in
         * configuration */
        if ((Uint32)0
            != (prevConfigParams->features
                & PSP_PREVIEWER_CHROMA_SUPPRESS))
        {
            /* enable Luma enhancement in PCR */
            CSL_FINS(prevRegs->PCR, PREV_PCR_SUPEN,
                (Uint32)CSL_PREV_PCR_SUPEN_ENABLE);
#ifdef PREVIEWER_DEBUG
            x = CSL_FEXT(prevRegs->PCR, PREV_PCR_SUPEN);
            if ((Uint32)CSL_PREV_PCR_SUPEN_ENABLE != x)
            {
                llcPrevDebugErrorStatus = 100;
            }
#endif /* PREVIEWER_DEBUG */
            if ((Uint32)0
                != (prevConfigParams->chromaSuppressionParam.hpfy))
            {
                CSL_FINS(prevRegs->CSUP, PREV_CSUP_HPFY,
                    (Uint32)CSL_PREV_CSUP_HPFY_ENABLE);
#ifdef PREVIEWER_DEBUG
                x = CSL_FEXT(prevRegs->CSUP, PREV_CSUP_HPFY);
                if ((Uint32)CSL_PREV_CSUP_HPFY_ENABLE != x)
                {
                    llcPrevDebugErrorStatus = 101;
                }
#endif /* PREVIEWER_DEBUG */
            }
            else
            {
                CSL_FINS(prevRegs->CSUP, PREV_CSUP_HPFY,
                    (Uint32)CSL_PREV_CSUP_HPFY_DISABLE);
#ifdef PREVIEWER_DEBUG
                x = CSL_FEXT(prevRegs->CSUP, PREV_CSUP_HPFY);
                if ((Uint32)CSL_PREV_CSUP_HPFY_DISABLE != x)
                {
                    llcPrevDebugErrorStatus = 102;
                }
#endif /* PREVIEWER_DEBUG */
            }

            CSL_FINS(prevRegs->CSUP, PREV_CSUP_CSUPTH,
                (Uint32)prevConfigParams->chromaSuppressionParam.threshold);
#ifdef PREVIEWER_DEBUG
            x = CSL_FEXT(prevRegs->CSUP, PREV_CSUP_CSUPTH);
            if ((Uint32)prevConfigParams->chromaSuppressionParam.threshold
                != x)
            {
                llcPrevDebugErrorStatus = 103;
            }
#endif /* PREVIEWER_DEBUG */
            CSL_FINS(prevRegs->CSUP, PREV_CSUP_CSUPG,
                (Uint32)prevConfigParams->chromaSuppressionParam.gain);
#ifdef PREVIEWER_DEBUG
            x = CSL_FEXT(prevRegs->CSUP, PREV_CSUP_CSUPG);
            if ((Uint32)prevConfigParams->chromaSuppressionParam.gain != x)
            {
                llcPrevDebugErrorStatus = 104;
            }
#endif /* PREVIEWER_DEBUG */
        }

        hwSetupReturnCode = CSL_SOK;
    }
    return hwSetupReturnCode;
}



/**
 *  LLC_prevOneShotPreviewer
 *  It is used to trigger previewer when source is SDRAM.
 */
CSL_Status LLC_prevOneShotPreviewer(
    PSP_previewerChannelCreateMode *prevChannelCreateMode,
    PSP_preview *prevPreviewParams,
    Ptr regs
    )
{
    CSL_Status oneShotReturnCode = CSL_ESYS_INVPARAMS;
#ifdef PREVIEWER_DEBUG
    Uint32 x;
#endif /* PREVIEWER_DEBUG */

    /* parameter validation */
    if (((NULL == regs) || (NULL == prevChannelCreateMode))
        || (NULL == prevPreviewParams))
    {
        oneShotReturnCode = CSL_ESYS_INVPARAMS;
    }
    else
    {
        prevRegs = (CSL_PrevRegsOvly)regs;
        vpssRegs = (CSL_VpssRegsOvly)CSL_VPSS_0_REGS;

        /* set channel mode to one shot mode */
        CSL_FINS(prevRegs->PCR, PREV_PCR_ONESHOT,
            (Uint32)CSL_PREV_PCR_ONESHOT_ONESHOTMODE);
#ifdef PREVIEWER_DEBUG
        x = CSL_FEXT(prevRegs->PCR, PREV_PCR_ONESHOT);
        if ((Uint32)CSL_PREV_PCR_ONESHOT_ONESHOTMODE != x)
        {
            llcPrevDebugErrorStatus = 105;
        }
#endif /* PREVIEWER_DEBUG */
        /* Set previewer source */
        CSL_FINS(prevRegs->PCR, PREV_PCR_SOURCE,
            (Uint32)(prevChannelCreateMode->chanSource.source));
#ifdef PREVIEWER_DEBUG
        x = CSL_FEXT(prevRegs->PCR, PREV_PCR_SOURCE);
        if ((Uint32)(prevChannelCreateMode->chanSource.source) != x)
        {
            llcPrevDebugErrorStatus = 106;
        }
#endif /* PREVIEWER_DEBUG */

        /* write source address */
        CSL_FINS(prevRegs->RSDR_ADDR, PREV_RSDR_ADDR_RADR,
            ((Uint32)prevPreviewParams->inBuf));
#ifdef PREVIEWER_DEBUG
        x = CSL_FEXT(prevRegs->RSDR_ADDR, PREV_RSDR_ADDR_RADR);
        if (((Uint32)prevPreviewParams->inBuf) != x)
        {
            llcPrevDebugErrorStatus = 107;
        }
#endif /* PREVIEWER_DEBUG */

        /* write desti address */
        CSL_FINS(prevRegs->WSDR_ADDR, PREV_WSDR_ADDR_ADDR,
            ((Uint32)prevPreviewParams->outBuf));
#ifdef PREVIEWER_DEBUG
        x = CSL_FEXT(prevRegs->WSDR_ADDR, PREV_WSDR_ADDR_ADDR);
        if (((Uint32)prevPreviewParams->outBuf) != x)
        {
            llcPrevDebugErrorStatus = 108;
        }
#endif /* PREVIEWER_DEBUG */

        /* clear buffer memory overflow bit */
        CSL_FINS(vpssRegs->PCR, VPSS_PCR_PRV_WBL_O, 0);
#ifdef PREVIEWER_DEBUG
        x = CSL_FEXT(vpssRegs->PCR, VPSS_PCR_PRV_WBL_O);
        if (0 != x)
        {
            llcPrevDebugErrorStatus = 109;
        }
#endif /* PREVIEWER_DEBUG */

        /* trigger previewer */
        CSL_FINS(prevRegs->PCR, PREV_PCR_ENABLE,
            (Uint32)CSL_PREV_PCR_ENABLE_PREV_ENABLE);

        oneShotReturnCode = CSL_SOK;
    }
    return oneShotReturnCode;
}



/**
 *  LLC_prevChannelStatus
 *  It reads previewer status.
 */
CSL_Status LLC_prevChannelStatus(
    Uint8 *channelStatus,
    Ptr regs
    )
{
    CSL_Status chanStatusReturnCode = CSL_ESYS_INVPARAMS;
    Uint32 prevChannelStatus = PSP_PREVIEWER_CHANNEL_BUSY;


    /* parameter validation */
    if ((NULL == regs) || (NULL == channelStatus))
    {
        chanStatusReturnCode = CSL_ESYS_INVPARAMS;
    }
    else
    {
        prevRegs = (CSL_PrevRegsOvly)regs;
        prevChannelStatus = CSL_FEXT(prevRegs->PCR, PREV_PCR_BUSY);
        if (CSL_PREV_PCR_BUSY_NOTBUSY == prevChannelStatus)
        {
            *channelStatus = PSP_PREVIEWER_CHANNEL_FREE;
        }
        else
        {
            *channelStatus = PSP_PREVIEWER_CHANNEL_BUSY;
        }
        chanStatusReturnCode = CSL_SOK;
    }
    return chanStatusReturnCode;
}



/**
 *  LLC_prevPreviewerStatus
 *  It is used to read whether previwer is enabled or not.
 */
CSL_Status LLC_prevPreviewerStatus(
    Uint8 *previewerStatus,
    Ptr regs)
{
    CSL_Status previewerStatusReturnCode = CSL_ESYS_INVPARAMS;

    /* parameter validation */
    if ((NULL == regs) || (NULL == previewerStatus))
    {
        previewerStatusReturnCode = CSL_ESYS_INVPARAMS;
    }
    else
    {
        prevRegs = (CSL_PrevRegsOvly)regs;
        *previewerStatus = CSL_FEXT(prevRegs->PCR, PREV_PCR_ENABLE);
        previewerStatusReturnCode = CSL_SOK;
    }
    return previewerStatusReturnCode;
}



/**
 *  \LLC_prevDarkFrameStatus
 *  It reads dark frame subtract failure status.
 */
CSL_Status LLC_prevDarkFrameStatus(
    Uint8 *darkFrameStatus,
    Ptr regs
    )
{
    CSL_Status darkStatusReturnCode = CSL_ESYS_INVPARAMS;
    Uint32 prevDarkFrameStatus = PSP_PREVIEWER_DARK_FRAME_FAILED;

    /* parameter validation */
    if ((NULL == regs) || (NULL == darkFrameStatus))
    {
        darkStatusReturnCode = CSL_ESYS_INVPARAMS;
    }
    else
    {
        prevRegs = (CSL_PrevRegsOvly)regs;
        prevDarkFrameStatus = CSL_FEXT(prevRegs->PCR, PREV_PCR_DRK_FAIL);
        if (CSL_PREV_PCR_DRK_FAIL_FAIL == prevDarkFrameStatus)
        {
            *darkFrameStatus = PSP_PREVIEWER_DARK_FRAME_FAILED;
        }
        else
        {
            *darkFrameStatus = PSP_PREVIEWER_DARK_FRAME_WORKING;
        }
        darkStatusReturnCode = CSL_SOK;
    }
    return darkStatusReturnCode;
}

/**
 *  LLC_prevSetReadReqExpand
 *  It sets read request expand.
 */
CSL_Status LLC_prevSetReadReqExpand(Uint16 prevExp, Ptr regs)
{
    CSL_Status setReadReqReturnCode = CSL_ESYS_INVPARAMS;
#ifdef PREVIEWER_DEBUG
    Uint32 x;
#endif /* PREVIEWER_DEBUG */

    /* parameter validation */
    if ((NULL == regs) || (NULL == prevExp))
    {
        setReadReqReturnCode = CSL_ESYS_INVPARAMS;
    }
    else
    {
        vpssRegs = (CSL_VpssRegsOvly)regs;

        CSL_FINS(vpssRegs->SDR_REQ_EXP, VPSS_SDR_REQ_EXP_PRV_EXP,
            (Uint32)prevExp);
#ifdef PREVIEWER_DEBUG
        x = CSL_FEXT(vpssRegs->SDR_REQ_EXP, VPSS_SDR_REQ_EXP_PRV_EXP);
        if ((Uint32)prevExp != x)
        {
            llcPrevDebugErrorStatus = 110;
        }
#endif /* PREVIEWER_DEBUG */
        setReadReqReturnCode = CSL_SOK;
    }
    return setReadReqReturnCode;
}

/**
 *  LLC_prevGetWriteBufMemOverflow
 *  It gets write buffer memory overflow.
 */
CSL_Status LLC_prevGetWriteBufMemOverflow(Uint8 *prevWBLO, Ptr regs)
{
    CSL_Status getMemOverFlowReturnCode = CSL_ESYS_INVPARAMS;

    /* parameter validation */
    if ((NULL == regs) || (NULL == prevWBLO))
    {
        getMemOverFlowReturnCode = CSL_ESYS_INVPARAMS;
    }
    else
    {
        vpssRegs = (CSL_VpssRegsOvly)regs;
        *prevWBLO = CSL_FEXT(vpssRegs->PCR, VPSS_PCR_PRV_WBL_O);
        getMemOverFlowReturnCode = CSL_SOK;
    }
    return getMemOverFlowReturnCode;
}

/**
 *  \LLC_prevSetDFC
 *  It is used to set dark frame capture parameter.
 */
CSL_Status LLC_prevSetDFC(Uint8 DFCState, Uint16 outPitch, Ptr regs)
{
    CSL_Status setDFCReturnCode = CSL_ESYS_INVPARAMS;
#ifdef PREVIEWER_DEBUG
    Uint32 x;
#endif /* PREVIEWER_DEBUG */

    /* parameter validation */
    if (NULL == regs)
    {
        setDFCReturnCode = CSL_ESYS_INVPARAMS;
    }
    else
    {
        prevRegs = (CSL_PrevRegsOvly)regs;
        if (PSP_PREVIEWER_DARK_FRAME_CAPTURE_ENABLE == DFCState)
        {
            /* enable dark frame subtract in PCR */
            CSL_FINS(prevRegs->PCR, PREV_PCR_DRKFCAP,
                (Uint32)CSL_PREV_PCR_DRKFCAP_CAPT_DK_FRM);
#ifdef PREVIEWER_DEBUG
            x = CSL_FEXT(prevRegs->PCR, PREV_PCR_DRKFCAP);
            if ((Uint32)CSL_PREV_PCR_DRKFCAP_CAPT_DK_FRM != x)
            {
                llcPrevDebugErrorStatus = 111;
            }
#endif /* PREVIEWER_DEBUG */
        }
        else
        {
            /* enable dark frame subtract in PCR */
            CSL_FINS(prevRegs->PCR, PREV_PCR_DRKFCAP,
                (Uint32)CSL_PREV_PCR_DRKFCAP_NORMAL);
#ifdef PREVIEWER_DEBUG
            x = CSL_FEXT(prevRegs->PCR, PREV_PCR_DRKFCAP);
            if ((Uint32)CSL_PREV_PCR_DRKFCAP_NORMAL != x)
            {
                llcPrevDebugErrorStatus = 112;
            }
#endif /* PREVIEWER_DEBUG */
        }
        /* set offset value for output image */
        CSL_FINS(prevRegs->WADD_OFFSET, PREV_WADD_OFFSET_OFFSET,
            (Uint32)outPitch);
#ifdef PREVIEWER_DEBUG
        x = CSL_FEXT(prevRegs->WADD_OFFSET, PREV_WADD_OFFSET_OFFSET);
        if ((Uint32)outPitch != x)
        {
            llcPrevDebugErrorStatus = 113;
        }
#endif /* PREVIEWER_DEBUG */

        setDFCReturnCode = CSL_SOK;
    }
    return setDFCReturnCode;
}

