/*******************************************************************************
**+--------------------------------------------------------------------------+**
**|                            ****                                          |**
**|                            ****                                          |**
**|                            ******o***                                    |**
**|                      ********_///_****                                   |**
**|                      ***** /_//_/ ****                                   |**
**|                       ** ** (__/ ****                                    |**
**|                           *********                                      |**
**|                            ****                                          |**
**|                            ***                                           |**
**|                                                                          |**
**|         Copyright (c) 2006-2010 Texas Instruments Incorporated           |**
**|                        ALL RIGHTS RESERVED                               |**
**|                                                                          |**
**| Permission is hereby granted to licensees of Texas Instruments           |**
**| Incorporated (TI) products to use this computer program for the sole     |**
**| purpose of implementing a licensee product based on TI products.         |**
**| No other rights to reproduce, use, or disseminate this computer          |**
**| program, whether in part or in whole, are granted.                       |**
**|                                                                          |**
**| TI makes no representation or warranties with respect to the             |**
**| performance of this computer program, and specifically disclaims         |**
**| any responsibility for any damages, special or consequential,            |**
**| connected with the use of this program.                                  |**
**|                                                                          |**
**+--------------------------------------------------------------------------+**
*******************************************************************************/

/**
 *  \file   psp_previewerApi.h
 *
 *  \brief  PREVIEWER APIs defination
 *
 *  This file contains the APIs that are used at DDC layer of the driver.
 *
 *  (C) Copyright 2006, Texas Instruments, Inc
 *
 *  \author     EI2
 *
 *  \version    0.1          Created
 *              1.0          First Release
 */

#ifndef _PSP_PREVIEWERAPI_H_
#define _PSP_PREVIEWERAPI_H_

#ifdef __cplusplus
extern "C" {
#endif

/**
 *  \brief PSP_prevCreate
 *
 *  It creates a given previewer device at DDA layer.
 *  It performs parameter validation and initialize DDA port structure.
 *  Assign DDA port structure instance to devp.
 *
 *  \param  devHandle   [OUT]   Void pointer passed by the GIO Layer to
 *                              store the address of the port structure
 *  \return success             PSP_SOK
 *          failure             PSP error
 */
PSP_Result PSP_prevCreate(PSP_Handle* devHandle);

/**
 *  \brief PSP_prevOpen
 *
 *  It opens Channel of the previewer device.
 *  The function prepares channel of the driver instance for data transfers
 *  and returns an handle to the channel instance.It performs parameter
 *  validation and initialize DDA channel structure.It will update port
 *  structure. it will call function for interrupt mapping.
 *
 *  \param chanHandle   [OUT]     previewer Channel Handle which will
 *                                be used in subsequent ioctl calls
 *  \param devHandle    [IN/OUT]  pointer to the port structure
 *  \param chanParams   [IN/OUT]  Extra parameter, will be passed at DDC layer
 *  \return success               PSP_SOK
 *          failure               PSP error
 */
PSP_Result PSP_prevOpen(PSP_Handle *chanHandle,
    PSP_Handle devHandle,
    PSP_previewerChannelCreateMode *chanParams);

/**
 *  \brief PSP_prevIoctl
 *  It controls Channel of the previewer device.
 *  This function provides ioctl functionality for previewer.It will call IOCTL
 *  of DDC layer.
 *
 *  \param chanHandle   [IN]     previewer Channel Handle
 *  \param  cmd         [IN]     Operation to be performed, typically an enum
 *                               gets passed
 *  \param  cmdArg      [IN/OUT] Provides additonal information related to the
 *                               operation
 *  \return success              PSP_SOK
 *          failure              PSP error
 */
PSP_Result PSP_prevIoctl(PSP_Handle chanHandle,
    PSP_previewerControlCmd cmd,
    Ptr cmdArg);

/**
 *  \brief PSP_prevClose
 *
 *  It closes Channel of the previewer device.
 *  This function is used to close Channel handle for previewer.
 *
 *  \param  chanHandle  [IN]    previewer Channel Handle
 *  \return success             PSP_SOK
 *          failure             PSP error
 */
PSP_Result PSP_prevClose(PSP_Handle chanHandle);

/**
 *  \brief PSP_prevDelete
 *
 *  It deletes a given previewer device at DDA layer.
 *  This function is called last and is used for driver deletion.This function
 *  does the deletion of the previewer device instance.
 *
 *  \param  devHandle   [IN]    pointer to DDA port structure instance
 *  \return success             PSP_SOK
 *          failure             PSP error
 */
PSP_Result PSP_prevDelete(PSP_Handle devHandle);

/**
 *  \brief PSP_prevGetPSPHandle
 *
 *  It returns PSP handle of channel object.
 *  This function is called from CCDC, in on the fly mode,
 *  to get the handle of channel object, which will be used in subsequent calls
 *
 *  \param  chanHandle   [OUT]  pointer to DDA channel handle
 *  \return success             PSP_SOK
 *          failure             PSP error
 */
PSP_Result PSP_prevGetPSPHandle(PSP_Handle *chanHandle);
#ifdef __cplusplus
}
#endif

#endif /* _PSP_PREVIEWERAPI_H_ */
