/*******************************************************************************
**+--------------------------------------------------------------------------+**
**|                            ****                                          |**
**|                            ****                                          |**
**|                            ******o***                                    |**
**|                      ********_///_****                                   |**
**|                      ***** /_//_/ ****                                   |**
**|                       ** ** (__/ ****                                    |**
**|                           *********                                      |**
**|                            ****                                          |**
**|                            ***                                           |**
**|                                                                          |**
**|         Copyright (c) 2006-2010 Texas Instruments Incorporated           |**
**|                        ALL RIGHTS RESERVED                               |**
**|                                                                          |**
**| Permission is hereby granted to licensees of Texas Instruments           |**
**| Incorporated (TI) products to use this computer program for the sole     |**
**| purpose of implementing a licensee product based on TI products.         |**
**| No other rights to reproduce, use, or disseminate this computer          |**
**| program, whether in part or in whole, are granted.                       |**
**|                                                                          |**
**| TI makes no representation or warranties with respect to the             |**
**| performance of this computer program, and specifically disclaims         |**
**| any responsibility for any damages, special or consequential,            |**
**| connected with the use of this program.                                  |**
**|                                                                          |**
**+--------------------------------------------------------------------------+**
*******************************************************************************/

/**
 *  \file   dda_rsz.c
 *
 *  \brief
 *
 *  This file contains the implementation of the Resizer driver to utilize the
 *  serivces of the Resizer device driver.
 *
 *  (C) Copyright 2010, Texas Instruments, Inc
 *
 *  \author     EI3
 *
 *  \version    0.1     Created
 *              1.0     First release
 */
/******************************************************************************
  Header File Inclusion
 ******************************************************************************/
#include <ti/sdo/pspdrivers/soc/dm6437/dsp/tistdtypes.h>
#include <ti/sdo/pspdrivers/common/psp_common.h>
#include <ti/sdo/pspdrivers/drivers/resizer/src/dda_rszIom_BIOS.h>


/******************************************************************************
  Function prottotypes
 ******************************************************************************/
PSP_Handle  PSP_RSZCreate(Uint32 instanceId);
PSP_Result PSP_RSZDelete(Uint32 instanceId);
PSP_Handle  PSP_RSZOpen(Int  segId);
PSP_Result PSP_RSZClose(PSP_Handle handle);
PSP_Result  PSP_RSZIoctl(PSP_Handle handle, PSP_RSZIoctlCmd cmd, Ptr cmdArg,
                         Ptr params);


/******************************************************************************
  Functions
 ******************************************************************************/
/**
 *    \brief   Function PSP_RSZCreate
 *    Create the given Resizer driver instance
 */
PSP_Handle  PSP_RSZCreate(Uint32 instanceId)
{

    DDC_RSZDeviceObject *rszDeviceHandleCreate;
    /* Validate instance ID */
    if (PSP_RSZ_NUM_INSTANCES <= instanceId)
    {
        rszDeviceHandleCreate= NULL;
    }

    /* Get the interrupt number for interrupt registeration */
    DDC_RSZSetDeviceInterruptNumber();

    /* Store Register Base address to the RSZ structure */
    DDC_RSZPerformRegOvrl();

    /* Initialize the Device specific variables and semaphores */
    rszDeviceHandleCreate= DDC_RSZInitializeModule();
    if (NULL != rszDeviceHandleCreate)
    {

        DDA_RSZRegisterIntrHandler(rszDeviceHandleCreate->IntNum);
    }

    return((Ptr)rszDeviceHandleCreate);
}

/**
 * \brief  Function PSP_RSZDelete
 * Delete a given Resizer driver instance
 */
PSP_Result PSP_RSZDelete(Uint32 instanceId)
{
    Int  status;
    DDC_RSZDeviceObject * rszDeviceHandleDelete;

    status = PSP_E_INVAL_PARAM;

    /* Validate instance ID */
    if (instanceId >= PSP_RSZ_NUM_INSTANCES )
    {
        status = IOM_EBADARGS;
    }

    /* set state to deleted */
    rszDeviceHandleDelete =DDC_RSZRemoveModule ();
    if (NULL != rszDeviceHandleDelete)
    {
        /* unregister the interrupt handler */
        DDA_RSZUnregisterIntrHandler(rszDeviceHandleDelete->IntNum);
        status  =   PSP_SOK;
    }
    return (status);
}

/**
 * \brief  Function PSP_RSZOpen
 * It configures the Resizer Module and return the Channel Handle
 */

PSP_Handle  PSP_RSZOpen(Int  segId)
{
    PSP_Handle handleToReturn     = NULL;

    /* Call to DDC level function to initialize the channel specific variables*/
    handleToReturn = (PSP_Handle)DDC_RSZOpenHandle(segId);

    return (handleToReturn);
}

/**
 * \brief Function PSP_RSZClose
 * Close the Resizer channel with the specified handle
 */
PSP_Result PSP_RSZClose(PSP_Handle handle)
{
    PSP_Result result         = PSP_E_INVAL_PARAM;

    if (NULL != handle)
    {

        if (DDC_RSZ_SOK == DDC_RSZCloseHandle(handle))
        {
            result    =   PSP_SOK;
        }
    }
    return (result);
}


/**
 * \brief Function PSP_RSZIoctl
 * I/O Control of the Resizer device
 */
/* ARGSUSED */
PSP_Result  PSP_RSZIoctl(PSP_Handle handle,
    PSP_RSZIoctlCmd         cmd,
    Ptr                     cmdArg,
    Ptr                     params)
{
    PSP_Result resultIO     =   PSP_E_INVAL_PARAM;

    if (NULL == cmdArg)
    {
        resultIO = PSP_E_INVAL_PARAM;
    }
    if ((NULL == handle) || (DDC_RSZ_SOK
            == DDC_RSZIsChannelHandleClosed(handle)))
    {
        resultIO = PSP_E_INVAL_PARAM;
    }
    else
    {
        resultIO = DDC_RSZIoctl(handle, cmd, cmdArg, NULL);
    }
    /* Map DDC return codes with PSP codes */
    switch(resultIO)
    {
        case DDC_RSZ_SOK:
            resultIO = PSP_SOK;
            break;
        case DDC_RSZ_E_FAIL:
        case DDC_RSZ_INVALID_STATE:
            resultIO = PSP_E_INVALID_MODE;
            break;
        case DDC_RSZ_INVALID_PARAM:
            resultIO = PSP_E_INVAL_PARAM;
            break;
        case DDC_RSZ_NOT_SUPPORTED:
            resultIO = PSP_E_NOT_SUPPORTED;
            break;
        case DDC_RSZ_E_TIMEOUT:
            resultIO = PSP_E_IO_CANCEL_FAIL;
            break;
        case DDC_RSZ_SINPROGRESS:
            resultIO = PSP_SINPROGRESS;
            break;
        default:
            resultIO = PSP_E_INVALID_MODE;
            break;
    }

    return (resultIO);
}
