/*******************************************************************************
**+--------------------------------------------------------------------------+**
**|                            ****                                          |**
**|                            ****                                          |**
**|                            ******o***                                    |**
**|                      ********_///_****                                   |**
**|                      ***** /_//_/ ****                                   |**
**|                       ** ** (__/ ****                                    |**
**|                           *********                                      |**
**|                            ****                                          |**
**|                            ***                                           |**
**|                                                                          |**
**|         Copyright (c) 2006-2010 Texas Instruments Incorporated           |**
**|                        ALL RIGHTS RESERVED                               |**
**|                                                                          |**
**| Permission is hereby granted to licensees of Texas Instruments           |**
**| Incorporated (TI) products to use this computer program for the sole     |**
**| purpose of implementing a licensee product based on TI products.         |**
**| No other rights to reproduce, use, or disseminate this computer          |**
**| program, whether in part or in whole, are granted.                       |**
**|                                                                          |**
**| TI makes no representation or warranties with respect to the             |**
**| performance of this computer program, and specifically disclaims         |**
**| any responsibility for any damages, special or consequential,            |**
**| connected with the use of this program.                                  |**
**|                                                                          |**
**+--------------------------------------------------------------------------+**
*******************************************************************************/

/**
 *  \file   dda_rszBios.c
 *
 *  \brief  Resizer Driver Adaptation for BIOS
 *
 *  This file contains adaptation of Resizer driver for BIOS
 *
 *  (C) Copyright 2010, Texas Instruments, Inc
 *
 *
 *  \author     EI3
 *
 *  \version    0.1     Created
 *              1.0     First release
 */
/******************************************************************************
  Header File Inclusion
 ******************************************************************************/
#include <std.h>
#include <iom.h>
#include <C64.h>
#include <ecm.h>
#include <ti/sdo/pspdrivers/pal_os/pal_osprotect.h>
#include <ti/sdo/pspdrivers/soc/dm6437/dsp/soc.h>
#include <ti/sdo/pspdrivers/drivers/resizer/src/ddc_rsz.h>


/******************************************************************************
  Macros
 ******************************************************************************/
/**
 * \brief Hardware Resizer interrupt number
 *
 */
#define HWI_RSZ_INTR_NUM        (HWI_EVT01_CMB_IRQ)


/******************************************************************************
  Function prototypes
 ******************************************************************************/

void DDA_RSZRegisterIntrHandler(Uint32 IntNum);
void DDA_RSZUnregisterIntrHandler(Uint32 intrNum);


/******************************************************************************
  Functions
 ******************************************************************************/

/**
 * \brief Function DDA_RSZRegisterIntrHandler
 * Registers interrupt with BIOS and enable it
 *
 */
void DDA_RSZRegisterIntrHandler(Uint32 IntNum)
{
    ECM_Attrs ecmattrs = ECM_ATTRS;

    /* Disabling the event */
    ECM_disableEvent((Uns)IntNum);

    /* Mapping the eventid to the ECM Dispatch of the DSP/BIOS */
    ecmattrs.unmask = (int)1;
    ECM_dispatchPlug(IntNum, (ECM_Fxn)&DDC_RSZIsr, &ecmattrs);
    /* Enabling the event */
    ECM_enableEvent(IntNum);

    /* Enabling Interrupt of CPU */
    C64_enableIER(HWI_RSZ_INTR_NUM);

}

/******************************************************************************
  Un-Register all the interrrupt with BIOS and disable these
  *****************************************************************************/
/**
 * \brief Function DDA_RSZUnregisterIntrHandler
 * Un-Registers interrupt with BIOS.
 *
 */
void DDA_RSZUnregisterIntrHandler(Uint32 intrNum)
{

    /* Disabling resizer interrupt */
    ECM_disableEvent(intrNum);

}

