/*******************************************************************************
**+--------------------------------------------------------------------------+**
**|                            ****                                          |**
**|                            ****                                          |**
**|                            ******o***                                    |**
**|                      ********_///_****                                   |**
**|                      ***** /_//_/ ****                                   |**
**|                       ** ** (__/ ****                                    |**
**|                           *********                                      |**
**|                            ****                                          |**
**|                            ***                                           |**
**|                                                                          |**
**|         Copyright (c) 2006-2010 Texas Instruments Incorporated           |**
**|                        ALL RIGHTS RESERVED                               |**
**|                                                                          |**
**| Permission is hereby granted to licensees of Texas Instruments           |**
**| Incorporated (TI) products to use this computer program for the sole     |**
**| purpose of implementing a licensee product based on TI products.         |**
**| No other rights to reproduce, use, or disseminate this computer          |**
**| program, whether in part or in whole, are granted.                       |**
**|                                                                          |**
**| TI makes no representation or warranties with respect to the             |**
**| performance of this computer program, and specifically disclaims         |**
**| any responsibility for any damages, special or consequential,            |**
**| connected with the use of this program.                                  |**
**|                                                                          |**
**+--------------------------------------------------------------------------+**
*******************************************************************************/

/**
 *  \file   ddc_rsz.c
 *
 *  \brief  rsz implementation
 *
 *  This file contains the implementation of the rsz driver to utilize the
 *  serivces of the rsz device driver.
 *
 *  (C) Copyright 2010, Texas Instruments, Inc
 *
 *  \author     EI3
 *
 *  \version    0.1     created
 *              1.0     First release
 */

/******************************************************************************
  Header File Inclusion
 ******************************************************************************/
#include <ti/sdo/pspdrivers/common/psp_common.h>
#include <ti/sdo/pspdrivers/pal_os/pal_osSem.h>
#include <ti/sdo/pspdrivers/pal_os/pal_osProtect.h>
#include <ti/sdo/pspdrivers/pal_os/pal_osMem.h>
#include <ti/sdo/pspdrivers/drivers/resizer/psp_resizer.h>
#include <ti/sdo/pspdrivers/drivers/resizer/src/ddc_rsz.h>
#include <ti/sdo/pspdrivers/drivers/resizer/src/llc_rsz.h>
#include <ti/sdo/pspdrivers/soc/dm6437/dsp/soc.h>
#include <ti/sdo/pspdrivers/soc/dm6437/dsp/cslr_resz.h>
#ifdef RESIZER_INSTRUMENTATION_ENABLED
#include <ti/sdo/pspdrivers/pal_os/bios/psp_log.h>
#endif /*RESIZER_INSTRUMENTATION_ENABLED */


/******************************************************************************
  Data-Structures
 ******************************************************************************/
/**
 * \brief rsz device object handle
 */
DDC_RSZDeviceObject         rszDeviceObject;

/******************************************************************************
  Function Prototypes
 ******************************************************************************/

PSP_Handle DDC_RSZOpenHandle(Int segmentId);
PSP_Handle DDC_RSZGetDeviceHandle(void);
void * DDC_RSZGetChannelHandle(Int segId);
DDC_RSZStatus DDC_RSZCloseHandle(Ptr handle);
DDC_RSZStatus DDC_RSZIsChannelHandleClosed(Ptr handleCH);
void DDC_RSZIsr(Uint32 arg);
void DDC_RSZPerformRegOvrl(void);
void DDC_RSZSetDeviceInterruptNumber();
static Int DDC_RSZStartResize(DDC_RSZChanObject * const rszConfChan,
    PSP_RSZresize * const resize);
static Int DDC_RSZStartAsyncResize(DDC_RSZChanObject * const rszConfChan,
    PSP_RSZresize * const resize);
Int DDC_RSZAddToArray(DDC_RSZChanObject * const rszConfChan);
Int DDC_RSZDeleteFromArray(DDC_RSZChanObject * const rszConfChan);
Int DDC_RSZValidateParameters(DDC_RSZChanObject * rszConfChan,
    PSP_RSZparams  * const rszparams);
Int DDC_RSZGetParameters(DDC_RSZChanObject * const rszConfChan,
    PSP_RSZparams  * const params);
Int DDC_RSZGetCropSize(DDC_RSZChanObject * const rszConfChan,
    PSP_RSZcropsize * const cropsize);
Int DDC_RSZGetPriority(DDC_RSZChanObject * const rszConfChan,
    PSP_RSZpriority * const prio);
Int DDC_RSZGetStatus(DDC_RSZChanObject * const rszConfChan,
    PSP_RSZstatus * const status);
Int DDC_RSZSetPriority(DDC_RSZChanObject * const rszConfChan,
    PSP_RSZpriority * const prio);
PSP_Result  DDC_RSZIoctl(PSP_Handle handle, PSP_RSZIoctlCmd cmd, Ptr cmdArg,
    Ptr params);
void* DDC_RSZInitializeModule ();
Void * DDC_RSZRemoveModule (void);


/******************************************************************************
  Functions
 ******************************************************************************/
/**
 * \brief  Function DDC_RSZOpenHandle
 * This function validate the parameters and configure the hardware
 *             and return the Channel Handle
 */
PSP_Handle DDC_RSZOpenHandle(Int segmentId)
{
    DDC_RSZDeviceObject *rszDeviceHandleOpen = NULL;
    DDC_RSZChanObject *handleToReturnOH = NULL;
    Int statusOH = DDC_RSZ_SOK;


    /*Get the Device Handle */
    rszDeviceHandleOpen = (DDC_RSZDeviceObject* )DDC_RSZGetDeviceHandle();
    if (NULL == rszDeviceHandleOpen)
    {
        statusOH = DDC_RSZ_E_FAIL;
    }
    else
    {
        if (((PSP_RESIZER_CREATED != rszDeviceHandleOpen->state)
                && (PSP_RESIZER_CLOSED != rszDeviceHandleOpen->state))
            && (PSP_RESIZER_OPENED != rszDeviceHandleOpen->state))
        {
            statusOH = DDC_RSZ_E_FAIL;
        }
        else
        {
            /*Get the Channel Handle based on Channel id */
            handleToReturnOH = DDC_RSZGetChannelHandle(segmentId);

            /*Check params and Channel Handle not NULL */
            if ( (NULL == handleToReturnOH))
            {
                    DDC_DEBUG_PRINTF("\n cannot allocate memory to channel structure");
                    statusOH = DDC_RSZ_E_FAIL;
            }
            else
            {
                    /* Initialize the params structure to 0 */
                    if (PAL_SOK != PAL_osMemSet(&(handleToReturnOH->params),
                                            ZERO, sizeof(LLC_ResizerConfigParams)))
                    {
                            PAL_osMemFree(segmentId, handleToReturnOH,sizeof(DDC_RSZChanObject));
                            handleToReturnOH = NULL;
                            statusOH = DDC_RSZ_E_FAIL;
                    }
                    else
                    {
                            /*Set STATE_NOT_CONFIGURED and priority to  zero*/
                            handleToReturnOH->DDC_ParamsConfigState = STATE_NOT_CONFIGURED;

                            /* Set priority to lowest for that configuration channel*/
                            handleToReturnOH->priority = MIN_PRIORITY;
                            handleToReturnOH->MemSegId = segmentId;
                            handleToReturnOH->ChannelStatus = CHANNEL_FREE;
                            handleToReturnOH->semTimeOut = PAL_OSSEM_NO_TIMEOUT;

                            /* Create Channel specific semaphore */
                            if (PAL_osSemCreate("channelSem", ZERO, NULL,
                                                    &(handleToReturnOH->ChannelSem))!= PAL_SOK)
                            {
                                    PAL_osMemFree(segmentId, handleToReturnOH,sizeof(DDC_RSZChanObject));
                                    handleToReturnOH = NULL;
                            }

                            /* Update the channel and device state */
                            handleToReturnOH->state  = DDC_RSZCHANOPENED;
                            rszDeviceHandleOpen->state = PSP_RESIZER_OPENED;
                    }
            }
        }
        /* Reset the register values */
        statusOH = LLC_RSZResetRegister(rszDeviceHandleOpen->regs);

        if (DDC_RSZ_E_FAIL == statusOH)
        {
                PAL_osMemFree(segmentId, handleToReturnOH, sizeof(DDC_RSZChanObject));
                handleToReturnOH = NULL;
        }
    }

    return ((void  *)(handleToReturnOH));
}

/**
 * \brief  Function DDC_RSZCloseHandle
 *         This function close the Resizer driver Channel handle
 *             once created.
 */
DDC_RSZStatus DDC_RSZCloseHandle(Ptr handle)
{

    DDC_RSZChanObject *handleToReturnCH = NULL;
    DDC_RSZDeviceObject * handleDeviceCH = NULL;
    DDC_RSZStatus resultCL = DDC_RSZ_INVALID_PARAM;

    /*Get the Device Handle */
    if ((NULL != handle))
    {
        handleToReturnCH = (DDC_RSZChanObject *)handle;

        handleDeviceCH = (DDC_RSZDeviceObject* )DDC_RSZGetDeviceHandle();

        /* Check Device handle not NULL */
        if ((NULL != handleDeviceCH)&&(NULL != handleToReturnCH))
        {
                /*free the channel instance by pal_osMemFree*/
                if ((PAL_SOK != PAL_osSemDelete(handleToReturnCH->ChannelSem)) ||
                                (PAL_SOK != PAL_osMemFree(handleToReturnCH->MemSegId, handle,
                                                          sizeof(DDC_RSZChanObject))))
                {
                        resultCL = DDC_RSZ_E_FAIL;
                }
                else
                {
                        handleDeviceCH ->state = PSP_RESIZER_CLOSED;
                        resultCL = DDC_RSZ_SOK;
                }
        }
    }

    return resultCL;
}


/**
 * \brief  Function DDC_RSZIsChannelHandleClosed
 *  Check if the handle is in closed state
 *
 */
DDC_RSZStatus DDC_RSZIsChannelHandleClosed(Ptr handleCH)
{

    DDC_RSZStatus resultICH = DDC_RSZ_INVALID_PARAM;
    DDC_RSZChanObject * handleICH;

    if (NULL != handleCH)
    {

        handleICH     = (DDC_RSZChanObject *)handleCH;
        /*Check the State of  Channel if Closed */
        if (handleICH->state == DDC_RSZCHANCLOSED)
        {
            resultICH = DDC_RSZ_SOK;
        }
    }
    return(resultICH);
}

/**
 * \brief  Function DDC_RSZGetDeviceHandle
 * To Get RSZ device handle
 */
PSP_Handle DDC_RSZGetDeviceHandle(void)
{
    return((void *)&rszDeviceObject);
}
/**
 * \brief  Function DDC_RSZGetChannelHandle
 * This function will returns the different Resizer channel
 *             handle
 */
void * DDC_RSZGetChannelHandle(Int segId)
{
    DDC_RSZChanObject *handleToReturnGH = NULL;
    Ptr Memptr = NULL;

    if ((NULL == Memptr) && (NULL == handleToReturnGH))
    {

        /* Allocate memory to channel handle and return handle */
        PAL_osMemAlloc(segId, sizeof(DDC_RSZChanObject), NULL,
            (Ptr *)(&handleToReturnGH));

        /* Clear the memory */
        if(NULL != handleToReturnGH)
        {
            if (PAL_SOK !=
                PAL_osMemSet(handleToReturnGH, 0, sizeof(DDC_RSZChanObject)))
            {
                handleToReturnGH = NULL;
            }
        }

    }
    return ((void *)(handleToReturnGH));
}


/**
 * \brief  Function DDC_RSZIsr
 * Interrupt service routine for Resizer device driver.
 */
/* ARGSUSED */
void DDC_RSZIsr(Uint32 arg)
{
    DDC_RSZDeviceObject * rszDeviceHandle
        = (DDC_RSZDeviceObject * )DDC_RSZGetDeviceHandle();

    if (NULL != rszDeviceHandle)
    {

#ifdef RESIZER_INSTRUMENTATION_ENABLED
        PSP_LOG_EVENT(  &DVTEvent_Log,
            "Resizer",
            PSP_DVT_DESC(   PSP_DVT_eINT_START,
                    PSP_DVT_dCHANNEL_ID,
                    PSP_DVT_dNONE,
                    PSP_DVT_dNONE),
            0);
#endif /* RESIZER_INSTRUMENTATION_ENABLED */
        if(TRUE != rszDeviceHandle->isAsyncResize)
        {
            /* Release the semaphore for ISR */
            /* This is to be done only in the case of sync calls for resizing,* 
             * where semaphores are used in the path                          */
               PAL_osSemGive(rszDeviceHandle->SemIsr);
        }
        else
        {
            /* This to be done only in case of (pseudo)async calls of resizing* 
             * where callback notification is used for resizing complete. The *
             * application shall then take care of the result in the callback */
             
             if((NULL != rszDeviceHandle->appCbk.fxn) && 
                (NULL != rszDeviceHandle->appCbk.arg))
             {
                 (rszDeviceHandle->appCbk.fxn)(rszDeviceHandle->appCbk.arg,
                                               DDC_RSZ_SOK,
                                               rszDeviceHandle->asyncBufPtr,
                                               rszDeviceHandle->asyncBufSize);
             }
             rszDeviceHandle->isResizeBusy = FALSE;
        }

#ifdef RESIZER_INSTRUMENTATION_ENABLED

        /* PSP_DVT_dSIZE_BYTES = Odd or Even field in Interlaced */
        PSP_LOG_EVENT(  &DVTEvent_Log,
            "Resizer",
            PSP_DVT_DESC(   PSP_DVT_eINT_END,
                    PSP_DVT_dCHANNEL_ID,
                    PSP_DVT_dNONE,
                    PSP_DVT_dNONE),
            0);
#endif /* RESIZER_INSTRUMENTATION_ENABLED */
    }

    return;
}
/**
 * \brief  Function DDC_RSZPerformRegOvrl
 * It will Perform register overlaying
 */
void DDC_RSZPerformRegOvrl(void)
{
    DDC_RSZDeviceObject * rszDeviceHandlePR = NULL;

    if (NULL == rszDeviceHandlePR)
    {
        rszDeviceHandlePR = (DDC_RSZDeviceObject *)DDC_RSZGetDeviceHandle();

        rszDeviceHandlePR->regs = (Ptr )CSL_VPSS_RESZ_0_REGS;
    }
}
/**
 * \brief Function DDC_RSZSetDeviceInterruptNumber
 * Set device ISR number
 */
void DDC_RSZSetDeviceInterruptNumber()
{
    DDC_RSZDeviceObject * rszDeviceHandleSIN = NULL;
    /*Get the Device Handle */
    if (NULL == rszDeviceHandleSIN)
    {
        rszDeviceHandleSIN = (DDC_RSZDeviceObject *)DDC_RSZGetDeviceHandle();
    }
    /*Set the Interrupt Number */
    rszDeviceHandleSIN->IntNum = (Int )CSL_INTC_EVENTID_RSZINT;

}

/**
 * \brief Function DDC_RSZStartAsyncResize
 * This function start the resizing operation after parameters are configured
 *
 */

static Int DDC_RSZStartAsyncResize(DDC_RSZChanObject * const rszConfChan,
    PSP_RSZresize * const resize)
{
    /* Conatains the input put and output buffer allocated size*/
    Int out_bufsize, in_bufsize, statusRSZ = DDC_RSZ_SOK;

    /* Conatins the pitch and vertical size of input and output image*/
    Int in_vsize, in_pitch, out_vsize, out_pitch;

    /* holds the return_value */
    DDC_RSZDeviceObject * rszDeviceHandleSR
        = (DDC_RSZDeviceObject * )DDC_RSZGetDeviceHandle();


    if ((NULL == rszConfChan)||(NULL == rszDeviceHandleSR)||(NULL == resize))
    {
        statusRSZ = DDC_RSZ_E_FAIL;
    }
    else
    {
#ifdef RESIZER_INSTRUMENTATION_ENABLED
        PSP_LOG_EVENT(  &DVTEvent_Log,
                        "Resizer",
                        PSP_DVT_DESC(   PSP_DVT_eFUNC_START,
                            PSP_DVT_dCHANNEL_ID_INST,
                            PSP_DVT_dPACKET_ID,
                            PSP_DVT_dSIZE_BYTES),
                        CHANNELID_INSTANCEID(
                            0,
                            0),
                        resize,
                        resize->inBufSize * resize->outBufSize
                     );
#endif /*RESIZER_INSTRUMENTATION_ENABLED */

        /* checking the configuartion status*/

        if (STATE_NOT_CONFIGURED
            == (rszConfChan->DDC_ParamsConfigState))
        {

            statusRSZ = DDC_RSZ_INVALID_PARAM;
        }
        else
        {
            /* Taking the inpitch of the image*/
            in_pitch = (Int)(rszConfChan->params.inPitch);
            /* Taking the out pitch of image*/
            in_vsize = (Int)(rszConfChan->params.inVsize);

            in_bufsize = (Int)(in_vsize * in_pitch);

            /*getting the outpitch*/
            out_pitch = (Int)rszConfChan->params.outPitch;

            /* getting the vertical size*/
            out_vsize = rszConfChan->params.outVsize;

            out_bufsize = out_vsize * out_pitch;
            if (ZERO != ((Int32)(resize->inBuf) % ALIGN32))
            {
                DDC_DEBUG_PRINTF(
                    "Input buffer addres not 32 bit align \n");
                statusRSZ = DDC_RSZ_INVALID_PARAM;
            }
            if (ZERO != ((Int32)(resize->outBuf) % ALIGN32))
            {
                DDC_DEBUG_PRINTF(
                    "Output buffer addres not 32 bit aligd \n");
                statusRSZ = DDC_RSZ_INVALID_PARAM;
            }


            /* assignning the address to the register configuration*/
            if ((resize->inBufSize) >= in_bufsize)
            {

                rszConfChan->params.inAddress = (Int)resize->inBuf;
            }
            else
            {
                DDC_DEBUG_PRINTF("Not enough input buffer size \n");
                statusRSZ = DDC_RSZ_INVALID_PARAM;
            }

            if ((resize->outBufSize >= out_bufsize)
                && (statusRSZ != DDC_RSZ_INVALID_PARAM))
            {
                rszConfChan->params.outAddress = (Int)resize->outBuf;
            }
            else
            {
                DDC_DEBUG_PRINTF("Not enough output buffer size \n");
                statusRSZ = DDC_RSZ_INVALID_PARAM;
            }

            /* Function call to add the entry of application in array*/
            if (DDC_RSZ_SOK == statusRSZ)
            {
                rszConfChan->state = DDC_RSZChannelBUSY;

                /*Function call to set up the hardware*/
#ifdef RESIZER_INSTRUMENTATION_ENABLED
                PSP_LOG_EVENT(  &DVTEvent_Log,
                    "Resizer",
                    PSP_DVT_DESC(   PSP_DVT_eFUNC_START,
                        PSP_DVT_eDATA_SND_START,
                        PSP_DVT_dPACKET_ID,
                        PSP_DVT_dNONE),
                    CHANNELID_INSTANCEID(
                        0,
                        0),
                    resize);
#endif /*RESIZER_INSTRUMENTATION_ENABLED */

                statusRSZ = LLC_RSZHardwareSetup(
                    (LLC_ResizerConfigParams *)
                    (&(rszConfChan->params)),
                    rszDeviceHandleSR->regs);

                statusRSZ = LLC_RSZresizerEnable(rszDeviceHandleSR->regs);

                if (SUCESS == statusRSZ)
                {
                    statusRSZ = DDC_RSZ_SOK;
                }

#ifdef RESIZER_INSTRUMENTATION_ENABLED
                PSP_LOG_EVENT(  &DVTEvent_Log,
                    "Resizer",
                    PSP_DVT_DESC(   PSP_DVT_eDATA_SND_END,
                        PSP_DVT_dCHANNEL_ID_INST,
                        PSP_DVT_dPACKET_ID,
                        PSP_DVT_dNONE),
                    CHANNELID_INSTANCEID(
                        0,
                        0),
                    resize);
#endif /*RESIZER_INSTRUMENTATION_ENABLED */

                if ((LLC_GetWriteBufferStatus() != ZERO) &&
                    (DDC_RSZ_SOK == statusRSZ))
                {
                    statusRSZ = DDC_RSZ_E_FAIL;
                    DDC_DEBUG_PRINTF(
                        "Error: Resizer write  buffer overflow");
                }
            }
            rszConfChan->state = DDC_RSZChannelFREE;
        }
    }
#ifdef RESIZER_INSTRUMENTATION_ENABLED
    PSP_LOG_EVENT(  &DVTEvent_Log,
        "Resizer",
        PSP_DVT_DESC(   PSP_DVT_eFUNC_END,
            PSP_DVT_dCHANNEL_ID_INST,
            PSP_DVT_dPACKET_ID,
            PSP_DVT_dSIZE_BYTES),
        CHANNELID_INSTANCEID(
            0,
            0),
        resize,
        0);
#endif /*RESIZER_INSTRUMENTATION_ENABLED */
    
    if(DDC_RSZ_SOK == statusRSZ)
    {
         statusRSZ = DDC_RSZ_SINPROGRESS; 
    }

    return statusRSZ;
}


/**
 * \brief Function DDC_RSZStartResize
 * This function start the resizing operation after parameters are configured
 *
 */

static Int DDC_RSZStartResize(DDC_RSZChanObject * const rszConfChan,
    PSP_RSZresize * const resize)
{
    /* Conatains the input put and output buffer allocated size*/
    Int out_bufsize, in_bufsize, statusRSZ = DDC_RSZ_SOK, statusDelArr;

    /* Conatins the pitch and vertical size of input and output image*/
    Int in_vsize, in_pitch, out_vsize, out_pitch;

    /* holds the return_value */
    DDC_RSZDeviceObject * rszDeviceHandleSR
        = (DDC_RSZDeviceObject * )DDC_RSZGetDeviceHandle();


    if (NULL == rszConfChan)
    {
        statusRSZ = DDC_RSZ_E_FAIL;
    }
    else
    {

        if (NULL == rszDeviceHandleSR)
        {
            statusRSZ = DDC_RSZ_E_FAIL;
        }
        else
        {

            if (NULL == resize)
            {
                statusRSZ = DDC_RSZ_E_FAIL;
            }
            else
            {

#ifdef RESIZER_INSTRUMENTATION_ENABLED
            PSP_LOG_EVENT(  &DVTEvent_Log,
                            "Resizer",
                            PSP_DVT_DESC(   PSP_DVT_eFUNC_START,
                                PSP_DVT_dCHANNEL_ID_INST,
                                PSP_DVT_dPACKET_ID,
                                PSP_DVT_dSIZE_BYTES),
                            CHANNELID_INSTANCEID(
                                0,
                                0),
                            resize,
                            resize->inBufSize * resize->outBufSize
                         );
#endif /*RESIZER_INSTRUMENTATION_ENABLED */

                /* checking the configuartion status*/

                if (STATE_NOT_CONFIGURED
                    == (rszConfChan->DDC_ParamsConfigState))
                {

                    statusRSZ = DDC_RSZ_INVALID_PARAM;
                }
                else
                {

                    /* Taking the inpitch of the image*/
                    in_pitch = (Int)(rszConfChan->params.inPitch);
                    /* Taking the out pitch of image*/
                    in_vsize = (Int)(rszConfChan->params.inVsize);

                    in_bufsize = (Int)(in_vsize * in_pitch);

                    /*getting the outpitch*/
                    out_pitch = (Int)rszConfChan->params.outPitch;

                    /* getting the vertical size*/
                    out_vsize = rszConfChan->params.outVsize;

                    out_bufsize = out_vsize * out_pitch;
                    if (ZERO != ((Int32)(resize->inBuf) % ALIGN32))
                    {
                        DDC_DEBUG_PRINTF(
                            "Input buffer addres not 32 bit align \n");
                        statusRSZ = DDC_RSZ_INVALID_PARAM;
                    }
                    if (ZERO != ((Int32)(resize->outBuf) % ALIGN32))
                    {
                        DDC_DEBUG_PRINTF(
                            "Output buffer addres not 32 bit aligd \n");
                        statusRSZ = DDC_RSZ_INVALID_PARAM;
                    }


                    /* assignning the address to the register configuration*/
                    if ((resize->inBufSize) >= in_bufsize)
                    {

                        rszConfChan->params.inAddress = (Int)resize->inBuf;
                    }
                    else
                    {
                        DDC_DEBUG_PRINTF("Not enough input buffer size \n");
                        statusRSZ = DDC_RSZ_INVALID_PARAM;
                    }

                    if ((resize->outBufSize >= out_bufsize)
                        && (statusRSZ != DDC_RSZ_INVALID_PARAM))
                    {
                        rszConfChan->params.outAddress = (Int)resize->outBuf;
                    }
                    else
                    {
                        DDC_DEBUG_PRINTF("Not enough output buffer size \n");
                        statusRSZ = DDC_RSZ_INVALID_PARAM;
                    }

                    /* Function call to add the entry of application in array*/
                    if (DDC_RSZ_SOK == statusRSZ)
                    {
                        rszConfChan->state = DDC_RSZChannelBUSY;

                        statusRSZ = DDC_RSZAddToArray(rszConfChan);

                        /*Function call to set up the hardware*/
                        if (DDC_RSZ_SOK == statusRSZ)
                        {
#ifdef RESIZER_INSTRUMENTATION_ENABLED
                            PSP_LOG_EVENT(  &DVTEvent_Log,
                                "Resizer",
                                PSP_DVT_DESC(   PSP_DVT_eFUNC_START,
                                    PSP_DVT_eDATA_SND_START,
                                    PSP_DVT_dPACKET_ID,
                                    PSP_DVT_dNONE),
                                CHANNELID_INSTANCEID(
                                    0,
                                    0),
                                resize);
#endif /*RESIZER_INSTRUMENTATION_ENABLED */

                            statusRSZ = LLC_RSZHardwareSetup(
                                (LLC_ResizerConfigParams *)
                                (&(rszConfChan->params)),
                                rszDeviceHandleSR->regs);

                            /* Clear the pending semaphore count if any */
                            PAL_osSemTake(rszDeviceHandleSR->SemIsr,0);

                            statusRSZ = LLC_RSZresizerEnable(rszDeviceHandleSR->regs);

                            if (SUCESS == statusRSZ)
                            {
                                statusRSZ = DDC_RSZ_SOK;
                            }

                            if (PAL_SOK != PAL_osSemTake(rszDeviceHandleSR->SemIsr,
                                                    rszDeviceHandleSR->SemIsrTimeout))
                            {
                                statusRSZ = DDC_RSZ_E_TIMEOUT;
                            }
                            else
                            {
                                /* return success if semaphore is posted
                                 * from ISR
                                 */
                                statusRSZ = DDC_RSZ_SOK;
                            }

#ifdef RESIZER_INSTRUMENTATION_ENABLED
                            PSP_LOG_EVENT(  &DVTEvent_Log,
                                "Resizer",
                                PSP_DVT_DESC(   PSP_DVT_eDATA_SND_END,
                                    PSP_DVT_dCHANNEL_ID_INST,
                                    PSP_DVT_dPACKET_ID,
                                    PSP_DVT_dNONE),
                                CHANNELID_INSTANCEID(
                                    0,
                                    0),
                                resize);
#endif /*RESIZER_INSTRUMENTATION_ENABLED */


                            if ((LLC_GetWriteBufferStatus() != ZERO) &&
                                (DDC_RSZ_SOK == statusRSZ))
                            {
                                statusRSZ = DDC_RSZ_E_FAIL;
                                DDC_DEBUG_PRINTF(
                                    "Error: Resizer write  buffer overflow");
                            }

                            statusDelArr = DDC_RSZDeleteFromArray(rszConfChan);

                            if(DDC_RSZ_SOK == statusRSZ)
                            {
                                /* Update the status only if Resizing is done
                                 * successfully. Otherwise return previous state
                                 */
                                statusRSZ = statusDelArr;
                            }
                        }
                        rszConfChan->state = DDC_RSZChannelFREE;
                    }
                }
            }
#ifdef RESIZER_INSTRUMENTATION_ENABLED
        PSP_LOG_EVENT(  &DVTEvent_Log,
            "Resizer",
            PSP_DVT_DESC(   PSP_DVT_eFUNC_END,
                PSP_DVT_dCHANNEL_ID_INST,
                PSP_DVT_dPACKET_ID,
                PSP_DVT_dSIZE_BYTES),
            CHANNELID_INSTANCEID(
                0,
                0),
            resize,
            0);
#endif /*RESIZER_INSTRUMENTATION_ENABLED */
        }
    }

    return statusRSZ;


}
/**
 * \brief  Function DDC_RSZAddToArray
 * This function used to add the channel pointer id into queue
 */

Int DDC_RSZAddToArray(DDC_RSZChanObject * const rszConfChan)
{
    DDC_RSZDeviceObject * rszDeviceHandleENQ
        = (DDC_RSZDeviceObject * )DDC_RSZGetDeviceHandle();

    Int ArrayIndexENQ, DeviceIndexENQ, statusENQ = DDC_RSZ_SOK;
    Int s;


    if ((NULL == rszDeviceHandleENQ) || (NULL == rszConfChan) )
    {
        statusENQ = DDC_RSZ_E_FAIL;
    }
    else
    {
        if (PAL_SOK != PAL_osSemTake (rszDeviceHandleENQ->ArraySem,
                                      rszConfChan->semTimeOut))
        {
            statusENQ = DDC_RSZ_E_FAIL;
        }
        else
        {

            /* Add configuration to the queue according to its priority */
            if (NULL == rszConfChan)
            {
                statusENQ = DDC_RSZ_E_FAIL;
            }
            else
            {

                if (EMPTY == rszDeviceHandleENQ->ArrayCount)
                {
                    /* If array empty insert at top position*/
                    s = rszDeviceHandleENQ->ArrayCount;
                    rszDeviceHandleENQ->DDC_RSZChanConfig[s] = rszConfChan;
                }
                else
                {
                    /* Check the priority and insert according to the priority
                       it will start from first index*/
                    for(ArrayIndexENQ = SECONDENTRY;
                        ArrayIndexENQ<rszDeviceHandleENQ->ArrayCount;
                        ArrayIndexENQ++)
                    {
                        if (rszDeviceHandleENQ->DDC_RSZChanConfig[
                            ArrayIndexENQ]->priority < rszConfChan->priority)
                        {
                            break;
                        }
                    }
                    /* Shift all the elements one step down in array IF first
                     * element and second have same prioroty than insert
                     * below first*/

                    for(DeviceIndexENQ = rszDeviceHandleENQ->ArrayCount;
                        DeviceIndexENQ>ArrayIndexENQ;
                        DeviceIndexENQ--)
                    {
                        rszDeviceHandleENQ->DDC_RSZChanConfig[DeviceIndexENQ]
                            = rszDeviceHandleENQ->DDC_RSZChanConfig[
                            DeviceIndexENQ -NEXT];
                    }

                    rszDeviceHandleENQ->DDC_RSZChanConfig[ArrayIndexENQ]
                        = rszConfChan;
                }

                /* incrementing number of requests for resizing*/
                rszDeviceHandleENQ->ArrayCount ++;


                if (SECONDENTRY != rszDeviceHandleENQ->ArrayCount)
                {

                    if (PAL_SOK != PAL_osSemGive(rszDeviceHandleENQ->ArraySem))
                    {
                        statusENQ = DDC_RSZ_E_FAIL;
                    }
                    if (PAL_SOK != PAL_osSemTake(rszConfChan->ChannelSem,
                                                 rszConfChan->semTimeOut))
                    {
                        statusENQ = DDC_RSZ_E_FAIL;
                    }
                }
                else
                {

                    if (PAL_SOK != PAL_osSemGive(rszDeviceHandleENQ->ArraySem))
                    {
                        statusENQ = DDC_RSZ_E_FAIL;
                    }
                }

            }
        }
    }

    return statusENQ;
}/*End of function DDC_RSZAddToArray*/



/**
 * \brief Function DDC_RSZDeleteFromArray
 * This function used to delete the channel pointer id into queue
 *
 */
Int DDC_RSZDeleteFromArray(DDC_RSZChanObject * const rszConfChan)
{
    Int ArrayIndexDEQ = FIRSTENTRY, DeviceIndexDEQ, statusDEQ = DDC_RSZ_SOK;

    DDC_RSZDeviceObject * rszDeviceHandleDEQ
        = (DDC_RSZDeviceObject * )DDC_RSZGetDeviceHandle();

    if (NULL == rszDeviceHandleDEQ)
    {
        statusDEQ = DDC_RSZ_E_FAIL;
    }
    else
    {
        if (NULL == rszConfChan)
        {
            statusDEQ = DDC_RSZ_E_FAIL;
        }
        else
        {
            if (PAL_SOK != PAL_osSemTake (rszDeviceHandleDEQ->ArraySem,
                                          rszConfChan->semTimeOut))
            {

                statusDEQ = DDC_RSZ_E_FAIL;
            }
            else
            {

                /*shift the entried in array */
                if (SECONDENTRY != rszDeviceHandleDEQ->ArrayCount)
                {
                    /* decrementing the request count*/
                    rszDeviceHandleDEQ->ArrayCount --;

                    /* Shift all the elements one step up in array*/
                    for(DeviceIndexDEQ = ArrayIndexDEQ;
                        DeviceIndexDEQ<rszDeviceHandleDEQ->ArrayCount;
                        DeviceIndexDEQ++)
                    {

                        rszDeviceHandleDEQ->DDC_RSZChanConfig[DeviceIndexDEQ]
                            = rszDeviceHandleDEQ->DDC_RSZChanConfig[
                            DeviceIndexDEQ+NEXT];
                    }
                    /* making last entry NULL;*/
                    rszDeviceHandleDEQ->DDC_RSZChanConfig[DeviceIndexDEQ +NEXT]
                        = NULL;
                }
                /* remove the top entry*/
                else
                {

                    rszDeviceHandleDEQ->ArrayCount --;
                    rszDeviceHandleDEQ->DDC_RSZChanConfig[FIRSTENTRY] = NULL;
                }
            }

            if (rszDeviceHandleDEQ->ArrayCount != FIRSTENTRY)
            {
                /* Get config having highest priority in array
                   and unlock config.sem of that configuration */

                if (PAL_SOK != PAL_osSemGive(rszDeviceHandleDEQ->ArraySem))
                {
                    statusDEQ = DDC_RSZ_E_FAIL;
                }
                if (PAL_osSemGive(rszDeviceHandleDEQ->DDC_RSZChanConfig
                        [FIRSTENTRY]->ChannelSem)!= PAL_SOK)
                {
                    statusDEQ = DDC_RSZ_E_FAIL;
                }
            }
            else
            {


                if (PAL_SOK != PAL_osSemGive(rszDeviceHandleDEQ->ArraySem))
                {
                    statusDEQ = DDC_RSZ_E_FAIL;
                }
            }
        }
    }


    return statusDEQ;
}
/* End of function DDC_RSZDeleteFromArray*/
/**
 * \brief  Function DDC_RSZValidateParameters
 * This function Validate the harware parameters
 *
 */
Int DDC_RSZValidateParameters(DDC_RSZChanObject * rszConfChan,
    PSP_RSZparams  * const rszparams)
{
    Int coeffcounterVP;
    Int hrsz = ZERO;
    Int vrsz = ZERO;
    Int alignment;
    Int vscale;
    Int Status = DDC_RSZ_SOK;

    if (NULL == rszConfChan)
    {
        Status = DDC_RSZ_E_FAIL;
    }

    if (NULL == rszparams)
    {
        Status = DDC_RSZ_E_FAIL;
    }

    /* calculating the horizontal and vertical ratio*/

    /* calculating the vertical ration which is integer */
    vrsz = ((rszparams->inVsize * RATIO_MULTIPLIER) / (rszparams->outVsize));
    /* calculating the horizontal ration which is integer */
    hrsz = ((rszparams->inHsize * RATIO_MULTIPLIER) / (rszparams->outHsize));

    /* recalculating Horizontal ratio*/
    if ((hrsz>= UP_RSZ_RATIO) && (hrsz <= DOWN_RSZ_RATIO))
    {
        if (rszparams->hstph > NUM_PHASES)
        {
            Status = DDC_RSZ_INVALID_PARAM;
        }
        /* Recalculating the horizontal ratio which is integer and according to
           formula given in the datasheet. Refer to Section4 of spraai7a*/
        hrsz = (((rszparams->inHsize-NUM_TAPS)* RATIO_MULTIPLIER))/(rszparams->outHsize -1);

        /* Need to recalculate the input horizontal size after hrsz recalculation*/
        rszparams->inHsize = ((((32*rszparams->hstph) + ((rszparams->outHsize -1)*hrsz) + 16) >> 8) + 7 );
    }
    else if ((hrsz >= UP_RSZ_RATIO1) && (hrsz <= DOWN_RSZ_RATIO1))
    {
        if (rszparams->hstph >NUM_D2PH)
        {
            Status = DDC_RSZ_INVALID_PARAM;
        }
        /* Recalculating the horizontal ratio which is integer according to
           formula given in datasheet. Refer to Section4 of spraai7a*/
        hrsz = (((rszparams->inHsize-NUM_D2TAPS)* RATIO_MULTIPLIER))/(rszparams->outHsize -1);

        /* Need to recalculate the input horizontal size after hrsz recalculation*/
        rszparams->inHsize = ((((64*rszparams->hstph) + ((rszparams->outHsize -1)*hrsz) + 32) >> 8) + 7 );
    }
    else
    {
        Status = DDC_RSZ_INVALID_PARAM;
    }


    /* recalculating vertical ratio*/
    if ((vrsz>= UP_RSZ_RATIO) && (vrsz <= DOWN_RSZ_RATIO))
    {
        if (rszparams->vstph > NUM_PHASES)
        {
            Status = DDC_RSZ_INVALID_PARAM;
        }
        /* Recalculating the vertical ratio which is integer according to
           formula given in datasheet. Refer to Section4 of spraai7a*/
        vrsz = (((rszparams->inVsize-NUM_TAPS)*RATIO_MULTIPLIER))/(rszparams->outVsize -1);

        /* Need to recalculate the input vertical size after vrsz recalculation*/
        rszparams->inVsize = ((((32*rszparams->vstph) + ((rszparams->outVsize -1)*vrsz) + 16) >> 8) + 4 );

    }
    else if ((vrsz >= UP_RSZ_RATIO1) && (vrsz <= DOWN_RSZ_RATIO1))
    {
        if (rszparams->vstph > NUM_D2PH)
        {
            Status = DDC_RSZ_INVALID_PARAM;
        }
        /* Recalculating the vertical ration which is integer according to
           formula given in datasheet. Refer to Section4 of spraai7a*/
        vrsz = (((rszparams->inVsize-NUM_D2TAPS)*RATIO_MULTIPLIER))/(rszparams->outVsize -1);

        /* Need to recalculate the input vertical size after vrsz recalculation*/
        rszparams->inVsize = ((((64*rszparams->vstph) + ((rszparams->outVsize -1)*vrsz) + 32) >> 8) + 7 );

    }
    else
    {
        Status = DDC_RSZ_INVALID_PARAM;
    }

    /* Fiiling the input pitch in the structure*/
    if (0 != ((rszparams->inPitch)%ALIGN32))
    {
        DDC_DEBUG_PRINTF("Inavlid input pitch \n");
        Status = DDC_RSZ_INVALID_PARAM;
    }
    rszConfChan->params.inPitch = rszparams->inPitch;

    /* If vertical upsizing then*/
    vscale = (rszparams->outVsize -  rszparams->inVsize);
    if (vscale > 0)
    {
        if (rszparams->inptyp == PSP_RSZ_INTYPE_YCBCR422_16BIT)
        {
            alignment = ALIGNMENT/2;
        }
        else if (rszparams->inptyp == PSP_RSZ_INTYPE_PLANAR_8BIT)
        {
            alignment = ALIGNMENT;
        }
        else
        {
             DDC_DEBUG_PRINTF("Inavlid input type \n");
             Status = DDC_RSZ_INVALID_PARAM;
        }
        /* errror checking for output size*/
        if (!((ZERO == (rszparams->outHsize %PIXEL_EVEN))
                && (ZERO == (rszparams->outHsize % alignment))))
        {
            DDC_DEBUG_PRINTF("wrong hsize \n");
            Status = DDC_RSZ_INVALID_PARAM;
        }
    }
    /* Filling the horizontal size of input frame in MMR*/
    if ((hrsz >= UP_RSZ_RATIO) && (hrsz <= DOWN_RSZ_RATIO))
    {
        if (rszparams->outHsize > MAX_IMAGE_WIDTH)
        {
            DDC_DEBUG_PRINTF("wrong width \n");
            Status = DDC_RSZ_INVALID_PARAM;
        }

    }
    /* checking the output image height*/
    else if ((hrsz >= UP_RSZ_RATIO1) && (hrsz <= DOWN_RSZ_RATIO1))
    {
        if (rszparams->outHsize >MAX_IMAGE_WIDTH_HIGH)
        {
            DDC_DEBUG_PRINTF("wrong width \n");
            Status = DDC_RSZ_INVALID_PARAM;
        }
    }
    else
    {
        DDC_DEBUG_PRINTF("ratio invalid \n");
        Status = DDC_RSZ_INVALID_PARAM;
    }

    rszConfChan->params.outHsize = rszparams->outHsize;

    rszConfChan->params.outVsize = rszparams->outVsize;



    if (1 == ((rszparams->outPitch)%ALIGN32))
    {
        DDC_DEBUG_PRINTF("Inavlid output pitch \n");
        Status = DDC_RSZ_INVALID_PARAM;
    }

    rszConfChan->params.outPitch = rszparams->outPitch;

    /* Configuring the chrominance algorithm*/
    rszConfChan->params.cbilin = rszparams->cbilin;


    /* planer */
    if (rszparams->inptyp == PSP_RSZ_INTYPE_PLANAR_8BIT)
    {

        rszConfChan->params.inptyp = rszparams->inptyp;
    }
    /* interleaved */
    else if (rszparams->inptyp == PSP_RSZ_INTYPE_YCBCR422_16BIT)
    {
        rszConfChan->params.inptyp = ZERO;
        /* Configuring the chrominace position type - only in case of
         * interleaved */
        if (rszparams->pixfmt == PSP_RSZ_PIX_FMT_UYVY)
        {
            rszConfChan->params.pixfmt = FORMAT_UYVY;
        }
        else if (rszparams->pixfmt == PSP_RSZ_PIX_FMT_YUYV)
        {
            rszConfChan->params.pixfmt = FORMAT_YUYV;
        }
        else
        {
            DDC_DEBUG_PRINTF("Inavlid pixel format \n");
            Status = DDC_RSZ_INVALID_PARAM;
        }
    }
    else
    {
        DDC_DEBUG_PRINTF("Inavlid input format \n");
        Status = DDC_RSZ_INVALID_PARAM;
    }

    /* checking the validity of the horizontal phase value*/
    if ((hrsz>= UP_RSZ_RATIO) && (hrsz <= DOWN_RSZ_RATIO))
    {
        if (rszparams->hstph > NUM_PHASES)
        {
            Status = DDC_RSZ_INVALID_PARAM;
        }
    }
    else if ((hrsz>= UP_RSZ_RATIO1) && (hrsz <= DOWN_RSZ_RATIO1))
    {
        if (rszparams->hstph > NUM_D2PH)
        {
            Status = DDC_RSZ_INVALID_PARAM;
        }
    }
    else
    {
        Status = DDC_RSZ_INVALID_PARAM;
    }

    rszConfChan->params.hstph = rszparams->hstph;



    /* checking the validity of the vertical phase value*/
    if ((vrsz>= UP_RSZ_RATIO) && (vrsz <= DOWN_RSZ_RATIO))
    {
        if (rszparams->vstph > NUM_PHASES)
        {
            Status = DDC_RSZ_INVALID_PARAM;
        }
    }
    else if ((vrsz>= UP_RSZ_RATIO1) && (vrsz <= DOWN_RSZ_RATIO1))
    {
        if (rszparams->vstph > NUM_D2PH)
        {
            Status = DDC_RSZ_INVALID_PARAM;
        }
    }
    else
    {
        Status = DDC_RSZ_INVALID_PARAM;
    }

    rszConfChan->params.vstph = rszparams->vstph;



    /* if input is from SDRAM that vertical pixel should be zero*/

    rszparams->vertStartingPixel = ZERO;


    /* Configuring the  starting pixel in vertical direction*/


    rszConfChan->params.vertStartingPixel = rszparams->vertStartingPixel;

    /* if input is 8 bit that start pixel should be less than 15*/
    if (PSP_RSZ_INTYPE_PLANAR_8BIT == rszparams->inptyp)
    {
        if ((rszparams->horzStartingPixel > MAX_HORZ_PIXEL_8BIT)
            || (rszparams->horzStartingPixel < ZERO))
        {
            Status = DDC_RSZ_INVALID_PARAM;
        }
    }
    /* if input is 16 bit that start pixel should be less than 31*/
    if (PSP_RSZ_INTYPE_YCBCR422_16BIT == rszparams->inptyp)
    {
        if ((rszparams->horzStartingPixel > MAX_HORZ_PIXEL_16BIT)
            || (rszparams->horzStartingPixel < ZERO))
        {
            Status = DDC_RSZ_INVALID_PARAM;
        }
    }

    /* Configuring the  starting pixel in horizontal direction*/
    rszConfChan->params.horzStartingPixel = rszparams->horzStartingPixel;


    for(coeffcounterVP = ZERO;coeffcounterVP<MAX_COEF_COUNTER;coeffcounterVP++)
    {
        /* Configuration of horizontal coefficients*/
        rszConfChan->params.hfiltCoeffs[2*coeffcounterVP]
            = rszparams->hfiltCoeffs[2*coeffcounterVP];

        /* Configuration of horizontal and vertical coefficients */


        rszConfChan->params.hfiltCoeffs[((2*coeffcounterVP) +NEXT)]
            = rszparams->hfiltCoeffs[((2*coeffcounterVP)+NEXT)];

        /* Configuration of Vertical coefficients*/
        rszConfChan->params.vfiltCoeffs[2*coeffcounterVP]
            = rszparams->vfiltCoeffs[2*coeffcounterVP];
        /* Configuration of Vertical coefficients*/

        rszConfChan->params.vfiltCoeffs[((2*coeffcounterVP) +NEXT)]
            = rszparams->vfiltCoeffs[((2*coeffcounterVP)+NEXT)];
    }
    /* Coefficinets of parameters for luma :- algo configuration*/


    rszConfChan->params.yenhParams.type = rszparams->yenhParams.type;

    /* Coefficinets of parameters for luma :- core configuration*/
    if (1 == (rszparams->yenhParams.type))
    {
        rszConfChan-> params.yenhParams.core = rszparams->yenhParams.core;

        /* Coefficinets of parameters for luma :- gain configuration*/

        rszConfChan->params.yenhParams.gain = rszparams->yenhParams.gain;

        /* Coefficinets of parameters for luma :- gain configuration*/
        rszConfChan->params.yenhParams.slop = rszparams->yenhParams.slop;

    }

    /* Configuring the horizontal ratio as ratio minus 1 as suggested in data
       sheet */
    rszConfChan->params.hrsz = (hrsz - 1);


    /* Configuring the vertical ratio as ratio minus 1 as suggested in data
       sheet */
    rszConfChan->params.vrsz = (vrsz - 1);

    /* Configuring the Horizontal size of input framn in MMR*/
    rszConfChan->params.inHsize = rszparams->inHsize;

    rszConfChan->params.inVsize = rszparams->inVsize;


    if (DDC_RSZ_SOK == Status)
    {
        DDC_DEBUG_PRINTF("Resizer State configured \n");
        rszConfChan->DDC_ParamsConfigState = STATE_CONFIGURED;
    }

    return Status;
}
/**
 * \brief Function DDC_RSZGetParameters
 * This function get the parameters information
 *
 */
Int DDC_RSZGetParameters(DDC_RSZChanObject * const rszConfChan,
    PSP_RSZparams  * const params)
{
    Int coeffcounterGP;
    Int statusGP = DDC_RSZ_E_FAIL;
    if (NULL != rszConfChan)
    {
        if (NULL != params)
        {

            if (STATE_NOT_CONFIGURED != (rszConfChan->DDC_ParamsConfigState))
            {


                /* getting the horizontal size*/
                params->inHsize = rszConfChan->params.inHsize;
                /* getting the vertical size*/
                params->inVsize = rszConfChan-> params.inVsize;

                /*     getting the input pitch*/
                params->inPitch = rszConfChan-> params.inPitch;

                /* getting the output horizontal size*/
                params->outHsize = rszConfChan->params.outHsize;

                /* getting the vertical size*/
                params->outVsize = rszConfChan->params.outVsize;


                /* getting the output pitch*/
                params->outPitch = rszConfChan->params.outPitch;

                /* getting the chrominance algorithm*/
                params->cbilin = rszConfChan->params.cbilin;


                /* getting the input type*/
                params->inptyp = rszConfChan->params.inptyp;

                /* getting the  starting pixel in horizontal direction*/
                params->horzStartingPixel
                    = rszConfChan->params.horzStartingPixel;

                /* getting the  starting pixel in vertical direction*/
                params->vertStartingPixel
                    = rszConfChan->params.vertStartingPixel;

                /* getting the horizontal starting phase*/
                params->hstph = rszConfChan->params.hstph;


                /* getting the vertical starting phase*/
                params->vstph = rszConfChan->params.vstph;



                for(coeffcounterGP = ZERO;coeffcounterGP<MAX_COEF_COUNTER;
                    coeffcounterGP++)
                {
                    /* getting the horizontal coefficients 0*/
                    params->hfiltCoeffs[2*coeffcounterGP]
                        = rszConfChan->params.hfiltCoeffs[2*coeffcounterGP];

                    /* getting the horizontal coefficients 1*/
                    params->hfiltCoeffs[((2*coeffcounterGP)+NEXT)]
                        = rszConfChan->params.hfiltCoeffs[((
                                2*coeffcounterGP)+NEXT)];

                    /* getting the vertical coefficients 0*/
                    params->vfiltCoeffs[2*coeffcounterGP]
                        = rszConfChan->params.vfiltCoeffs[2*coeffcounterGP];

                    /* getting the vertical coefficients 1*/
                    params->vfiltCoeffs[((2*coeffcounterGP)+NEXT)]
                        = rszConfChan->params.vfiltCoeffs[((
                                2*coeffcounterGP)+NEXT)];
                }
                /* getting the parameters for luma :- algo*/
                params->yenhParams.type = rszConfChan->params.yenhParams.type;

                /* getting the parameters for luma :- core*/
                params->yenhParams.core = rszConfChan->params.yenhParams.core;

                /* Coefficinets of parameters for luma :- gain*/
                params->yenhParams.gain = rszConfChan->params.yenhParams.gain;

                /* Coefficinets of parameters for luma :- SLOP configuration*/
                params->yenhParams.slop = rszConfChan->params.yenhParams.slop;

                /* getting the input type*/
                params->pixfmt = rszConfChan->params.pixfmt;
                if(params->pixfmt == FORMAT_UYVY)
                {
                    params->pixfmt = PSP_RSZ_PIX_FMT_UYVY;
                }
                else
                {
                    params->pixfmt = PSP_RSZ_PIX_FMT_YUYV;
                }
                statusGP = DDC_RSZ_SOK;
            }
        }
    }

    return statusGP;
}
/**
 * \brief  Function DDC_RSZGetCropSize
 * This function get the croping information about image
 *
 */
Int DDC_RSZGetCropSize(DDC_RSZChanObject * const rszConfChan,
    PSP_RSZcropsize * const cropsize)
{

    Int lumaEnable, statusCS = DDC_RSZ_SOK;

    if (NULL == rszConfChan)
    {
        statusCS = DDC_RSZ_E_FAIL;
    }
    else
    {
        if (NULL == cropsize)
        {
            statusCS = DDC_RSZ_E_FAIL;
        }
        else
        {
            cropsize->hcrop = ZERO;
            cropsize->vcrop = ZERO;
            lumaEnable = (rszConfChan->params.yenhParams.type);

            /* Luma enhancement reduces image width 1 pixels from left, right */
            if (1 == (lumaEnable))
            {
                cropsize->hcrop += CROP_PIXEL;
            }
        }
    }
    return statusCS;
}



/**
 * \brief  Function DDC_RSZGetPriority
 * This function get the priority about the channel
 *
 */
Int DDC_RSZGetPriority(DDC_RSZChanObject * const rszConfChan,
    PSP_RSZpriority * const prio)
{
    Int statusPRI;
    if (NULL == rszConfChan)
    {
        statusPRI = DDC_RSZ_E_FAIL;
    }
    else
    {
        if (NULL == prio)
        {
            statusPRI = DDC_RSZ_E_FAIL;
        }
        /* Get the priority from the channel*/
        prio->priority = rszConfChan->priority;

        statusPRI = DDC_RSZ_SOK;
    }
    return statusPRI;
}
/**
 * \brief  Function DDC_RSZGetStatus
 * This function get the status of the channel
 *
 */
Int DDC_RSZGetStatus(DDC_RSZChanObject * const rszConfChan,
    PSP_RSZstatus * const status)
{
    Int statusSTA;
    DDC_RSZDeviceObject * rszDeviceHandleGT
        = (DDC_RSZDeviceObject * )DDC_RSZGetDeviceHandle();

    if (NULL != rszDeviceHandleGT)
    {

        if (NULL == rszConfChan)
        {
            statusSTA = DDC_RSZ_E_FAIL;
        }
        else
        {
            if (NULL == status)
            {
                statusSTA = DDC_RSZ_E_FAIL;
            }
            else
            {
                if (DDC_RSZChannelBUSY == rszConfChan->state)
                {
                    status->chanBusy = CHANNEL_BUSY;
                }
                else
                {
                    status->chanBusy = CHANNEL_FREE;
                }
                status->hwBusy = LLC_RSZGetHWStatus(rszDeviceHandleGT->regs);
                status->src = INPUT_RAM;
                statusSTA = DDC_RSZ_SOK;
            }
        }
    }
    return statusSTA;
}
/**
 * \brief  Function DDC_RSZSetPriority
 * This function set the priority of the channel
 *
 */
Int DDC_RSZSetPriority(DDC_RSZChanObject * const rszConfChan,
    PSP_RSZpriority * const prio)
{
    /* Check the prioroty range and assign the priority*/

    Int statusSPRI = DDC_RSZ_SOK;

    if (NULL == rszConfChan)
    {
        statusSPRI = DDC_RSZ_E_FAIL;
    }
    else
    {
        if (NULL == rszConfChan)
        {
            statusSPRI = DDC_RSZ_E_FAIL;
        }
        else
        {
            if (NULL != prio)
            {
                if ((prio->priority > MAX_PRIORITY)
                    || (prio->priority < MIN_PRIORITY))
                {
                    statusSPRI = DDC_RSZ_INVALID_PARAM;
                }
                else
                {
                    rszConfChan->priority = prio->priority;
                }
            }
        }
    }

    return statusSPRI;
}
/**
 * \brief  Function DDC_RSZIoctl
 * This function is used to call function relates to IOCTL commands
 */
/* ARGSUSED */
PSP_Result  DDC_RSZIoctl(PSP_Handle handle, PSP_RSZIoctlCmd cmd, Ptr cmdArg,
    Ptr params)
{
    Int result = DDC_RSZ_E_FAIL;

    if ((NULL != cmdArg) && (NULL != handle))
    {

        switch (cmd)
        {
            case PSP_RSZ_IOCTL_SET_PARAMS:
                {
                    /*Configure and validate the resizer Parameters */
                    result = DDC_RSZValidateParameters(handle, cmdArg);

                }
                break;
            case PSP_RSZ_IOCTL_GET_PARAMS:
                {
                    /* Gwt the Resizer Paremeters */
                    result = DDC_RSZGetParameters(handle, cmdArg);


                }
                break;
            case PSP_RSZ_IOCTL_RESIZE:
                {
                    /*Start resize */
                    result = DDC_RSZStartResize(handle, cmdArg);

                }
                break;
            case PSP_RSZ_IOCTL_SET_PRIORITY:
                {
                    /*Set the priority */
                    result = DDC_RSZSetPriority(handle, cmdArg);

                }
                break;
            case PSP_RSZ_IOCTL_GET_PRIORITY:
                {
                    /*Get the priority */
                    result = DDC_RSZGetPriority(handle, cmdArg);

                }
                break;
            case PSP_RSZ_IOCTL_GET_STATUS:
                {
                    /*Get the status */
                    result = DDC_RSZGetStatus(handle, cmdArg);

                }
                break;
            case PSP_RSZ_IOCTL_GET_CROPSIZE:
                {
                    /* Get cropping information */
                    result = DDC_RSZGetCropSize(handle, cmdArg);

                }
                break;
            case PSP_RSZ_IOCTL_SET_EXP:
                {


                    result = LLC_RSZSetExp(*((Int *)cmdArg));
                    if (1 == result)
                    {
                        result = DDC_RSZ_SOK;
                    }
                }
                break;
            case PSP_RSZ_IOCTL_SET_SEM_TIMEOUT:
                {
                    if (NULL != cmdArg)
                    {
                        /* Change the semTimeOut value */
                        ((DDC_RSZChanObject *)handle)->semTimeOut
                                                        = *(Int32 *)cmdArg;
                        result = DDC_RSZ_SOK;

                    }
                    else
                    {
                        result = DDC_RSZ_INVALID_PARAM;
                    }
                }
                break;
            case PSP_RSZ_IOCTL_SET_ISRSEM_TIMEOUT:
                {
                    DDC_RSZDeviceObject *rszDeviceHandle;
                    rszDeviceHandle = (DDC_RSZDeviceObject*)DDC_RSZGetDeviceHandle();

                    if (NULL != cmdArg)
                    {
                        /* Change the interrupt semaphore timeout value */
                        rszDeviceHandle->SemIsrTimeout = *(Int32 *)cmdArg;
                        result = DDC_RSZ_SOK;

                    }
                    else
                    {
                        result = DDC_RSZ_INVALID_PARAM;
                    }
                }
                break;
            case PSP_RSZ_IOCTL_SET_RESIZE_CALLBACK:
                {
                    DDC_RSZDeviceObject *rszDeviceHandle;
                    rszDeviceHandle = (DDC_RSZDeviceObject*)DDC_RSZGetDeviceHandle();
                    
                    rszDeviceHandle->appCbk.fxn = \
                       ((PSP_RSZcallback*)cmdArg)->fxn;
                    rszDeviceHandle->appCbk.arg = \
                       ((PSP_RSZcallback*)cmdArg)->arg;
                    rszDeviceHandle->isAsyncResize = TRUE;
                    result = DDC_RSZ_SOK;

                }
                break;
            case PSP_RSZ_IOCTL_RESIZE_ASYNC:
                {
                    DDC_RSZDeviceObject *rszDeviceHandle;
                    rszDeviceHandle = (DDC_RSZDeviceObject*)DDC_RSZGetDeviceHandle();
                                        
                    if(FALSE != rszDeviceHandle->isResizeBusy)
                    {
                        result = DDC_RSZ_INVALID_STATE;
                    }
                    else
                    {
                        rszDeviceHandle->isResizeBusy = TRUE;
                        rszDeviceHandle->asyncBufPtr = cmdArg;
                        rszDeviceHandle->asyncBufSize = sizeof(PSP_RSZresize);
                        /*Start async resize */
                        result = DDC_RSZStartAsyncResize(handle, cmdArg);                        
                    }
                }
                break;
            default:
                {
                    result = DDC_RSZ_NOT_SUPPORTED;
                }
                break;
        }
    }
    return result;

}
/**
 * \brief  Function DDC_RSZInitializeModule
 * This function is used to Initialize the resizer device driver
 *
 */
void* DDC_RSZInitializeModule ()
{
    /* Get the device handle */
    DDC_RSZDeviceObject * rszDeviceHandleCreate
        = (DDC_RSZDeviceObject * )DDC_RSZGetDeviceHandle();


    if (NULL != rszDeviceHandleCreate)
    {

        rszDeviceHandleCreate->ArrayCount = ZERO;

        /* Create the semaphore to protect queue for multiplt
           channel handling */
        if (PAL_osSemCreate("ArraySem", INIT_ARRAYSEM , NULL,
                (&(rszDeviceHandleCreate->ArraySem)))!= PAL_SOK)
        {
            rszDeviceHandleCreate = NULL;
        }
        else
        {
            /* Create semaphore for ISR */
            if (PAL_osSemCreate("SemIsr", INIT_ISRSEM , NULL,
                                    (&(rszDeviceHandleCreate->SemIsr)))!= PAL_SOK)
            {
                PAL_osSemDelete(rszDeviceHandleCreate->ArraySem);
                rszDeviceHandleCreate = NULL;
            }
            else
            {
                /* Initialize the default timeout value for SemIsr */
                rszDeviceHandleCreate->SemIsrTimeout = (Int)SEMISR_TIMEOUT;
            }
        }

        if(NULL != rszDeviceHandleCreate)
        {
            rszDeviceHandleCreate->state = PSP_RESIZER_CREATED;
            rszDeviceHandleCreate->isAsyncResize = FALSE;
            rszDeviceHandleCreate->isResizeBusy = FALSE;
            rszDeviceHandleCreate->asyncBufSize = 0;
            rszDeviceHandleCreate->asyncBufPtr = NULL;

            /* setting the VPSS SDR_REQ_EXP register */
            LLC_RSZSetExp(RESZEXP_INITVALUE);
        }

    }

    return((void *)(rszDeviceHandleCreate));
}
/**
 * \brief  Function DDC_RSZRemoveModule
 * This function is used to De Initialize the resizer
 *
 */
Void * DDC_RSZRemoveModule (void)
{

    DDC_RSZDeviceObject * rszDeviceHandleDelete
        = (DDC_RSZDeviceObject * )DDC_RSZGetDeviceHandle();

    if (NULL != rszDeviceHandleDelete)
    {
        if ((PSP_RESIZER_CREATED != rszDeviceHandleDelete->state)
            && (PSP_RESIZER_CLOSED  != rszDeviceHandleDelete->state))
        {

            rszDeviceHandleDelete = NULL;
        }
        else
        {
            if ((PAL_SOK != PAL_osSemDelete(rszDeviceHandleDelete->SemIsr)) ||
                (PAL_SOK != PAL_osSemDelete(rszDeviceHandleDelete->ArraySem)))
            {
                rszDeviceHandleDelete = NULL;
            }
            else
            {
                /* set state to deleted */
                rszDeviceHandleDelete->state = PSP_RESIZER_DELETED;
                rszDeviceHandleDelete->isAsyncResize = FALSE;
                rszDeviceHandleDelete->isResizeBusy = FALSE;
                rszDeviceHandleDelete->asyncBufSize = 0;
                rszDeviceHandleDelete->asyncBufPtr = NULL;
            }
        }

    }
    return ((void *)(rszDeviceHandleDelete));
}

