/*******************************************************************************
**+--------------------------------------------------------------------------+**
**|                            ****                                          |**
**|                            ****                                          |**
**|                            ******o***                                    |**
**|                      ********_///_****                                   |**
**|                      ***** /_//_/ ****                                   |**
**|                       ** ** (__/ ****                                    |**
**|                           *********                                      |**
**|                            ****                                          |**
**|                            ***                                           |**
**|                                                                          |**
**|         Copyright (c) 2006-2010 Texas Instruments Incorporated           |**
**|                        ALL RIGHTS RESERVED                               |**
**|                                                                          |**
**| Permission is hereby granted to licensees of Texas Instruments           |**
**| Incorporated (TI) products to use this computer program for the sole     |**
**| purpose of implementing a licensee product based on TI products.         |**
**| No other rights to reproduce, use, or disseminate this computer          |**
**| program, whether in part or in whole, are granted.                       |**
**|                                                                          |**
**| TI makes no representation or warranties with respect to the             |**
**| performance of this computer program, and specifically disclaims         |**
**| any responsibility for any damages, special or consequential,            |**
**| connected with the use of this program.                                  |**
**|                                                                          |**
**+--------------------------------------------------------------------------+**
*******************************************************************************/
/**
 *  \file   ddc_rsz.h
 *
 *  \brief  DDC header file for RSZ
 *
 *  This file contains the dependencies across the RSZ driver.
 *
 *  (C) Copyright 2010, Texas Instruments, Inc
 *
 *  \author     EI3
 *
 *  \version    0.1     Created
 *              1.0     First release
 */
#ifndef _DDC_RSZ_H
#define _DDC_RSZ_H

/******************************************************************************
  Header File Inclusion
 ******************************************************************************/

#include <ti/sdo/pspdrivers/drivers/resizer/psp_resizer.h>
#include <ti/sdo/pspdrivers/drivers/resizer/src/llc_rsz.h>
#include <ti/sdo/pspdrivers/pal_os/bios/psputils.h>
#include <ti/sdo/pspdrivers/pal_os/pal_ossem.h>

#ifdef __cplusplus
extern "C" {
#endif

/******************************************************************************
  Macros
 ******************************************************************************/

#define FIRSTENTRY                      (0u)
#define SECONDENTRY                     (1)
#define EMPTY                           (0u)
#define ALIGNMENT                       (16)
#define ALIGN32                         (32)
#define CHANNEL_BUSY                    (1)
#define CHANNEL_FREE                    (0)
#define PIXEL_EVEN                      (2)
#define RATIO_MULTIPLIER                (256)
#define UP_RSZ_RATIO                    (64)
#define DOWN_RSZ_RATIO                  (512)
#define UP_RSZ_RATIO1                   (513)
#define DOWN_RSZ_RATIO1                 (1024)
#define NUM_PHASES                      (8)
#define NUM_TAPS                        (4)
#define NUM_D2PH                        (4)  /* for downsampling 2+x ~ 4x,
                                                number of phases */
#define NUM_D2TAPS                      (7)  /* for downsampling*/
#define BYTES_PER_PIXEL                 (2)
#define MAX_IMAGE_WIDTH                 (1280)
#define FORMAT_UYVY                     (1)
#define FORMAT_YUYV                     (0)
#define MAX_IMAGE_WIDTH_HIGH            (640)
#define MAX_HORZ_PIXEL_8BIT             (31)
#define MAX_HORZ_PIXEL_16BIT            (15)
#define INPUT_RAM                       (1)
#define MIN_PRIORITY                    (0)
#define MAX_PRIORITY                    (5)
#define CROP_PIXEL                      (2)
#define RESZEXP_INITVALUE               (0xe)
#define INIT_ARRAYSEM                   (1)
#define INIT_ISRSEM                     (0)
#define SEMISR_TIMEOUT                  (40)
#define SEMTAKE_RETRYCNT                (100)
#define RSZ_HWBUSY                      (1)
#ifdef RESIZER_DEBUG_DDC_PRINTF
#define DDC_DEBUG_PRINTF(STR) PSP_DEBUG1("%s", (STR));
#else /* RESIZER_DEBUG_DDA_PRINTF */
#define DDC_DEBUG_PRINTF(STR)
#endif /* RESIZER_DEBUG_DDA_PRINTF */
#define SUCESS                      1
/*******************************************************************************
  DDC Channel State
 ******************************************************************************/
/**
 * \brief   Structure _DDC_RSZState
 *  This enum contains description about the state of the Resizer Driver.
 *
 */
typedef enum _DDC_RSZState
{


    DDC_RSZCHANCLOSED,
    /**< RSZ channel closed state */
    DDC_RSZCHANOPENED,
    /**< RSZ channel open state */
    DDC_RSZChannelFREE,
    /**< RSZ channel free state */
    DDC_RSZChannelBUSY,
    /**< RSZ channel Busy */
    DDC_RSZBufferoverflow
    /**< Write buffer overflow */
} DDC_RSZChanState;

/******************************************************************************
  Enumerations
 ******************************************************************************/
/**
 * \brief Enumeration RESIZER_STATE
 * This enum describes the various states of RSZ driver goes through
 * the entire cycle.
 *
 */

typedef enum RESIZER_STATE
{

    PSP_RESIZER_DELETED,
    /**< RSZ device deleted */
    PSP_RESIZER_CREATED,
    /**< RSZ device created */
    PSP_RESIZER_OPENED,
    /**< RSZ device opened */
    PSP_RESIZER_CLOSED
        /**< RSZ device closed */
} resizerState;

/*******************************************************************************
  Error Codes
 ******************************************************************************/
/**
 *  \brief Enumeration _DDC_RSZStatus
 *  This enum contains DDC related error codes that will be passed
 *  to the DDA layer.
 */
typedef enum _DDC_RSZStatus
{

    DDC_RSZ_SOK = (0),
    /**< Operation passed code for DDC related functionality */
    DDC_RSZ_E_FAIL,
    /**< Operation failed code for DDC related functionality */
    DDC_RSZ_INVALID_STATE,
    /**< Invalid state error code for DDC related functionality */
    DDC_RSZ_INVALID_PARAM,
    /**< Invalid param error code for DDC related functionality */
    DDC_RSZ_NOT_SUPPORTED,
    /**< Invalid module error code for DDC related functionality */
    DDC_RSZ_E_TIMEOUT,
    /**< Timeout error code for DDC related functionality */
    DDC_RSZ_SINPROGRESS
    /**< Status to indicate that the operation in progress */
} DDC_RSZStatus;

/*******************************************************************************
  Parameters state
 ******************************************************************************/
/**
 * \brief   Structure _DDC_ParamsConfigDone
 *  This enum contains DDC related error codes that will be passed
 *  to the DDA layer.
 */

typedef enum _DDC_ParamsConfigDone
{
    STATE_CONFIGURED,
    /**<    Resizer driver configured by application */
    STATE_NOT_CONFIGURED
        /**<    Resizer driver not configured by application */
}DDC_ParamsConfigDone;
/*******************************************************************************
  RESIZER CHANNEL Object
 ******************************************************************************/
/**
 * \brief Structure _DDC_RSZChanObject
 *  Structure to define the Resizer Driver object which includes relevant
 *  element for Resizer module functionality
 */
typedef struct _DDC_RSZChanObject
{

    DDC_RSZChanState                   state;
    /**<    Resizer state either closed or open for Ccdc */

    LLC_ResizerConfigParams       params;
    /**<    Handle for access the resizer config params */
    Int  priority;
    /**<        stores priority of the application */

    Int  ChannelStatus;
    /**<        stores statusof the channel */

    PAL_OsSemHandle  ChannelSem;
    /**<        Semaphore for every channel */

    DDC_ParamsConfigDone DDC_ParamsConfigState;
    /**<        stores state of configuration */
    Int  MemSegId;
    /**<        stores Memory segment id */

    Int32       semTimeOut;
    /**< Pending on semaphore timeout */

} DDC_RSZChanObject;

/*******************************************************************************
  Device Object
 ******************************************************************************/
/**
 * \brief  Structure _DDC_RSZDeviceObject
 * Stucture for the RSZ device object as a whole
 */
typedef struct _DDC_RSZDeviceObject
{
    Uint                            rszInstanceId;
    /**<  Resizer device id */
    resizerState                       state;
    /**<  Resizer channel state */
    Uint                            IntNum;
    /**<  Value for Front-end device object */
    Ptr                             regs;
    /**<    Handle for Resizer overlaying register */
    PAL_OsSemHandle   SemIsr;
    /**<  Semaphore for interrupt */
    Int     SemIsrTimeout;
    /**<  Configurable timeout value for interrupt semaphore */
    PAL_OsSemHandle ArraySem;
    /**<  Semaphore for array */
    DDC_RSZChanObject  *DDC_RSZChanConfig[PSP_RESIZER_NUM_CHANNELS];
    /**<  Pointer to resizer parameter structure */
    Int ArrayCount;
    /**<  for counting number of elements in arrray */
    PSP_RSZcallback   appCbk;
    /**<  Structure to store (pseudo)async callback and callback argument     */
    Bool   isAsyncResize;
    /**<  To check if the (pseudo)async has been used or sync method is used  */
    Bool   isResizeBusy;
    /**<  To check if the (pseudo)async resize operation is busy              */
    Uint32 asyncBufSize;
    /**<  The input buffer size that is given for resizing                    */
    Ptr asyncBufPtr;
    /**<  The input buffer resize pointer that is given for resize IOCTL      */
}DDC_RSZDeviceObject;

/******************************************************************************
  INTERFACE FUNCTIONS
  This Functions are called from the DDA Layer
 ******************************************************************************/
/**
 * \brief  Function DDC_RSZOpenHandle
 *  This function validate the basic parameters for various the
 *  channels, configure the hardware and return the handle to the
 *     specific reszier channel.
 *
 * \param      handle                  [IN]    It hold number of channel opened
 *                                              which the handle to be closed.
 *
 *
 * \returns    Handle to the specific channel
 */
PSP_Handle DDC_RSZOpenHandle(Int);
/**
 * \brief  Function DDC_RSZCloseHandle
 *  This function closes the handle of the corresponding channel
 *
 * \param      handle                  [IN]        Handle of the channel for
 *                                                 which the handle to be
 *                                                 closed.
 *
 * \returns    status                  [OUT]       Status of the operation.
 *
 *
 */
DDC_RSZStatus DDC_RSZCloseHandle(Ptr handle);
/**
 * \brief  Function DDC_RSZIoctl
 *  This function call the diferent control functions based on command.
 * \param      handle                  [IN]     Handle of the channel.
 * \param      Cmd                     [IN]     control operation command.
 * \param      argument                [IN]     structure for control operation
 * \param      params                  [IN]     Pointer for out structure.
 *
 * \returns    status                  [OUT]       Status of the operation.
 *
 */
PSP_Result DDC_RSZIoctl(PSP_Handle, PSP_RSZIoctlCmd, Ptr, Ptr);
/**
 * \brief  Function DDC_RSZInitializeModule
 * This function perform the Initialize activities.
 * \param none
 * \returns none
 *
 */
void * DDC_RSZInitializeModule (void);
/**
 * \brief  Function DDC_RSZRemoveModule
 * This function perform the DeInitialize activities
 * \param  None
 * \returns None
 *
 */
void * DDC_RSZRemoveModule (void);
/******************************************************************************
  LOCAL FUNCTIONS
  This Functions are called at DDC Layer functions
 ******************************************************************************/

/**
 *  \brief  Function DDC_RSZGetChannelHandle
 *  This function returns the handle of the corresponding ID that
 *  has been passed.
 *
 *  \returns    Handle of Resizer for which the ID is passed.
 */
void * DDC_RSZGetChannelHandle();

/**
 * \brief Function DDCStartResize
 *  This function start the resizing operation after parameters are configured
 * \param      DDC_RSZChanObject   [IN]    Pointer to channel object
 *  \param     Id                     [IN] Pointer to resizer structure
 *                                          passed by application
 *  \returns   Channel handle
 *
 */
Int DDCStartResize(DDC_RSZChanObject * const , PSP_RSZresize * const );
/**
 *  \brief  Function DDC_RSZAddToArray
 This function used to add the channel pointer id into queue
 *  \param      DDC_RSZChanObject   [IN]    Pointer to channel object
 *  \returns    status of the operation
 *
 */

Int DDC_RSZAddToArray(DDC_RSZChanObject* const );
/**
 * \brief Function DDC_RSZDeleteFromArray
 This function used to delete the channel pointer id into queue
 * \param      DDC_RSZChanObject   [IN]    Pointer to channel object
 * \returns    status of the operation
 *
 */
Int DDC_RSZDeleteFromArray(DDC_RSZChanObject * const );
/**
 * \brief Function DDC_RSZValidateParameters
 * This function set up the harware parameters
 *  \param     DDC_RSZChanObject   [IN]    Pointer to channel object
 *  \param     PSP_RSZparams       [IN]    Pointer to params structure
 *                                         passed by application
 *  \returns Status of the operation
 *
 *
 */
Int DDC_RSZValidateParameters(DDC_RSZChanObject * , PSP_RSZparams *const);
/**
 * \brief  Function DDC_RSZGetParameters
 *  This function get the harware parameters
 *  \param     DDC_RSZChanObject   [IN]    Pointer to channel object
 *  \param     PSP_RSZparams       [IN]    Pointer to params structure passed
 *                                         by application
 *  \returns status of the operation
 *
 */
Int DDC_RSZGetParameters(DDC_RSZChanObject *const, PSP_RSZparams *const);
/**
 * \brief Function DDC_RSZGetCropSize
 * This function calculat the crop size
 * \param      DDC_RSZChanObject   [IN]    Pointer to channel object
 * \param      PSP_RSZparams       [OUT]   Pointer to params structure passed
 *                                         by application
 *
 * \returns    Status of the operation
 *
 *
 */

Int DDC_RSZGetCropSize(DDC_RSZChanObject *const, PSP_RSZcropsize *const);
/**
 * \brief  DDC_RSZGetPriority
 * This function get the croping information about image
 *  \param     DDC_RSZChanObject   [IN]    Pointer to channel object
 *  \param     PSP_RSZcropsize     [OUT]   Pointer to cropsize structure passed
 *                                         by application
 *  \returns Status of the operation
 *
 */
Int DDC_RSZGetPriority(DDC_RSZChanObject *const, PSP_RSZpriority *const);
/**
 * \brief  Function DDC_RSZGetStatus
 * This function get the priority about the channel
 *  \param     DDC_RSZChanObject   [IN]    Pointer to channel object
 *  \param     PSP_RSZpriority     [OUT]   Pointer to priority structure passed
 *                                         by application
 *  \returns Status of the operation
 *
 */
Int DDC_RSZGetStatus(DDC_RSZChanObject *const, PSP_RSZstatus *const);
/**
 * \brief  Function DDC_RSZSetPriority
 *  This function get the status of the channel
 *  \param     DDC_RSZChanObject   [IN]    Pointer to channel object
 *  \param     PSP_RSZstatus       [OUT]   Pointer to status structure passed
 *                                         by application
 *  \returns Status of the operation
 *
 */
Int DDC_RSZSetPriority(DDC_RSZChanObject *const, PSP_RSZpriority *const);
/**
 * \brief  Function DDC_RSZIsChannelHandleClosed
 * This function set the priority of the channel
 *  \param     DDC_RSZChanObject   [IN]    Pointer to channel object
 *  \param     PSP_RSZpriority     [IN]    Pointer to priority structure passed
 *  by application
 *  \returns Status of operation
 *
 */
DDC_RSZStatus DDC_RSZIsChannelHandleClosed(Ptr handleICH);
/**
 * \brief  Function DDC_RSZGetDeviceHandle
 * This function is used to get the device handle
 *
 * \returns    DDC_RSZ_E_FAIL  - if  handle is obtained
 *             DDC_RSZ_SOK -     if channel handle is not obtained
 */

PSP_Handle DDC_RSZGetDeviceHandle(void);

/**
 *  \brief  Function DDC_RSZIsr
 * This is the front end ISR. This will be invoked at every resizing
 *  interrupt.
 *
 *
 *  \returns    Status of operation
 */

void DDC_RSZIsr(Uint32 arg);

/**
 * \brief Function DDC_RSZPerformRegOvrl
 * It will Perform register overlaying
 *
 * \param           None
 * \returns          None
 *
 */
void DDC_RSZPerformRegOvrl(void);

/**
 * \brief Function DDC_RSZSetDeviceInterruptNumber
 * Set device ISR number
 * \param  None
 * \returns None
 *
 */
void DDC_RSZSetDeviceInterruptNumber();

#ifdef __cplusplus
}
#endif

#endif /*_DDC_RSZ_H */
