/*******************************************************************************
**+--------------------------------------------------------------------------+**
**|                            ****                                          |**
**|                            ****                                          |**
**|                            ******o***                                    |**
**|                      ********_///_****                                   |**
**|                      ***** /_//_/ ****                                   |**
**|                       ** ** (__/ ****                                    |**
**|                           *********                                      |**
**|                            ****                                          |**
**|                            ***                                           |**
**|                                                                          |**
**|         Copyright (c) 2006-2010 Texas Instruments Incorporated           |**
**|                        ALL RIGHTS RESERVED                               |**
**|                                                                          |**
**| Permission is hereby granted to licensees of Texas Instruments           |**
**| Incorporated (TI) products to use this computer program for the sole     |**
**| purpose of implementing a licensee product based on TI products.         |**
**| No other rights to reproduce, use, or disseminate this computer          |**
**| program, whether in part or in whole, are granted.                       |**
**|                                                                          |**
**| TI makes no representation or warranties with respect to the             |**
**| performance of this computer program, and specifically disclaims         |**
**| any responsibility for any damages, special or consequential,            |**
**| connected with the use of this program.                                  |**
**|                                                                          |**
**+--------------------------------------------------------------------------+**
*******************************************************************************/

/**
 *  \file   llc_rsz.c
 *
 *  \brief  Resizer LLC layer Function dependencies
 *
 *  This file contains the dependencies of LLC layer functions
 *
 *  (C) Copyright 2010, Texas Instruments, Inc
 *
 *  \author     EI3
 *
 *  \version    0.1     Created
 *              1.0     First release
 */
#include <ti/sdo/pspdrivers/soc/dm6437/dsp/csl_error.h>
#include <ti/sdo/pspdrivers/soc/dm6437/dsp/cslr_resz.h>
#include <ti/sdo/pspdrivers/drivers/resizer/src/llc_rsz.h>
#include <ti/sdo/pspdrivers/soc/dm6437/dsp/cslr_vpss.h>
#include <ti/sdo/pspdrivers/soc/dm6437/dsp/soc.h>

/******************************************************************************
  Function Prototypes
 ******************************************************************************/

Int LLC_RSZHardwareSetup(LLC_ResizerConfigParams *setup, Ptr regs);
Int LLC_RSZresizerEnable(Ptr regs);
Int LLC_RSZGetHWStatus(Ptr regs);
Int LLC_RSZSetExp(Int exp);
Int LLC_GetWriteBufferStatus();
Int LLC_RSZResetRegister(Ptr const regs);

/******************************************************************************
  Functions
 ******************************************************************************/

/**
 * \brief Function LLC_RSZHardwareSetup
 * This will set the hardware register overlaying structure
 *
 */
Int LLC_RSZHardwareSetup(LLC_ResizerConfigParams *setup, Ptr regs)
{
    Int i;
    CSL_ReszRegsOvly tempAddr;

    if (NULL != setup)
    {
        if (NULL != regs)
        {

            tempAddr = (CSL_ReszRegsOvly)regs;


            CSL_FINS(tempAddr->YENH, RESZ_YENH_ALGO,
                CSL_RESZ_YENH_ALGO_DISABLE);
            /* According to requiremnt input is always from DDR2 so
             * explicitly done 1 */
            CSL_FINS(tempAddr->RSZ_CNT, RESZ_RSZ_CNT_INPSRC, INPUT_SOURCE_DDR2);

            CSL_FINS(tempAddr->RSZ_CNT, RESZ_RSZ_CNT_INPTYP, setup->inptyp);

            CSL_FINS(tempAddr->RSZ_CNT, RESZ_RSZ_CNT_YCPOS, setup->pixfmt);

            CSL_FINS(tempAddr->RSZ_CNT, RESZ_RSZ_CNT_CBILIN, setup->cbilin);


            CSL_FINS(tempAddr->IN_START, RESZ_IN_START_VERT_ST,
                setup->vertStartingPixel);
            CSL_FINS(tempAddr->IN_START, RESZ_IN_START_HORZ_ST,
                setup->horzStartingPixel);



            CSL_FINS(tempAddr->IN_SIZE, RESZ_IN_SIZE_VERT, setup->inVsize);
            CSL_FINS(tempAddr->IN_SIZE, RESZ_IN_SIZE_HORZ, setup->inHsize);



            CSL_FINS(tempAddr->OUT_SIZE, RESZ_OUT_SIZE_VERT, setup->outVsize);
            CSL_FINS(tempAddr->OUT_SIZE, RESZ_OUT_SIZE_HORZ, setup->outHsize);


            CSL_FINS(tempAddr->RSZ_CNT, RESZ_RSZ_CNT_VRSZ, setup->vrsz);
            CSL_FINS(tempAddr->RSZ_CNT, RESZ_RSZ_CNT_HRSZ, setup->hrsz);


            CSL_FINS(tempAddr->RSZ_CNT, RESZ_RSZ_CNT_VSTPH, setup->hstph);
            CSL_FINS(tempAddr->RSZ_CNT, RESZ_RSZ_CNT_HSTPH, setup->vstph);


            CSL_FINS(tempAddr->SDR_INOFF, RESZ_SDR_INOFF_OFFSET,
                setup->inPitch);


            CSL_FINS(tempAddr->SDR_INADD, RESZ_SDR_INADD_SDR_INADD,
                (Uint32)setup->inAddress);


            CSL_FINS(tempAddr->SDR_OUTOFF, RESZ_SDR_OUTOFF_OFFSET,
                setup->outPitch);


            CSL_FINS(tempAddr->SDR_OUTADD, RESZ_SDR_OUTADD_SDR_OUTADD,
                (Uint32)setup->outAddress);

            /* Configuration of coefficients into register. Every register
               will hold two coefficients */
            for (i=ZERO;i<MAX_COEF_COUNTER;i++)
            {

                CSL_FINS(*((&tempAddr->HFILT10)+ i), RESZ_HFILT10_COEF0,
                    setup->hfiltCoeffs[i*2]);
                CSL_FINS(*((&tempAddr->HFILT10)+ i), RESZ_HFILT10_COEF1,
                    setup->hfiltCoeffs[((i*2)+NEXT)]);
                CSL_FINS(*(&tempAddr->VFILT10+ i), RESZ_VFILT10_COEF0,
                    setup->vfiltCoeffs[i*2]);
                CSL_FINS(*(&tempAddr->VFILT10+ i), RESZ_VFILT10_COEF1,
                    setup->vfiltCoeffs[((i*2)+NEXT)]);

            }

            CSL_FINS(tempAddr->YENH, RESZ_YENH_ALGO, setup->yenhParams.type);
            CSL_FINS(tempAddr->YENH, RESZ_YENH_GAIN, setup->yenhParams.gain);
            CSL_FINS(tempAddr->YENH, RESZ_YENH_SLOP, setup->yenhParams.slop);
            CSL_FINS(tempAddr->YENH, RESZ_YENH_CORE, setup->yenhParams.core);
        }
    }
    return CSL_SOK;
}
/**
 * \brief Function LLC_RSZresizerEnable
 * This will enable the resizer engine
 *
 */
Int LLC_RSZresizerEnable(Ptr regs)
{
    CSL_ReszRegsOvly tempAddrEN;

    if (NULL != regs)
    {
        tempAddrEN = (CSL_ReszRegsOvly )regs;
        CSL_FINS(tempAddrEN->PCR, RESZ_PCR_ENABLE, CSL_RESZ_PCR_ENABLE_ENABLE);
    }
    return CSL_SOK;
}

/**
 * \brief Function LLC_RSZGetHWStatus
 * This will enable the resizer engine
 *
 */
Int LLC_RSZGetHWStatus(Ptr regs)
{
    CSL_ReszRegsOvly tempAddrST;
    Int pcr = -1;
    if (NULL != regs)
    {

        tempAddrST = (CSL_ReszRegsOvly )regs;
        pcr  = CSL_FEXT(tempAddrST->PCR , RESZ_PCR_BUSY);

    }
    return(pcr);

}
/**
 * \brief Function LLC_RSZSetExp
 * This Function will set the delay time for read request.
 *
 */
Int LLC_RSZSetExp(Int exp)
{

    CSL_VpssRegsOvly vpssreg;

    vpssreg = (CSL_VpssRegsOvly)CSL_VPSS_0_REGS;

    CSL_FINS( vpssreg->SDR_REQ_EXP, VPSS_SDR_REQ_EXP_RESZ_EXP, exp);

    return CSL_SOK;
}
/**
 * \brief Function LLC_GetWriteBufferStatus
 * This Function is used to check the write buffer overflow bit.
 *
 *
 */
Int LLC_GetWriteBufferStatus()
{

    CSL_VpssRegsOvly vpssregBS;
    Int valueWB = -1;

    vpssregBS = (CSL_VpssRegsOvly)CSL_VPSS_0_REGS;

    if (NULL != vpssregBS)
    {

        valueWB = vpssregBS->PCR;
        valueWB  = ((valueWB >> LLC_WBSSHIFT) & LLC_WBSMASK);

    }
    return (valueWB);
}
/**
 * \brief Function LLC_RSZResetRegister
 * This Function is used to set the initail values to register.
 *
 *
 */

Int LLC_RSZResetRegister(Ptr const regs)
{
    CSL_ReszRegsOvly tempAddrRST;
    Int filterCounter = 0;
    Int statusReset = 0;
    if (NULL != regs)
    {
        tempAddrRST = (CSL_ReszRegsOvly)regs;
        if (NULL != tempAddrRST)
        {
            tempAddrRST->PID        = CSL_RESZ_PID_RESETVAL;
            tempAddrRST->PCR        = CSL_RESZ_PCR_RESETVAL;
            tempAddrRST->RSZ_CNT    = CSL_RESZ_RSZ_CNT_RESETVAL;
            tempAddrRST->OUT_SIZE   = CSL_RESZ_OUT_SIZE_RESETVAL;
            tempAddrRST->IN_START   = CSL_RESZ_IN_START_RESETVAL;
            tempAddrRST->IN_SIZE    = CSL_RESZ_IN_SIZE_RESETVAL;
            tempAddrRST->SDR_INADD  = CSL_RESZ_SDR_INADD_RESETVAL;
            tempAddrRST->SDR_INOFF  = CSL_RESZ_SDR_INOFF_RESETVAL;
            tempAddrRST->SDR_OUTADD = CSL_RESZ_SDR_OUTADD_RESETVAL;
            tempAddrRST->SDR_OUTOFF = CSL_RESZ_SDR_OUTOFF_RESETVAL;
            for(filterCounter =ZERO;filterCounter <MAX_COEF_COUNTER;
                filterCounter++)
            {
                *(&tempAddrRST->HFILT10+filterCounter)
                    = CSL_RESZ_HFILT10_RESETVAL;
                *(&tempAddrRST->VFILT10+filterCounter)
                    = CSL_RESZ_VFILT10_RESETVAL;
            }

            tempAddrRST->YENH   = CSL_RESZ_YENH_RESETVAL;
        }
        else
        {   /* 1 indicates error is there for reset */
            statusReset = 1;
        }
    }
    return statusReset;
}

