/*******************************************************************************
**+--------------------------------------------------------------------------+**
**|                            ****                                          |**
**|                            ****                                          |**
**|                            ******o***                                    |**
**|                      ********_///_****                                   |**
**|                      ***** /_//_/ ****                                   |**
**|                       ** ** (__/ ****                                    |**
**|                           *********                                      |**
**|                            ****                                          |**
**|                            ***                                           |**
**|                                                                          |**
**|         Copyright (c) 2006-2010 Texas Instruments Incorporated           |**
**|                        ALL RIGHTS RESERVED                               |**
**|                                                                          |**
**| Permission is hereby granted to licensees of Texas Instruments           |**
**| Incorporated (TI) products to use this computer program for the sole     |**
**| purpose of implementing a licensee product based on TI products.         |**
**| No other rights to reproduce, use, or disseminate this computer          |**
**| program, whether in part or in whole, are granted.                       |**
**|                                                                          |**
**| TI makes no representation or warranties with respect to the             |**
**| performance of this computer program, and specifically disclaims         |**
**| any responsibility for any damages, special or consequential,            |**
**| connected with the use of this program.                                  |**
**|                                                                          |**
**+--------------------------------------------------------------------------+**
*******************************************************************************/

/**
 *  \file   llc_rsz.h
 *
 *  \brief  Resizer LLC layer Function dependencies
 *
 *  This file contains the dependencies of LLC layer functions
 *
 *  (C) Copyright 2010, Texas Instruments, Inc
 *
 *
 *  \author     EI3
 *
 *  \version    0.1     Created
 *              1.0     First release
 */
#ifndef _LLC_RSZ_H
#define _LLC_RSZ_H

/******************************************************************************
  Headers
 ******************************************************************************/
#include <ti/sdo/pspdrivers/drivers/resizer/psp_resizer.h>

#ifdef __cplusplus
extern "C" {
#endif

/**
 *  \brief  Structure _LLC_RESIZERConfigParams
 *  Conatins all the parameters for resizing . This structure
 *   is used to configure resiser parameters
 */
#define MAX_COEF_COUNTER                (16)
#define NEXT                            (1)
#define ZERO                            (0u)
#define LLC_WBSSHIFT                    (18u)
#define LLC_WBSMASK                     (15u)
#define INPUT_SOURCE_DDR2               (1u)
/******************************************************************************
  Data structure
 ******************************************************************************/
typedef struct _LLC_ResizerConfigParams
{
    Int inHsize;
    /**< represents input frame horizontal size */
    Int inVsize;
    /**< represents linput frame vertical size */
    Int inPitch;
    /**< represents offset between two rows of input frame */
    Int inptyp;
    /**< For determining 16 bit or 8 bit data */
    Int vertStartingPixel;
    /**< for specifying vertical starting pixel in input */
    Int horzStartingPixel;
    /**< for specyfing horizontal starting pixel in input */
    Int cbilin;
    /**< defined, filter with luma or bi-linear Interpolation */
    Int pixfmt;
    /**< defined, UYVY or YUYV image format */
    Int outHsize;
    /**< represents output frame horizontal size */
    Int outVsize;
    /**< represents output frame vertical size */
    Int outPitch;
    /**< represents offset between two rows of output frame */
    Int hstph;
    /**< for specifying horizontal starting phase */
    Int vstph;
    /**< for specifying vertical starting phase */
    Int16 hfiltCoeffs[32];
    /**< horizontal filter coefficients */
    Int16 vfiltCoeffs[32];
    /**< vertical filter coefficients */
    PSP_RSZyenhParams yenhParams;
    /**< represents luma enhacement parameters */
    Int hrsz;
    /**< Horizonatl resize ratio */
    Int vrsz;
    /**< Vertical resize ratio */
    Int      inAddress;
    /**< Inpur frame address */
    Int      outAddress;
    /**< Output frame address */

}LLC_ResizerConfigParams;

/******************************************************************************
  Functions
 ******************************************************************************/
/**
 * \brief Function LLC_RSZHardwareSetup(
 * This will set the hardware register overlaying structure
 *
 * \param  regs       [IN] Channel confuguration structure
 * \param  address     [IN]    base address of the resizer register
 * \returns                NULL
 *
 */
Int LLC_RSZHardwareSetup(LLC_ResizerConfigParams *, Ptr );
/**
 * \brief Function LLC_RSZresizerEnable
 * This will enable the resizer engine
 *
 * \param  regs       [IN] Channel confuguration structure
 * \returns                  None
 *
 */
Int  LLC_RSZresizerEnable(Ptr );
/**
 * \brief Function LLC_RSZGetHWStatus
 * This will enable the resizer engine
 *
 * \param  regs       [IN] void
 * \returns NULL
 *
 *
 */
Int LLC_RSZGetHWStatus(Ptr );

/**
 * \brief Function LLC_RSZSetExp
 * This Function will set the delay time for read request.
 *
 * \param  exp    [IN] void
 * \returns         1 on Sucess
 *
 *
 */
Int LLC_RSZSetExp(int );
/**
 * \brief This Function is used to check the write buffer overflow bit.
 *
 * \param  regs       [IN] void
 * \returns NULL
 *
 *
 */
Int LLC_GetWriteBufferStatus();

/**
 * \brief Function LLC_RSZResetRegister
 * This Function is initialize the register with initial values.
 *
 * \param  regs       [IN] void
 * \returns 1 on sucess
 *
 *
 */
Int LLC_RSZResetRegister(Ptr const );

#ifdef __cplusplus
}
#endif

#endif  /* _LLC_RSZ_H */
