/*******************************************************************************
**+--------------------------------------------------------------------------+**
**|                            ****                                          |**
**|                            ****                                          |**
**|                            ******o***                                    |**
**|                      ********_///_****                                   |**
**|                      ***** /_//_/ ****                                   |**
**|                       ** ** (__/ ****                                    |**
**|                           *********                                      |**
**|                            ****                                          |**
**|                            ***                                           |**
**|                                                                          |**
**|         Copyright (c) 2006-2010 Texas Instruments Incorporated           |**
**|                        ALL RIGHTS RESERVED                               |**
**|                                                                          |**
**| Permission is hereby granted to licensees of Texas Instruments           |**
**| Incorporated (TI) products to use this computer program for the sole     |**
**| purpose of implementing a licensee product based on TI products.         |**
**| No other rights to reproduce, use, or disseminate this computer          |**
**| program, whether in part or in whole, are granted.                       |**
**|                                                                          |**
**| TI makes no representation or warranties with respect to the             |**
**| performance of this computer program, and specifically disclaims         |**
**| any responsibility for any damages, special or consequential,            |**
**| connected with the use of this program.                                  |**
**|                                                                          |**
**+--------------------------------------------------------------------------+**
*******************************************************************************/
/**
 *  \file   psp_rszApi.h
 *
 *  \brief  Resizer APIs defination
 *
 *  This file contains the APIs that are used at DDA layer of the driver.
 *
 *  (C) Copyright 2006, Texas Instruments, Inc
 *
 *
 *  \version    0.1     EI3     Created
 */
#ifndef _PSP_RSZAPI_H_
#define _PSP_RSZAPI_H_

#include <ti/sdo/pspdrivers/common/psp_common.h>
#include <gio.h>
#include <ti/sdo/pspdrivers/soc/dm6437/dsp/tistdtypes.h>

#ifdef __cplusplus
extern "C" {
#endif

/******************************************************************************
  Functions
 ******************************************************************************/
/**
 *  \brief    Function PSP_RSZCreate
 *  This function is the first to be called and is used for driver
 *  initialization.
 *
 *  It performs register map overlaying and software book-keeping.
 *  It registers the interrupt Handler.
 *
 *
 *  \returns    Returns               SUCCESS/FAILURE status.
 */
PSP_Handle  PSP_RSZCreate(Uint32);
/**
 *  \brief    Function PSP_RSZDelete
 *  This function is called last and is used for driver deletion.
 *
 *
 *
 *
 *  \returns    Returns                             SUCCESS/FAILURE status.
 */
PSP_Result      PSP_RSZDelete();
/**
 *  \brief  Function PSP_RSZClose
 *   This function close individual Channel handle for Resizer
 *   Modules
 *
 *  \param      handle          [IN]    Resizer individual channel Handle
 *                                      to be closed.
 *
 *  \Returns    Returns                 SUCCESS/FAILURE status.
 */
PSP_Result      PSP_RSZClose(PSP_Handle  handle);
/**
 *  \brief Function   PSP_RSZOpen
 *  This function creates the channel handle for Resizer
 *  driver.

 *  \returns  Returns     Channel handle of Resizer or NULL
 */
PSP_Handle      PSP_RSZOpen();
/**
 *  \brief  Function  PSP_RSZIoctl
 *  This function makes runtime changes for the Resizer.
 *
 *
 *  \param    handle          [IN]    Channel Handle for resizer
 *
 *
 *  \param    cmd             [IN]    IOCTL command
 *
 *  \param    cmdArg          [IN]    Command Arguments to be passed.
 *
 *
 *  \param    params          [IN]    Reserved for Future Use.
 *
 *  \Returns    Returns               SUCCESS/FAILURE status.
 */

PSP_Result      PSP_RSZIoctl(PSP_Handle handle,
    PSP_RSZIoctlCmd   cmd,
    Ptr               cmdArg,
    Ptr               params);

#ifdef __cplusplus
}
#endif

#endif  /* _PSP_RSZAPI_H_ */
