/******************************************************************************
**+-------------------------------------------------------------------------+**
**|                            ****                                         |**
**|                            ****                                         |**
**|                            ******o***                                   |**
**|                      ********_///_****                                  |**
**|                      ***** /_//_/ ****                                  |**
**|                       ** ** (__/ ****                                   |**
**|                           *********                                     |**
**|                            ****                                         |**
**|                            ***                                          |**
**|                                                                         |**
**|         Copyright (c) 2006-2010 Texas Instruments Incorporated          |**
**|                        ALL RIGHTS RESERVED                              |**
**|                                                                         |**
**| Permission is hereby granted to licensees of Texas Instruments          |**
**| Incorporated (TI) products to use this computer program for the sole    |**
**| purpose of implementing a licensee product based on TI products.        |**
**| No other rights to reproduce, use, or disseminate this computer         |**
**| program, whether in part or in whole, are granted.                      |**
**|                                                                         |**
**| TI makes no representation or warranties with respect to the            |**
**| performance of this computer program, and specifically disclaims        |**
**| any responsibility for any damages, special or consequential,           |**
**| connected with the use of this program.                                 |**
**|                                                                         |**
**+-------------------------------------------------------------------------+**
******************************************************************************/

/**
 *  \file   dda_spiBios.h
 *
 *  \brief  SPI IOM Layer definition
 *
 *  This file contains the interfaces, data types and symbolic definitions
 *  that are needed by the application to utilize the services of the SPI
 *  device driver.
 *
 *  (C) Copyright 2006, Texas Instruments, Inc
 *
 *
 *  \author     PSG
 *  \version    0.1     Created                         Kapil Bohra
 *              0.2     Arranged datastruture members
 *                      and clean up effort             Nagarjuna Kristam
 *              0.3     Implemented review comments
 */


#ifndef _DDA_SPIBIOS_H
#define _DDA_SPIBIOS_H

#include <std.h>
#include <iom.h>
#include <ti/sdo/pspdrivers/common/psp_common.h>
#include <ti/sdo/pspdrivers/drivers/spi/psp_spi.h>
#include <ti/sdo/pspdrivers/drivers/spi/src/psp_spiApi.h>
#include <ti/sdo/pspdrivers/drivers/spi/src/ddc_spi.h>

#ifdef CHIP_DM648
#include <ti/sdo/pspdrivers/soc/dm648/dsp/tistdtypes.h>
#include <ti/sdo/pspdrivers/soc/dm648/dsp/cslr_spi.h>
#endif

#ifdef CHIP_C6452
#include <ti/sdo/pspdrivers/soc/c6452/dsp/tistdtypes.h>
#include <ti/sdo/pspdrivers/soc/c6452/dsp/cslr_spi.h>
#endif

#ifdef __cplusplus
extern "C" {
#endif

/**
 *  \brief  channel structure
 *
 * There is one SpiChanObj per direction.  This mini-driver must be
 * opened for input and output separately.
 *
 */
typedef struct SpiChanObj_t
{
    Uint32                   mode;
    /**<  INPUT or OUTPUT                       */
    struct SpiPortObj_t       *port;
    /**<  to support multiple SPI spi_Ports     */
    IOM_TiomCallback        cbFxn;
    /**<  to notify client when I/O complete    */
    Ptr                     cbArg;
    /**<  argument for cbFxn()                  */
    PSP_Handle              ddc_Handle;
    /**<  Spi Handle to access the spi params   */
} SpiChanObj , *SpiChanHandle;

/**
 *  \brief  port structure
 *
 * There is one SpiPortObj per SPI.
 * This mini-driver supspi_Ports 'NUMPORTS' SPI.
 *
 */
typedef struct  SpiPortObj_t
{
    Uns                           spiPortNumber;
    /**<  Instance number for back reference            */
    SpiChanObj                    chans[PSP_SPI_NUM_OPENS];
    /**<  channels for the SPI                          */
    DDC_SPIState                spiState;
    /**<  state of the SPI Either open or closed        */

} SpiPortObj, *SpiPortHandle;


/************< Functions implemented by DDA ************/
/*
 *  ======== _DDA_spiRegisterIntrHandler ========
 *
 */
void _DDA_spiRegisterIntrHandler(
                                 Uint32     instNum,
                                 Uint32     intNum,
                                 pspSpiIsr  initIsr,
                                 PSP_Handle spiObj
                                );



/*
 *  ======== _DDA_spiUnregisterIntrHandler ========
 *
 */
void _DDA_spiUnregisterIntrHandler(Uint32 instNum, Uint32 intNum);

#ifdef __cplusplus
}
#endif /* extern "C" */

#endif /* _DDA_SPIBIOS_H */
