/******************************************************************************
**+-------------------------------------------------------------------------+**
**|                            ****                                         |**
**|                            ****                                         |**
**|                            ******o***                                   |**
**|                      ********_///_****                                  |**
**|                      ***** /_//_/ ****                                  |**
**|                       ** ** (__/ ****                                   |**
**|                           *********                                     |**
**|                            ****                                         |**
**|                            ***                                          |**
**|                                                                         |**
**|         Copyright (c) 2006-2010 Texas Instruments Incorporated          |**
**|                        ALL RIGHTS RESERVED                              |**
**|                                                                         |**
**| Permission is hereby granted to licensees of Texas Instruments          |**
**| Incorporated (TI) products to use this computer program for the sole    |**
**| purpose of implementing a licensee product based on TI products.        |**
**| No other rights to reproduce, use, or disseminate this computer         |**
**| program, whether in part or in whole, are granted.                      |**
**|                                                                         |**
**| TI makes no representation or warranties with respect to the            |**
**| performance of this computer program, and specifically disclaims        |**
**| any responsibility for any damages, special or consequential,           |**
**| connected with the use of this program.                                 |**
**|                                                                         |**
**+-------------------------------------------------------------------------+**
******************************************************************************/
/**
 *  \file   psp_vpbe.h
 *
 *  \brief  VPBE interface definition
 *
 *  This file contains the interfaces, data types and symbolic definitions
 *  that are needed by the application to utilize the serivces of the VPBE
 *  device driver.
 *
 *  (C) Copyright 2010, Texas Instruments, Inc
 *
 *  \note       Set tabstop to 4 (:se ts=4) while viewing this file in an
 *              editor
 *
 *  \author     Maulik Desai
 *
 *  \version    0.1     Created
 *
 *  <b>Compiler Switch Used</b>
 *
 *  <b>_DEBUG</b><br>
 *   This is used as a flag to compiler whether to include the debug statements
 *   inserted in the code into the final image. This flag helps to build DEBUG
 *   image of the program. For RELEASE images this is not passed to the compiler.
 *
 *  <b>CHIP_XXXX</b><br>
 *   The CSL layer is written in a common file for all the variants of a SOC.
 *   This flag differentiates the variant we are compiling for, for e.g.
 *   CHIP_DM648, and the CSL definitions for that variant appropriately gets
 *   defined for register base addresses, num of ports of a peripheral etc.
 *
 *  <b>VPBE_INSTRUMENTATION_ENABLED</b><br>
 *   This flag is passed to the compiler to include the instrumentation code
 *   parts into the final image/lib of the program. This helps build the
 *   iRelease/iDebug versions of the image/lib with a common code base.
 *
 */
#ifndef _PSP_VPBE_H
#define _PSP_VPBE_H

/**
 * Header File Inclusion
 */
#include <ti/sdo/pspdrivers/system/dm6437/bios/evmDM6437/video/fvid.h>
#include <ti/sdo/pspdrivers/system/dm6437/bios/evmDM6437/video/psp_vpss_extvidEncoder.h>

#ifdef __cplusplus
extern "C" {
#endif

/**<  brief number of instances supported by  platform  */
#define PSP_VPBE_NUM_INSTANCES              (1u)
/**< First instance Id index                            */
#define PSP_VPBE_0_INSTANCE_ID              (0u)

/**
 * Defines
 */
#define PSP_VPBE_MAX_MAIN_CLUT_ENTRIES      (256u)

#define PSP_VPBE_MAX_BMP_CLUT_ENTRIES       (16u)

/* External Peripheral Command base */
#define VPBE_ExtVIDENC_BASE                 (0x800000u)

/**
  * \brief Enum defines the channnel id for different plane
  *
  */
typedef enum _PSP_VPBE_Id
{
    /**< Invalid VPBE id                                                     */
    PSP_VPBE_INVALID_ID = -1,
    /**< Video 0 plane  id                                                   */
    PSP_VPBE_VIDEO_0,
    /**< Video 1 plane  id                                                   */
    PSP_VPBE_VIDEO_1,
    /**< OSD 0 plane  id                                                     */
    PSP_VPBE_OSD_0,
    /**< OSD 1 plane  id                                                     */
    PSP_VPBE_OSD_1,
    /**< Cursor plane  id                                                    */
    PSP_VPBE_CURSOR,
    /**< Venc plane  id                                                      */
    PSP_VPBE_VENC,
    /**< Maximum Interfaces Supported                                        */
    PSP_VPBE_MAX_INTERFACES_SUPPORTED

} PSP_VPBE_Id;

/**
  * \brief Enum for vpbe related IOCTL
  *
  */
typedef enum _PSP_VPBEIoctlCommand
{
    PSP_VPBE_IOCTL_OSD_BOUNDARY,
    /**< IOCTL for OSD Windows Boundary Parameters                          */
    PSP_VPBE_IOCTL_OSD_BLENDING,
    /**< IOCTL for OSD Windows Blending Factor                              */
    /**< Applicable for OSD-0 and OSD-1 Windows                             */
    PSP_VPBE_IOCTL_OSD_TRANSPARENCY,
    /**< IOCTL for OSD Windows Tranparency color                            */
    /**< Applicable for OSD-0 and OSD-1 Windows                             */
    PSP_VPBE_IOCTL_OSD_ZOOM,
    /**< IOCTL for Zooming OSD Windows                                      */
    PSP_VPBE_IOCTL_OSD_PROGRAM_MAIN_CLUT,
    /**< IOCTL for Program Main CLUT                                        */
    PSP_VPBE_IOCTL_OSD_PROGRAM_BMP_CLUT,
    /**< IOCTL for Program BMP CLUT                                         */
    PSP_VPBE_IOCTL_OSD_VALIDATE_BUFFER,
    /**< IOCTL for Validate Buffer                                          */
    PSP_VPBE_IOCTL_START_VIDEO_0,
    /**< IOCTL to Start Video-0 Buffer                                      */
    PSP_VPBE_IOCTL_START_VIDEO_1,
    /**< IOCTL to Start Video-1 Buffer                                      */
    PSP_VPBE_IOCTL_START_OSD_0,
    /**< IOCTL to Start OSD-0 Buffer                                        */
    PSP_VPBE_IOCTL_START_OSD_1,
    /**< IOCTL to Start OSD-1 Buffer                                        */
    PSP_VPBE_IOCTL_START_CURSOR,
    /**< IOCTL to Start Cursor                                              */
    PSP_VPBE_IOCTL_START_VENC,
    /**< IOCTL to Start Venc                                                */
    PSP_VPBE_IOCTL_STOP_VIDEO_0,
    /**< IOCTL to Stop Video-0                                              */
    PSP_VPBE_IOCTL_STOP_VIDEO_1,
    /**< IOCTL to Stop Video-1                                              */
    PSP_VPBE_IOCTL_STOP_OSD_0,
    /**< IOCTL to Stop OSD-0                                                */
    PSP_VPBE_IOCTL_STOP_OSD_1,
    /**< IOCTL to Stop OSD-1                                                */
    PSP_VPBE_IOCTL_STOP_CURSOR,
    /**< IOCTL to Stop Cursor                                               */
    PSP_VPBE_IOCTL_STOP_VENC
    /**< IOCTL to Stop VENC                                                 */
} PSP_VPBEIoctlCommand;

/**
 * Blending Ratio
 */
 /**
  * \brief Enum for the Blending Ratio factor for different planes
  *        (VIDEO/OSD)
  *
  */
typedef enum _PSP_VPBE_BlendingFactor
{
    PSP_VPBE_BLEND0 = 0,
    PSP_VPBE_BLEND1,
    PSP_VPBE_BLEND2,
    PSP_VPBE_BLEND3,
    PSP_VPBE_BLEND4,
    PSP_VPBE_BLEND5,
    PSP_VPBE_BLEND6,
    PSP_VPBE_BLEND7
} PSP_VPBEBlendingFactor;
/**
  * \brief Enum for the different Scaling Factors for specified planes
  *
  */
typedef enum _PSP_VPBE_Scalingfactor
{
    /**< No Scaling                                                          */
    PSP_VPBE_ZOOM_IDENTITY = 1,
    /**< Scaling by 2x                                                       */
    PSP_VPBE_ZOOM_2X,
    /**< Scaling by 4x                                                       */
    PSP_VPBE_ZOOM_4X

} PSP_VPBEScalingFactor;

/**
  * \brief Enum for the Expansion format in different planes
  *        (Horizontal & Vertical)
  *
  */
typedef enum _PSP_VPBE_Expansionfactor
{
    /**< No expansion                                                        */
    PSP_VPBE_EXP_IDENTITY   = 1,
    /**< Square Pixel Expansion by 9/8(Horizontal Direction only)            */
    PSP_VPBE_EXP_NINE_BY_EIGHT,
    /**< Square Pixel Expansion by 6/5(Vertical Direction only)              */
    PSP_VPBE_EXP_SIX_BY_FIVE

} PSP_VPBEExpansionFactor;

/**
  * \brief Enum for the CLUT SOURCE
  *
  */
typedef enum _PSP_VPBE_CLUTSOURCE
{
    PSP_VPBE_CLUTSOURCE_ROM = 0,
    /**< CLUT source to be from ROM */
    PSP_VPBE_CLUTSOURCE_RAM
    /**< CLUT source to be from RAM */
}PSP_VPBE_CLUTSOURCE;

/**
  * \brief Enum for the Video Standard
  *
  */
typedef enum _PSP_VPBETimings
{
    PSP_VPBE_AUTO_MODE                          = 0,
    PSP_VPBE_DISPLAY_NTSC_INTERLACED_COMPOSITE  = 1,
    PSP_VPBE_DISPLAY_NTSC_INTERLACED_S_VIDEO    = 2,
    PSP_VPBE_DISPLAY_NTSC_INTERLACED_COMPONENT  = 3,
    PSP_VPBE_DISPLAY_NTSC_PROGRESSIVE_COMPONENT = 4,
    PSP_VPBE_DISPLAY_PAL_INTERLACED_COMPOSITE   = 5,
    PSP_VPBE_DISPLAY_PAL_INTERLACED_S_VIDEO     = 6,
    PSP_VPBE_DISPLAY_PAL_INTERLACED_COMPONENT   = 7,
    PSP_VPBE_DISPLAY_PAL_PROGRESSIVE_COMPONENT  = 8,
    PSP_VPBE_DISPLAY_YCC16_DIGITAL_480P         = 9
    /* Add others as and when necessary  */
    /* HDTV etc*/
} PSP_VPBETimings;

typedef enum _PSP_VPBERAMWRMode
{
    PSP_VPBE_RAMWR_NORMAL_MODE                  = 0,
    /**<RAM WR in NORMAL MODE                                       */
    PSP_VPBE_RAMWR_DVD_MODE                     = 1
    /**<RAM WR in DVD MODE                                          */
}PSP_VPBERAMWRMode;

/******************************************************************************
                                Data-Structures
******************************************************************************/

/**
 * Callback Function Prototype
 */
/**
  * /brief Prototype for callback function
  *
  */
typedef void (*PSP_VPBEAppCallback)(Ptr * cbkContext,Ptr param, Int status);

/**
  * \ brief structure for OSD Config Parameters object
  *
  */
typedef struct _PSP_VPBEOsdConfigParams
{
    /* Mode  */
    FVID_FieldFrame        ffMode;
    /**<field frame mode(Interlaced/Progressive)                    */
    FVID_bitsPerPixel      bitsPerPixel;
    /**< Bits per pixel in different planes                         */
    FVID_colorFormat       colorFormat;
    /**< Color format in different planes                           */
    Uint32                   pitch;
    /**< Pitch or offset for given plane(offset)                    */
    Uint32                    leftMargin;
    /**<  Left margin of the window                                 */
    Uint32                    topMargin;
    /**<  Top margin of the window                                  */
    Uint32                    width;
    /**<  Width of the window                                       */
    Uint32                    height;
    /**<  Height of the window                                      */
    Int                     segId;
    /** SegId passed from Application to allocate memory              */
    /* SCALING(ZOOM)/EXPANSION */
    PSP_VPBEScalingFactor   hScaling;
    /**<Scaling the plane in the horizontal direction                */
    PSP_VPBEScalingFactor   vScaling;
    /**<Scaling the plane in the vertical direction                  */
    PSP_VPBEExpansionFactor hExpansion;
    /**< Expanding the plane in the horizontal direction             */
    PSP_VPBEExpansionFactor vExpansion;
    /**< Expanding the plane in the vertical direction               */

    /* Application Callback */

    PSP_VPBEAppCallback     appCallback;
    /**< Handle for callback from osd plane operation                */

    /* Blending*/
    /**< blending factor to config for OSD plane(0-8)                */
    /** Blending is Applicable to OSD 0 and OSD 1 Plane Only         */
    PSP_VPBEBlendingFactor     blending;
    /* Transparency */
    Bool                       transparency;
    /**< Transparency Color for OSD-0 and OSD-1 plane only           */
    Uint32                     transparencyColor;
    /**< Transparency for OSD-0 and OSD-1 plane only                 */
    /* CLUT sources */
    PSP_VPBE_CLUTSOURCE       CLUTSource;
    /**< CLUTSORUCE for OSD-0 and OSD-1 plane only                   */

} PSP_VPBEOsdConfigParams;
/**
  * \ brief structure for CURSOR Config Parameters object
  *
  */
typedef struct _PSP_VPBECursorConfigParams
{
    Uint32                    leftMargin;
    /**<  Left margin of the window                                 */
    Uint32                    topMargin;
    /**<  Top margin of the window                                  */
    Uint32                    width;
    /**<  Width of the window                                       */
    Uint32                    height;
    /**<  Height of the window                                      */
    PSP_VPBE_CLUTSOURCE         CursorCLUTS;
    /**< CLUT source for Cursor                                     */
} PSP_VPBECursorConfigParams;

/**
  * \brief structure for VENC Config Parameters
  *
  */
typedef struct _PSP_VPBEVENCConfigParams
{
    PSP_VPBETimings         displayStandard;
    /**< Config the display Standard for Venc(Video Encoder)        */
    PSP_VPSS_ExtVideoEncoderFxns  extVidEncFxn;
    /**< External Video Encoder Interface
         THS8200 -video Encoder is currently supported for Digital Interface.
         To use external video encoder configure venc in digital YCC16 mode.
         480p is only supported
      */
} PSP_VPBEVencConfigParams;

typedef struct _PSP_VPBEValidateParams
{
    FVID_Frame   InParams;
    FVID_Frame   OutParams;

}PSP_VPBEValidateParams;

/**
 *  Channel Parameters
 */

/**
  * \brief structure for object for Channel Params
  *
  */
typedef struct _PSP_VPBEChannelParams {
    PSP_VPBE_Id             id;
    /**< VPBE plane id                                              */
    Ptr                     params;
    /**< Handle to access params (SurfaceParams)                    */
} PSP_VPBEChannelParams;


/**
  * \brief  Structure for Color Space Parameters object
  *
  */
typedef struct _PSP_VPBEColorSpaceParams
{
    Uint8         Y;
    /**< Luma Color Space                                           */
    Uint8         Cb;
    /**< Chroma Color Space-Blue                                    */
    Uint8         Cr;
    /**< Chroma Color Space-Red                                     */
} PSP_VPBEColorSpaceParams;

/**
  * \brief  Structure for CLUT Parameters object
  *
  */
typedef struct _PSP_VPBEMainClutParams
{
    PSP_VPBEColorSpaceParams   MainClut_val[PSP_VPBE_MAX_MAIN_CLUT_ENTRIES];
    /**< Main clut values                                                */
    PSP_VPBERAMWRMode          mode;
    /**< RAM WR Mode                                                    */
} PSP_VPBEMainClutParams;


/**
 * BMP CLUT Parameters
 */
typedef struct _PSP_VPBE_BMPClutParams
{
    Uint8                  BMPClut_val[PSP_VPBE_MAX_BMP_CLUT_ENTRIES];
    /**< BMP clut values                                                */
    PSP_VPBERAMWRMode      mode;
    /**< RAM WR Mode                                                    */
} PSP_VPBEBMPClutParams;

#ifdef __cplusplus
}
#endif

#endif /* _PSP_VPBE_H */
