/******************************************************************************
**+-------------------------------------------------------------------------+**
**|                            ****                                         |**
**|                            ****                                         |**
**|                            ******o***                                   |**
**|                      ********_///_****                                  |**
**|                      ***** /_//_/ ****                                  |**
**|                       ** ** (__/ ****                                   |**
**|                           *********                                     |**
**|                            ****                                         |**
**|                            ***                                          |**
**|                                                                         |**
**|         Copyright (c) 2006-2010 Texas Instruments Incorporated          |**
**|                        ALL RIGHTS RESERVED                              |**
**|                                                                         |**
**| Permission is hereby granted to licensees of Texas Instruments          |**
**| Incorporated (TI) products to use this computer program for the sole    |**
**| purpose of implementing a licensee product based on TI products.        |**
**| No other rights to reproduce, use, or disseminate this computer         |**
**| program, whether in part or in whole, are granted.                      |**
**|                                                                         |**
**| TI makes no representation or warranties with respect to the            |**
**| performance of this computer program, and specifically disclaims        |**
**| any responsibility for any damages, special or consequential,           |**
**| connected with the use of this program.                                 |**
**|                                                                         |**
**+-------------------------------------------------------------------------+**
******************************************************************************/

/**
 *  \file   dda_vpbe.c
 *
 *  \brief  vpss implementation
 *
 *  This file contains the implementation of the vpbe driver to utilize the
 *  serivces of the vpbe device driver.
 *
 *  (C) Copyright 2010, Texas Instruments, Inc
 *
 *  \note       Set tabstop to 4 (:se ts=4) while viewing this file in an
 *              editor
 *
 *  \author     Maulik Desai
 *
 *  \version    1.0     Created
 */
/******************************************************************************
                            Header File Inclusion
******************************************************************************/

#include <string.h>

#include <ti/sdo/pspdrivers/drivers/vpbe/psp_vpbe.h>
#include <ti/sdo/pspdrivers/drivers/vpbe/src/ddc_vpbe.h>
#include <ti/sdo/pspdrivers/drivers/vpbe/src/ddc_vpbeOsd.h>

/******************************************************************************
                                Functions
******************************************************************************/
/**
  * \brief      Create the given vpbe driver (instance)
  */
PSP_Result  PSP_VPBECreate(Uint32 instanceId)
{
    PSP_Result resultCR = PSP_SOK;
    DDC_VPBEDeviceObject * vpbeDeviceHandleCreate =
                            (DDC_VPBEDeviceObject * )DDC_VPBEGetDeviceHandle();

    /* Validate instance ID */
    if((NULL == vpbeDeviceHandleCreate)||(PSP_VPBE_NUM_INSTANCES <= instanceId))
    {
        resultCR = PSP_E_INVAL_PARAM;
    }

    /* Check state of driver */
    else if (VPSS_DELETED != vpbeDeviceHandleCreate->state)
    {
        resultCR = PSP_E_INVAL_PARAM;
    }

    else
    {
        /*Set the Interrrupt Number */
        DDC_VPBESetInterruptNumber();
        /* Store Register Base address to the VPBE structure */
        DDC_VPBERegisterOverlaying();
        /* Update the Device State */
        vpbeDeviceHandleCreate->state           = VPSS_CREATED;
        vpbeDeviceHandleCreate->venc.state      = DDC_VPBE_CLOSED;
        vpbeDeviceHandleCreate->osd[0].state    = DDC_VPBE_CLOSED;
    }
    return (resultCR);
}

/**
  * \brief      Delete a given vpss driver (instance)
  */
PSP_Result PSP_VPBEDelete(Uint32 instanceId)
{
    PSP_Result resultDL = PSP_E_INVAL_PARAM;

    DDC_VPBEDeviceObject * vpbeDeviceHandleDelete =
                        (DDC_VPBEDeviceObject * )DDC_VPBEGetDeviceHandle();

    /* Validate instance ID */
    if((NULL == vpbeDeviceHandleDelete)||(PSP_VPBE_NUM_INSTANCES <= instanceId))
    {
        resultDL = PSP_E_INVAL_PARAM;
    }
    /* Check state of driver */
    else if((VPSS_CREATED != vpbeDeviceHandleDelete->state) &&
            (VPSS_CLOSED != vpbeDeviceHandleDelete->state))
    {
        resultDL = PSP_E_INVAL_PARAM;
    }
    else
    {
        /* set state to deleted */
        vpbeDeviceHandleDelete->state = VPSS_DELETED;
        memset(vpbeDeviceHandleDelete,0,sizeof(DDC_VPBEDeviceObject));
        resultDL    =   PSP_SOK;
    }

    return (resultDL);
}

/**
  * \brief  It configures the VPBE Modules and return the Channel Handle
  */
PSP_Handle  PSP_VPBEOpen(Uint32 instanceId,PSP_VPBEChannelParams * chanParams)
{
    PSP_VPBE_Id chanId          = PSP_VPBE_INVALID_ID;
    PSP_Handle handleToReturn   = NULL;
    Ptr Params                  = NULL;
    /* Get the Device Handle */
    DDC_VPBEDeviceObject * vpbeDeviceHandleOpen =
                           (DDC_VPBEDeviceObject * )DDC_VPBEGetDeviceHandle();
    /* Check the parameter not NULL */
    if((NULL ==chanParams)||(PSP_VPBE_NUM_INSTANCES <= instanceId))
    {
            handleToReturn = NULL;
    }
    else
    {
        chanId = chanParams->id;
        Params = chanParams->params;
        /* Validate instance ID */
        if(((NULL == Params)||(NULL== vpbeDeviceHandleOpen))||((PSP_VPBE_VIDEO_0 > chanId) &&(PSP_VPBE_MAX_INTERFACES_SUPPORTED < chanId)))
        {
            handleToReturn = NULL;
        }
        /* Check state of driver */
        else if (((VPSS_CREATED != vpbeDeviceHandleOpen->state) &&
                 (VPSS_CLOSED   != vpbeDeviceHandleOpen->state))&&
                 (VPSS_OPENED   != vpbeDeviceHandleOpen->state))
        {
            handleToReturn = NULL;
        }
        else
        {
            /* Configures the Modules and returns Channel Handle */
            handleToReturn = (PSP_Handle)DDC_VPBEOpenHandle(chanId,Params);
            /*Check Channel Handle not NULL */
            if(NULL != handleToReturn)
            {
                /*Update the State as Opened if Handle not NULL */
                vpbeDeviceHandleOpen->state          = VPSS_OPENED;
                vpbeDeviceHandleOpen->vpbeInstanceId = instanceId;
            }
        }
    }

    return (handleToReturn);
}

/**
  * \brief  Close the VPBE channel with the specified handle
  */
PSP_Result PSP_VPBEClose(PSP_Handle handle)
{
    PSP_Result      resultCL = PSP_E_INVAL_PARAM;
    DDC_VPBEStatus  result   = DDC_VPBE_E_FAIL;
    DDC_VPBEDeviceObject* vpbeDeviceHandle =
                        (DDC_VPBEDeviceObject * )DDC_VPBEGetDeviceHandle();
    /*Check the Handle not NULL  */
    if((NULL == handle)||(NULL == vpbeDeviceHandle))
    {
        resultCL = PSP_E_INVAL_PARAM;
    }
    else
    {
        /* Closes the Channel and returns numofopenChannels still open */
        result = DDC_VPBECloseHandle(handle);
        if(DDC_VPBE_SOK == result)
        {
            /* Update the State as closed if all the channels of
               VPBE modules are closed */
              vpbeDeviceHandle->state = VPSS_CLOSED;
              resultCL  =   PSP_SOK;
        }
        else if(DDC_VPBE_E_RESOURCES == result)
        {
            resultCL = PSP_E_RESOURCES;
        }
        else
        {
            resultCL = PSP_E_INVAL_PARAM;
        }
    }

    return (resultCL);
}

PSP_Result PSP_VPBESubmitRequest(PSP_Handle             handle,
                                 Uint32                 cmd,
                                 Ptr                    cmdArg)
{
    FVID_Frame *dequeuedFrameBuffer = NULL;
    FVID_Frame *surfParamPtr        = NULL;
    PSP_Result resultSR    = PSP_E_INVAL_PARAM;
    DDC_VPBEStatus  result = DDC_VPBE_E_FAIL;

    if((NULL != handle)&& (NULL != cmdArg))
    {
        switch(cmd)
        {
            case FVID_DEQUEUE:
            {
                /*Dequeue the frame buffer */
                if(DDC_VPBE_SOK == DDC_VPBEDeQueueFrameBuffer(handle,
                                                              &dequeuedFrameBuffer))
                {
                    if(NULL != dequeuedFrameBuffer)
                    {
                        *(FVID_Frame **)cmdArg = dequeuedFrameBuffer;
                        resultSR = PSP_SOK;
                    }
                }
            }
            break;
            case FVID_QUEUE:
            {
                surfParamPtr = (FVID_Frame *)cmdArg;
                result  = DDC_VPBEQueueFrameBuffer(handle,surfParamPtr);
                /* Pass Channel Handle and framebuffer*/
                /* Queue the Frame Buffer */
                if(DDC_VPBE_SOK == result)
                {
                   resultSR = PSP_SOK;
                }
                else if(DDC_VPBE_E_RESOURCES == result)
                {
                    resultSR = PSP_E_RESOURCES;
                }
                else
                {
                    resultSR = PSP_E_INVAL_PARAM;
                }
            }
            break;
            default :
            {
                    resultSR    = PSP_E_INVAL_PARAM;
            }
            break;
        }
    }
   return resultSR;
}

/**
  * \brief      I/O Control of the vpss device
  */
 /*ARGSUSED */
PSP_Result  PSP_VPBEIoctl(  PSP_Handle              handle,
                            PSP_VPBEIoctlCommand    cmd,
                            Ptr                     cmdArg,
                            Ptr                     params)
{
    PSP_Result resultIOTL           = PSP_E_INVAL_PARAM;
    DDC_VPBEStatus  result          = DDC_VPBE_E_FAIL;
    FVID_Frame *allocFramebuffer    = NULL;

    /*Check the Handle not NULL and Channel not Closed */
    if(((NULL == handle))||
       (DDC_VPBE_SOK == DDC_VPBEIsChannelHandleClosed(handle)))
    {
        resultIOTL = PSP_E_INVAL_PARAM;
    }
    else
    {
        switch (cmd)
        {
            case PSP_VPBE_IOCTL_OSD_BOUNDARY:
            {
                /*Configure the Window Boundary Parameters */
                if(DDC_VPBE_SOK == DDC_VPBEConfigWindowBoundary(handle,cmdArg))
                {
                    resultIOTL = PSP_SOK;
                }
            }
            break;
            case PSP_VPBE_IOCTL_OSD_BLENDING:
            {
                /*Configure the BlendingFactor  */
                if(DDC_VPBE_SOK == DDC_VPBEConfigBlending(handle,cmdArg))
                {
                    resultIOTL = PSP_SOK;
                }
            }
            break;
            case PSP_VPBE_IOCTL_OSD_TRANSPARENCY:
            {
                /* Configure the Transparency color and transparency enable/disable */
                if(DDC_VPBE_SOK == DDC_VPBEConfigTransparency(handle,cmdArg))
                {
                    resultIOTL = PSP_SOK;
                }
            }
            break;
            case PSP_VPBE_IOCTL_OSD_ZOOM:
            {
                /*Configure the Zooming of OSD Planes */
                if(DDC_VPBE_SOK == DDC_VPBEConfigZoomParameters(handle,cmdArg))
                {
                    resultIOTL = PSP_SOK;
                }
            }
            break;
            case PSP_VPBE_IOCTL_OSD_PROGRAM_MAIN_CLUT:
            {
                /*Configure the Main CLUT */
                if(DDC_VPBE_SOK == DDC_VPBEConfigMainCLUT(handle,cmdArg))
                {
                    resultIOTL = PSP_SOK;
                }
            }
            break;
            case PSP_VPBE_IOCTL_OSD_PROGRAM_BMP_CLUT:
            {
                /*Configure the BMP CLUT */
                if(DDC_VPBE_SOK == DDC_VPBEConfigBMPCLUT(handle,cmdArg))
                {
                    resultIOTL = PSP_SOK;
                }
            }
            break;
            case PSP_VPBE_IOCTL_OSD_VALIDATE_BUFFER:
            {
                /* Validate the Frame Buffer */
                if(DDC_VPBE_SOK ==DDC_VPBEValidateFrameBuffer(cmdArg))
                {
                    resultIOTL = PSP_SOK;
                }
            }
            break;
            case PSP_VPBE_IOCTL_START_VIDEO_0:
            case PSP_VPBE_IOCTL_START_VIDEO_1:
            case PSP_VPBE_IOCTL_START_OSD_0:
            case PSP_VPBE_IOCTL_START_OSD_1:
            case PSP_VPBE_IOCTL_START_VENC:
            case PSP_VPBE_IOCTL_START_CURSOR:
            {
                if(DDC_VPBE_SOK == DDC_VPBEStartEngine(handle))
                {
                    resultIOTL = PSP_SOK;
                }
            }
            break;

            case PSP_VPBE_IOCTL_STOP_VIDEO_0:
            case PSP_VPBE_IOCTL_STOP_VIDEO_1:
            case PSP_VPBE_IOCTL_STOP_OSD_0:
            case PSP_VPBE_IOCTL_STOP_OSD_1:
            case PSP_VPBE_IOCTL_STOP_VENC:
            case PSP_VPBE_IOCTL_STOP_CURSOR:
            {
                if(DDC_VPBE_SOK == DDC_VPBEStopEngine(handle))
                {
                    resultIOTL = PSP_SOK;
                }
            }
            break;
            case FVID_ALLOC_BUFFER :
            {
                result = DDC_VPBEAllocFrameBuffer(handle,&allocFramebuffer);
                if(DDC_VPBE_SOK == result)
                {
                    *(FVID_Frame **)cmdArg = allocFramebuffer;
                    resultIOTL = PSP_SOK;
                }
                else if(DDC_VPBE_NO_MEMORY == result)
                {
                    resultIOTL = PSP_E_NO_MEMORY;
                }
                else
                {
                    resultIOTL = PSP_E_INVAL_PARAM;
                }

            }
            break;
            case FVID_FREE_BUFFER :
            {
                if(DDC_VPBE_SOK == DDC_VPBEFreeFrameBuffer(handle,
                                                           (FVID_Frame **)cmdArg))
                {
                    resultIOTL = PSP_SOK;
                }
            }
            break;
            default:
            {
                /*THS8200 external video decoder is supported in current driver */
                if(DDC_VPBE_SOK!= DDC_ConfigextVIDENCParams(handle,cmd,cmdArg))
                {
                    resultIOTL = PSP_E_INVAL_PARAM;
                }
                else
                {
                    resultIOTL = PSP_SOK;
                }
            }
            break;
        }
    }
    return (resultIOTL);
}
