/******************************************************************************
**+-------------------------------------------------------------------------+**
**|                            ****                                         |**
**|                            ****                                         |**
**|                            ******o***                                   |**
**|                      ********_///_****                                  |**
**|                      ***** /_//_/ ****                                  |**
**|                       ** ** (__/ ****                                   |**
**|                           *********                                     |**
**|                            ****                                         |**
**|                            ***                                          |**
**|                                                                         |**
**|         Copyright (c) 2006-2010 Texas Instruments Incorporated          |**
**|                        ALL RIGHTS RESERVED                              |**
**|                                                                         |**
**| Permission is hereby granted to licensees of Texas Instruments          |**
**| Incorporated (TI) products to use this computer program for the sole    |**
**| purpose of implementing a licensee product based on TI products.        |**
**| No other rights to reproduce, use, or disseminate this computer         |**
**| program, whether in part or in whole, are granted.                      |**
**|                                                                         |**
**| TI makes no representation or warranties with respect to the            |**
**| performance of this computer program, and specifically disclaims        |**
**| any responsibility for any damages, special or consequential,           |**
**| connected with the use of this program.                                 |**
**|                                                                         |**
**+-------------------------------------------------------------------------+**
******************************************************************************/

/**
 *  \file   dda_vpbeBios.c
 *
 *  \brief  VPBE Driver Adaptation for BIOS
 *
 *  This file contains adaptation of VPBE driver for BIOS
 *
 *  (C) Copyright 2010, Texas Instruments, Inc
 *
 *  \note       Set tabstop to 4 (:se ts=4) while viewing this file in an
 *              editor
 *
 *  \author     Maulik Desai
 *
 *  \version    0.1     Created
 */

/******************************************************************************
                            Header File Inclusion
******************************************************************************/
#include <std.h>

#include <C64.h>
#include <ecm.h>
#include <ti/sdo/pspdrivers/pal_os/pal_osprotect.h>

#include <ti/sdo/pspdrivers/drivers/vpbe/psp_vpbe.h>
#include <ti/sdo/pspdrivers/drivers/vpbe/src/dda_vpbeBios.h>
#include <ti/sdo/pspdrivers/drivers/vpbe/src/ddc_vpbe.h>
#include <ti/sdo/pspdrivers/soc/dm6437/dsp/soc.h>

/******************************************************************************
                                    Macros
******************************************************************************/

/** Hardware venc interrupt number  */
#define HWI_VENC_INTR_NUM       (HWI_EVT02_CMB_IRQ)

/******************************************************************************
                                Functions
******************************************************************************/
/**
  * \brief Register Back end interrrupt with BIOS and enable it
  *
  */
void _DDA_VPBERegisterIntrHandler(Uint32 instNum ,Uint32 IntNum)
{
    ECM_Attrs ecmattrs = ECM_ATTRS;
    Uns cookie = 0;

    /* Disable Interrupts at start of Critical Section */
    PAL_osProtectEntry(PAL_OSPROTECT_INTERRUPT, &cookie);

    /* Depending upon the device id of the VPSS */
    switch(instNum)
    {
        case PSP_VPBE_0_INSTANCE_ID:
        {
            /* Mapping the eventid to the ECM Dispatch of the DSP/BIOS*/
            ecmattrs.unmask = (int)1;
            ECM_dispatchPlug(IntNum, (ECM_Fxn)&DDC_VPBEIsr, &ecmattrs);
            /* Enabling the event */
            ECM_enableEvent(IntNum);
        }
        break;
        default:
        {

        }
        break;
    }

    /* Enabling the HWI_ID */
    C64_enableIER(HWI_VENC_INTR_NUM);

    /* Enabling the interrupts */
    PAL_osProtectExit(PAL_OSPROTECT_INTERRUPT, cookie);
}

/**
  * \brief Un-Register ISR Routine with BIOS and disable Back End
  *        Interrupt
  */
/* ARGSUSED */
void _DDA_VPBEUnregisterIntrHandler(Uint32 instNum, Uint32 intrNum)
{
    /* Disabling interrupt */
    ECM_disableEvent(intrNum);
}
