/******************************************************************************
**+-------------------------------------------------------------------------+**
**|                            ****                                         |**
**|                            ****                                         |**
**|                            ******o***                                   |**
**|                      ********_///_****                                  |**
**|                      ***** /_//_/ ****                                  |**
**|                       ** ** (__/ ****                                   |**
**|                           *********                                     |**
**|                            ****                                         |**
**|                            ***                                          |**
**|                                                                         |**
**|         Copyright (c) 2006-2010 Texas Instruments Incorporated          |**
**|                        ALL RIGHTS RESERVED                              |**
**|                                                                         |**
**| Permission is hereby granted to licensees of Texas Instruments          |**
**| Incorporated (TI) products to use this computer program for the sole    |**
**| purpose of implementing a licensee product based on TI products.        |**
**| No other rights to reproduce, use, or disseminate this computer         |**
**| program, whether in part or in whole, are granted.                      |**
**|                                                                         |**
**| TI makes no representation or warranties with respect to the            |**
**| performance of this computer program, and specifically disclaims        |**
**| any responsibility for any damages, special or consequential,           |**
**| connected with the use of this program.                                 |**
**|                                                                         |**
**+-------------------------------------------------------------------------+**
******************************************************************************/

/**
 *  \file   ddc_vpbe.c
 *
 *  \brief  DDC layer Implementation
 *
 *  This file contains the implementation of the vpbe driver to utilize the
 *  serivces of the vpbe device driver.
 *
 *  (C) Copyright 2010, Texas Instruments, Inc
 *
 *  \author     Maulik Desai
 *
 *  \version    1.0     Created
 */

/******************************************************************************
                            Header File Inclusion
******************************************************************************/
#include <ti/sdo/pspdrivers/soc/dm6437/dsp/tistdtypes.h>
#include <ti/sdo/pspdrivers/common/psp_common.h>
#include <ti/sdo/pspdrivers/pal_os/pal_osSem.h>
#include <ti/sdo/pspdrivers/pal_os/pal_osmem.h>
#include <ti/sdo/pspdrivers/pal_os/pal_osProtect.h>
#include <std.h>
#include <math.h>

#include <ti/sdo/pspdrivers/drivers/vpbe/psp_vpbe.h>
#include <ti/sdo/pspdrivers/drivers/vpbe/src/ddc_vpbe.h>
#include <ti/sdo/pspdrivers/drivers/vpbe/src/ddc_vpbeOsd.h>
#include <ti/sdo/pspdrivers/drivers/vpbe/src/ddc_vpbeVenc.h>
#include <ti/sdo/pspdrivers/drivers/vpbe/src/ddc_vpbeCursor.h>
#include <ti/sdo/pspdrivers/drivers/vpbe/src/llc_vpbeOsd.h>
#include <ti/sdo/pspdrivers/drivers/vpbe/src/llc_vpbeCursor.h>
#include <ti/sdo/pspdrivers/drivers/vpbe/src/llc_vpbeVenc.h>
#include <ti/sdo/pspdrivers/soc/dm6437/dsp/soc.h>

#ifdef VPBE_INSTRUMENTATION_ENABLED
    #include <ti/sdo/pspdrivers/pal_os/bios/psp_log.h>
#endif /*VPBE_INSTRUMENTATION_ENABLED */

/**
  * \brief VPBE device object handle
  */
static DDC_VPBEDeviceObject   vpbeDeviceObject;

 /**
   * \brief VPBE Time Stamp Function
   */
extern void _DDA_VPBEGetTimeStamp(Ptr timeStamp);

extern void _DDA_VPBERegisterIntrHandler(Uint32 instNum ,Uint32 IntNum);
extern void _DDA_VPBEUnregisterIntrHandler(Uint32 instNum, Uint32 intrNum);

/******************************************************************************
                            INTERFACE FUNCTIONS
                This Functions are called from the DDA Layer
******************************************************************************/

/**
  * \brief      This function validate the parameters configure the hardware
  *             and return the VPBE Channel (VIDEO/OSD/VENC) Handle.
  */
Ptr DDC_VPBEOpenHandle(PSP_VPBE_Id id, Ptr params)
{
    DDC_VPBEDeviceObject * handleDeviceOH   = NULL;
    DDC_VPBEOsdObject    * handleOsdOH      = NULL;
    DDC_VPBECursorObject * handleCursorOH   = NULL;
    DDC_VPBEVencObject   * handleVencOH     = NULL;
    Ptr handleToReturnOH                    = NULL;
    PAL_OsSemAttrs semAttrs = PAL_OSSEM_ATTRS;

    semAttrs.type = PAL_OSSEM_TYPE_FIFO;

    /*Get the Device Handle */
    handleDeviceOH      = (DDC_VPBEDeviceObject* )DDC_VPBEGetDeviceHandle();
    /*Get Channel handle Id */
    handleToReturnOH    = DDC_VPBEGetChannelHandle(id);
    /* Check the Channel Handle and params not NULL */
    if(((NULL != params) && (handleToReturnOH != NULL))&&(handleDeviceOH!=NULL))
    {
        switch(id)
        {
            case PSP_VPBE_VIDEO_0:
            case PSP_VPBE_VIDEO_1:
            case PSP_VPBE_OSD_0:
            case PSP_VPBE_OSD_1:
            {
                handleOsdOH = (DDC_VPBEOsdObject* )handleToReturnOH;
                /*Check the OSD channel handle and its state */
                if((DDC_VPBE_OPENED == handleOsdOH->state)||(handleOsdOH == NULL))
                {
                    handleToReturnOH = NULL;
                }
                else
                {   /* check OSD-0 and OSD-1 Id */
                    if((PSP_VPBE_OSD_0 == id) ||(PSP_VPBE_OSD_1 == id))
                    {
                        /* Check VIDEO-0 Plane active */
                        if(TRUE == DDC_VPBEIsOsdPlaneActive(PSP_VPBE_VIDEO_0))
                        {
                            /*Configure the OSD-0 and OSD-1 Planes */
                            if(((DDC_VPBE_SOK == DDC_VPBEConfigOsdParams(handleOsdOH ,params))
                             &&(DDC_VPBE_SOK == DDC_VPBEConfigBlending(handleOsdOH ,params)))
                             &&((DDC_VPBE_SOK == DDC_VPBEConfigZoomParameters(handleOsdOH ,params))
                             &&(DDC_VPBE_SOK == DDC_VPBEConfigTransparency(handleOsdOH ,params))))
                            {
                                    if (PAL_osSemCreate("VPBEDequeueSEM", 0, &semAttrs,&handleOsdOH->vpbedequeueSem ) != PAL_SOK)
                                    {
                                        handleToReturnOH = NULL;
                                     }
                                    else
                                    {

                                        handleOsdOH->OsdChanId          = id;
                                        /*Check State as opened */
                                        handleOsdOH->state              = DDC_VPBE_OPENED;
                                        handleOsdOH->vpssDeviceHandle   = handleDeviceOH;
                                    }
                            }
                            else
                            {
                                handleToReturnOH = NULL;
                            }
                        }
                        else
                        {
                             handleToReturnOH = NULL;
                        }
                    }
                    else
                    {
                        /* Configure the VIDEO-0 and VIDEO-1 Plane */
                        if((DDC_VPBE_SOK == DDC_VPBEConfigOsdParams(handleOsdOH ,params))
                         &&(DDC_VPBE_SOK == DDC_VPBEConfigZoomParameters(handleOsdOH ,params)))
                        {
                            if (PAL_osSemCreate("VPBEDequeueSEM", 0, &semAttrs,&handleOsdOH->vpbedequeueSem ) != PAL_SOK)
                            {
                                        handleToReturnOH = NULL;
                            }
                            else
                            {

                                handleOsdOH->OsdChanId          = id;
                                handleOsdOH->state              = DDC_VPBE_OPENED;
                                handleOsdOH->vpssDeviceHandle   = handleDeviceOH;
                            }
                        }
                        else
                        {
                            handleToReturnOH = NULL;
                        }
                    }
                }

            }
            break;
            case PSP_VPBE_VENC:
            {
                handleVencOH = (DDC_VPBEVencObject* )handleToReturnOH;
                /* Check state of VENC */
                if((DDC_VPBE_OPENED == handleVencOH->state) ||
                   (handleVencOH == NULL))
                {
                    handleToReturnOH = NULL;
                }
                else
                {
                    /*Configure the VENC */
                    if(DDC_VPBE_SOK == DDC_VPBEConfigVencParams(handleVencOH,
                                                                   params))
                    {
                        handleVencOH->VencChanId        = id;
                        /*Update the State */
                        handleVencOH->state             = DDC_VPBE_OPENED;
                        handleVencOH->vpssDeviceHandle  = handleDeviceOH;
                    }
                    else
                    {
                        handleToReturnOH = NULL;
                    }
                }
            }
            break;
            case PSP_VPBE_CURSOR:
            {
                handleCursorOH = (DDC_VPBECursorObject* )handleToReturnOH;
                /*Check the Cursor state */
                if(DDC_VPBE_OPENED == handleOsdOH->state)
                {
                    handleToReturnOH = NULL;
                }
                /*Check all the OSD Planes are Active */
                else if(((FALSE == DDC_VPBEIsOsdPlaneActive(PSP_VPBE_VIDEO_0))
                    &&  (FALSE  == DDC_VPBEIsOsdPlaneActive(PSP_VPBE_VIDEO_1)))
                    &&  ((FALSE == DDC_VPBEIsOsdPlaneActive(PSP_VPBE_OSD_0))
                    &&  (FALSE  == DDC_VPBEIsOsdPlaneActive(PSP_VPBE_OSD_1))))
                {
                    handleToReturnOH = NULL;
                }
                else
                {
                    /*Configure the Cursor params */
                    if(DDC_VPBE_SOK == DDC_VPBEConfigCursorParams(handleCursorOH,
                                                                     params))
                    {
                        handleCursorOH->CursorChanId     = id;
                        /*Update the State as opened */
                        handleCursorOH->state            = DDC_VPBE_OPENED;
                        handleCursorOH->vpssDeviceHandle = handleDeviceOH;
                    }
                    else
                    {
                        handleToReturnOH = NULL;
                    }
                }
            }
            break;
            default:
            {
                handleToReturnOH = NULL;
            }
            break;
        }
    }

    return(handleToReturnOH);
}

/**
  * \brief      This function close the VPBE Channel(VIDEO/OSD/VENC) handle
  *
  */
DDC_VPBEStatus DDC_VPBECloseHandle(Ptr handle)
{
    PSP_VPBE_Id idCH                        = PSP_VPBE_INVALID_ID;
    DDC_VPBEStatus resultCH                 = DDC_VPBE_INVALID_PARAM;
    DDC_VPBEDeviceObject * handleDeviceCH   = NULL;
    DDC_VPBEOsdObject    * handleOsdCH      = NULL;
    DDC_VPBEVencObject   * handleVencCH     = NULL;
    DDC_VPBECursorObject * handleCursorCH   = NULL;
    /*Get the Device Handle */
    handleDeviceCH = (DDC_VPBEDeviceObject* )DDC_VPBEGetDeviceHandle();

    if((handle != NULL)&&(handleDeviceCH!=NULL))
    {
        /*Get the Channel Id */
        idCH = DDC_VPBEGetChannelId(handle);

        switch(idCH)
        {
            case PSP_VPBE_VIDEO_0:
            case PSP_VPBE_VIDEO_1:
            case PSP_VPBE_OSD_0:
            case PSP_VPBE_OSD_1:
            {
                handleOsdCH             = (DDC_VPBEOsdObject *)handle;
                /*Check the state of OSD plane */
                if((handleOsdCH->state  != DDC_VPBE_CLOSED) ||
                   (handleOsdCH != NULL))
                {
                    resultCH = DDC_VPBE_SOK;
                    LLC_setOsdDisplayOff(idCH,handleOsdCH->OsdRegs);
                    /*Check OSD1 Window is in Attribute mode */
                    if(FVID_ATTRIBUTE == handleOsdCH->OsdParams.colorFormat)
                    {
                        LLC_setOSDWin1AttrModeDisable(handleOsdCH->OsdRegs);
                    }
                    /*Reset the Framebuffer */
                    DDC_VPBEResetFrameBufferObject(&(handleOsdCH->fb));
                    /*Set the SDRAM Address to zero */
                    LLC_setOsdFBStartAddress(idCH,handleOsdCH->OsdRegs,0x00000000);

                    /* Delete the Semaphore */
                    if( NULL!= handleOsdCH->vpbedequeueSem)
                    {
                        if (PAL_osSemDelete(handleOsdCH->vpbedequeueSem)!= PAL_SOK) {
                            resultCH = (DDC_VPBE_E_RESOURCES);
                        }
                    }
                    /* Closed the OSD plane Channel */
                    handleOsdCH->PlaneActive = FALSE;
                    handleOsdCH->state       = DDC_VPBE_CLOSED;
                }
            }
            break;
            case PSP_VPBE_VENC:
            {
                handleVencCH            = (DDC_VPBEVencObject *)handle;
                /*Check the State not Closed */
                if(handleVencCH->state != DDC_VPBE_CLOSED)
                {
                    handleVencCH->state = DDC_VPBE_CLOSED;
                    /*Turn off the VENC */
                    LLC_setVencDisable(handleVencCH->VencRegs);
                    /*Unregister the VENC Interrupt */
                    _DDA_VPBEUnregisterIntrHandler( handleDeviceCH->vpbeInstanceId,
                                                    handleDeviceCH->IntNum);
                    resultCH = DDC_VPBE_SOK;
                }
            }
            break;
            case PSP_VPBE_CURSOR:
            {
                handleCursorCH          = (DDC_VPBECursorObject *)handle;
                /*Check the State of Cursor */
                if(handleCursorCH->state != DDC_VPBE_CLOSED)
                {
                    LLC_setCursorDisable(handleCursorCH->CursorRegs);
                    handleCursorCH->state   = DDC_VPBE_CLOSED;
                    resultCH = DDC_VPBE_SOK;
                }
            }
            break;
            default:
            {
                resultCH = DDC_VPBE_E_FAIL;
            }
            break;
        }
    }
    return  resultCH;
}

/**
  * \brief      Check whether VPBE Channel Handle is closed
  *
  */
DDC_VPBEStatus DDC_VPBEIsChannelHandleClosed(Ptr handleICH)
{
    PSP_VPBE_Id idICH                       = PSP_VPBE_INVALID_ID;
    DDC_VPBEStatus resultICH                = DDC_VPBE_INVALID_PARAM;
    DDC_VPBEOsdObject    * handleOsdICH     = NULL;
    DDC_VPBEVencObject   * handleVencICH    = NULL;
    DDC_VPBECursorObject * handleCursorICH  = NULL;
    /*Check the Handle parameter not null */
    if(handleICH != NULL)
    {
        /* Check the Channel Id */
        idICH = DDC_VPBEGetChannelId(handleICH);

        switch(idICH)
        {
            case PSP_VPBE_VIDEO_0:
            case PSP_VPBE_VIDEO_1:
            case PSP_VPBE_OSD_0:
            case PSP_VPBE_OSD_1:
            {
                handleOsdICH            = (DDC_VPBEOsdObject *)handleICH;
                /*Check the OSD plane channel state is closed or not */
                if(handleOsdICH->state == DDC_VPBE_CLOSED)
                {
                    resultICH = DDC_VPBE_SOK;
                }
            }
            break;
            case PSP_VPBE_VENC:
            {
                handleVencICH           = (DDC_VPBEVencObject *)handleICH;
                /*Check the VENC channel state is closed or not */
                if(handleVencICH->state == DDC_VPBE_CLOSED)
                {
                    resultICH = DDC_VPBE_SOK;
                }
            }
            break;
            case PSP_VPBE_CURSOR:
            {
                handleCursorICH         = (DDC_VPBECursorObject *)handleICH;
                /*Check the Cursor channel state is closed or not */
                if(handleCursorICH->state == DDC_VPBE_CLOSED)
                {
                    resultICH = DDC_VPBE_SOK;
                }
            }
            break;
            default:
            {
                    resultICH = DDC_VPBE_INVALID_PARAM;
            }
            break;
        }
    }
    return(resultICH);
}

/**
  * \brief  Get VPBE device handle
  */
Ptr DDC_VPBEGetDeviceHandle(void)
{
    /*Return the Device Object */
    return(&vpbeDeviceObject);
}

/**
  * \brief      It will add the frame buffer to the Queue. It is valid for both
  *             plane of Video and OSD
  */
DDC_VPBEStatus DDC_VPBEQueueFrameBuffer(Ptr                     handleQF,
                                        FVID_Frame * fbPtrQF)
{
    PSP_VPBE_Id idQF                        = PSP_VPBE_INVALID_ID;
    DDC_VPBEStatus resultQF                 = DDC_VPBE_E_FAIL;
    DDC_VPBEOsdObject   * vpbeOsdHandleQF   = NULL;
    DDC_VPBEDeviceObject * vpbeDeviceHandleCVMP = NULL;
    Uint32 pitchOPS= 0;
    if((NULL==handleQF)||(NULL==fbPtrQF))
    {
        resultQF = DDC_VPBE_INVALID_PARAM;
    }
    else
    {
        /*Get the Venc Channel Handle */
        vpbeDeviceHandleCVMP = (DDC_VPBEDeviceObject * )DDC_VPBEGetDeviceHandle();
        /*Get the Channel Id  */
        idQF = DDC_VPBEGetChannelId(handleQF);
        switch(idQF)
        {
            case PSP_VPBE_VIDEO_0:
            case PSP_VPBE_VIDEO_1:
            case PSP_VPBE_OSD_0:
            case PSP_VPBE_OSD_1:
            {
                vpbeOsdHandleQF = (DDC_VPBEOsdObject *)handleQF;
                /*TURN ON the OSD planes at the time of first Queue */
                /*Check whether OSD1 Attribute Mode is Active */
                if(((FVID_ATTRIBUTE == vpbeOsdHandleQF->OsdParams.colorFormat)
                                            &&(FALSE == vpbeOsdHandleQF->PlaneActive))
                                            &&(idQF == PSP_VPBE_OSD_1))
                {
                    /* Set Attribute Mode */
                    LLC_setOSDWin1AttrModeEnable(vpbeOsdHandleQF->OsdRegs);
                }
                /*Check whether the Plane is ACTIVE */
                /* Validate the Frame Buffer */
                if(DDC_VPBE_SOK == DDC_VPBECheckFrameBuffer(vpbeOsdHandleQF,fbPtrQF))
                {
                    /*Add validated Frame Buffer in Active Queue  */
                    resultQF = DDC_VPBEAddQueue(DDC_VPBE_ACTIVE_QUEUE,
                                                vpbeOsdHandleQF,fbPtrQF);
                    /*If OSD plane is not active turn it active at first add queue */
                    if((FALSE == vpbeOsdHandleQF->PlaneActive) && (resultQF == DDC_VPBE_SOK))
                    {

#ifdef VPBE_INSTRUMENTATION_ENABLED
                        PSP_LOG_EVENT(  &DVTEvent_Log,
                                        "VPBE",
                                        PSP_DVT_DESC(
                                        PSP_DVT_eDATA_SND_START,
                                        PSP_DVT_dCHANNEL_ID_INST,
                                        PSP_DVT_dPACKET_ID,
                                        PSP_DVT_dNONE),
                                        CHANNELID_INSTANCEID(
                                        1,
                                        0),
                                        fbPtrQF);
#endif /* VPBE_INSTRUMENTATION_ENABLED */

                        pitchOPS = fbPtrQF->pitch/32u;
                        LLC_setOsdOffset(idQF,vpbeOsdHandleQF->OsdRegs,pitchOPS);
                        LLC_setOsdFBStartAddress(idQF,vpbeOsdHandleQF->OsdRegs,fbPtrQF->frame.frameBufferPtr);
                        /* TURN Display ON */
                        LLC_setOsdDisplayOn(idQF,vpbeOsdHandleQF->OsdRegs);
                        /* Register Interrupt Handler */
                        if(NULL != vpbeDeviceHandleCVMP)
                        {
                            _DDA_VPBERegisterIntrHandler(0,vpbeDeviceHandleCVMP->IntNum);
                        }
                        vpbeOsdHandleQF->PlaneActive = TRUE;
                        resultQF = DDC_VPBE_SOK;
                    }
                }
                else
                {
                    resultQF = DDC_VPBE_INVALID_PARAM;
                }

            }
            break;
            default:
            {
                resultQF = DDC_VPBE_E_FAIL;
            }
            break;
        }
    }/* else */

    return(resultQF);
}

/**
  * \brief      It will De-Queue the frame buffer from the Queue. It is valid
  *             for both plane of Video and OSD.
  */
DDC_VPBEStatus DDC_VPBEDeQueueFrameBuffer(Ptr              handleDQ,
                                          FVID_Frame ** deQueuedFrameBufferDQ)
{
    PSP_VPBE_Id             idDQ                = PSP_VPBE_INVALID_ID;
    DDC_VPBEStatus          resultDQ            = DDC_VPBE_E_FAIL;
    FVID_Frame * fbAddrDQ            = NULL;
    DDC_VPBEOsdObject     * vpbeOsdHandleDQ     = NULL;
    if(NULL == handleDQ)
    {
        resultDQ = DDC_VPBE_INVALID_PARAM;
    }
    else
    {
        /*Get the Channel Id */
        idDQ = DDC_VPBEGetChannelId(handleDQ);
        switch(idDQ)
        {
            case PSP_VPBE_VIDEO_0:
            case PSP_VPBE_VIDEO_1:
            case PSP_VPBE_OSD_0:
            case PSP_VPBE_OSD_1:
            {
                vpbeOsdHandleDQ = (DDC_VPBEOsdObject *)handleDQ;
                if(NULL != vpbeOsdHandleDQ)
                {
                    /* Delete the Frame Buffer from the Free queue */
                    if(DDC_VPBE_SOK == DDC_VPBEDelQueue(DDC_VPBE_FREE_QUEUE,
                                                        vpbeOsdHandleDQ,
                                                        &fbAddrDQ))
                    {
                        if(NULL!=fbAddrDQ)
                        {
                            *deQueuedFrameBufferDQ  = fbAddrDQ;
                            resultDQ                = DDC_VPBE_SOK;
                        }
                    }
                }
            }
            break;
            default:
            {
                    resultDQ                = DDC_VPBE_E_FAIL;
            }
            break;
        }
    }
    return(resultDQ);
}

/**
  * \brief      It will Perform register overlaying
  */
void DDC_VPBERegisterOverlaying(void)
{
    DDC_VPBECursorObject* vpbeCursorHandlePR    = NULL;
    DDC_VPBEOsdObject   * vpbeOsdHandlePR       = NULL;
    DDC_VPBEVencObject  * vpbeVencHandlePR      = NULL;
    /*Get the OSD -0 Plane Channel Handle */
    vpbeOsdHandlePR = (DDC_VPBEOsdObject* )DDC_VPBEGetChannelHandle(PSP_VPBE_OSD_0);
    if(NULL != vpbeOsdHandlePR)
    {   /*assign the OSD Reg base address */
        vpbeOsdHandlePR->OsdRegs = (DDC_VPBEOsdObject* )(CSL_VPSS_OSD_0_REGS);
    }
    /*Get the OSD -1 Plane Channel Handle */
    vpbeOsdHandlePR = (DDC_VPBEOsdObject* )DDC_VPBEGetChannelHandle(PSP_VPBE_OSD_1);
    if(NULL != vpbeOsdHandlePR)
    {   /*assign the OSD Reg base address */
        vpbeOsdHandlePR->OsdRegs = (DDC_VPBEOsdObject* )(CSL_VPSS_OSD_0_REGS);
    }
    /*Get the VIDEO -0 Plane Channel Handle */
    vpbeOsdHandlePR = (DDC_VPBEOsdObject* )DDC_VPBEGetChannelHandle(PSP_VPBE_VIDEO_0);
    if(NULL != vpbeOsdHandlePR)
    {   /*assign the OSD Reg base address */
        vpbeOsdHandlePR->OsdRegs = (DDC_VPBEOsdObject* )(CSL_VPSS_OSD_0_REGS);
    }
    /*Get the VIDEO -1 Plane Channel Handle */
    vpbeOsdHandlePR = (DDC_VPBEOsdObject* )DDC_VPBEGetChannelHandle(PSP_VPBE_VIDEO_1);
    if(NULL != vpbeOsdHandlePR)
    {   /*assign the OSD Reg base address */
        vpbeOsdHandlePR->OsdRegs = (DDC_VPBEOsdObject* )(CSL_VPSS_OSD_0_REGS);
    }
    /*Get the VENC Channel Handle */
    vpbeVencHandlePR = (DDC_VPBEVencObject* )DDC_VPBEGetChannelHandle(PSP_VPBE_VENC);
    if(NULL != vpbeVencHandlePR)
    {   /*assign the OSD Reg base address */
        vpbeVencHandlePR->VencRegs = (DDC_VPBEVencObject* )(CSL_VPSS_VENC_0_REGS);
    }
    /*Get the CURSOR Channel Handle */
    vpbeCursorHandlePR = (DDC_VPBECursorObject* )DDC_VPBEGetChannelHandle(PSP_VPBE_CURSOR);
    if(NULL != vpbeCursorHandlePR)
    {   /*assign the OSD Reg base address */
        vpbeCursorHandlePR->CursorRegs = (DDC_VPBECursorObject* )(CSL_VPSS_OSD_0_REGS);
    }
    if(vpbeOsdHandlePR!=NULL)
    {
        LLC_ResetOsdReg(vpbeOsdHandlePR->OsdRegs);
    }
    if(vpbeVencHandlePR!=NULL)
    {
        LLC_ResetVencReg(vpbeVencHandlePR->VencRegs);
    }

}
/**
  * \brief      Set device ISR number
  */
void DDC_VPBESetInterruptNumber()
{
    DDC_VPBEDeviceObject * vpbeDeviceHandleSIN = NULL;
    /* Get the Device Handle */
    vpbeDeviceHandleSIN = (DDC_VPBEDeviceObject *)DDC_VPBEGetDeviceHandle();
    if(NULL!= vpbeDeviceHandleSIN)
    {
        /*Store the VENC Interrupt number */
        vpbeDeviceHandleSIN->IntNum = CSL_INTC_EVENTID_VENCINT;
    }
}

DDC_VPBEStatus DDC_VPBEValidateFrameBuffer(PSP_VPBEValidateParams *surfVF)
{

    DDC_VPBEStatus  result                      = DDC_VPBE_SOK;
    Int fbAddressVF                             = NULL;
    float  rawPitchGV      = 0.0;
    Uint32 roundedPitchGV  = 0x00000000;

    /*Check the Parameters not NULL */
    if((NULL == surfVF))
    {
        result = DDC_VPBE_INVALID_PARAM;
    }
    else
    {
        fbAddressVF = (Int) surfVF->InParams.frame.frameBufferPtr;

        if((((fbAddressVF % 32u) != 0))         ||
            ((surfVF->InParams.pitch == 0)      ||
            ((surfVF->InParams.pitch % 32u) != 0)))
            {

                if((0!=surfVF->InParams.pitch)&&((surfVF->InParams.pitch % 32u)!=0))
                {
                    rawPitchGV              = (float)(((float)surfVF->InParams.pitch/32u));
                    roundedPitchGV          = (Uint32)ceil(rawPitchGV);
                    surfVF->OutParams.pitch = roundedPitchGV * 32u;
                 }
                result = DDC_VPBE_INVALID_PARAM;
            }
    }
    return(result);
}

/**
  * \brief      Validate Frame Buffers For VPSS Interface Object
  */
DDC_VPBEStatus DDC_VPBECheckFrameBuffer(Ptr                       handleVF,
                                           FVID_Frame *surfVF)
{

    DDC_VPBEStatus  result  = DDC_VPBE_SOK;
    Int fbAddressVF         = 0;
    /*Check the Parameters not NULL */
    if((NULL == surfVF) || (NULL == handleVF))
    {
        result = DDC_VPBE_INVALID_PARAM;
    }
    else
    {
        if (NULL != surfVF->frame.frameBufferPtr)
        {
            fbAddressVF = (Int) surfVF->frame.frameBufferPtr;
        }
        else
        {
            result = DDC_VPBE_INVALID_PARAM;
        }
    }
    if(((result != DDC_VPBE_SOK)      ||
       ((fbAddressVF % (32u)) != 0u)) ||
       ((surfVF->pitch == 0u)         ||
       ((surfVF->pitch % (32u)) != 0u)))
    {
        result = DDC_VPBE_INVALID_PARAM;
    }
    return(result);
}

/**
  * \brief   Configure Window boundary Parameter
  */
DDC_VPBEStatus DDC_VPBEConfigWindowBoundary(Ptr handleCW, Ptr paramsCW)
{
    DDC_VPBEOsdObject       * osdWindowHandleCW = NULL;
    PSP_VPBEOsdConfigParams * windowCW          = NULL ;
    DDC_VPBEOsdObject       * vid0HandleCW      = NULL;
    PSP_VPBE_Id idCW                            = PSP_VPBE_INVALID_ID;
    DDC_VPBEStatus  resultCW                    = DDC_VPBE_E_FAIL;
    Uint32 planeHeight = 0,planeWidth = 0;
    Uint32 topMargin   = 0,leftMargin = 0;
    /*Check the parameters not NULL */
    if((NULL == handleCW) || (NULL == paramsCW))
    {
        resultCW = DDC_VPBE_E_FAIL;
    }
    else
    {
        /*Get the VIDEO-0 OSD plane handle */
        vid0HandleCW = (DDC_VPBEOsdObject * )DDC_VPBEGetChannelHandle(PSP_VPBE_VIDEO_0);
        windowCW     = (PSP_VPBEOsdConfigParams *)paramsCW;
        /*Get the OSD plane Channel Id */
        idCW         = DDC_VPBEGetChannelId(handleCW);
        /*Validate the Id */
        if(((idCW != PSP_VPBE_VIDEO_0) && (idCW != PSP_VPBE_VIDEO_1)) &&
           ((idCW != PSP_VPBE_OSD_0)   && (idCW != PSP_VPBE_OSD_1)))
        {
                resultCW = DDC_VPBE_E_FAIL;
        }
        else
        {
            resultCW = DDC_VPBE_SOK;
            osdWindowHandleCW = (DDC_VPBEOsdObject * )handleCW;
            if(((idCW == PSP_VPBE_VIDEO_1)||(idCW ==PSP_VPBE_OSD_0))||(idCW ==PSP_VPBE_OSD_1))
            {
                if(TRUE == DDC_VPBEIsWithinWindowBoundary(vid0HandleCW->OsdParams.leftMargin,vid0HandleCW->OsdParams.topMargin,
                                                          vid0HandleCW->OsdParams.width,vid0HandleCW->OsdParams.height,
                                                          windowCW->leftMargin,windowCW->topMargin,
                                                          windowCW->width,windowCW->height))
                {
                    resultCW = DDC_VPBE_SOK;
                }
                else
                {
                    resultCW = DDC_VPBE_E_FAIL;
                 }
            }
            if(DDC_VPBE_SOK == resultCW)
            {
                planeWidth  = windowCW->width;
                planeHeight = windowCW->height;
                leftMargin  = windowCW->leftMargin;
                topMargin   = windowCW->topMargin;

                osdWindowHandleCW->OsdParams.width      = planeWidth;
                osdWindowHandleCW->OsdParams.height     = planeHeight;
                osdWindowHandleCW->OsdParams.leftMargin = leftMargin;
                osdWindowHandleCW->OsdParams.topMargin  = topMargin;

                if(FVID_FRAME_MODE == osdWindowHandleCW->OsdParams.ffMode)
                {
                    planeHeight = planeHeight >> 1;
                    topMargin   = topMargin   >> 1;
                }
                LLC_setOsdDisplayScreenHeight(idCW,osdWindowHandleCW->OsdRegs,planeHeight);
                LLC_setOsdDisplayScreenWidth(idCW,osdWindowHandleCW->OsdRegs,planeWidth);
                LLC_setOsdDisplayLeftMargin(idCW,osdWindowHandleCW->OsdRegs,leftMargin);
                LLC_setOsdDisplayTopMargin(idCW,osdWindowHandleCW->OsdRegs,topMargin);
            }

        }
    }
    return(resultCW);
}

/**
  * \brief   Configure Zoom Parameters
  */
DDC_VPBEStatus DDC_VPBEConfigZoomParameters(Ptr handleCZ, Ptr paramsCZ)
{
    DDC_VPBEOsdObject       * vpbeOsdHandleCZ = NULL;
    PSP_VPBEOsdConfigParams * zoomCZ          = NULL;
    DDC_VPBEStatus  resultCZ                  = DDC_VPBE_E_FAIL;
    PSP_VPBE_Id idCZ                          = PSP_VPBE_INVALID_ID;
    /* Check the Parameters not NULL */
    if((NULL == handleCZ) || (NULL == paramsCZ))
    {
        resultCZ = DDC_VPBE_E_FAIL;
    }
    else
    {
        zoomCZ  = (PSP_VPBEOsdConfigParams *)paramsCZ;
        /*Get the Channel Id */
        idCZ    = DDC_VPBEGetChannelId(handleCZ);
        /*Validate the Channel Id */
        if(((idCZ  != PSP_VPBE_VIDEO_0) && (idCZ != PSP_VPBE_VIDEO_1)) &&
            ((idCZ != PSP_VPBE_OSD_0)   && (idCZ != PSP_VPBE_OSD_1)))
        {
            resultCZ = DDC_VPBE_E_FAIL;
        }
        else
        {
            resultCZ        = DDC_VPBE_SOK;
            vpbeOsdHandleCZ = (DDC_VPBEOsdObject *)handleCZ;
            /*Zoom the OSD planes in Horizontal direction */
            if(FALSE == LLC_setOsdHorZoom(idCZ, zoomCZ->hScaling, vpbeOsdHandleCZ->OsdRegs))
            {
                resultCZ = DDC_VPBE_E_FAIL;
            }
            else
            {
                vpbeOsdHandleCZ->OsdParams.hScaling = zoomCZ->hScaling;
            }
            /*Zoom the OSD planes in Vertical direction */
            if(FALSE == LLC_setOsdVertZoom(idCZ,zoomCZ->vScaling, vpbeOsdHandleCZ->OsdRegs))
            {
                resultCZ = DDC_VPBE_E_FAIL;
            }
            else
            {
                vpbeOsdHandleCZ->OsdParams.vScaling = zoomCZ->vScaling;
            }
            /*Horizontal Expansion of OSD planes  */
            if(FALSE == LLC_setOsdHorzExp_9_8(idCZ,zoomCZ->hExpansion,vpbeOsdHandleCZ->OsdRegs))
            {
                resultCZ = DDC_VPBE_E_FAIL;
            }
            else
            {
                vpbeOsdHandleCZ->OsdParams.hExpansion = zoomCZ->hExpansion;
            }
            /*Vertical Expansion of OSD planes  */
            if(FALSE == LLC_setOsdVertExp_6_5(idCZ,zoomCZ->vExpansion,vpbeOsdHandleCZ->OsdRegs))
            {
                resultCZ = DDC_VPBE_E_FAIL;
            }
            else
            {
                vpbeOsdHandleCZ->OsdParams.hExpansion = zoomCZ->vExpansion;
            }
        }
    }
    return( resultCZ);
}

/************************************************************************
                        LOCAL FUNCTIONS
            This Functions are called by DDC layer functions
*************************************************************************/
/**
  * \brief  Get VPBE Channel(OSD Planes/VENC/Cursor) Id
  */
PSP_VPBE_Id DDC_VPBEGetChannelId(Ptr handle)
{
    PSP_VPBE_Id idGI                          = PSP_VPBE_INVALID_ID;
    /*Get the Device Handle */
    DDC_VPBEDeviceObject * vpbeDeviceHandleGI =
                           (DDC_VPBEDeviceObject *)DDC_VPBEGetDeviceHandle();
    /*Check the Handle not NULL */
    if((NULL!=handle) && (NULL!=vpbeDeviceHandleGI))
    {
        if(&(vpbeDeviceHandleGI->osd[DDC_VPBE_PLANE_VIDEO0])    == handle)
        {
            idGI = PSP_VPBE_VIDEO_0;
        }
        else if(&(vpbeDeviceHandleGI->osd[DDC_VPBE_PLANE_VIDEO1])== handle)
        {
            idGI = PSP_VPBE_VIDEO_1;
        }
        else if(&(vpbeDeviceHandleGI->osd[DDC_VPBE_PLANE_OSD0]) == handle)
        {
            idGI = PSP_VPBE_OSD_0;
        }
        else if(&(vpbeDeviceHandleGI->osd[DDC_VPBE_PLANE_OSD1])== handle)
        {
            idGI = PSP_VPBE_OSD_1;
        }
        else if(&(vpbeDeviceHandleGI->cursor)== handle)
        {
            idGI = PSP_VPBE_CURSOR;
        }
        else if(&(vpbeDeviceHandleGI->venc) == handle)
        {
            idGI = PSP_VPBE_VENC;
        }
        else
        {
            idGI = PSP_VPBE_INVALID_ID;
        }
    }

    return(idGI);
}

/**
  * \brief      This function will returns the different VPBE Channel
  *             (OSD Planes/VENC/Cursor) handle
  */
Ptr DDC_VPBEGetChannelHandle(PSP_VPBE_Id id)
{
    Ptr handleToReturnGH                      = NULL;
    /*Get the Device Handle */
    DDC_VPBEDeviceObject * vpbeDeviceHandleGH =
                        (DDC_VPBEDeviceObject * )DDC_VPBEGetDeviceHandle();
    if(NULL!= vpbeDeviceHandleGH)
    {
        switch(id)
        {
            case PSP_VPBE_VIDEO_0:
            case PSP_VPBE_VIDEO_1:
            case PSP_VPBE_OSD_0 :
            case PSP_VPBE_OSD_1 :
            {
                handleToReturnGH = &(vpbeDeviceHandleGH->osd[(id-PSP_VPBE_VIDEO_0)]);
            }
            break;
            case PSP_VPBE_CURSOR:
            {
                handleToReturnGH = &(vpbeDeviceHandleGH->cursor);
            }
            break;
            case PSP_VPBE_VENC:
            {
                handleToReturnGH = &(vpbeDeviceHandleGH->venc);
            }
            break;
            default:
            {
                handleToReturnGH = NULL;
            }
            break;
        }
    }
    return(handleToReturnGH);
}
/**
  * \brief   Get VIDEO plane status.
  */
Bool DDC_VPBEIsOsdPlaneActive(PSP_VPBE_Id idGV)
{
    Bool planeStatusIV                  = FALSE;
    /*Get the Channel Handle based on channel Id*/
    DDC_VPBEOsdObject* vpbeVidHandleIV  =
                                    (DDC_VPBEOsdObject*)DDC_VPBEGetChannelHandle(idGV);
    /* Check whether OSD planes is active */
    if((NULL != vpbeVidHandleIV ) &&
       (TRUE == vpbeVidHandleIV->PlaneActive))
    {
        planeStatusIV = TRUE;
    }

    return(planeStatusIV);
}

/**
  * \brief   This function reset the frame buffer object
  */
void DDC_VPBEResetFrameBufferObject(DDC_VPBEFrameBufferObject * fbRF)
{
    Uint fbIndex = 0;
    /* Check the Framebuffer not NULL */
    if(NULL != fbRF)
    {
        fbRF->writeIndexFreeQue         = 0u;
        fbRF->readIndexFreeQue          = 0u;

        fbRF->writeIndexActiveQue       = 0u;
        fbRF->readIndexActiveQue        = 0u;

        for(fbIndex = 0; fbIndex < DDC_VPBE_MAX_FRAME_BUFFERS; fbIndex++)
        {
            fbRF->freeQueue[fbIndex]    = NULL;
            fbRF->activeQueue[fbIndex]  = NULL;
        }
    }
}

/**
  * \brief  This function add the framebuffers in the queue
  */
DDC_VPBEStatus DDC_VPBEAddQueue(DDC_VPBEQueueType         qTypeAQ,
                                Ptr                     handle,
                                FVID_Frame * fbAddressAQ)
{
    Uint32 cookieAQ                      = 0u;
    DDC_VPBEStatus resultAQ              = DDC_VPBE_E_FAIL;
    DDC_VPBEOsdObject         * handleAQ = NULL;
    DDC_VPBEFrameBufferObject * fbAQ     = NULL;
    if(NULL!=handle)
    {
        handleAQ = (DDC_VPBEOsdObject *)handle;
        fbAQ     = &(handleAQ->fb);
    }

    /* Check the Parameters not NULL */
    if ( (NULL != fbAddressAQ ) && (NULL != fbAQ) )
    {
        switch(qTypeAQ)
        {
            case DDC_VPBE_FREE_QUEUE:
            {
                /*Check the FreeQueue its null */
                /*If Freequeue is null then store the Framebuffer in the queue */
                if(NULL == fbAQ->freeQueue[fbAQ->writeIndexFreeQue])
                {
                    fbAQ->freeQueue[fbAQ->writeIndexFreeQue] = fbAddressAQ;
                    fbAQ->writeIndexFreeQue = (fbAQ->writeIndexFreeQue+1u)% DDC_VPBE_MAX_FRAME_BUFFERS;
                    if(TRUE == handleAQ->vpbedequeueWaitFlag)
                    {
                        if (PAL_osSemGive(handleAQ->vpbedequeueSem) != PAL_SOK) {

                        }
                        handleAQ->vpbedequeueWaitFlag = FALSE;
                    }

                    resultAQ                = DDC_VPBE_SOK;
                }
            }
            break;
            case DDC_VPBE_ACTIVE_QUEUE:
            {
                /*Disable the interrupts while enter to Critical section */
                PAL_osProtectEntry(PAL_OSPROTECT_INTERRUPT,&cookieAQ);
                /*Check the Active Queue its null */
                /*If activequeue is null then store the Framebuffer in the queue */
                if(NULL == fbAQ->activeQueue[fbAQ->writeIndexActiveQue])
                {
                    fbAQ->activeQueue[fbAQ->writeIndexActiveQue] = fbAddressAQ;
                    fbAQ->writeIndexActiveQue = (fbAQ->writeIndexActiveQue+1u)% DDC_VPBE_MAX_FRAME_BUFFERS;
                    resultAQ                  = DDC_VPBE_SOK;
                }
                else
                {
                    resultAQ = DDC_VPBE_E_RESOURCES;
                }
                /*Enable Interrupts at exit of Critical Section */
                PAL_osProtectExit(PAL_OSPROTECT_INTERRUPT,cookieAQ);
            }
            break;
            default:
            {
                resultAQ = DDC_VPBE_E_FAIL;
            }
            break;
        }
    }

    return(resultAQ);
}
/**
  * \brief      This will delete a fram buffer from the Queue
  */
DDC_VPBEStatus DDC_VPBEDelQueue(DDC_VPBEQueueType        qTypeDQ,
                                Ptr                      handle ,
                                FVID_Frame **  fbAddressDQ)
{
    DDC_VPBEStatus result                = DDC_VPBE_E_FAIL;
    Uint indexDQ                         = 0u;
    Uint32 cookieDQ                      = 0u;
    DDC_VPBEOsdObject         * handleDQ = NULL;
    DDC_VPBEFrameBufferObject * fbDQ     = NULL;
    if(NULL!= handle)
    {
        handleDQ = (DDC_VPBEOsdObject *)handle;
        fbDQ     = &(handleDQ->fb);
    }

    /*Check the Parameters not NULL */
    if ( (NULL != fbAddressDQ ) && (NULL != fbDQ) )
    {
        switch(qTypeDQ)
        {
            case DDC_VPBE_FREE_QUEUE:
            {
                /*Disable interrupts while enter to Critical section */
                PAL_osProtectEntry(PAL_OSPROTECT_INTERRUPT,&cookieDQ);
                if(fbDQ->freeQueue[fbDQ->readIndexFreeQue]== NULL)
                {
                    handleDQ->vpbedequeueWaitFlag= TRUE;
                    /*Enable the interrupts at the exit point of Critical section */
                    PAL_osProtectExit(PAL_OSPROTECT_INTERRUPT,cookieDQ);
                    if (PAL_osSemTake(handleDQ->vpbedequeueSem, 2000) != PAL_SOK){
                        result = DDC_VPBE_E_FAIL;
                    }
                }
                else
                {
                    /*Enable the interrupts at the exit point of Critical section */
                    PAL_osProtectExit(PAL_OSPROTECT_INTERRUPT,cookieDQ);
                }
                if(NULL!=fbDQ->freeQueue[fbDQ->readIndexFreeQue])
                {
                    /*Disable interrupts while enter to Critical section */
                    PAL_osProtectEntry(PAL_OSPROTECT_INTERRUPT,&cookieDQ);
                    *fbAddressDQ            = fbDQ->freeQueue[fbDQ->readIndexFreeQue];
                    fbDQ->freeQueue[fbDQ->readIndexFreeQue] = NULL;
                    fbDQ->readIndexFreeQue  = (fbDQ->readIndexFreeQue+1u)% DDC_VPBE_MAX_FRAME_BUFFERS;
                    /*Enable the interrupts at the exit point of Critical section */
                    PAL_osProtectExit(PAL_OSPROTECT_INTERRUPT,cookieDQ);
                    result = DDC_VPBE_SOK;
                }
            }
            break;
            case DDC_VPBE_ACTIVE_QUEUE:
            {
                /*Check the next index active queue whether its null or not */
                /*If framebuffer still in the queue then make the current index
                  of the active queue to be NULL */
                indexDQ = (fbDQ->readIndexActiveQue+1u)% DDC_VPBE_MAX_FRAME_BUFFERS;
                if(NULL != fbDQ->activeQueue[indexDQ])
                {
                    *fbAddressDQ             = fbDQ->activeQueue[fbDQ->readIndexActiveQue];
                    fbDQ->activeQueue[fbDQ->readIndexActiveQue] = NULL;
                    fbDQ->readIndexActiveQue = indexDQ;
                    result                   = DDC_VPBE_SOK;
                }
            }
            break;
            default:
            {
                result                       = DDC_VPBE_E_FAIL;
            }
            break;
        }
    }

    return(result);
}

/**
  * \brief      Get next frame buffer address
  */
FVID_Frame * DDC_VPBEGetNxtFBAddress(const DDC_VPBEFrameBufferObject * fbGN)
{
    FVID_Frame * retHandle  = NULL;
    /*Check the parameter not null */
    if (NULL != fbGN)
    {
        retHandle = (fbGN->activeQueue[fbGN->readIndexActiveQue]);
    }
    return retHandle;
}

/**
  * \brief      Interrupt service routine for Back-End
  */
/* ARGSUSED */
void DDC_VPBEIsr(Uint32 arg)
{
    DDC_VPBEVencObject* vpbeVencHandleVBI   = NULL;
    DDC_VPBEFieldId currentFieldVBI;

#ifdef VPBE_INSTRUMENTATION_ENABLED
    PSP_LOG_EVENT(  &DVTEvent_Log,
                    "VPBE",
                    PSP_DVT_DESC(   PSP_DVT_eINT_START,
                                    PSP_DVT_dNONE,
                                    PSP_DVT_dNONE,
                                    PSP_DVT_dNONE)
                                );
#endif /* VPBE_INSTRUMENTATION_ENABLED */

    /*Get the VENC Channel Handle */
    vpbeVencHandleVBI = (DDC_VPBEVencObject*)DDC_VPBEGetChannelHandle(PSP_VPBE_VENC);

    if(NULL!=vpbeVencHandleVBI)
    {
        currentFieldVBI = (DDC_VPBEFieldId)LLC_getVencField(vpbeVencHandleVBI->VencRegs);

        switch(vpbeVencHandleVBI->VencParams.displayStandard)
        {
            case PSP_VPBE_DISPLAY_NTSC_INTERLACED_COMPOSITE:
            case PSP_VPBE_DISPLAY_NTSC_INTERLACED_S_VIDEO:
            case PSP_VPBE_DISPLAY_NTSC_INTERLACED_COMPONENT:
            case PSP_VPBE_DISPLAY_PAL_INTERLACED_COMPOSITE:
            case PSP_VPBE_DISPLAY_PAL_INTERLACED_S_VIDEO:
            case PSP_VPBE_DISPLAY_PAL_INTERLACED_COMPONENT:
            {
                vpbeVencHandleVBI->fieldId^= 1;
                if(currentFieldVBI == vpbeVencHandleVBI->fieldId)
                {
                    /* 1st Field */
                    if(DDC_VPBE_1ST_FIELD == currentFieldVBI)
                    {
                        DDC_VPBEUpdateFreeQueue(PSP_VPBE_VIDEO_0);
                        DDC_VPBEUpdateFreeQueue(PSP_VPBE_VIDEO_1);
                        DDC_VPBEUpdateFreeQueue(PSP_VPBE_OSD_0);
                        DDC_VPBEUpdateFreeQueue(PSP_VPBE_OSD_1);

                    }
                    /* 2nd Field */
                    if(DDC_VPBE_2ND_FIELD == currentFieldVBI)
                    {
                        DDC_VPBEUpdateFbAdress(PSP_VPBE_VIDEO_0);
                        DDC_VPBEUpdateFbAdress(PSP_VPBE_VIDEO_1);
                        DDC_VPBEUpdateFbAdress(PSP_VPBE_OSD_0);
                        DDC_VPBEUpdateFbAdress(PSP_VPBE_OSD_1);
                    }
               }
               else if(DDC_VPBE_1ST_FIELD == currentFieldVBI)
               {
                  vpbeVencHandleVBI->fieldId = currentFieldVBI;
               }
            }
            break;
            case PSP_VPBE_DISPLAY_NTSC_PROGRESSIVE_COMPONENT:
            case PSP_VPBE_DISPLAY_PAL_PROGRESSIVE_COMPONENT:
            case PSP_VPBE_DISPLAY_YCC16_DIGITAL_480P:
            {
                DDC_VPBEUpdateFreeQueue(PSP_VPBE_VIDEO_0);
                DDC_VPBEUpdateFreeQueue(PSP_VPBE_VIDEO_1);
                DDC_VPBEUpdateFreeQueue(PSP_VPBE_OSD_0);
                DDC_VPBEUpdateFreeQueue(PSP_VPBE_OSD_1);
                DDC_VPBEUpdateFbAdress(PSP_VPBE_VIDEO_0);
                DDC_VPBEUpdateFbAdress(PSP_VPBE_VIDEO_1);
                DDC_VPBEUpdateFbAdress(PSP_VPBE_OSD_0);
                DDC_VPBEUpdateFbAdress(PSP_VPBE_OSD_1);
            }
            break;
            default:
            {
                /* Not Supported Currently */
            }
            break;
        }
        /*Call the Application callback function */
        DDC_VPBE_AppCallbackFunction(PSP_VPBE_VIDEO_0,currentFieldVBI);
        DDC_VPBE_AppCallbackFunction(PSP_VPBE_VIDEO_1,currentFieldVBI);
        DDC_VPBE_AppCallbackFunction(PSP_VPBE_OSD_0,currentFieldVBI);
        DDC_VPBE_AppCallbackFunction(PSP_VPBE_OSD_1,currentFieldVBI);
    }

#ifdef VPBE_INSTRUMENTATION_ENABLED
    PSP_LOG_EVENT(  &DVTEvent_Log,
                    "VPBE",
                    PSP_DVT_DESC(   PSP_DVT_eINT_END,
                                    PSP_DVT_dNONE,
                                    PSP_DVT_dNONE,
                                    PSP_DVT_dNONE)
                                );
#endif /*VPBE_INSTRUMENTATION_ENABLED*/
}
/**
  * \brief      This function invokes the callback that the application has
  *             registered with the driver.
  */
void DDC_VPBE_AppCallbackFunction(PSP_VPBE_Id      idCACF,
                                  DDC_VPBEFieldId   currentFieldCACF)
{
    DDC_VPBEOsdObject     * vpbeOsdHandleCACF   = NULL;
    switch(idCACF)
    {
        case PSP_VPBE_VIDEO_0:
        case PSP_VPBE_VIDEO_1:
        case PSP_VPBE_OSD_0:
        case PSP_VPBE_OSD_1:
        {
            /*Get the OSD plane Channel Handle */
            vpbeOsdHandleCACF = (DDC_VPBEOsdObject*)DDC_VPBEGetChannelHandle(idCACF);
            /*Check the OSD plane handle not NULL */
            if((vpbeOsdHandleCACF != NULL)                      &&
               ((DDC_VPBE_OPENED == vpbeOsdHandleCACF->state)   &&
               (NULL != vpbeOsdHandleCACF->OsdParams.appCallback)))
            {
                vpbeOsdHandleCACF->fbPtr = NULL;
                vpbeOsdHandleCACF->OsdParams.appCallback(&(vpbeOsdHandleCACF->fbPtr),
                                                NULL,
                                                currentFieldCACF);
                if(NULL != vpbeOsdHandleCACF->fbPtr)
                {
                    LLC_setOsdFBStartAddress(idCACF,
                                                  vpbeOsdHandleCACF->OsdRegs,
                                                  vpbeOsdHandleCACF->fbPtr);
                }
            }
        }
        break;
        default:
        {
            /* Not Supported Currently */
        }
        break;
    }
}

/**
  * \brief      Validates the window boundary by checking leftMargine,topMargin
  *             Width and Height.
  */
Bool DDC_VPBEIsWithinWindowBoundary(Uint32 srcleftMargin,Uint32 srctopMargin,Uint32 srcwidth,Uint srcheight,
                                    Uint32 trgleftMargin,Uint32 trgtopMargin,Uint32 trgwidth,Uint trgheight)
{
    Bool resultIW = FALSE;
    if(((trgleftMargin + trgwidth) <= (srcleftMargin + srcwidth)) &&
       ((trgtopMargin + trgheight) <= (srctopMargin + srcheight)))
        {
            resultIW = TRUE;
        }

    return(resultIW);
}


DDC_VPBEStatus DDC_VPBEAllocFrameBuffer(Ptr handle ,
                                        FVID_Frame ** allocFrameBuffer)
{
    Ptr                     bufferalloc      = NULL;
    FVID_Frame * surfaceFB        = NULL;
    DDC_VPBEOsdObject     * vpbeOsdHandle    = NULL;
    DDC_VPBEStatus          result  = DDC_VPBE_E_FAIL;
    PAL_Result              status  = PSP_E_NO_MEMORY;
    Uint32 fb_size = 0;

    if(NULL != handle)
    {
        result             = DDC_VPBE_NO_MEMORY;
        vpbeOsdHandle    = (DDC_VPBEOsdObject * )handle;
        status = PAL_osMemAlloc(vpbeOsdHandle->OsdParams.segId,sizeof(FVID_Frame),32u,(Ptr *)&bufferalloc);
        if(PAL_SOK == status)
        {
            if(NULL != bufferalloc)
            {
                surfaceFB   =   (FVID_Frame *)bufferalloc;
                fb_size =(vpbeOsdHandle->OsdParams.height)*(vpbeOsdHandle->OsdParams.pitch);
                status = PAL_osMemAlloc(vpbeOsdHandle->OsdParams.segId,fb_size,128u,&(surfaceFB->frame.frameBufferPtr));
                if(PAL_SOK == status)
                {
                    if(NULL!=surfaceFB->frame.frameBufferPtr)
                    {
                        surfaceFB->lines    = vpbeOsdHandle->OsdParams.height;
                        surfaceFB->pitch    = vpbeOsdHandle->OsdParams.pitch;
                        surfaceFB->bpp      = (FVID_bitsPerPixel)
                                              (((vpbeOsdHandle->OsdParams.pitch)/vpbeOsdHandle->OsdParams.width)*8);
                        *allocFrameBuffer = bufferalloc;
                        result = DDC_VPBE_SOK;
                    }
                }
                else
                {
                    status = PAL_osMemFree(vpbeOsdHandle->OsdParams.segId,surfaceFB,sizeof(FVID_Frame));
                    if(PAL_SOK == status)
                    {
                        result  = DDC_VPBE_NO_MEMORY;
                    }
                }
            }
        }
    }
    return result;
}

DDC_VPBEStatus DDC_VPBEFreeFrameBuffer(Ptr handle,
                                       FVID_Frame ** allocFrameBuffer)
{
    DDC_VPBEOsdObject     * vpbeOsdHandle    = NULL;
    DDC_VPBEStatus result = DDC_VPBE_E_FAIL;
    Uint32 fb_size =0;
    FVID_Frame *ptrFrame;

    if((NULL == handle)||(NULL == allocFrameBuffer))
    {
        result = DDC_VPBE_E_FAIL;
    }
    else
    {
        ptrFrame = *allocFrameBuffer;
        vpbeOsdHandle = (DDC_VPBEOsdObject *)handle;
        fb_size = (vpbeOsdHandle->OsdParams.height)*(vpbeOsdHandle->OsdParams.pitch);
        if(PAL_SOK == PAL_osMemFree(vpbeOsdHandle->OsdParams.segId,ptrFrame->frame.frameBufferPtr,fb_size))
        {
            if(PAL_SOK ==PAL_osMemFree(vpbeOsdHandle->OsdParams.segId,ptrFrame,sizeof(FVID_Frame)))
            {
                result = DDC_VPBE_SOK;
            }
        }
    }
    return result;
}
void DDC_VPBEUpdateFbAdress(PSP_VPBE_Id idUN)
{
    DDC_VPBEOsdObject     * vpbeOsdHandleUN     = NULL;
    FVID_Frame * fbAddActiveUN       = NULL;
    switch(idUN)
    {
        case PSP_VPBE_VIDEO_0:
        case PSP_VPBE_VIDEO_1:
        case PSP_VPBE_OSD_0:
        case PSP_VPBE_OSD_1:
        {
            vpbeOsdHandleUN   = (DDC_VPBEOsdObject *)DDC_VPBEGetChannelHandle(idUN);
            if((NULL != vpbeOsdHandleUN ) && (DDC_VPBE_OPENED == vpbeOsdHandleUN->state))
            {
                if(NULL == vpbeOsdHandleUN->fb.tempfbAddFree)
                {
#ifdef VPBE_INSTRUMENTATION_ENABLED
                        PSP_LOG_EVENT(  &DVTEvent_Log,
                                        "VPBE",
                                        PSP_DVT_DESC(
                                            PSP_DVT_eDATA_SND_END,
                                            PSP_DVT_dCHANNEL_ID_INST,
                                            PSP_DVT_dPACKET_ID,
                                            PSP_DVT_dNONE),
                                        CHANNELID_INSTANCEID(
                                            1,
                                            0),
                                        vpbeOsdHandleUN->fb.tempfbAddFree);
#endif /*VPBE_INSTRUMENTATION_ENABLED*/

                    /* Delete Frame buffer address from Active Queue */
                    if(DDC_VPBE_SOK == DDC_VPBEDelQueue(DDC_VPBE_ACTIVE_QUEUE,
                                                        vpbeOsdHandleUN,
                                                        &(vpbeOsdHandleUN->fb.tempfbAddFree)))
                    {
                        /*Get the Next Frame Buffer Address */
                        fbAddActiveUN = DDC_VPBEGetNxtFBAddress(&(vpbeOsdHandleUN->fb));
                        if(NULL!=fbAddActiveUN)
                        {

#ifdef VPBE_INSTRUMENTATION_ENABLED
                            PSP_LOG_EVENT(  &DVTEvent_Log,
                                            "VPBE",
                                            PSP_DVT_DESC(
                                                PSP_DVT_eDATA_SND_START,
                                                PSP_DVT_dCHANNEL_ID_INST,
                                                PSP_DVT_dPACKET_ID,
                                                PSP_DVT_dNONE),
                                            CHANNELID_INSTANCEID(
                                                1,
                                                0),
                                            fbAddActiveUN);
#endif /*VPBE_INSTRUMENTATION_ENABLED*/

                            /* Update the Frame Buffer Address on Hardware Register */
                            LLC_setOsdFBStartAddress(idUN,vpbeOsdHandleUN->OsdRegs,
                                                      fbAddActiveUN->frame.frameBufferPtr);
                        }
                    }
                }
            }
        }
        break;
        default:
        {
            /* Not Supported Currently */
        }
        break;
    }
}

void DDC_VPBEUpdateFreeQueue(PSP_VPBE_Id idUN)
{
    DDC_VPBEOsdObject     * vpbeOsdHandleUN     = NULL;
    switch(idUN)
    {
        case PSP_VPBE_VIDEO_0:
        case PSP_VPBE_VIDEO_1:
        case PSP_VPBE_OSD_0:
        case PSP_VPBE_OSD_1:
        {
            vpbeOsdHandleUN   = (DDC_VPBEOsdObject *)DDC_VPBEGetChannelHandle(idUN);
            if((NULL != vpbeOsdHandleUN ) && (DDC_VPBE_OPENED == vpbeOsdHandleUN->state))
            {
                /*Add Frame Buffer Address in the Free Queue */
                if(NULL!=vpbeOsdHandleUN->fb.tempfbAddFree)
                {
                    _DDA_VPBEGetTimeStamp(&(vpbeOsdHandleUN->fb.tempfbAddFree)->timeStamp);
                    DDC_VPBEAddQueue(DDC_VPBE_FREE_QUEUE,
                                     vpbeOsdHandleUN,vpbeOsdHandleUN->fb.tempfbAddFree);
                    vpbeOsdHandleUN->fb.tempfbAddFree = NULL;
                }
            }
        }
        break;
        default:
        {

        }
    }
}

DDC_VPBEStatus DDC_VPBEStopEngine(Ptr handle)
{
    PSP_VPBE_Id idCH          = PSP_VPBE_INVALID_ID;
    DDC_VPBEStatus result     = DDC_VPBE_E_FAIL;
    DDC_VPBEDeviceObject * handleDeviceCH   = NULL;
    DDC_VPBEOsdObject    * handleOsdCH      = NULL;
    DDC_VPBEVencObject   * handleVencCH     = NULL;
    DDC_VPBECursorObject * handleCursorCH   = NULL;
    DDC_VPBEFrameBufferObject * fbStop      = NULL;
    Uint32 cookie = 0u;

    /*Get the Device Handle */
    handleDeviceCH = (DDC_VPBEDeviceObject* )DDC_VPBEGetDeviceHandle();

    if((NULL != handle))
    {
        /*Get the Channel Id */
        idCH = DDC_VPBEGetChannelId(handle);
        switch(idCH)
        {
            case PSP_VPBE_VIDEO_0:
            case PSP_VPBE_VIDEO_1:
            case PSP_VPBE_OSD_0:
            case PSP_VPBE_OSD_1:
            {
               handleOsdCH  = (DDC_VPBEOsdObject *)handle;
               fbStop       = (DDC_VPBEFrameBufferObject *)&(handleOsdCH->fb);

                LLC_setOsdDisplayOff(idCH,handleOsdCH->OsdRegs);
                /*Check OSD1 Window is in Attribute mode */
                if(FVID_ATTRIBUTE == handleOsdCH->OsdParams.colorFormat)
                {
                    LLC_setOSDWin1AttrModeDisable(handleOsdCH->OsdRegs);
                }
                /*Set the SDRAM Address to zero */
                LLC_setOsdFBStartAddress(idCH,handleOsdCH->OsdRegs,0x00000000);

                PAL_osProtectEntry(PAL_OSPROTECT_INTERRUPT,&cookie);
                if((fbStop->writeIndexActiveQue - fbStop->readIndexActiveQue)!=0)
                {
                    while(fbStop->readIndexActiveQue != fbStop->writeIndexActiveQue)
                    {
                        if( (NULL != fbStop->activeQueue[fbStop->readIndexActiveQue]) &&
                            (NULL == fbStop->freeQueue[fbStop->writeIndexFreeQue]))
                        {
                            fbStop->freeQueue[fbStop->writeIndexFreeQue]=
                                    fbStop->activeQueue[fbStop->readIndexActiveQue];
                            fbStop->activeQueue[fbStop->readIndexActiveQue] = NULL;
                            fbStop->writeIndexFreeQue  = (fbStop->writeIndexFreeQue +1u);
                            /* Circular buffer upto DDC_VPFE_MAX_FRAME_BUFFERS */
                            fbStop->writeIndexFreeQue  %= DDC_VPBE_MAX_FRAME_BUFFERS;
                            fbStop->readIndexActiveQue = (fbStop->readIndexActiveQue +1u);
                            /* Circular buffer upto DDC_VPFE_MAX_FRAME_BUFFERS */
                            fbStop->readIndexActiveQue %= DDC_VPBE_MAX_FRAME_BUFFERS;
                         }
                    }
                }
                if(NULL!= handleOsdCH->fb.tempfbAddFree)
                {
                    fbStop->freeQueue[fbStop->writeIndexFreeQue] = handleOsdCH->fb.tempfbAddFree;
                    fbStop->writeIndexFreeQue  = (fbStop->writeIndexFreeQue +1u);
                    fbStop->writeIndexFreeQue  %= DDC_VPBE_MAX_FRAME_BUFFERS;
                    handleOsdCH->fb.tempfbAddFree = NULL;
                }
                /* Enable Interrupts at exit of Critical Section */
                PAL_osProtectExit(PAL_OSPROTECT_INTERRUPT,cookie);

                /*Closed the OSD plane Channel */
                handleOsdCH->PlaneActive = FALSE;
                result = DDC_VPBE_SOK;
            }
            break;
            case PSP_VPBE_VENC:
            {
                handleVencCH = (DDC_VPBEVencObject *)handle;
                /*Disable the Venc Module */
                LLC_setVencDisable(handleVencCH->VencRegs);
                /*Unregister the VENC Interrupt */
                _DDA_VPBEUnregisterIntrHandler( handleDeviceCH->vpbeInstanceId,
                                                handleDeviceCH->IntNum);

                result  = DDC_VPBE_SOK;
            }
            break;
            case PSP_VPBE_CURSOR:
            {
                handleCursorCH          = (DDC_VPBECursorObject *)handle;
                /*Disable the Cursor Plane */
                LLC_setCursorDisable(handleCursorCH->CursorRegs);

                result = DDC_VPBE_SOK;
            }
            break;
            default:
            {
                result = DDC_VPBE_E_FAIL;
            }
            break;
        }
    }
    return  result;
}

DDC_VPBEStatus DDC_VPBEStartEngine(Ptr handle)
{
    PSP_VPBE_Id idCH          = PSP_VPBE_INVALID_ID;
    DDC_VPBEStatus result     = DDC_VPBE_E_FAIL;
    DDC_VPBEOsdObject    * handleOsdCH      = NULL;
    DDC_VPBEVencObject   * handleVencCH     = NULL;
    DDC_VPBECursorObject * handleCursorCH   = NULL;
    DDC_VPBEFrameBufferObject * fbStart     = NULL;
    DDC_VPBEDeviceObject * vpbeDeviceHandleCVMP = NULL;
    FVID_Frame * fbPtrQF = NULL;
    Uint32 pitchOPS= 0,cookie = 0;
    Bool OsdStat =0;

    if((NULL != handle))
    {
        /*Get the Venc Channel Handle */
        vpbeDeviceHandleCVMP = (DDC_VPBEDeviceObject * )DDC_VPBEGetDeviceHandle();
        /*Get the Channel Id */
        idCH = DDC_VPBEGetChannelId(handle);
        switch(idCH)
        {
            case PSP_VPBE_VIDEO_0:
            case PSP_VPBE_VIDEO_1:
            case PSP_VPBE_OSD_0:
            case PSP_VPBE_OSD_1:
            {
               handleOsdCH  = (DDC_VPBEOsdObject *)handle;
               fbStart      = (DDC_VPBEFrameBufferObject *)&(handleOsdCH->fb);
               OsdStat      =  LLC_getOSDEngineStat(idCH,handleOsdCH->OsdRegs);

               if(0 == OsdStat)
               {
                    /*Disable the interrupts while enter to Critical section */
                    PAL_osProtectEntry(PAL_OSPROTECT_INTERRUPT,&cookie);
                    if((fbStart->writeIndexFreeQue - fbStart->readIndexFreeQue)!= 0)
                    {
                        while(fbStart->readIndexFreeQue !=fbStart->writeIndexFreeQue)
                        {
                            if((NULL != fbStart->freeQueue[fbStart->readIndexFreeQue]) &&
                               (NULL == fbStart->activeQueue[fbStart->writeIndexActiveQue]))
                            {
                                fbStart->activeQueue[fbStart->writeIndexActiveQue] =
                                          fbStart->freeQueue[fbStart->readIndexFreeQue];
                                fbStart->freeQueue[fbStart->readIndexFreeQue] = NULL;
                                fbStart->writeIndexActiveQue = (fbStart->writeIndexActiveQue +1u);
                                /* Circular buffer upto DDC_VPFE_MAX_FRAME_BUFFERS */
                                fbStart->writeIndexActiveQue %= DDC_VPBE_MAX_FRAME_BUFFERS;
                                fbStart->readIndexFreeQue   = (fbStart->readIndexFreeQue +1u);
                                /* Circular buffer upto DDC_VPFE_MAX_FRAME_BUFFERS */
                                fbStart->readIndexFreeQue   %= DDC_VPBE_MAX_FRAME_BUFFERS;
                            }
                        }
                    }
                    PAL_osProtectExit(PAL_OSPROTECT_INTERRUPT,cookie);

                    /*Read the Framebuffer from Active Queue */
                    if(NULL != fbStart->activeQueue[fbStart->readIndexActiveQue])
                    {
                        fbPtrQF = fbStart->activeQueue[fbStart->readIndexActiveQue];
                         /*If ActiveQueue is not NULL */
                        if(NULL != fbPtrQF)
                        {
                            if(((FVID_ATTRIBUTE == handleOsdCH->OsdParams.colorFormat)
                                                    &&(FALSE == handleOsdCH->PlaneActive))
                                                    &&(idCH == PSP_VPBE_OSD_1))
                            {
                                /* Set Attribute Mode */
                                LLC_setOSDWin1AttrModeEnable(handleOsdCH->OsdRegs);
                            }
                           /*If OSD plane is not active turn it active at first add queue */
                            if((FALSE == handleOsdCH->PlaneActive))
                            {
                                pitchOPS = fbPtrQF->pitch/32u;
                                LLC_setOsdOffset(idCH,handleOsdCH->OsdRegs,pitchOPS);
                                LLC_setOsdFBStartAddress(idCH,handleOsdCH->OsdRegs,fbPtrQF->frame.frameBufferPtr);
                                /* TURN Display ON */
                                LLC_setOsdDisplayOn(idCH,handleOsdCH->OsdRegs);
                                /* Register Interrupt Handler */
                                if(NULL != vpbeDeviceHandleCVMP)
                                {
                                    _DDA_VPBERegisterIntrHandler(0,vpbeDeviceHandleCVMP->IntNum);
                                }
                                handleOsdCH->PlaneActive = TRUE;
                                result = DDC_VPBE_SOK;
                            }
                        }
                    }
                    else
                    {
                        result = DDC_VPBE_E_FAIL;
                    }
                }
                else
                {
                    result = DDC_VPBE_SOK;
                }
            }
            break;
            case PSP_VPBE_VENC:
            {
                handleVencCH = (DDC_VPBEVencObject *)handle;
                LLC_setVencEnable(handleVencCH->VencRegs);
                result = DDC_VPBE_SOK;
            }
            break;
            case PSP_VPBE_CURSOR:
            {
                handleCursorCH = (DDC_VPBECursorObject *)handle;
                LLC_setCursorEnable(handleCursorCH->CursorRegs);
                result = DDC_VPBE_SOK;
            }
            break;
            default:
            {
                result  = DDC_VPBE_E_FAIL;
            }
            break;
        }
    }
    return result;
}
/**
  * \brief  To configure the TH8200 Chip
  */
DDC_VPBEStatus DDC_ConfigextVIDENCParams(Ptr handle, Uint32 cmd ,Ptr cmdArg)
{
    DDC_VPBEVencObject * vencHandle  = NULL;
    DDC_VPBEStatus  result = DDC_VPBE_E_FAIL;
    if((NULL== handle)||(NULL == cmdArg))
    {
        result = DDC_VPBE_E_FAIL;
    }
    else
    {
        vencHandle = (DDC_VPBEVencObject *)handle;
        if(NULL != vencHandle->extVidEncFxn)
        {
            if(NULL != vencHandle->extVidEncFxn->Control)
            {
               result = (DDC_VPBEStatus)vencHandle->extVidEncFxn->Control(vencHandle->extVidEncHandle,
                                                                          cmd-VPBE_ExtVIDENC_BASE ,cmdArg);
            }
        }
    }
    return result;
}
