/******************************************************************************
**+-------------------------------------------------------------------------+**
**|                            ****                                         |**
**|                            ****                                         |**
**|                            ******o***                                   |**
**|                      ********_///_****                                  |**
**|                      ***** /_//_/ ****                                  |**
**|                       ** ** (__/ ****                                   |**
**|                           *********                                     |**
**|                            ****                                         |**
**|                            ***                                          |**
**|                                                                         |**
**|         Copyright (c) 2006-2010 Texas Instruments Incorporated          |**
**|                        ALL RIGHTS RESERVED                              |**
**|                                                                         |**
**| Permission is hereby granted to licensees of Texas Instruments          |**
**| Incorporated (TI) products to use this computer program for the sole    |**
**| purpose of implementing a licensee product based on TI products.        |**
**| No other rights to reproduce, use, or disseminate this computer         |**
**| program, whether in part or in whole, are granted.                      |**
**|                                                                         |**
**| TI makes no representation or warranties with respect to the            |**
**| performance of this computer program, and specifically disclaims        |**
**| any responsibility for any damages, special or consequential,           |**
**| connected with the use of this program.                                 |**
**|                                                                         |**
**+-------------------------------------------------------------------------+**
******************************************************************************/

/**
 *  \file   ddc_vpbeCursor.c
 *
 *  \brief  vpbe implementation
 *
 *  This file contains the implementation of the vpbe driver to utilize the
 *  serivces of the vpbe device driver.
 *
 *  (C) Copyright 2006, Texas Instruments, Inc
 *
 *  \note       Set tabstop to 4 (:se ts=4) while viewing this file in an
 *              editor
 *
 *  \author     Maulik Desai
 *
 *  \version    1.0     Created
 */

/******************************************************************************
                            Header File Inclusion
******************************************************************************/
#include <ti/sdo/pspdrivers/common/psp_common.h>
#include <ti/sdo/pspdrivers/drivers/vpbe/psp_vpbe.h>
#include <ti/sdo/pspdrivers/drivers/vpbe/src/ddc_vpbe.h>
#include <ti/sdo/pspdrivers/drivers/vpbe/src/ddc_vpbeCursor.h>
#include <ti/sdo/pspdrivers/drivers/vpbe/src/llc_vpbeCursor.h>

/******************************************************************************
                                    Functions
******************************************************************************/

/**
  * \brief To configure the cursor mode params
  *
  */
DDC_VPBEStatus DDC_VPBEConfigCursorParams(DDC_VPBECursorObject * const cursorHandleCCMP,Ptr params)
{
    DDC_VPBEStatus result                           = DDC_VPBE_E_FAIL;
    PSP_VPBECursorConfigParams * cursorConfigParam  = NULL;
    /*Get the Video-0 Channel Handle */
    DDC_VPBEOsdObject          * vidHandleCCMP      = DDC_VPBEGetChannelHandle(PSP_VPBE_VIDEO_0);

    /*Check the Video Channel handle and parameters not NULL */
    if(((NULL != vidHandleCCMP) && (NULL != cursorHandleCCMP)) &&
        (NULL != params))
    {
        cursorConfigParam = (PSP_VPBECursorConfigParams *)params;

        /*Check the Cursor boundary is within Video-0 Boundary */
        if(TRUE == DDC_VPBEIsWithinWindowBoundary( vidHandleCCMP->OsdParams.leftMargin,
                                                   vidHandleCCMP->OsdParams.topMargin,
                                                   vidHandleCCMP->OsdParams.width,
                                                   vidHandleCCMP->OsdParams.height,
                                                   cursorConfigParam->leftMargin,
                                                   cursorConfigParam->topMargin,
                                                   cursorConfigParam->width,
                                                   cursorConfigParam->height)
                                                   )
        {
            /* Currently cursor width vertical/horizontal is not exposed to
               application and is configured statically from within driver */
                LLC_setCursorVWidth(cursorHandleCCMP->CursorRegs,1u);
                LLC_setCursorHWidth(cursorHandleCCMP->CursorRegs,1u);
                LLC_setCursorXPosition(cursorHandleCCMP->CursorRegs,cursorConfigParam->leftMargin);
                LLC_setCursorXSize(cursorHandleCCMP->CursorRegs,cursorConfigParam->width);
                if(cursorConfigParam->CursorCLUTS == PSP_VPBE_CLUTSOURCE_RAM)
                {
                    LLC_setCursorCLUTSelectRAM(cursorHandleCCMP->CursorRegs);
                }
                if(cursorConfigParam->CursorCLUTS == PSP_VPBE_CLUTSOURCE_ROM)
                {
                    LLC_setCursorCLUTSelectROM(cursorHandleCCMP->CursorRegs);
                    LLC_setCursorROMTYPE(cursorHandleCCMP->CursorRegs);
                }
                if(FVID_FRAME_MODE== vidHandleCCMP->OsdParams.ffMode)
                {
                        LLC_setCursorYSize(cursorHandleCCMP->CursorRegs,cursorConfigParam->height/2u);
                        LLC_setCursorYPosition(cursorHandleCCMP->CursorRegs,cursorConfigParam->topMargin/2u);
                }
                else
                {
                        LLC_setCursorYSize(cursorHandleCCMP->CursorRegs,cursorConfigParam->height);
                        LLC_setCursorYPosition(cursorHandleCCMP->CursorRegs,cursorConfigParam->topMargin);
                }

                LLC_setCursorEnable(cursorHandleCCMP->CursorRegs);
                cursorHandleCCMP->CursorParams.leftMargin   = cursorConfigParam->leftMargin;
                cursorHandleCCMP->CursorParams.width        = cursorConfigParam->width;
                cursorHandleCCMP->CursorParams.height       = cursorConfigParam->height;
                cursorHandleCCMP->CursorParams.topMargin    = cursorConfigParam->topMargin;
                result                                  = DDC_VPBE_SOK;
        }

    }
    return(result);
}
