/******************************************************************************
**+-------------------------------------------------------------------------+**
**|                            ****                                         |**
**|                            ****                                         |**
**|                            ******o***                                   |**
**|                      ********_///_****                                  |**
**|                      ***** /_//_/ ****                                  |**
**|                       ** ** (__/ ****                                   |**
**|                           *********                                     |**
**|                            ****                                         |**
**|                            ***                                          |**
**|                                                                         |**
**|         Copyright (c) 2006-2010 Texas Instruments Incorporated          |**
**|                        ALL RIGHTS RESERVED                              |**
**|                                                                         |**
**| Permission is hereby granted to licensees of Texas Instruments          |**
**| Incorporated (TI) products to use this computer program for the sole    |**
**| purpose of implementing a licensee product based on TI products.        |**
**| No other rights to reproduce, use, or disseminate this computer         |**
**| program, whether in part or in whole, are granted.                      |**
**|                                                                         |**
**| TI makes no representation or warranties with respect to the            |**
**| performance of this computer program, and specifically disclaims        |**
**| any responsibility for any damages, special or consequential,           |**
**| connected with the use of this program.                                 |**
**|                                                                         |**
**+-------------------------------------------------------------------------+**
******************************************************************************/

/**
 *  \file   ddc_vpbeOsd.c
 *
 *  \brief  vpbe implementation
 *
 *  This file contains the implementation of the vpss driver to utilize the
 *  serivces of the vpbe device driver.
 *
 *  (C) Copyright 2010, Texas Instruments, Inc
 *
 *  \note       Set tabstop to 4 (:se ts=4) while viewing this file in an
 *              editor
 *
 *  \author     Maulik Desai
 *
 *  \version    1.0     Created
 */

/******************************************************************************
                            Header File Inclusion
******************************************************************************/
#include <ti/sdo/pspdrivers/common/psp_common.h>
#include <ti/sdo/pspdrivers/drivers/vpbe/psp_vpbe.h>
#include <ti/sdo/pspdrivers/drivers/vpbe/src/ddc_vpbe.h>
#include <ti/sdo/pspdrivers/drivers/vpbe/src/ddc_vpbeOsd.h>
#include <ti/sdo/pspdrivers/drivers/vpbe/src/llc_vpbeOsd.h>

/******************************************************************************
                                    Functions
******************************************************************************/
/**
 *  \brief  Configure the OSD planes
**/
DDC_VPBEStatus DDC_VPBEConfigOsdParams(DDC_VPBEOsdObject* osdHandleCO,Ptr params)
{
    PSP_VPBEOsdConfigParams  *osdConfigParams        = NULL;
    DDC_VPBEOsdObject        *otherVideoPlaneHandle  = NULL;
    PSP_VPBE_Id osdId                                = PSP_VPBE_INVALID_ID;
    DDC_VPBEStatus result                            = DDC_VPBE_E_FAIL;
    FVID_bitsPerPixel planeBpp;
    FVID_colorFormat  planeCF;
    FVID_FieldFrame   planeMode;
    /*check the parameters not NULL */
    if((NULL != params) && (NULL != osdHandleCO))
    {
        osdConfigParams                 = (PSP_VPBEOsdConfigParams * )params;
        planeMode                       = osdConfigParams->ffMode;
        osdId                           = DDC_VPBEGetChannelId(osdHandleCO);
        osdHandleCO->OsdParams.appCallback = osdConfigParams->appCallback;
        osdHandleCO->OsdParams.segId       = osdConfigParams->segId;
    }
    if(osdId != PSP_VPBE_INVALID_ID)
    {
        LLC_setOsdDisplayOff(osdId,osdHandleCO->OsdRegs);
        /*Check planeMode is FRAME Mode */
        if(FVID_FRAME_MODE == planeMode) /* Interlaced */
        {
            LLC_setOsdModeInterlaced(osdId,osdHandleCO->OsdRegs);
            osdHandleCO->OsdParams.ffMode = planeMode;
            result = DDC_VPBE_SOK;
        }
        else if(FVID_FIELD_MODE == planeMode)
        {
            LLC_setOsdModeProgressive(osdId,osdHandleCO->OsdRegs);
            osdHandleCO->OsdParams.ffMode = planeMode;
            result = DDC_VPBE_SOK;
        }
        else
        {
            result = DDC_VPBE_E_FAIL;
        }
        /*Configure the Window Boundary Params */
        if(DDC_VPBE_SOK != DDC_VPBEConfigWindowBoundary(osdHandleCO,osdConfigParams))
        {
            result = DDC_VPBE_E_FAIL;
        }
        if((0 == osdConfigParams->pitch)||((osdConfigParams->pitch % 32u)!=0))
        {
                result = DDC_VPBE_INVALID_PARAM;
        }
        else
        {
            osdHandleCO->OsdParams.pitch = osdConfigParams->pitch;
        }
    }

    if(DDC_VPBE_SOK == result)
    {
        switch(osdId)
        {
            case PSP_VPBE_VIDEO_0:
            case PSP_VPBE_VIDEO_1:
            {
                    planeBpp = osdConfigParams->bitsPerPixel;
                    planeCF  = osdConfigParams ->colorFormat;

                    osdHandleCO->OsdParams.bitsPerPixel = planeBpp;
                    osdHandleCO->OsdParams.colorFormat  = planeCF;
                    /* Select the colorformat */
                    if(FVID_YCbCr422_INTERLEAVED == planeCF)
                    {
                        LLC_setVidChromaOrderYCbCr(osdId,osdHandleCO->OsdRegs);
                        result = DDC_VPBE_SOK;
                    }
                    else if(FVID_YCrCb422_INTERLEAVED == planeCF)
                    {
                        LLC_setVidChromaOrderYCrCb(osdId,osdHandleCO->OsdRegs);
                        result = DDC_VPBE_SOK;
                    }

                    else if(FVID_RGB_888_INTERLEAVED == planeCF)
                    {
                        /* If colorformat is RGG888 then check other plane */
                        /* One VIDEO plane can be in RGB888 mode at a time */
                        switch(osdId)
                        {
                            case PSP_VPBE_VIDEO_0:
                            {
                                otherVideoPlaneHandle = DDC_VPBEGetChannelHandle(PSP_VPBE_VIDEO_1);
                            }
                            break;
                            case PSP_VPBE_VIDEO_1:
                            {
                                otherVideoPlaneHandle = DDC_VPBEGetChannelHandle(PSP_VPBE_VIDEO_0);
                            }
                            break;
                            default:
                            break;
                        }
                        if((NULL != otherVideoPlaneHandle) &&
                           (FVID_RGB_888_INTERLEAVED != otherVideoPlaneHandle->OsdParams.colorFormat))
                        {
                            LLC_setVidColorFormatRGB888(osdId,osdHandleCO->OsdRegs);
                            LLC_setRGB888ModeEnable(osdId,osdHandleCO->OsdRegs);
                            result = DDC_VPBE_SOK;
                        }
                        else
                        {
                            result = DDC_VPBE_E_FAIL;
                        }
                    }
                    else
                    {
                        result = DDC_VPBE_E_FAIL;
                    }
            }
            break;
            case PSP_VPBE_OSD_0:
            case PSP_VPBE_OSD_1:
            {
                    planeBpp  = osdConfigParams->bitsPerPixel;
                    planeCF   = osdConfigParams->colorFormat;

                    osdHandleCO->OsdParams.bitsPerPixel     = planeBpp;
                    osdHandleCO->OsdParams.colorFormat      = planeCF;

                    switch(planeCF)
                    {
                        case FVID_CLUT_INDEXED:
                        {
                            LLC_setOSDWinColorFormatBMPLUTMode(osdId,osdHandleCO->OsdRegs);
                            LLC_setOSDWinNORMALMode(osdId,osdHandleCO->OsdRegs);
                            if(FVID_BPP_BITS1 == planeBpp)
                            {
                                LLC_setOSDWinPixelBitWidth1Bit(osdId,osdHandleCO->OsdRegs);
                            }
                            else if(FVID_BPP_BITS2 == planeBpp)
                            {
                                LLC_setOSDWinPixelBitWidth2Bit(osdId,osdHandleCO->OsdRegs);
                            }
                            else if(FVID_BPP_BITS4 == planeBpp)
                            {
                                LLC_setOSDWinPixelBitWidth4Bit(osdId,osdHandleCO->OsdRegs);
                            }
                            else if(FVID_BPP_BITS8 == planeBpp)
                            {
                                LLC_setOSDWinPixelBitWidth8Bit(osdId,osdHandleCO->OsdRegs);
                            }
                            else
                            {
                                result = DDC_VPBE_E_FAIL;
                            }
                        }
                        break;
                        case FVID_RGB565_INTERLEAVED:
                        {
                            LLC_setOSDWinNORMALMode(osdId,osdHandleCO->OsdRegs);
                            LLC_setOSDWinColorFormatRGB16(osdId,osdHandleCO->OsdRegs);
                        }
                        break;
                        case FVID_DVD_MODE:
                        {
                            LLC_setOSDWinDVDMode(osdId,osdHandleCO->OsdRegs);
                            LLC_setOSDWinPixelBitWidth8Bit(osdId,osdHandleCO->OsdRegs);
                        }
                        break;
                        case FVID_ATTRIBUTE:
                        {
                            if(osdId == PSP_VPBE_OSD_1)
                            {
                                LLC_setOSDWinPixelBitWidth8Bit(osdId,osdHandleCO->OsdRegs);
                                LLC_setOSDWin1AttrModeEnable(osdHandleCO->OsdRegs);
                            }
                            else
                            {
                                result = DDC_VPBE_E_FAIL;
                            }
                        }
                        break;
                        default:
                        {
                            result = DDC_VPBE_E_FAIL;
                        }
                        break;
                    }
            }
            break;
            default:
            break;
        }
    }
    return result;
}
/**
 *  \brief  Configure the Blending Params
**/
DDC_VPBEStatus DDC_VPBEConfigBlending(Ptr handleCB, Ptr paramsCB)
{
    PSP_VPBEOsdConfigParams *blendConfig        = NULL;
    DDC_VPBEOsdObject       *vpbeOsdHandleCB    = NULL;
    DDC_VPBEStatus           resultCB           =  DDC_VPBE_E_FAIL;
    PSP_VPBE_Id              idCB               =  PSP_VPBE_INVALID_ID;
    Uint32 blendingRatioCB                      =  0;

    /*Check the Parameters not NULL */
    if((NULL == handleCB) && (NULL == paramsCB))
    {
        resultCB = DDC_VPBE_INVALID_PARAM;
    }
    else
    {
        blendConfig     = (PSP_VPBEOsdConfigParams*)paramsCB;
        vpbeOsdHandleCB = (DDC_VPBEOsdObject *)handleCB;
        /*Get the OSD planes Channel Id */
        idCB = DDC_VPBEGetChannelId(handleCB);
        /*Blending occurs in OSD-0 and OSD-1 planes */
        /*validate the OSD id */
        if((PSP_VPBE_OSD_0 == idCB) || ((PSP_VPBE_OSD_1 == idCB)&&(FVID_ATTRIBUTE != vpbeOsdHandleCB->OsdParams.colorFormat)))
        {
            blendingRatioCB = (blendConfig->blending & (0x0007u));
            LLC_setOSDWinBlendingRatio(idCB, vpbeOsdHandleCB->OsdRegs, blendingRatioCB);
            vpbeOsdHandleCB->OsdParams.blending = (PSP_VPBEBlendingFactor)blendingRatioCB;
            resultCB = DDC_VPBE_SOK;
        }
        else if((FVID_ATTRIBUTE == vpbeOsdHandleCB->OsdParams.colorFormat))
        {
            resultCB = DDC_VPBE_SOK;
        }
        else
        {
            resultCB = DDC_VPBE_E_FAIL;
        }
    }
    return(resultCB);
}
/**
  * \brief  Configure the Transparency Params
**/
DDC_VPBEStatus DDC_VPBEConfigTransparency(Ptr handleCT, Ptr paramsCT)
{
    DDC_VPBEOsdObject       * vpbeOsdHandleCT   = NULL ;
    PSP_VPBEOsdConfigParams * transpCT          = NULL ;
    PSP_VPBE_Id               idCT              = PSP_VPBE_INVALID_ID;
    DDC_VPBEStatus            resultCT          = DDC_VPBE_E_FAIL;

    /* Check the Parameters not NULL */
    if((NULL == handleCT) || (NULL == paramsCT))
    {
        resultCT = DDC_VPBE_E_FAIL;
    }
    else
    {
        vpbeOsdHandleCT = (DDC_VPBEOsdObject * )handleCT;
        transpCT        = (PSP_VPBEOsdConfigParams * )paramsCT;
        /*Get the Channel Handle Id */
        idCT            = DDC_VPBEGetChannelId(handleCT);
        /* Transparency is valid for OSD-0 and OSD-1 planes */
        /* Validate the OSD plane Id */
        if((PSP_VPBE_OSD_0 == idCT) || (PSP_VPBE_OSD_1 == idCT))
        {
            if(TRUE == transpCT->transparency)
            {
                LLC_setOSDWinTransparencyColour(idCT, vpbeOsdHandleCT->OsdRegs,transpCT->transparencyColor);
                LLC_setOSDWinTransparencyEnable(idCT, vpbeOsdHandleCT->OsdRegs);

                vpbeOsdHandleCT->OsdParams.transparency     = transpCT->transparency;
                vpbeOsdHandleCT->OsdParams.transparencyColor    = transpCT->transparencyColor;
                resultCT = DDC_VPBE_SOK;
            }
            else
            {
                LLC_setOSDWinTransparencyDisable(idCT, vpbeOsdHandleCT->OsdRegs);
                resultCT = DDC_VPBE_SOK;
             }
        }
        else
        {
            resultCT = DDC_VPBE_E_FAIL;
        }
    }
    return(resultCT);
}

/**
  * \brief  Programming the MAIN CLUT
**/
DDC_VPBEStatus DDC_VPBEConfigMainCLUT(DDC_VPBEOsdObject* const osdHandleCMC, Ptr paramsCMC)
{
    PSP_VPBEMainClutParams * mainCLUTParams = NULL;
    DDC_VPBEStatus resultCMC                =  DDC_VPBE_E_FAIL;
    Uint32  index                           =  0;

    Uint32 loop;
    /*Check the Parameters not NULL */
    if((NULL == osdHandleCMC)&&(NULL == paramsCMC))
    {
        resultCMC   = DDC_VPBE_E_FAIL;
    }
    else
    {
        mainCLUTParams  =   (PSP_VPBEMainClutParams *)paramsCMC;
            if(PSP_VPBE_RAMWR_DVD_MODE == mainCLUTParams->mode)
            {
            LLC_setOSDWinRAMWRMode(mainCLUTParams->mode,osdHandleCMC->OsdRegs);
                for (index = 0;index < (PSP_VPBE_MAX_MAIN_CLUT_ENTRIES/8u) ; index++)
                {
                    for(loop =0 ;loop<8u;loop++)
                    {
                        LLC_setClutEntry_Y(osdHandleCMC->OsdRegs ,mainCLUTParams->MainClut_val[(8*index)+loop].Y);
                        LLC_setClutEntry_Cb(osdHandleCMC->OsdRegs,mainCLUTParams->MainClut_val[(8*index)+loop].Cb);
                        LLC_setClutEntry_Cr(osdHandleCMC->OsdRegs,mainCLUTParams->MainClut_val[(8*index)+loop].Cr);
                        LLC_setClutEntry_Addr(osdHandleCMC->OsdRegs,index);
                    }
                    while(1u==LLC_getOSDWinCPBSYStatus(osdHandleCMC->OsdRegs))
                    {

                    }
                }
                resultCMC = DDC_VPBE_SOK;
            }
            else
            {
                LLC_setOSDWinRAMWRMode(mainCLUTParams->mode,osdHandleCMC->OsdRegs);
                for (index = 0;index < PSP_VPBE_MAX_MAIN_CLUT_ENTRIES ; index++)
                {
                    while(1u==LLC_getOSDWinCPBSYStatus(osdHandleCMC->OsdRegs))
                    {

                    }
                    LLC_setClutEntry_Y(osdHandleCMC->OsdRegs,mainCLUTParams->MainClut_val[index].Y);
                    LLC_setClutEntry_Cb(osdHandleCMC->OsdRegs,mainCLUTParams->MainClut_val[index].Cb);
                    LLC_setClutEntry_Cr(osdHandleCMC->OsdRegs,mainCLUTParams->MainClut_val[index].Cr);
                    LLC_setClutEntry_Addr(osdHandleCMC->OsdRegs,index);
                }
                resultCMC = DDC_VPBE_SOK;
            }
        }
    return(resultCMC);
}

/*-----------------------------------------------------------------------------
                        Programming the BMP CLUT
-----------------------------------------------------------------------------*/
/**
  * \brief  Programming the BMP CLUT
**/
DDC_VPBEStatus DDC_VPBEConfigBMPCLUT(DDC_VPBEOsdObject* const osdHandleCBC,Ptr paramsCBC)
{
    PSP_VPBEBMPClutParams * BMPCLUTParams   = NULL;
    PSP_VPBE_Id osdIdCBC                    = PSP_VPBE_INVALID_ID;
    DDC_VPBEStatus resultCBC                = DDC_VPBE_E_FAIL;

    /*Check the Parameters if NULL */
    if((NULL == osdHandleCBC) && (NULL == paramsCBC))
    {
        resultCBC   = DDC_VPBE_E_FAIL;
    }
    else
    {
        BMPCLUTParams       =   (PSP_VPBEBMPClutParams * )paramsCBC;
        /* Get the Channel Handle Id */
        osdIdCBC = DDC_VPBEGetChannelId(osdHandleCBC);

        LLC_setOSDWinCLUTSelectRAM(osdIdCBC,osdHandleCBC->OsdRegs);
        /* Validate the OSD planes Id(OSD-0 and OSD-1) */
        if((PSP_VPBE_OSD_0 == osdIdCBC) || (PSP_VPBE_OSD_1 == osdIdCBC))
        {
            LLC_setBMPCLUTEntry(osdIdCBC,osdHandleCBC->OsdRegs,(Uint8 *)&BMPCLUTParams->BMPClut_val[0]);
            resultCBC = DDC_VPBE_SOK;
        }
        else
        {
            resultCBC = DDC_VPBE_E_FAIL;
        }
    }
    return(resultCBC);
}
