/******************************************************************************
**+-------------------------------------------------------------------------+**
**|                            ****                                         |**
**|                            ****                                         |**
**|                            ******o***                                   |**
**|                      ********_///_****                                  |**
**|                      ***** /_//_/ ****                                  |**
**|                       ** ** (__/ ****                                   |**
**|                           *********                                     |**
**|                            ****                                         |**
**|                            ***                                          |**
**|                                                                         |**
**|         Copyright (c) 2006-2010 Texas Instruments Incorporated          |**
**|                        ALL RIGHTS RESERVED                              |**
**|                                                                         |**
**| Permission is hereby granted to licensees of Texas Instruments          |**
**| Incorporated (TI) products to use this computer program for the sole    |**
**| purpose of implementing a licensee product based on TI products.        |**
**| No other rights to reproduce, use, or disseminate this computer         |**
**| program, whether in part or in whole, are granted.                      |**
**|                                                                         |**
**| TI makes no representation or warranties with respect to the            |**
**| performance of this computer program, and specifically disclaims        |**
**| any responsibility for any damages, special or consequential,           |**
**| connected with the use of this program.                                 |**
**|                                                                         |**
**+-------------------------------------------------------------------------+**
******************************************************************************/

/**
 *  \file   ddc_vpbeOsd.h
 *
 *  \brief  VPBE Osd related functionality dependencies
 *
 *  This file contains the Osd core level functionalities
 *
 *  (C) Copyright 2010, Texas Instruments, Inc
 *
 *  \note       Set tabstop to 4 (:se ts=4) while viewing this file in an
 *              editor
 *
 *  \author     Maulik Desai
 *
 *  \version    0.1     Created
 */

#ifndef _DDC_VPBEOSD_H
#define _DDC_VPBEOSD_H

#ifdef __cplusplus
extern "C" {
#endif

/******************************************************************************
                                 Functions
******************************************************************************/

/**
  * \brief  This function configures the OSD planes(VIDEO/OSD) params
  *
  * \param  osdHandleCO [IN]        handle for OSD plane
  * \param  params      [IN]        handle for OSD params value
  *
  * \returns                        Pass or fail status
  */
DDC_VPBEStatus DDC_VPBEConfigOsdParams(DDC_VPBEOsdObject* osdHandleCO,Ptr params);


/**
  * \brief  This function configures the blending params
  *
  * \param  handleCB    [IN]        handle for blending
  * \param  paramsCB    [IN]        handle for blending params
  *
  * \returns                        pass or fail status
  */
DDC_VPBEStatus DDC_VPBEConfigBlending(Ptr handleCB, Ptr paramsCB);

/**
 *  \brief  This function is used to configure the Transparency functionality
 *          in OSD(On Screen Display) Plane.Each plane having two instance ID.
 *
 *  This function is used to configure the Transparency parameters.This is
 *  called by IOCTL functuion.
 *
 *  This function returns the SUCCESS/FAILURE status of the operation.
 *
 *  \param   handleCT   [IN]        Transparency handle for osd plane.
 *  \param   paramsCT   [IN]        Transparency Params.
 *
 *  \Returns                        SUCCESS/FAILURE
 */
DDC_VPBEStatus DDC_VPBEConfigTransparency(Ptr handleCT, Ptr paramsCT);

/**
  * \brief This functions configures main CLUT (256 entries)
  *
  * \param  osdHandleCMC [IN]       handle for OSD plane
  * \param  paramsCMC    [IN]       handle for params
  *
  * \returns                        pass or fail status
  */
DDC_VPBEStatus DDC_VPBEConfigMainCLUT(DDC_VPBEOsdObject* const osdHandleCMC, Ptr paramsCMC);

/**
  * \brief This functions configures BMP CLUT (16 entries)
  *
  * \param  osdHandleCBC [IN]       handle for OSD plane
  * \param  paramsCBC    [IN]       handle for params
  *
  * \returns                        pass or fail status
  */
DDC_VPBEStatus DDC_VPBEConfigBMPCLUT(DDC_VPBEOsdObject* const osdHandleCBC,Ptr paramsCBC);

#ifdef __cplusplus
}
#endif

#endif  /*_DDC_VPBEOSD_H */
