/******************************************************************************
**+-------------------------------------------------------------------------+**
**|                            ****                                         |**
**|                            ****                                         |**
**|                            ******o***                                   |**
**|                      ********_///_****                                  |**
**|                      ***** /_//_/ ****                                  |**
**|                       ** ** (__/ ****                                   |**
**|                           *********                                     |**
**|                            ****                                         |**
**|                            ***                                          |**
**|                                                                         |**
**|         Copyright (c) 2006-2010 Texas Instruments Incorporated          |**
**|                        ALL RIGHTS RESERVED                              |**
**|                                                                         |**
**| Permission is hereby granted to licensees of Texas Instruments          |**
**| Incorporated (TI) products to use this computer program for the sole    |**
**| purpose of implementing a licensee product based on TI products.        |**
**| No other rights to reproduce, use, or disseminate this computer         |**
**| program, whether in part or in whole, are granted.                      |**
**|                                                                         |**
**| TI makes no representation or warranties with respect to the            |**
**| performance of this computer program, and specifically disclaims        |**
**| any responsibility for any damages, special or consequential,           |**
**| connected with the use of this program.                                 |**
**|                                                                         |**
**+-------------------------------------------------------------------------+**
******************************************************************************/

/**
 *  \file   ddc_vpbeVenc.c
 *
 *  \brief  vpbe implementation
 *
 *  This file contains the implementation of the vpss driver to utilize the
 *  serivces of the vpss device driver.
 *
 *  (C) Copyright 2010, Texas Instruments, Inc
 *
 *  \note       Set tabstop to 4 (:se ts=4) while viewing this file in an
 *              editor
 *
 *  \author     Maulik Desai
 *
 *  \version    1.0     Created
 */

/******************************************************************************
                            Header File Inclusion
******************************************************************************/
#include <std.h>
#include <ti/sdo/pspdrivers/drivers/vpbe/psp_vpbe.h>
#include <ti/sdo/pspdrivers/drivers/vpbe/src/ddc_vpbe.h>
#include <ti/sdo/pspdrivers/drivers/vpbe/src/ddc_vpbeVenc.h>
#include <ti/sdo/pspdrivers/drivers/vpbe/src/llc_vpbeOsd.h>
#include <ti/sdo/pspdrivers/drivers/vpbe/src/llc_vpbeVenc.h>

/******************************************************************************
                                    Functions
******************************************************************************/
/**
 *  \brief  Configure the VENC Params
**/
DDC_VPBEStatus DDC_VPBEConfigVencParams(DDC_VPBEVencObject* const vencHandleCVMP,Ptr params)
{
    PSP_VPBEVencConfigParams *vencConfigParams     = NULL;
    DDC_VPBEDeviceObject     *vpbeDeviceHandleCVMP = NULL;
    DDC_VPBEStatus resultCVMP                      = DDC_VPBE_SOK;

    vpbeDeviceHandleCVMP = (DDC_VPBEDeviceObject * )DDC_VPBEGetDeviceHandle();

    if(((NULL == vencHandleCVMP) || (NULL == params))|| (NULL == vpbeDeviceHandleCVMP))
    {
        resultCVMP = DDC_VPBE_INVALID_PARAM;
    }
    else
    {
        vencConfigParams     = (PSP_VPBEVencConfigParams * )params;
        LLC_setVencDisable(vencHandleCVMP->VencRegs);

        switch(vencConfigParams->displayStandard)
        {
            case PSP_VPBE_DISPLAY_NTSC_INTERLACED_COMPOSITE:
            {
                LLC_setDisplayStartPosition(vpbeDeviceHandleCVMP->osd[0].OsdRegs,0x7Au,0x12u);

                LLC_setVideoOutputTYP_NTSC(vencHandleCVMP->VencRegs);
                LLC_setVideoOutputSDTVMode(vencHandleCVMP->VencRegs);
                LLC_setVencScanModeInterlaced(vencHandleCVMP->VencRegs);
                LLC_setDigitalVidOutModeYcc8(vencHandleCVMP->VencRegs);
                LLC_setREC656Mode(vencHandleCVMP->VencRegs);
                LLC_setOSDClockControl0(vencHandleCVMP->VencRegs,1u); /* Default */
                LLC_setOSDClockControl1(vencHandleCVMP->VencRegs,2u); /* Default */
                LLC_setEnableCompositeOutput(vencHandleCVMP->VencRegs);

                /* Composite output; Select all DACs */
                LLC_setDacBOutVidFormatCVBS(vencHandleCVMP->VencRegs);
                LLC_setDacCOutVidFormatCVBS(vencHandleCVMP->VencRegs);
                LLC_setDacDOutVidFormatCVBS(vencHandleCVMP->VencRegs);

                LLC_setDacBNormalMode(vencHandleCVMP->VencRegs);
                LLC_setDacCNormalMode(vencHandleCVMP->VencRegs);
                LLC_setDacDNormalMode(vencHandleCVMP->VencRegs);


                LLC_setEnableCompositeOutput(vencHandleCVMP->VencRegs);
            }
            break;
            case PSP_VPBE_DISPLAY_NTSC_INTERLACED_S_VIDEO:
            {
                LLC_setDisplayStartPosition(vpbeDeviceHandleCVMP->osd[0].OsdRegs,
                                            0x7Au,0x12u);
                LLC_setVideoOutputTYP_NTSC(vencHandleCVMP->VencRegs);
                LLC_setVideoOutputSDTVMode(vencHandleCVMP->VencRegs);
                LLC_setVencScanModeInterlaced(vencHandleCVMP->VencRegs);
                LLC_setDigitalVidOutModeYcc8(vencHandleCVMP->VencRegs);
                LLC_setREC656Mode(vencHandleCVMP->VencRegs);
                LLC_setOSDClockControl0(vencHandleCVMP->VencRegs,1u); /* Default */
                LLC_setOSDClockControl1(vencHandleCVMP->VencRegs,2u); /* Default */

                /* S-Video Output; DAC B: S-Video Y, DAC C: S-Video C*/
                LLC_setDac1OutVidFormatSVidY(vencHandleCVMP->VencRegs);
                LLC_setDac2OutVidFormatSVidC(vencHandleCVMP->VencRegs);

                /*Enable DAC B and C */
                LLC_setDacBNormalMode(vencHandleCVMP->VencRegs);
                LLC_setDacCNormalMode(vencHandleCVMP->VencRegs);

                LLC_setEnableCompositeOutput(vencHandleCVMP->VencRegs);
            }
            break;
            case PSP_VPBE_DISPLAY_NTSC_INTERLACED_COMPONENT:
            {
                LLC_setDisplayStartPosition(vpbeDeviceHandleCVMP->osd[0].OsdRegs,
                                            0x7Au,0x12u);
                LLC_setVideoOutputTYP_NTSC(vencHandleCVMP->VencRegs);
                LLC_setVideoOutputSDTVMode(vencHandleCVMP->VencRegs);
                LLC_setVencScanModeInterlaced(vencHandleCVMP->VencRegs);
                LLC_setDigitalVidOutModeYcc8(vencHandleCVMP->VencRegs);
                LLC_setREC656Mode(vencHandleCVMP->VencRegs);
                LLC_setOSDClockControl0(vencHandleCVMP->VencRegs,1u); /* Default */
                LLC_setOSDClockControl1(vencHandleCVMP->VencRegs,2u); /* Default */

                /* Component output;  DAC B->Y, DAC C->Pb, DAC D: Pr*/
                LLC_setDacBOutVidFormatCompY (vencHandleCVMP->VencRegs);
                LLC_setDacCOutVidFormatCompPb(vencHandleCVMP->VencRegs);
                LLC_setDacDOutVidFormatCompPr(vencHandleCVMP->VencRegs);

                /*Enable DAC B ,C and D*/
                LLC_setDacBNormalMode(vencHandleCVMP->VencRegs);
                LLC_setDacCNormalMode(vencHandleCVMP->VencRegs);
                LLC_setDacDNormalMode(vencHandleCVMP->VencRegs);

                LLC_setEnableCompositeOutput(vencHandleCVMP->VencRegs);
            }
            break;
            case PSP_VPBE_DISPLAY_NTSC_PROGRESSIVE_COMPONENT:
            {
                LLC_setDisplayStartPosition(vpbeDeviceHandleCVMP->osd[0].OsdRegs,
                                            0x7Au,0x22u);
                LLC_setVideoOutputTYP_525p_HDTV(vencHandleCVMP->VencRegs);
                LLC_setVideoOutputHDTVMode(vencHandleCVMP->VencRegs);
                LLC_setDigitalVidOutModeYcc8(vencHandleCVMP->VencRegs);
                LLC_setREC656Mode(vencHandleCVMP->VencRegs);
                LLC_setOSDClockControl0(vencHandleCVMP->VencRegs,0); /* For HDTV Clk Pattern Bit Width == 0 */
                LLC_setOSDClockControl1(vencHandleCVMP->VencRegs,1u); /* For HDTV Clk Pattern == 1 */

                /* Component output; DAC A->Y, DAC B->Pb, DAC C: Pr*/
                /* Component output;  DAC B->Y, DAC C->Pb, DAC D: Pr*/
                LLC_setDacBOutVidFormatCompY (vencHandleCVMP->VencRegs);
                LLC_setDacCOutVidFormatCompPb(vencHandleCVMP->VencRegs);
                LLC_setDacDOutVidFormatCompPr(vencHandleCVMP->VencRegs);

                /*Enable DAC B ,C and D*/
                LLC_setDacBNormalMode(vencHandleCVMP->VencRegs);
                LLC_setDacCNormalMode(vencHandleCVMP->VencRegs);
                LLC_setDacDNormalMode(vencHandleCVMP->VencRegs);

                LLC_setEnableCompositeOutput(vencHandleCVMP->VencRegs);
            }
            break;
            case PSP_VPBE_DISPLAY_PAL_INTERLACED_COMPOSITE:
            {
                LLC_setDisplayStartPosition(vpbeDeviceHandleCVMP->osd[0].OsdRegs,
                                            0x84u,0x16u);
                LLC_setVideoOutputTYP_PAL(vencHandleCVMP->VencRegs);
                LLC_setVideoOutputSDTVMode(vencHandleCVMP->VencRegs);
                LLC_setVencScanModeInterlaced(vencHandleCVMP->VencRegs);
                LLC_setDigitalVidOutModeYcc8(vencHandleCVMP->VencRegs);
                LLC_setREC656Mode(vencHandleCVMP->VencRegs);
                LLC_setOSDClockControl0(vencHandleCVMP->VencRegs,1u); /* Default */
                LLC_setOSDClockControl1(vencHandleCVMP->VencRegs,2u); /* Default */

                /* Composite output; Select all DACs */
                LLC_setDacBOutVidFormatCVBS(vencHandleCVMP->VencRegs);
                LLC_setDacCOutVidFormatCVBS(vencHandleCVMP->VencRegs);
                LLC_setDacDOutVidFormatCVBS(vencHandleCVMP->VencRegs);

                LLC_setDacBNormalMode(vencHandleCVMP->VencRegs);
                LLC_setDacCNormalMode(vencHandleCVMP->VencRegs);
                LLC_setDacDNormalMode(vencHandleCVMP->VencRegs);

                LLC_setEnableCompositeOutput(vencHandleCVMP->VencRegs);
            }
            break;
            case PSP_VPBE_DISPLAY_PAL_INTERLACED_S_VIDEO:
            {
                LLC_setDisplayStartPosition(vpbeDeviceHandleCVMP->osd[0].OsdRegs,
                                            0x84u,0x16u);
                LLC_setVideoOutputTYP_PAL(vencHandleCVMP->VencRegs);
                LLC_setVideoOutputSDTVMode(vencHandleCVMP->VencRegs);
                LLC_setVencScanModeInterlaced(vencHandleCVMP->VencRegs);
                LLC_setDigitalVidOutModeYcc8(vencHandleCVMP->VencRegs);
                LLC_setREC656Mode(vencHandleCVMP->VencRegs);
                LLC_setOSDClockControl0(vencHandleCVMP->VencRegs,1u); /* Default */
                LLC_setOSDClockControl1(vencHandleCVMP->VencRegs,2u); /* Default */

                /* S-Video Output; DAC B: S-Video Y, DAC C: S-Video C*/
                LLC_setDac1OutVidFormatSVidY(vencHandleCVMP->VencRegs);
                LLC_setDac2OutVidFormatSVidC(vencHandleCVMP->VencRegs);

                /*Enable DACa B and C */
                LLC_setDacBNormalMode(vencHandleCVMP->VencRegs);
                LLC_setDacCNormalMode(vencHandleCVMP->VencRegs);

                LLC_setEnableCompositeOutput(vencHandleCVMP->VencRegs);
            }
            break;
            case PSP_VPBE_DISPLAY_PAL_INTERLACED_COMPONENT:
            {
                LLC_setDisplayStartPosition(vpbeDeviceHandleCVMP->osd[0].OsdRegs,
                                            0x84u,0x16u);
                LLC_setVideoOutputTYP_PAL(vencHandleCVMP->VencRegs);
                LLC_setVideoOutputSDTVMode(vencHandleCVMP->VencRegs);
                LLC_setVencScanModeInterlaced(vencHandleCVMP->VencRegs);
                LLC_setDigitalVidOutModeYcc8(vencHandleCVMP->VencRegs);
                LLC_setREC656Mode(vencHandleCVMP->VencRegs);
                LLC_setOSDClockControl0(vencHandleCVMP->VencRegs,1u); /* Default */
                LLC_setOSDClockControl1(vencHandleCVMP->VencRegs,2u); /* Default */

                /* Component output;  DAC B->Y, DAC C->Pb, DAC D: Pr*/
                LLC_setDacBOutVidFormatCompY (vencHandleCVMP->VencRegs);
                LLC_setDacCOutVidFormatCompPb(vencHandleCVMP->VencRegs);
                LLC_setDacDOutVidFormatCompPr(vencHandleCVMP->VencRegs);

                /*Enable DAC B ,C and D*/
                LLC_setDacBNormalMode(vencHandleCVMP->VencRegs);
                LLC_setDacCNormalMode(vencHandleCVMP->VencRegs);
                LLC_setDacDNormalMode(vencHandleCVMP->VencRegs);

                LLC_setEnableCompositeOutput(vencHandleCVMP->VencRegs);
            }
            break;
            case PSP_VPBE_DISPLAY_PAL_PROGRESSIVE_COMPONENT:
            {
                LLC_setDisplayStartPosition(vpbeDeviceHandleCVMP->osd[0].OsdRegs,
                                            0x84u,0x22u);
                LLC_setVideoOutputTYP_625p_HDTV(vencHandleCVMP->VencRegs);
                LLC_setVideoOutputHDTVMode(vencHandleCVMP->VencRegs);
                LLC_setDigitalVidOutModeYcc8(vencHandleCVMP->VencRegs);
                LLC_setREC656Mode(vencHandleCVMP->VencRegs);
                LLC_setOSDClockControl0(vencHandleCVMP->VencRegs,0); /* For HDTV Clk Pattern Bit Width == 0 */
                LLC_setOSDClockControl1(vencHandleCVMP->VencRegs,1u); /* For HDTV Clk Pattern == 1 */

                /* Component output;  DAC B->Y, DAC C->Pb, DAC D: Pr*/
                LLC_setDacBOutVidFormatCompY (vencHandleCVMP->VencRegs);
                LLC_setDacCOutVidFormatCompPb(vencHandleCVMP->VencRegs);
                LLC_setDacDOutVidFormatCompPr(vencHandleCVMP->VencRegs);

                /*Enable DAC B ,C and D*/
                LLC_setDacBNormalMode(vencHandleCVMP->VencRegs);
                LLC_setDacCNormalMode(vencHandleCVMP->VencRegs);
                LLC_setDacDNormalMode(vencHandleCVMP->VencRegs);

                LLC_setEnableCompositeOutput(vencHandleCVMP->VencRegs);
            }
            break;
            case PSP_VPBE_DISPLAY_YCC16_DIGITAL_480P:
            {
                vencHandleCVMP->extVidEncFxn = &vencConfigParams->extVidEncFxn;
                if(NULL != vencHandleCVMP->extVidEncFxn->Open)
                {
                    vencHandleCVMP->extVidEncHandle   = vencHandleCVMP->extVidEncFxn->Open();
                    resultCVMP = DDC_VPBE_SOK;
                }
                else
                {
                    resultCVMP = DDC_VPBE_E_FAIL;
                }
                if(DDC_VPBE_SOK == resultCVMP)
                {
                    LLC_setDisplayStartPosition(vpbeDeviceHandleCVMP->osd[0].OsdRegs,0x80u,0x29u);

                    LLC_setLCDOutputON(vencHandleCVMP->VencRegs);
                    LLC_setLCDOutputPolarityActHigh(vencHandleCVMP->VencRegs);
                    /* NTSC/PAL timing */
                    LLC_setVideoTimingNTSCPAL(vencHandleCVMP->VencRegs);
                    /* SDTV enable */
                    LLC_setVideoOutputHDTVMode(vencHandleCVMP->VencRegs);
                    /*Progressive */
                    LLC_setVencScanModeProgressive(vencHandleCVMP->VencRegs);
                    /* Master Mode */
                    LLC_setMasterMode(vencHandleCVMP->VencRegs);
                    /*YCC16 mode enable*/
                    LLC_setDigitalVidOutModeYcc16(vencHandleCVMP->VencRegs);
                   /* VCLK Output Enable */
                    LLC_setEnableVCLKOutputEnable(vencHandleCVMP->VencRegs);
                    /* VCLK Pin Output Enable */
                    LLC_setEnableVCLKPinOutputEn(vencHandleCVMP->VencRegs);
                    /* Horz/Vert Sync I/o control */
                    LLC_setVencVDHDSyncDirOut(vencHandleCVMP->VencRegs);
                    /* Digital Data Out Enable */
                    LLC_setVencDataOut(vencHandleCVMP->VencRegs);
                    /* YC Direction -Output*/
                    LLC_setYCPin_DigitalVideoOutput(vencHandleCVMP->VencRegs);
                    /*Enable Vertical Sync */
                    LLC_setVencVDOutputEnable(vencHandleCVMP->VencRegs);
                    /* Enable Horz Sync */
                    LLC_setVencHDOutputEnable(vencHandleCVMP->VencRegs);
                    /* VSYNC Active High */
                    LLC_setVencVDSyncPolarityPos(vencHandleCVMP->VencRegs);
                    /* HSYNC Active low */
                    LLC_setVencHDSyncPolarityNeg(vencHandleCVMP->VencRegs);
                    /* HVALID */
                    LLC_setVencHorzValidData(vencHandleCVMP->VencRegs, HORZ_VALID_DATA);
                    /* VVALID */
                    LLC_setVencVertValidData(vencHandleCVMP->VencRegs, VERT_VALID_DATA);
                    /* Enable */
                    LLC_setDCLKPatternMode_Enable(vencHandleCVMP->VencRegs);
                    /* Valid bit Width */
                    LLC_setDCLKPatternBitWidth(vencHandleCVMP->VencRegs, 0u);
                    /* Clk Pattern */
                    LLC_setDCLKPattern(vencHandleCVMP->VencRegs, 1u);
                    /* OSD CLK */
                    LLC_setOSDClockControl0(vencHandleCVMP->VencRegs,0u); 
                    LLC_setOSDClockControl1(vencHandleCVMP->VencRegs,1u); 
                }
            }
            break;
            default:
            {
                resultCVMP = DDC_VPBE_E_FAIL;
            }
            break;
        }

        if(DDC_VPBE_SOK == resultCVMP)
        {
            LLC_setVencEnable(vencHandleCVMP->VencRegs);
            vencHandleCVMP->VencParams.displayStandard  = vencConfigParams->displayStandard;
        }
    }

    return(resultCVMP);
}
