/******************************************************************************
**+-------------------------------------------------------------------------+**
**|                            ****                                         |**
**|                            ****                                         |**
**|                            ******o***                                   |**
**|                      ********_///_****                                  |**
**|                      ***** /_//_/ ****                                  |**
**|                       ** ** (__/ ****                                   |**
**|                           *********                                     |**
**|                            ****                                         |**
**|                            ***                                          |**
**|                                                                         |**
**|         Copyright (c) 2006-2010 Texas Instruments Incorporated          |**
**|                        ALL RIGHTS RESERVED                              |**
**|                                                                         |**
**| Permission is hereby granted to licensees of Texas Instruments          |**
**| Incorporated (TI) products to use this computer program for the sole    |**
**| purpose of implementing a licensee product based on TI products.        |**
**| No other rights to reproduce, use, or disseminate this computer         |**
**| program, whether in part or in whole, are granted.                      |**
**|                                                                         |**
**| TI makes no representation or warranties with respect to the            |**
**| performance of this computer program, and specifically disclaims        |**
**| any responsibility for any damages, special or consequential,           |**
**| connected with the use of this program.                                 |**
**|                                                                         |**
**+-------------------------------------------------------------------------+**
******************************************************************************/

/**
 *  \file   llc_vpbeCursor.c
 *
 *  \brief  VPBE csl layer cursor Functions
 *
 *  This file contains the Implementation details of CSL layer functions
 *
 *  (C) Copyright 2010, Texas Instruments, Inc
 *
 *  \note       Set tabstop to 4 (:se ts=4) while viewing this file in an
 *              editor
 *
 *  \author     Maulik Desai
 *
 *  \version    0.1     Created
 */

/******************************************************************************
                            Header File Inclusion
******************************************************************************/
#include <ti/sdo/pspdrivers/common/psp_common.h>

#include <ti/sdo/pspdrivers/drivers/vpbe/src/llc_vpbeCursor.h>
#include <ti/sdo/pspdrivers/soc/dm6437/dsp/cslr_osd.h>

/******************************************************************************
                                Data-Structures
******************************************************************************/
/*-----------------------------------------------------------------------------
                    VENC CSL Overlay Register Structure Handle
-----------------------------------------------------------------------------*/
/**
  * \brief CSL Overlay Register Structure Handle
  */

static  CSL_OsdRegs     * cursorRegs;

/******************************************************************************
                                    Functions
******************************************************************************/
/**
  * \brief To set cursor enable
  *
  */
void LLC_setCursorEnable(Ptr llcRegisterBaseAddr)
{
    if(NULL!=llcRegisterBaseAddr)
    {
        cursorRegs = (CSL_OsdRegs * )llcRegisterBaseAddr;
        CSL_FINST(cursorRegs->RECTCUR,OSD_RECTCUR_RCACT,ON);
    }
}
/**
  * \brief To set cursor disable
  *
  */
void LLC_setCursorDisable(Ptr llcRegisterBaseAddr)
{

    if(NULL!=llcRegisterBaseAddr)
    {
        cursorRegs = (CSL_OsdRegs * )llcRegisterBaseAddr;
        CSL_FINST(cursorRegs->RECTCUR,OSD_RECTCUR_RCACT,OFF);
    }
}
/**
  * \brief To set cursor CLUT in RAM area
  *
  */
void LLC_setCursorCLUTSelectROM(Ptr llcRegisterBaseAddr)
{

    if(NULL!=llcRegisterBaseAddr)
    {
        cursorRegs = (CSL_OsdRegs * )llcRegisterBaseAddr;
        CSL_FINST(cursorRegs->RECTCUR,OSD_RECTCUR_CLUTSR,ROM_LUT);
    }
}

/**
  * \brief To set cursor CLUT in RAM area
  *
  */
void LLC_setCursorCLUTSelectRAM(Ptr llcRegisterBaseAddr)
{

    if(NULL!=llcRegisterBaseAddr)
    {
        cursorRegs = (CSL_OsdRegs * )llcRegisterBaseAddr;
        CSL_FINST(cursorRegs->RECTCUR,OSD_RECTCUR_CLUTSR,RAM_LUT);
    }
}

void LLC_setCursorROMTYPE(Ptr llcRegisterBaseAddr)
{
    if(NULL!=llcRegisterBaseAddr)
    {
        cursorRegs = (CSL_OsdRegs * )llcRegisterBaseAddr;
        CSL_FINST(cursorRegs->MISCCTL,OSD_MISCCTL_RSEL,CLUT0_DM270);
    }

}
/**
  * \brief To set cursor Vertical width
  *
  */
void LLC_setCursorVWidth(Ptr llcRegisterBaseAddr, Uint32 vWidth)
{

    if(NULL!=llcRegisterBaseAddr)
    {
        cursorRegs = (CSL_OsdRegs * )llcRegisterBaseAddr;
        CSL_FINS(cursorRegs->RECTCUR,OSD_RECTCUR_RCVW,vWidth);
    }
}


/**
  * \brief To set cursor horizontal width
  *
  */
void LLC_setCursorHWidth(Ptr llcRegisterBaseAddr, Uint32 hWidth)
{
    if(NULL!=llcRegisterBaseAddr)
    {
        cursorRegs = (CSL_OsdRegs * )llcRegisterBaseAddr;
        CSL_FINS(cursorRegs->RECTCUR,OSD_RECTCUR_RCHW,hWidth);
    }
}

/**
  * \brief To set cursor X position
  *
  */
void LLC_setCursorXPosition(Ptr llcRegisterBaseAddr, Uint xPosition)
{

    if(NULL!=llcRegisterBaseAddr)
    {
        cursorRegs = (CSL_OsdRegs * )llcRegisterBaseAddr;
        CSL_FINS(cursorRegs->CURXP,OSD_CURXP_RCSX,xPosition);
    }
}


/**
  * \brief To set cursor Y position
  *
  */
void LLC_setCursorYPosition(Ptr llcRegisterBaseAddr, Uint yPosition)
{
    if(NULL!=llcRegisterBaseAddr)
    {
        cursorRegs = (CSL_OsdRegs * )llcRegisterBaseAddr;
        CSL_FINS(cursorRegs->CURYP,OSD_CURYP_RCSY,yPosition);
    }
}


/**
  * \brief To set cursor X Size
  *
  */
void LLC_setCursorXSize(Ptr llcRegisterBaseAddr, Uint xSize)
{
    if(NULL!=llcRegisterBaseAddr)
    {
        cursorRegs = (CSL_OsdRegs * )llcRegisterBaseAddr;
        CSL_FINS(cursorRegs->CURXL,OSD_CURXL_RCSW,xSize);
    }
}


/**
  * \brief To set cursor Y Size
  *
  */
void LLC_setCursorYSize(Ptr llcRegisterBaseAddr, Uint ySize)
{
    if(NULL!=llcRegisterBaseAddr)
    {
        cursorRegs = (CSL_OsdRegs * )llcRegisterBaseAddr;
        CSL_FINS(cursorRegs->CURYL,OSD_CURYL_RCSH,ySize);
    }
}
