/******************************************************************************
**+-------------------------------------------------------------------------+**
**|                            ****                                         |**
**|                            ****                                         |**
**|                            ******o***                                   |**
**|                      ********_///_****                                  |**
**|                      ***** /_//_/ ****                                  |**
**|                       ** ** (__/ ****                                   |**
**|                           *********                                     |**
**|                            ****                                         |**
**|                            ***                                          |**
**|                                                                         |**
**|         Copyright (c) 2006-2010 Texas Instruments Incorporated          |**
**|                        ALL RIGHTS RESERVED                              |**
**|                                                                         |**
**| Permission is hereby granted to licensees of Texas Instruments          |**
**| Incorporated (TI) products to use this computer program for the sole    |**
**| purpose of implementing a licensee product based on TI products.        |**
**| No other rights to reproduce, use, or disseminate this computer         |**
**| program, whether in part or in whole, are granted.                      |**
**|                                                                         |**
**| TI makes no representation or warranties with respect to the            |**
**| performance of this computer program, and specifically disclaims        |**
**| any responsibility for any damages, special or consequential,           |**
**| connected with the use of this program.                                 |**
**|                                                                         |**
**+-------------------------------------------------------------------------+**
******************************************************************************/

/**
 *  \file   llc_vpbeCursor.h
 *
 *  \brief  VPBE LLC layer cursor Functions
 *
 *  This file contains the Implementation details of LLC layer functions
 *
 *  (C) Copyright 2010, Texas Instruments, Inc
 *
 *  \note       Set tabstop to 4 (:se ts=4) while viewing this file in an
 *              editor
 *
 *  \author     Maulik Desai
 *
 *  \version    0.1     Created
 */

#ifndef _LLC_VPBECURSOR_H
#define _LLC_VPBECURSOR_H

#ifdef __cplusplus
extern "C" {
#endif

/******************************************************************************
                                 Functions
******************************************************************************/
/**
  * \brief This will validate the params and Enable the cursor
  *
  * \param llcRegisterBaseAddr      [IN]        Register address from cursor is
  *                                             to be set
  *
  * \returns nothing
  */
void LLC_setCursorEnable(Ptr llcRegisterBaseAddr);


/**
  * \brief This will validate the params and disable the cursor
  *
  * \param llcRegisterBaseAddr      [IN]        Register address from cursor is
  *                                             to be set
  *
  * \returns nothing
  */
void LLC_setCursorDisable(Ptr llcRegisterBaseAddr);


/**
  * \brief  This will configure the color look up table for specified ROM memory
  *         area for cursor
  *
  * \param llcRegisterBaseAddr      [IN]        Register address from cursor is
  *                                             to be set
  *
  * \returns nothing
  */
void LLC_setCursorCLUTSelectROM(Ptr llcRegisterBaseAddr);

/**
  * \brief  This will configure the color look up table for specified ROM memory
  *         area for cursor-TYPE select
  *
  * \param llcRegisterBaseAddr      [IN]        Register address from cursor is
  *                                             to be set
  *
  * \returns nothing
  */
void LLC_setCursorROMTYPE(Ptr llcRegisterBaseAddr);
/**
  * \brief  This will configure the clour look up table for specified RAM memory
  *         area for cursor
  *
  * \param llcRegisterBaseAddr      [IN]        Register address from cursor is
  *                                             to be set
  *
  * \returns nothing
  */
void LLC_setCursorCLUTSelectRAM(Ptr llcRegisterBaseAddr);


/**
  * \brief This will configure the cursor width in vertical plane
  *
  * \param  llcRegisterBaseAddr     [IN]        Register address from cursor is
  *                                             to be set
  * \param vWidth                   [IN]        Width value
  */
void LLC_setCursorVWidth(Ptr llcRegisterBaseAddr, Uint32 vWidth);


/**
  * \brief This will configure the cursor width in Horizontal plane
  *
  * \param  llcRegisterBaseAddr     [IN]        Register address from cursor is
  *                                             to be set
  * \param  hWidth                  [IN]        Width value
  */
void LLC_setCursorHWidth(Ptr llcRegisterBaseAddr, Uint32 hWidth);


/**
  * \brief This will configure the cursor X position Ccdc plane
  *
  * \param  llcRegisterBaseAddr     [IN]        Register address from cursor is
  *                                             to be set
  * \param  xPosition               [IN]        xposition value
  */
void LLC_setCursorXPosition(Ptr llcRegisterBaseAddr, Uint xPosition);


/**
  * \brief This will configure the cursor Y position Ccdc plane
  *
  * \param  llcRegisterBaseAddr     [IN]        Register address from cursor is
  *                                             to be set
  * \param  yPosition               [IN]        yposition value
  *
  */
void LLC_setCursorYPosition(Ptr llcRegisterBaseAddr, Uint yPosition);


/**
  * \brief This will configure the cursor X size in Ccdc plane
  *
  * \param  llcRegisterBaseAddr     [IN]        Register address from cursor is
  *                                             to be set
  * \param  xSize                   [IN]        xSize value
  */
void LLC_setCursorXSize(Ptr llcRegisterBaseAddr, Uint xSize);


/**
  * \brief This will configure the cursor Y size in Ccdc plane
  *
  * \param  llcRegisterBaseAddr     [IN]        Register address from cursor is
  *                                             to be set
  * \param  ySize                   [IN]        ySize value
  */
void LLC_setCursorYSize(Ptr llcRegisterBaseAddr, Uint ySize);

#ifdef __cplusplus
}
#endif

#endif  /*_LLC_VPBECURSOR_H */
