/******************************************************************************
**+-------------------------------------------------------------------------+**
**|                            ****                                         |**
**|                            ****                                         |**
**|                            ******o***                                   |**
**|                      ********_///_****                                  |**
**|                      ***** /_//_/ ****                                  |**
**|                       ** ** (__/ ****                                   |**
**|                           *********                                     |**
**|                            ****                                         |**
**|                            ***                                          |**
**|                                                                         |**
**|         Copyright (c) 2006-2010 Texas Instruments Incorporated          |**
**|                        ALL RIGHTS RESERVED                              |**
**|                                                                         |**
**| Permission is hereby granted to licensees of Texas Instruments          |**
**| Incorporated (TI) products to use this computer program for the sole    |**
**| purpose of implementing a licensee product based on TI products.        |**
**| No other rights to reproduce, use, or disseminate this computer         |**
**| program, whether in part or in whole, are granted.                      |**
**|                                                                         |**
**| TI makes no representation or warranties with respect to the            |**
**| performance of this computer program, and specifically disclaims        |**
**| any responsibility for any damages, special or consequential,           |**
**| connected with the use of this program.                                 |**
**|                                                                         |**
**+-------------------------------------------------------------------------+**
******************************************************************************/

/**
 *  \file   llc_vpbeOsd.c
 *
 *  \brief  VPBE LLC layer Functions
 *
 *  This file contains the Implementation details of LLC layer functions
 *
 *  (C) Copyright 2010, Texas Instruments, Inc
 *
 *  \author     Maulik Desai
 *
 *  \version    0.1     created
 */

/******************************************************************************
                            Header File Inclusion
******************************************************************************/
#include <ti/sdo/pspdrivers/soc/dm6437/dsp/tistdtypes.h>
#include <ti/sdo/pspdrivers/drivers/vpbe/psp_vpbe.h>
#include <ti/sdo/pspdrivers/drivers/vpbe/src/llc_vpbeOsd.h>
#include <ti/sdo/pspdrivers/soc/dm6437/dsp/cslr_osd.h>

/******************************************************************************
                                Data-Structures
******************************************************************************/
/*-----------------------------------------------------------------------------
                    OSD CSL Overlay Register Structure Handle
-----------------------------------------------------------------------------*/
/**
  *  OSD CSL Overlay Register Structure Handle
  *
  */
static  CSL_OsdRegs     * osdRegs;

/******************************************************************************
                                    Functions
******************************************************************************/
void LLC_ResetOsdReg(Ptr regs)
{
   if(NULL!=regs)
   {
    osdRegs = (CSL_OsdRegs * )regs;

    osdRegs->MODE             = (Uint32)CSL_OSD_MODE_RESETVAL;
    osdRegs->VIDWINMD         = (Uint32)CSL_OSD_VIDWINMD_RESETVAL;
    osdRegs->OSDWIN0MD        = (Uint32)CSL_OSD_OSDWIN0MD_RESETVAL;
    osdRegs->OSDWIN1MD        = (Uint32)CSL_OSD_OSDWIN1MD_RESETVAL;
    osdRegs->RECTCUR          = (Uint32)CSL_OSD_RECTCUR_RESETVAL;
    osdRegs->VIDWIN0OFST      = (Uint32)CSL_OSD_VIDWIN0OFST_RESETVAL;
    osdRegs->VIDWIN1OFST      = (Uint32)CSL_OSD_VIDWIN1OFST_RESETVAL;
    osdRegs->OSDWIN0OFST      = (Uint32)CSL_OSD_OSDWIN0OFST_RESETVAL;
    osdRegs->OSDWIN1OFST      = (Uint32)CSL_OSD_OSDWIN1OFST_RESETVAL;
    osdRegs->VIDWIN0ADR       = (Uint32)CSL_OSD_VIDWIN0ADR_RESETVAL;
    osdRegs->VIDWIN1ADR       = (Uint32)CSL_OSD_VIDWIN1ADR_RESETVAL;
    osdRegs->OSDWIN0ADR       = (Uint32)CSL_OSD_OSDWIN0ADR_RESETVAL;
    osdRegs->OSDWIN1ADR       = (Uint32)CSL_OSD_OSDWIN1ADR_RESETVAL;
    osdRegs->BASEPX           = (Uint32)CSL_OSD_BASEPX_RESETVAL;
    osdRegs->BASEPY           = (Uint32)CSL_OSD_BASEPY_RESETVAL;
    osdRegs->VIDWIN0XP        = (Uint32)CSL_OSD_VIDWIN0XP_RESETVAL;
    osdRegs->VIDWIN0YP        = (Uint32)CSL_OSD_VIDWIN0YP_RESETVAL;
    osdRegs->VIDWIN0XL        = (Uint32)CSL_OSD_VIDWIN0XL_RESETVAL;
    osdRegs->VIDWIN0YL        = (Uint32)CSL_OSD_VIDWIN0YL_RESETVAL;
    osdRegs->VIDWIN1XP        = (Uint32)CSL_OSD_VIDWIN1XP_RESETVAL;
    osdRegs->VIDWIN1YP        = (Uint32)CSL_OSD_VIDWIN1YP_RESETVAL;
    osdRegs->VIDWIN1XL        = (Uint32)CSL_OSD_VIDWIN1XL_RESETVAL;
    osdRegs->VIDWIN1YL        = (Uint32)CSL_OSD_VIDWIN1YL_RESETVAL;
    osdRegs->OSDWIN0XP        = (Uint32)CSL_OSD_OSDWIN0XP_RESETVAL;
    osdRegs->OSDWIN0YP        = (Uint32)CSL_OSD_OSDWIN0YP_RESETVAL;
    osdRegs->OSDWIN0XL        = (Uint32)CSL_OSD_OSDWIN0XL_RESETVAL;
    osdRegs->OSDWIN0YL        = (Uint32)CSL_OSD_OSDWIN0YL_RESETVAL;
    osdRegs->OSDWIN1XP        = (Uint32)CSL_OSD_OSDWIN1XP_RESETVAL;
    osdRegs->OSDWIN1YP        = (Uint32)CSL_OSD_OSDWIN1YP_RESETVAL;
    osdRegs->OSDWIN1XL        = (Uint32)CSL_OSD_OSDWIN1XL_RESETVAL;
    osdRegs->OSDWIN1YL        = (Uint32)CSL_OSD_OSDWIN1YL_RESETVAL;
    osdRegs->CURXP            = (Uint32)CSL_OSD_CURXP_RESETVAL;
    osdRegs->CURYP            = (Uint32)CSL_OSD_CURYP_RESETVAL;
    osdRegs->CURXL            = (Uint32)CSL_OSD_CURXL_RESETVAL;
    osdRegs->CURYL            = (Uint32)CSL_OSD_CURYL_RESETVAL;
    osdRegs->W0BMP01           = (Uint32)CSL_OSD_W0BMP01_RESETVAL;
    osdRegs->W0BMP23           = (Uint32)CSL_OSD_W0BMP23_RESETVAL;
    osdRegs->W0BMP45           = (Uint32)CSL_OSD_W0BMP45_RESETVAL;
    osdRegs->W0BMP67           = (Uint32)CSL_OSD_W0BMP67_RESETVAL;
    osdRegs->W0BMP89           = (Uint32)CSL_OSD_W0BMP89_RESETVAL;
    osdRegs->W0BMPAB           = (Uint32)CSL_OSD_W0BMPAB_RESETVAL;
    osdRegs->W0BMPCD           = (Uint32)CSL_OSD_W0BMPCD_RESETVAL;
    osdRegs->W0BMPEF           = (Uint32)CSL_OSD_W0BMPEF_RESETVAL;
    osdRegs->W1BMP01           = (Uint32)CSL_OSD_W1BMP01_RESETVAL;
    osdRegs->W1BMP23           = (Uint32)CSL_OSD_W1BMP23_RESETVAL;
    osdRegs->W1BMP45           = (Uint32)CSL_OSD_W1BMP45_RESETVAL;
    osdRegs->W1BMP67           = (Uint32)CSL_OSD_W1BMP67_RESETVAL;
    osdRegs->W1BMP89           = (Uint32)CSL_OSD_W1BMP89_RESETVAL;
    osdRegs->W1BMPAB           = (Uint32)CSL_OSD_W1BMPAB_RESETVAL;
    osdRegs->W1BMPCD           = (Uint32)CSL_OSD_W1BMPCD_RESETVAL;
    osdRegs->W1BMPEF           = (Uint32)CSL_OSD_W1BMPEF_RESETVAL;
    osdRegs->MISCCTL           = (Uint32)CSL_OSD_MISCCTL_RESETVAL;
    osdRegs->CLUTRAMYCB        = (Uint32)CSL_OSD_CLUTRAMYCB_RESETVAL;
    osdRegs->CLUTRAMCR         = (Uint32)CSL_OSD_CLUTRAMCR_RESETVAL;
    osdRegs->TRANSPVAL         = (Uint32)CSL_OSD_TRANSPVAL_RESETVAL;
    osdRegs->PPVWIN0ADR        = (Uint32)CSL_OSD_PPVWIN0ADR_RESETVAL;
    }

}

/**
  * \brief To configure the OSD display mode interlaced
  *
  */
void LLC_setOsdModeInterlaced(PSP_VPBE_Id osdId,Ptr regs)
{
    if(NULL!=regs)
    {
        osdRegs = (CSL_OsdRegs * )regs;
        switch(osdId)
        {
            case PSP_VPBE_VIDEO_0:
            {
                CSL_FINST(osdRegs->VIDWINMD, OSD_VIDWINMD_VFF0, FRAMEMODE);
            }
            break;
            case PSP_VPBE_VIDEO_1:
            {
                CSL_FINST(osdRegs->VIDWINMD, OSD_VIDWINMD_VFF1, FRAMEMODE);
            }
            break;
            case PSP_VPBE_OSD_0:
            {
                CSL_FINST(osdRegs->OSDWIN0MD, OSD_OSDWIN0MD_OFF0, FRAMEMODE);
            }
            break;
            case PSP_VPBE_OSD_1:
            {
                CSL_FINST(osdRegs->OSDWIN1MD, OSD_OSDWIN1MD_OFF1, FRAMEMODE);
            }
            break;
            default:
            {

            }
            break;
        }
    }
}

/**
  * \brief To configure the OSD display mode Progressive
  *
  */
void LLC_setOsdModeProgressive(PSP_VPBE_Id osdId,Ptr regs)
{
    if(NULL!=regs)
    {
        osdRegs = (CSL_OsdRegs * )regs;

        switch(osdId)
        {
            case PSP_VPBE_VIDEO_0:
            {
                CSL_FINST(osdRegs->VIDWINMD, OSD_VIDWINMD_VFF0, FIELDMODE);
            }
            break;
            case PSP_VPBE_VIDEO_1:
            {
                CSL_FINST(osdRegs->VIDWINMD, OSD_VIDWINMD_VFF1, FIELDMODE);
            }
            break;
            case PSP_VPBE_OSD_0:
            {
                CSL_FINST(osdRegs->OSDWIN0MD, OSD_OSDWIN0MD_OFF0, FIELDMODE);
            }
            break;
            case PSP_VPBE_OSD_1:
            {
                CSL_FINST(osdRegs->OSDWIN1MD, OSD_OSDWIN1MD_OFF1, FIELDMODE);
            }
            break;
            default:
            {

            }
            break;
        }
    }
}

/**
  * \brief To configure the OSD display ON
  *
  */
void LLC_setOsdDisplayOn(PSP_VPBE_Id osdId,Ptr regs)
{
    if(NULL!=regs)
    {
        osdRegs = (CSL_OsdRegs * )regs;
        switch(osdId)
        {
            case PSP_VPBE_VIDEO_0:
            {
                CSL_FINST(osdRegs->VIDWINMD, OSD_VIDWINMD_ACT0, ON);
            }
            break;
            case PSP_VPBE_VIDEO_1:
            {
                CSL_FINST(osdRegs->VIDWINMD, OSD_VIDWINMD_ACT1, ON);
            }
            break;
            case PSP_VPBE_OSD_0:
            {
                CSL_FINST(osdRegs->OSDWIN0MD, OSD_OSDWIN0MD_OACT0, ON);
            }
            break;
            case PSP_VPBE_OSD_1:
            {
                CSL_FINST(osdRegs->OSDWIN1MD, OSD_OSDWIN1MD_OACT1, ON);
            }
            break;
            default:
            {

            }
            break;
        }
    }
}

/**
  * \brief To configure the OSD display OFF
  *
  */
void LLC_setOsdDisplayOff(PSP_VPBE_Id osdId,Ptr regs)
{
    if(NULL!=regs)
    {
        osdRegs = (CSL_OsdRegs * )regs;
        switch(osdId)
        {
            case PSP_VPBE_VIDEO_0:
            {
                CSL_FINST(osdRegs->VIDWINMD, OSD_VIDWINMD_ACT0, OFF);
            }
            break;
            case PSP_VPBE_VIDEO_1:
            {
                CSL_FINST(osdRegs->VIDWINMD, OSD_VIDWINMD_ACT1, OFF);
            }
            break;
            case PSP_VPBE_OSD_0:
            {
                CSL_FINST(osdRegs->OSDWIN0MD, OSD_OSDWIN0MD_OACT0, OFF);
            }
            break;
            case PSP_VPBE_OSD_1:
            {
                CSL_FINST(osdRegs->OSDWIN1MD, OSD_OSDWIN1MD_OACT1, OFF);
            }
            break;
            default:
            {

            }
            break;
        }
    }
}

/**
  * \brief To configure the OSD display screen width
  *
  */
void LLC_setOsdDisplayScreenWidth(PSP_VPBE_Id osdId,Ptr regs,Uint32 planeWidth)
{
    if(NULL!=regs)
    {
        osdRegs = (CSL_OsdRegs * )regs;
        switch(osdId)
        {
            case PSP_VPBE_VIDEO_0:
            {
                osdRegs->VIDWIN0XL  = planeWidth;
            }
            break;
            case PSP_VPBE_VIDEO_1:
            {
                osdRegs->VIDWIN1XL  = planeWidth;
            }
            break;
            case PSP_VPBE_OSD_0:
            {
                osdRegs->OSDWIN0XL    = planeWidth;
            }
            break;
            case PSP_VPBE_OSD_1:
            {
                osdRegs->OSDWIN1XL    = planeWidth;
            }
            break;
            default:
            {

            }
            break;
        }
    }
}

/**
  * \brief To configure the OSD display screen height
  *
  */
void LLC_setOsdDisplayScreenHeight(PSP_VPBE_Id osdId,Ptr regs,Uint32 planeHeight)
{
    if(NULL!=regs)
    {
        osdRegs = (CSL_OsdRegs * )regs;
        switch(osdId)
        {
            case PSP_VPBE_VIDEO_0:
            {
                osdRegs->VIDWIN0YL = planeHeight;
            }
            break;
            case PSP_VPBE_VIDEO_1:
            {
                osdRegs->VIDWIN1YL = planeHeight;
            }
            break;
            case PSP_VPBE_OSD_0:
            {
                osdRegs->OSDWIN0YL = planeHeight;
            }
            break;
            case PSP_VPBE_OSD_1:
            {
                osdRegs->OSDWIN1YL = planeHeight;
            }
            break;
            default:
            {

            }
            break;
        }
    }
}

/**
  * \brief To configure the OSD display screen left margin
  *
  */
void LLC_setOsdDisplayLeftMargin(PSP_VPBE_Id osdId,Ptr regs,Uint32 lMargin)
{
    if(NULL!=regs)
    {
        osdRegs = (CSL_OsdRegs * )regs;
        switch(osdId)
        {
            case PSP_VPBE_VIDEO_0:
            {
                osdRegs->VIDWIN0XP = lMargin;
            }
            break;
            case PSP_VPBE_VIDEO_1:
            {
                osdRegs->VIDWIN1XP = lMargin;
            }
            break;

            case PSP_VPBE_OSD_0:
            {
                osdRegs->OSDWIN0XP = lMargin;
            }
            break;
            case PSP_VPBE_OSD_1:
            {
                osdRegs->OSDWIN1XP = lMargin;
            }
            break;
            default:
            {

            }
            break;
        }
    }
}

/**
  * \brief To configure the OSD display screen top margin
  *
  */
void LLC_setOsdDisplayTopMargin(PSP_VPBE_Id osdId,Ptr regs,Uint32 tMargin)
{
    if(NULL!=regs)
    {
        osdRegs = (CSL_OsdRegs * )regs;
        switch(osdId)
        {
            case PSP_VPBE_VIDEO_0:
            {
                osdRegs->VIDWIN0YP = tMargin;
            }
            break;
            case PSP_VPBE_VIDEO_1:
            {
                osdRegs->VIDWIN1YP = tMargin;
            }
            break;

            case PSP_VPBE_OSD_0:
            {
                osdRegs->OSDWIN0YP = tMargin;
            }
            break;
            case PSP_VPBE_OSD_1:
            {
                osdRegs->OSDWIN1YP = tMargin;
            }
            break;
            default:
            {

            }
            break;
        }
    }
}

/**
  * \brief To configure the OSD frame buffer start address
  *
  */
void LLC_setOsdFBStartAddress(PSP_VPBE_Id osdId,Ptr regs,Ptr fbPtr)
{
    Uint32 addr;
    if((NULL!=regs))
    {
        addr = (Uint32)fbPtr;
        osdRegs = (CSL_OsdRegs * )regs;
        switch(osdId)
        {
            case PSP_VPBE_VIDEO_0:
            {
                osdRegs->VIDWIN0ADR = addr;
            }
            break;
            case PSP_VPBE_VIDEO_1:
            {
                osdRegs->VIDWIN1ADR = addr;
            }
            break;
            case PSP_VPBE_OSD_0:
            {
                osdRegs->OSDWIN0ADR = addr;
            }
            break;
            case PSP_VPBE_OSD_1:
            {
                osdRegs->OSDWIN1ADR = addr;
            }
            break;
            default:
            {

            }
            break;
        }
    }
}

/**
  * \brief To configure the OSD offset
  *
  */
void LLC_setOsdOffset(PSP_VPBE_Id osdId,Ptr regs,Uint32 offset)
{
    if(NULL!=regs)
    {
        osdRegs = (CSL_OsdRegs * )regs;
        switch(osdId)
        {
            case PSP_VPBE_VIDEO_0:
            {
                osdRegs->VIDWIN0OFST = offset;
            }
            break;
            case PSP_VPBE_VIDEO_1:
            {
                osdRegs->VIDWIN1OFST = offset;
            }
            break;
            case PSP_VPBE_OSD_0:
            {
                osdRegs->OSDWIN0OFST = offset;
            }
            break;
            case PSP_VPBE_OSD_1:
            {
                osdRegs->OSDWIN1OFST = offset;
            }
            break;
            default:
            break;
        }
    }
}

/**
  * \brief To set the Horizontal OSD zoom
  *
  */
Bool LLC_setOsdHorZoom(PSP_VPBE_Id osdId,PSP_VPBEScalingFactor HorScaleFactor ,Ptr regs)
{
    Bool resultHZ = FALSE;
    if(NULL!=regs)
    {
        osdRegs = (CSL_OsdRegs * )regs;
        switch(osdId)
        {
            case PSP_VPBE_VIDEO_0:
            {
                if(PSP_VPBE_ZOOM_2X == HorScaleFactor)
                {
                    CSL_FINST(osdRegs->VIDWINMD, OSD_VIDWINMD_VHZ0, X2);
                    resultHZ = TRUE;
                }
                else if(PSP_VPBE_ZOOM_4X == HorScaleFactor)
                {
                    CSL_FINST(osdRegs->VIDWINMD, OSD_VIDWINMD_VHZ0, X4);
                    resultHZ = TRUE;
                }
                else
                {
                    if(PSP_VPBE_ZOOM_IDENTITY == HorScaleFactor)
                    {
                        CSL_FINST(osdRegs->VIDWINMD, OSD_VIDWINMD_VHZ0, X1);
                        resultHZ = TRUE;
                     }
                }
            }
            break;
            case PSP_VPBE_VIDEO_1:
            {
                if(PSP_VPBE_ZOOM_2X == HorScaleFactor)
                {
                    CSL_FINST(osdRegs->VIDWINMD, OSD_VIDWINMD_VHZ1, X2);
                    resultHZ = TRUE;
                }
                else if(PSP_VPBE_ZOOM_4X == HorScaleFactor)
                {
                    CSL_FINST(osdRegs->VIDWINMD, OSD_VIDWINMD_VHZ1, X4);
                    resultHZ = TRUE;
                }
                else
                {
                    if(PSP_VPBE_ZOOM_IDENTITY == HorScaleFactor)
                    {
                        CSL_FINST(osdRegs->VIDWINMD, OSD_VIDWINMD_VHZ1, X1);
                        resultHZ = TRUE;
                    }
                }
            }
            break;
            case PSP_VPBE_OSD_0:
            {
                if(PSP_VPBE_ZOOM_2X == HorScaleFactor)
                {
                    CSL_FINST(osdRegs->OSDWIN0MD, OSD_OSDWIN0MD_OHZ0, X2);
                    resultHZ = TRUE;
                }
                else if(PSP_VPBE_ZOOM_4X == HorScaleFactor)
                {
                    CSL_FINST(osdRegs->OSDWIN0MD, OSD_OSDWIN0MD_OHZ0, X4);
                    resultHZ = TRUE;
                }
                else
                {
                    if(PSP_VPBE_ZOOM_IDENTITY == HorScaleFactor)
                    {
                        CSL_FINST(osdRegs->OSDWIN0MD, OSD_OSDWIN0MD_OHZ0, X1);
                        resultHZ = TRUE;
                    }
                }
            }
            break;
            case PSP_VPBE_OSD_1:
            {
                if(PSP_VPBE_ZOOM_2X == HorScaleFactor)
                {
                    CSL_FINST(osdRegs->OSDWIN1MD, OSD_OSDWIN1MD_OHZ1, X2);
                    resultHZ = TRUE;
                }
                else if(PSP_VPBE_ZOOM_4X == HorScaleFactor)
                {
                    CSL_FINST(osdRegs->OSDWIN1MD, OSD_OSDWIN1MD_OHZ1, X4);
                    resultHZ = TRUE;
                }
                else
                {
                    if(PSP_VPBE_ZOOM_IDENTITY == HorScaleFactor)
                    {
                        CSL_FINST(osdRegs->OSDWIN1MD, OSD_OSDWIN1MD_OHZ1, X1);
                        resultHZ = TRUE;
                    }
                }
            }
            break;
            default:
            {
                resultHZ = FALSE;
            }
            break;
        }
    }
    return resultHZ;
}
/**
  * \brief To set the Vertical OSD zoom
  *
  */
Bool LLC_setOsdVertZoom(PSP_VPBE_Id osdId,PSP_VPBEScalingFactor VertScaleFactor ,Ptr regs)
{
    Bool resultVZ = FALSE;
    if(NULL!=regs)
    {
        osdRegs = (CSL_OsdRegs * )regs;
        switch(osdId)
        {
            case PSP_VPBE_VIDEO_0:
            {
                if(PSP_VPBE_ZOOM_2X == VertScaleFactor)
                {
                    CSL_FINST(osdRegs->VIDWINMD, OSD_VIDWINMD_VVZ0, X2);
                    resultVZ = TRUE;
                }
                else if(PSP_VPBE_ZOOM_4X == VertScaleFactor)
                {
                    CSL_FINST(osdRegs->VIDWINMD, OSD_VIDWINMD_VVZ0, X4);
                    resultVZ = TRUE;
                }
                else
                {
                    if(PSP_VPBE_ZOOM_IDENTITY == VertScaleFactor)
                    {
                        CSL_FINST(osdRegs->VIDWINMD, OSD_VIDWINMD_VVZ0, X1);
                        resultVZ = TRUE;
                    }
                }
            }
            break;
            case PSP_VPBE_VIDEO_1:
            {
                if(PSP_VPBE_ZOOM_2X == VertScaleFactor)
                {
                    CSL_FINST(osdRegs->VIDWINMD, OSD_VIDWINMD_VVZ1, X2);
                    resultVZ = TRUE;
                }
                else if(PSP_VPBE_ZOOM_4X == VertScaleFactor)
                {
                    CSL_FINST(osdRegs->VIDWINMD, OSD_VIDWINMD_VVZ1, X4);
                    resultVZ = TRUE;
                }
                else
                {
                    if(PSP_VPBE_ZOOM_IDENTITY == VertScaleFactor)
                    {
                        CSL_FINST(osdRegs->VIDWINMD, OSD_VIDWINMD_VVZ1, X1);
                        resultVZ = TRUE;
                    }
                }
            }
            break;
            case PSP_VPBE_OSD_0:
            {
                if(PSP_VPBE_ZOOM_2X == VertScaleFactor)
                {
                    CSL_FINST(osdRegs->OSDWIN0MD, OSD_OSDWIN0MD_OVZ0, X2);
                    resultVZ = TRUE;
                }
                else if(PSP_VPBE_ZOOM_4X == VertScaleFactor)
                {
                    CSL_FINST(osdRegs->OSDWIN0MD, OSD_OSDWIN0MD_OVZ0, X4);
                    resultVZ = TRUE;
                }
                else
                {
                    if(PSP_VPBE_ZOOM_IDENTITY == VertScaleFactor)
                    {
                        CSL_FINST(osdRegs->OSDWIN0MD, OSD_OSDWIN0MD_OVZ0, X1);
                        resultVZ = TRUE;
                    }
                }
            }
            break;
            case PSP_VPBE_OSD_1:
            {
                if(PSP_VPBE_ZOOM_2X== VertScaleFactor)
                {
                    CSL_FINST(osdRegs->OSDWIN1MD, OSD_OSDWIN1MD_OVZ1, X2);
                    resultVZ = TRUE;
                }
                else if(PSP_VPBE_ZOOM_4X == VertScaleFactor)
                {
                    CSL_FINST(osdRegs->OSDWIN1MD, OSD_OSDWIN1MD_OVZ1, X4);
                    resultVZ = TRUE;
                }
                else
                {
                    if(PSP_VPBE_ZOOM_IDENTITY == VertScaleFactor)
                    {
                        CSL_FINST(osdRegs->OSDWIN1MD, OSD_OSDWIN1MD_OVZ1, X1);
                        resultVZ = TRUE;
                    }
                }
            }
            break;
            default:
            {
                resultVZ = FALSE;
            }
            break;
        }
    }
    return resultVZ;
}

/**
  * \brief To set the OSD horizonatal expansion by 9_8
  *
  */
Bool LLC_setOsdHorzExp_9_8(PSP_VPBE_Id osdId,PSP_VPBEExpansionFactor HExpFactor,Ptr regs)
{
    Bool resultHE   = FALSE;
    if(NULL!=regs)
    {

        osdRegs = (CSL_OsdRegs * )regs;
        switch(osdId)
        {
            case PSP_VPBE_VIDEO_0:
            case PSP_VPBE_VIDEO_1:
            {
                if(PSP_VPBE_EXP_NINE_BY_EIGHT== HExpFactor)
                {
                    CSL_FINST(osdRegs->MODE, OSD_MODE_VHRSZ, X9_8);
                    resultHE    = TRUE;
                }
                else
                {
                    if(PSP_VPBE_EXP_IDENTITY == HExpFactor)
                    {
                        CSL_FINST(osdRegs->MODE, OSD_MODE_VHRSZ, X1);
                        resultHE    = TRUE;
                    }
                }
            }
            break;
            case PSP_VPBE_OSD_1:
            case PSP_VPBE_OSD_0:
            {
                if(PSP_VPBE_EXP_NINE_BY_EIGHT== HExpFactor)
                {
                    CSL_FINST(osdRegs->MODE, OSD_MODE_OHRSZ, X9_8);
                    resultHE    = TRUE;
                }
                else
                {
                    if(PSP_VPBE_EXP_IDENTITY == HExpFactor)
                    {
                        CSL_FINST(osdRegs->MODE, OSD_MODE_OHRSZ, X1);
                        resultHE    = TRUE;
                    }
                }
            }
            break;
            default:
            {
                    resultHE    = FALSE;
            }
            break;
        }
    }
    return resultHE;
}

/**
  * \brief To set the OSD vertical expansion by 6_5
  *
  */
Bool  LLC_setOsdVertExp_6_5(PSP_VPBE_Id osdId,PSP_VPBEExpansionFactor VExpFactor,Ptr regs)
{
    Bool resultVE = FALSE;
    if(NULL!=regs)
    {

        osdRegs = (CSL_OsdRegs * )regs;
        switch(osdId)
        {
            case PSP_VPBE_VIDEO_0:
            case PSP_VPBE_VIDEO_1:
            {
                if(PSP_VPBE_EXP_SIX_BY_FIVE== VExpFactor)
                {
                    CSL_FINST(osdRegs->MODE, OSD_MODE_VVRSZ, X6_5);
                    resultVE = TRUE;
                }
                else
                {
                    if(PSP_VPBE_EXP_IDENTITY == VExpFactor)
                    {
                        CSL_FINST(osdRegs->MODE, OSD_MODE_VVRSZ, X1);
                        resultVE = TRUE;
                    }
                }
            }
            break;
            case PSP_VPBE_OSD_0:
            case PSP_VPBE_OSD_1:
            {
                if(PSP_VPBE_EXP_SIX_BY_FIVE== VExpFactor)
                {
                    CSL_FINST(osdRegs->MODE, OSD_MODE_OVRSZ, X6_5);
                    resultVE = TRUE;
                }
                else
                {
                    if(PSP_VPBE_EXP_IDENTITY == VExpFactor)
                    {
                        CSL_FINST(osdRegs->MODE, OSD_MODE_OVRSZ, X1);
                        resultVE = TRUE;
                    }
                }

            }
            break;
            default :
            {
                resultVE = FALSE;
            }
            break;
        }
    }
 return resultVE;
}
/**
  * \brief To disable the OSD zoom
  *
  */
void LLC_setOsdZoomDisable(PSP_VPBE_Id osdId, Ptr regs)
{
    if(NULL!=regs)
    {
        osdRegs = (CSL_OsdRegs * )regs;
        switch(osdId)
        {
            case PSP_VPBE_VIDEO_0:
            {
                CSL_FINST(osdRegs->VIDWINMD, OSD_VIDWINMD_VHZ0, X1);
                CSL_FINST(osdRegs->VIDWINMD, OSD_VIDWINMD_VVZ0, X1);
                CSL_FINST(osdRegs->MODE, OSD_MODE_VVRSZ, X1);
                CSL_FINST(osdRegs->MODE, OSD_MODE_VHRSZ, X1);
            }
            break;
            case PSP_VPBE_VIDEO_1:
            {
                CSL_FINST(osdRegs->VIDWINMD, OSD_VIDWINMD_VHZ1, X1);
                CSL_FINST(osdRegs->VIDWINMD, OSD_VIDWINMD_VVZ1, X1);
                CSL_FINST(osdRegs->MODE, OSD_MODE_VVRSZ, X1);
                CSL_FINST(osdRegs->MODE, OSD_MODE_VHRSZ, X1);
            }
            break;
            case PSP_VPBE_OSD_0:
            {
                CSL_FINST(osdRegs->OSDWIN0MD, OSD_OSDWIN0MD_OHZ0, X1);
                CSL_FINST(osdRegs->OSDWIN0MD, OSD_OSDWIN0MD_OVZ0, X1);
                CSL_FINST(osdRegs->MODE, OSD_MODE_OVRSZ, X1);
                CSL_FINST(osdRegs->MODE, OSD_MODE_OHRSZ, X1);
            }
            break;
            case PSP_VPBE_OSD_1:
            {
                CSL_FINST(osdRegs->OSDWIN1MD, OSD_OSDWIN1MD_OHZ1, X1);
                CSL_FINST(osdRegs->OSDWIN1MD, OSD_OSDWIN1MD_OVZ1, X1);
                CSL_FINST(osdRegs->MODE, OSD_MODE_OVRSZ, X1);
                CSL_FINST(osdRegs->MODE, OSD_MODE_OHRSZ, X1);
            }
            break;
            default:
            {
                break;
            }
        }
    }
}
/*****************************************************************************************
                        FUNCTIONS SPECIFIC TO OSD(OSD0 and OSD1) PLANES
*******************************************************************************************/
/**
  * \brief To set the OSD Transparency colour
  *
  */
Bool LLC_setOSDWinTransparencyColour(PSP_VPBE_Id osdId, Ptr regs, Uint32 colour)
{
    Bool    resultCT;
    if(NULL == regs)
    {
        resultCT = FALSE;
    }
    else
    {
        resultCT = TRUE;
        osdRegs = (CSL_OsdRegs * )regs;
        switch(osdId)
        {
            case PSP_VPBE_OSD_0:
            {
                CSL_FINS(osdRegs->TRANSPVAL, OSD_TRANSPVAL_RGBTRANS, colour);
            }
            break;
            case PSP_VPBE_OSD_1:
            {
                CSL_FINS(osdRegs->TRANSPVAL, OSD_TRANSPVAL_RGBTRANS, colour);
            }
            break;
            default:
            {
                resultCT = FALSE;
            }
            break;
        }
    }
    return(resultCT);
}

/**
  * \brief To set the OSD Transparency enable
  *
  */
Bool LLC_setOSDWinTransparencyEnable(PSP_VPBE_Id osdId, Ptr regs)
{
    Bool    resultCT;
    if( NULL == regs)
    {
        resultCT = FALSE;
    }
    else
    {
        resultCT = TRUE;
        osdRegs = (CSL_OsdRegs * )regs;
        switch(osdId)
        {
            case PSP_VPBE_OSD_0:
            {
                CSL_FINST(osdRegs->OSDWIN0MD, OSD_OSDWIN0MD_TE0, ENABLE);
            }
            break;
            case PSP_VPBE_OSD_1:
            {
                CSL_FINST(osdRegs->OSDWIN1MD, OSD_OSDWIN1MD_TE1, ENABLE);
            }
            break;
            default:
            {
                resultCT = FALSE;
            }
            break;
        }
    }

    return(resultCT);
}

/**
  * \brief To set the OSD Transparency disable
  *
  */

Bool LLC_setOSDWinTransparencyDisable(PSP_VPBE_Id osdId, Ptr regs)
{
    Bool    resultCT;
    if(NULL == regs)
    {
        resultCT = FALSE;
    }
    else
    {
        resultCT = TRUE;
        osdRegs = (CSL_OsdRegs * )regs;
        switch(osdId)
        {
            case PSP_VPBE_OSD_0:
            {
                CSL_FINST(osdRegs->OSDWIN0MD, OSD_OSDWIN0MD_TE0, DISABLE);
            }
            break;
            case PSP_VPBE_OSD_1:
            {
                CSL_FINST(osdRegs->OSDWIN1MD, OSD_OSDWIN1MD_TE1, DISABLE);
            }
            break;
            default:
            {
                resultCT = FALSE;
            }
            break;
        }
    }

    return(resultCT);
}

/**
  * \brief To program the Luma color space for the CLUT
  *
  */
void LLC_setClutEntry_Y(Ptr regs , Uint8 value_Y)
{
    if(NULL!=regs)
    {
        osdRegs = (CSL_OsdRegs * )regs;
        CSL_FINS(osdRegs->CLUTRAMYCB, OSD_CLUTRAMYCB_Y, value_Y);
    }
}


/**
  * \brief To program the Chroma-Blue color space for the CLUT
  *
  */

void LLC_setClutEntry_Cb(Ptr regs , Uint8 value_Cb)
{
    if(NULL!=regs)
    {
        osdRegs = (CSL_OsdRegs * )regs;
        CSL_FINS(osdRegs->CLUTRAMYCB, OSD_CLUTRAMYCB_CB, value_Cb);
    }
}

/**
  * \brief To program the Chroma-Red color space for the CLUT
  *
  */
void LLC_setClutEntry_Cr(Ptr regs , Uint8 value_Cr)
{
    if(NULL!=regs)
    {
        osdRegs = (CSL_OsdRegs * )regs;
        CSL_FINS(osdRegs->CLUTRAMCR, OSD_CLUTRAMCR_CR, value_Cr);
    }
}

/**
  * \brief To program the Address for the CLUT
  *
  */

void LLC_setClutEntry_Addr(Ptr regs , Uint32 index)
{
    if(NULL!=regs)
    {
        osdRegs = (CSL_OsdRegs * )regs;
        CSL_FINS(osdRegs->CLUTRAMCR, OSD_CLUTRAMCR_CADDR, index);
    }
}

/**
  * \brief To program the CLUT entries for the BMP CLUT
  *
  */

void LLC_setBMPCLUTEntry(PSP_VPBE_Id osdId, Ptr regs , const Uint8 * table)

{
    if((NULL!=regs) && (NULL != table))
    {
          osdRegs = (CSL_OsdRegs * )regs;
          switch (osdId)
          {
                case PSP_VPBE_OSD_0:
                {
                      CSL_FINS(osdRegs->W0BMP01,OSD_W0BMP01_PAL00 , *(table));
                      CSL_FINS(osdRegs->W0BMP01,OSD_W0BMP01_PAL01 , *(table+1));

                      CSL_FINS(osdRegs->W0BMP23,OSD_W0BMP23_PAL02 , *(table+2));
                      CSL_FINS(osdRegs->W0BMP23,OSD_W0BMP23_PAL03 , *(table+3));

                      CSL_FINS(osdRegs->W0BMP45,OSD_W0BMP45_PAL04 , *(table+4));
                      CSL_FINS(osdRegs->W0BMP45,OSD_W0BMP45_PAL05 , *(table+5));

                      CSL_FINS(osdRegs->W0BMP67,OSD_W0BMP67_PAL06 , *(table+6));
                      CSL_FINS(osdRegs->W0BMP67,OSD_W0BMP67_PAL07 , *(table+7));

                      CSL_FINS(osdRegs->W0BMP89,OSD_W0BMP89_PAL08 , *(table+8));
                      CSL_FINS(osdRegs->W0BMP89,OSD_W0BMP89_PAL09 , *(table+9));

                      CSL_FINS(osdRegs->W0BMPAB,OSD_W0BMPAB_PAL10 , *(table+10));
                      CSL_FINS(osdRegs->W0BMPAB,OSD_W0BMPAB_PAL11 , *(table+11));

                      CSL_FINS(osdRegs->W0BMPCD,OSD_W0BMPCD_PAL12 , *(table+12));
                      CSL_FINS(osdRegs->W0BMPCD,OSD_W0BMPCD_PAL13 , *(table+13));

                      CSL_FINS(osdRegs->W0BMPEF,OSD_W0BMPEF_PAL14 , *(table+14));
                      CSL_FINS(osdRegs->W0BMPEF,OSD_W0BMPEF_PAL15 , *(table+15));
                }
                break;
                case PSP_VPBE_OSD_1:
                {
                      CSL_FINS(osdRegs->W1BMP01,OSD_W1BMP01_PAL00 , *(table));
                      CSL_FINS(osdRegs->W1BMP01,OSD_W1BMP01_PAL01 , *(table+1));

                      CSL_FINS(osdRegs->W1BMP23,OSD_W1BMP23_PAL02 , *(table+2));
                      CSL_FINS(osdRegs->W1BMP23,OSD_W1BMP23_PAL03 , *(table+3));

                      CSL_FINS(osdRegs->W1BMP45,OSD_W1BMP45_PAL04 , *(table+4));
                      CSL_FINS(osdRegs->W1BMP45,OSD_W1BMP45_PAL05 , *(table+5));

                      CSL_FINS(osdRegs->W1BMP67,OSD_W1BMP67_PAL06 , *(table+6));
                      CSL_FINS(osdRegs->W1BMP67,OSD_W1BMP67_PAL07 , *(table+7));

                      CSL_FINS(osdRegs->W1BMP89,OSD_W1BMP89_PAL08 , *(table+8));
                      CSL_FINS(osdRegs->W1BMP89,OSD_W1BMP89_PAL09 , *(table+9));

                      CSL_FINS(osdRegs->W1BMPAB,OSD_W1BMPAB_PAL10 , *(table+10));
                      CSL_FINS(osdRegs->W1BMPAB,OSD_W1BMPAB_PAL11 , *(table+11));

                      CSL_FINS(osdRegs->W1BMPCD,OSD_W1BMPCD_PAL12 , *(table+12));
                      CSL_FINS(osdRegs->W1BMPCD,OSD_W1BMPCD_PAL13 , *(table+13));

                      CSL_FINS(osdRegs->W1BMPEF,OSD_W1BMPEF_PAL14 , *(table+14));
                      CSL_FINS(osdRegs->W1BMPEF,OSD_W1BMPEF_PAL15 , *(table+15));
                }
                break;
                default:
                break;
          }
    }
}
/**
  * \brief To configure the BMP Windows pixel bit width to 1 bit
  *
  */
void LLC_setOSDWinPixelBitWidth1Bit(PSP_VPBE_Id osdId,Ptr regs)
{
    if(NULL!=regs)
    {
        osdRegs = (CSL_OsdRegs * )regs;
        switch(osdId)
        {
            case PSP_VPBE_OSD_0:
            {
                CSL_FINST(osdRegs->OSDWIN0MD, OSD_OSDWIN0MD_BMW0, 1_BIT);
            }
            break;
            case PSP_VPBE_OSD_1:
            {
                CSL_FINST(osdRegs->OSDWIN1MD, OSD_OSDWIN1MD_BMW1, 1_BIT);
            }
            break;
            default:
            {

            }
            break;
        }
    }
}

/**
  * \brief To configure the BMP Windows pixel bit width to 2 bit
  *
  */

void LLC_setOSDWinPixelBitWidth2Bit(PSP_VPBE_Id osdId,Ptr regs)
{
    if(NULL!=regs)
    {
        osdRegs = (CSL_OsdRegs * )regs;
        switch(osdId)
        {
            case PSP_VPBE_OSD_0:
            {
                CSL_FINST(osdRegs->OSDWIN0MD, OSD_OSDWIN0MD_BMW0, 2_BITS);
            }
            break;
            case PSP_VPBE_OSD_1:
            {
                CSL_FINST(osdRegs->OSDWIN1MD, OSD_OSDWIN1MD_BMW1, 2_BITS);
            }
            break;
            default:
            {

            }
            break;
        }
    }
}

/**
  * \brief To configure the BMP Windows pixel bit width to 4 bit
  *
  */

void LLC_setOSDWinPixelBitWidth4Bit(PSP_VPBE_Id osdId,Ptr regs)
{
    if(NULL!=regs)
    {
        osdRegs = (CSL_OsdRegs * )regs;
        switch(osdId)
        {
            case PSP_VPBE_OSD_0:
            {
                CSL_FINST(osdRegs->OSDWIN0MD, OSD_OSDWIN0MD_BMW0, 4_BITS);
            }
            break;
            case PSP_VPBE_OSD_1:
            {
                CSL_FINST(osdRegs->OSDWIN1MD, OSD_OSDWIN1MD_BMW1, 4_BITS);
            }
            break;
            default:
            {

            }
            break;
        }
    }
}
/**
  * \brief To configure the BMP Windows pixel bit width to 8bit
  *
  */
void LLC_setOSDWinPixelBitWidth8Bit(PSP_VPBE_Id osdId,Ptr regs)
{
    if(NULL!=regs)
    {
        osdRegs = (CSL_OsdRegs * )regs;
        switch(osdId)
        {
            case PSP_VPBE_OSD_0:
            {
                CSL_FINST(osdRegs->OSDWIN0MD, OSD_OSDWIN0MD_BMW0, 8_BITS);
            }
            break;
            case PSP_VPBE_OSD_1:
            {
                CSL_FINST(osdRegs->OSDWIN1MD, OSD_OSDWIN1MD_BMW1, 8_BITS);
            }
            break;
            default:
            {

            }
            break;
        }
    }
}
/**
  * \brief To configure the BMP Windows blending ratio
  *
  */
void LLC_setOSDWinBlendingRatio(PSP_VPBE_Id osdId,Ptr regs,Uint32 blendRatio)
{
    if(NULL!=regs)
    {
        osdRegs = (CSL_OsdRegs * )regs;
        switch(osdId)
        {
            case PSP_VPBE_OSD_0:
            {
                CSL_FINS(osdRegs->OSDWIN0MD, OSD_OSDWIN0MD_BLND0, blendRatio);
            }
            break;
            case PSP_VPBE_OSD_1:
            {
                CSL_FINS(osdRegs->OSDWIN1MD, OSD_OSDWIN1MD_BLND1, blendRatio);
            }
            break;
            default:
            {

            }
            break;
        }
    }
}

/**
  * \brief To configure the BMP Windows1 attribute mode enable
  *
  */
void LLC_setOSDWin1AttrModeEnable(Ptr regs)
{
    if(NULL!=regs)
    {
        osdRegs = (CSL_OsdRegs * )regs;
        CSL_FINST(osdRegs->OSDWIN1MD, OSD_OSDWIN1MD_OASW, ATTRIBUTEWINDOW);
    }
}

/**
  * \brief To configure the BMP Windows1 attribute mode disable
  *
  */
void LLC_setOSDWin1AttrModeDisable(Ptr regs)
{
    if(NULL!=regs)
    {
        osdRegs = (CSL_OsdRegs * )regs;
        CSL_FINST(osdRegs->OSDWIN1MD, OSD_OSDWIN1MD_OASW, OSDWINDOW1);
    }
}

/**
  * \brief To configure the OSD colour format BMPLUT mode
  *
  */
void LLC_setOSDWinColorFormatBMPLUTMode(PSP_VPBE_Id osdId,Ptr regs)
{
    if(NULL!=regs)
    {
        osdRegs = (CSL_OsdRegs * )regs;
        switch(osdId)
        {
            case PSP_VPBE_OSD_0:
            {
                CSL_FINST(osdRegs->OSDWIN0MD, OSD_OSDWIN0MD_RGB0E, BMPLUT_MODE);
            }
            break;
            case PSP_VPBE_OSD_1:
            {
                CSL_FINST(osdRegs->OSDWIN1MD, OSD_OSDWIN1MD_RGB1E, BMPLUT_MODE);
            }
            break;
            default:
            {

            }
            break;
        }
    }
}
/**
  * \brief To configure the OSD colour format RGB16 mode
  *
  */
void LLC_setOSDWinColorFormatRGB16(PSP_VPBE_Id osdId,Ptr regs)
{
    if(NULL!=regs)
    {
        osdRegs = (CSL_OsdRegs * )regs;
        switch(osdId)
        {
            case PSP_VPBE_OSD_0:
            {
                CSL_FINST(osdRegs->OSDWIN0MD, OSD_OSDWIN0MD_RGB0E, RGB16_MODE);
            }
            break;
            case PSP_VPBE_OSD_1:
            {
                CSL_FINST(osdRegs->OSDWIN1MD, OSD_OSDWIN1MD_RGB1E, RGB16_MODE);
            }
            break;
            default:
            {

            }
            break;
        }
    }
}

void LLC_setOSDWinCLUTSelectRAM(PSP_VPBE_Id osdId, Ptr regs)
{
    if(NULL!=regs)
    {
        osdRegs = (CSL_OsdRegs * )regs;
        switch(osdId)
        {
            case PSP_VPBE_OSD_0:
            {
                CSL_FINST(osdRegs->OSDWIN0MD,OSD_OSDWIN0MD_CLUTS0,RAM_LUT);
            }
            break;
            case PSP_VPBE_OSD_1:
            {
                CSL_FINST(osdRegs->OSDWIN1MD,OSD_OSDWIN1MD_CLUTS1,RAM_LUT);
            }
            break;
            default:
            {

            }
            break;
        }
    }
}


/**
  * \brief To configure the OSD DVD mode ON
  *
  */
void LLC_setOSDWinDVDMode(PSP_VPBE_Id osdId,Ptr regs)
{
    if(NULL!=regs)
    {
        osdRegs = (CSL_OsdRegs * )regs;
        switch(osdId)
        {
            case PSP_VPBE_OSD_0:
            {
                CSL_FINST(osdRegs->OSDWIN0MD , OSD_OSDWIN0MD_DVDE0, DVDBMP);
            }
            break;
            case PSP_VPBE_OSD_1:
            {
                CSL_FINST(osdRegs->OSDWIN1MD, OSD_OSDWIN1MD_DVDE1, DVDBMP);
            }
            break;
            default:
            {

            }
            break;
        }
    }
}
/**
  * \brief To configure the OSD DVD mode Off
  *
  */
void LLC_setOSDWinNORMALMode(PSP_VPBE_Id osdId,Ptr regs)
{
    if(NULL!=regs)
    {
        osdRegs = (CSL_OsdRegs * )regs;
        switch(osdId)
        {
            case PSP_VPBE_OSD_0:
            {
                CSL_FINST(osdRegs->OSDWIN0MD , OSD_OSDWIN0MD_DVDE0, NORMALBMP);
            }
            break;
            case PSP_VPBE_OSD_1:
            {
                CSL_FINST(osdRegs->OSDWIN1MD, OSD_OSDWIN1MD_DVDE1, NORMALBMP);
            }
            break;
            default:
            {

            }
            break;
        }
    }
}
void LLC_setOSDWinRAMWRMode(PSP_VPBERAMWRMode mode ,Ptr regs)
{
    if(NULL!= regs)
    {
        osdRegs = (CSL_OsdRegs * )regs;
        if(PSP_VPBE_RAMWR_DVD_MODE == mode)
        {
            CSL_FINST(osdRegs->MISCCTL, OSD_MISCCTL_CLUTWR_DVD, DVDMODE);
        }
        else
        {
            CSL_FINST(osdRegs->MISCCTL, OSD_MISCCTL_CLUTWR_DVD, NORMAL);
        }
    }
}

Bool LLC_getOSDWinCPBSYStatus(Ptr regs)
{
    Bool status;
    if(NULL!=regs)
    {
        osdRegs = (CSL_OsdRegs * )regs;
        status = (Bool)CSL_FEXT(osdRegs->MISCCTL,OSD_MISCCTL_CPBSY);
    }
    return status;
}
/**************************************************************************
            FUNCTIONS SPECIFIC TO VIDEO(VIDEO 0 and VIDEO 1) PLANE
***************************************************************************/

/**
  * \brief to set video chroma order to YCbCr
  *
  */
void LLC_setVidChromaOrderYCbCr(PSP_VPBE_Id vidId,Ptr regs)
{
    if(NULL!=regs)
    {

        osdRegs = (CSL_OsdRegs * )regs;
        switch(vidId)
        {
            case PSP_VPBE_VIDEO_0:
            {
                CSL_FINST(osdRegs->MODE, OSD_MODE_CS, CB_CR);
            }
            break;
            case PSP_VPBE_VIDEO_1:
            {
                CSL_FINST(osdRegs->MODE, OSD_MODE_CS, CB_CR);
            }
            break;
            default:
            {

            }
            break;
        }
    }
}

/**
  * \brief to set video chroma order  to YCrCb
  *
  */
void LLC_setVidChromaOrderYCrCb(PSP_VPBE_Id vidId,Ptr regs)
{
    if(NULL!=regs)
    {
        osdRegs = (CSL_OsdRegs * )regs;

        switch(vidId)
        {
            case PSP_VPBE_VIDEO_0:
            {
                CSL_FINST(osdRegs->MODE, OSD_MODE_CS, CR_CB);
            }
            break;
            case PSP_VPBE_VIDEO_1:
            {
                CSL_FINST(osdRegs->MODE, OSD_MODE_CS, CR_CB);
            }
            break;
            default:
            {

            }
            break;
        }
    }
}

/**
  * \brief to set video colour format to RGB888
  *
  */
void LLC_setVidColorFormatRGB888(PSP_VPBE_Id vidId,Ptr regs)
{
    if(NULL!=regs)
    {

        osdRegs = (CSL_OsdRegs * )regs;

        switch(vidId)
        {
            case PSP_VPBE_VIDEO_0:
            {
                CSL_FINST(osdRegs->MISCCTL, OSD_MISCCTL_RGBWIN, VIDWIN0);
            }
            break;
            case PSP_VPBE_VIDEO_1:
            {
                CSL_FINST(osdRegs->MISCCTL, OSD_MISCCTL_RGBWIN, VIDWIN1);
            }
            break;
            default:
            {

            }
            break;
        }
    }
}

/**
  * \brief to set video colour format to RGB888 enable
  *
  */
void LLC_setRGB888ModeEnable(PSP_VPBE_Id vidId,Ptr regs)
{
    if(NULL!=regs)
    {

        osdRegs = (CSL_OsdRegs * )regs;
        switch(vidId)
        {
            case PSP_VPBE_VIDEO_0:
            {
                CSL_FINST(osdRegs->MISCCTL, OSD_MISCCTL_RGBEN, ENABLE);
            }
            break;
            case PSP_VPBE_VIDEO_1:
            {
                CSL_FINST(osdRegs->MISCCTL, OSD_MISCCTL_RGBEN, ENABLE);
            }
            break;
            default:
            {

            }
            break;
        }
    }
}

/**
  * \brief to set video colour format to RGB888 disable
  *
  */
void LLC_setRGB888ModeDisable(PSP_VPBE_Id vidId,Ptr regs)
{
    if(NULL!=regs)
    {

        osdRegs = (CSL_OsdRegs * )regs;
        switch(vidId)
        {
            case PSP_VPBE_VIDEO_0:
            {
                CSL_FINST(osdRegs->MISCCTL, OSD_MISCCTL_RGBEN, DISABLE);
            }
            break;
            case PSP_VPBE_VIDEO_1:
            {
                CSL_FINST(osdRegs->MISCCTL, OSD_MISCCTL_RGBEN, DISABLE);
            }
            break;
            default:
            {

            }
            break;
        }
    }
}


/**
  * \brief To set video display start position
  *
  */
void LLC_setDisplayStartPosition(Ptr regs, Uint32 baseX, Uint32 baseY)
{
    if(NULL!=regs)
    {
        osdRegs = (CSL_OsdRegs * )regs;
        osdRegs->BASEPX = baseX;
        osdRegs->BASEPY = baseY;
    }
}

/**
  *\brief This function get the Venc field ID
  *
  */
Bool LLC_getOSDEngineStat(PSP_VPBE_Id osdId,Ptr regs)
{
    Bool value;
    if(NULL!=regs)
    {
        osdRegs = (CSL_OsdRegs * )regs;
        switch(osdId)
        {
            case PSP_VPBE_VIDEO_0:
            {
                value = (Bool)CSL_FEXT(osdRegs->VIDWINMD, OSD_VIDWINMD_ACT0);
            }
            break;
            case PSP_VPBE_VIDEO_1:
            {
                value = (Bool)CSL_FEXT(osdRegs->VIDWINMD, OSD_VIDWINMD_ACT1);

            }
            break;
            case PSP_VPBE_OSD_0:
            {
                value = (Bool)CSL_FEXT(osdRegs->OSDWIN0MD, OSD_OSDWIN0MD_OACT0);
            }
            break;
            case PSP_VPBE_OSD_1:
            {
                value = (Bool)CSL_FEXT(osdRegs->OSDWIN1MD, OSD_OSDWIN1MD_OACT1);
            }
            break;
            default:
            {

            }
            break;
        }
    }
    return value;
}
