/******************************************************************************
**+-------------------------------------------------------------------------+**
**|                            ****                                         |**
**|                            ****                                         |**
**|                            ******o***                                   |**
**|                      ********_///_****                                  |**
**|                      ***** /_//_/ ****                                  |**
**|                       ** ** (__/ ****                                   |**
**|                           *********                                     |**
**|                            ****                                         |**
**|                            ***                                          |**
**|                                                                         |**
**|         Copyright (c) 2006-2010 Texas Instruments Incorporated          |**
**|                        ALL RIGHTS RESERVED                              |**
**|                                                                         |**
**| Permission is hereby granted to licensees of Texas Instruments          |**
**| Incorporated (TI) products to use this computer program for the sole    |**
**| purpose of implementing a licensee product based on TI products.        |**
**| No other rights to reproduce, use, or disseminate this computer         |**
**| program, whether in part or in whole, are granted.                      |**
**|                                                                         |**
**| TI makes no representation or warranties with respect to the            |**
**| performance of this computer program, and specifically disclaims        |**
**| any responsibility for any damages, special or consequential,           |**
**| connected with the use of this program.                                 |**
**|                                                                         |**
**+-------------------------------------------------------------------------+**
******************************************************************************/

/**
 *  \file   llc_vpbeOsd.h
 *
 *  \brief  VPBE LLC layer Function dependencies
 *
 *  This file contains the dependencies of LLC layer functions
 *
 *  (C) Copyright 2010, Texas Instruments, Inc
 *
 *  \note       Set tabstop to 4 (:se ts=4) while viewing this file in an
 *              editor
 *
 *  \author     Maulik Desai
 *
 *  \version    0.1     Created
 */

#ifndef _LLC_VPBEOSD_H
#define _LLC_VPBEOSD_H

#ifdef __cplusplus
extern "C" {
#endif

/******************************************************************************
                                  Functions
******************************************************************************/
/**
  * \brief To Store the Reset Value of Osd Register.
  *
  * \param  regs        [IN]        Handle to access hardware register.
  *
  */

void LLC_ResetOsdReg(Ptr regs);
/**
  * \brief To configure the OSD display mode interlaced
  *
  *  \param osdId       [IN]        VIDEO/OSD planes id(Either 0 or 1).
  * \param  regs        [IN]        Handle to access hardware register.
  *
  */
void LLC_setOsdModeInterlaced(PSP_VPBE_Id osdId,Ptr regs);

/**
  * \brief To configure the OSD display mode Progressive
  *
  *  \param osdId       [IN]        VIDEO/OSD planes id(Either 0 or 1).
  * \param  regs        [IN]        Handle to access hardware register.
  *
  */
void LLC_setOsdModeProgressive(PSP_VPBE_Id osdId,Ptr regs);
/**
  * \brief To configure the OSD display ON
  *
  *  \param osdId       [IN]    VIDEO/OSD planes id(Either 0 or 1).
  * \param  regs        [IN]    Handle to access hardware register
  *
  */
void LLC_setOsdDisplayOn(PSP_VPBE_Id osdId,Ptr regs);
/**
  * \brief To configure the OSD display OFF
  *
  *  \param osdId       [IN]    VIDEO/OSD planes id(Either 0 or 1).
  * \param  regs        [IN]     Handle to access hardware register
  *
  */
void LLC_setOsdDisplayOff(PSP_VPBE_Id osdId,Ptr regs);

/**
  * \brief To configure the OSD display screen width
  *
  * \param osdId        [IN]     VIDEO/OSD planes id(Either 0 or 1).
  * \param  regs        [IN]     Handle to access hardware register
  * \param planeWidth   [IN]     Value of plane width
  *
  */
void LLC_setOsdDisplayScreenWidth(PSP_VPBE_Id osdId,Ptr regs,Uint32 planeWidth);
/**
  * \brief To configure the OSD display screen height
  *
  *  \param osdId       [IN]     VIDEO/OSD planes id(Either 0 or 1).
  * \param  regs        [IN]     Handle to access hardware register
  * \param  planeHeight [IN]     Value of plane height
  *
  */
void LLC_setOsdDisplayScreenHeight(PSP_VPBE_Id osdId,Ptr regs,Uint32 planeHeight);
/**
  * \brief To configure the OSD display screen left margin
  *
  *  \param osdId       [IN]    VIDEO/OSD planes id(Either -0 or 1).
  * \param  regs        [IN]     Handle to access hardware register
  * \param  lMargin     [IN]     Value of left margin
  *
  */
void LLC_setOsdDisplayLeftMargin(PSP_VPBE_Id osdId,Ptr regs,Uint32 lMargin);
/**
  * \brief To configure the OSD display screen top margin
  *
  *  \param osdId       [IN]    VIDEO/OSD planes id(Either -0 or 1).
  * \param  regs        [IN]     Handle to access hardware register
  * \param tMargin      [IN]     Value of top margin
  *
  */
void LLC_setOsdDisplayTopMargin(PSP_VPBE_Id osdId,Ptr regs,Uint32 tMargin);
/**
  * \brief To configure the OSD frame buffer start address
  *
  *  \param osdId       [IN]    VIDEO/OSD planes id(Either -0 or 1).
  * \param  regs        [IN]     Handle to access hardware register
  * \param  fbPtr       [IN]     Handle to pass address value
  *
  */
void LLC_setOsdFBStartAddress(PSP_VPBE_Id osdId,Ptr regs,Ptr fbPtr);
/**
  * \brief To configure the OSD offset
  *
  *  \param osdId       [IN]    VIDEO/OSD planes id(Either -0 or 1).
  * \param  regs        [IN]     Handle to access hardware register
  * \param  offset      [IN]     Offset value
  *
  */
void LLC_setOsdOffset(PSP_VPBE_Id osdId,Ptr regs,Uint32 offset);
/**
 *  \brief  This function is used to configure hardware register to Enable the
 *          Horizontal Zoom by 1X/2X/4X in VIDEO/OSD(On Screen Display) Plane.
 *
 *  This function returns the SUCCESS/FAILURE status of the operation.
 *
 *  \param osdId            [IN]    VIDEO/OSD planes id(Either 0 or 1).
 *  \param ScalingFactor    [IN]    Scaling Factor(2X/4X)
 *  \param  regs            [IN]    Handle to access hardware register.
 *
 *  \returns                    Returns SUCCESS/FAILURE
 */
Bool LLC_setOsdHorZoom(PSP_VPBE_Id osdId,PSP_VPBEScalingFactor ScalingFactor ,Ptr regs);
/**
 *  \brief  This function is used to configure hardware register to Enable the
 *          Vertical Zoom by 1X/2X/4X in VIDEO/OSD(On Screen Display) Plane.
 *
 *  This function returns the SUCCESS/FAILURE status of the operation.
 *
 *  \param osdId            [IN]    VIDEO/OSD planes id(Either -0 or 1).
 *  \param ScalingFactor    [IN]    Scaling Factor(2X/4X)
 *  \param  regs            [IN]    Handle to access hardware register.
 *
 *  \returns                       Returns SUCCESS/FAILURE'
 */
Bool LLC_setOsdVertZoom(PSP_VPBE_Id osdId,PSP_VPBEScalingFactor ScalingFactor ,Ptr regs);
/**
 *  \brief  This function is used to configure hardware register to Enable
 *          Horizonatal expansion by 9 / 8 format in VIDEO/OSD Plane.
 *
 *  This function returns the SUCCESS/FAILURE status of the operation.
 *
 *  \param osdId        [IN]    VIDEO/OSD planes id(Either -0 or 1).
 *  \param HExpFactor   [IN]    Horizontal Expansion Factor
 *  \param  regs        [IN]    Handle to access hardware register.
 *
 *  \returns                    Returns SUCCESS/FAILURE
 */

Bool LLC_setOsdHorzExp_9_8(PSP_VPBE_Id osdId,PSP_VPBEExpansionFactor HExpFactor,Ptr regs);
/**
 *  \brief  This function is used to configure hardware register to Enable
 *          Vertical expansion by 6/5 format in VIDEO/OSD Plane.
 *
 *  This function returns the SUCCESS/FAILURE status of the operation.
 *
 *  \param osdId        [IN]    VIDEO/OSD planes id(Either -0 or 1).
 *  \param VExpFactor   [IN]    Vertical Expansion Factor
 *  \param  regs        [IN]    Handle to access hardware register.
 *
 *  \returns                    Returns SUCCESS/FAILURE'
 */
Bool LLC_setOsdVertExp_6_5(PSP_VPBE_Id osdId,PSP_VPBEExpansionFactor VExpFactor,Ptr regs);
/**
 *  \brief  This function is used to configure hardware register to Disable the
 *          Zoom and it will put zoom in identity expansion by 6/5 format in
 *          VIDEO/OSD(On Screen Display) Plane.
 *
 *  This function returns the SUCCESS/FAILURE status of the operation.
 *
 *  \param osdId        [IN]    VIDEO/OSD planes id(Either -0 or 1).
 *  \param  regs        [IN]    Handle to access hardware register.
 *
 *  \returns                    Returns SUCCESS/FAILURE'
 */
void LLC_setOsdZoomDisable(PSP_VPBE_Id osdId, Ptr regs);

/************************************************************************************
                    FUNCTIONS SPECIFIC TO OSD(OSD0 and OSD1) PLANES
************************************************************************************/

/**
 *  \brief This function is used to configure hardware register to set the
 *         colour of pixel later which is used in the Transparency functionality
 *         in OSD(On Screen Display) Plane.
 *
 *  This function returns the SUCCESS/FAILURE status of the operation.
 *
 *  \param  osdId       [IN]        Osd plane id(Either 0 or 1).
 *  \param  regs        [IN]        Handle to access hardware register.
 *  \param  colour      [IN]        colour values.
 *
 *  \returns                        Returns SUCCESS/FAILURE'
 */
Bool LLC_setOSDWinTransparencyColour(PSP_VPBE_Id osdId, Ptr regs, Uint32 colour);

/**
 *  \brief   This function is used to configure hardware register to enable the
 *           Transparency functionality OSD(On Screen Display) Plane.
 *
 *  This function returns the SUCCESS/FAILURE status of the operation.
 *
 *  \param  osdId       [IN]        Osd plane id(Either 0 or 1).
 *  \param  regs        [IN]        Handle to access hardware register.
 *
 *  \returns                        Returns SUCCESS/FAILURE'
 */
Bool LLC_setOSDWinTransparencyEnable(PSP_VPBE_Id osdId, Ptr regs);

/**
 *  \brief  This function is used to configure hardware register to Disable
 *          the Transparency functionality OSD(On Screen Display) Plane.
 *
 *  This function returns the SUCCESS/FAILURE status of the operation.
 *
 *  \param  osdId       [IN]        Osd plane id(Either 0 or 1).
 *  \param  regs        [IN]        Handle to access hardware register.
 *
 *  \returns                        Returns SUCCESS/FAILURE'
 */
Bool LLC_setOSDWinTransparencyDisable(PSP_VPBE_Id osdId, Ptr regs);

/**
  * \brief To configure the main CLUT entry for the LUMA color space
  *
  * \param  regs        [IN]    Handle to access hardware register
  * \param value_Y      [IN]    value of the entry
  *
  */
void LLC_setClutEntry_Y(Ptr regs , Uint8 value_Y);

/**
  * \brief To configure the main CLUT entry for the Chroma-Blue color space
  *
  * \param  regs        [IN]    Handle to access hardware register
  * \param value_Cb     [IN]    value of the entry
  *
  */
void LLC_setClutEntry_Cb(Ptr regs , Uint8 value_Cb);
/**
  * \brief To configure the main CLUT entry for the Chroma-Red color space
  *
  * \param  regs        [IN]    Handle to access hardware register
  * \param value_Cr     [IN]    value of the entry
  *
  */
void LLC_setClutEntry_Cr(Ptr regs , Uint8 value_Cr);
/**
  * \brief To configure the main CLUT entry Address
  *
  * \param  regs        [IN]    Handle to access hardware register
  * \param index        [IN]    index of the address
  *
  */

void LLC_setClutEntry_Addr(Ptr regs , Uint32 index);
/**
  * \brief To configure the main CLUT entry Address
  *
  * \param  osdId       [IN]    Id of the OSD plane
  * \param  regs        [IN]    Handle to access hardware register
  * \param table        [IN]    Pointer of the CLUT values
  *
  */

void LLC_setBMPCLUTEntry(PSP_VPBE_Id osdId, Ptr regs ,const Uint8 * table);
/**
  * \brief To configure the OSD pixel bit width to 1 bit
  *
  * \param  osdId       [IN]     Osd plane id(Either 0 or 1)
  * \param  regs        [IN]     Handle to access hardware register
  *
  */

void LLC_setOSDWinPixelBitWidth1Bit(PSP_VPBE_Id osdId,Ptr regs);
/**
  * \brief To configure the OSD pixel bit width to 2 bit
  *
  * \param  osdId       [IN]     Osd plane id(Either 0 or 1)
  * \param  regs        [IN]     Handle to access hardware register
  *
  */

void LLC_setOSDWinPixelBitWidth2Bit(PSP_VPBE_Id osdId,Ptr regs);
/**
  * \brief To configure the OSD pixel bit width to 4 bit
  *
  * \param  osdId       [IN]     Osd plane id(Either 0 or 1)
  * \param  regs        [IN]     Handle to access hardware register
  *
  */
void LLC_setOSDWinPixelBitWidth4Bit(PSP_VPBE_Id osdId,Ptr regs);
/**
  * \brief To configure the OSD pixel bit width to 8bit
  *
  * \param  osdId       [IN]     Osd plane id(Either 0 or 1)
  * \param regs         [IN]     Handle to access hardware register
  *
  */

void LLC_setOSDWinPixelBitWidth8Bit(PSP_VPBE_Id osdId,Ptr regs);
/**
  * \brief To configure the OSD blending ratio
  *
  * \param  osdId       [IN]     Osd plane id(Either 0 or 1)
  * \param  regs        [IN]     Handle to access hardware register
  * \param  blendRatio  [IN]     Blend ratio value
  *
  */
void LLC_setOSDWinBlendingRatio(PSP_VPBE_Id osdId,Ptr regs,Uint32 blendRatio);
/**
  * \brief To configure the OSD attribute mode enable
  *
  * \param   regs       IN]     Handle to access hardware register
  *
  */
void LLC_setOSDWin1AttrModeEnable(Ptr regs);
/**
  * \brief To configure the OSD attribute mode disable
  *
  * \param  regs        [IN]     Handle to access hardware register
  *
  */
void LLC_setOSDWin1AttrModeDisable(Ptr regs);
/**
  * \brief To configure the OSD colour format BMPLUT mode
  *
  * \param  osdId       [IN]     Osd plane id(Either 0 or 1)
  * \param  regs        [IN]     Handle to access hardware register
  *
  */

void LLC_setOSDWinColorFormatBMPLUTMode(PSP_VPBE_Id osdId,Ptr regs);
/**
  * \brief To configure the OSD colour format RGB16 mode
  *
  * \param  osdId       [IN]     Osd plane id(Either 0 or 1)
  * \param  regs        [IN]     Handle access hardware register
  *
  */

void LLC_setOSDWinColorFormatRGB16(PSP_VPBE_Id osdId,Ptr regs);
/**
  * \brief To configure the OSDWindows CLUT SELECT to RAM
  *
  * \param  osdId       [IN]     Osd plane id(Either 0 or 1)
  * \param  regs        [IN]     handle to access hardware register
  *
  */
void LLC_setOSDWinCLUTSelectRAM(PSP_VPBE_Id osdId, Ptr regs);
/**
  * \brief To configure the OSDWindows NORMAL mode
  *
  * \param  osdId       [IN]     Osd plane id(Either 0 or 1)
  * \param  regs        [IN]     handle to access hardware register
  *
  */
void LLC_setOSDWinNORMALMode(PSP_VPBE_Id osdId,Ptr regs);
/**
  * \brief To configure the OSDWindows DVD mode
  *
  * \param  osdId       [IN]     Osd plane id(Either 0 or 1)
  * \param  regs        [IN]     handle to access hardware register
  *
  */
void LLC_setOSDWinDVDMode(PSP_VPBE_Id osdId,Ptr regs);
/**
  * \brief To configure the OSDWindows RAM WR  mode
  *
  * \param  mode        [IN]     RAM WR mode -(NORMAL or DVD)
  * \param  regs        [IN]     handle to access hardware register
  *
  */
void LLC_setOSDWinRAMWRMode(PSP_VPBERAMWRMode mode ,Ptr regs);
/**
  * \brief To Get the CPBSY Status
  *
  * \param  regs        [IN]     handle to access hardware register
  *
  */
Bool LLC_getOSDWinCPBSYStatus(Ptr regs);

/**************************************************************************
             FUNCTIONS SPECIFIC TO VIDEO(VIDEO 0 and VIDEO 1) PLANES
***************************************************************************/
/**
  * \brief  This will configure the video chroma order YCbCr in Video plane
  *
  * \param  vidId       [IN]     Video plane id(Either 0 or 1)
  * \param  regs        [IN]     Handle to access hardware register
  *
  */
void LLC_setVidChromaOrderYCbCr(PSP_VPBE_Id vidId,Ptr regs);
/**
  * \brief  This will configure the video chroma order YCrCb in Video plane
  *
  * \param  vidId       [IN]     Video plane id(Either 0 or 1)
  * \param  regs        [IN]     Handle to access hardware register
  *
  */

void LLC_setVidChromaOrderYCrCb(PSP_VPBE_Id vidId,Ptr regs);


/**
  * \brief  This will configure the video colour format RGB888 in Video plane
  *
  * \param  vidId       [IN]     Video plane id(Either 0 or 1)
  * \param  regs        [IN]     Handle to access hardware register
  *
  */

void LLC_setVidColorFormatRGB888(PSP_VPBE_Id vidId,Ptr regs);
/**
  * \brief  This will enable the video RGB888ModeEnable in Video plane
  *
  * \param  vidId       [IN]     Video plane id(Either 0 or 1)
  * \param  regs        [IN]     Handle to access hardware register
  *
  */
void LLC_setRGB888ModeEnable(PSP_VPBE_Id vidId,Ptr regs);
/**
  * \brief  This will disable the video RGB888ModeEnable in Video plane
  *
  * \param  vidId       [IN]     Video plane id(Either 0 or 1)
  * \param  regs        [IN]     Handle to access hardware register
  *
  */
void LLC_setRGB888ModeDisable(PSP_VPBE_Id vidId,Ptr regs);
/**
  * \brief  To configure the proper video display start position in Video plane
  *
  * \param  regs        [IN]    Handle to access hardware register
  * \param  baseX       [IN]    Base X value
  * \param  baseY       [IN]    Base Y value
  *
  */
void LLC_setDisplayStartPosition(Ptr regs, Uint32 baseX, Uint32 baseY);
/**
  * \brief To configure the OSD display ON
  *
  *  \param osdId       [IN]    VIDEO/OSD planes id(Either 0 or 1).
  * \param  regs        [IN]    Handle to access hardware register
  *
  */
Bool LLC_getOSDEngineStat(PSP_VPBE_Id osdId,Ptr regs);

#ifdef __cplusplus
}
#endif

#endif /* _LLC_VPBEOSD_H */
