/******************************************************************************
**+-------------------------------------------------------------------------+**
**|                            ****                                         |**
**|                            ****                                         |**
**|                            ******o***                                   |**
**|                      ********_///_****                                  |**
**|                      ***** /_//_/ ****                                  |**
**|                       ** ** (__/ ****                                   |**
**|                           *********                                     |**
**|                            ****                                         |**
**|                            ***                                          |**
**|                                                                         |**
**|         Copyright (c) 2006-2010 Texas Instruments Incorporated          |**
**|                        ALL RIGHTS RESERVED                              |**
**|                                                                         |**
**| Permission is hereby granted to licensees of Texas Instruments          |**
**| Incorporated (TI) products to use this computer program for the sole    |**
**| purpose of implementing a licensee product based on TI products.        |**
**| No other rights to reproduce, use, or disseminate this computer         |**
**| program, whether in part or in whole, are granted.                      |**
**|                                                                         |**
**| TI makes no representation or warranties with respect to the            |**
**| performance of this computer program, and specifically disclaims        |**
**| any responsibility for any damages, special or consequential,           |**
**| connected with the use of this program.                                 |**
**|                                                                         |**
**+-------------------------------------------------------------------------+**
******************************************************************************/

/**
 *  \file   llc_vpbeVenc.c
 *
 *  \brief  VPBE LLC layer Functions
 *
 *  This file contains the Implementation details of LLC layer functions
 *
 *  (C) Copyright 2010, Texas Instruments, Inc
 *
 *  \note       Set tabstop to 4 (:se ts=4) while viewing this file in an
 *              editor
 *
 *  \author     Maulik Desai
 *
 *  \version    0.1     Created
 */

/******************************************************************************
                            Header File Inclusion
******************************************************************************/
#include <ti/sdo/pspdrivers/common/psp_common.h>
#include <ti/sdo/pspdrivers/drivers/vpbe/src/llc_vpbeVenc.h>
#include <ti/sdo/pspdrivers/soc/dm6437/dsp/cslr_venc.h>
/******************************************************************************
                                Data-Structures
******************************************************************************/
/**
  *  VENC CSL Overlay Register Structure Handle
  */
static  CSL_VencRegs * vencRegs;

/******************************************************************************
                                    Functions
******************************************************************************/
/**
  *\brief This function reset the Venc Register
  *
  */
void LLC_ResetVencReg(Ptr llcRegisterBaseAddr)
{
    if(NULL!=llcRegisterBaseAddr)
    {
        vencRegs = (CSL_VencRegs * )llcRegisterBaseAddr;

        vencRegs->VMOD      = (Uint32)CSL_VENC_VMOD_RESETVAL;
        vencRegs->VIDCTL    = (Uint32)CSL_VENC_VIDCTL_RESETVAL;
        vencRegs->VDPRO     = (Uint32)CSL_VENC_VDPRO_RESETVAL;
        vencRegs->SYNCCTL   = (Uint32)CSL_VENC_SYNCCTL_RESETVAL;
        vencRegs->YCCCTL    = (Uint32)CSL_VENC_YCCCTL_RESETVAL;
        vencRegs->RGBCTL    = (Uint32)CSL_VENC_RGBCTL_RESETVAL;
        vencRegs->VSTAT     =  (Uint32)CSL_VENC_VSTAT_RESETVAL;
        vencRegs->DACTST    =  (Uint32)CSL_VENC_DACTST_RESETVAL;
        vencRegs->CVBS      =  (Uint32)CSL_VENC_CVBS_RESETVAL;
        vencRegs->CMPNT     =  (Uint32)CSL_VENC_CMPNT_RESETVAL;
        vencRegs->DACSEL    =  (Uint32)CSL_VENC_DACSEL_RESETVAL;
        vencRegs->OSDCLK0   =  (Uint32)CSL_VENC_OSDCLK0_RESETVAL;
        vencRegs->OSDCLK1   =  (Uint32)CSL_VENC_OSDCLK1_RESETVAL;
    }

}
/**
  *\brief This function get the Venc field ID
  *
  */
Bool LLC_getVencField(Ptr llcRegisterBaseAddr)
{
    Bool value;
    if(NULL!=llcRegisterBaseAddr)
    {
        vencRegs = (CSL_VencRegs * )llcRegisterBaseAddr;
        value = (Bool)CSL_FEXT(vencRegs->VSTAT, VENC_VSTAT_FIDST);
    }
    return value;
}
/**
  * \brief This function configure the DAC B normal mode for VENC
  *
  */
void LLC_setDacBNormalMode(Ptr llcRegisterBaseAddr)
{
    if(NULL!=llcRegisterBaseAddr)
    {
        vencRegs = (CSL_VencRegs * )llcRegisterBaseAddr;
        CSL_FINST(vencRegs->DACTST, VENC_DACTST_DAPD1, NORMAL);
    }
}
/**
  * \brief This function configure the DAC B power down mode for VENC
  *
  */
void LLC_setDacBPowerDownMode(Ptr llcRegisterBaseAddr)
{

    if(NULL!=llcRegisterBaseAddr)
    {
        vencRegs = (CSL_VencRegs * )llcRegisterBaseAddr;
        CSL_FINST(vencRegs->DACTST, VENC_DACTST_DAPD1, PWRDN);
    }
}
/**
  * \brief This function configure the DAC C normal mode for VENC
  *
  */
void LLC_setDacCNormalMode(Ptr llcRegisterBaseAddr)
{

    if(NULL!=llcRegisterBaseAddr)
    {
        vencRegs = (CSL_VencRegs * )llcRegisterBaseAddr;
        CSL_FINST(vencRegs->DACTST, VENC_DACTST_DAPD2, NORMAL);
    }
}
/**
  * \brief This function configure the DAC C power down mode for VENC
  *
  */
void LLC_setDacCPowerDownMode(Ptr llcRegisterBaseAddr)
{

    if(NULL!=llcRegisterBaseAddr)
    {
        vencRegs = (CSL_VencRegs * )llcRegisterBaseAddr;
        CSL_FINST(vencRegs->DACTST, VENC_DACTST_DAPD2, PWRDN);
    }
}
/**
  * \brief This function configure the DAC D normal mode for VENC
  *
  */
void LLC_setDacDNormalMode(Ptr llcRegisterBaseAddr)
{

    if(NULL!=llcRegisterBaseAddr)
    {
        vencRegs = (CSL_VencRegs * )llcRegisterBaseAddr;
        CSL_FINST(vencRegs->DACTST, VENC_DACTST_DAPD3, NORMAL);
    }
}
/**
  * \brief This function configure the DAC D power down mode for VENC
  *
  */
void LLC_setDacDPowerDownMode(Ptr llcRegisterBaseAddr)
{

    if(NULL!=llcRegisterBaseAddr)
    {
        vencRegs = (CSL_VencRegs * )llcRegisterBaseAddr;
        CSL_FINST(vencRegs->DACTST, VENC_DACTST_DAPD3, PWRDN);
    }
}
/**
  * \brief This function configure the DAC B output as video format CVBS
  *
  */
void LLC_setDacBOutVidFormatCVBS(Ptr llcRegisterBaseAddr)
{

    if(NULL!=llcRegisterBaseAddr)
    {
        vencRegs = (CSL_VencRegs * )llcRegisterBaseAddr;
        CSL_FINST(vencRegs->DACSEL, VENC_DACSEL_DA1S, CVBS);
    }
}
/**
  * \brief This function configure the DAC C output as video format CVBS
  *
  */
void LLC_setDacCOutVidFormatCVBS(Ptr llcRegisterBaseAddr)
{

    if(NULL!=llcRegisterBaseAddr)
    {
        vencRegs = (CSL_VencRegs * )llcRegisterBaseAddr;
        CSL_FINST(vencRegs->DACSEL, VENC_DACSEL_DA2S, CVBS);
    }
}
/**
  * \brief This function configure the DAC D output as video format CVBS
  *
  */
void LLC_setDacDOutVidFormatCVBS(Ptr llcRegisterBaseAddr)
{

    if(NULL!=llcRegisterBaseAddr)
    {
        vencRegs = (CSL_VencRegs * )llcRegisterBaseAddr;
        CSL_FINST(vencRegs->DACSEL, VENC_DACSEL_DA3S, CVBS);
    }
}
/**
  * \brief This function configure the DAC B output video format CompY
  *
  */
void LLC_setDacBOutVidFormatCompY(Ptr llcRegisterBaseAddr)
{
    if(NULL!=llcRegisterBaseAddr)
    {
        vencRegs = (CSL_VencRegs * )llcRegisterBaseAddr;
        CSL_FINST(vencRegs->DACSEL, VENC_DACSEL_DA1S, Y_G);
    }
}
/**
  * \brief This function configure the DAC C output video format CompPb
  *
  */
void LLC_setDacCOutVidFormatCompPb(Ptr llcRegisterBaseAddr)
{
    if(NULL!=llcRegisterBaseAddr)
    {
        vencRegs = (CSL_VencRegs * )llcRegisterBaseAddr;
        CSL_FINST(vencRegs->DACSEL, VENC_DACSEL_DA2S, PB_B);
    }
}
/**
  * \brief This function configure the DAC D output video format CompPr
  *
  */
void LLC_setDacDOutVidFormatCompPr(Ptr llcRegisterBaseAddr)
{
    if(NULL!=llcRegisterBaseAddr)
    {
        vencRegs = (CSL_VencRegs * )llcRegisterBaseAddr;
        CSL_FINST(vencRegs->DACSEL, VENC_DACSEL_DA3S, PR_R);
    }
}
/**
  * \brief This function configure the Venc plane as scan mode interlaced
  *
  */
void LLC_setVencScanModeInterlaced(Ptr llcRegisterBaseAddr)
{

    if(NULL!=llcRegisterBaseAddr)
    {
        vencRegs = (CSL_VencRegs * )llcRegisterBaseAddr;
        CSL_FINST(vencRegs->VMOD, VENC_VMOD_ITLC, INTERLACE);
    }
}
/**
  * \brief This function configure the Venc plane as scan mode Progressive
  *
  */
void LLC_setVencScanModeProgressive(Ptr llcRegisterBaseAddr)
{

    if(NULL!=llcRegisterBaseAddr)
    {
        vencRegs = (CSL_VencRegs * )llcRegisterBaseAddr;
        CSL_FINST(vencRegs->VMOD, VENC_VMOD_ITLC, NON_INTERLACE);
    }
}
/**
  * \brief This function enable the composite output
  *
  */
void LLC_setEnableCompositeOutput(Ptr llcRegisterBaseAddr)
{

    if(NULL!=llcRegisterBaseAddr)
    {
        vencRegs = (CSL_VencRegs * )llcRegisterBaseAddr;
        CSL_FINST(vencRegs->VMOD, VENC_VMOD_VIE, NORMAL_COMPOSITE_OUT);
    }
}
/**
  * \brief This function enable the fixed level output
  *
  */
void LLC_setEnableFixedLevelOutput(Ptr llcRegisterBaseAddr)
{

    if(NULL!=llcRegisterBaseAddr)
    {
        vencRegs = (CSL_VencRegs * )llcRegisterBaseAddr;
        CSL_FINST(vencRegs->VMOD, VENC_VMOD_VIE, FIXED_L_LEVEL_OUT);
    }
}
/**
  * \brief This function enable the Venc plane
  *
  */
void LLC_setVencEnable(Ptr llcRegisterBaseAddr)
{

    if(NULL!=llcRegisterBaseAddr)
    {
          vencRegs = (CSL_VencRegs * )llcRegisterBaseAddr;
          CSL_FINST(vencRegs->VMOD, VENC_VMOD_VENC, ENABLE);
    }
}
/**
  * \brief This function disable the Venc plane
  *
  */
void LLC_setVencDisable(Ptr llcRegisterBaseAddr)
{

    if(NULL!=llcRegisterBaseAddr)
    {
        vencRegs = (CSL_VencRegs * )llcRegisterBaseAddr;
        CSL_FINST(vencRegs->VMOD, VENC_VMOD_VENC, DISABLE);
    }
}
/**
  * \brief This function set the video output type NTSC
  *
  */
void LLC_setVideoOutputTYP_NTSC(Ptr llcRegisterBaseAddr)
{

    if(NULL!=llcRegisterBaseAddr)
    {
        vencRegs = (CSL_VencRegs * )llcRegisterBaseAddr;
        CSL_FINST(vencRegs->VMOD, VENC_VMOD_TVTYP, SDTV_NTSC);
    }
}
/**
  * \brief This function set video output PAL type
  *
  */
void LLC_setVideoOutputTYP_PAL(Ptr llcRegisterBaseAddr)
{

    if(NULL!=llcRegisterBaseAddr)
    {
        vencRegs = (CSL_VencRegs * )llcRegisterBaseAddr;
        CSL_FINST(vencRegs->VMOD, VENC_VMOD_TVTYP, SDTV_PAL);
    }
}
/**
  * \brief This function set video output 525p HDTV
  *
  */
void LLC_setVideoOutputTYP_525p_HDTV(Ptr llcRegisterBaseAddr)
{

    if(NULL!=llcRegisterBaseAddr)
    {
        vencRegs = (CSL_VencRegs * )llcRegisterBaseAddr;
        CSL_FINST(vencRegs->VMOD, VENC_VMOD_TVTYP, HDTV_525P);
    }
}
/**
  * \brief This function set video output 625p HDTV
  *
  */
void LLC_setVideoOutputTYP_625p_HDTV(Ptr llcRegisterBaseAddr)
{

    if(NULL!=llcRegisterBaseAddr)
    {
        vencRegs = (CSL_VencRegs * )llcRegisterBaseAddr;
        CSL_FINST(vencRegs->VMOD, VENC_VMOD_TVTYP, HDTV_625P);
    }
}

/**
  * \ This function set digital video output mode Ycc8
  *
  */
void LLC_setDigitalVidOutModeYcc8(Ptr llcRegisterBaseAddr)
{

    if(NULL!=llcRegisterBaseAddr)
    {
        vencRegs = (CSL_VencRegs * )llcRegisterBaseAddr;
        CSL_FINST(vencRegs->VMOD, VENC_VMOD_VDMD, YCBCR_8BIT);
    }
}
/**
  * \brief This function enable the video output REC656Mode
  *
  */
void LLC_setREC656Mode(Ptr llcRegisterBaseAddr)
{
    if(NULL!=llcRegisterBaseAddr)
    {
        vencRegs = (CSL_VencRegs * )llcRegisterBaseAddr;
        CSL_FINST(vencRegs->YCCCTL, VENC_YCCCTL_R656, REC656);
    }
}

/**
  * \brief This function set video output to SDTV Mode
  *
  */
void LLC_setVideoOutputSDTVMode(Ptr llcRegisterBaseAddr)
{

    if(NULL!=llcRegisterBaseAddr)
    {
        vencRegs = (CSL_VencRegs * )llcRegisterBaseAddr;
        CSL_FINST(vencRegs->VMOD, VENC_VMOD_HDMD, SDTV);
    }
}
/**
  * \brief This function set video output to HDTV Mode
  *
  */
void LLC_setVideoOutputHDTVMode(Ptr llcRegisterBaseAddr)
{

    if(NULL!=llcRegisterBaseAddr)
    {
        vencRegs = (CSL_VencRegs * )llcRegisterBaseAddr;
        CSL_FINST(vencRegs->VMOD, VENC_VMOD_HDMD, HDTV);
    }
}
/**
  * \brief  This function set OSD clock control0
  *
  */
void LLC_setOSDClockControl0(Ptr llcRegisterBaseAddr, Uint32 clkPatternBitWidth)
{

    if(NULL!=llcRegisterBaseAddr)
    {
        vencRegs = (CSL_VencRegs * )llcRegisterBaseAddr;
        CSL_FINS(vencRegs->OSDCLK0, VENC_OSDCLK0_OCPW, clkPatternBitWidth);
    }
}
/**
  * \brief This function set OSD clock control1
  *
  */
void LLC_setOSDClockControl1(Ptr llcRegisterBaseAddr, Uint32 clkPattern)
{

    if(NULL!=llcRegisterBaseAddr)
    {
        vencRegs = (CSL_VencRegs * )llcRegisterBaseAddr;
        CSL_FINS(vencRegs->OSDCLK1, VENC_OSDCLK0_OCPW, clkPattern);
    }
}
/**
  * \brief This function set S-Video-Y
  *
  */
void LLC_setDac1OutVidFormatSVidY(Ptr llcRegisterBaseAddr)
{

    if(NULL!=llcRegisterBaseAddr)
    {
        vencRegs = (CSL_VencRegs * )llcRegisterBaseAddr;
        CSL_FINST(vencRegs->DACSEL, VENC_DACSEL_DA1S, SVIDEO_Y);
    }
}
/**
  * \brief This function set S-Video-C
  *
  */
void LLC_setDac2OutVidFormatSVidC(Ptr llcRegisterBaseAddr)
{
    if(NULL!=llcRegisterBaseAddr)
    {
        vencRegs = (CSL_VencRegs * )llcRegisterBaseAddr;
        CSL_FINST(vencRegs->DACSEL, VENC_DACSEL_DA2S, SVIDEO_C);
    }
}

/*************************************YCC16 mode ************************/
/**
  * \ This function set digital video output mode Ycc8
  *
  */
void LLC_setDigitalVidOutModeYcc16(Ptr llcRegisterBaseAddr)
{
    if(NULL!=llcRegisterBaseAddr)
    {
        vencRegs = (CSL_VencRegs * )llcRegisterBaseAddr;
        CSL_FINST(vencRegs->VMOD, VENC_VMOD_VDMD, YCBCR_16BIT);
    }
}
void LLC_setLCDEnable(Ptr llcRegisterBaseAddr)
{
    if(NULL!=llcRegisterBaseAddr)
    {
        vencRegs = (CSL_VencRegs * )llcRegisterBaseAddr;
        CSL_FINST(vencRegs->LCDOUT, VENC_LCDOUT_OEE, ON);
    }

}
void LLC_setVLCKEnable(Ptr llcRegisterBaseAddr)
{
    if(NULL!=llcRegisterBaseAddr)
    {
        vencRegs = (CSL_VencRegs * )llcRegisterBaseAddr;
        CSL_FINST(vencRegs->VIDCTL, VENC_VIDCTL_VCLKE, ON);
        CSL_FINST(vencRegs->VIDCTL, VENC_VIDCTL_VCLKZ, HIGHIMPEDENCE);
    }

}

void LLC_setYCOutputDir(Ptr llcRegisterBaseAddr)
{
    if(NULL!=llcRegisterBaseAddr)
    {
        vencRegs = (CSL_VencRegs * )llcRegisterBaseAddr;
        CSL_FINST(vencRegs->VIDCTL, VENC_VIDCTL_YCDIR, OUTPUT);
        CSL_FINST(vencRegs->VIDCTL, VENC_VIDCTL_SYDIR, OUTPUT);
    }
}


/*Adding Code */
void LLC_setDigVideoOutputRGB666(Ptr llcRegisterBaseAddr)
{
    if(NULL!=llcRegisterBaseAddr)
    {
        vencRegs = (CSL_VencRegs * )llcRegisterBaseAddr;
        CSL_FINST(vencRegs->VMOD, VENC_VMOD_VDMD, RGB8_8BIT);
    }
}


/**
  * \brief      to set video timings as non-standard
  *
  */
void LLC_setVideoTimingNTSCPAL(Ptr llcRegisterBaseAddr)
{
    if(NULL!=llcRegisterBaseAddr)
    {
        vencRegs = (CSL_VencRegs * )llcRegisterBaseAddr;
        CSL_FINST(vencRegs->VMOD, VENC_VMOD_VMD, NTSC_PALTIMING);
    }
}
/**
  * \brief      to set video timings as non-standard
  *
  */
void LLC_setVideoTimingNotNTSCPAL(Ptr llcRegisterBaseAddr)
{
    if(NULL!=llcRegisterBaseAddr)
    {
        vencRegs = (CSL_VencRegs * )llcRegisterBaseAddr;
        CSL_FINST(vencRegs->VMOD, VENC_VMOD_VMD, NOTNTSC_PALTIMING);
    }
}

/**
  * \brief      to set VENC in the master mode
  *
  */
void LLC_setMasterMode(Ptr llcRegisterBaseAddr)
{
    if(NULL!=llcRegisterBaseAddr)
    {
        vencRegs = (CSL_VencRegs * )llcRegisterBaseAddr;
        CSL_FINST(vencRegs->VMOD, VENC_VMOD_SLAVE, MASTERMODE);
    }
}


/**
  * \brief      to set HD/VD SYNC signal direction as output
  *
  */
void LLC_setVencVDHDSyncDirOut(Ptr llcRegisterBaseAddr)
{
    if(NULL!=llcRegisterBaseAddr)
    {
        vencRegs = (CSL_VencRegs * )llcRegisterBaseAddr;
        CSL_FINST(vencRegs->VIDCTL, VENC_VIDCTL_SYDIR, OUTPUT);
    }
}

void LLC_setVencDataOut(Ptr llcRegisterBaseAddr)
{
    if(NULL!=llcRegisterBaseAddr)
    {
        vencRegs = (CSL_VencRegs * )llcRegisterBaseAddr;
        CSL_FINST(vencRegs->VIDCTL, VENC_VIDCTL_DOMD, NORMAL_OUT);
    }
}
/**
  * \brief      To enable VCLK output enable
  *
  */
void LLC_setEnableVCLKOutputEnable(Ptr llcRegisterBaseAddr)
{
    if(NULL!=llcRegisterBaseAddr)
    {
        vencRegs = (CSL_VencRegs * )llcRegisterBaseAddr;
        CSL_FINST(vencRegs->VIDCTL, VENC_VIDCTL_VCLKE, ON);
    }
}
/**
  * \brief      To enable VCLK pin output
  *
  */
void LLC_setEnableVCLKPinOutputEn(Ptr llcRegisterBaseAddr)
{
    if(NULL!=llcRegisterBaseAddr)
    {
        vencRegs = (CSL_VencRegs * )llcRegisterBaseAddr;
        CSL_FINST(vencRegs->VIDCTL, VENC_VIDCTL_VCLKZ, OUTPUT);
    }
}

/**
  * \brief      To set YC Pins in digital video output mode
  *
  */
void LLC_setYCPin_DigitalVideoOutput(Ptr llcRegisterBaseAddr)
{
    if(NULL!=llcRegisterBaseAddr)
    {
        vencRegs = (CSL_VencRegs * )llcRegisterBaseAddr;
        CSL_FINST(vencRegs->VIDCTL, VENC_VIDCTL_YCDIR,OUTPUT);
    }
}
/**
  * \brief      To enable VD Sync output
  *
  */
void LLC_setVencVDOutputEnable(Ptr llcRegisterBaseAddr)
{
    if(NULL!=llcRegisterBaseAddr)
    {
        vencRegs = (CSL_VencRegs * )llcRegisterBaseAddr;
        CSL_FINST(vencRegs->SYNCCTL, VENC_SYNCCTL_SYEV, ON);
    }
}
/**
  * \brief      To enable HD Sync output
  *
  */
void LLC_setVencHDOutputEnable(Ptr llcRegisterBaseAddr)
{
    if(NULL!=llcRegisterBaseAddr)
    {
        vencRegs = (CSL_VencRegs * )llcRegisterBaseAddr;
        CSL_FINST(vencRegs->SYNCCTL, VENC_SYNCCTL_SYEH, ON);
    }
}
/**
  * \brief      to set VD SYNC signal polarity as positive
  *
  */
void LLC_setVencVDSyncPolarityPos(Ptr llcRegisterBaseAddr)
{
    if(NULL!=llcRegisterBaseAddr)
    {
        vencRegs = (CSL_VencRegs * )llcRegisterBaseAddr;
        CSL_FINST(vencRegs->SYNCCTL, VENC_SYNCCTL_VPL, ACTIVEH);
    }
}
/**
  * \brief      to set HD SYNC signal polarity as negative
  *
  */
void LLC_setVencHDSyncPolarityNeg(Ptr llcRegisterBaseAddr)
{
    if(NULL!=llcRegisterBaseAddr)
    {
        vencRegs = (CSL_VencRegs * )llcRegisterBaseAddr;
        CSL_FINST(vencRegs->SYNCCTL, VENC_SYNCCTL_HPL, ACTIVEH);/*ACTIVEH*/
    }
}
/**
  * \brief      to set width for the HD and VD signals
  *
  */
void LLC_setVencHDVDSignalWidth(Ptr llcRegisterBaseAddr, Uint widHD, Uint widVD)
{
    if(NULL!=llcRegisterBaseAddr)
    {
        vencRegs = (CSL_VencRegs * )llcRegisterBaseAddr;
        CSL_FINS(vencRegs->HSPLS, VENC_HSPLS_HSPLS, widHD);
        CSL_FINS(vencRegs->VSPLS, VENC_VSPLS_VSPLS, widVD);
    }
}
/**
  * \brief      to set valid data area on the horizontal
  *
  */
void LLC_setVencHorzValidData(Ptr llcRegisterBaseAddr, Uint hValidData)
{
    if(NULL!=llcRegisterBaseAddr)
    {
        vencRegs = (CSL_VencRegs * )llcRegisterBaseAddr;
        CSL_FINS(vencRegs->HVALID, VENC_HVALID_HVALID, hValidData);
    }
}


/**
  * \brief      to set valid data area on the vertical
  *
  */
void LLC_setVencVertValidData(Ptr llcRegisterBaseAddr, Uint vValidData)
{
    if(NULL!=llcRegisterBaseAddr)
    {
        vencRegs = (CSL_VencRegs * )llcRegisterBaseAddr;
        CSL_FINS(vencRegs->VVALID, VENC_VVALID_VVALID, vValidData);
    }
}

/**
  * \brief      to set the number of pixels
  *
  */
void LLC_setVencPixLines(Ptr llcRegisterBaseAddr, Uint numPixelPerLine, Uint numLinesPerField )
{
    if(NULL!=llcRegisterBaseAddr)
    {
        vencRegs = (CSL_VencRegs * )llcRegisterBaseAddr;
        CSL_FINS(vencRegs->HINT, VENC_HINT_HINT, numPixelPerLine);
        CSL_FINS(vencRegs->VINT, VENC_VINT_VINT, numLinesPerField);
    }
}


/**
  * \brief      to set the horz start pixel
  *
  */
void LLC_setVencHorzStartPixel(Ptr llcRegisterBaseAddr, Uint hStartValidData)
{
    if(NULL!=llcRegisterBaseAddr)
    {
        vencRegs = (CSL_VencRegs * )llcRegisterBaseAddr;
        CSL_FINS(vencRegs->HSTART, VENC_HSTART_HSTART, hStartValidData);
    }
}

/**
  * \brief      to set the vert start pixel
  *
  */
void LLC_setVencVertStartPixel(Ptr llcRegisterBaseAddr, Uint vStartValidData)
{
    if(NULL!=llcRegisterBaseAddr)
    {
        vencRegs = (CSL_VencRegs * )llcRegisterBaseAddr;
        CSL_FINS(vencRegs->VSTART, VENC_VSTART_VSTART, vStartValidData);
    }
}

/**
  * \brief      To enable DCLK pattern mode
  *
  */
void LLC_setDCLKPatternMode_Enable(Ptr llcRegisterBaseAddr)
{
    if(NULL!=llcRegisterBaseAddr)
    {
        vencRegs = (CSL_VencRegs * )llcRegisterBaseAddr;
        CSL_FINST(vencRegs->DCLKCTL, VENC_DCLKCTL_DCKEC, ENABLE);

    }
}
/**
  * \brief      To set DCLK pattern width
  *
  */
void LLC_setDCLKPatternBitWidth(Ptr llcRegisterBaseAddr, Uint32 width)
{
    if(NULL!=llcRegisterBaseAddr)
    {
        vencRegs = (CSL_VencRegs * )llcRegisterBaseAddr;
        CSL_FINS(vencRegs->DCLKCTL, VENC_DCLKCTL_DCKPW, width);
    }
}
/**
  * \brief      To set DCLK pattern
  *
  */
void LLC_setDCLKPattern(Ptr llcRegisterBaseAddr, Uint16 pattern)
{
    if(NULL!=llcRegisterBaseAddr)
    {
        vencRegs = (CSL_VencRegs * )llcRegisterBaseAddr;
        CSL_FINS(vencRegs->DCLKPTN0, VENC_DCLKPTN0_DCPTN0, pattern);
    }
}
/**
  * \brief      To set LCD output enable
  *
  */
void LLC_setLCDOutputON(Ptr llcRegisterBaseAddr)
{
    if(NULL!=llcRegisterBaseAddr)
    {
        vencRegs = (CSL_VencRegs * )llcRegisterBaseAddr;
        CSL_FINST(vencRegs->LCDOUT, VENC_LCDOUT_OEE, ON);
    }
}
/**
  * \brief      To set LCD output polarity as Active High
  *
  */
void LLC_setLCDOutputPolarityActHigh(Ptr llcRegisterBaseAddr)
{
    if(NULL!=llcRegisterBaseAddr)
    {
        vencRegs = (CSL_VencRegs * )llcRegisterBaseAddr;
        CSL_FINST(vencRegs->LCDOUT, VENC_LCDOUT_OEP, ACTIVEH);
    }
}
/**
  * \brief      To set digital output mode as RGB mode
  *
  */
void LLC_setRGBModeDigitalOutput(Ptr llcRegisterBaseAddr)
{
    if(NULL!=llcRegisterBaseAddr)
    {
        vencRegs = (CSL_VencRegs * )llcRegisterBaseAddr;
        CSL_FINST(vencRegs->CMPNT, VENC_CMPNT_MRGB,RGB);
    }
}
/**
  * \brief      To set digital output mode as RGB mode
  *
  */
void LLC_setYCPOrder(Ptr llcRegisterBaseAddr)
{
    if(NULL!=llcRegisterBaseAddr)
    {
        vencRegs = (CSL_VencRegs * )llcRegisterBaseAddr;
        CSL_FINST(vencRegs->YCCCTL, VENC_YCCCTL_YCP, YCC16_CRCB);
    }
}
