/******************************************************************************
**+-------------------------------------------------------------------------+**
**|                            ****                                         |**
**|                            ****                                         |**
**|                            ******o***                                   |**
**|                      ********_///_****                                  |**
**|                      ***** /_//_/ ****                                  |**
**|                       ** ** (__/ ****                                   |**
**|                           *********                                     |**
**|                            ****                                         |**
**|                            ***                                          |**
**|                                                                         |**
**|         Copyright (c) 2006-2010 Texas Instruments Incorporated          |**
**|                        ALL RIGHTS RESERVED                              |**
**|                                                                         |**
**| Permission is hereby granted to licensees of Texas Instruments          |**
**| Incorporated (TI) products to use this computer program for the sole    |**
**| purpose of implementing a licensee product based on TI products.        |**
**| No other rights to reproduce, use, or disseminate this computer         |**
**| program, whether in part or in whole, are granted.                      |**
**|                                                                         |**
**| TI makes no representation or warranties with respect to the            |**
**| performance of this computer program, and specifically disclaims        |**
**| any responsibility for any damages, special or consequential,           |**
**| connected with the use of this program.                                 |**
**|                                                                         |**
**+-------------------------------------------------------------------------+**
******************************************************************************/
/**
 *  \file   llc_vpbeVenc.h
 *
 *  \brief  VPBE LLC layer Function dependencies
 *
 *  This file contains the dependencies of LLC layer functions
 *
 *  (C) Copyright 2010, Texas Instruments, Inc
 *
 *  \note       Set tabstop to 4 (:se ts=4) while viewing this file in an
 *              editor
 *
 *  \author     Maulik Desai
 *
 *  \version    0.1     Created
 */

 #ifndef _LLC_VPBEVENC_H
 #define _LLC_VPBEVENC_H

#ifdef __cplusplus
extern "C" {
#endif

/******************************************************************************
                                Functions
******************************************************************************/
/**
  * \brief This will Configure the Venc Register in Default Values
  *
  * \param   llcRegisterBaseAddr [IN]   register base adddress
  *
  */
void LLC_ResetVencReg(Ptr llcRegisterBaseAddr);
/**
  * \brief This will return the Venc field Id
  *
  * \param  handleGVF           [IN]        Handle for Venc ID
  * \returns                                It will return the venc ID
  *
  */
Bool LLC_getVencField(Ptr handleGVF);

/**
  * \brief This will configure the DAC B normal mode for VENC
  *
  * \param   llcRegisterBaseAddr [IN]   register base adddress
  *
  */
void LLC_setDacBNormalMode(Ptr llcRegisterBaseAddr);

/**
  * \brief This will configure the DAC B power down mode for VENC
  *
  * \param   llcRegisterBaseAddr [IN]   register base adddress
  *
  */
void LLC_setDacBPowerDownMode(Ptr llcRegisterBaseAddr);

/**
  * \brief This will configure the DAC C normal mode for VENC
  *
  * \param   llcRegisterBaseAddr [IN]   register base adddress
  *
  */
void LLC_setDacCNormalMode(Ptr llcRegisterBaseAddr);

/**
  * \brief This will configure the DAC C power down mode for VENC
  *
  * \param   llcRegisterBaseAddr [IN]   register base adddress
  *
  */
void LLC_setDacCPowerDownMode(Ptr llcRegisterBaseAddr);

/**
  * \brief This will configure the DAC D normal mode for VENC
  *
  * \param   llcRegisterBaseAddr [IN]   register base adddress
  *
  */
void LLC_setDacDNormalMode(Ptr llcRegisterBaseAddr);

/**
  * \brief This will configure the DAC D power down mode for VENC
  *
  * \param   llcRegisterBaseAddr [IN]   register base adddress
  *
  */
void LLC_setDacDPowerDownMode(Ptr llcRegisterBaseAddr);

/**
  * \brief This will configure the DAC B output as video format CVBS
  *
  * \param  llcRegisterBaseAddr [IN]   register base adddress
  *
  */
void LLC_setDacBOutVidFormatCVBS(Ptr llcRegisterBaseAddr);


/**
  * \brief This will configure the DAC C output as video format CVBS
  *
  * \param  llcRegisterBaseAddr [IN]   register base adddress
  *
  */
void LLC_setDacCOutVidFormatCVBS(Ptr llcRegisterBaseAddr);


/**
  * \brief This will configure the DAC D output as video format CVBS
  *
  * \param  llcRegisterBaseAddr [IN]   register base adddress
  *
  */
void LLC_setDacDOutVidFormatCVBS(Ptr llcRegisterBaseAddr);


/**
  * \brief This will configure the Venc plane as scan mode interlaced
  *
  * \param  llcRegisterBaseAddr [IN]   register base adddress
  *
  */
void LLC_setVencScanModeInterlaced(Ptr llcRegisterBaseAddr);


/**
  * \brief This will configure the Venc plane as scan mode Progressive
  *
  * \param  llcRegisterBaseAddr [IN]   register base adddress
  *
  */
void LLC_setVencScanModeProgressive(Ptr llcRegisterBaseAddr);


/**
  * \brief This will enable the composite output
  *
  * \param  llcRegisterBaseAddr [IN]   register base adddress
  *
  */
void LLC_setEnableCompositeOutput(Ptr llcRegisterBaseAddr);


/**
  * \brief This will enable the fixed level output
  *
  * \param  llcRegisterBaseAddr [IN]   register base adddress
  *
  */
void LLC_setEnableFixedLevelOutput(Ptr llcRegisterBaseAddr);


/**
  * \brief This will enable the Venc plane
  *
  * \param  llcRegisterBaseAddr [IN]   register base adddress
  *
  */
void LLC_setVencEnable(Ptr llcRegisterBaseAddr);


/**
  * \brief This will disable the Venc plane
  *
  * \param  llcRegisterBaseAddr [IN]   register base adddress
  *
  */
void LLC_setVencDisable(Ptr llcRegisterBaseAddr);


/**
  * \brief This will validate & enable the video output SDTVNTSC
  *
  * \param  llcRegisterBaseAddr [IN]   register base adddress
  *
  */
void LLC_setVideoOutputSDTVNTSC(Ptr llcRegisterBaseAddr);


/**
  * \brief This will validate & enable the video output SDTVPAL
  *
  * \param  llcRegisterBaseAddr [IN]   register base adddress
  *
  */
void LLC_setVideoOutputSDTVPAL(Ptr llcRegisterBaseAddr);


/**
  * \brief This will validate & enable the digital video output ModeYcc8
  *
  * \param  llcRegisterBaseAddr [IN]   register base adddress
  *
  */
void LLC_setDigitalVidOutModeYcc8(Ptr llcRegisterBaseAddr);


/**
  * \brief This will  enable the video output REC656Mode
  *
  * \param  llcRegisterBaseAddr [IN]   register base adddress
  *
  */
void LLC_setREC656Mode(Ptr llcRegisterBaseAddr);
/**
  * \brief To configure the DAC B output video format CompY
  *
  * \param  llcRegisterBaseAddr [IN]   register based address
  *
  */
void LLC_setDacBOutVidFormatCompY(Ptr llcRegisterBaseAddr);
/**
  * \brief To configure the DAC C output video format CompPb
  *
  * \param  llcRegisterBaseAddr [IN]   register based address
  *
  */
void LLC_setDacCOutVidFormatCompPb(Ptr llcRegisterBaseAddr);

/**
  * \brief To configure the DAC D output video format CompPr
  *
  * \param  llcRegisterBaseAddr [IN]   register based address
  *
  */
void LLC_setDacDOutVidFormatCompPr(Ptr llcRegisterBaseAddr);

/**
  * \brief To set the video output type NTSC
  *
  * \param  llcRegisterBaseAddr [IN]   register based address
  *
  */
void LLC_setVideoOutputTYP_NTSC(Ptr llcRegisterBaseAddr);


/**
  * \brief to set video output PAL type
  *
  * \param  llcRegisterBaseAddr [IN]   register based address
  *
  */
void LLC_setVideoOutputTYP_PAL(Ptr llcRegisterBaseAddr);
/**
  * \brief to set video output to 525p HDTV Mode
  *
  * \param  llcRegisterBaseAddr [IN]   register based address
  *
  */
void LLC_setVideoOutputTYP_525p_HDTV(Ptr llcRegisterBaseAddr);
/**
  * \brief to set video output to 625p HDTV Mode
  *
  * \param  llcRegisterBaseAddr [IN]   register based address
  *
  */
void LLC_setVideoOutputTYP_625p_HDTV(Ptr llcRegisterBaseAddr);
/**
  * \brief to set video output to SDTVMode
  *
  * \param  llcRegisterBaseAddr [IN]   register based address
  *
  */
void LLC_setVideoOutputSDTVMode(Ptr llcRegisterBaseAddr);
/**
  * \brief to set video output to HDTVMode
  *
  * \param  llcRegisterBaseAddr [IN]   register based address
  *
  */
void LLC_setVideoOutputHDTVMode(Ptr llcRegisterBaseAddr);


/**
  * \ to set OSD clock control0
  *
  * \param  llcRegisterBaseAddr [IN]   register based address
  * \param  clkPatternBitWidth  [IN]   clock pattern width value
  *
  */
void LLC_setOSDClockControl0(Ptr llcRegisterBaseAddr, Uint32 clkPatternBitWidth);


/**
  * \brief to set OSD clock control1
  *
  * \param  llcRegisterBaseAddr [IN]   register based address
  * \param  clkPattern          [IN]   clock pattern value
  *
  */
void LLC_setOSDClockControl1(Ptr llcRegisterBaseAddr, Uint32 clkPattern);


/**
  * \brief to DAC 1 Video Output Format for S-Video-Y
  *
  * \param  llcRegisterBaseAddr [IN]   register based handle
  *
  */
void LLC_setDac1OutVidFormatSVidY(Ptr llcRegisterBaseAddr);


/**
  * \brief to DAC Video Output Format for S-Video-C
  *
  * \param  llcRegisterBaseAddr [IN]   register based handle
  *
  */
void LLC_setDac2OutVidFormatSVidC(Ptr llcRegisterBaseAddr);

void LLC_setDigitalVidOutModeYcc16(Ptr llcRegisterBaseAddr);

void LLC_setLCDEnable(Ptr llcRegisterBaseAddr);

void LLC_setVLCKEnable(Ptr llcRegisterBaseAddr);

void LLC_setYCOutputDir(Ptr llcRegisterBaseAddr);
void LLC_setVideoTimingNotNTSCPAL(Ptr llcRegisterBaseAddr);
void LLC_setLCDOutputON(Ptr llcRegisterBaseAddr);
void LLC_setLCDOutputPolarityActHigh(Ptr llcRegisterBaseAddr);
void LLC_setVideoTimingNTSCPAL(Ptr llcRegisterBaseAddr);
void LLC_setMasterMode(Ptr llcRegisterBaseAddr);
void LLC_setEnableVCLKOutputEnable(Ptr llcRegisterBaseAddr);
void LLC_setEnableVCLKPinOutputEn(Ptr llcRegisterBaseAddr);
void LLC_setVencVDHDSyncDirOut(Ptr llcRegisterBaseAddr);
void LLC_setVencDataOut(Ptr llcRegisterBaseAddr);
void LLC_setYCPin_DigitalVideoOutput(Ptr llcRegisterBaseAddr);
void LLC_setVencVDOutputEnable(Ptr llcRegisterBaseAddr);
void LLC_setVencHDOutputEnable(Ptr llcRegisterBaseAddr);
void LLC_setVencVDSyncPolarityPos(Ptr llcRegisterBaseAddr);
void LLC_setVencHDSyncPolarityNeg(Ptr llcRegisterBaseAddr);
void LLC_setYCPOrder(Ptr llcRegisterBaseAddr);
void LLC_setVencHorzValidData(Ptr llcRegisterBaseAddr, Uint hValidData);
void LLC_setVencVertValidData(Ptr llcRegisterBaseAddr, Uint vValidData);
void LLC_setDCLKPatternMode_Enable(Ptr llcRegisterBaseAddr);
void LLC_setDCLKPatternBitWidth(Ptr llcRegisterBaseAddr, Uint32 width);
void LLC_setDCLKPattern(Ptr llcRegisterBaseAddr, Uint16 pattern);

#ifdef __cplusplus
}
#endif

#endif  /*_LLC_VPBEVENC_H */
