/******************************************************************************
**+-------------------------------------------------------------------------+**
**|                            ****                                         |**
**|                            ****                                         |**
**|                            ******o***                                   |**
**|                      ********_///_****                                  |**
**|                      ***** /_//_/ ****                                  |**
**|                       ** ** (__/ ****                                   |**
**|                           *********                                     |**
**|                            ****                                         |**
**|                            ***                                          |**
**|                                                                         |**
**|         Copyright (c) 2006-2010 Texas Instruments Incorporated          |**
**|                        ALL RIGHTS RESERVED                              |**
**|                                                                         |**
**| Permission is hereby granted to licensees of Texas Instruments          |**
**| Incorporated (TI) products to use this computer program for the sole    |**
**| purpose of implementing a licensee product based on TI products.        |**
**| No other rights to reproduce, use, or disseminate this computer         |**
**| program, whether in part or in whole, are granted.                      |**
**|                                                                         |**
**| TI makes no representation or warranties with respect to the            |**
**| performance of this computer program, and specifically disclaims        |**
**| any responsibility for any damages, special or consequential,           |**
**| connected with the use of this program.                                 |**
**|                                                                         |**
**+-------------------------------------------------------------------------+**
******************************************************************************/
/**
 *  \file   psp_vpbeApi.h
 *
 * \brief   File contains defination of API used by DDA layer
 *
 *  This file contains APIs defination of APIs that are wrapper APIs for DDC
 *  layer. These APIs will be called by DDA layer.
 *
 *  (C) Copyright 2010, Texas Instruments, Inc
 *
 *  \note       Set tabstop to 4 (:se ts=4) while viewing this file in an
 *              editor
 *
 *  \author     Maulik Desai
 *
 *  \version    0.1     Created
 */

#ifndef _PSP_VPBE_API_
#define _PSP_VPBE_API_

#ifdef __cplusplus
extern "C" {
#endif

/**
 *  \brief      This function is the first to be called and is used for driver
 *              initialization.
 *
 *              It performs register map overlaying and software book-keeping.
 *              It register the interrupt Handler.
 *
 *  \param      instanceId              [IN]        VPSS Instance number.
 *
 *  \returns                                        SUCCESS/FAILURE status.
 */
PSP_Result      PSP_VPBECreate(Uint32 instanceId);

/**
 *  \brief      This function is called last and is used for driver deletion.
 *              This function does the deletion of the entire VPFE hardware
 *
 *  \param      instanceId              [IN]        VPSS Instance number.
 *
 *  \returns                                        SUCCESS/FAILURE status.
 */
PSP_Result     PSP_VPBEDelete(Uint32 instanceId);
/**
 *  \brief      This function creates  the channel handle for individual VPBE
 *              Plane(Video/OSD)/VENC/CURSOR.
 *
 *  \param      instanceId              [IN]        VPSS instance id.
 *
 *  \param      chanParams              [OUT]       Channel Configuration
 *                                                  parameters
 *
 *  \returns                                        Channel handle of VPFE
 *                                                  or NULL

 */
PSP_Handle  PSP_VPBEOpen(Uint32 instanceId,PSP_VPBEChannelParams * chanParams);

/**
 *
 *  \brief      This function close individual Channel handle for individual VPBE
 *              Modules
 *
 *  \param      handle                  [IN]        Plane/VENC/CURSOR Channel
 *                                                  handle will be closed.
 *
 *  \Returns                                        SUCCESS/FAILURE status.
 */
PSP_Result PSP_VPBEClose(PSP_Handle handle);

/**
 *  \brief      This function makes runtime changes for the individual VPBE
 *              Plane(Video/OSD)/VENC/CURSOR
 *
 *  \param      handle                  [IN]        Handle of the VPBE Modules
 *                                                  (Plane/VENC/CURSOR) for
 *                                                  which the control operation
 *                                                  will be performed.
 *
 *  \param      cmd                     [IN]        IOCTL command
 *
 *  \param      cmdArg                  [IN]        Command Arguments to be passed.
 *                                                  ConfigParams structure to be
 *                                                  passed as part of any change
 *                                                  in the parameters.
 *
 *  \param      params                  [IN]        Reserved for Future Use
 *
 *  \Returns                                        SUCCESS/FAILURE status.
 */
PSP_Result  PSP_VPBEIoctl(PSP_Handle            handle,
                          PSP_VPBEIoctlCommand  cmd,
                          Ptr                   cmdArg,
                          Ptr                   params);

/**
 *  \brief  This function is called to Queue/Dequeue Frame buffer for individual
 *          Plane(Video/OSD)/VENC/CURSOR
 *
 *  \param      handle                  [IN]        Handle of the VPBE Modules
 *                                                  (Plane/VENC/CURSOR) for
 *                                                  which the control operation
 *                                                  will be performed.
 *
 *  \param      cmd                     [IN]        Submit Command(QUEUE/DEQUEUE)
 *
 *  \param      cmdArg                  [IN]        Command Arguments to be passed.
 *                                                  SufaceParams to be passed as
 *                                                  part of Submit Request to queue
 *                                                  or dequeue of Framebuffers.
 */
PSP_Result PSP_VPBESubmitRequest(PSP_Handle             handle,
                                 Uint32         cmd,
                                 Ptr                    cmdArg);
#ifdef __cplusplus
}
#endif

#endif /*_PSP_VPBE_API_*/
