/******************************************************************************
**+-------------------------------------------------------------------------+**
**|                            ****                                         |**
**|                            ****                                         |**
**|                            ******o***                                   |**
**|                      ********_///_****                                  |**
**|                      ***** /_//_/ ****                                  |**
**|                       ** ** (__/ ****                                   |**
**|                           *********                                     |**
**|                            ****                                         |**
**|                            ***                                          |**
**|                                                                         |**
**|         Copyright (c) 2006-2010 Texas Instruments Incorporated          |**
**|                        ALL RIGHTS RESERVED                              |**
**|                                                                         |**
**| Permission is hereby granted to licensees of Texas Instruments          |**
**| Incorporated (TI) products to use this computer program for the sole    |**
**| purpose of implementing a licensee product based on TI products.        |**
**| No other rights to reproduce, use, or disseminate this computer         |**
**| program, whether in part or in whole, are granted.                      |**
**|                                                                         |**
**| TI makes no representation or warranties with respect to the            |**
**| performance of this computer program, and specifically disclaims        |**
**| any responsibility for any damages, special or consequential,           |**
**| connected with the use of this program.                                 |**
**|                                                                         |**
**+-------------------------------------------------------------------------+**
******************************************************************************/

/**
 *  \file   dda_vpfeBios.c
 *
 *  \brief  vpfe Driver Adaptation for BIOS
 *
 *  This file contains adaptation of vpfe driver for BIOS
 *
 *  (C) Copyright 2010, Texas Instruments, Inc
 *
 *  \note       Set tabstop to 4 (:se ts=4) while viewing this file in an
 *              editor
 *
 *  \author     Maulik Desai
 *
 *  \version    0.1     Created
 */

/******************************************************************************
                            Header File Inclusion
******************************************************************************/
#include <std.h>
#include <iom.h>
#include <C64.h>
#include <ecm.h>
#include <ti/sdo/pspdrivers/pal_os/pal_osprotect.h>

#include <ti/sdo/pspdrivers/drivers/vpfe/psp_vpfe.h>
#include <ti/sdo/pspdrivers/drivers/vpfe/src/dda_vpfeBios.h>
#include <ti/sdo/pspdrivers/drivers/vpfe/src/ddc_vpfe.h>
#include <ti/sdo/pspdrivers/soc/dm6437/dsp/soc.h>

/******************************************************************************
                                    Macros
******************************************************************************/
/**
  * \brief Hardware Ccdc interrupt number
  *
  */
#define HWI_CCDC_INTR_NUM       (HWI_EVT01_CMB_IRQ)

/******************************************************************************
                                Functions
******************************************************************************/
/**
  * \brief Register interrrupt with BIOS and enable it
  *
  */
void _DDA_VPFERegisterIntrHandler(Uint32 instNum, Uint32 IntNum)
{
    ECM_Attrs ecmattrs = ECM_ATTRS;

    /* Depending upon the device id of the VPSS */
    switch(instNum)
    {
        case PSP_VPFE_0_INSTANCE_ID:
        {
            /* Mapping the eventid to the ECM Dispatch of the DSP/BIOS*/
            ecmattrs.unmask = (int)1;
            ECM_dispatchPlug(IntNum, (ECM_Fxn)&DDC_VPFEIsr, &ecmattrs);
            /* Enabling the event */
            ECM_enableEvent(IntNum);
        }
        break;
        default:
        {

        }
        break;
    }
    /* Enabling Interrupt of CPU */
    C64_enableIER(HWI_CCDC_INTR_NUM);
}
/**
  * \brief Un-Register Front End interrupt with BIOS.
  *
  */
/* ARGSUSED */
void _DDA_VPFEUnregisterIntrHandler(Uint32 instNum, Uint32 intrNum)
{
    /* Disabling interrupt */
    ECM_disableEvent(intrNum);
}
