/******************************************************************************
**+-------------------------------------------------------------------------+**
**|                            ****                                         |**
**|                            ****                                         |**
**|                            ******o***                                   |**
**|                      ********_///_****                                  |**
**|                      ***** /_//_/ ****                                  |**
**|                       ** ** (__/ ****                                   |**
**|                           *********                                     |**
**|                            ****                                         |**
**|                            ***                                          |**
**|                                                                         |**
**|         Copyright (c) 2006-2010 Texas Instruments Incorporated          |**
**|                        ALL RIGHTS RESERVED                              |**
**|                                                                         |**
**| Permission is hereby granted to licensees of Texas Instruments          |**
**| Incorporated (TI) products to use this computer program for the sole    |**
**| purpose of implementing a licensee product based on TI products.        |**
**| No other rights to reproduce, use, or disseminate this computer         |**
**| program, whether in part or in whole, are granted.                      |**
**|                                                                         |**
**| TI makes no representation or warranties with respect to the            |**
**| performance of this computer program, and specifically disclaims        |**
**| any responsibility for any damages, special or consequential,           |**
**| connected with the use of this program.                                 |**
**|                                                                         |**
**+-------------------------------------------------------------------------+**
******************************************************************************/

/**
 *  \file   ddc_vpfeCcdc.c
 *
 *  \brief  vpfe implementation
 *
 *  This file contains the implementation of the vpfe driver to utilize the
 *  serivces of the vpfe device driver.
 *
 *  (C) Copyright 2010, Texas Instruments, Inc
 *
 *  \author     Ashutosh Shrivastava
 *
 *  \version    1.0 new implementation
 */

/******************************************************************************
                            Header File Inclusion
******************************************************************************/
#include <stdlib.h>
#include <std.h>
#include <iom.h>

#include <ti/sdo/pspdrivers/drivers/vpfe/psp_vpfe.h>
#include <ti/sdo/pspdrivers/drivers/previewer/psp_previewer.h>
#include <ti/sdo/pspdrivers/drivers/previewer/src/psp_previewerApi.h>
#include <ti/sdo/pspdrivers/drivers/vpfe/src/ddc_vpfe.h>
#include <ti/sdo/pspdrivers/drivers/vpfe/src/ddc_vpfeCcdc.h>
#include <ti/sdo/pspdrivers/drivers/vpfe/src/llc_vpfeCcdc.h>

/******************************************************************************
                                    Functions
******************************************************************************/
/*-----------------------------------------------------------------------------
                    To validate the CCDC mode parameters
-----------------------------------------------------------------------------*/
/**
 *  \brief .This function validates whether the parameters that are
 *          passed in the params are valid for the CCDC or are incorrect.
 *          On success this function returns an enumerated status of the
 *          operation indicating the validity of the parameters.
 */

DDC_VPFEStatus DDC_VPFEConfigCcdcParams(DDC_VPFECcdcObject* const ccdcHandleCC,Ptr paramsCC)
{
    DDC_VPFEStatus result                       = DDC_VPFE_E_FAIL;
    PSP_VPFECcdcConfigParams *ccdcModeParamsCC  = NULL;
    DDC_VPFEDeviceObject *vpfeDeviceHandleCC    = NULL;
    PSP_VPFECcdcRawParams *ccdcRawParamsCC      = NULL;
    Uint32 hd_vd_wid_h                          = 0;
    Uint32 hd_vd_wid_v                          = 0;
    Uint32 pix_lines_p                          = 0;
    Uint32 pix_lines_h                          = 0;
    Ptr prevHandle = NULL;
    PSP_previewerGetInfoForCCDC prevInfo;

    /*Default value */
    prevInfo.source = PSP_PREVIEWER_CHANNEL_SDRAM;
    /* Get the Device Handle  */
    vpfeDeviceHandleCC = (DDC_VPFEDeviceObject * )DDC_VPFEGetDeviceHandle();
    /* Check the Parameters not NULL */
    if (((NULL != ccdcHandleCC) && (NULL != paramsCC))&&
           (NULL != vpfeDeviceHandleCC))
    {
        ccdcModeParamsCC  = (PSP_VPFECcdcConfigParams * )paramsCC;
        ccdcRawParamsCC = (PSP_VPFECcdcRawParams *)&(
            (PSP_VPFECcdcConfigParams*)paramsCC)->rawParams;
        /* TURN Off the CCDC */
        LLC_setCcdcCaptureOff(ccdcHandleCC->regs);
        ccdcHandleCC->CcdcParams.appCallback = ccdcModeParamsCC->appCallback;
        ccdcHandleCC->CcdcParams.segId  =   ccdcModeParamsCC->segId;
    }
    /* Input to CCDC :- Video Decoder(YUV Data) */
    if (FVID_VI_BT656_8BIT == ccdcModeParamsCC->inpmod)
    {
        ccdcHandleCC->dataflow          = PSP_VPFE_DECODER_CCDC;
        ccdcHandleCC->extVidDecFxn      = &ccdcModeParamsCC->extVDFxn;
        if(NULL != ccdcHandleCC->extVidDecFxn->Open)
        {
            ccdcHandleCC->extVidDecHandle   = ccdcHandleCC->extVidDecFxn->Open();
            result = DDC_VPFE_SOK;
        }
        else
        {
            result = DDC_VPFE_E_FAIL;
        }
        if(DDC_VPFE_SOK == result)
        {

            if (FVID_FRAME_MODE == ccdcModeParamsCC->ffMode)
            {
                LLC_setCcdcModeInterlaced(ccdcHandleCC->regs);
                ccdcHandleCC->CcdcParams.ffMode = FVID_FRAME_MODE;
                result = DDC_VPFE_SOK;
            }
            else
            {
                result = DDC_VPFE_E_FAIL;
            }
        }
        if(DDC_VPFE_SOK == result)
        {
            LLC_setCcdcHorzStartPixel(ccdcHandleCC->regs,
                    (ccdcModeParamsCC->horzStartPix<<1));
            /*Twice the number of pixels*/
            LLC_setCcdcHorzPixelOutputOnRAM(ccdcHandleCC->regs,
                ((ccdcModeParamsCC->width << 1u)-1u));
            LLC_setCcdcVertStartPixel(ccdcHandleCC->regs,
                    (ccdcModeParamsCC->vertStartPix>>1));
            /*Half the number of lines*/
            LLC_setCcdcVertLines(ccdcHandleCC->regs,
                ((ccdcModeParamsCC->height >> 1u)-1u));
            LLC_setErrorCorrectionEnable(ccdcHandleCC->regs);
            LLC_setREC656InterfaceEnable(ccdcHandleCC->regs);
            LLC_setPack8BitsPerPixel(ccdcHandleCC->regs);
            LLC_setCcdcPixelBitWidth8Bit(ccdcHandleCC->regs);
            LLC_setCcdcColorFormatYCC8Bits(ccdcHandleCC->regs);
            LLC_setYBitPosOddPixel(ccdcHandleCC->regs);

            ccdcHandleCC->CcdcParams.height = ccdcModeParamsCC->height;
            ccdcHandleCC->CcdcParams.width = ccdcModeParamsCC->width;
            ccdcHandleCC->CcdcParams.pitch = ccdcModeParamsCC->pitch;
                result = DDC_VPFE_SOK;
        }
        if(DDC_VPFE_SOK == result)
        {
            LLC_setHDVDToSyncWithExtHDVD(ccdcHandleCC->regs);
            LLC_setCcdcVDSyncPolarityNeg(ccdcHandleCC->regs);
            LLC_setCcdcHDSyncPolarityPos(ccdcHandleCC->regs);
            LLC_setCcdcFIDPolarityPositive(ccdcHandleCC->regs);
            LLC_setNotLatchedOnVSYNC(ccdcHandleCC->regs);
            LLC_setFIDSignalLatchOnVDTiming(ccdcHandleCC->regs);
            LLC_setCcdcOutputToSDRAMEnable(ccdcHandleCC->regs);
            LLC_setFIDSignalNonInversed(ccdcHandleCC->regs);
            LLC_setLnOfstValField_1_1Lines(ccdcHandleCC->regs);
            LLC_setLnOfstEvnLnEvnFld_2Lines(ccdcHandleCC->regs);
            LLC_setLnOfstOddLnEvnFld_2Lines(ccdcHandleCC->regs);
            LLC_setLnOfstEvnLnOddFld_2Lines(ccdcHandleCC->regs);
            LLC_setLnOfstOddLnOddFld_2Lines(ccdcHandleCC->regs);
            LLC_setCcdcCaptureOff(ccdcHandleCC->regs);
            ccdcHandleCC->FieldType = DDC_VPFE_FIELD_INTERLACED;
            result = DDC_VPFE_SOK;
        }

    }
    /* Input to CCDC :- SENSOR(RAW Data)*/
    if (FVID_VI_RAW_10BIT_CS == ccdcModeParamsCC->inpmod )
    {
        ccdcHandleCC->extVidDecFxn    = &ccdcModeParamsCC->extVDFxn;
        if(NULL != ccdcHandleCC->extVidDecFxn->Open)
        {
            ccdcHandleCC->extVidDecHandle = ccdcHandleCC->extVidDecFxn->Open();
        }
        /* Get the Previewer Handle */
        PSP_prevGetPSPHandle(&prevHandle);
        if (NULL!=prevHandle)
        {
            PSP_prevIoctl(prevHandle, PSP_PREVIEWER_GET_INFO_FOR_CCDC,
                &prevInfo);
        }
        /* Previewer is one-shot mode configured */
        /* Configure CCDC Output to RAM  */
        if (PSP_PREVIEWER_CHANNEL_SDRAM == prevInfo.source)
        {
            ccdcHandleCC->dataflow  = PSP_VPFE_SENSOR_CCDC_RAM;

            /* WEN bit Enable */
            LLC_setCcdcOutputToSDRAMEnable(ccdcHandleCC->regs);
            result  = DDC_VPFE_SOK;
        }
        /* Previewer is on-the-fly configured */
        if (PSP_PREVIEWER_CHANNEL_CCDC == prevInfo.source)
        {
            ccdcHandleCC->dataflow     = PSP_VPFE_SENSOR_CCDC_PREVIEWER;
            vpfeDeviceHandleCC->IntNum = prevInfo.intNo;


            result  = DDC_VPFE_SOK;
        }
        if ((DDC_VPFE_SOK == result)&&(NULL!= ccdcRawParamsCC))
        {
                if (PSP_VPFE_SyncDir_Input == ccdcRawParamsCC->HDVDMaster)
                {
                    LLC_setVDHDSyncDirectionInput(ccdcHandleCC->regs);
                }
                else
                {
                    LLC_setVDHDSyncDirectionOutput(ccdcHandleCC->regs);
                }
                LLC_setFieldIdDirectionInput(ccdcHandleCC->regs);
                if (PSP_VPFE_SyncPol_Positive == ccdcRawParamsCC->VDSyncPol)
                {
                    LLC_setCcdcVDSyncPolarityPos(ccdcHandleCC->regs);
                }
                else
                {
                    LLC_setCcdcVDSyncPolarityNeg(ccdcHandleCC->regs);
                }
                if (PSP_VPFE_SyncPol_Positive == ccdcRawParamsCC->HDSyncPol)
                {
                    LLC_setCcdcHDSyncPolarityPos(ccdcHandleCC->regs);
                }
                else
                {
                    LLC_setCcdcHDSyncPolarityNeg(ccdcHandleCC->regs);
                }
                LLC_setCcdcFIDPolarityPositive(ccdcHandleCC->regs);
                /* EXWEN assumed to be programmed to default  */
                if (PSP_VPFE_DataPol_Normal == ccdcRawParamsCC->dataPol)
                {
                    LLC_ccdcsetDataPolNormal(ccdcHandleCC->regs);
                }
                else
                {
                    LLC_ccdcsetDataPolOnesComp(ccdcHandleCC->regs);
                }
                LLC_setCcdcModeProgressive(ccdcHandleCC->regs);
                switch (ccdcRawParamsCC->dataSize)
                {
                    case PSP_VPFE_BITS16:
                        LLC_setCcdcPixelBitWidth16Bit(ccdcHandleCC->regs);
                        break;
                    case PSP_VPFE_BITS15:
                        LLC_setCcdcPixelBitWidth15Bit(ccdcHandleCC->regs);
                        break;
                    case PSP_VPFE_BITS14:
                        LLC_setCcdcPixelBitWidth14Bit(ccdcHandleCC->regs);
                        break;
                    case PSP_VPFE_BITS13:
                        LLC_setCcdcPixelBitWidth13Bit(ccdcHandleCC->regs);
                        break;
                    case PSP_VPFE_BITS12:
                        LLC_setCcdcPixelBitWidth12Bit(ccdcHandleCC->regs);
                        break;
                    case PSP_VPFE_BITS11:
                        LLC_setCcdcPixelBitWidth11Bit(ccdcHandleCC->regs);
                        break;
                    case PSP_VPFE_BITS10:
                        LLC_setCcdcPixelBitWidth10Bit(ccdcHandleCC->regs);
                        break;
                    case PSP_VPFE_BITS8:
                        LLC_setCcdcPixelBitWidth8Bit(ccdcHandleCC->regs);
                        break;
                    default:
                        LLC_setCcdcPixelBitWidth16Bit(ccdcHandleCC->regs);
                        break;
                }
                if(PSP_VPFE_PACK8_16BITS_PIXEL == ccdcRawParamsCC->pack8)
                {
                    LLC_setPack16BitsPerPixel(ccdcHandleCC->regs);
                }
                else
                {
                    LLC_setPack8BitsPerPixel(ccdcHandleCC->regs);
                }
                LLC_setCcdcColorFormatCCDRaw(ccdcHandleCC->regs);
                LLC_setHDVDToSyncWithExtHDVD(ccdcHandleCC->regs);
                hd_vd_wid_h = (ccdcRawParamsCC->HDSyncWidth - 1u);
                hd_vd_wid_v = (ccdcRawParamsCC->VDSyncWidth - 1u);
                LLC_setCcdcHDVDSignalWidth(ccdcHandleCC->regs,
                    (Uint)hd_vd_wid_h, (Uint) hd_vd_wid_v);

                pix_lines_p = (ccdcRawParamsCC->numPxlPerLine - 1u);
                pix_lines_h = (ccdcRawParamsCC->numLinPerFld - 1u);
                LLC_setCcdcPixLines( ccdcHandleCC->regs, pix_lines_p, pix_lines_h );
                LLC_setCcdcHorzStartPixel(ccdcHandleCC->regs,
                    ccdcModeParamsCC->horzStartPix);
                LLC_setCcdcHorzPixelOutputOnRAM(ccdcHandleCC->regs,
                    (ccdcModeParamsCC->width - 1u));
                LLC_setCcdcVertStartPixel(ccdcHandleCC->regs,
                    ccdcModeParamsCC->vertStartPix);
                LLC_setCcdcVertLines(ccdcHandleCC->regs,
                    (ccdcModeParamsCC->height - 1u));
                LLC_setCcdcOffset(ccdcHandleCC->regs, ccdcModeParamsCC->pitch);
                LLC_setFIDSignalLatchOnVDTiming(ccdcHandleCC->regs);
                if (ccdcRawParamsCC->ALawEnable == PSP_VPFE_ALaw_Enable)
                {
                    LLC_Ccdc_ALawEnable(ccdcHandleCC->regs);
                    if(ccdcRawParamsCC->ALaw_Width<= 6u)
                    {
                        LLC_Ccdc_ALaw_SetGammaInput(ccdcHandleCC->regs,
                                      (Uint)ccdcRawParamsCC->ALaw_Width);
                    }
                    else
                    {
                        result = DDC_VPFE_E_FAIL;
                    }
                }
                else
                {
                    LLC_Ccdc_ALawDisable(ccdcHandleCC->regs);
                }
                ccdcHandleCC->CcdcParams.height =   ccdcModeParamsCC->height;
                ccdcHandleCC->CcdcParams.width =    ccdcModeParamsCC->width;
                ccdcHandleCC->CcdcParams.pitch =    ccdcModeParamsCC->pitch;
                ccdcHandleCC->CcdcParams.ffMode =   FVID_FIELD_MODE;
                ccdcHandleCC->CcdcParams.rawParams = ccdcModeParamsCC->rawParams;
#ifdef PSP_VIDEO_PATH_ENABLE
            /* Video Port Path -Data Formatter */
            {
                /* Enable VPEN */
                LLC_setCcdcVideoPortEnable(ccdcHandleCC->regs);
                /* 10 bit Selector */
                switch (ccdcRawParamsCC->dataSize)
                {
                    case PSP_VPFE_BITS16:
                        LLC_setCcdcDataFormatterBitSelect_9_00(
                            ccdcHandleCC->regs);
                        break;
                    case PSP_VPFE_BITS15:
                        LLC_setCcdcDataFormatterBitSelect_14_05(
                            ccdcHandleCC->regs);
                        break;
                    case PSP_VPFE_BITS14:
                        LLC_setCcdcDataFormatterBitSelect_13_04(
                            ccdcHandleCC->regs);
                        break;
                    case PSP_VPFE_BITS13:
                        LLC_setCcdcDataFormatterBitSelect_12_03(
                            ccdcHandleCC->regs);
                        break;
                    case PSP_VPFE_BITS12:
                        LLC_setCcdcDataFormatterBitSelect_11_02(
                            ccdcHandleCC->regs);
                        break;
                    case PSP_VPFE_BITS11:
                        LLC_setCcdcDataFormatterBitSelect_10_01(
                            ccdcHandleCC->regs);
                        break;
                    case PSP_VPFE_BITS10:
                        LLC_setCcdcDataFormatterBitSelect_9_00(
                            ccdcHandleCC->regs);
                        break;
                    default:
                        LLC_setCcdcDataFormatterBitSelect_9_00(
                            ccdcHandleCC->regs);
                        break;
                }
                /* Data Formatter Pixel Selection */
                LLC_setCcdcDataFormatterHorzStartPixel(ccdcHandleCC->regs,
                    ccdcModeParamsCC->horzStartPix);
                LLC_setCcdcDataFormatterHorzInfo(ccdcHandleCC->regs,
                    (ccdcModeParamsCC->width));
                LLC_setCcdcDataFormatterVertStartLine(ccdcHandleCC->regs,
                    ccdcModeParamsCC->vertStartPix);
                LLC_setCcdcDataFormatterVertInfo(ccdcHandleCC->regs,
                    (ccdcModeParamsCC->height));
                /* Video Port Pixel Selection */
                LLC_setCcdcVidPortHorzStartPixel(ccdcHandleCC->regs, 0);
                LLC_setCcdcVidPortHorzInfo(ccdcHandleCC->regs,
                    (ccdcModeParamsCC->width));
                LLC_setCcdcVidPortVertInfo(ccdcHandleCC->regs,
                    (ccdcModeParamsCC->height - 1u));
             }
#endif /*PSP_VIDEO_PATH_ENABLE*/
        }
    }
    return(result);
}
/**
 *  \brief .This function is responsible for the setting of Black Level Compensationa and
 *          Black Adjustment parameters. This function validates whether the parameters are
 *          valid for the CCDC or are incorrect.
 *          On success this function returns an enumerated status of the
 *          operation indicating the validity of the parameters.
 */
DDC_VPFEStatus DDC_VPFEBlackAdjust(DDC_VPFECcdcObject* const ccdcHandleCC,Ptr paramsCC)
{
    DDC_VPFEStatus result                       = DDC_VPFE_E_FAIL;
    DDC_VPFEDeviceObject *vpfeDeviceHandleCC    = NULL;
    PSP_VPFECCDC_BlackAdj * blackAdj            = NULL;

    vpfeDeviceHandleCC = (DDC_VPFEDeviceObject * )DDC_VPFEGetDeviceHandle();

    /* Check the Parameters not NULL */
    if(((NULL != ccdcHandleCC) && (NULL != paramsCC))&& (NULL != vpfeDeviceHandleCC))
    {

        blackAdj  = (PSP_VPFECCDC_BlackAdj * )paramsCC;
        result  =   DDC_VPFE_SOK;
    }

    if (DDC_VPFE_SOK == result)
    {
        if (PSP_VPFE_BlkCompEnable == blackAdj->clampEn )
        {
            LLC_Ccdc_ClampEnable(ccdcHandleCC->regs);
        }
        else
        {
            LLC_Ccdc_ClampDisable(ccdcHandleCC->regs);
        }
        LLC_Ccdc_ClampSamplePixperLine(ccdcHandleCC->regs,(Uint)blackAdj->blackSampLen);
        LLC_Ccdc_ClampSampleLines(ccdcHandleCC->regs,(Uint)blackAdj->blackSampLine);
        LLC_Ccdc_ClampSampleStartPix(ccdcHandleCC->regs,(Uint)blackAdj->blackPixStart);
        LLC_Ccdc_ClampSampleGain(ccdcHandleCC->regs,(Uint)blackAdj->blackGain);

        LLC_Ccdc_SetDCClamp(ccdcHandleCC->regs,(Uint)blackAdj->dcSub);
        LLC_Ccdc_SetColorPattern(ccdcHandleCC->regs,(Uint)blackAdj->colPtn);
        LLC_Ccdc_BlackCompensation(ccdcHandleCC->regs,(Uint)blackAdj->blkCmpR,
                                                         (Uint)blackAdj->blkCmpGR,
                                                         (Uint)blackAdj->blkCmpGB,
                                                         (Uint)blackAdj->blkCmpB);
    }
    return result;
}

/**
 *  \brief .This function is responsible for the setting of fault Pixel Correction related
 *           parameters. This function validates whether the parameters are
 *          valid for the CCDC or are incorrect.
 *          On success this function returns an enumerated status of the
 *          operation indicating the validity of the parameters.
 */

DDC_VPFEStatus DDC_VPFEFpc(DDC_VPFECcdcObject* const ccdcHandleCC,Ptr paramsCC)
{
    DDC_VPFEStatus result                       = DDC_VPFE_E_FAIL;
    PSP_VPFE_CCDC_Fpc   *fpc                    = NULL;
    DDC_VPFEDeviceObject *vpfeDeviceHandleCC    = NULL;

    vpfeDeviceHandleCC = (DDC_VPFEDeviceObject * )DDC_VPFEGetDeviceHandle();

    /* Check the Parameters not NULL */
    if(((NULL != ccdcHandleCC) && (NULL != paramsCC))&& (NULL != vpfeDeviceHandleCC))
    {
        fpc  = (PSP_VPFE_CCDC_Fpc * )paramsCC;
        result  =   DDC_VPFE_SOK;
    }
    if ((DDC_VPFE_SOK == result) && (NULL != fpc ))
    {
        if (fpc->fpcreset == PSP_VPFE_Err_reset)
        {
            /* Reset the FPC */
            LLC_Ccdc_Fpc_Reset(ccdcHandleCC->regs);
        }
        else
        {
            /* Reset and the rest of the stuff cannot be combined. Do the Rest ogf the things here */
            LLC_Ccdc_Fpc_SetAddr(ccdcHandleCC->regs,(Uint)fpc->fpcAddr);
            LLC_Ccdc_Fpc_Setnum(ccdcHandleCC->regs,(Uint)fpc->fpcnum);
            LLC_Ccdc_Fpc_Disable(ccdcHandleCC->regs);
            LLC_Ccdc_Fpc_Enable(ccdcHandleCC->regs);
            /* The above sequence of turning OFF and ON is required acc to spec */
        }

    }
    return result;
}
