/******************************************************************************
**+-------------------------------------------------------------------------+**
**|                            ****                                         |**
**|                            ****                                         |**
**|                            ******o***                                   |**
**|                      ********_///_****                                  |**
**|                      ***** /_//_/ ****                                  |**
**|                       ** ** (__/ ****                                   |**
**|                           *********                                     |**
**|                            ****                                         |**
**|                            ***                                          |**
**|                                                                         |**
**|         Copyright (c) 2006-2010 Texas Instruments Incorporated          |**
**|                        ALL RIGHTS RESERVED                              |**
**|                                                                         |**
**| Permission is hereby granted to licensees of Texas Instruments          |**
**| Incorporated (TI) products to use this computer program for the sole    |**
**| purpose of implementing a licensee product based on TI products.        |**
**| No other rights to reproduce, use, or disseminate this computer         |**
**| program, whether in part or in whole, are granted.                      |**
**|                                                                         |**
**| TI makes no representation or warranties with respect to the            |**
**| performance of this computer program, and specifically disclaims        |**
**| any responsibility for any damages, special or consequential,           |**
**| connected with the use of this program.                                 |**
**|                                                                         |**
**+-------------------------------------------------------------------------+**
******************************************************************************/

/**
 *  \file   llc_vpfeCcdc.c
 *
 *  \brief  VPFE LLC layer Functions
 *
 *  This file contains the Implementation details of LLC layer functions
 *
 *  (C) Copyright 2010, Texas Instruments, Inc
 *
 *  \author     Maulik Desai
 *
 *  \version    0.1     created
 */

/******************************************************************************
                            Header File Inclusion
******************************************************************************/
#include <ti/sdo/pspdrivers/drivers/vpfe/psp_vpfe.h>
#include <ti/sdo/pspdrivers/drivers/vpfe/src/llc_vpfeCcdc.h>
#include <ti/sdo/pspdrivers/soc/dm6437/dsp/cslr_ccdc.h>

/******************************************************************************
                                Data-Structures
******************************************************************************/
/*-----------------------------------------------------------------------------
                    CCDC CSL Overlay Register Structure Handle
-----------------------------------------------------------------------------*/
/**
  * \ handle to access the Ccdc hardware register
  *
  */
static CSL_CcdcRegs  * ccdcRegs;
typedef CSL_CcdcRegs   CSL_VpssCcdcRegs;

/******************************************************************************
                                    Functions
******************************************************************************/
/*-----------------------------------------------------------------------------

-----------------------------------------------------------------------------*/
void LLC_ResetCcdcReg(Ptr regs)
{
    if(NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        ccdcRegs->PCR        = (Uint32)CSL_CCDC_PCR_RESETVAL;
        ccdcRegs->SYN_MODE   = (Uint32)CSL_CCDC_SYN_MODE_RESETVAL;
        ccdcRegs->HD_VD_WID  = (Uint32)CSL_CCDC_HD_VD_WID_RESETVAL;
        ccdcRegs->PIX_LINES  = (Uint32)CSL_CCDC_PIX_LINES_RESETVAL;
        ccdcRegs->HORZ_INFO  = (Uint32)CSL_CCDC_HORZ_INFO_RESETVAL;
        ccdcRegs->VERT_START = (Uint32)CSL_CCDC_VERT_START_RESETVAL;
        ccdcRegs->VERT_LINES = (Uint32)CSL_CCDC_VERT_LINES_RESETVAL;
        ccdcRegs->CULLING    = (Uint32)CSL_CCDC_CULLING_RESETVAL;
        ccdcRegs->HSIZE_OFF  = (Uint32)CSL_CCDC_HSIZE_OFF_RESETVAL;
        ccdcRegs->SDOFST     = (Uint32)CSL_CCDC_SDOFST_RESETVAL;
        ccdcRegs->SDR_ADDR   = (Uint32)CSL_CCDC_SDR_ADDR_RESETVAL;
        ccdcRegs->CLAMP      = (Uint32)CSL_CCDC_CLAMP_RESETVAL;
        ccdcRegs->DCSUB      = (Uint32)CSL_CCDC_DCSUB_RESETVAL;
        ccdcRegs->COLPTN     = (Uint32)CSL_CCDC_COLPTN_RESETVAL;
        ccdcRegs->BLKCMP     = (Uint32)CSL_CCDC_BLKCMP_RESETVAL;
        ccdcRegs->FPC        = (Uint32)CSL_CCDC_FPC_RESETVAL;
        ccdcRegs->FPC_ADDR   = (Uint32)CSL_CCDC_FPC_ADDR_RESETVAL;
        ccdcRegs->VDINT      = (Uint32)CSL_CCDC_VDINT_RESETVAL;
        ccdcRegs->ALAW       = (Uint32)CSL_CCDC_ALAW_RESETVAL;
        ccdcRegs->REC656IF   = (Uint32)CSL_CCDC_REC656IF_RESETVAL;
        ccdcRegs->CCDCFG     = (Uint32)CSL_CCDC_CCDCFG_RESETVAL;
        ccdcRegs->FMTCFG     = (Uint32)CSL_CCDC_FMTCFG_RESETVAL;
        ccdcRegs->FMT_HORZ   = (Uint32)CSL_CCDC_FMT_HORZ_RESETVAL;
        ccdcRegs->FMT_VERT   = (Uint32)CSL_CCDC_FMT_VERT_RESETVAL;
        ccdcRegs->VP_OUT     = (Uint32)CSL_CCDC_VP_OUT_RESETVAL;
    }
}

/**
  * \brief Read the field ID from the CCDC register
  *
  */
Bool LLC_getCcdcField(Ptr regs)
{
    Bool field;
    if(NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        field = (Bool)CSL_FEXT(ccdcRegs->SYN_MODE,CCDC_SYN_MODE_FLDSTAT);
    }
    return(field);
}

/**
  * \brief  This will validate the params and config the Display mode
  *
  */
void LLC_setCcdcModeProgressive(Ptr regs)
{
    if(NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINST(ccdcRegs->SYN_MODE,CCDC_SYN_MODE_FLDMODE, NON_INTERLACED);
    }
}

/**
  * \brief  This will configure the Display mode for interlaced
  *
  */
void LLC_setCcdcModeInterlaced( Ptr regs)
{
    if(NULL!= regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINST(ccdcRegs->SYN_MODE,CCDC_SYN_MODE_FLDMODE, INTERLACED);
    }
}

/**
  * \brief  This Function will configure the Horizontal start pixel for
  *         Ccdc plane
  *
  */
void LLC_setCcdcHorzStartPixel( Ptr regs, Uint ccdcLMargin)
{
    if(NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINS(ccdcRegs->HORZ_INFO, CCDC_HORZ_INFO_SPH, ccdcLMargin);
    }
}

/**
  * \brief This will send the Pixel output on Ram memory area
  *
  */
void LLC_setCcdcHorzPixelOutputOnRAM( Ptr regs, Uint ccdcHPix)
{
    if(NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINS(ccdcRegs->HORZ_INFO, CCDC_HORZ_INFO_NPH, ccdcHPix);
    }
}

/**
  * \brief This will set the start pixel for vertical in Ccdc plane
  *
  */
void LLC_setCcdcVertStartPixel( Ptr regs, Uint ccdcTMargin)
{
    if(NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINS(ccdcRegs->VERT_START, CCDC_VERT_START_SLV0, ccdcTMargin);
        CSL_FINS(ccdcRegs->VDINT, CCDC_VDINT_VDINT0, ccdcTMargin);
        CSL_FINS(ccdcRegs->VERT_START, CCDC_VERT_START_SLV1, ccdcTMargin);
    }
}

/**
  * \brief This will set the lines in Vertical postion in Ccdc plane
  *
  */
void LLC_setCcdcVertLines( Ptr regs, Uint ccdcVertLine)
{
    if(NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINS(ccdcRegs->VERT_LINES, CCDC_VERT_LINES_NLV, ccdcVertLine);
    }
}

/**
  * \brief This will set the pixel bit width to 16 bit
  *
  */
void LLC_setCcdcPixelBitWidth16Bit( Ptr regs)
{
    if(NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINST(ccdcRegs->SYN_MODE,CCDC_SYN_MODE_DATSIZ, _16_BITS);
    }
}

/**
  * \brief This will set the pixel bit width to 15 bit
  *
  */
void LLC_setCcdcPixelBitWidth15Bit( Ptr regs)
{
    if(NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINST(ccdcRegs->SYN_MODE,CCDC_SYN_MODE_DATSIZ, _15_BITS);
    }
}

/**
  * \brief This will set the pixel bit width to 14 bit
  *
  */
void LLC_setCcdcPixelBitWidth14Bit( Ptr regs)
{
    if(NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINST(ccdcRegs->SYN_MODE,CCDC_SYN_MODE_DATSIZ, _14_BITS);
    }
}

/**
  * \brief This will set the pixel bit width to 13 bit
  *
  */
void LLC_setCcdcPixelBitWidth13Bit( Ptr regs)
{
    if(NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINST(ccdcRegs->SYN_MODE,CCDC_SYN_MODE_DATSIZ, _13_BITS);
    }
}

/**
  * \brief This will set the pixel bit width to 12 bit
  *
  */
void LLC_setCcdcPixelBitWidth12Bit( Ptr regs)
{
    if(NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINST(ccdcRegs->SYN_MODE,CCDC_SYN_MODE_DATSIZ, _12_BITS);
    }
}

/**
  * \brief This will set the pixel bit width to 11 bit
  *
  */
void LLC_setCcdcPixelBitWidth11Bit( Ptr regs)
{
    if(NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINST(ccdcRegs->SYN_MODE,CCDC_SYN_MODE_DATSIZ, _11_BITS);
    }
}

/**
  * \brief This will set the pixel bit width to 10 bit
  *
  */
void LLC_setCcdcPixelBitWidth10Bit( Ptr regs)
{
    if(NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINST(ccdcRegs->SYN_MODE,CCDC_SYN_MODE_DATSIZ, _10_BITS);
    }
}

/**
  *\ brief This will set the pixel bit width to 8 bit
  *
  */
void LLC_setCcdcPixelBitWidth8Bit( Ptr regs)
{
    if(NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINST(ccdcRegs->SYN_MODE,CCDC_SYN_MODE_DATSIZ, _8_BITS);
    }
}

/**
  * \brief This will configure the Ccdc color format to YCC8 bits
  *
  */
void LLC_setCcdcColorFormatYCC8Bits( Ptr regs)
{
    if(NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINST(ccdcRegs->SYN_MODE,CCDC_SYN_MODE_INPMOD, YCBCR8);
    }
}

/**
  * \brief This will configure the Ccdc color format to Raw Mode bits
  *
  */
void LLC_setCcdcColorFormatCCDRaw( Ptr regs)
{
    if(NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINST(ccdcRegs->SYN_MODE,CCDC_SYN_MODE_INPMOD, CCDRAW);
    }
}

/**
  * \brief This will configure the start address of frame buffer in
  *  Ccdc plane
  *
  */
void LLC_setCcdcFBStartAddress( Ptr regs, Ptr fbAddress)
{
    Uint32 addr;
    if((NULL!=regs)&&(NULL!=fbAddress))
    {
        addr = (Uint32) fbAddress;
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINS(ccdcRegs->SDR_ADDR, CCDC_SDR_ADDR_SDR_ADDR, addr);
    }
}

/**
  * \brief This will configure the offset in Ccdc plane
  *
  */
void LLC_setCcdcOffset( Ptr regs, Uint ccdcOffset)
{
    if(NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINS(ccdcRegs->HSIZE_OFF, CCDC_HSIZE_OFF_LNOFST, ccdcOffset);
    }
}

/**
  * \brief This will set the output to SD RAM area
  *
  */
void LLC_setCcdcOutputToSDRAMEnable( Ptr regs)
{
    if(NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINST(ccdcRegs->SYN_MODE,CCDC_SYN_MODE_WEN, ENABLE);
    }
}

/**
  * \brief This will disable from SDRAM area
  *
  */
void LLC_setCcdcOutputToSDRAMDisable( Ptr regs)
{
    if(NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINST(ccdcRegs->SYN_MODE,CCDC_SYN_MODE_WEN, DISABLE);
    }
}

/**
  * \brief This will validate the param and will sync the
  *        HDVD to ExtHDVD
  */
void LLC_setHDVDToSyncWithExtHDVD( Ptr regs)
{
    if(NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINST(ccdcRegs->SYN_MODE,CCDC_SYN_MODE_VDHDEN, ENABLE);
    }
}

/**
  * \brief This will configure the FID polarity positive
  *
  */
void LLC_setCcdcFIDPolarityPositive( Ptr regs)
{
    if(NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINST(ccdcRegs->SYN_MODE,CCDC_SYN_MODE_FLDPOL, POSITIVE);
    }
}

/**
  * \brief This will configure the FID polarity negative
  *
  */
void LLC_setCcdcFIDPolarityNegative( Ptr regs)
{
    if(NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINST(ccdcRegs->SYN_MODE,CCDC_SYN_MODE_FLDPOL, NEGATIVE);
    }
}

/**
  * \brief This will configure the  HD Sync polarity positive in Ccdc plane
  *
  */
void LLC_setCcdcHDSyncPolarityPos( Ptr regs)
{
    if(NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINST(ccdcRegs->SYN_MODE,CCDC_SYN_MODE_HDPOL, POSITIVE);
    }
}

/**
  * \brief This will configure the  HD Sync polarity negative in Ccdc plane
  *
  */
void LLC_setCcdcHDSyncPolarityNeg( Ptr regs)
{
    if(NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINST(ccdcRegs->SYN_MODE,CCDC_SYN_MODE_HDPOL, NEGATIVE);
    }
}

/**
  * \brief This will configure the VD Sync polarity positive in Ccdc plane
  *
  */
void LLC_setCcdcVDSyncPolarityPos( Ptr regs)
{

    if(NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINST(ccdcRegs->SYN_MODE,CCDC_SYN_MODE_VDPOL, POSITIVE);
    }
}

/**
  * \brief This will configure the VD Sync polarity negative in Ccdc plane
  *
  */
void LLC_setCcdcVDSyncPolarityNeg( Ptr regs)
{
    if(NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINST(ccdcRegs->SYN_MODE,CCDC_SYN_MODE_VDPOL, NEGATIVE);
    }
}

/**
  * \brief This will configure the Capture on in Ccdc plane
  *
  */
void LLC_setCcdcCaptureOn( Ptr regs)
{
    if(NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINST(ccdcRegs->PCR,CCDC_PCR_ENABLE, ENABLE);
    }
}

/**
  * \brief This will configure the Capture off in Ccdc plane
  *
  */
void LLC_setCcdcCaptureOff( Ptr regs)
{
    if(NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINST(ccdcRegs->PCR,CCDC_PCR_ENABLE, DISABLE);
    }
}

/**
  * \brief To configure the VDHD sync direction input
  *
  */
void LLC_setVDHDSyncDirectionInput( Ptr regs)
{
    if(NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINST(ccdcRegs->SYN_MODE,CCDC_SYN_MODE_VDHDOUT, INPUT);
    }
}

/**
  * \brief To configure the VDHD sync direction output
  *
  */
void LLC_setVDHDSyncDirectionOutput( Ptr regs)
{
    if(NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINST(ccdcRegs->SYN_MODE,CCDC_SYN_MODE_VDHDOUT, OUTPUT);
    }
}

/**
  * \brief To configure the field id direction input
  *
  */
void LLC_setFieldIdDirectionInput( Ptr regs)
{
    if(NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINST(ccdcRegs->SYN_MODE,CCDC_SYN_MODE_FLDOUT, INPUT);
    }
}

/**
  * \brief To configure the field id direction output
  *
  */
void LLC_setFieldIdDirectionOutput( Ptr regs)
{
    if(NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINST(ccdcRegs->SYN_MODE,CCDC_SYN_MODE_FLDOUT, OUTPUT);
    }
}

/**
  * \brief To set the Ccdc plane data width to 16 bits.
  *
  */
void LLC_setCcdcDataWidth16Bits( Ptr regs)
{

    if(NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINST(ccdcRegs->SYN_MODE,CCDC_SYN_MODE_DATSIZ, _16_BITS);
    }
}

/**
  * \brief To set the Ccdc plane in pack 8 bits per pixel
  *
  */
void LLC_setPack8BitsPerPixel( Ptr regs)
{

    if(NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINST(ccdcRegs->SYN_MODE,CCDC_SYN_MODE_PACK8, _8BITS_PIXEL);
    }
}

/**
  * \brief To set the Ccdc plane in pack 16 bits per pixel
  *
  */
void LLC_setPack16BitsPerPixel( Ptr regs)
{
    if(NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINST(ccdcRegs->SYN_MODE,CCDC_SYN_MODE_PACK8, _16BITS_PIXEL);
    }
}

/**
  * \brief To set the Ccdc plane in REC656 interlaced enable
  *
  */
void LLC_setREC656InterfaceEnable( Ptr regs)
{
    if(NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINST(ccdcRegs->REC656IF,CCDC_REC656IF_R656ON, ENABLE);
    }
}

/**
  * \brief To set the error correction enable
  *
  */
void LLC_setErrorCorrectionEnable( Ptr regs)
{
    if(NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINST(ccdcRegs->REC656IF,CCDC_REC656IF_ECCFVH, ENABLE);
    }
}

/**
  * \brief To set the Ccdc plane in REC656 interlaced disable
  *
  */
void LLC_setREC656InterfaceDisable( Ptr regs)
{
    if(NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINST(ccdcRegs->REC656IF,CCDC_REC656IF_R656ON, DISABLE);
    }
}

/**
  * \brief  To set the FID signal to latch on  Video timings
  *
  */
void LLC_setFIDSignalLatchOnVDTiming( Ptr regs)
{
    if(NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINST(ccdcRegs->CCDCFG,CCDC_CCDCFG_FIDMD, LATCH_AT_VSYNC);
    }
}

/**
  * \brief  To set the FID signal to no latch on  Video timings
  *
  */
void LLC_setFIDSignalNoLatch( Ptr regs)
{
    if(NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINST(ccdcRegs->CCDCFG,CCDC_CCDCFG_FIDMD, NO_LATCH);
    }
}

/**
  * \brief To set the FID signal to latch on  Video edge
  *
  */
void LLC_setFIDSignalLatchOnVDEdge( Ptr regs)
{
    if(NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINST(ccdcRegs->CCDCFG,CCDC_CCDCFG_FIDMD, LATCH_AT_VD_EDGE);
    }
}

/**
  * \brief To set the FID signal to latch on  Video DHD Phase
  *
  */
void LLC_setFIDSignlLatchOnVDHDPhas(Ptr regs)
{
    if(NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINST(ccdcRegs->CCDCFG,CCDC_CCDCFG_FIDMD, LATCH_ON_VD_HD_PHASE);
    }
}

/**
  * \brief To set the VD Interrupt0 timings
  *
  */
void LLC_setVDINT0Timing( Ptr regs, Uint hLinesVD0)
{
    if(NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINS(ccdcRegs->VDINT,CCDC_VDINT_VDINT0, hLinesVD0);
    }
}

/**
  * \brief To set the VD Interrupt1 timings
  *
  */
void LLC_setVDINT1Timing( Ptr regs, Uint hLinesVD1)
{
    if(NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINS(ccdcRegs->VDINT,CCDC_VDINT_VDINT1, hLinesVD1);
    }
}

/**
  * \brief To set the REC656D data width to 8 bits in Ccdc plane
  *
  */
void LLC_setREC656DataWidth8Bits( Ptr regs)
{
    if(NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINST(ccdcRegs->CCDCFG,CCDC_CCDCFG_BW656, _8_BITS);
    }
}

/**
  * \brief To set the REC656D data width to 10 bits in Ccdc plane
  *
  */
void LLC_setREC656DataWidth10Bits( Ptr regs)
{
    if(NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINST(ccdcRegs->CCDCFG,CCDC_CCDCFG_BW656, _10_BITS);
    }
}

/**
  * \brief To set the function latch register on VSYNC on latch
  *
  */
void LLC_setLatchOnVSYNC( Ptr regs)
{
    if(NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINST(ccdcRegs->CCDCFG,CCDC_CCDCFG_VDLC, LATCHEDONVSYNC);
    }
}

/**
  * \brief To set the function latch register on VSYNC no latch
  *
  */
void LLC_setNotLatchedOnVSYNC( Ptr regs)
{
    if(NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINST(ccdcRegs->CCDCFG,CCDC_CCDCFG_VDLC, NOTLATCHEDONVSYNC);
    }
}

/**
  * \brief To set the Y bit position to odd pixel
  *
  */
void LLC_setYBitPosOddPixel( Ptr regs)
{
    if(NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINST(ccdcRegs->CCDCFG, CCDC_CCDCFG_Y8POS, ODDPIXEL);
    }
}

/**
  * \brief To set the FID signal to be non inversed
  *
  */
void LLC_setFIDSignalNonInversed( Ptr regs)
{
    if(NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINST(ccdcRegs->SDOFST, CCDC_SDOFST_FIINV, NONINVERSE);
    }
}

/**
  * \brief To set the FID signal to be inversed
  *
  */
void LLC_setFIDSignalInversed( Ptr regs)
{
    if(NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINST(ccdcRegs->SDOFST, CCDC_SDOFST_FIINV, INVERSE);
    }
}

/**
  * \brief To set the line offset value of field to  1_1lines
  *
  */
void LLC_setLnOfstValField_1_1Lines( Ptr regs)
{

    if(NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINST(ccdcRegs->SDOFST, CCDC_SDOFST_FOFST, PLUS_1LINE);
    }
}

/**
  * \brief To set the line offset value of even line even field to  0_2lines
  *
  */
void LLC_setLnOfstEvnLnEvnFld_2Lines( Ptr regs)
{

    if(NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINST(ccdcRegs->SDOFST, CCDC_SDOFST_LOFTS0, PLUS_2LINES);
    }
}
/**
  * \brief To set the line offset value of even line odd field to  1_2lines
  *
  */
void LLC_setLnOfstEvnLnOddFld_2Lines( Ptr regs)
{

    if(NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINST(ccdcRegs->SDOFST, CCDC_SDOFST_LOFTS2, PLUS_2LINES);
    }
}

/**
  * \brief To set the line offset value of odd line even field to  0_2lines
  *
  */
void LLC_setLnOfstOddLnEvnFld_2Lines( Ptr regs)
{

    if(NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINST(ccdcRegs->SDOFST, CCDC_SDOFST_LOFTS1, PLUS_2LINES);
    }
}

/**
  * \brief To set the line offset value of odd line odd field to  1_2lines
  *
  */
void LLC_setLnOfstOddLnOddFld_2Lines( Ptr regs)
{
    if(NULL!= regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINST(ccdcRegs->SDOFST, CCDC_SDOFST_LOFTS3, PLUS_2LINES);
    }
}
/**
  * \brief To set the data polarity to Normal
  *
  */
void LLC_ccdcsetDataPolNormal( Ptr regs)
{
    if(NULL!= regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINST(ccdcRegs->SYN_MODE, CCDC_SYN_MODE_DATAPOL, NORMAL);
    }
}
/**
  * \brief To set the data polarity to OnesComplement
  *
  */
void LLC_ccdcsetDataPolOnesComp( Ptr regs)
{
    if(NULL!= regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINST(ccdcRegs->SYN_MODE, CCDC_SYN_MODE_DATAPOL, ONES_COMPLEMENT);
    }
}


/**
  * \brief This will configure the HD and VD Signal width
  *
  *
  */
void LLC_setCcdcHDVDSignalWidth( Ptr regs, Uint hdw, Uint vdw)
{
    if(NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINS(ccdcRegs->HD_VD_WID, CCDC_HD_VD_WID_HDW, hdw);
        CSL_FINS(ccdcRegs->HD_VD_WID, CCDC_HD_VD_WID_VDW, vdw);
    }
}

/**
  * \brief This will configure the pixels per line and the half lines
  *        per field or frame
  *
  *
  */
void LLC_setCcdcPixLines( Ptr regs, Uint ppln, Uint hlpfr )
{
    if(NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINS(ccdcRegs->PIX_LINES, CCDC_PIX_LINES_PPLN, ppln);
        CSL_FINS(ccdcRegs->PIX_LINES, CCDC_PIX_LINES_HLPFR, hlpfr);
    }
}

/**
  * \brief This will Enable the Black clamping
  *        per field or frame
  *
  *
  */
void LLC_Ccdc_ClampEnable(Ptr regs)
{
    if(NULL!= regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINST(ccdcRegs->CLAMP, CCDC_CLAMP_CLAMPEN, ENABLE);
    }
}

/**
  * \brief This will Disable the Black clamping
  *
  *
  *
  */
void LLC_Ccdc_ClampDisable(Ptr regs)
{
    if(NULL!= regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINST(ccdcRegs->CLAMP, CCDC_CLAMP_CLAMPEN, DISABLE);
    }
}

/**
  * \brief This will Set the Optical black clamping length of each line
  *
  *
  *
  */
void LLC_Ccdc_ClampSamplePixperLine(Ptr regs, Uint  pixsperline)
{
    if(NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINS(ccdcRegs->CLAMP, CCDC_CLAMP_OBSLEN, pixsperline);
    }
}

/**
  * \brief This will Set the Optical black clamping lines
  *
  *
  *
  */
void LLC_Ccdc_ClampSampleLines(Ptr regs, Uint   pxlines)
{
    if(NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINS(ccdcRegs->CLAMP, CCDC_CLAMP_OBSLN, pxlines);
    }
}

/**
  * \brief This will Set the Optical black clamping start pixel
  *
  *
  *
  */
void LLC_Ccdc_ClampSampleStartPix(Ptr regs, Uint    startpix)
{
    if(NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINS(ccdcRegs->CLAMP, CCDC_CLAMP_OBST, startpix);
    }
}

/**
  * \brief This will Set the Optical black clamping Gain
  *
  *
  *
  */
void LLC_Ccdc_ClampSampleGain(Ptr regs, Uint obgain)
{
    if(NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINS(ccdcRegs->CLAMP, CCDC_CLAMP_OBGAIN, obgain);
    }
}

/**
  * \brief This will set the DC Clamp
  *
  *
  *
  */
void LLC_Ccdc_SetDCClamp(Ptr regs, Uint dcsub)
{
    if(NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINS(ccdcRegs->DCSUB, CCDC_DCSUB_DCSUB, dcsub);
    }
}

/**
  * \brief This will set the CCD Color Pattern
  *
  *
  *
  */
void LLC_Ccdc_SetColorPattern(Ptr regs, Uint colpattern)
{
    if(NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        ccdcRegs->COLPTN = colpattern;
    }
}

/**
  * \brief This will set the Black Level Compensation
  *
  *
  *
  */
void LLC_Ccdc_BlackCompensation(Ptr regs, Uint r_ye, Uint gr_cy, Uint gb_g, Uint b_mg)
{
    if(NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINS(ccdcRegs->BLKCMP, CCDC_BLKCMP_R, r_ye);
        CSL_FINS(ccdcRegs->BLKCMP, CCDC_BLKCMP_GR, gr_cy);
        CSL_FINS(ccdcRegs->BLKCMP, CCDC_BLKCMP_GB, gb_g);
        CSL_FINS(ccdcRegs->BLKCMP, CCDC_BLKCMP_B, b_mg);
    }
}

/**
  * \brief This Enable the ALaw compaction to 8 bits
  *
  *
  *
  */

void LLC_Ccdc_ALawEnable(Ptr regs)
{
    if(NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINST(ccdcRegs->ALAW, CCDC_ALAW_CCDTBL, ENABLE);

    }
}

/**
  * \brief This Disable the ALaw compaction to 8 bits
  *
  *
  *
  */
void LLC_Ccdc_ALawDisable(Ptr regs)
{
    if(NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINST(ccdcRegs->ALAW, CCDC_ALAW_CCDTBL, DISABLE);

    }
}

/**
  * \brief This will set the gamma input of the ALaw Configuration
  *
  *
  *
  */
void LLC_Ccdc_ALaw_SetGammaInput(Ptr regs, Uint gwdi)
{
    if(NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINS(ccdcRegs->ALAW, CCDC_ALAW_GWDI, gwdi);
    }
}

/**
  * \brief This will Reset the Fault Pixel Correction
  *
  *
  *
  */
void LLC_Ccdc_Fpc_Reset(Ptr regs)
{
    if(NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINST(ccdcRegs->FPC, CCDC_FPC_FPERR, ERROR);
    }
}

/**
  * \brief This will Disable the Fault Pixel Correction
  *
  *
  *
  */
void LLC_Ccdc_Fpc_Disable(Ptr regs)
{
    if(NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINST(ccdcRegs->FPC, CCDC_FPC_FPCEN, DISABLED);
    }
}

/**
  * \brief This will enable the Fault Pixel Correction
  *
  *
  *
  */
void LLC_Ccdc_Fpc_Enable(Ptr regs)
{
    if(NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINST(ccdcRegs->FPC, CCDC_FPC_FPCEN, ENABLED);
    }
}

/**
  * \brief This will set the address of the Fault Pixel Correction Table
  *
  *
  *
  */
void LLC_Ccdc_Fpc_SetAddr(Ptr regs, Uint fpcaddress)
{
    if(NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINS(ccdcRegs->FPC_ADDR, CCDC_FPC_ADDR_FPC_ADDR, fpcaddress);
    }

}

/**
  * \brief This will set the number of the fault pixels to be corrected
  *
  *
  *
  */
void LLC_Ccdc_Fpc_Setnum(Ptr regs, Uint fpcnum)
{
    if(NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINS(ccdcRegs->FPC, CCDC_FPC_FPNUM, fpcnum);
    }
}
/**
 * \brief This will Enable the Video Port Interface
 *
 *
 *
 */
void LLC_setCcdcVideoPortEnable(Ptr regs)
{
    if (NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINST(ccdcRegs->FMTCFG, CCDC_FMTCFG_VPEN, ENABLE);
    }

}
/**
 * \brief This will Disable the Video Port Interface
 *
 *
 *
 */
void LLC_setCcdcVideoPortDisable(Ptr regs)
{
    if (NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINST(ccdcRegs->FMTCFG, CCDC_FMTCFG_VPEN, DISABLE);
    }

}
/**
 * \brief Number of Input bits to be retained.This function will
 *        select 15-06 bits
 *
 *
 */
void LLC_setCcdcDataFormatterBitSelect_15_06(Ptr regs)
{
    if (NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINST(ccdcRegs->FMTCFG, CCDC_FMTCFG_VPIN, BITS_15_06);
    }
}
/**
 * \brief Number of Input bits to be retained.This function will
 *        select 14_05 bits
 *
 *
 */
void LLC_setCcdcDataFormatterBitSelect_14_05(Ptr regs)
{
    if (NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINST(ccdcRegs->FMTCFG, CCDC_FMTCFG_VPIN, BITS_14_05);
    }
}
/**
 * \brief Number of Input bits to be retained.This function will
 *        select 13_04 bits
 *
 *
 */

void LLC_setCcdcDataFormatterBitSelect_13_04(Ptr regs)
{
    if (NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINST(ccdcRegs->FMTCFG, CCDC_FMTCFG_VPIN, BITS_13_04);
    }
}
/**
 * \brief Number of Input bits to be retained.This function will
 *        select 12_03 bits
 *
 *
 */
void LLC_setCcdcDataFormatterBitSelect_12_03(Ptr regs)
{
    if (NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINST(ccdcRegs->FMTCFG, CCDC_FMTCFG_VPIN, BITS_12_03);
    }
}
/**
 * \brief Number of Input bits to be retained.This function will
 *        select 11_02 bits
 *
 *
 */
void LLC_setCcdcDataFormatterBitSelect_11_02(Ptr regs)
{
    if (NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINST(ccdcRegs->FMTCFG, CCDC_FMTCFG_VPIN, BITS_11_02);
    }
}
/**
 * \brief Number of Input bits to be retained.This function will
 *        select 10_01 bits
 *
 *
 */
void LLC_setCcdcDataFormatterBitSelect_10_01(Ptr regs)
{
    if (NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINST(ccdcRegs->FMTCFG, CCDC_FMTCFG_VPIN, BITS_10_01);
    }
}
void LLC_setCcdcDataFormatterBitSelect_9_00(Ptr regs)
{
    if (NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINST(ccdcRegs->FMTCFG, CCDC_FMTCFG_VPIN, BITS_09_00);
    }
}
/**
 * \brief Set the Number of Pixels in Horizontal Direction
 *
 *
 *
 */
void LLC_setCcdcDataFormatterHorzInfo(Ptr regs, Uint ccdcHPix)
{
    if (NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINS(ccdcRegs->FMT_HORZ, CCDC_FMT_HORZ_FMTLNH, ccdcHPix);
    }
}
/**
 * \brief Set Start Pixel Horizontal from start of HD
 *
 *
 *
 */
void LLC_setCcdcDataFormatterHorzStartPixel(Ptr regs, Uint ccdcLMargin)
{
    if (NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINS(ccdcRegs->FMT_HORZ, CCDC_FMT_HORZ_FMTSPH, ccdcLMargin);
    }
}
/**
 * \brief Set Start Line from start of VD
 *
 *
 *
 */
void LLC_setCcdcDataFormatterVertStartLine(Ptr regs, Uint ccdcTMargin)
{
    if (NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINS(ccdcRegs->FMT_VERT, CCDC_FMT_VERT_FMTSLV, ccdcTMargin);
    }
}
/**
 * \brief Set Number of Lines in Vertical Direction
 *
 *
 *
 */
void LLC_setCcdcDataFormatterVertInfo(Ptr regs, Uint ccdcVLines)
{
    if (NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINS(ccdcRegs->FMT_VERT, CCDC_FMT_VERT_FMTLNV, ccdcVLines);
    }
}
/**
 * \brief Set Horizontal Start Pixels in each output line out of Video Port
 *
 *
 *
 */
void LLC_setCcdcVidPortHorzStartPixel(Ptr regs, Uint ccdcLMargin)
{
    if (NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINS(ccdcRegs->VP_OUT, CCDC_VP_OUT_HORZ_ST, ccdcLMargin);
    }
}
/**
 * \brief Set Number of Horizontal Pixels out of Video Port
 *
 *
 *
 */
void LLC_setCcdcVidPortHorzInfo(Ptr regs, Uint ccdcHPixel)
{
    if (NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINS(ccdcRegs->VP_OUT, CCDC_VP_OUT_HORZ_NUM, ccdcHPixel);
    }
}
/**
 * \brief Set Number of Vertical Lines out of Video Port
 *
 *
 *
 */
void LLC_setCcdcVidPortVertInfo(Ptr regs, Uint ccdcVLines)
{
    if (NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINS(ccdcRegs->VP_OUT, CCDC_VP_OUT_VERT_NUM, ccdcVLines);
    }
}

/**
  * \brief Read the CCDC Engine Enable/Disable Bit
  *
  */
Bool LLC_getCcdcEngineStat(Ptr regs)
{
    Bool field;
    if(NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        field = (Bool)CSL_FEXT(ccdcRegs->PCR,CCDC_PCR_ENABLE);
    }
    return(field);
}
/**
  * \brief To set the line offset value of even line even field to  0_1lines
  *
  */
void LLC_setLnOfstEvnLnEvnFld_1Line( Ptr regs)
{

    if(NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINST(ccdcRegs->SDOFST, CCDC_SDOFST_LOFTS0, PLUS_1LINE);
    }
}
/**
  * \brief To set the line offset value of even line odd field to  1_1lines
  *
  */
void LLC_setLnOfstEvnLnOddFld_1Line( Ptr regs)
{

    if(NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINST(ccdcRegs->SDOFST, CCDC_SDOFST_LOFTS2, PLUS_1LINE);
    }
}

/**
  * \brief To set the line offset value of odd line even field to  0_1lines
  *
  */
void LLC_setLnOfstOddLnEvnFld_1Line( Ptr regs)
{

    if(NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINST(ccdcRegs->SDOFST, CCDC_SDOFST_LOFTS1, PLUS_1LINE);
    }
}

/**
  * \brief To set the line offset value of odd line odd field to  1_1lines
  *
  */
void LLC_setLnOfstOddLnOddFld_1Line( Ptr regs)
{
    if(NULL!= regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINST(ccdcRegs->SDOFST, CCDC_SDOFST_LOFTS3, PLUS_1LINE);
    }
}
/**
  * \brief To set the VDINT as number of lines
  *
  */
void LLC_configVDINT(Ptr regs, Uint numlines)
{
    if(NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        CSL_FINS(ccdcRegs->VDINT, CCDC_VDINT_VDINT0, numlines);
    }
}    

Uint32 LLC_getVDINT(Ptr regs)
{
    Uint32 value;
    if(NULL!=regs)
    {
        ccdcRegs = (CSL_CcdcRegs * )regs;
        value = CSL_FEXT(ccdcRegs->VDINT,CCDC_VDINT_VDINT0);
    }
    return(value);
}
