/******************************************************************************
**+-------------------------------------------------------------------------+**
**|                            ****                                         |**
**|                            ****                                         |**
**|                            ******o***                                   |**
**|                      ********_///_****                                  |**
**|                      ***** /_//_/ ****                                  |**
**|                       ** ** (__/ ****                                   |**
**|                           *********                                     |**
**|                            ****                                         |**
**|                            ***                                          |**
**|                                                                         |**
**|         Copyright (c) 2006-2010 Texas Instruments Incorporated          |**
**|                        ALL RIGHTS RESERVED                              |**
**|                                                                         |**
**| Permission is hereby granted to licensees of Texas Instruments          |**
**| Incorporated (TI) products to use this computer program for the sole    |**
**| purpose of implementing a licensee product based on TI products.        |**
**| No other rights to reproduce, use, or disseminate this computer         |**
**| program, whether in part or in whole, are granted.                      |**
**|                                                                         |**
**| TI makes no representation or warranties with respect to the            |**
**| performance of this computer program, and specifically disclaims        |**
**| any responsibility for any damages, special or consequential,           |**
**| connected with the use of this program.                                 |**
**|                                                                         |**
**+-------------------------------------------------------------------------+**
******************************************************************************/

/**
 *  \file   llc_vpfeCcdc.h
 *
 *  \brief  VPFE LLC layer Function dependencies
 *
 *  This file contains the dependencies of LLC layer functions
 *
 *  (C) Copyright 2010, Texas Instruments, Inc
 *
 *  \note       Set tabstop to 4 (:se ts=4) while viewing this file in an
 *              editor
 *
 *  \author     Maulik Desai
 *
 *  \version    0.1     Created
 */
#ifndef _LLC_VPFECCDC_H
#define _LLC_VPFECCDC_H

#ifdef __cplusplus
extern "C" {
#endif

/******************************************************************************
                               Functions
******************************************************************************/
/**
  * \brief This will Update all the Register with Default Values
  *
  * \param  regs        [IN]    handle for Ccdc plane
  * \returns                    Ccdc field id
  *
  */
void LLC_ResetCcdcReg(Ptr regs);

/**
  * \brief This will return the Ccdc field id
  *
  * \param  regs        [IN]    handle for Ccdc plane
  * \returns                    Ccdc field id
  *
  */
Bool LLC_getCcdcField(Ptr regs);

/**
  * \brief  This will validate the params and config the Display mode
  *
  * \param  regs        [IN]                handle to access Ccdc related hardware
  *
  */
void LLC_setCcdcModeProgressive(Ptr regs);

/**
  * \brief  This will configure the Display mode for interlaced
  *
  *
  * \param  regs        [IN]                handle to access Ccdc related hardware
  *
  */
void LLC_setCcdcModeInterlaced(Ptr regs);

/**
  * \brief  This Function will configure the Horizontal start pixel for
  *         Ccdc plane
  *
  *
  * \param  regs        [IN]                handle to access Ccdc related hardware
  * \param  ccdcLMargin [IN]            left margin of Ccdc plane
  *
  */
void LLC_setCcdcHorzStartPixel(Ptr regs, Uint ccdcLMargin);

/**
  * \brief This will send the Pixel output on Ram memory  area
  *
  *
  * \param  regs        [IN]         handle to access Ccdc related hardware
  * \param  ccdcHorzPixels [IN]      Horizontal pixel of Ccdc plane
  *
  */
void LLC_setCcdcHorzPixelOutputOnRAM(Ptr regs, Uint ccdcHorzPixels);

/**
  * \brief This will set the start pixel for vertical in Ccdc plane
  *
  *
  * \param  regs        [IN]                handle to access Ccdc related hardware
  * \param  ccdcTMargin [IN]        Top margin pixel for Ccdc palne in vertical position
  *
  */
void LLC_setCcdcVertStartPixel(Ptr regs, Uint ccdcTMargin);

/**
  * \brief This will set the lines in Vertical postion in Ccdc plane
  *
  * \param  regs         [IN]               handle to access Ccdc related hardware
  * \param  ccdcVertLine [IN]       vertical line in Ccdc plane
  *
  */
void LLC_setCcdcVertLines(Ptr regs, Uint ccdcVertLine);

/**
  * \brief This will set the pixel bit width to 16 bit
  *
  *
  * \param  regs        [IN]                handle to access Ccdc related hardware
  *
  */
void LLC_setCcdcPixelBitWidth16Bit(Ptr regs);

/**
  * \brief This will set the pixel bit width to 8 bit
  *
  *
  * \param  regs        [IN]                handle to access Ccdc related hardware
  *
  */
void LLC_setCcdcPixelBitWidth8Bit(Ptr regs);

/**
  * \brief This will configure the Ccdc cloour format to YCC8 bits
  *
  *
  * \param  regs        [IN]                handle to access Ccdc related hardware
  *
  */
void LLC_setCcdcColorFormatYCC8Bits(Ptr regs);

/**
  * \brief This will configure the Ccdc croma order to YCbCr
  *
  *
  * \param  regs        [IN]                handle to access Ccdc related hardware
  *
  */
void LLC_setCcdcChromaOrderYCbCr(Ptr regs);

/**
  * \brief This will configure the start address of frame buffer in
  *  Ccdc plane
  *
  * \param  regs        [IN]                Handle to access Ccdc related hardware
  * \param fbAddress    [IN]                 Address to set the start address
  *
  */
void LLC_setCcdcFBStartAddress(Ptr regs, Ptr fbAddress);

/**
  * \brief This will configure the offset in Ccdc plane
  *
  * \param  regs        [IN]                Handle to access Ccdc related hardware
  * \param ccdcOffset   [IN]                Ccdc offset value
  *
  */
void LLC_setCcdcOffset(Ptr regs, Uint ccdcOffset);

/**
  * \brief This will set the output to SD RAm area
  *
  *
  * \param  regs        [IN]                Handle to access Ccdc related hardware
  *
  */
void LLC_setCcdcOutputToSDRAMEnable(Ptr regs);

/**
  * \brief This will disable from SDRAM area
  *
  *
  * \param  regs        [IN]                Handle to access Ccdc related hardware
  *
  */
void LLC_setCcdcOutputToSDRAMDisable(Ptr regs);

/**
  * \brief This will validate the param and will sync the
  *        HDVD to ExtHDVD
  *
  * \param  regs        [IN]                Handle to access Ccdc related hardware
  *
  */
void LLC_setHDVDToSyncWithExtHDVD(Ptr regs);

/**
  * \brief This will configure the FID polarity positive
  *
  * \param  regs        [IN]                Handle to access Ccdc related hardware
  *
  */
void LLC_setCcdcFIDPolarityPositive(Ptr regs);

/**
  * \brief This will configure the FID polarity negative
  *
  * \param  regs        [IN]                Handle to access Ccdc related hardware
  *
  */
void LLC_setCcdcFIDPolarityNegative(Ptr regs);

/**
  * \brief This will configure the  HD Sync polarity positive in Ccdc plane
  *
  * \param  regs        [IN]                Handle to access Ccdc related hardware
  *
  */
void LLC_setCcdcHDSyncPolarityPos(Ptr regs);

/**
  * \brief This will configure the  HD Sync polarity negative in Ccdc plane
  *
  * \param  regs        [IN]                Handle to access Ccdc related hardware
  *
  */
void LLC_setCcdcHDSyncPolarityNeg(Ptr regs);

/**
  * \brief This will configure the VD Sync polarity positive in Ccdc plane
  *
  * \param  regs        [IN]                Handle to access Ccdc related hardware
  *
  */
void LLC_setCcdcVDSyncPolarityPos(Ptr regs);

/**
  * \brief This will configure the VD Sync polarity negative in Ccdc plane
  *
  * \param  regs        [IN]                Handle to access Ccdc related hardware
  *
  */
void LLC_setCcdcVDSyncPolarityNeg(Ptr regs);

/**
  * \brief This will configure the Capture on in Ccdc plane
  *
  * \param  regs        [IN]                Handle to access Ccdc related hardware
  *
  */
void LLC_setCcdcCaptureOn(Ptr regs);

/**
  * \brief This will configure the Capture off in Ccdc plane
  *
  *
  * \param  regs        [IN]                Handle to access Ccdc related hardware
  *
  */
void LLC_setCcdcCaptureOff(Ptr regs);

/**
  * \\brief To set the line offset value of odd line odd field to  1_2lines
  *
  *
  * \param  regs        [IN]                Handle to access Ccdc related hardware
  *
  */
void LLC_setLnOfstOddLnOddFld_2Lines(Ptr regs);

/**
  * \brief To set the line offset value of even line odd field to  1_2lines
  *
  *
  * \param  regs        [IN]                Handle to access Ccdc related hardware
  *
  */
void LLC_setLnOfstEvnLnOddFld_2Lines(Ptr regs);

/**
  * \brief To set the line offset value of odd line even field to  0_2lines
  *
  *
  * \param  regs        [IN]                Handle to access Ccdc related hardware
  *
  */
void LLC_setLnOfstOddLnEvnFld_2Lines(Ptr regs);

/**
  * \brief To set the line offset value of even line even field to  0_2lines
  *
  *
  * \param  regs        [IN]                Handle to access Ccdc related hardware
  *
  */
void LLC_setLnOfstEvnLnEvnFld_2Lines(Ptr regs);

/**
  * \brief To set the line offset value of field to  1_1lines
  *
  *
  * \param  regs        [IN]                Handle to access Ccdc related hardware
  *
  */
void LLC_setLnOfstValField_1_1Lines(Ptr regs);

/**
  * \brief To set the FID signal to be inversed
  *
  *
  * \param  regs        [IN]                Handle to access Ccdc related hardware
  *
  */
void LLC_setFIDSignalInversed(Ptr regs);

/**
  * \brief To set the FID signal to be non inversed
  *
  *
  * \param  regs        [IN]                Handle to access Ccdc related hardware
  *
  */
void LLC_setFIDSignalNonInversed(Ptr regs);

/**
  * \brief To set the Y bit position to odd pixel
  *
  *
  * \param  regs        [IN]                Handle to access Ccdc related hardware
  *
  */
void LLC_setYBitPosOddPixel(Ptr regs);

/**
  * \brief To set the function latch register on VSYNC no latch
  *
  *
  * \param  regs        [IN]                Handle to access Ccdc related hardware
  *
  */
void LLC_setNotLatchedOnVSYNC( Ptr regs);


/**
  * \brief To set the function latch register on VSYNC on latch
  *
  *
  * \param  regs        [IN]                Handle to access Ccdc related hardware
  *
  */
void LLC_setLatchOnVSYNC( Ptr regs);

/**
  * \brief To set the REC656D data width to 10 bits in Ccdc plane
  *
  *
  * \param  regs        [IN]                Handle to access Ccdc related hardware
  *
  */
void LLC_setREC656DataWidth10Bits( Ptr regs);

/**
  * \brief To set the REC656D data width to 8 bits in Ccdc plane
  *
  *
  * \param  regs        [IN]                Handle to access Ccdc related hardware
  *
  */
void LLC_setREC656DataWidth8Bits( Ptr regs);

/**
  * \brief To set the VD Interrupt1 timings
  *
  *
  * \param  regs        [IN]                Handle to access Ccdc related hardware
  * \param hLinesVD1    [IN]                h lines line value
  *
  */
void LLC_setVDINT1Timing( Ptr regs, Uint hLinesVD1);

/**
  * \brief To set the VD Interrupt0 timings
  *
  *
  * \param  regs        [IN]                Handle to access Ccdc related hardware
  * \param hLinesVD0    [IN]                h lines value
  *
  */
void LLC_setVDINT0Timing( Ptr regs, Uint hLinesVD0);

/**
  * \brief To set the FID signal to latch on  Video DHD Phase
  *
  *
  * \param  regs        [IN]                Handle to access Ccdc related hardware
  *
  */
void LLC_setFIDSignlLatchOnVDHDPhas( Ptr regs);

/**
  * \brief To set the FID signal to latch on  Video edge
  *
  *
  * \param  regs        [IN]                Handle to access Ccdc related hardware
  *
  */
void LLC_setFIDSignalLatchOnVDEdge( Ptr regs);


/**
  * \brief  To set the FID signal to no latch on  Video timings
  *
  *
  * \param  regs        [IN]                Handle to access Ccdc related hardware
  *
  */
void LLC_setFIDSignalNoLatch( Ptr regs);

/**
  * \brief  To set the FID signal to latch on  Video timings
  *
  *
  * \param  regs        [IN]                Handle to access Ccdc related hardware
  *
  */
void LLC_setFIDSignalLatchOnVDTiming( Ptr regs);

/**
  * \brief To set the Ccdc plane in REC656 interlaced disable
  *
  *
  * \param  regs        [IN]                Handle to access Ccdc related hardware
  *
  */
void LLC_setREC656InterfaceDisable( Ptr regs);

/**
  * \brief To set the error correction enable
  *
  *
  * \param  regs        [IN]                Handle to access Ccdc related hardware
  *
  */
void LLC_setErrorCorrectionEnable( Ptr regs);


/**
  * \brief To set the Ccdc plane in REC656 interlaced enable
  *
  *
  * \param  regs        [IN]                Handle to access Ccdc related hardware
  *
  */
void LLC_setREC656InterfaceEnable( Ptr regs);


/**
  * \brief To set the Ccdc plane in pack 16 bits per pixel
  *
  *
  * \param  regs        [IN]                Handle to access Ccdc related hardware
  *
  */
void LLC_setPack16BitsPerPixel( Ptr regs);

/**
  * \brief To set the Ccdc plane in pack 8 bits per pixel
  *
  *
  * \param  regs        [IN]                Handle to access Ccdc related hardware
  *
  */
void LLC_setPack8BitsPerPixel( Ptr regs);

/**
  * \brief To set the Ccdc plane data width to 16 bits.
  *
  *
  * \param  regs        [IN]                Handle to access Ccdc related hardware
  *
  */
void LLC_setCcdcDataWidth16Bits( Ptr regs);


/**
  * \brief To configure the field id direction output
  *
  *
  * \param  regs        [IN]                Handle to access Ccdc related hardware
  *
  */
void LLC_setFieldIdDirectionOutput( Ptr regs);


/**
  * \brief To configure the field id direction input
  *
  *
  * \param  regs        [IN]                Handle to access Ccdc related hardware
  *
  */
void LLC_setFieldIdDirectionInput( Ptr regs);

/**
  * \brief To configure the VDHD sync direction output
  *
  *
  * \param  regs        [IN]                Handle to access Ccdc related hardware
  *
  */
void LLC_setVDHDSyncDirectionOutput( Ptr regs);

/**
  * \brief To configure the VDHD sync direction input
  *
  *
  * \param  regs        [IN]                Handle to access Ccdc related hardware
  *
  */
void LLC_setVDHDSyncDirectionInput( Ptr regs);

/**
  * \brief This will configure the Ccdc cloour format to RAW Mode
  *
  *
  * \param  regs        [IN]                handle to access Ccdc related hardware
  *
  */
void LLC_setCcdcColorFormatCCDRaw( Ptr regs);

/**
  * \brief This will configure the HD and VD Signal width
  *
  *
  * \param  regs        [IN]                handle to access Ccdc related hardware
  * \param  hdw         [IN]                width of sync pulse hdw
  * \param  vdw         [IN]                width of sync pulse vdw
  */
void LLC_setCcdcHDVDSignalWidth( Ptr regs, Uint hdw, Uint vdw);
/**
  * \brief This will configure the pixel per line and the half
  *        lines per field or frame
  *
  * \param  regs        [IN]                handle to access Ccdc related hardware
  * \param  ppln        [IN]                pixel per line
  * \param  hlpfr       [IN]                half lines per field or frame
  */
void LLC_setCcdcPixLines( Ptr regs, Uint ppln, Uint hlpfr );

/**
  * \brief This will Enable the Black clamping
  * \param  regs        [IN]                Handle to access Ccdc related hardware
  *
  */
void LLC_Ccdc_ClampEnable(Ptr regs);

/**
  * \brief This will Disable the Black clamping
  * \param  regs        [IN]                Handle to access Ccdc related hardware
  *
  */
void LLC_Ccdc_ClampDisable(Ptr regs);


/**
  * \brief This will Set the Optical black clamping length of each line
  * \param  regs        [IN]            Handle to access Ccdc related hardware
  * \param pixsperline  [IN]            Pixels per Line
  *
  *
  */
void LLC_Ccdc_ClampSamplePixperLine(Ptr regs, Uint  pixsperline);


/**
  * \brief This will Set the Optical black clamping lines
  * \param  regs        [IN]                Handle to access Ccdc related hardware
  * \param pxlines      [IN]                number of Lines
  *
  *
  */
void LLC_Ccdc_ClampSampleLines(Ptr regs, Uint   pxlines);


/**
  * \brief This will Set the Optical black clamping start pixel
  * \param  regs        [IN]                Handle to access Ccdc related hardware
  * \param startpix     [IN]                Starting Pixel
  *
  *
  */
void LLC_Ccdc_ClampSampleStartPix(Ptr regs, Uint    startpix);


/**
  * \brief This will Set the Optical black clamping Gain
  * \param  regs        [IN]                Handle to access Ccdc related hardware
  * \param obgain       [IN]                Gain
  *
  */
void LLC_Ccdc_ClampSampleGain(Ptr regs, Uint obgain);

/**
  * \brief This will set the DC Clamp
  * \param  regs        [IN]                Handle to access Ccdc related hardware
  * \param dcsub        [IN]                DC level to subtract from CCD data
  *
  *
  */
void LLC_Ccdc_SetDCClamp(Ptr regs, Uint dcsub);

/**
  * \brief This will set the CCD Color Pattern
  * \param  regs        [IN]                Handle to access Ccdc related hardware
  * \param  colpattern  [IN]                color pattern
  *
  *
  */
void LLC_Ccdc_SetColorPattern(Ptr regs, Uint colpattern);

/**
  * \brief This will set the Blacl Level Compensation
  * \param  regs        [IN]                Handle to access Ccdc related hardware
  * \param  r_ye        [IN]                Black level compensation for R/Ye pixels
  * \param  gr_cy       [IN]                for Gr/Cy
  * \param  gb_g        [IN]                for Gb/G
  * \param  b_mg        [IN]                for B/Mg
  *
  *
  */
void LLC_Ccdc_BlackCompensation(Ptr regs, Uint r_ye, Uint gr_cy, Uint gb_g, Uint b_mg);

/**
  * \brief This Enable the ALaw compaction to 8 bits
  * \param  regs        [IN]                Handle to access Ccdc related hardware
  *
  *
  */

void LLC_Ccdc_ALawEnable(Ptr regs);

/**
  * \brief This Disable the ALaw compaction to 8 bits
  * \param  regs        [IN]                Handle to access Ccdc related hardware
  *
  *
  */
void LLC_Ccdc_ALawDisable(Ptr regs);

/**
  * \brief This will set the gamma input of the ALaw Configuration
  * \param  regs        [IN]                Handle to access Ccdc related hardware
  * \param  gwdi        [IN]                one of the maks for choosng the gamma bits
  *
  *
  */
void LLC_Ccdc_ALaw_SetGammaInput(Ptr regs, Uint gwdi);

/**
  * \brief To set the data polarity to Normal
  * \param  regs        [IN]                Handle to access Ccdc related hardware
  *
  */
void LLC_ccdcsetDataPolNormal( Ptr regs);

/**
  * \brief To set the data polarity to OnesComplement
  * \param  regs        [IN]                Handle to access Ccdc related hardware
  *
  */
void LLC_ccdcsetDataPolOnesComp( Ptr regs);

/**
  * \brief This will set the pixel bit width to 16 bit
  * \param  regs        [IN]                Handle to access Ccdc related hardware
  *
  */
void LLC_setCcdcPixelBitWidth16Bit( Ptr regs);
/**
  * \brief This will set the pixel bit width to 15 bit
  * \param  regs        [IN]                Handle to access Ccdc related hardware
  *
  */
void LLC_setCcdcPixelBitWidth15Bit( Ptr regs);
/**
  * \brief This will set the pixel bit width to 14 bit
  * \param  regs        [IN]                Handle to access Ccdc related hardware
  *
  */
void LLC_setCcdcPixelBitWidth14Bit( Ptr regs);
/**
  * \brief This will set the pixel bit width to 13 bit
  * \param  regs        [IN]                Handle to access Ccdc related hardware
  *
  */
void LLC_setCcdcPixelBitWidth13Bit( Ptr regs);
/**
  * \brief This will set the pixel bit width to 12 bit
  * \param  regs        [IN]                Handle to access Ccdc related hardware
  *
  */
void LLC_setCcdcPixelBitWidth12Bit( Ptr regs);
/**
  * \brief This will set the pixel bit width to 11 bit
  * \param  regs        [IN]                Handle to access Ccdc related hardware
  *
  */
void LLC_setCcdcPixelBitWidth11Bit( Ptr regs);
/**
  * \brief This will set the pixel bit width to 10 bit
  * \param  regs        [IN]                Handle to access Ccdc related hardware
  *
  */
void LLC_setCcdcPixelBitWidth10Bit( Ptr regs);
/**
  * \brief This will set the pixel bit width to 8 bit
  * \param  regs        [IN]                Handle to access Ccdc related hardware
  *
  */
void LLC_setCcdcPixelBitWidth8Bit( Ptr regs);

/**
  * \brief This will Reset the Fault Pixel Correction
  * \param  regs        [IN]                Handle to access Ccdc related hardware
  *
  *
  */
void LLC_Ccdc_Fpc_Reset(Ptr regs);

/**
  * \brief This will Disable the Fault Pixel Correction
  * \param  regs        [IN]                Handle to access Ccdc related hardware
  *
  *
  */
void LLC_Ccdc_Fpc_Disable(Ptr regs);
/**
  * \brief This will enable the Fault Pixel Correction
  * \param  regs        [IN]                Handle to access Ccdc related hardware
  *
  *
  */
void LLC_Ccdc_Fpc_Enable(Ptr regs);

/**
  * \brief This will set the address of the Fault Pixel Correction Table
  * \param  regs        [IN]                Handle to access Ccdc related hardware
  * \param  fpcaddress  [IN]                address of the FPC Table
  *
  *
  */
void LLC_Ccdc_Fpc_SetAddr(Ptr regs, Uint fpcaddress);

/**
  * \brief This will set the number of the fault pixels to be corrected
  * \param  regs        [IN]                Handle to access Ccdc related hardware
  * \param  fpcnum      [IN]                Number of fault pixel correction pixels
  *
  *
  */
void LLC_Ccdc_Fpc_Setnum(Ptr regs, Uint fpcnum);
/**
 * \brief This will Enable the Video Port Interface
 *
 * \param   regs        [IN]              Handle to access Ccdc hardware
 *
 */
void LLC_setCcdcVideoPortEnable(Ptr regs);
/**
 * \brief This will Disable the Video Port Interface
 *
 * \param   regs        [IN]                Handle to access Ccdc hardware
 *
 */
void LLC_setCcdcVideoPortDisable(Ptr regs);
/**
 * \brief Number of Input bits to be retained.This function will
 *        select 15-06 bits
 *
 * \param   regs        [IN]                Handle to access Ccdc hardware
 *
 */
void LLC_setCcdcDataFormatterBitSelect_15_06(Ptr regs);
/**
 * \brief Number of Input bits to be retained.This function will
 *        select 14-05 bits
 *
 * \param   regs        [IN]                Handle to access Ccdc hardware
 *
 */
void LLC_setCcdcDataFormatterBitSelect_14_05(Ptr regs);
/**
 * \brief Number of Input bits to be retained.This function will
 *        select 13_04 bits
 *
 * \param   regs        [IN]                Handle to access Ccdc hardware
 *
 */
void LLC_setCcdcDataFormatterBitSelect_13_04(Ptr regs);
/**
 * \brief Number of Input bits to be retained.This function will
 *        select 12_03 bits
 *
 * \param   regs        [IN]                Handle to access Ccdc hardware
 *
 */

void LLC_setCcdcDataFormatterBitSelect_12_03(Ptr regs);
/**
 * \brief Number of Input bits to be retained.This function will
 *        select 11_02 bits
 *
 * \param   regs        [IN]                Handle to access Ccdc hardware
 *
 */

void LLC_setCcdcDataFormatterBitSelect_11_02(Ptr regs);
/**
 * \brief Number of Input bits to be retained.This function will
 *        select 10_01 bits
 *
 * \param   regs        [IN]                Handle to access Ccdc hardware
 *
 */

void LLC_setCcdcDataFormatterBitSelect_10_01(Ptr regs);
/**
 * \brief Number of Input bits to be retained.This function will
 *        select 9_00 bits
 *
 * \param   regs        [IN]                Handle to access Ccdc hardware
 *
 */
void LLC_setCcdcDataFormatterBitSelect_9_00(Ptr regs);
/**
 * \brief Set the Number of Pixels in Horizontal Direction
 *
 * \param   regs        [IN]     Handle to access Ccdc hardware
 * \param   ccdcHPix   [IN]      Number of Pixel in Horizontal Direction
 *
 */
void LLC_setCcdcDataFormatterHorzInfo(Ptr regs, Uint ccdcHPix);
/**
 * \brief Set Start Pixel Horizontal from start of HD
 *
 * \param   regs          [IN]   Handle to access Ccdc hardware
 * \param   ccdcLMargin   [IN]   Start Pixel Horizontal
 *
 */
void LLC_setCcdcDataFormatterHorzStartPixel(Ptr regs, Uint ccdcLMargin);
/**
 * \brief Set Start Line from start of VD
 *
 * \param   regs          [IN]   Handle to access Ccdc hardware
 * \param   ccdcTMargin   [IN]   Start Line from VD
 *
 */
void LLC_setCcdcDataFormatterVertStartLine(Ptr regs, Uint ccdcTMargin);
/**
 * \brief Set Number of Lines in Vertical Direction
 *
 * \param   regs          [IN]   Handle to access Ccdc hardware
 * \param   ccdcLMargin   [IN]   Number of Lines
 *
 */
void LLC_setCcdcDataFormatterVertInfo(Ptr regs, Uint ccdcVLines);
/**
 * \brief Set Horizontal Start Pixels in each output line out of Video Port
 *
 * \param   regs          [IN]   Handle to access Ccdc hardware
 * \param   ccdcLMargin   [IN]   Horizontal Start Pixel
 *
 */
void LLC_setCcdcVidPortHorzStartPixel(Ptr regs, Uint ccdcLMargin);
/**
 * \brief Set Number of Horizontal Pixels out of Video Port
 *
 * \param   regs          [IN]   Handle to access Ccdc hardware
 * \param   ccdcHPixel    [IN]   Number of Pixel in Horizontal Direction
 *
 */
void LLC_setCcdcVidPortHorzInfo(Ptr regs, Uint ccdcHPixel);
/**
 * \brief Set Number of Vertical Lines out of Video Port
 *
 * \param   regs          [IN]   Handle to access Ccdc hardware
 * \param   ccdcVLines    [IN]    Number of Lines
 *
 */
void LLC_setCcdcVidPortVertInfo(Ptr regs, Uint ccdcVLines);

/**
 * \brief To Get the CCDC Engine Enable/Disable
 *
 * \param   regs          [IN]   Handle to access Ccdc hardware
 *
 */
Bool LLC_getCcdcEngineStat(Ptr regs);
/**
  * \brief To set the line offset value of even line even field to 0_1line
  *
  *
  * \param  regs        [IN]     Handle to access Ccdc related hardware
  *
  */
void LLC_setLnOfstEvnLnEvnFld_1Line( Ptr regs);
/**
  * \brief To set the line offset value of even line odd field to 0_1line
  *
  *
  * \param  regs        [IN]     Handle to access Ccdc related hardware
  *
  */
void LLC_setLnOfstEvnLnOddFld_1Line( Ptr regs);
/**
  * \brief To set the line offset value of odd line even field to 0_1line
  *
  *
  * \param  regs        [IN]     Handle to access Ccdc related hardware
  *
  */
void LLC_setLnOfstOddLnEvnFld_1Line( Ptr regs);
/**
  * \brief To set the line offset value of odd line odd field to 0_1line
  *
  *
  * \param  regs        [IN]     Handle to access Ccdc related hardware
  *
  */
void LLC_setLnOfstOddLnOddFld_1Line( Ptr regs);
/**
 * \brief To Get the CCDC Engine Enable/Disable
 *
 * \param   regs          [IN]   Handle to access Ccdc hardware
 * \param   numlines      [IN]   Number of lines the VSYNC configured
 */
void LLC_configVDINT(Ptr regs, Uint numlines);

Uint32 LLC_getVDINT(Ptr regs);

#ifdef __cplusplus
}
#endif

#endif /* _LLC_VPFECCDC_H */
