/******************************************************************************
**+-------------------------------------------------------------------------+**
**|                            ****                                         |**
**|                            ****                                         |**
**|                            ******o***                                   |**
**|                      ********_///_****                                  |**
**|                      ***** /_//_/ ****                                  |**
**|                       ** ** (__/ ****                                   |**
**|                           *********                                     |**
**|                            ****                                         |**
**|                            ***                                          |**
**|                                                                         |**
**|         Copyright (c) 2006-2010 Texas Instruments Incorporated          |**
**|                        ALL RIGHTS RESERVED                              |**
**|                                                                         |**
**| Permission is hereby granted to licensees of Texas Instruments          |**
**| Incorporated (TI) products to use this computer program for the sole    |**
**| purpose of implementing a licensee product based on TI products.        |**
**| No other rights to reproduce, use, or disseminate this computer         |**
**| program, whether in part or in whole, are granted.                      |**
**|                                                                         |**
**| TI makes no representation or warranties with respect to the            |**
**| performance of this computer program, and specifically disclaims        |**
**| any responsibility for any damages, special or consequential,           |**
**| connected with the use of this program.                                 |**
**|                                                                         |**
**+-------------------------------------------------------------------------+**
******************************************************************************/
/**
 *  \file   psp_vpfeApi.h
 *
 * \brief   File contains defination of API used by DDA layer
 *
 *  This file contains APIs defination of APIs that are wrapper APIs for DDC
 *  layer. These APIs will be called by DDA layer.
 *
 *  (C) Copyright 2010, Texas Instruments, Inc
 *
 *  \note       Set tabstop to 4 (:se ts=4) while viewing this file in an
 *              editor
 *
 *  \author     Maulik Desai
 *
 *  \version    0.1     Created
 */

#ifndef _PSP_VPFE_API_
#define _PSP_VPFE_API_

#ifdef __cplusplus
extern "C" {
#endif

/**
 *  \brief      This function is the first to be called and is used for driver
 *              initialization.
 *
 *              It performs register map overlaying and software book-keeping.
 *              It register the interrupt Handler.
 *
 *  \param      instanceId              [IN]        VPSS instance Id.
 *
 *  \returns    Returns                             SUCCESS/FAILURE status.
 */
PSP_Result      PSP_VPFECreate(Uint32  instanceId);

/**
 *  \brief      This function is called last and is used for driver deletion.
 *              This function does the deletion of the entire VPFE hardware
 *
 *  \param      instanceId              [IN]        VPSS Instance number.
 *
 *  \returns    Returns                             SUCCESS/FAILURE status.
 */
PSP_Result      PSP_VPFEDelete(Uint32  instanceId);
/**
 *  \brief      This function creates  the channel handle for individual VPFE
 *              (CCDCand other)modules.
 *
 *  \param      instanceId              [IN]        VPSS instance id.
 *
 *  \param      chanConfigParams        [IN]        Channel Configuration
 *                                                  parameters
 *
 *  \returns    Returns                             Channel handle of VPFE
 *                                                  or NULL
 */
PSP_Handle      PSP_VPFEOpen(Uint32 instanceId,PSP_VPFEChannelParams * chanParams);
/**
 *  \brief      This function close individual Channel handle for individual VPFE
 *              Modules
 *
 *  \param      handle                  [IN]        VPFE individual channel Handle
 *                                                  to be closed.
 *
 *  \Returns    Returns                             SUCCESS/FAILURE status.
 */
PSP_Result      PSP_VPFEClose(PSP_Handle  handle);

/**
 *  \brief      This function makes runtime changes for the individual VPFE
 *              (CCDC and other)modules
 *
 *  \param      handle                  [IN]        Channel Handle(CCDC and
 *                                                  other Front End modules)for
 *                                                  which the control operation
 *                                                  will be performed.
 *
 *  \param      cmd                     [IN]        IOCTL command
 *
 *  \param      cmdArg                  [IN]        Command Arguments to be passed.
 *                                                  ConfigParams to be passed as
 *                                                  cmdArg
 *
 *  \param      params                  [IN]        Reserved for Future Use.
 *
 *  \Returns    Returns                             SUCCESS/FAILURE status.
 */

PSP_Result      PSP_VPFEIoctl(PSP_Handle             handle,
                              Uint32                 cmd,
                              Ptr                    cmdArg,
                              Ptr                    params);

/**
 *  \brief This function is called to Queue/Dequeue Frame buffer for individual
 *         VPFE (CCDC and other) VPFE modules.
 *
 *
 *
 *  \param  chanp                       [IN]        Channel Handle of the VPFE(CCDC
 *                                                  and other Front End Modules)for
 *                                                  which the control operation will
 *                                                  be performed
 *
 *  \param  cmd                         [IN]        Submit Command(QUEUE/DE-QUEUE)
 *
 *  \param  cmdArg                      [IN]        Command Arguments to be passed.
 *                                                  Surface Params to be passed as          *                                                   cmdArg
 *
 *  \Returns    Returns                             SUCCESS/FAILURE status.
 */
PSP_Result      PSP_VPFESubmitRequest(PSP_Handle                handle,
                                      Uint32        cmd,
                                      Ptr                       cmdArg);
#ifdef __cplusplus
}
#endif

#endif /*_PSP_VPFE_API_*/
