/*******************************************************************************
**+--------------------------------------------------------------------------+**
**|                            ****                                          |**
**|                            ****                                          |**
**|                            ******o***                                    |**
**|                      ********_///_****                                   |**
**|                      ***** /_//_/ ****                                   |**
**|                       ** ** (__/ ****                                    |**
**|                           *********                                      |**
**|                            ****                                          |**
**|                            ***                                           |**
**|                                                                          |**
**|         Copyright (c) 1998-2006 Texas Instruments Incorporated           |**
**|                        ALL RIGHTS RESERVED                               |**
**|                                                                          |**
**| Permission is hereby granted to licensees of Texas Instruments           |**
**| Incorporated (TI) products to use this computer program for the sole     |**
**| purpose of implementing a licensee product based on TI products.         |**
**| No other rights to reproduce, use, or disseminate this computer          |**
**| program, whether in part or in whole, are granted.                       |**
**|                                                                          |**
**| TI makes no representation or warranties with respect to the             |**
**| performance of this computer program, and specifically disclaims         |**
**| any responsibility for any damages, special or consequential,            |**
**| connected with the use of this program.                                  |**
**|                                                                          |**
**+--------------------------------------------------------------------------+**
*******************************************************************************/

/**
 *  \file   edc.h
 *
 *  This file contains common defines and structures for external devices
 */

#ifndef _EDC_H
#define _EDC_H


/*
 * ========= INCLUDE FILES ==========
 */
#include <std.h>

#ifdef __cplusplus
extern "C" {
#endif

/*
 * ========== Defines ==============
 */

/*
 * EDC control commands
 */
/** \brief EDC configure command */
#define EDC_CONFIG                      (0x00000001)
/** \brief EDC reset command */
#define EDC_RESET                       (0x00000002)
/** \brief Command to start EDC */
#define EDC_START                       (0x00000003)
/** \brief Command to stop EDC */
#define EDC_STOP                        (0x00000004)
/** \brief Command to get EDC configuration */
#define EDC_GET_CONFIG                  (0x00000005)
/** \brief Command to get EDC status */
#define EDC_GET_STATUS                  (0x00000006)

/** \brief base of user defined commands */
#define EDC_USER                        (0x10000000)


/*
 * EDC return codes
 */
/** \brief EDC success return value */
#define EDC_SUCCESS                     (0)
/** \brief EDC failure condition return value */
#define EDC_FAILED                      (-1)


/** \brief EDC handle type casting */
typedef void*  EDC_Handle;


/**
 *  \brief EDC Function table Structure
 *  This structure contains function pointers of external devices
 */
typedef struct EDC_Fxns
{
    EDC_Handle  (*open)(String name, Arg optArg);
    /**< edcOpen()      required, open the device */

    Int32 (*close)(Ptr devHandle);
    /**< edcClose()      required, close the device */

    Int32 (*ctrl)(Ptr devHandle, Uns cmd, Arg arg);
    /**< edcCtrl()       required, control/query device */
} EDC_Fxns;


#ifdef __cplusplus
}
#endif

#endif /* _EDC_H */

/******************************************************************************/
/* End of file                                                                */
/******************************************************************************/
