/*******************************************************************************
**+--------------------------------------------------------------------------+**
**|                            ****                                          |**
**|                            ****                                          |**
**|                            ******o***                                    |**
**|                      ********_///_****                                   |**
**|                      ***** /_//_/ ****                                   |**
**|                       ** ** (__/ ****                                    |**
**|                           *********                                      |**
**|                            ****                                          |**
**|                            ***                                           |**
**|                                                                          |**
**|         Copyright (c) 1998-2007 Texas Instruments Incorporated           |**
**|                        ALL RIGHTS RESERVED                               |**
**|                                                                          |**
**| Permission is hereby granted to licensees of Texas Instruments           |**
**| Incorporated (TI) products to use this computer program for the sole     |**
**| purpose of implementing a licensee product based on TI products.         |**
**| No other rights to reproduce, use, or disseminate this computer          |**
**| program, whether in part or in whole, are granted.                       |**
**|                                                                          |**
**| TI makes no representation or warranties with respect to the             |**
**| performance of this computer program, and specifically disclaims         |**
**| any responsibility for any damages, special or consequential,            |**
**| connected with the use of this program.                                  |**
**|                                                                          |**
**+--------------------------------------------------------------------------+**
*******************************************************************************/

/**
 *  \file  _vportrmk.h file
 *
 *  This header file defines generic macros for field manipulation
 */

#ifndef _VPORTRMK_H
#define _VPORTRMK_H

#include <ti/sdo/pspdrivers/soc/dm648/dsp/cslr_vport.h>

#ifdef __cplusplus
extern "C" {
#endif

/** \brief macro to generate proper shift value for VPORT registers */
#define _PER_FSHIFT(PER,REG,FIELD) \
    CSL_##PER##_##REG##_##FIELD##_SHIFT

/** \brief macro to generate proper mask value for VPORT registers */
#define _PER_FMASK(PER,REG,FIELD) \
    CSL_##PER##_##REG##_##FIELD##_MASK

/** \brief macro to generate proper field value for VPORT registers */
#define _PER_FMK(PER,REG,FIELD,x) (\
    (((Uint32)(x))<<_PER_FSHIFT(##PER,##REG,##FIELD))\
    &_PER_FMASK(##PER,##REG,##FIELD)\
)

/** \brief macro to generate threshold value for VCTHRLD register */
#define VP_VCTHRLD_RMK(vcthrld2,vcthrld1) (Uint32)(\
     _PER_FMK(VPORT,VC_THRLD,VCTHRLD2,vcthrld2)\
    |_PER_FMK(VPORT,VC_THRLD,VCTHRLD1,vcthrld1)\
)

/** \brief macro to generate stop value for VCSTOP1 register as per given
 *   fields
 */
#define VP_VCSTOP1_RMK(vcystop,vcxstop) (Uint32)(\
     _PER_FMK(VPORT,VC_STOP1,VC_YSTOP,vcystop)\
    |_PER_FMK(VPORT,VC_STOP1,VC_XSTOP,vcxstop)\
)

/** \brief macro to generate register value for VCCTL register as per given
 *   fields
 */
#define VP_VCCTL_RMK(rstch,blkcap,rdfe,finv,exc,fldd,vrst,\
    hrst,vcen,pk10b,lfde,sfde,resmpl,scale,con,frame,cf2,cf1,cmode) (Uint32)(\
     _PER_FMK(VPORT,VC_CTL,RSTCH,rstch)\
    |_PER_FMK(VPORT,VC_CTL,BLKCAP,blkcap)\
    |_PER_FMK(VPORT,VC_CTL,RDFE,rdfe)\
    |_PER_FMK(VPORT,VC_CTL,FINV,finv)\
    |_PER_FMK(VPORT,VC_CTL,EXC,exc)\
    |_PER_FMK(VPORT,VC_CTL,FLDD,fldd)\
    |_PER_FMK(VPORT,VC_CTL,VRST,vrst)\
    |_PER_FMK(VPORT,VC_CTL,HRST,hrst)\
    |_PER_FMK(VPORT,VC_CTL,VCEN,vcen)\
    |_PER_FMK(VPORT,VC_CTL,10BPK1,pk10b)\
    |_PER_FMK(VPORT,VC_CTL,LFDE,lfde)\
    |_PER_FMK(VPORT,VC_CTL,SFDE,sfde)\
    |_PER_FMK(VPORT,VC_CTL,RESMPL,resmpl)\
    |_PER_FMK(VPORT,VC_CTL,SCALE,scale)\
    |_PER_FMK(VPORT,VC_CTL,CON,con)\
    |_PER_FMK(VPORT,VC_CTL,FRAME,frame)\
    |_PER_FMK(VPORT,VC_CTL,CF2,cf2)\
    |_PER_FMK(VPORT,VC_CTL,CF1,cf1)\
    |_PER_FMK(VPORT,VC_CTL,CMODE,cmode)\
)

/**
 *  \brief macro to generate register value for VCVINT register as per given
 *  fields
 */
#define VP_VCVINT_RMK(vif2,fscl2,vint2,vif1,vint1) (Uint32)(\
     _PER_FMK(VPORT,VC_VINT,VIF2,vif2)\
    |_PER_FMK(VPORT,VC_VINT,FSCL2,fscl2)\
    |_PER_FMK(VPORT,VC_VINT,VINT2,vint2)\
    |_PER_FMK(VPORT,VC_VINT,VIF1,vif1)\
    |_PER_FMK(VPORT,VC_VINT,VINT1,vint1)\
)

/**
 *  \brief macro to generate register value for VCEVTCT register as per given
 *  fields
 */
#define VP_VCEVTCT_RMK(capevtct2,capevtct1) (Uint32)(\
     _PER_FMK(VPORT,VC_EVTCT,CAP_EVTCT2,capevtct2)\
    |_PER_FMK(VPORT,VC_EVTCT,CAP_EVTCT1,capevtct1)\
)

/**
 *  \brief macro to generate register value for VCSTRT1 register as per given
 *  fields
 */
#define VP_VCSTRT1_RMK(vcystart,sse,vcxstart) (Uint32)(\
     _PER_FMK(VPORT,VC_STRT1,VC_YSTART,vcystart)\
    |_PER_FMK(VPORT,VC_STRT1,SSE,sse)\
    |_PER_FMK(VPORT,VC_STRT1,VC_XSTART,vcxstart)\
)

/**
 *  \brief macro to generate register value for VPCTL register as per given
 *  fields
 */
#define VP_VPCTL_RMK(vprst,vphlt,vclk2p,vct3p,vct2p,vct1p,\
    tsi,disp,dchnl) (Uint32)(\
     _PER_FMK(VPORT,VP_CTL,VPRST,vprst)\
    |_PER_FMK(VPORT,VP_CTL,VPHLT,vphlt)\
    |_PER_FMK(VPORT,VP_CTL,VCLK2P,vclk2p)\
    |_PER_FMK(VPORT,VP_CTL,VCT3P,vct3p)\
    |_PER_FMK(VPORT,VP_CTL,VCT2P,vct2p)\
    |_PER_FMK(VPORT,VP_CTL,VCT1P,vct1p)\
    |_PER_FMK(VPORT,VP_CTL,TCI,tsi)\
    |_PER_FMK(VPORT,VP_CTL,DISP,disp)\
    |_PER_FMK(VPORT,VP_CTL,2CHNL,dchnl)\
)

/**
 *  \brief macro to generate register value for VDVBLKS2 register as per given
 *  fields
 */
#define VP_VDVBLKS2_RMK(vblnkystart2,vblnkxstart2) (Uint32)(\
     _PER_FMK(VPORT,VD_VBLKS2,VBLNK_YSTART2,vblnkystart2)\
    |_PER_FMK(VPORT,VD_VBLKS2,VBLNK_XSTART2,vblnkxstart2)\
)

/**
 *  \brief macro to generate register value for VDFRMSZ register as per given
 *  fields
 */
#define VP_VDFRMSZ_RMK(frmheight,frmwidth) (Uint32)(\
     _PER_FMK(VPORT,VD_FRMSZ,FRM_HEIGHT,frmheight)\
    |_PER_FMK(VPORT,VD_FRMSZ,FRM_WIDTH,frmwidth)\
)

/**
 *  \brief macro to generate register value for VDIMGSZ1 register as per given
 *  fields
 */
#define VP_VDIMGSZ1_RMK(imgvsize1,imghsize1) (Uint32)(\
     _PER_FMK(VPORT,VD_IMGSZ1,IMG_VSIZE1,imgvsize1)\
    |_PER_FMK(VPORT,VD_IMGSZ1,IMG_HSIZE1,imghsize1)\
)

/**
 *  \brief macro to generate register value for VDHSYNC register as per given
 *  fields
 */
#define VP_VDHSYNC_RMK(hsyncstop,hsyncstart) (Uint32)(\
     _PER_FMK(VPORT,VD_HSYNC,HSYNC_STOP,hsyncstop)\
    |_PER_FMK(VPORT,VD_HSYNC,HSYNC_START,hsyncstart)\
)

/**
 *  \brief macro to generate register value for VDVSYNE1 register as per given
 *  fields
 */
#define VP_VDVSYNE1_RMK(vsyncystop1,vsyncxstop1) (Uint32)(\
     _PER_FMK(VPORT,VD_VSYNE1,VSYNC_YSTOP1,vsyncystop1)\
    |_PER_FMK(VPORT,VD_VSYNE1,VSYNC_XSTOP1,vsyncxstop1)\
)

/**
 *  \brief macro to generate register value for VDCLIP register as per given
 *  fields
 */
#define VP_VDCLIP_RMK(clipchigh,clipclow,clipyhigh,clipylow) (Uint32)(\
     _PER_FMK(VPORT,VD_CLIP,CLIPC_HI,clipchigh)\
    |_PER_FMK(VPORT,VD_CLIP,CLIPC_LO,clipclow)\
    |_PER_FMK(VPORT,VD_CLIP,CLIPY_HI,clipyhigh)\
    |_PER_FMK(VPORT,VD_CLIP,CLIPY_LO,clipylow)\
)

/**
 *  \brief macro to generate register value for VDIMGSZ2 register as per given
 *  fields
 */
#define VP_VDIMGSZ2_RMK(imgvsize2,imghsize2) (Uint32)(\
     _PER_FMK(VPORT,VD_IMGSZ2,IMG_VSIZE2,imgvsize2)\
    |_PER_FMK(VPORT,VD_IMGSZ2,IMG_HSIZE2,imghsize2)\
)

/**
 *  \brief macro to generate register value for VDVSYNE2 register as per given
 *  fields
 */
#define VP_VDVSYNE2_RMK(vsyncystop2,vsyncxstop2) (Uint32)(\
     _PER_FMK(VPORT,VD_VSYNE2,VSYNC_YSTOP2,vsyncystop2)\
    |_PER_FMK(VPORT,VD_VSYNE2,VSYNC_XSTOP2,vsyncxstop2)\
)

/**
 *  \brief macro to generate register value for VDFBIT register as per given
 *  fields
 */
#define VP_VDFBIT_RMK(fbitset,fbitclr) (Uint32)(\
     _PER_FMK(VPORT,VD_FBIT,FBIT_SET,fbitset)\
    |_PER_FMK(VPORT,VD_FBIT,FBIT_CLR,fbitclr)\
)

/**
 *  \brief macro to generate register value for VDVSYNS1 register as per given
 *  fields
 */
#define VP_VDVSYNS1_RMK(vsyncystart1,vsyncxstart1) (Uint32)(\
     _PER_FMK(VPORT,VD_VSYNS1,VSYNC_YSTART1,vsyncystart1)\
    |_PER_FMK(VPORT,VD_VSYNS1,VSYNC_XSTART1,vsyncxstart1)\
)

/**
 *  \brief macro to generate register value for VDVSYNS2 register as per given
 *  fields
 */
#define VP_VDVSYNS2_RMK(vsyncystart2,vsyncxstart2) (Uint32)(\
     _PER_FMK(VPORT,VD_VSYNS2,VSYNC_YSTART2,vsyncystart2)\
    |_PER_FMK(VPORT,VD_VSYNS2,VSYNC_XSTART2,vsyncxstart2)\
)

/**
 *  \brief macro to generate register value for VDDISPEVT register as per given
 *  fields
 */
#define VP_VDDISPEVT_RMK(dispevt2,dispevt1) (Uint32)(\
     _PER_FMK(VPORT,VD_DISPEVT,DISPEVT2,dispevt2)\
    |_PER_FMK(VPORT,VD_DISPEVT,DISPEVT1,dispevt1)\
)

/**
 *  \brief macro to generate register value for VDHBLNK register as per given
 *  fields
 */
#define VP_VDHBLNK_RMK(hblnkstop,hbdla,hblnkstart) (Uint32)(\
     _PER_FMK(VPORT,VD_HBLNK,HBLNK_STOP,hblnkstop)\
    |_PER_FMK(VPORT,VD_HBLNK,HBDLA,hbdla)\
    |_PER_FMK(VPORT,VD_HBLNK,HBLNK_START,hblnkstart)\
)

/**
 *  \brief macro to generate register value for VDVBIT1 register as per given
 *  fields
 */
#define VP_VDVBIT1_RMK(vbitclr1,vbitset1) (Uint32)(\
  _PER_FMK(VPORT,VD_VBIT1,VBIT_CLR1,vbitclr1)\
    |_PER_FMK(VPORT,VD_VBIT1,VBIT_SET1,vbitset1)\
)

/**
 *  \brief macro to generate register value for VDCTL register as per given
 *  fields
 */
#define VP_VDCTL_RMK(rstch,blkdis,pvpsyn,fxs,vxs,hxs,vctl3s,vctl2s,vctl1s,\
    vden,dpk,rgbx,rsync,dven,resmpl,scale,con,frame,df2,df1,dmode) (Uint32)(\
     _PER_FMK(VPORT,VD_CTL,RSTCH,rstch)\
    |_PER_FMK(VPORT,VD_CTL,BLKDIS,blkdis)\
    |_PER_FMK(VPORT,VD_CTL,PVPSYN,pvpsyn)\
    |_PER_FMK(VPORT,VD_CTL,FXS,fxs)\
    |_PER_FMK(VPORT,VD_CTL,VXS,vxs)\
    |_PER_FMK(VPORT,VD_CTL,HXS,hxs)\
    |_PER_FMK(VPORT,VD_CTL,VCTL3S,vctl3s)\
    |_PER_FMK(VPORT,VD_CTL,VCTL2S,vctl2s)\
    |_PER_FMK(VPORT,VD_CTL,VCTL1S,vctl1s)\
    |_PER_FMK(VPORT,VD_CTL,VDEN,vden)\
    |_PER_FMK(VPORT,VD_CTL,DPK,dpk)\
    |_PER_FMK(VPORT,VD_CTL,RGBX,rgbx)\
    |_PER_FMK(VPORT,VD_CTL,RSYNC,rsync)\
    |_PER_FMK(VPORT,VD_CTL,DVEN,dven)\
    |_PER_FMK(VPORT,VD_CTL,RESMPL,resmpl)\
    |_PER_FMK(VPORT,VD_CTL,SCALE,scale)\
    |_PER_FMK(VPORT,VD_CTL,CON,con)\
    |_PER_FMK(VPORT,VD_CTL,FRAME,frame)\
    |_PER_FMK(VPORT,VD_CTL,DF2,df2)\
    |_PER_FMK(VPORT,VD_CTL,DF1,df1)\
    |_PER_FMK(VPORT,VD_CTL,DMODE,dmode)\
)

/**
 *  \brief macro to generate register value for VDIMGOFF1 register as per given
 *  fields
 */
#define VP_VDIMGOFF1_RMK(nv,imgvoff1,nh,imghoff1) (Uint32)(\
     _PER_FMK(VPORT,VD_IMGOFF1,NV,nv)\
    |_PER_FMK(VPORT,VD_IMGOFF1,IMG_VOFF1,imgvoff1)\
    |_PER_FMK(VPORT,VD_IMGOFF1,NH,nh)\
    |_PER_FMK(VPORT,VD_IMGOFF1,IMG_HOFF1,imghoff1)\
)

/**
 *  \brief macro to generate register value for VDIMGOFF2 register as per given
 *  fields
 */
#define VP_VDIMGOFF2_RMK(nv,imgvoff2,nh,imghoff2) (Uint32)(\
     _PER_FMK(VPORT,VD_IMGOFF2,NV,nv)\
    |_PER_FMK(VPORT,VD_IMGOFF2,IMG_VOFF2,imgvoff2)\
    |_PER_FMK(VPORT,VD_IMGOFF2,NH,nh)\
    |_PER_FMK(VPORT,VD_IMGOFF2,IMG_HOFF2,imghoff2)\
)

/**
 *  \brief macro to generate register value for VDFLDT1 register as per given
 *  fields
 */
#define VP_VDFLDT1_RMK(fld1ystart,fld1xstart) (Uint32)(\
     _PER_FMK(VPORT,VD_FLDT1,FLD1_YSTART,fld1ystart)\
    |_PER_FMK(VPORT,VD_FLDT1,FLD1_XSTART,fld1xstart)\
)

/**
 *  \brief macro to generate threshold value for VDTHRLD register as per given
 *  fields
 */
#define VP_VDTHRLD_RMK(vdthrld2,incpix,vdthrld1) (Uint32)(\
     _PER_FMK(VPORT,VD_THRLD,VDTHRLD2,vdthrld2)\
    |_PER_FMK(VPORT,VD_THRLD,INCPIX,incpix)\
    |_PER_FMK(VPORT,VD_THRLD,VDTHRLD1,vdthrld1)\
)

/**
 *  \brief macro to generate register value for VDFLDT2 register as per given
 *  fields
 */
#define VP_VDFLDT2_RMK(fld2ystart,fld2xstart) (Uint32)(\
     _PER_FMK(VPORT,VD_FLDT2,FLD2_YSTART,fld2ystart)\
    |_PER_FMK(VPORT,VD_FLDT2,FLD2_XSTART,fld2xstart)\
)

/**
 *  \brief macro to generate register value for VDVBLKE1 register as per given
 *  fields
 */
#define VP_VDVBLKE1_RMK(vblnkystop1,vblnkxstop1) (Uint32)(\
     _PER_FMK(VPORT,VD_VBLKE1,VBLNK_YSTOP1,vblnkystop1)\
    |_PER_FMK(VPORT,VD_VBLKE1,VBLNK_XSTOP1,vblnkxstop1)\
)

/**
 *  \brief macro to generate register value for VDVBLKE2 register as per given
 *  fields
 */
#define VP_VDVBLKE2_RMK(vblnkystop2,vblnkxstop2) (Uint32)(\
     _PER_FMK(VPORT,VD_VBLKE2,VBLNK_YSTOP2,vblnkystop2)\
    |_PER_FMK(VPORT,VD_VBLKE2,VBLNK_XSTOP2,vblnkxstop2)\
)

/**
 *  \brief macro to generate register value for VPCTL register as per given
 *  fields
 */
#define VP_VPCTL_RMK(vprst,vphlt,vclk2p,vct3p,vct2p,vct1p,\
    tsi,disp,dchnl) (Uint32)(\
     _PER_FMK(VPORT,VP_CTL,VPRST,vprst)\
    |_PER_FMK(VPORT,VP_CTL,VPHLT,vphlt)\
    |_PER_FMK(VPORT,VP_CTL,VCLK2P,vclk2p)\
    |_PER_FMK(VPORT,VP_CTL,VCT3P,vct3p)\
    |_PER_FMK(VPORT,VP_CTL,VCT2P,vct2p)\
    |_PER_FMK(VPORT,VP_CTL,VCT1P,vct1p)\
    |_PER_FMK(VPORT,VP_CTL,TCI,tsi)\
    |_PER_FMK(VPORT,VP_CTL,DISP,disp)\
    |_PER_FMK(VPORT,VP_CTL,2CHNL,dchnl)\
)

/**
 *  \brief macro to generate register value for VDVINT register as per given
 *  fields
 */
#define VP_VDVINT_RMK(vif2,vint2,vif1,vint1) (Uint32)(\
     _PER_FMK(VPORT,VD_VINT,V1F2,vif2)\
    |_PER_FMK(VPORT,VD_VINT,VINT2,vint2)\
    |_PER_FMK(VPORT,VD_VINT,V1F1,vif1)\
    |_PER_FMK(VPORT,VD_VINT,VINT1,vint1)\
)

/**
 *  \brief macro to generate register value for VDVBLKS1 register as per given
 *  fields
 */
#define VP_VDVBLKS1_RMK(vblnkystart1,vblnkxstart1) (Uint32)(\
     _PER_FMK(VPORT,VD_VBLKS1,VBLNK_YSTART1,vblnkystart1)\
    |_PER_FMK(VPORT,VD_VBLKS1,VBLNK_XSTART1,vblnkxstart1)\
)

#ifdef __cplusplus
}
#endif

#endif /* _VPORT_REGRMK_H */

/******************************************************************************/
/* End of file                                                                */
/******************************************************************************/
