/******************************************************************************
**+-------------------------------------------------------------------------+**
**|                            ****                                         |**
**|                            ****                                         |**
**|                            ******o***                                   |**
**|                      ********_///_****                                  |**
**|                      ***** /_//_/ ****                                  |**
**|                       ** ** (__/ ****                                   |**
**|                           *********                                     |**
**|                            ****                                         |**
**|                            ***                                          |**
**|                                                                         |**
**|         Copyright (c) 1998-2007 Texas Instruments Incorporated          |**
**|                        ALL RIGHTS RESERVED                              |**
**|                                                                         |**
**| Permission is hereby granted to licensees of Texas Instruments          |**
**| Incorporated (TI) products to use this computer program for the sole    |**
**| purpose of implementing a licensee product based on TI products.        |**
**| No other rights to reproduce, use, or disseminate this computer         |**
**| program, whether in part or in whole, are granted.                      |**
**|                                                                         |**
**| TI makes no representation or warranties with respect to the            |**
**| performance of this computer program, and specifically disclaims        |**
**| any responsibility for any damages, special or consequential,           |**
**| connected with the use of this program.                                 |**
**|                                                                         |**
**+-------------------------------------------------------------------------+**
******************************************************************************/

/**
 *  \file vportdis.h file
 *
 *  This file contains channel object structure for display driver
 */

#ifndef _VPORTDIS_H
#define _VPORTDIS_H

#ifdef __cplusplus
extern "C" {
#endif

#include <ti/sdo/pspdrivers/system/dm648/bios/evmDM648/video/fvid.h>
#include <iom.h>
#include <ti/sdo/edma3/drv/edma3_drv.h>

/** \brief video port VCTL1 pin used as HSYNC signal */
#define VPORTDIS_VCTL1_HSYNC            (0)
/** \brief video port VCTL1 pin used as HBLNK signal */
#define VPORTDIS_VCTL1_HBLNK            (1)
/** \brief video port VCTL1 pin used as AVID signal */
#define VPORTDIS_VCTL1_AVID             (2)
/** \brief video port VCTL1 pin used as FLD signal */
#define VPORTDIS_VCTL1_FLD              (3)

/** \brief video port VCTL2 pin used as VSYNC signal */
#define VPORTDIS_VCTL2_VSYNC            (0)
/** \brief video port VCTL2 pin used as VBLNK signal */
#define VPORTDIS_VCTL2_VBLNK            (1)
/** \brief video port VCTL2 pin used as CSYNC signal */
#define VPORTDIS_VCTL2_CSYNC            (2)
/** \brief video port VCTL2 pin used as FLD signal */
#define VPORTDIS_VCTL2_FLD              (3)

/** \brief video port VCTL3 pin used as CBLNK signal */
#define VPORTDIS_VCTL3_CBLNK            (0)
/** \brief video port VCTL3 pin used as FLD signal */
#define VPORTDIS_VCTL3_FLD              (1)

/* In display operation, video port outputs HCTL/VCTL/FID signals when exc is
 * disabled. These signals are inputs to video port when exc is enabled
 */
/**
 *  \brief  video port display external control disable
 *  In display operation, embedded EAV/SAV code is used as input when exc
 *  disabled.
 */
#define VPORTDIS_EXC_DISABLE            (0)
/**
 *  \brief  video port external control enable
 *  HCTL/VCTL/FID is used as an input to VPORT when it is enabled
 */
#define VPORTDIS_EXC_ENABLE             (1)

/** \brief  video port fifo 10bit Normal packing mode */
#define VPORTDIS_BPK_10BIT_NORMAL       (0)
/** \brief  video port fifo 10bit Dense packing mode */
#define VPORTDIS_BPK_10BIT_DENSE        (1)

/** \brief  default value for other than active video input pixels disabled */
#define VPORTDIS_DEFVAL_DISABLE         (0)
/** \brief  default value for other than active video input pixels enabled */
#define VPORTDIS_DEFVAL_ENABLE          (1)

/** \brief  RGB extract disable */
#define VPORTDIS_RGBX_DISABLE           (0)
/** \brief  RGB extract enable */
#define VPORTDIS_RGBX_ENABLE            (1)

/**
  * \brief  VPORT Display Params Structure
  *  The parameter structure for display.
  */
typedef struct {
    Int                 dmode;
    /**< Display mode settings. Available values for this field are defined in
     * "vport.h" file with VPORT operation mode title.
     */

    Int                 fldOp;
    /**< Field & Frame operation, Available values for this field are defined in
     * "vport.h" file with fldOp title.
     */

    Int                 scale;
    /**< 2x scaling, available values for this field are defined in "vport.h"
     * file with video port HORIZONTAL scaling mode title.
     */

    Int                 resmpl;
    /**< Chroma resampling, available values for this field are defined in
     * "vport.h" file with Video port HORIZONTAL chroma resampling mode title
     */

    Int                 defValEn;
    /**< Default value enable for values that not covered by image area (outside
     * active image area)
     */

    Int                 bpk10Bit;
    /**< VPORT display 10-Bit mode. Available values for this field are defined
     * above.
     */

    Int                 vctl1Config;
    /**< Video port VCTL1 pin config value. Available values for this field are
     * defined above
     */

    Int                 vctl2Config;
    /**< Video port VCTL2 pin config value. Available values for this field are
     * defined above
     */

    Int                 vctl3Config;
    /**< Video port VCTL3 pin config value. Available values for this field are
     * defined above
     */

    Int                 extCtl;
    /**< External control enabled/disabled for synchronization of signals.
     * Available values for this field are defined above.
     */

    Uint16              frmHSize;
    /**< Horizontal size of the video frame, including the blanking period*/

    Uint16              frmVSize;
    /**< Vertical size of the video frame, including the blanking period */

    Int16               imgHOffsetFld1;
    /**< Display image horizontal offset in Field 1, relative to the end of
     * horizontal blanking. Can be negative to enable output during horizontal
     * blanking.
     */

    Int16               imgVOffsetFld1;
    /**< Display image vertical offset in Field 1, relative to the end of
     * vertical blanking. Can be negative to enable output during vertical
     * blanking
     */

    Uint16              imgHSizeFld1;
    /**< Display image width in pixels for Field 1 */

    Uint16              imgVSizeFld1;
    /**< Display image height in lines for Field 1 */

    Int16               imgHOffsetFld2;
    /**< Display image horizontal offset in Field 2, relative to the end of
     * horizontal blanking. Can be negative to enable output during horizontal
     * blanking
     */

    Int16               imgVOffsetFld2;
    /**< Display image vertical offset in Field 2, relative to the end of
     * vertical blanking. Can be negative to enable output during vertical
     * blanking.
     */

    Uint16              imgHSizeFld2;
    /**< Display image width in pixels for Field 2 */

    Uint16              imgVSizeFld2;
    /**< Display image height in lines for Field 2 */

    Uint16              hBlnkStart;
    /**< Specifies the pixel number within the line on which horizontal blanking
     * starts.
     */

    Uint16              hBlnkStop;
    /**< Specifies the pixel number within the line on which horizontal blanking
     * ends.
     */

    Uint16              vBlnkXStartFld1;
    /**< Specifies the pixel number on which the vertical blanking starts for
     * Field 1.
     */
    Uint16              vBlnkYStartFld1;
    /**< Specifies the line number on which the vertical blanking starts for
     * Field 1.
     */
    Uint16              vBlnkXStopFld1;
    /**< Specifies the pixel number on which the vertical blanking ends for
     * Field 1.
     */
    Uint16              vBlnkYStopFld1;
    /**< Specifies the line number on which the vertical blanking ends for
     * Field 1.
     */

    Uint16              vBlnkXStartFld2;
    /**< Specifies the pixel number on which the vertical blanking starts for
     * Field 2.
     */
    Uint16              vBlnkYStartFld2;
    /**< Specifies the line number on which the vertical blanking starts for
     * Field 2.
     */
    Uint16              vBlnkXStopFld2;
    /**< Specifies the pixel number on which the vertical blanking ends for
     * Field 2.
     */
    Uint16              vBlnkYStopFld2;
    /**< Specifies the line number on which the vertical blanking ends for
     * Field 2.
     */

    Uint16              xStartFld1;
    /**< Specifies the pixel number on the first line of Field 1 on which the
     * FLD output is de-asserted.
     */
    Uint16              yStartFld1;
    /**< Specifies the line number of Field 1 on which the FLD output is
     * de-asserted.
     */
    Uint16              xStartFld2;
    /**< Specifies the pixel number on the first line of Field 2 on which the
     * FLD output is asserted.
     */
    Uint16              yStartFld2;
    /**< Specifies the line number of Field 2 on which the FLD output is
     * asserted.
     */

    Uint16              hSyncStart;
    /**< Specifies the pixel number on which HSYNC is asserted. */
    Uint16              hSyncStop;
    /**< Specifies the pixel number on which HSYNC is de-asserted. */

    Uint16              vSyncXStartFld1;
    /**< Specifies the pixel number on which VSYNC is asserted in Field 1. */
    Uint16              vSyncYStartFld1;
    /**< Specifies the line number on which VSYNC is asserted in Field 1. */
    Uint16              vSyncXStopFld1;
    /**< Specifies the pixel number on which VSYNC is de-asserted in Field 1. */
    Uint16              vSyncYStopFld1;
    /**< Specifies the line number on which VSYNC is de-asserted in Field 1. */

    Uint16              vSyncXStartFld2;
    /**< Specifies the pixel number on which VSYNC is asserted in Field 1. */
    Uint16              vSyncYStartFld2;
    /**< Specifies the line number on which VSYNC is asserted in Field 1. */
    Uint16              vSyncXStopFld2;
    /**< Specifies the pixel number on which VSYNC is de-asserted in Field 1 */
    Uint16              vSyncYStopFld2;
    /**< Specifies the line number on which VSYNC is de-asserted in Field 1. */

    Uint8               yClipLow;
    /**< Y clip lower value, if input value lower than this value will be
     * clipped to this value.
     */
    Uint8               yClipHigh;
    /**< Y clip higher value, if input value higher than this value will be
     * clipped to this value.
     */

    Uint8               cClipLow;
    /**< C clip lower value, if input value lower than this value will be
     * clipped to this value.
     */
    Uint8               cClipHigh;
    /**< C clip higher value, if input value higher than this value will be
     * clipped to this value.
     */

    Uint8               yDefVal;
    /**< Y default value when image data is not available (outside active frame
     * area).
     */
    Uint8               cbDefVal;
    /**< Cb default value when image data is not available (outside active frame
     * area).
     */
    Uint8               crDefVal;
    /**< Cr default value when image data is not available (outside active frame
     * area).
     */

    Int                 rgbX;
    /**< Only used in raw mode for sequential 24/30-bit RGB data output, RGB
     * extract enable, performing & FIFO unpacking. Please refer to Video Port
     * Peripheral Reference Guide for more information.
     */

    Int                 incPix;
    /**< Internal FPCOUNT is increment every incPix output clocks - used only
     * in RAW mode
     */

    Uint16              thrld;
    /**< Video FIFO threshold value, indicates number of double words to
     * generate DMA events
     */

    Int                 numFrmBufs;
    /**< Number of frame buffers that the driver allocates. For normal mode
     * operation numFrmBufs should be 0 while for legacy mode operation
     * numFrmBufs value should be between minimum and maximum number buffers.
     */

    Int                 alignment;
    /**< Frame buffer alignment used by driver while allocating memory for video
     * frame buffer
     */

    Int                 mergeFlds;
    /**< Indicates whether to interleave data of the two fields in memory or
     * just store them separated. Available values for this field are defined in
     * "vport.h" file.
     */

    Int                 segId;
    /**< Memory segment ID, used by driver to allocate video frame buffer */

    EDMA3_DRV_Handle    hEdma;
    /**< EDMA driver handle */
} VPORTDIS_Params;

/** \brief VPORT display function pointer table */
extern IOM_Fxns VPORTDIS_Fxns;

#ifdef __cplusplus
}
#endif /* extern "C" */

#endif /* _VPORTDIS_H */

/******************************************************************************/
/* End of file                                                                */
/******************************************************************************/
