/*******************************************************************************
**+--------------------------------------------------------------------------+**
**|                            ****                                          |**
**|                            ****                                          |**
**|                            ******o***                                    |**
**|                      ********_///_****                                   |**
**|                      ***** /_//_/ ****                                   |**
**|                       ** ** (__/ ****                                    |**
**|                           *********                                      |**
**|                            ****                                          |**
**|                            ***                                           |**
**|                                                                          |**
**|         Copyright (c) 1998-2006 Texas Instruments Incorporated           |**
**|                        ALL RIGHTS RESERVED                               |**
**|                                                                          |**
**| Permission is hereby granted to licensees of Texas Instruments           |**
**| Incorporated (TI) products to use this computer program for the sole     |**
**| purpose of implementing a licensee product based on TI products.         |**
**| No other rights to reproduce, use, or disseminate this computer          |**
**| program, whether in part or in whole, are granted.                       |**
**|                                                                          |**
**| TI makes no representation or warranties with respect to the             |**
**| performance of this computer program, and specifically disclaims         |**
**| any responsibility for any damages, special or consequential,            |**
**| connected with the use of this program.                                  |**
**|                                                                          |**
**+--------------------------------------------------------------------------+**
*******************************************************************************/

/** \file   pal_osProtect.c
    \brief  OsPROTECT Services Source File for BIOS

    This file implements OS abstraction services for reentrancy protection.
    For interrupt protection, assembly code is used since BIOS does not provide
    a function that returns previous interrupt status (cpsr).

    (C) Copyright 2006, Texas Instruments, Inc

    \author     PSP Group
    \version    0.1 - Created
 */
#include <std.h>
#include <hwi.h>
#include <tsk.h>
#include <ti/sdo/pspdrivers/pal_os/pal_osProtect.h>


/* PAL OS Protect Exit */
void PAL_osProtectEntry(Int level, Uint32* imask)
{
    if (level == PAL_OSPROTECT_INTERRUPT)
    {
        if( NULL != imask )
        {
            *imask = HWI_disable();
        }
    }
    else if (level == PAL_OSPROTECT_SCHEDULER)
    {
        TSK_disable();
    }
    else
    {
        /* Does nothing. Else added to remove MISRAC warning*/
    }

    return;
}


/* PAL OS Protect Exit */
void PAL_osProtectExit(Int level, Uint32 imask)
{
    if (level == PAL_OSPROTECT_INTERRUPT)
    {
        HWI_restore(imask);
    }
    else if (level == PAL_OSPROTECT_SCHEDULER)
    {
        TSK_enable();
    }
    else
    {
        /* Does nothing. Else added to remove MISRAC warning*/
    }

    return;
}


