/*******************************************************************************
**+--------------------------------------------------------------------------+**
**|                            ****                                          |**
**|                            ****                                          |**
**|                            ******o***                                    |**
**|                      ********_///_****                                   |**
**|                      ***** /_//_/ ****                                   |**
**|                       ** ** (__/ ****                                    |**
**|                           *********                                      |**
**|                            ****                                          |**
**|                            ***                                           |**
**|                                                                          |**
**|         Copyright (c) 1998-2006 Texas Instruments Incorporated           |**
**|                        ALL RIGHTS RESERVED                               |**
**|                                                                          |**
**| Permission is hereby granted to licensees of Texas Instruments           |**
**| Incorporated (TI) products to use this computer program for the sole     |**
**| purpose of implementing a licensee product based on TI products.         |**
**| No other rights to reproduce, use, or disseminate this computer          |**
**| program, whether in part or in whole, are granted.                       |**
**|                                                                          |**
**| TI makes no representation or warranties with respect to the             |**
**| performance of this computer program, and specifically disclaims         |**
**| any responsibility for any damages, special or consequential,            |**
**| connected with the use of this program.                                  |**
**|                                                                          |**
**+--------------------------------------------------------------------------+**
*******************************************************************************/

/**
 *  \file   pal_osTask.c
 *
 *  \brief  BIOS OS Task Source File
 *
 *  This file implements additional OS abstraction services for BIOS.
 *  The following BIOS services are provided:
 *
 *   1. Task get priority
 *   2. Tsk_self - to return the Handler of the task
  *
 *  (C) Copyright 2006, Texas Instruments, Inc
 *
 *  \author     PSP Group
 *  \version    0.1
 */

#include <std.h>
#include <tsk.h>

#include <ti/sdo/pspdrivers/pal_os/pal_osTask.h>


/**
 *  \brief    Returns the handler of the current running task.
 *

 *
 *  \return
 *            Valid Task Handle  if success<br>
 *            NULL              if any errors<br>
 */
Ptr  PAL_osTskSelf()
{
    TSK_Handle tskhdl;

    tskhdl = TSK_self();

    return (Ptr)tskhdl;
}


/**
 *  \brief    Returns the Priority of the Task*
 *
* \param    handle     [IN]    Task handle
 */
 /*  return   Task Priority         if success<br>
 *            PAL ERROR Codes       if failure<br>
 */

Int32  PAL_osTskGetPriority(Ptr Handle)
{
    TSK_Handle tskhdl;
    Int32 priority;

    tskhdl = (TSK_Handle)Handle;

    priority = TSK_getpri(tskhdl);


    return (priority);
}


/**
 *  \brief
 *
* \param       NONE
 */
 /*  return   TRUE                  if context is task context
 *            FALSE                 if context is not the task context
 */

Bool  PAL_osTskIsTsk()
{
    Bool result;

    result = TSK_isTSK();


    return (result);
}



