/*******************************************************************************
**+--------------------------------------------------------------------------+**
**|                            ****                                          |**
**|                            ****                                          |**
**|                            ******o***                                    |**
**|                      ********_///_****                                   |**
**|                      ***** /_//_/ ****                                   |**
**|                       ** ** (__/ ****                                    |**
**|                           *********                                      |**
**|                            ****                                          |**
**|                            ***                                           |**
**|                                                                          |**
**|         Copyright (c) 1998-2006 Texas Instruments Incorporated           |**
**|                        ALL RIGHTS RESERVED                               |**
**|                                                                          |**
**| Permission is hereby granted to licensees of Texas Instruments           |**
**| Incorporated (TI) products to use this computer program for the sole     |**
**| purpose of implementing a licensee product based on TI products.         |**
**| No other rights to reproduce, use, or disseminate this computer          |**
**| program, whether in part or in whole, are granted.                       |**
**|                                                                          |**
**| TI makes no representation or warranties with respect to the             |**
**| performance of this computer program, and specifically disclaims         |**
**| any responsibility for any damages, special or consequential,            |**
**| connected with the use of this program.                                  |**
**|                                                                          |**
**+--------------------------------------------------------------------------+**
*******************************************************************************/

/**
 *  \file   pal_osTime.c
 *  \brief  BIOS OS time Source File
 *
 *  This file implements additional OS abstraction services for BIOS.
 *  The following BIOS services are provided:
 *
 *  1. time - GEt current systime
 *
 *  (C) Copyright 2006, Texas Instruments, Inc
 *
 *  \author     PSP Group
 *  \version    0.1
 */

#include <std.h>
#include <trc.h>
#include <log.h>
#include <prd.h>

#include <ti/sdo/pspdrivers/common/psp_common.h>

/**
 * \brief BIOS Debug features LOG
 */
extern far LOG_Obj trace;


/**
 * \brief PALOS Get OS Ticks per mSecs
 */
Uint32 PAL_osGetCurrentTick(void)
{
    return PRD_getticks();
}

/**
 * \brief   PALOS check timeout
 * \param   startValue  [IN]   Start value
 * \param   timeout     [IN]   Timeout value
 * \return  true or false
 */
Bool PAL_osCheckTimeOut(Uint32 startValue,Uint32 timeout)
{
    Uint32 checkValue;
    Bool    retVal;
    checkValue = PAL_osGetCurrentTick();
    if ( checkValue < startValue )
    {
        checkValue = (((0xFFFFFFFFU) - startValue) + checkValue) + (1U) ;
    }
    else
    {
        checkValue = checkValue - startValue;
    }

    if (checkValue < timeout)
    {
        retVal  =   FALSE;
    }
    else
    {
        retVal  =   TRUE;
    }
    return  retVal;
}

