/*******************************************************************************
**+--------------------------------------------------------------------------+**
**|                            ****                                          |**
**|                            ****                                          |**
**|                            ******o***                                    |**
**|                      ********_///_****                                   |**
**|                      ***** /_//_/ ****                                   |**
**|                       ** ** (__/ ****                                    |**
**|                           *********                                      |**
**|                            ****                                          |**
**|                            ***                                           |**
**|                                                                          |**
**|         Copyright (c) 1998-2006 Texas Instruments Incorporated           |**
**|                        ALL RIGHTS RESERVED                               |**
**|                                                                          |**
**| Permission is hereby granted to licensees of Texas Instruments           |**
**| Incorporated (TI) products to use this computer program for the sole     |**
**| purpose of implementing a licensee product based on TI products.         |**
**| No other rights to reproduce, use, or disseminate this computer          |**
**| program, whether in part or in whole, are granted.                       |**
**|                                                                          |**
**| TI makes no representation or warranties with respect to the             |**
**| performance of this computer program, and specifically disclaims         |**
**| any responsibility for any damages, special or consequential,            |**
**| connected with the use of this program.                                  |**
**|                                                                          |**
**+--------------------------------------------------------------------------+**
*******************************************************************************/

/** \file   pal_osTaskLet.h

    \brief  PAL OS Service Header File for Tasklet or software interrupt(SWI)
     management

    This file declares additional OS abstraction services. The following
    services are provided:

    1. Create a TaskLet
    2. Post a TaskLet
    3. Delete a TaskLet

    (C) Copyright 2004, Texas Instruments, Inc

    \author     PSP Group
    \version    1.0
 */

#ifndef _PAL_OSTASK_H
#define _PAL_OSTASK_H

#include <ti/sdo/pspdrivers/common/psp_common.h>
#include <ti/sdo/pspdrivers/pal_os/pal_os.h>

#ifdef __cplusplus
extern "C" {
#endif


/**
 * \brief PAL OS Task Handle
 */
typedef Ptr PAL_OsTaskHandle;

 /* brief    Returns the handler of the current running task.
 *
 * \ */
 /*  return   Task handler         if success<br>
 *            PAL ERROR Codes if failure<br>
*/

Ptr  PAL_osTskSelf();



/* brief    Returns the Priority of the Task*
 *
 * \param    handle     [IN]    Task handle
 */
 /*  return   Task Priority         if success<br>
 *            PAL ERROR Codes       if failure<br>
*/

Int32  PAL_osTskGetPriority(Ptr Handle);


/**
 *  \brief    
 *
* \param       NONE
 */
 /*  return   TRUE                  if context is task context
 *            FALSE                 if context is not the task context
 */

Bool  PAL_osTskIsTsk(); 


/*@}*/
#ifdef __cplusplus
}
#endif

#endif /* _PAL_OSTASKLET_H */


