/*******************************************************************************
**+--------------------------------------------------------------------------+**
**|                            ****                                          |**
**|                            ****                                          |**
**|                            ******o***                                    |**
**|                      ********_///_****                                   |**
**|                      ***** /_//_/ ****                                   |**
**|                       ** ** (__/ ****                                    |**
**|                           *********                                      |**
**|                            ****                                          |**
**|                            ***                                           |**
**|                                                                          |**
**|         Copyright (c) 1998-2006 Texas Instruments Incorporated           |**
**|                        ALL RIGHTS RESERVED                               |**
**|                                                                          |**
**| Permission is hereby granted to licensees of Texas Instruments           |**
**| Incorporated (TI) products to use this computer program for the sole     |**
**| purpose of implementing a licensee product based on TI products.         |**
**| No other rights to reproduce, use, or disseminate this computer          |**
**| program, whether in part or in whole, are granted.                       |**
**|                                                                          |**
**| TI makes no representation or warranties with respect to the             |**
**| performance of this computer program, and specifically disclaims         |**
**| any responsibility for any damages, special or consequential,            |**
**| connected with the use of this program.                                  |**
**|                                                                          |**
**+--------------------------------------------------------------------------+**
*******************************************************************************/

/** \file   pal_osTaskLet.h

    \brief  PAL OS Service Header File for Tasklet or software interrupt(SWI)
     management

    This file declares additional OS abstraction services. The following
    services are provided:

    1. Create a TaskLet
    2. Post a TaskLet
    3. Delete a TaskLet

    (C) Copyright 2004, Texas Instruments, Inc

    \author     PSP Group
    \version    1.0
 */

#ifndef _PAL_OSTASKLET_H
#define _PAL_OSTASKLET_H

#include <ti/sdo/pspdrivers/common/psp_common.h>
#include <ti/sdo/pspdrivers/pal_os/pal_os.h>

#ifdef __cplusplus
extern "C" {
#endif

/**
 * \brief PAL OS TaskLet handler function pointer
 *
 */
typedef void (*PAL_osTaskLetFxn)(Ptr arg);

/**
 * \defgroup PALOSTasklet PAL OS Tasklet Interface
 *
 * PAL OS TASKLET INTERFACE
 * @{
 */

/**
 *  \brief    PAL OS create a TaskLet handler
 *
 *  \param    priority     [IN]   TaskLet priority
 *  \param    tsklFunc     [IN]   TaskLet handler function
 *  \param    arg          [IN]   Argument to be passed to TaskLet handler
 *
 *  \return
 *            Valid TaskLet Handle  if success<br>
 *            NULL              if any errors<br>
 */
Ptr  PAL_osCreateTaskLet(Int32 priority, PAL_osTaskLetFxn tsklFunc, Ptr arg);

/**
 * \brief    PAL OS post or trigger a TaskLet
 *
 * \param    handle     [IN]    TaskLet handle
 *
 *  \return   PAL_SOK         if success<br>
 *            PAL ERROR Codes if failure<br>
 */
PAL_Result PAL_osPostTaskLet(Ptr handle);

/**
 * \brief    PAL OS delete a TaskLet handler
 *
 * \param    handle     [IN]    TaskLet handle to be deleted
 *
 *  \return   PAL_SOK         if success<br>
 *            PAL ERROR Codes if failure<br>
 */
PAL_Result PAL_osDeleteTaskLet(Ptr handle);

/*@}*/
#ifdef __cplusplus
}
#endif

#endif /* _PAL_OSTASKLET_H */
