/******************************************************************************
**+-------------------------------------------------------------------------+**
**|                            ****                                         |**
**|                            ****                                         |**
**|                            ******o***                                   |**
**|                      ********_///_****                                  |**
**|                      ***** /_//_/ ****                                  |**
**|                       ** ** (__/ ****                                   |**
**|                           *********                                     |**
**|                            ****                                         |**
**|                            ***                                          |**
**|                                                                         |**
**|         Copyright (c) 1998-2006 Texas Instruments Incorporated          |**
**|                        ALL RIGHTS RESERVED                              |**
**|                                                                         |**
**| Permission is hereby granted to licensees of Texas Instruments          |**
**| Incorporated (TI) products to use this computer program for the sole    |**
**| purpose of implementing a licensee product based on TI products.        |**
**| No other rights to reproduce, use, or disseminate this computer         |**
**| program, whether in part or in whole, are granted.                      |**
**|                                                                         |**
**| TI makes no representation or warranties with respect to the            |**
**| performance of this computer program, and specifically disclaims        |**
**| any responsibility for any damages, special or consequential,           |**
**| connected with the use of this program.                                 |**
**|                                                                         |**
**+-------------------------------------------------------------------------+**
******************************************************************************/

/**
 *  \file   pal_sys_soc.h
 *
 *  \brief  defines data structure specfic to SoC
 *
 *  This file defines data types and services (macros as well as functions)
 *  that are applicable to the abstracted h/w system (SoC/Board).
 *
 *  (C) Copyright 2006, Texas Instruments, Inc
 *
 *  \version    1.0     PSP Architecture Team   Created
 */

#ifndef __PAL_SYS_SOC_H__
#define __PAL_SYS_SOC_H__


/**
 * \defgroup PAL SYS SoC specific Data structure
 *
 * All Data structure are specific to SoC and it will be required to
 * redefine these all when move from one SoC to another.
 *
 * @{
 */

#ifdef __cplusplus
extern "C" {
#endif

/*****************************************************************************
 * CPU Clock Frequency
 *****************************************************************************/
#define PAL_SYS_CPU_CLOCK_FREQUENCY			(24000000u)

/*****************************************************************************
 * Reset Control Module
 *****************************************************************************/
#define PAL_SYS_RESET_UART 1
#define PAL_SYS_RESET_I2C 2
#define PAL_SYS_RESET_SPI 3


/**
 *  \brief  System Reset  Mode
 *
 *  System Reset  Mode
 */
typedef enum
{
    PAL_SYS_RESET_SOC_NOT_DEFINED      = 1
} PAL_SysSystemRstMode;

/**
 *  \brief  System Reset  status
 *
 *  System Reset  status
 */
typedef enum
{
    PAL_SYS_HARDWARE_RESET_NOT_DEFINED = 0
} PAL_SysSystemResetStatus;



/*****************************************************************************
 * Power Control Module
 *****************************************************************************/
#define PAL_SYS_PWR_MODULE_DSP  1
#define PAL_SYS_PWR_MODULE_ARM  2



/**
 *  \brief  System Power  Mode
 *
 *  System Power Mode
 */
typedef enum
{
    PAL_SYS_GLOBAL_POWER_MODE__NOT_DEFINED       = 0
} PAL_SysSysytemPowerMode;

/*****************************************************************************
 * Wakeup Control
 *****************************************************************************/

 /**
 *  \brief  Wake Intrrupt number
 *
 *  Wake Intrrupt number
 */
typedef enum
{
    PAL_SYS_WAKEUP_INT0_NOT_DEFINED = 1
} PAL_SysWakeupInterrupt;

 /**
 *  \brief  Wake Intrrupt Control
 *
 *  Wake Intrrupt Control
 */
typedef enum
{
    PAL_SYS_WAKEUP_DISABLED = 0,
    PAL_SYS_WAKEUP_ENABLED
} PAL_SysWakeupCtrl;

 /**
 *  \brief  Wake Polarity
 *
 *  Wake Polarity
 */
typedef enum
{
    PAL_SYS_WAKEUP_ACTIVE_HIGH = 0,
    PAL_SYS_WAKEUP_ACTIVE_LOW
} PAL_SysWakeupPolarity;

/*****************************************************************************
 * GPIO Control
 *****************************************************************************/

#define PAL_SYS_GPIO1_PIN1
#define PAL_SYS_GPIO1_PIN2
#define PAL_SYS_GPIO1_PIN3

#define PAL_SYS_GPIO2_PIN1
#define PAL_SYS_GPIO2_PIN2
#define PAL_SYS_GPIO2_PIN3



/*****************************************************************************
 * CLKC Control
 *****************************************************************************/





/**
 * \brief Module Number for PSC
 */
#define PAL_SYS_CLK_MODULE_VPSSDMA                  0       /**<VPSS DMA Module No*/
#define PAL_SYS_CLK_MODULE_VPSSMMR                  1       /**<VPSS MMR Module No*/
#define PAL_SYS_CLK_MODULE_EDMATPCC                 2       /**<TPCC LPSC Module No*/
#define PAL_SYS_CLK_MODULE_EDMATPTC0                3       /**<TPTC0 LPSC Module No*/
#define PAL_SYS_CLK_MODULE_EDMATPTC1                4       /**<TPTC1 LPSC Module No*/
#define PAL_SYS_CLK_MODULE_EDMATPTC2                5       /**<TPTC2 LPSC Module No*/
#define PAL_SYS_CLK_MODULE_EMACMC                   6       /**<EMAC Memory controller LPSC Module No*/
#define PAL_SYS_CLK_MODULE_MDIO                     7       /**<MDIO LPSC Module No*/
#define PAL_SYS_CLK_MODULE_EMAC                     8       /**<EMAC LPSC Module No*/
#define PAL_SYS_CLK_MODULE_MCASP0                   9       /**<McASP0 LPSC Module No*/
#define PAL_SYS_CLK_MODULE_VLYNQ                    11      /**<VLYNQ LPSC Module No*/

#define PAL_SYS_CLK_MODULE_UHPI                     12      /**<UHPI LPSC Module No*/
#define PAL_SYS_CLK_MODULE_DDR                      13      /**<DDR LPSC Module No*/
#define PAL_SYS_CLK_MODULE_AEMIF                    14      /**<EMIFA LPSC Module No*/
#define PAL_SYS_CLK_MODULE_PCI                      15      /**<PCI LPSC Module No*/
#define PAL_SYS_CLK_MODULE_MCBSP0                   16      /**<MCBSP0 LPSC Module No*/
#define PAL_SYS_CLK_MODULE_MCBSP1                   17      /**<MCBSP1 LPSC Module No*/

#define PAL_SYS_CLK_MODULE_I2C                      18      /**<I2C LPSC Module No*/
#define PAL_SYS_CLK_MODULE_UART0                    19      /**<UART0 LPSC Module No*/
#define PAL_SYS_CLK_MODULE_UART1                    20      /**<UART1 LPSC Module No*/
#define PAL_SYS_CLK_MODULE_VPSSDAC                  21      /**<VPSS DAC LPSC Module No*/
#define PAL_SYS_CLK_MODULE_HECC                     22      /**<HECC LPSC Module No*/
#define PAL_SYS_CLK_MODULE_PWM0                     23      /**<PWM0 LPSC Module No*/
#define PAL_SYS_CLK_MODULE_PWM1                     24      /**<PWM1 LPSC Module No*/
#define PAL_SYS_CLK_MODULE_PWM2                     25      /**<PWM2 LPSC Module No*/
#define PAL_SYS_CLK_MODULE_GPIO                     26      /**<GPIO LPSC Module No*/
#define PAL_SYS_CLK_MODULE_TIMER0                   27      /**<TIMER0 LPSC Module No*/
#define PAL_SYS_CLK_MODULE_TIMER1                   28      /**<TIMER1 LPSC Module No*/
#define PAL_SYS_CLK_MODULE_CPU                      39      /**<C64+ CPU LPSC Module No*/

/*****************************************************************************
 * Timer Control
 *****************************************************************************/

 /**
 *  \brief  Timer Ioctl Param
 *
 *  Timer Ioctl Param
 */
typedef enum
{
    PAL_SYS_IOCTLE_TIMER_SET_COUNT_DIRECTION = 0,
    PAL_SYS_IOCTLE_TIMER_GET_COUNT_DIRECTION,
    PAL_SYS_IOCTLE_SET_TIMER_SET_TICK_RELOAD,
    PAL_SYS_IOCTLE_SET_TIMER_GET_TICK_RELOAD
}
PAL_SysTimerIoctl;


/*****************************************************************************
 * RTC Control
 *****************************************************************************/

 /**
 *  \brief  Timer Ioctl Param
 *
 *  Timer Ioctl Param
 */
typedef enum
{
    PAL_SYS_IOCTLE_RTC_SET_HOUR_FORMAT = 0,
    PAL_SYS_IOCTLE_RTC_GET_HOUR_FORMAT
}
PAL_SysRtcIoctl;

/*****************************************************************************
 * MISC
 *****************************************************************************/

 /**
 *  \brief  Chip Info
 *
 *  Chip Info
 */
typedef struct
{
    unsigned int chipInfo;
    unsigned int versionId;
}PAL_SysVersionInfo;

#ifdef __cplusplus
}
#endif

#endif
