/******************************************************************************
**+-------------------------------------------------------------------------+**
**|                            ****                                         |**
**|                            ****                                         |**
**|                            ******o***                                   |**
**|                      ********_///_****                                  |**
**|                      ***** /_//_/ ****                                  |**
**|                       ** ** (__/ ****                                   |**
**|                           *********                                     |**
**|                            ****                                         |**
**|                            ***                                          |**
**|                                                                         |**
**|         Copyright (c) 1998-2006 Texas Instruments Incorporated          |**
**|                        ALL RIGHTS RESERVED                              |**
**|                                                                         |**
**| Permission is hereby granted to licensees of Texas Instruments          |**
**| Incorporated (TI) products to use this computer program for the sole    |**
**| purpose of implementing a licensee product based on TI products.        |**
**| No other rights to reproduce, use, or disseminate this computer         |**
**| program, whether in part or in whole, are granted.                      |**
**|                                                                         |**
**| TI makes no representation or warranties with respect to the            |**
**| performance of this computer program, and specifically disclaims        |**
**| any responsibility for any damages, special or consequential,           |**
**| connected with the use of this program.                                 |**
**|                                                                         |**
**+-------------------------------------------------------------------------+**
******************************************************************************/

/**
 *  \file   pal_sys_soc.h
 *
 *  \brief  defines data structure specfic to SoC
 *
 *  This file defines data types and services (macros as well as functions)
 *  that are applicable to the abstracted h/w system (SoC/Board).
 *
 *  (C) Copyright 2006, Texas Instruments, Inc
 *
 *  \version    0.1        Created                  PSP Architecture Team
 *  \version    0.2    Added pinmux functionalities Nagarjuna
 */

#ifndef __PAL_SYS_SOC_H__
#define __PAL_SYS_SOC_H__

#ifdef __cplusplus
extern "C" {
#endif

/**
 * \defgroup PAL SYS SoC specific Data structure
 *
 * All Data structure are specific to SoC and it will be required to
 * redefine these all when move from one SoC to another.
 *
 * @{
 */

/*****************************************************************************
 * CPU Clock Frequency
 *****************************************************************************/
#define PAL_SYS_CPU_CLOCK_FREQUENCY			(891000000u)

/*****************************************************************************
 * Reset Control Module
 *****************************************************************************/
#define PAL_SYS_RESET_UART 1
#define PAL_SYS_RESET_I2C 2
#define PAL_SYS_RESET_SPI 3
 /* @} */

/**
 *  \brief  System Reset  Mode
 *
 *  System Reset  Mode
 */
typedef enum
{
    PAL_SYS_RESET_SOC_NOT_DEFINED      = 1    /**< SOC not defined */
} PAL_SysSystemRstMode;

/**
 *  \brief  System Reset  status
 *
 *  System Reset  status
 */
typedef enum
{
    PAL_SYS_HARDWARE_RESET_NOT_DEFINED = 0        /**<HW resert not defined */
} PAL_SysSystemResetStatus;



/**
 * defgroup Power Control Module
 * @{
 */
#define PAL_SYS_PWR_MODULE_DSP  1


/* @} */

/**
 *  \defgroup  System Power  Mode
 *
 *  System Power Mode
 * @{
 */
typedef enum
{
    PAL_SYS_GLOBAL_POWER_MODE__NOT_DEFINED       = 0
} PAL_SysSysytemPowerMode;

/* @} */
/*****************************************************************************
 * Wakeup Control
 *****************************************************************************/

 /**
 *  \brief  Wake Intrrupt number
 *
 *  Wake Intrrupt number
 */
typedef enum
{
    PAL_SYS_WAKEUP_INT0_NOT_DEFINED = 1        /* notdefined */
} PAL_SysWakeupInterrupt;

 /**
 *  \brief  Wake Intrrupt Control
 *
 *  Wake Intrrupt Control
 */
typedef enum
{
    PAL_SYS_WAKEUP_DISABLED = 0,
    PAL_SYS_WAKEUP_ENABLED
} PAL_SysWakeupCtrl;

 /**
 *  \brief  Wake Polarity
 *
 *  Wake Polarity
 */
typedef enum
{
    PAL_SYS_WAKEUP_ACTIVE_HIGH = 0,
    PAL_SYS_WAKEUP_ACTIVE_LOW
} PAL_SysWakeupPolarity;

/*****************************************************************************
 * GPIO Control
 *****************************************************************************/

#define PAL_SYS_GPIO1_PIN1
#define PAL_SYS_GPIO1_PIN2
#define PAL_SYS_GPIO1_PIN3

#define PAL_SYS_GPIO2_PIN1
#define PAL_SYS_GPIO2_PIN2
#define PAL_SYS_GPIO2_PIN3



/*****************************************************************************
 * CLKC Control
 *****************************************************************************/





/**
 * \brief Module Number for PSC
 */

#define PAL_SYS_CLK_MODULE_EDMATPCC     (0)  /**<TPCC  LPSC Module No       */
#define PAL_SYS_CLK_MODULE_TSIP0        (5)  /**<TSIP0 LPSC Module No       */
#define PAL_SYS_CLK_MODULE_TSIP1        (6)  /**<TSIP1 LPSC Module No       */
#define PAL_SYS_CLK_MODULE_EMIF3D       (7)  /**<EMIF3D LPSC Module No      */
#define PAL_SYS_CLK_MODULE_UHPI         (8)  /**<UHPI  LPSC Module No       */
#define PAL_SYS_CLK_MODULE_VLYNQ        (9)  /**<VLYNQ LPSC Module No       */
#define PAL_SYS_CLK_MODULE_GPIO         (10) /**<GPIO LPSC Module No        */
#define PAL_SYS_CLK_MODULE_TIMER0       (11) /**<TIMER0 LPSC Module No      */
#define PAL_SYS_CLK_MODULE_TIMER1       (12) /**<TIMER1 LPSC Module No      */
#define PAL_SYS_CLK_MODULE_SPI          (17) /**<SPI LPSC Module No         */
#define PAL_SYS_CLK_MODULE_I2C          (18) /**<I2C LPSC Module No         */
#define PAL_SYS_CLK_MODULE_PCI          (19) /**<PCI LPSC Module No         */
#define PAL_SYS_CLK_MODULE_VP0          (20) /**<Video Port0 LPSC Module No */
#define PAL_SYS_CLK_MODULE_VP1          (21) /**<Video Port1 LPSC Module No */
#define PAL_SYS_CLK_MODULE_VP2          (22) /**<Video Port2 LPSC Module No */
#define PAL_SYS_CLK_MODULE_VP3          (23) /**<Video Port3 LPSC Module No */
#define PAL_SYS_CLK_MODULE_VP4          (24) /**<Video Port4 LPSC Module No */
#define PAL_SYS_CLK_MODULE_EMIF3B       (25) /**<EMIF3B LPSC Module No      */
#define PAL_SYS_CLK_MODULE_TIMER2       (26) /**<TIMER0 LPSC Module No      */
#define PAL_SYS_CLK_MODULE_TIMER3       (27) /**<TIMER1 LPSC Module No      */
#define PAL_SYS_CLK_MODULE_VIC          (28) /**<VIC LPSC Module No         */
#define PAL_SYS_CLK_MODULE_MCASP        (29) /**<McASP  LPSC Module No      */
#define PAL_SYS_CLK_MODULE_UART         (30) /**<UART LPSC Module No        */
#define PAL_SYS_CLK_MODULE_IMCOP        (31) /**<IMCOP LPSC Module No       */
#define PAL_SYS_CLK_MODULE_CHIP         (32) /**<Chip Regs LPSC Module No   */
#define PAL_SYS_CLK_MODULE_GEM          (33) /**<GEM LPSC Module No         */
#define PAL_SYS_CLK_MODULE_ETHERNET     (34) /**<Ethernet LPSC Module No    */


/*****************************************************************************
 * Timer Control
 *****************************************************************************/

 /**
 *  \brief  Timer Ioctl Param
 *
 *  Timer Ioctl Param
 */
typedef enum
{
    PAL_SYS_IOCTLE_TIMER_SET_COUNT_DIRECTION = 0,
    PAL_SYS_IOCTLE_TIMER_GET_COUNT_DIRECTION,
    PAL_SYS_IOCTLE_SET_TIMER_SET_TICK_RELOAD,
    PAL_SYS_IOCTLE_SET_TIMER_GET_TICK_RELOAD
}
PAL_SysTimerIoctl;


/*****************************************************************************
 * RTC Control
 *****************************************************************************/

 /**
 *  \brief  Timer Ioctl Param
 *
 *  Timer Ioctl Param
 */
typedef enum
{
    PAL_SYS_IOCTLE_RTC_SET_HOUR_FORMAT = 0,
    PAL_SYS_IOCTLE_RTC_GET_HOUR_FORMAT
}
PAL_SysRtcIoctl;

/*****************************************************************************
 * Pinmuc Control
 *****************************************************************************/

 /**
 *  \brief  Timer Ioctl Param
 *
 *  Timer Ioctl Param
 */
typedef enum PAL_SysPinmuxCtrl_t
{
    PAL_SYS_PINMUX_UART = 0,
    PAL_SYS_PINMUX_I2C,
    PAL_SYS_PINMUX_SPI,
    PAL_SYS_PINMUX_TSIP,
    PAL_SYS_PINMUX_VLYNQ,
    PAL_SYS_PINMUX_VP0,
    PAL_SYS_PINMUX_VP1,
    PAL_SYS_PINMUX_VP2,
    PAL_SYS_PINMUX_VP3_VP4,
    PAL_SYS_PINMUX_TIMER,
    PAL_SYS_PINMUX_MCASP
}
PAL_SysPinmuxCtrl;


/*****************************************************************************
 * MISC
 *****************************************************************************/

 /**
 *  \brief  Chip Info
 *
 *  Chip Info
 */
typedef struct
{
    unsigned int chipInfo;
    unsigned int versionId;
}PAL_SysVersionInfo;

#ifdef __cplusplus
}
#endif

#endif
