/*******************************************************************************
**+--------------------------------------------------------------------------+**
**|                            ****                                          |**
**|                            ****                                          |**
**|                            ******o***                                    |**
**|                      ********_///_****                                   |**
**|                      ***** /_//_/ ****                                   |**
**|                       ** ** (__/ ****                                    |**
**|                           *********                                      |**
**|                            ****                                          |**
**|                            ***                                           |**
**|                                                                          |**
**|         Copyright (c) 1998-2006 Texas Instruments Incorporated           |**
**|                        ALL RIGHTS RESERVED                               |**
**|                                                                          |**
**| Permission is hereby granted to licensees of Texas Instruments           |**
**| Incorporated (TI) products to use this computer program for the sole     |**
**| purpose of implementing a licensee product based on TI products.         |**
**| No other rights to reproduce, use, or disseminate this computer          |**
**| program, whether in part or in whole, are granted.                       |**
**|                                                                          |**
**| TI makes no representation or warranties with respect to the             |**
**| performance of this computer program, and specifically disclaims         |**
**| any responsibility for any damages, special or consequential,            |**
**| connected with the use of this program.                                  |**
**|                                                                          |**
**+--------------------------------------------------------------------------+**
*******************************************************************************/

/** \file   pal_sys.c
    \brief  OsSem Services Source File for BIOS

    (C) Copyright 2006, Texas Instruments, Inc

    \author    PSG
    \version    0.1 - Created                       Purushotam Kumar
                0.2 - Added PINMUX functionalities  Nagarjuna Kristam

 */


#ifdef CHIP_DM648
#include <ti/sdo/pspdrivers/pal_sys/dm648/pal_sys.h>

#include <ti/sdo/pspdrivers/soc/dm648/dsp/cslr_psc.h>
#include <ti/sdo/pspdrivers/soc/dm648/dsp/cslr_sys.h>
#include <ti/sdo/pspdrivers/soc/dm648/dsp/soc.h>
#endif

#ifdef CHIP_C6452
#include <ti/sdo/pspdrivers/pal_sys/c6452/pal_sys.h>

#include <ti/sdo/pspdrivers/soc/c6452/dsp/cslr_psc.h>
#include <ti/sdo/pspdrivers/soc/c6452/dsp/cslr_sys.h>
#include <ti/sdo/pspdrivers/soc/c6452/dsp/soc.h>
#endif


static CSL_PscRegsOvly  pscRegs =   (CSL_PscRegsOvly)CSL_PSC_0_REGS;

static CSL_SysRegsOvly  sysRegs =   (CSL_SysRegsOvly)CSL_SYS_0_REGS;

/**
 *  \brief Reset Ioctl
 *
 *  This function provides reset Ctrl functionality.
 *
 *  \param  resetModuleId [IN]          module Id
 *  \param  resetCtrl     [IN]          reset Ctrl
 *  \return PSP_SOK or PSP Error code
 */
PAL_Result PAL_sysResetCtrl(Uint32 resetModuleId,PAL_sysResetControl resetCtrl)
{
    /* Added to remove remark while compiling with -pdr option*/
    resetModuleId = resetModuleId;
    resetCtrl = resetCtrl;

    return PAL_SYS_ERROR_NOT_SUPPORTED;
}

/**
 *  \brief Get status of Reset
 *
 *  This function get reset status.
 *
 *  \param  resetModuleId     [IN]      module Id
  *  \return PAL_sysResetControl
 */
/* ARGSUSED */
PAL_sysResetControl PAL_sysGetResetStatus(Uint32 resetModuleId)
{

    return (PAL_sysResetControl)PAL_SYS_ERROR_NOT_SUPPORTED;
}

/**
 *  \brief perform system reset
 *
 *  This function performs system reset.
 *
 *  \param  mode    [IN]        reset mode
 *  \return PSP_SOK or PSP Error code
 */
PAL_Result PAL_sysSystemReset(PAL_SysSystemRstMode mode)
{
    /* Added to remove remark while compiling with -pdr option*/
    mode = mode;
    return PAL_SYS_ERROR_NOT_SUPPORTED;
}
/**
 *  \brief perform system reset
 *
 *  This function performs system reset.
 *
 *  \return PAL_SysSystemResetStatus
 */
PAL_SysSystemResetStatus PAL_sysGetSysLastResetStatus(void)
{
    return (PAL_SysSystemResetStatus)1;
}





/*****************************************************************************
 * Power Control Module
 *****************************************************************************/


/**
 *  \brief Module Power Ioctl
 *
 *  This function provides module power control functionality.
 *
 *  \param  powerModule [IN]       module Id
 *  \param  powerCtrl   [IN]       power Ctrl
 *  \return PSP_SOK or PSP Error code
 */
PAL_Result PAL_sysPowerCtrl(Uint32 powerModule,  PAL_sysPowerControl powerCtrl)
{
    /* Added to remove remark while compiling with -pdr option*/
    powerModule = powerModule;
    powerCtrl = powerCtrl;
    return PAL_SYS_ERROR_NOT_SUPPORTED;
}

/**
 *  \brief Get Module Power status
 *
 *  This function provides module power control functionality.
 *
 *  \param  powerModule     [IN]     module Id
 *  \return PAL_sysPowerControl
 */
PAL_sysPowerControl PAL_sysGetPowerStatus(Uint32 powerModule)
{
    /* Added to remove remark while compiling with -pdr option*/
    powerModule = powerModule;

    return (PAL_sysPowerControl)PAL_SYS_ERROR_NOT_SUPPORTED;
}

/**
 *  \brief Set Global Power Mode
 *
 *  This function sets global power mode.
 *
 *  \param  powerMode    [IN]    power mode
 *  \return PSP_SOK or PSP Error code
 */
PAL_Result PAL_sysSetGlobalPowerMode(PAL_SysSysytemPowerMode powerMode)
{
    /* Added to remove remark while compiling with -pdr option*/
    powerMode = powerMode;

    return PAL_SYS_ERROR_NOT_SUPPORTED;
}

/**
 *  \brief Get Global Power mode
 *
 *  This function provides global power mode.
 *
 *  \return PAL_SysSysytemPowerMode
 */
PAL_SysSysytemPowerMode PAL_sysGetGlobalPowerMode(void)
{
    return (PAL_SysSysytemPowerMode)1;
}




/*****************************************************************************
 * Wakeup Control
 *****************************************************************************/


/**
 *  \brief Wake up control
 *
 *  This function provides functionality of wake up control.
 *
 *  \param   wakeupInt        [IN]      Interrupt for wakeup
 *  \param   wakeupCtrl       [IN]      wake up control
 *  \param   wakeupPolarity   [IN]      wake up polarity
 *  \return PSP_SOK or PSP Error code
 */
/* ARGSUSED */
PAL_Result PAL_sysWakeupCtrl(PAL_SysWakeupInterrupt wakeupInt,
                         PAL_SysWakeupCtrl wakeupCtrl,
                         PAL_SysWakeupPolarity wakeupPolarity)
{
    return PAL_SYS_ERROR_NOT_SUPPORTED;
}


/*****************************************************************************
 * GPIO Control
 *****************************************************************************/




/**
 *  \brief GPIO Init
 *
 *  Init function for GPIO.
 *
 *  \return
 */
void PAL_sysGpioInit(void)
{

}


/**
 *  \brief GPIO control
 *
 *  This function provides functionality for GPIO control.
 *
 *  \param   gpioPin        [IN]        GPIO Pin number
 *  \param   pinMode        [IN]        mode of GPIO pin
 *  \param   pinDirection   [IN]        GPIO pin direction
 *  \return PSP_SOK or PSP Error code
 */
/* ARGSUSED */
PAL_Result PAL_sysGpioCtrl(Uint32 gpioPin,
                      PAL_SysGpioPinMode pinMode,
                      PAL_SysGpioPinDirection pinDirection)
{
    return PAL_SYS_ERROR_NOT_SUPPORTED;
}

/**
 *  \brief GPIO pin Out
 *
 *  It is used to set value to one GPIO pin.
 *
 *  \param   gpioPin    [IN]        GPIO Pin number
 *  \param   value      [IN]        value to be set on GPIO pin
 *  \return PSP_SOK or PSP Error code
 */
/* ARGSUSED */
PAL_Result PAL_sysGpioOutBit(Uint32 gpioPin, int value)
{
    return PAL_SYS_ERROR_NOT_SUPPORTED;
}

/**
 *  \brief GPIO pin In
 *
 *  It is used to get value at one GPIO pin.
 *
 *  \param   gpioPin    [IN]        GPIO Pin number
 *  \return value at GPIO pin
 */
/* ARGSUSED */
Int PAL_sysGpioInBit(Uint32 gpioPin)
{
    return PAL_SYS_ERROR_NOT_SUPPORTED;
}

/**
 *  \brief Set value to group of GPIO Pin
 *
 *  It is used to set value to group of GPIO Pin.
 *
 *  \param   outVal     [IN]         vale to be set on group of GPIO pin
 *  \param   outMask    [IN]         Mask defines group of pins in GPIO register
 *  \param   regIndex   [IN]         Index of register
 *  \return PSP_SOK or PSP Error code
 */
/* ARGSUSED */
PAL_Result PAL_sysGpioOutValue(Uint32 outVal, Uint32 outMask,
                           Uint32 regIndex)
{
    return PAL_SYS_ERROR_NOT_SUPPORTED;
}

/**
 *  \brief Get value of group of GPIO Pin
 *
 *  It is used to get value of group of GPIO Pin.
 *
 *  \param   inVal      [IN]       vale of group of GPIO pin
 *  \param   regIndex   [IN]       Index of register
 *  \return PSP_SOK or PSP Error code
 */
/* ARGSUSED */
PAL_Result PAL_sysGpioInValue(Uint32 *inVal, Uint32 regIndex)
{
    return PAL_SYS_ERROR_NOT_SUPPORTED;
}


/*****************************************************************************
 * CLKC Control
 *****************************************************************************/

 /**
 *  \brief Clock Init
 *
 *  Init function for Clock.
 *
 *  \param  param [IN]
 *  \return
 */
/* ARGSUSED */
void PAL_sysClkcInit(void* param)
{
}

/**
 *  \brief Set frequency to clock
 *
 *  It is used to set frequncy to clock .
 *
 *  \param   clkId         [IN]     Clock Id
 *  \param   outputFreq    [IN]     frequency
 *  \return PSP_SOK or PSP Error code
 */
/* ARGSUSED */
PAL_Result PAL_sysClkcSetFreq(Uint32 clkId, Uint32 outputFreq)
{
    return PAL_SYS_ERROR_NOT_SUPPORTED;
}


/**
 *  \brief Get Clock frequency
 *
 *  It is used to get frequncy of clock .
 *
 *  \param   clkId    [IN]          Clock Id
 *  \return Clock frequency
 */
/* ARGSUSED */
Int PAL_sysClkcGetFreq(Uint32 clkId)
{
    return PAL_SYS_ERROR_NOT_SUPPORTED;
}

/**
 *  \brief Module Clock Control
 *
 *  It is used provides module clock control functionalties .
 *
 *  \param   moduleId    [IN]    module Id
 *  \param   clkCtrl     [IN]    Clock Ctrl
  *  \return PSP_SOK or PSP Error code
 */
PAL_Result PAL_sysModuleClkCtrl(Uint32 moduleId,PAL_SysModuleClkControl clkCtrl)
{

#define TIMEOUT_COUNT   (10240u)
    PAL_Result        result   = PAL_SOK;
    Uint32            lpscNum  = moduleId;
    Uint16            state    = 0;
    volatile Uint32   count    = 0;


    if(clkCtrl == PAL_SYS_MODULE_CLK_ENABLE) /* Module clk enable in LPSC */
    {
        state = (0x0003u);
    }
    else /* Module clk disable in LPSC */
    {
        state = (0x0002u);
    }

    /* NEXT=state */
    pscRegs->MDCTL[lpscNum] = (pscRegs->MDCTL[lpscNum]&0xFFFFFFE0) | state;

    pscRegs->PTCMD = (0x1u);

    /*Wait for power state transition to finish*/
    count = TIMEOUT_COUNT;
    while( ((pscRegs->PTSTAT & (0x1u)) != 0) && (count>0))
    {
        count --;
    }

    if (0 == count) /* If timeout, then there is no such resource in LPSC */
    {
       result = PAL_SYS_ERROR_NO_RESOURCES;
    }
    else
    {
        /* Wait for MODSTAT = ENABLE/DISABLE from LPSC */
        count = TIMEOUT_COUNT;
        while( ((pscRegs->MDSTAT[lpscNum] & (0x1Fu)) != state) && (count>0))
        {
            count --;
        }

        if (0 == count) /* If timeout, the resource may not be functioning */
        {
           result = PAL_SYS_ERROR_NO_RESOURCES;
        }
    }

    return result;
}

/**
 *  \brief Get Status of Module Clock
 *
 *  It is used provides module clock control functionalties .
 *
 *  \param   moduleId    [IN]     module Id
 *  \return PAL_SysModuleClkControle
 */
/* ARGSUSED */
PAL_SysModuleClkControl PAL_sysGetModuleClkCtrl(Uint32 moduleId)
{
    return (PAL_SysModuleClkControl)PAL_SYS_ERROR_NOT_SUPPORTED;
}





/*****************************************************************************
 * RTC Control
 *****************************************************************************/




 /**
 *  \brief RTC Init
 *
 *  Init function for RTC.
 *
 *  \param  param [IN]
 *  \return
 */
/* ARGSUSED */
void PAL_sysRtcInit(void* param)
{
}

 /**
 *  \brief RTC DeInit
 *
 *  DeInit function for RTC.
 *
 *  \param  param [IN]
 *  \return
 */
/* ARGSUSED */
void PAL_sysRtcDeInit(void* param)
{
}
 /**
 *  \brief Set time to RTC
 *
 *  Set time to RTC
 *
 *  \param  rtcTime [IN]   current time to be set to RTC
 *  \return PSP_SOK or PSP Error code
 */
/* ARGSUSED */
PAL_Result PAL_sysRtcSetTime(PAL_SysRtctime* rtcTime)
{
    return PAL_SYS_ERROR_NOT_SUPPORTED;
}

 /**
 *  \brief Get current time from RTC
 *
 *  Get current time from RTC
 *
 *  \param  rtcTime [OUT]   current time
 *  \return PSP_SOK or PSP Error code
 */
/* ARGSUSED */
PAL_Result PAL_sysRtcGetTime(PAL_SysRtctime* rtcTime)
{
    return PAL_SYS_ERROR_NOT_SUPPORTED;
}

/**
 *  \brief RTC Control
 *
 *  It is used provides RTC control functionalties .
 *
 *  \param  timerId      [IN]     timer ID
 *  \param  rtcIoctl     [IN]     timer Ioctl
 *  \param  arg          [IN/OUT] argument for Ioctl
 *  \return PSP_SOK or PSP Error code
 */
/* ARGSUSED */
PAL_Result PAL_sysRtcCtrl(Uint32 timerId,PAL_SysRtcIoctl rtcIoctl, void *arg)
{
    return PAL_SYS_ERROR_NOT_SUPPORTED;
}



/*****************************************************************************
 * RTC Control
 *****************************************************************************/

/**
 *  \brief WatchDog Init
 *
 *  Init function for WatchDog.
 *
 *  \param  param        [IN]
 *  \param  wdgInstId    [IN]    Wdg instanceId
 *  \return PSP_SOK or PSP Error code
 */
/* ARGSUSED */
PAL_Result PAL_sysWdgInit (Uint32 wdgInstId,void* param)
{
    return PAL_SYS_ERROR_NOT_SUPPORTED;
}



/**
 *  \brief WatchDog DeInit
 *
 *  DeInit function for WatchDog.
 *
 *  \param  param        [IN]
 *  \param  wdgInstId    [IN]    Wdg instanceId
 *  \return
 */
/* ARGSUSED */
void PAL_sysWdgDeInit (Uint32 wdgInstId,void *param)
{
}



 /**
 *  \brief Set time to Wdg
 *
 *  Set time to Wdg
 *
 *  \param  wdgInstId   [IN]   Wdg instanceId
 *  \param  time        [IN]   time to be set to Wdg
 *  \return PSP_SOK or PSP Error code
 */
/* ARGSUSED */
PAL_Result PAL_sysWdgSetTimeOut (Uint32 wdgInstId, PAL_sysWdgTime *time)
{
    return PAL_SYS_ERROR_NOT_SUPPORTED;
}



 /**
 *  \brief Get time to Wdg
 *
 *  Get time to Wdg
 *
 *  \param  wdgInstId   [IN]      Wdg instanceId
 *  \param  time        [OUT]     time
 *  \return PSP_SOK or PSP Error code
 */
/* ARGSUSED */
PAL_Result PAL_sysWdgGetTimeOut (Uint32 wdgInstId, PAL_sysWdgTime *time)
{
    return PAL_SYS_ERROR_NOT_SUPPORTED;
}




 /**
 *  \brief Pet the Watch Dog, to avoid Reset
 *
 *  Pet the Watch Dog, to avoid Reset
 *
 *  \param  wdgInstId    [IN]   Wdg instanceId
 *  \return PSP_SOK or PSP Error code
 */
/* ARGSUSED */
PAL_Result PAL_sysWdgKeepAlive (Uint32 wdgInstId)
{
    return PAL_SYS_ERROR_NOT_SUPPORTED;
}





 /**
 *  \brief Enable the Watch Dog
 *
 *  Enable the Watch Dog. This function returns error if the
 *  Count loaded is Zero
 *
 *  \param  wdgInstId    [IN]   Wdg instanceId
 *  \return PSP_SOK or PSP Error code
 */
/* ARGSUSED */
PAL_Result PAL_sysWdgEnable (Uint32 wdgInstId)
{
    return PAL_SYS_ERROR_NOT_SUPPORTED;
}



 /**
 *  \brief Disable the Watch Dog
 *
 *  Disable the Watch Dog.
 *
 *  \param  wdgInstId    [IN]   Wdg instanceId
 *  \return PSP_SOK or PSP Error code
 */
/* ARGSUSED */
PAL_Result PAL_sysWdgDisable (Uint32 wdgInstId)
{
    return PAL_SYS_ERROR_NOT_SUPPORTED;
}

/*****************************************************************************
 * pinmux control
 *****************************************************************************/

/**
 *  \brief Pinmux Control
 *
 *  It is used pinmux for the devices .
 *
 *  \param      muxId    [IN]    Pinmux device id
 *  \return     PSP_SOK or PSP Error code
 */
PAL_Result PAL_sysPinmuxEnable(PAL_SysPinmuxCtrl muxId)
{
    PAL_Result  result = PSP_SOK;

    switch(muxId)
    {
        case PAL_SYS_PINMUX_UART:
            CSL_FINST(sysRegs->PINMUX,SYS_PINMUX_SPI_UART_EN,UART_ENABLE);
            break;

        case PAL_SYS_PINMUX_I2C:
            /* Not pinmuxed in DM648 SOC */
            break;

        case PAL_SYS_PINMUX_SPI:
            CSL_FINST(sysRegs->PINMUX,SYS_PINMUX_SPI_UART_EN,SPI_ENABLE);
            break;

        case PAL_SYS_PINMUX_TSIP:
            /* Not applicable in DVR. Applicable only in NON DVR mode */
            break;

        case PAL_SYS_PINMUX_VLYNQ:
            CSL_FINST(sysRegs->PINMUX,SYS_PINMUX_VLYNQ_EN,VLYNQ_ENABLED);
            break;

        case PAL_SYS_PINMUX_VP0:
            CSL_FINST(sysRegs->PINMUX,SYS_PINMUX_GPIO_EN,VP0_ENABLE);
            break;

        case PAL_SYS_PINMUX_VP1:
            CSL_FINST(sysRegs->PINMUX,SYS_PINMUX_VP1_EN,VP1_ENABLE);
            break;

        case PAL_SYS_PINMUX_VP2:
            CSL_FINST(sysRegs->PINMUX,SYS_PINMUX_VLYNQ_EN,VP2_ENABLED);
            break;

        case PAL_SYS_PINMUX_VP3_VP4:
            CSL_FINST(sysRegs->PINMUX,SYS_PINMUX_VP34_EN,VP34_ENABLE);
            break;

        case PAL_SYS_PINMUX_TIMER:
            CSL_FINST(sysRegs->PINMUX,SYS_PINMUX_TIMER_EN,TIM0_TIM1_ENABLE);
            break;

        case PAL_SYS_PINMUX_MCASP:
            CSL_FINST(sysRegs->PINMUX,SYS_PINMUX_MCASP_EN,MCASP_ENABLED);
            break;

        default:
            result = PSP_E_INVAL_PARAM;
            break;
    }

    return result;
}

/*****************************************************************************
 * MISC
 *****************************************************************************/

 /**
 *  \brief Get chip vesrion info
 *
 *  It is used to chip vesrion info.
 *
 *  \param   verInfo [IN]                verInfo
 *  \return Pointer to chip info
 */
/* ARGSUSED */
char *PAL_sysGetChipVersionInfo(PAL_SysVersionInfo *verInfo)
{
    return NULL;
}
