/*******************************************************************************
**+--------------------------------------------------------------------------+**
**|                            ****                                          |**
**|                            ****                                          |**
**|                            ******o***                                    |**
**|                      ********_///_****                                   |**
**|                      ***** /_//_/ ****                                   |**
**|                       ** ** (__/ ****                                    |**
**|                           *********                                      |**
**|                            ****                                          |**
**|                            ***                                           |**
**|                                                                          |**
**|         Copyright (c) 1998-2006 Texas Instruments Incorporated           |**
**|                        ALL RIGHTS RESERVED                               |**
**|                                                                          |**
**| Permission is hereby granted to licensees of Texas Instruments           |**
**| Incorporated (TI) products to use this computer program for the sole     |**
**| purpose of implementing a licensee product based on TI products.         |**
**| No other rights to reproduce, use, or disseminate this computer          |**
**| program, whether in part or in whole, are granted.                       |**
**|                                                                          |**
**| TI makes no representation or warranties with respect to the             |**
**| performance of this computer program, and specifically disclaims         |**
**| any responsibility for any damages, special or consequential,            |**
**| connected with the use of this program.                                  |**
**|                                                                          |**
**+--------------------------------------------------------------------------+**
*******************************************************************************/

/** \file   pal_sysPciInt.h
 *  \brief  Files containing defines and structure internal to PCI driver
 *
 *  The file contains various register masks and offsets that are used in PAL
 *  SYS PCI driver
 *
 *  (C) Copyright 2006, Texas Instruments, Inc
 *
 *  \version    1.0        Rinkal Shah   Created
 *
 */

#ifndef _PAL_SYSPCIINT_H_
#define _PAL_SYSPCIINT_H_

#include <ti/sdo/pspdrivers/pal_sys/pci/pal_sysPci.h>

#ifdef CHIP_DM648
#include <ti/sdo/pspdrivers/soc/dm648/dsp/soc.h>
#endif

#ifdef CHIP_C6452
#include <ti/sdo/pspdrivers/soc/c6452/dsp/soc.h>
#endif

#ifdef CHIP_DM6437
#include <ti/sdo/pspdrivers/soc/dm6437/dsp/soc.h>
#endif

#ifdef CHIP_C6424
#include <ti/sdo/pspdrivers/soc/c6424/dsp/soc.h>
#endif

#ifdef __cplusplus
extern "C" {
#endif

/**
 * PCI event enable mask
 */
#if defined(CHIP_DM648) || defined (CHIP_C6452)
#define     CSL_PCI_INT_ENABLE_MASK         (HWI_EVT01_CMB_IRQ)
#endif

#if defined(CHIP_DM6437) || defined (CHIP_C6424)
#define     CSL_PCI_INT_ENABLE_MASK         (HWI_EVT02_CMB_IRQ)
#endif
/**
 * \defgroup pciIntSetClearMask
 *
 * PCI interrupts set masks
 *
 * @{
 */

/**
 * Mask to enable Target abort interrupt of Host
 */
#define PCI_HOST_INT_SET_CLEAR_MASK_TGT_ABORT           (0x00000002u)
/**
 * Mask to enable Master abort interrupt of Host
 */
#define PCI_HOST_INT_SET_CLEAR_MASK_MS_ABORT            (0x00000004u)
/**
 * Mask to enable system error detect interrupt of Host
 */
#define PCI_HOST_INT_SET_CLEAR_MASK_SYS_ERR_DETECT      (0x00000020u)
/**
 * Mask to enable parity error detect interrupt of Host
 */
#define PCI_HOST_INT_SET_CLEAR_MASK_PARITY_ERR_DETECT   (0x00000040u)
/**
 * Mask to enable Software interrupt 0 of Host
 */
#define PCI_HOST_INT_SET_CLEAR_MASK_SOFTINT0            (0x01000000u)
/**
 * Mask to enable Software interrupt 1 of Host
 */
#define PCI_HOST_INT_SET_CLEAR_MASK_SOFTINT1            (0x02000000u)
/**
 * Mask to enable Software interrupt 2 of Host
 */
#define PCI_HOST_INT_SET_CLEAR_MASK_SOFTINT2            (0x04000000u)
/**
 * Mask to enable Software interrupt 3 of Host
 */
#define PCI_HOST_INT_SET_CLEAR_MASK_SOFTINT3            (0x08000000u)

/**
 * Mask to enable target abort error interrupt of backend applicaiton
 */
#define PCI_DSP_INT_SET_CLEAR_MASK_TGT_ABORT            (0x00000002u)
/**
 * Mask to enable master abort error interrupt of backend applicaiton
 */
#define PCI_DSP_INT_SET_CLEAR_MASK_MS_ABORT             (0x00000004u)
/**
 * Mask to enable system error detect interrupt of backend applicaiton
 */
#define PCI_DSP_INT_SET_CLEAR_MASK_SYS_ERR_DETECT       (0x00000020u)
/**
 * Mask to enable parity error detect interrupt of backend applicaiton
 */
#define PCI_DSP_INT_SET_CLEAR_MASK_PARITY_ERR_DETECT    (0x00000040u)
/**
 * Mask to enable Software interrupt 0 of backend applicaiton
 */
#define PCI_DSP_INT_SET_CLEAR_MASK_SOFTINT0             (0x01000000u)
/**
 * Mask to enable Software interrupt 1 of backend applicaiton
 */
#define PCI_DSP_INT_SET_CLEAR_MASK_SOFTINT1             (0x02000000u)
/**
 * Mask to enable Software interrupt 2 of backend applicaiton
 */
#define PCI_DSP_INT_SET_CLEAR_MASK_SOFTINT2             (0x04000000u)
/**
 * Mask to enable Software interrupt 3 of backend applicaiton
 */
#define PCI_DSP_INT_SET_CLEAR_MASK_SOFTINT3             (0x08000000u)




/* @} pciIntSetClearMask */


#define     PCI_CONFIGURE_CONFIG_SPACE_WRITE_TRANSACTION_MASK   (0xfffffffeu)
#define     PCI_CONFIGURE_CONFIG_SPACE_READ_TRANSACTION_MASK    (0x1u)
#define     PCI_CONFIGURE_CONFIG_SPACE_TRANSACTION_MASK         (0xfffffffbu)
#define     PCI_CONFIGURE_IO_TRANSACTION_MASK                   (0x4u)
#define     PCI_CONFIGURE_CONFIG_SPACE_BYTE_ENABLE_MASK         (0xffffff0fu)
#define     PCI_CONFIGURE_CONFIG_SPACE_DWORD_TRANSACTION_MASK   (0x40u)
#define     PCI_BASE_ENABLE_MASK                                (0x0008u)


/*
 * Enum containing various states of the driver
 */
typedef enum {
    /** Object deleted */
    PCI_DELETED   = 0u,
    /** Obect Created */
    PCI_CREATED   = 1u,
    /** Object Opened */
    PCI_OPENED    = 2u,
    /** Object Closed */
    PCI_CLOSED    = 3u
} pciObjState;

/**
 * \brief PCI driver instance object
 *
 * Structure that will store the details of PCI driver instance
 */
typedef struct _pciInstanceObject
{
    /** State of driver */
    pciObjState state;
    /** Configuration parameters passed by application while opening driver */
    PAL_sysPciInitConfig cfgParams;
    /** Semaphore to protect multiple access of back end configuration space */
    PAL_OsSemHandle        pciSpaceAccessLock;
    /** pointer to base address of backend registers of local PCI controller */
    volatile Uint32     *pciBaseAddr;
}pciInstanceObject, *pciInstanceHandle;

#ifdef __cplusplus
}
#endif

#endif /*_PAL_SYSPCIINT_H_*/
