/*******************************************************************************
**+--------------------------------------------------------------------------+**
**|                            ****                                          |**
**|                            ****                                          |**
**|                            ******o***                                    |**
**|                      ********_///_****                                   |**
**|                      ***** /_//_/ ****                                   |**
**|                       ** ** (__/ ****                                    |**
**|                           *********                                      |**
**|                            ****                                          |**
**|                            ***                                           |**
**|                                                                          |**
**|         Copyright (c) 1998-2006 Texas Instruments Incorporated           |**
**|                        ALL RIGHTS RESERVED                               |**
**|                                                                          |**
**| Permission is hereby granted to licensees of Texas Instruments           |**
**| Incorporated (TI) products to use this computer program for the sole     |**
**| purpose of implementing a licensee product based on TI products.         |**
**| No other rights to reproduce, use, or disseminate this computer          |**
**| program, whether in part or in whole, are granted.                       |**
**|                                                                          |**
**| TI makes no representation or warranties with respect to the             |**
**| performance of this computer program, and specifically disclaims         |**
**| any responsibility for any damages, special or consequential,            |**
**| connected with the use of this program.                                  |**
**|                                                                          |**
**+--------------------------------------------------------------------------+**
*******************************************************************************/

/**   \file    pal_sysvlynqDev.h
 *
 *    \brief   This file contains the header for device API's which are connected with VLYNQ.
 *
 *    (C)      Copyright 2006,    Texas Instruments, Inc
 *
 *    \author        PSG
 *
 *    \version      0.1     Suraj      Created
 *                  0.2     PSP Team - Modified for DM6437
 *
 */


#ifndef _PAL_SYSVLYNQDEV_H
#define _PAL_SYSVLYNQDEV_H

#include <ti/sdo/pspdrivers/pal_sys/vlynq/pal_sysvlynq.h>
#include <ti/sdo/pspdrivers/common/psp_common.h>

#ifdef __cplusplus
extern "C" {
#endif

/** Callback function prototype.*/
typedef Int32 (*PAL_VLYNQ_DEV_CB_FN)(void *this_driver , Uint32 condition, Uint32 value);


/**
 *  \fn     PAL_Result PAL_sysVlynqDevCbRegister (PAL_VLYNQ_DEV_HND *vlynq_dev,
 *                                                  PAL_VLYNQ_DEV_CB_FN cb_fn,
 *                                                  void *this_driver);
 *
 *  \brief This function Register for the callbacks.
 *
 *  \param  vlynq_dev_cb    [IN]    The handle to remote device instance
 *  \param  cb_fn           [IN]    The callback function that is be called by
 *                                  implementation for local error, or remote
 *                                  error update conditions.
 *  \param  this_driver     [IN]    The driver instance, which is registering
 *                                  for the callbacks
 *
 *  \return If successful, returns 0
 *          If failed, returns negative number
 */
PAL_Result PAL_sysVlynqDevCbRegister( PAL_VLYNQ_DEV_HND *vlynq_dev_cb,
        PAL_VLYNQ_DEV_CB_FN cb_fn,
        void *this_driver);


/**
 *  \fn PAL_Result PAL_sysVlynqDevCbUnregister (PAL_VLYNQ_DEV_HND *vlynq_dev,
 *                                              void *this_driver);
 *
 *  \brief This function Unregister the callbacks.
 *
 *
 *  \param  vlynq_dev_uncb  [IN]    The handle to remote device instance
 *  \param  this_driver     [IN]    The driver instance, which is registering
 *                                  for the callbacks
 *
 *  \return If successful, returns 0
 *          If failed, returns negative number
 */
PAL_Result PAL_sysVlynqDevCbUnregister( PAL_VLYNQ_DEV_HND *vlynq_dev_uncb,
        void  *this_driver);

/**
 *  \fn     PAL_VLYNQ_DEV_HND *PAL_sysVlynqDevFind (const char *name, Uint8 instance);
 *  \brief  This function finds the required device from vlynq chain
 *
 *  \param  name         [IN]    The name of the device whose information is
 *                               being sought. This should same as that used
 *                               in the PAL_sysVlynqDevCreate( ).
 *  \param  instance     [IN]    The instance of the remote device.This should
 *                               same as that used in the PAL_sysVlynqDevCreate( ).
 *
 *  \return NULL, if no device could be found or a valid handle.
 */
PAL_VLYNQ_DEV_HND *PAL_sysVlynqDevFind(const char *name, Uint8 instance);

/**
 *  \fn     PAL_VLYNQ_HND *PAL_sysVlynqDevGetVlynq( PAL_VLYNQ_DEV_HND *vlynq_dev);
 *  \brief  This function Get the VLYNQ device and handle for this device handle.
 *
 *
 *  \param  vlynq_dev_get [IN]   The device whose associated VLYNQ control
 *                              module is being sought
 *
 *  \return NULL on error or a valid VLYNQ handle
 */
PAL_VLYNQ_HND *PAL_sysVlynqDevGetVlynq( PAL_VLYNQ_DEV_HND *vlynq_dev_get);



/**
 *  \fn     PAL_Result PAL_sysVlynqDevFindIrq( PAL_VLYNQ_DEV_HND *vlynq_dev_irq,
 *                                          Uint8 *irq, Uint32 num_irq);
 *
 *  \brief  This function Get the mapped interrupts of the device.
 *
 *  \param  vlynq_dev_irq   [IN]  The handle to remote device instance
 *  \param  irq             [IN]  The placeholder for the identifiers of the IRQ(s)
 *                                vectors in the perspective of the chain
 *  \param  num_irq         [IN]  The number of interrupts to be read
 *
 *  \return If successful, returns 0
 *          If failed, returns negative number
 */
PAL_Result PAL_sysVlynqDevFindIrq( PAL_VLYNQ_DEV_HND *vlynq_dev_irq,
            Uint8 *irq,
            Uint32 num_irq);

/**
 *  \fn     PAL_Result PAL_sysVlynqDevGetResetBit( PAL_VLYNQ_DEV_HND *vlynq_dev,
 *                                                  Uint32 *reset_bit);
 *
 *  \brief  This function Get the reset bit of the device..
 *
 *  \param  vlynq_dev_bit   [IN]  The handle to remote device instance
 *  \param  reset_bit       [IN]  The placeholder for the identifiers of reset bit.
 *                                Only for on board remote devices for which hardware
 *                                reset provisions have been made.
 *
 *  \return If successful, returns 0
 *          If failed, returns negative number
 */
PAL_Result PAL_sysVlynqDevGetResetBit( PAL_VLYNQ_DEV_HND *vlynq_dev_bit,
            Uint32 *reset_bit);

/**
 *  \fn     PAL_VLYNQ_DEV_HND *PAL_sysVlynqDevCreate(PAL_VLYNQ_HND *vlynq,
 *              const char *name,Uint32 instance, Int32 reset_bit,Bool peer);
 *
 *  \brief This function Creates a device reference.
 *
 *  \param  vlynq     [IN]  The VLYNQ module instance to which a device has to be added
 *  \param  name      [IN]  Name of the device; shall not exceed 30 characters
 *                          and shall be NULL terminated
 *  \param  instance  [IN]  The instance of the device; it is 0 based.
 *  \param  reset_bit [IN]  The reset bit for the VLYNQ device in the
 *                          perspective of the system
 *  \param  peer      [IN]  Identifies whether the device is connected to the
 *                          local or peer VLYNQ module.
 *
 *  \return On failure, returns NULL otherwise,
 *            returns a valid handle to the device instance.
 */
PAL_VLYNQ_DEV_HND *PAL_sysVlynqDevCreate(PAL_VLYNQ_HND *vlynq, const char *name,
                    Uint32 instance, Int32 reset_bit,
                    Bool peer);

/**
 *  \fn     PAL_Result PAL_sysVlynqDevDestroy( PAL_VLYNQ_DEV_HND *vlynq_dev)
 *  \brief  This function Destroys the device reference
 *
 *  \param  vlynq_dev_destroy [IN]  The vlynq device handle to be destroyed
 *
 *  \return If successful, returns 0
 *          If failed, returns negative number
 */
PAL_Result PAL_sysVlynqDevDestroy( PAL_VLYNQ_DEV_HND *vlynq_dev_destroy);


/* Protected API(s) to be used only by pal_sysvlynq.c */
PAL_Result pal_vlynq_dev_init(void);


/*
 *  This will be called by the Local and Peer error ISR.
 *  This will call the application callback
 *  (Protected API to be used only by pal_sysvlynq.c)
 *  Input:
 *    vlynq_dev_event   [IN]    The handle device instance; would have
 *                              been returned by PAL_sysVlynqDevFind( ).
 *    cmd               [IN]    Input command parameter to the callback function
 *    val               [IN]    Input value parameter to the callback function
 *   Return:
 *   If successful, returns PAL_VLYNQ_OK
 *   If failed, returns error code
 */
PAL_Result pal_vlynq_dev_handle_event( PAL_VLYNQ_DEV_HND *vlynq_dev_event,
        Uint32 cmd, Uint32 val);


/**
 *  \brief This IOCTL is for adding and removing IRQ information from device
 *
 *  \param  vlynq_dev_ioctl [IN]  The VLYNQ device instance which would have been returned
 *  \param  cmd             [IN]  The command which is to be processed
 *  \param  cmd_val         [IN]  The value of the command to be executed
 *  \return If successful, returns 0
 *          If failed, returns error code
 */
PAL_Result pal_vlynq_dev_ioctl( PAL_VLYNQ_DEV_HND *vlynq_dev_ioctl, Uint32 cmd,
        Uint32 cmd_val);

#ifdef __cplusplus
}
#endif

#endif
