/*******************************************************************************
**+--------------------------------------------------------------------------+**
**|                            ****                                          |**
**|                            ****                                          |**
**|                            ******o***                                    |**
**|                      ********_///_****                                   |**
**|                      ***** /_//_/ ****                                   |**
**|                       ** ** (__/ ****                                    |**
**|                           *********                                      |**
**|                            ****                                          |**
**|                            ***                                           |**
**|                                                                          |**
**|         Copyright (c) 1998-2006 Texas Instruments Incorporated           |**
**|                        ALL RIGHTS RESERVED                               |**
**|                                                                          |**
**| Permission is hereby granted to licensees of Texas Instruments           |**
**| Incorporated (TI) products to use this computer program for the sole     |**
**| purpose of implementing a licensee product based on TI products.         |**
**| No other rights to reproduce, use, or disseminate this computer          |**
**| program, whether in part or in whole, are granted.                       |**
**|                                                                          |**
**| TI makes no representation or warranties with respect to the             |**
**| performance of this computer program, and specifically disclaims         |**
**| any responsibility for any damages, special or consequential,            |**
**| connected with the use of this program.                                  |**
**|                                                                          |**
**+--------------------------------------------------------------------------+**
*******************************************************************************/

/**   \file    pal_sysvlynqIoctl.h
 *
 *    \brief   This file contains the parameters for IOCTL command and
 *             declaration of vlynq IOCLT API
 *
 *    (C)      Copyright 2006,    Texas Instruments, Inc
 *
 *    \author     PSG
 *    \version    0.1     Suraj                    Created
 *
 */


#ifndef _PAL_SYSVLYNQIOCTL_H
#define _PAL_SYSVLYNQIOCTL_H


#ifdef __cplusplus
extern "C" {
#endif

/*
 * The 32 bit IOCTL Command.
 * ------------------------------------------------------------------------
 * |           |          |          |       |          |      |          |
 * | 31:Bit Op | 30: R/W* | 29: Peer | 28-24 | 23-16    | 15-8 | 7-0      |
 * |           |          |          | Resv  | Major id | Resv | Minor id |
 * |           |          |          |       |          |      |          |
 * ------------------------------------------------------------------------
 *
 * The IOCTL operations have been broadly divided into two categories of o-
 * perations; Bit Op(eration) and non-Bit Op(eration).
 *
 * Bit Op(eration) means manipulation of certain bits in certain register of
 * VLYNQ control modules. The register and its contents (bits) are specified
 * by the hardware reference manual. For Bit Op=1, the major id are the re-
 * gister id(s) and the minor id(s) are the bits identified within that reg.
 *
 * Non Bit Op(eration), when Bit Op=0, means raw 32 bits accesses of certain
 * VLYNQ register or any other operation as specified in the implementation.
 * For raw 32 bit accesses PAL_VLYNQ_IOCTL_REG_CMD is the major command (id)
 * and reg id(s) refer(s) to minor id(s).
 *
 * R/W*: 0 - Write, 1 - Read.
 * Peer: When, set means that operation has to be carried out on remote or
 *       peer vlynq.
 */

/*  Mask defines */
/**< Bit Op(eration)                                */
#define PAL_VLYNQ_IOCTL_BIT_CMD            (1 << 31u)
/**< Read or Write regoster or register bits        */
#define PAL_VLYNQ_IOCTL_READ_CMD           (1 << 30u)
/**< Remote or Local bit                            */
#define PAL_VLYNQ_IOCTL_REMOTE_CMD         (1 << 29u)

/**< set Major command value                        */
#define PAL_VLYNQ_IOCTL_MAJOR_VAL(val)     (((val) & 0xffu) << 16u)
/**< get Major command value                        */
#define PAL_VLYNQ_IOCTL_MAJOR_DE_VAL(cmd)  (((cmd) >> 16) & 0xffu)

/**< set Major command value                        */
#define PAL_VLYNQ_IOCTL_MINOR_VAL(val)     ((val) & 0xffu)
/**< get Major command value                        */
#define PAL_VLYNQ_IOCTL_MINOR_DE_VAL(cmd)  ((cmd) & 0xffu)

/**< Major commands; if bit operation is not selected */

/**< Vlynq register access. */
#define PAL_VLYNQ_IOCTL_REG_CMD            (0x00u)
/**< Prepare to teardown the link. */
#define PAL_VLYNQ_IOCTL_PREP_LINK_DOWN     (0x01u)
/**< Setup vlynq, now the link is up. */
#define PAL_VLYNQ_IOCTL_PREP_LINK_UP       (0x02u)
/**< Clear internal interrupt errors. */
#define PAL_VLYNQ_IOCTL_CLEAR_INTERN_ERR   (0x03u)

/**< Control Register bits. The minor id(s) for control reg */
/**< Control register RESET command */
#define PAL_VLYNQ_IOCTL_CNT_RESET_CMD      (0x00u)
/**< Control register ILOOP command */
#define PAL_VLYNQ_IOCTL_CNT_ILOOP_CMD      (0x01u)
/**< Control register AOPT command :  Write */
#define PAL_VLYNQ_IOCTL_CNT_AOPT_CMD       (0x02u)
/**< Control register INT2CFG command */
#define PAL_VLYNQ_IOCTL_CNT_INT2CFG_CMD    (0x07u)
/**< Control register INTVEC command */
#define PAL_VLYNQ_IOCTL_CNT_INTVEC_CMD     (0x08u)
/**< Control register INT_EN command */
#define PAL_VLYNQ_IOCTL_CNT_INT_EN_CMD     (0x0du)
/**< Control register INT_LOC command */
#define PAL_VLYNQ_IOCTL_CNT_INT_LOC_CMD    (0x0eu)
/**< Control register CLK_DIR command */
#define PAL_VLYNQ_IOCTL_CNT_CLK_DIR_CMD    (0x0fu)
/**< Control register CLK_DIV command : Write */
#define PAL_VLYNQ_IOCTL_CNT_CLK_DIV_CMD    (0x10u)
/**< Control register CLK_MOD command */
#define PAL_VLYNQ_IOCTL_CNT_CLK_MOD_CMD    (0x15u)
/**< Control register TX_FAST command */
#define PAL_VLYNQ_IOCTL_CNT_TX_FAST_CMD    (0x15u)
/**< Control register RTM_SELECT command */
#define PAL_VLYNQ_IOCTL_CNT_RTM_SELECT_CMD (0x16u)
/**< Control register RTM_SAMPLE command */
#define PAL_VLYNQ_IOCTL_CNT_RTM_VALIDWR_CMD (0x17u)
/**< Control register RTM_SAMPLE command */
#define PAL_VLYNQ_IOCTL_CNT_RTM_SAMPLE_CMD (0x18u)
/**< Control register SLKPU command : Write */
#define PAL_VLYNQ_IOCTL_CNT_CLK_SLKPU_CMD  (0x1eu)
/**< Control register PMEM command  : Write */
#define PAL_VLYNQ_IOCTL_CNT_PMEM_CMD       (0x1fu)

/**< Status register bits. The minor id(s) for status reg */
/**< Status register LINK bit in status register */
#define PAL_VLYNQ_IOCTL_STS_LINK           (0x00u)
/**< Status register MPEND bit in status register */
#define PAL_VLYNQ_IOCTL_STS_MPEND          (0x01u)
/**< Status register SPEND bit in status register */
#define PAL_VLYNQ_IOCTL_STS_SPEND          (0x02u)
/**< Status register NFEMP0 bit in status register */
#define PAL_VLYNQ_IOCTL_STS_NFEMP0         (0x03u)
/**< Status register NFEMP1 bit in status register */
#define PAL_VLYNQ_IOCTL_STS_NFEMP1         (0x04u)
/**< Status register NFEMP2 bit in status register */
#define PAL_VLYNQ_IOCTL_STS_NFEMP2         (0x05u)
/**< Status register NFEMP3 bit in status register */
#define PAL_VLYNQ_IOCTL_STS_NFEMP3         (0x06u)
/**< Status register LERR bit in status register */
#define PAL_VLYNQ_IOCTL_STS_LERR           (0x07u)
/**< Status register RERR bit in status register */
#define PAL_VLYNQ_IOCTL_STS_RERR           (0x08u)
/**< Status register OFLOW bit in status register */
#define PAL_VLYNQ_IOCTL_STS_OFLOW          (0x09u)
/**< Status register IFLOW bit in status register */
#define PAL_VLYNQ_IOCTL_STS_IFLOW          (0x0Au)
/**< Status register RTM bit in status register */
#define PAL_VLYNQ_IOCTL_STS_RTM            (0x0Bu)
/**< Status register RTM_VAL bit in status register */
#define PAL_VLYNQ_IOCTL_STS_RTM_VAL        (0x0Cu)
/**< Status register SWIDOUT bit in status register */
#define PAL_VLYNQ_IOCTL_STS_SWIDOUT        (0x14u)
/**< Status register MODESUP bit in status register */
#define PAL_VLYNQ_IOCTL_STS_MODESUP        (0x15u)
/**< Status register SWIDIN bit in status register */
#define PAL_VLYNQ_IOCTL_STS_SWIDIN         (0x18u)
/**< Status register SWIDTH bit in status register */
#define PAL_VLYNQ_IOCTL_STS_SWIDTH         (0x18u)
/**< Status register DEBUG bit in status register */
#define PAL_VLYNQ_IOCTL_STS_DEBUG          (0x1du)


/**< The VLYNQ registers; the reg id(s).
 *
 *      For non Bit operations, these defines are minor id(s) for the raw
 * 32 bit access done using the major cmd PAL_VLYNQ_IOCTL_REG_CMD.
 *
 * For bit operations, these defines are the major id(s) and identify the
 * register whose bits have to be manipulated.
 *
 */

/**< Vlynq REVSION_REG register */
#define PAL_VLYNQ_IOCTL_REVSION_REG        (0x00)
/**< Vlynq CONTROL_REG register */
#define PAL_VLYNQ_IOCTL_CONTROL_REG        (0x04)
/**< Vlynq STATUS_REG register */
#define PAL_VLYNQ_IOCTL_STATUS_REG         (0x08)
/**< Vlynq INT_PRIR_REG register */
#define PAL_VLYNQ_IOCTL_INT_PRIR_REG       (0x0c)
/**< Vlynq INT_STS_REG register */
#define PAL_VLYNQ_IOCTL_INT_STS_REG        (0x10)
/**< Vlynq INT_PEND_REG register */
#define PAL_VLYNQ_IOCTL_INT_PEND_REG       (0x14)
/**< Vlynq INT_PTR_REG register */
#define PAL_VLYNQ_IOCTL_INT_PTR_REG        (0x18)
/**< Vlynq TX_MAP_REG register */
#define PAL_VLYNQ_IOCTL_TX_MAP_REG         (0x1c)
/**< Vlynq RX1_SZ_REG register */
#define PAL_VLYNQ_IOCTL_RX1_SZ_REG         (0x20)
/**< Vlynq RX1_OFF_REG register */
#define PAL_VLYNQ_IOCTL_RX1_OFF_REG        (0x24)
/**< Vlynq RX2_SZ_REG register */
#define PAL_VLYNQ_IOCTL_RX2_SZ_REG         (0x28)
/**< Vlynq RX2_OFF_REG register */
#define PAL_VLYNQ_IOCTL_RX2_OFF_REG        (0x2c)
/**< Vlynq RX3_SZ_REG register */
#define PAL_VLYNQ_IOCTL_RX3_SZ_REG         (0x30)
/**< Vlynq RX3_OFF_REG register */
#define PAL_VLYNQ_IOCTL_RX3_OFF_REG        (0x34)
/**< Vlynq RX4_SZ_REG register */
#define PAL_VLYNQ_IOCTL_RX4_SZ_REG         (0x38)
/**< Vlynq RX4_OFF_REG register */
#define PAL_VLYNQ_IOCTL_RX4_OFF_REG        (0x3c)
/**< Vlynq  register */
#define PAL_VLYNQ_IOCTL_CVR_REG            (0x40)
/**< Vlynq CVR_REG register */
#define PAL_VLYNQ_IOCTL_AUTO_NEG_REG       (0x44)
/**< Vlynq MAN_NEG_REG  register */
#define PAL_VLYNQ_IOCTL_MAN_NEG_REG        (0x48)
/**< Vlynq NEG_STS_REG register */
#define PAL_VLYNQ_IOCTL_NEG_STS_REG        (0x4c)
/**< Vlynq ENDIAN_REG register */
#define PAL_VLYNQ_IOCTL_ENDIAN_REG         (0x4c)
/**< Vlynq IVR30_REG register */
#define PAL_VLYNQ_IOCTL_IVR30_REG          (0x60)
/**< Vlynq IVR74_REG register */
#define PAL_VLYNQ_IOCTL_IVR74_REG          (0x64)

/**<  Dumping options, they are not part of ioctl options.
   * But are for the Dump API */

/**< Vlynq dump all at starting address 0x10000 */
#define PAL_VLYNQ_DUMP_ALL_ROOT         (0x10000u)
/**< Vlynq dump raw data */
#define PAL_VLYNQ_DUMP_RAW_DATA         (0x20000u)
/**< Vlynq dump all registers at starting address 0x30000 */
#define PAL_VLYNQ_DUMP_ALL_REGS         (0x30000u)
/**< Vlynq status register offset */
#define PAL_VLYNQ_DUMP_STS_REG          (0x00008u)
/**< Vlynq control register offset */
#define PAL_VLYNQ_DUMP_CNTL_REG         (0x00004u)


/**
  * \fn  PAL_Result vlynq_read_write_ioctl(volatile Uint32 *p_start_reg, Uint32 cmd, Uint32 *pVal, Uint32 vlynq_rev)
  *
  * \brief  Read or write to status or command registers.
  *
  * \param  p_start_reg [IN]    Handle to access the vlynq param
  * \param  cmd         [IN]    Command to do operation
  * \param  pVal        [IN]    Value which is to be passed to do operation
  * \param vlynq_rev    [IN]    Vlynq revision number
  *
  * \return                        Success or error code
  */

PAL_Result vlynq_read_write_ioctl(volatile Uint32 *p_start_reg, Uint32 cmd,
                                  Uint32 *pVal, Uint32 vlynq_rev);
/**
 * \fn       Int32 vlynq_dump_ioctl(volatile Uint32 *start_reg, Uint32 dump_type, char *buf,Int32 limit, Uint32 vlynq_rev)
 *
 * \brief    Dump the command register or status register values from start
             register to the length.
 *
 * \param    start_reg    [IN]    Start of the command register.
 * \param    dump_type    [IN]    Select status or command registers.
 * \param    buf          [IN]    Address where to dump registers.
 * \param    limit        [IN]    Number of registers to be dumped.
 * \param    vlynq_rev    [IN]    Revision of the vlynq module.
 *
 * \return                        len of type Int32
 */
Int32 vlynq_dump_ioctl(volatile Uint32 *start_reg, Uint32 dump_type, char *buf,
        Int32 limit, Uint32 vlynq_rev);

#ifdef __cplusplus
}
#endif

#endif
