/*******************************************************************************
**+--------------------------------------------------------------------------+**
**|                            ****                                          |**
**|                            ****                                          |**
**|                            ******o***                                    |**
**|                      ********_///_****                                   |**
**|                      ***** /_//_/ ****                                   |**
**|                       ** ** (__/ ****                                    |**
**|                           *********                                      |**
**|                            ****                                          |**
**|                            ***                                           |**
**|                                                                          |**
**|         Copyright (c) 1998-2006 Texas Instruments Incorporated           |**
**|                        ALL RIGHTS RESERVED                               |**
**|                                                                          |**
**| Permission is hereby granted to licensees of Texas Instruments           |**
**| Incorporated (TI) products to use this computer program for the sole     |**
**| purpose of implementing a licensee product based on TI products.         |**
**| No other rights to reproduce, use, or disseminate this computer          |**
**| program, whether in part or in whole, are granted.                       |**
**|                                                                          |**
**| TI makes no representation or warranties with respect to the             |**
**| performance of this computer program, and specifically disclaims         |**
**| any responsibility for any damages, special or consequential,            |**
**| connected with the use of this program.                                  |**
**|                                                                          |**
**+--------------------------------------------------------------------------+**
*******************************************************************************/

/** \file   pal_sysvlynqIoctl.c
 *
 *  \brief  This file contains the device IOCTL API's for the device.
 *
 *  (C) Copyright 2006, Texas Instruments, Inc
 *
 *  \author     Suraj
 *  \version    0.3
 *
 */

#include <ti/sdo/pspdrivers/pal_sys/vlynq/pal_sysvlynq.h>
#include <ti/sdo/pspdrivers/pal_sys/vlynq/pal_sysvlynqIoctl.h>

/**< Is used to flag bit is write enabled of protected.*/
#define IOCTL_WR         0x01u

/**
 * \brief Vlynq Configuration register structure.
 *
 *        Used to hold the information like Register ID,offset of a bit, name of the bit,
 *        mask for that register, revision and whether it is writable or only readable.
 */
typedef struct pal_vlynq_ioctl_info
{

    Int16         id;
    /**< The ID of the register      */
    Uint16        offset;
    /**< Register offset or bit offset      */
    const Char    *name;
    /**< Name of the register or register bit.     */
    Uint32        mask;
    /**< Mask for the register or register bit.     */
    Uint32        start_revision;
     /**<  Start revision of the register.     */
    Uint32        end_revision;
     /**<  End revision of the register.     */
    Uint8         access_flags;
    /**< 0x01 - write, otherwise read, can be enhanced later.     */
} PAL_VLYNQ_IOCTL_INFO_T;

/**
 * Static Array of control bits as per the vlynq 2.0 and greater specfication.
 * It is been initialized with the ID'd and there corresponding bit's as per the
 * revision.
 */
static PAL_VLYNQ_IOCTL_INFO_T control_reg_ioctl[ ] = {

    { PAL_VLYNQ_IOCTL_CNT_RESET_CMD,       0, "reset"        ,  0x00000001u, VLYNQ_REV_10200, LATEST_VLYNQ_REV, IOCTL_WR },
    { PAL_VLYNQ_IOCTL_CNT_ILOOP_CMD,       1u, "iloop"       ,  0x00000002u, VLYNQ_REV_10100, LATEST_VLYNQ_REV, 0        },
    { PAL_VLYNQ_IOCTL_CNT_AOPT_CMD,        2u, "aopt disable" , 0x00000004u, VLYNQ_REV_10200, LATEST_VLYNQ_REV, IOCTL_WR },
    { PAL_VLYNQ_IOCTL_CNT_INT2CFG_CMD,     7u, "int2cfg"      , 0x00000080u, VLYNQ_REV_10100, LATEST_VLYNQ_REV, IOCTL_WR },
    { PAL_VLYNQ_IOCTL_CNT_INTVEC_CMD,      8u, "intvec"       , 0x00001f00u, VLYNQ_REV_10100, LATEST_VLYNQ_REV, 0        },
    { PAL_VLYNQ_IOCTL_CNT_INT_EN_CMD,     13u, "intenable"    , 0x00002000u, VLYNQ_REV_10100, LATEST_VLYNQ_REV, IOCTL_WR },
    { PAL_VLYNQ_IOCTL_CNT_INT_LOC_CMD,    14u, "intlocal"     , 0x00004000u, VLYNQ_REV_10100, LATEST_VLYNQ_REV, IOCTL_WR },
    { PAL_VLYNQ_IOCTL_CNT_CLK_DIR_CMD,    15u, "clkdir"       , 0x00008000u, VLYNQ_REV_10100, LATEST_VLYNQ_REV, 0        },
    { PAL_VLYNQ_IOCTL_CNT_CLK_DIV_CMD,    16u, "clkdiv"       , 0x00070000u, VLYNQ_REV_10100, LATEST_VLYNQ_REV, IOCTL_WR },
    { PAL_VLYNQ_IOCTL_CNT_CLK_MOD_CMD,    21u, "mode"         , 0x00e00000u, VLYNQ_REV_10100, VLYNQ_REV_101ff , 0        },
    { PAL_VLYNQ_IOCTL_CNT_TX_FAST_CMD,    21u, "txfastpath"   , 0x00200000u, VLYNQ_REV_10205, LATEST_VLYNQ_REV, IOCTL_WR },
    { PAL_VLYNQ_IOCTL_CNT_RTM_SELECT_CMD, 22u, "rtmenable"    , 0x00400000u, VLYNQ_REV_10205, LATEST_VLYNQ_REV, 0        },
    { PAL_VLYNQ_IOCTL_CNT_RTM_VALIDWR_CMD,23u, "wr-rtmval"    , 0x00800000u, VLYNQ_REV_10205, LATEST_VLYNQ_REV, IOCTL_WR },
    { PAL_VLYNQ_IOCTL_CNT_RTM_SAMPLE_CMD, 24u, "rtmsampleval" , 0x07000000u, VLYNQ_REV_10205, LATEST_VLYNQ_REV, IOCTL_WR },
    { PAL_VLYNQ_IOCTL_CNT_CLK_SLKPU_CMD,  30u, "slkpudis"     , 0x40000000u, VLYNQ_REV_10204, LATEST_VLYNQ_REV, IOCTL_WR },
    { PAL_VLYNQ_IOCTL_CNT_PMEM_CMD,       31u, "pmem"         , 0x80000000u, VLYNQ_REV_10200, LATEST_VLYNQ_REV, IOCTL_WR },
    {  -1,                                32u, "dead end"     , 0xdeadfeedu, 0x00000000u, 0xdeadfeedu      , 0        }

};

/**
 * Static Array of status bits as per the vlynq specfication.It is been
 * initialized with the ID'd and there corresponding bit's as per the revision.
 */
static PAL_VLYNQ_IOCTL_INFO_T status_reg_ioctl[ ] = {

    { PAL_VLYNQ_IOCTL_STS_LINK,     0u, "link"         , 0x00000001u, VLYNQ_REV_10100, LATEST_VLYNQ_REV, 0 },
    { PAL_VLYNQ_IOCTL_STS_MPEND,    1u, "mpend"        , 0x00000002u, VLYNQ_REV_10100, LATEST_VLYNQ_REV, 0 },
    { PAL_VLYNQ_IOCTL_STS_SPEND,    2u, "spend"        , 0x00000004u, VLYNQ_REV_10100, LATEST_VLYNQ_REV, 0 },
    { PAL_VLYNQ_IOCTL_STS_NFEMP0,   3u, "nfempty0"     , 0x00000008u, VLYNQ_REV_10100, LATEST_VLYNQ_REV, 0 },
    { PAL_VLYNQ_IOCTL_STS_NFEMP1,   4u, "nfempty1"     , 0x00000010u, VLYNQ_REV_10100, LATEST_VLYNQ_REV, 0 },
    { PAL_VLYNQ_IOCTL_STS_NFEMP2,   5u, "nfempty2"     , 0x00000020u, VLYNQ_REV_10100, LATEST_VLYNQ_REV, 0 },
    { PAL_VLYNQ_IOCTL_STS_NFEMP3,   6u, "nfempty3"     , 0x00000040u, VLYNQ_REV_10100, LATEST_VLYNQ_REV, 0 },
    { PAL_VLYNQ_IOCTL_STS_LERR,     7u, "lerror"       , 0x00000080u, VLYNQ_REV_10100, LATEST_VLYNQ_REV, 0 },
    { PAL_VLYNQ_IOCTL_STS_RERR,     8u, "rerror"       , 0x00000100u, VLYNQ_REV_10100, LATEST_VLYNQ_REV, 0 },
    { PAL_VLYNQ_IOCTL_STS_OFLOW,    9u, "oflow"        , 0x00000200u, VLYNQ_REV_10100, LATEST_VLYNQ_REV, 0 },
    { PAL_VLYNQ_IOCTL_STS_IFLOW,   10u, "iflow"        , 0x00000400u, VLYNQ_REV_10100, LATEST_VLYNQ_REV, 0 },
    { PAL_VLYNQ_IOCTL_STS_RTM,     11u, "rtm"          , 0x00000800u, VLYNQ_REV_10205, LATEST_VLYNQ_REV, 0 },
    { PAL_VLYNQ_IOCTL_STS_RTM_VAL, 12u, "rtmcurrval"   , 0x00007000u, VLYNQ_REV_10205, LATEST_VLYNQ_REV, 0 },
    { PAL_VLYNQ_IOCTL_STS_SWIDOUT, 20u, "swidthout"    , 0x00f00000u, VLYNQ_REV_10200, LATEST_VLYNQ_REV, 0 },
    { PAL_VLYNQ_IOCTL_STS_MODESUP, 21u, "modesup"      , 0x00700000u, VLYNQ_REV_10100, LATEST_VLYNQ_REV, 0 },
    { PAL_VLYNQ_IOCTL_STS_SWIDTH,  24u, "swidth"       , 0x03000000u, VLYNQ_REV_10100, VLYNQ_REV_10200 , 0 },
    { PAL_VLYNQ_IOCTL_STS_SWIDIN,  24u, "swidthin"     , 0x0f000000u, VLYNQ_REV_10200, LATEST_VLYNQ_REV, 0 },
    { PAL_VLYNQ_IOCTL_STS_DEBUG,   29u, "debug"        , 0x70000000u, VLYNQ_REV_10100, 0x000101ffu      , 0 },
    {  -1,                         32u, "dead end"     , 0xdeadfeedu, 0x00000000u, 0xdeadfeedu      , 0 }

};
/**
 * Static Array of control registers as per the vlynq 2.0 and greater specfication.
 * It is been initialized with the ID'd and there corresponding bit's as per the
 * revision.
 */
static PAL_VLYNQ_IOCTL_INFO_T vlynq_reg32_ioctl[ ] = {

    { PAL_VLYNQ_IOCTL_REVSION_REG,  0x00u, "revision"     , 0xffffffffu, VLYNQ_REV_10100, LATEST_VLYNQ_REV, 0        },
    { PAL_VLYNQ_IOCTL_CONTROL_REG,  0x04u, "control"      , 0xffffffffu, VLYNQ_REV_10100, LATEST_VLYNQ_REV, 0        },
    { PAL_VLYNQ_IOCTL_STATUS_REG,   0x08u, "status"       , 0xffffffffu, VLYNQ_REV_10100, LATEST_VLYNQ_REV, 0        },
    { PAL_VLYNQ_IOCTL_INT_PRIR_REG, 0x0cu, "intPriority"  , 0xffffffffu, VLYNQ_REV_10200, LATEST_VLYNQ_REV, 0        },
    { PAL_VLYNQ_IOCTL_INT_STS_REG,  0x10u, "intStatus"    , 0xffffffffu, VLYNQ_REV_10100, LATEST_VLYNQ_REV, 0        },
    { PAL_VLYNQ_IOCTL_INT_PEND_REG, 0x14u, "intPending"   , 0xffffffffu, VLYNQ_REV_10100, LATEST_VLYNQ_REV, 0        },
    { PAL_VLYNQ_IOCTL_INT_PTR_REG,  0x18u, "intPtr"       , 0xffffffffu, VLYNQ_REV_10100, LATEST_VLYNQ_REV, IOCTL_WR },
    { PAL_VLYNQ_IOCTL_TX_MAP_REG,   0x1cu, "txMap"        , 0xffffffffu, VLYNQ_REV_10100, LATEST_VLYNQ_REV, 0        },
    { PAL_VLYNQ_IOCTL_RX1_SZ_REG,   0x20u, "rxSize1"      , 0xffffffffu, VLYNQ_REV_10100, LATEST_VLYNQ_REV, 0        },
    { PAL_VLYNQ_IOCTL_RX1_OFF_REG,  0x24u, "rxoffset1"    , 0xffffffffu, VLYNQ_REV_10100, LATEST_VLYNQ_REV, 0        },
    { PAL_VLYNQ_IOCTL_RX2_SZ_REG,   0x28u, "rxSize2"      , 0xffffffffu, VLYNQ_REV_10100, LATEST_VLYNQ_REV, 0        },
    { PAL_VLYNQ_IOCTL_RX2_OFF_REG,  0x2cu, "rxoffset2"    , 0xffffffffu, VLYNQ_REV_10100, LATEST_VLYNQ_REV, 0        },
    { PAL_VLYNQ_IOCTL_RX3_SZ_REG,   0x30u, "rxSize3"      , 0xffffffffu, VLYNQ_REV_10100, LATEST_VLYNQ_REV, 0        },
    { PAL_VLYNQ_IOCTL_RX3_OFF_REG,  0x34u, "rxoffset3"    , 0xffffffffu, VLYNQ_REV_10100, LATEST_VLYNQ_REV, 0        },
    { PAL_VLYNQ_IOCTL_RX4_SZ_REG,   0x38u, "rxSize4"      , 0xffffffffu, VLYNQ_REV_10100, LATEST_VLYNQ_REV, 0        },
    { PAL_VLYNQ_IOCTL_RX4_OFF_REG,  0x3cu, "rxoffset4"    , 0xffffffffu, VLYNQ_REV_10100, LATEST_VLYNQ_REV, 0        },
    { PAL_VLYNQ_IOCTL_CVR_REG,      0x40u, "chipVersion"  , 0xffffffffu, VLYNQ_REV_10100, LATEST_VLYNQ_REV, 0        },
    { PAL_VLYNQ_IOCTL_AUTO_NEG_REG, 0x44u, "autoNegn"     , 0xffffffffu, VLYNQ_REV_10200, LATEST_VLYNQ_REV, 0        },
    { PAL_VLYNQ_IOCTL_MAN_NEG_REG,  0x48u, "manualNegn"   , 0xffffffffu, VLYNQ_REV_10200, LATEST_VLYNQ_REV, 0        },
    { PAL_VLYNQ_IOCTL_NEG_STS_REG,  0x4cu, "negnStatus"   , 0xffffffffu, VLYNQ_REV_10200, LATEST_VLYNQ_REV, 0        },
    { PAL_VLYNQ_IOCTL_ENDIAN_REG,   0x4cu, "endian"       , 0xffffffffu, VLYNQ_REV_10200, VLYNQ_REV_10204,       0        },
    { PAL_VLYNQ_IOCTL_IVR30_REG,    0x60u, "ivr30"        , 0xffffffffu, VLYNQ_REV_10100, LATEST_VLYNQ_REV, 0        },
    { PAL_VLYNQ_IOCTL_IVR74_REG,    0x64u, "ivr74"        , 0xffffffffu, VLYNQ_REV_10100, LATEST_VLYNQ_REV, 0        },
    {  -1,                            32u, "dead end"     , 0xdeadfeedu, 0x00000000u, 0xdeadfeedu  ,0            }
};


/**
  * \brief  The vlynq swap enable or disable
  */
extern Bool   vlynq_swap_hack;

/**
  * \brief To change the endianess
  */
extern Uint32 vlynq_endian_swap(Uint32);

/**
 * \brief   Swap according to the endianness of the device.
 *          Definitely, not re-entrant
 *
 * \param   val         [IN]    Is of the type of Uint32.
 *
 * \return                      val of type Uint32
 */
static Uint32 vlynq_check_and_swap(Uint32 val)
{
    if(vlynq_swap_hack == True) {
        val = vlynq_endian_swap(val);
    }
    return (val);
}


/**
 * \brief   Dump the command register values from start register to the length.
 *
 * \param   vlynq_ioctl [IN]    Is of the type of PAL_VLYNQ_IOCTL_INFO_T.
 * \param   p_start_reg [IN]    Start of the command register.
 * \param   buf         [IN]    Address where to dump registers.
 * \param   limit       [IN]    Number of registers to be dumped.
 * \param   revision    [IN]    Revision of the vlynq module.
 * \param   bit_op      [IN]    For identifying the major or minor commands.
 *
 * \return                      PAL_VLYNQ_OK or PAL Error Code
 */
static Int32 vlynq_dump_cmd(PAL_VLYNQ_IOCTL_INFO_T *vlynq_ioctl, volatile Uint32 *p_start_reg,
        Char *buf, Int32 limit, Uint32 revision, Bool bit_op)
{
    Int32 len = 0;
    PAL_VLYNQ_IOCTL_INFO_T *p_ioctl = NULL;
    PAL_Result ret_val = PAL_VLYNQ_OK;


    if(vlynq_ioctl == NULL){
        ret_val = PAL_VLYNQ_INVALID_PARAM;
    }
    p_ioctl = vlynq_ioctl;
    if((p_ioctl != NULL) && (buf != NULL)){
        for(; p_ioctl->id > -1; p_ioctl++)
        {
            Uint32 val = 0;
            if((revision >= p_ioctl->start_revision) &&
                    (revision <= p_ioctl->end_revision))
            {
                if(len < limit){
                    len += sprintf(buf + len, "%20s : ", p_ioctl->name);
                }
                else{
                    ret_val = PAL_VLYNQ_INVALID_PARAM;
                    break;
                }
                if(FALSE != bit_op){
                    val = (vlynq_check_and_swap((*p_start_reg)) & p_ioctl->mask) >> p_ioctl->offset;
                }
                else{
                    val =  vlynq_check_and_swap(*(p_start_reg + p_ioctl->offset / 0x04u)) & p_ioctl->mask;
                }
                if(len < limit){
                    len += sprintf(buf + len, "0x%08x.\n", val);
                }
                else{
                    ret_val = PAL_VLYNQ_INVALID_PARAM;
                    break;
                }

            }
        }
    }
    return ((ret_val == PAL_VLYNQ_OK)?len:ret_val);
}


/**
 * \brief   Write the value of the command ID and it is a bit operation.
 *
 * \param   vlynq_ioctl [IN]    Handle to access the struct PAL_VLYNQ_IOCTL_INFO_T element.
 * \param   p_reg       [IN]    Register where value of command is to be written based on
 *                              type of command.
 * \param   cmd         [IN]    ID of the command.
 * \param   pVal         [IN]   Value of the cmd to be written.
 * \param   revision    [IN]    Revision of the vlynq module.
 * \param   bit_op      [IN]    For identifying the major or minor commands.
 *
 * \return                      PAL_VLYNQ_OK or PAL Error Code
 */
static PAL_Result vlynq_write_cmd(PAL_VLYNQ_IOCTL_INFO_T *vlynq_ioctl, volatile Uint32 *p_reg,
        Uint32 cmd, Uint32 *pVal, Uint32 revision, Bool bit_op)
{
    PAL_VLYNQ_IOCTL_INFO_T *p_ioctl = NULL;
    PAL_Result ret_val = PAL_VLYNQ_INVALID_PARAM;

    if(vlynq_ioctl == NULL){
        ret_val = PAL_VLYNQ_INVALID_PARAM;
    }
    p_ioctl = vlynq_ioctl;
    if((p_ioctl != NULL) && (p_reg != NULL)){
        for(p_ioctl = vlynq_ioctl; p_ioctl->id > -1; p_ioctl++)
        {
            if((revision >= p_ioctl->start_revision) &&
                    (revision <= p_ioctl->end_revision)) {

                if(cmd == p_ioctl->id) {
                    /* Can we write ? */
                    if(FALSE == (p_ioctl->access_flags & IOCTL_WR)){
                        break;
                    }
                    /* Hack. One of the case. We need to enhance the data structure for
                     * generic implementation. */
                    if(cmd == PAL_VLYNQ_IOCTL_CNT_CLK_DIV_CMD) {
                        if((* pVal) != 0){
                            * pVal -= 1u; /* Adjusting the clock divisor. */
                        }
                        else{
                            break;
                        }
                    }

                    if(FALSE != bit_op){
                        (* p_reg) &= (vlynq_check_and_swap(~(p_ioctl->mask)));
                        (* p_reg) |= (vlynq_check_and_swap(((* pVal) << (p_ioctl->offset)) & (p_ioctl->mask)));
                    }
                    else {
                        * (p_reg+ ( (Uint32)(p_ioctl->offset) / 0x04u)) =
                                        vlynq_check_and_swap(* pVal & p_ioctl->mask);
                    }
                    ret_val = PAL_VLYNQ_OK;
                    break;
                }

            }
        }
    }
    return (ret_val);
}



/**
 * \brief   Read the value of the command ID and it is a bit operation
 *
 * \param   vlynq_ioctl [IN]    Handle to access the struct PAL_VLYNQ_IOCTL_INFO_T element.
 * \param   p_reg       [IN]    Register where value of command is to be written based on
 *                              type of command.
 * \param   cmd         [IN]    ID of the command.
 * \param   val         [IN]    Return pointer for value of register.
 * \param   revision    [IN]    Revision of the vlynq module.
 * \param   bit_op      [IN]    For identifying the major or minor commands.
 *
 * \return                      PAL_VLYNQ_OK or PAL Error Code
 */
static PAL_Result vlynq_read_cmd(PAL_VLYNQ_IOCTL_INFO_T *vlynq_ioctl, volatile Uint32 *p_reg,
        Uint32 cmd,  volatile Uint32 *val, Uint32 revision, Bool bit_op)
{
    PAL_Result ret_val = PAL_VLYNQ_INVALID_PARAM;
    PAL_VLYNQ_IOCTL_INFO_T *p_ioctl = NULL;

    if(vlynq_ioctl == NULL){
        ret_val = PAL_VLYNQ_INVALID_PARAM;
    }
    p_ioctl = vlynq_ioctl;
    if((p_ioctl != NULL) && (val != NULL)){
        for( p_ioctl = vlynq_ioctl; p_ioctl->id > -1; p_ioctl++)
        {
            if((revision >= p_ioctl->start_revision) &&
                    (revision <= p_ioctl->end_revision)){
                if(cmd == p_ioctl->id){
                    if(TRUE == bit_op){
                        *val = (vlynq_check_and_swap(*p_reg) & p_ioctl->mask) >> p_ioctl->offset;
                    }
                    else{
                        *val = vlynq_check_and_swap(*(p_reg + p_ioctl->offset/0x4u)) & p_ioctl->mask;
                    }
                    ret_val = PAL_VLYNQ_OK;
                    break;
                }
            }
        }
    }
    return(ret_val);
}


/**
 * \brief   Read or write to status or command registers  .
 *
 * \param   p_start_reg [IN]    Register handle to read or write based on command.
 * \param   cmd         [IN]    ID of the command.
 * \param   pVal         [IN]   Return pointer for value of register to be
 *                              read or value to be written.
 * \param   vlynq_rev   [IN]    Revision of the vlynq module.
 *
 * \return                      PAL_VLYNQ_OK or PAL Error Code
 */
PAL_Result vlynq_read_write_ioctl(volatile Uint32 *p_start_reg, Uint32 cmd,
        Uint32 *pVal, Uint32 vlynq_rev)
{
    Bool        read_flag = 0;
    Uint32      sub_cmd   = PAL_VLYNQ_IOCTL_MINOR_DE_VAL(cmd);
    PAL_Result  ret_val   = PAL_VLYNQ_INVALID_PARAM;
    Int32       valid     = 1;
    Bool        bit_op    = 1;

    PAL_VLYNQ_IOCTL_INFO_T *p_ioctl = NULL;

    if(0 != (cmd & PAL_VLYNQ_IOCTL_READ_CMD) ) {
        read_flag = 1;
    }

    /*
     * Since we are supporting just one non bit operation, we are hacking
     * the implementation. Ideally, we need to have a separate function.
     */

    if(0 == (cmd & (Uint32)PAL_VLYNQ_IOCTL_BIT_CMD))
    {
        bit_op = 0;

        if(0 == PAL_VLYNQ_IOCTL_MAJOR_DE_VAL(cmd)) {
            p_ioctl = vlynq_reg32_ioctl;
        }
        else {
            valid = 0;
        }
    }
    else
    {
        /* We are doing bit accesses. */
        switch(PAL_VLYNQ_IOCTL_MAJOR_DE_VAL(cmd))
        {
            case PAL_VLYNQ_IOCTL_CONTROL_REG:

                p_ioctl = control_reg_ioctl;
                break;

            case PAL_VLYNQ_IOCTL_STATUS_REG:

                p_ioctl = status_reg_ioctl;
                break;

            default:

                valid = 0;
                break;
        }
    }

    if(TRUE == valid)
    {
        if(TRUE == read_flag) {
            ret_val = vlynq_read_cmd(p_ioctl, p_start_reg, sub_cmd,
                    pVal, vlynq_rev, bit_op);
        }
        else {
            ret_val = vlynq_write_cmd(p_ioctl, p_start_reg, sub_cmd,
                    pVal, vlynq_rev, bit_op);
        }
    }


    return(ret_val);
}


/**
 * \brief   Dump the command register or status register values from start
            register to the length.
 *
 * \param   start_reg   [IN]    Start of the command register.
 * \param   dump_type   [IN]    Select status or command registers.
 * \param   buf         [IN]    Address where to dump registers.
 * \param   limit       [IN]    Number of registers to be dumped.
 * \param   vlynq_rev   [IN]    Revision of the vlynq module.
 *
 * \return                      len of type Int32
 */
Int32 vlynq_dump_ioctl(volatile Uint32 *start_reg, Uint32 dump_type, Char *buf,
        Int32 limit, Uint32 vlynq_rev)
{
    Int32       len = 0;
    Uint32 revision = vlynq_rev;
    switch(dump_type)
    {
        case PAL_VLYNQ_DUMP_STS_REG: {
                                             len += vlynq_dump_cmd(status_reg_ioctl, start_reg, buf + len,
                                                     limit - len, revision, 1);
                                         break;
                                     }
        case PAL_VLYNQ_DUMP_CNTL_REG: {
                                              len += vlynq_dump_cmd(control_reg_ioctl, start_reg, buf + len,
                                                      limit - len, revision, 1);
                                          break;
                                      }

        case PAL_VLYNQ_DUMP_ALL_REGS: {
                                              len += vlynq_dump_cmd(vlynq_reg32_ioctl, start_reg, buf + len,
                                                      limit - len, revision, 0);
                                          break;
                                      }

        default: {
                     break;
                 }
    }

    return (len);
}

