/*******************************************************************************
**+--------------------------------------------------------------------------+**
**|                            ****                                          |**
**|                            ****                                          |**
**|                            ******o***                                    |**
**|                      ********_///_****                                   |**
**|                      ***** /_//_/ ****                                   |**
**|                       ** ** (__/ ****                                    |**
**|                           *********                                      |**
**|                            ****                                          |**
**|                            ***                                           |**
**|                                                                          |**
**|         Copyright (c) 1998-2006 Texas Instruments Incorporated           |**
**|                        ALL RIGHTS RESERVED                               |**
**|                                                                          |**
**| Permission is hereby granted to licensees of Texas Instruments           |**
**| Incorporated (TI) products to use this computer program for the sole     |**
**| purpose of implementing a licensee product based on TI products.         |**
**| No other rights to reproduce, use, or disseminate this computer          |**
**| program, whether in part or in whole, are granted.                       |**
**|                                                                          |**
**| TI makes no representation or warranties with respect to the             |**
**| performance of this computer program, and specifically disclaims         |**
**| any responsibility for any damages, special or consequential,            |**
**| connected with the use of this program.                                  |**
**|                                                                          |**
**+--------------------------------------------------------------------------+**
*******************************************************************************/

/** \file   pal_sysvlynqOs.h
 *
 *  \brief  This file contains the device ISR and ISR param information.
 *
 *  (C) Copyright 2006, Texas Instruments, Inc
 *
 *  \author     Suraj
 *  \version    0.3
 *
 */
#ifndef _PAL_SYSVLYNQOS_H
#define _PAL_SYSVLYNQOS_H


#ifdef __cplusplus
extern "C" {
#endif

/** Board dependent, no of root vlynq modules in vlynq chain of devices */
/* Maximum number of vlynq PORTS on Soc. */
#define MAX_ROOT_VLYNQ 1u

/* The maximum number of vlynq interfaces with in the system. */
/* in SOC one VLYNQ port generates clock and operates as master
        and another VLYNQ port sinks that clock and operates as slave
        So only one interface will come into picture between master and slave */
#define MAX_VLYNQ_COUNT 1u

/** Number of params with ISR. */
#define PAL_VLYNQ_DEV_ISR_PARM_NUM 3

/* To keep the ISR dispatch simple we align the signature of the ISR
 * to that stipulated by the OS.
 */
typedef void (*PAL_VLYNQ_DEV_ISR_FN)(int, void*, void*);

/* The vlynq handle. */
typedef void PAL_VLYNQ_HND;
/* The vlynq dev handle. */
typedef void PAL_VLYNQ_DEV_HND;


/**
 * \brief This strucure holds isr params information.
 */
typedef struct pal_vlynq_dev_isr_param_grp_t
{
    /** This is of type int.*/
    int  arg1;
    /** This is of type void pointer.*/
    void *arg2;
    /** This is of type void pointer.*/
    void *arg3;

} PAL_VLYNQ_DEV_ISR_PARAM_GRP_T;

#ifdef __cplusplus
}
#endif

#endif
