/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005, 2006
 *
 *   Use of this software is controlled by the terms and conditions found in the
 *   license agreement under which this software has been supplied.
 *   ===========================================================================
 */
/** ============================================================================
 *   @file  cslr_ddr2.h
 *
 *   @path  $(CSLPATH)\inc
 *
 *   @desc  This file contains the Register Descriptions for DDR2
 *          Reference: User Guide SPRU986A
 *  ============================================================================
 */
#ifndef _CSLR_DDR2_H_
#define _CSLR_DDR2_H_

#ifdef __cplusplus
extern "C" {
#endif

#include <ti/sdo/pspdrivers/soc/c6424/dsp/cslr.h>
#include <ti/sdo/pspdrivers/soc/c6424/dsp/tistdtypes.h>

/* Minimum unit = 1 byte */

/**************************************************************************\
* Register Overlay Structure
\**************************************************************************/
typedef struct  {
    volatile Uint8 RSVD0[4];
    volatile Uint32 SDRSTAT;
    volatile Uint32 SDBCR;
    volatile Uint32 SDRCR;
    volatile Uint32 SDTIMR;
    volatile Uint32 SDTIMR2;
    volatile Uint8 RSVD1[8];
    volatile Uint32 PBBPR;
    volatile Uint8 RSVD2[156];
    volatile Uint32 IRR;
    volatile Uint32 IMR;
    volatile Uint32 IMSR;
    volatile Uint32 IMCR;
    volatile Uint8 RSVD3[20];
    volatile Uint32 DDRPHYCR;
    volatile Uint8 RSVD4[8];
    volatile Uint32 VTPIOCR;
} CSL_Ddr2Regs;

/**************************************************************************\
* Overlay structure typedef definition
\**************************************************************************/
typedef volatile CSL_Ddr2Regs         *CSL_Ddr2RegsOvly;

/**************************************************************************\
* Field Definition Macros
\**************************************************************************/

/* SDRSTAT */


#define CSL_DDR2_SDRSTAT_PHYRDY_MASK (0x00000004u)
#define CSL_DDR2_SDRSTAT_PHYRDY_SHIFT (0x00000002u)
#define CSL_DDR2_SDRSTAT_PHYRDY_RESETVAL (0x00000000u)
/*----PHYRDY Tokens----*/
#define CSL_DDR2_SDRSTAT_PHYRDY_POWERED_DOWN (0x00000000u)
#define CSL_DDR2_SDRSTAT_PHYRDY_POWERED_UP (0x00000001u)


#define CSL_DDR2_SDRSTAT_RESETVAL (0x20000000u)

/* SDBCR */


#define CSL_DDR2_SDBCR_BOOTUNLOCK_MASK (0x00800000u)
#define CSL_DDR2_SDBCR_BOOTUNLOCK_SHIFT (0x00000017u)
#define CSL_DDR2_SDBCR_BOOTUNLOCK_RESETVAL (0x00000000u)
/*----BOOTUNLOCK Tokens----*/
#define CSL_DDR2_SDBCR_BOOTUNLOCK_DDRDRV_LOCK (0x00000000u)
#define CSL_DDR2_SDBCR_BOOTUNLOCK_DDRDRV_UNLOCK (0x00000001u)


#define CSL_DDR2_SDBCR_DDRDRIVE_MASK (0x00040000u)
#define CSL_DDR2_SDBCR_DDRDRIVE_SHIFT (0x00000012u)
#define CSL_DDR2_SDBCR_DDRDRIVE_RESETVAL (0x00000001u)
/*----DDRDRIVE Tokens----*/
#define CSL_DDR2_SDBCR_DDRDRIVE_NORMAL (0x00000000u)
#define CSL_DDR2_SDBCR_DDRDRIVE_WEAK (0x00000001u)


#define CSL_DDR2_SDBCR_TIMUNLOCK_MASK (0x00008000u)
#define CSL_DDR2_SDBCR_TIMUNLOCK_SHIFT (0x0000000Fu)
#define CSL_DDR2_SDBCR_TIMUNLOCK_RESETVAL (0x00000000u)
/*----TIMUNLOCK Tokens----*/
#define CSL_DDR2_SDBCR_TIMUNLOCK_CLEAR (0x00000000u)
#define CSL_DDR2_SDBCR_TIMUNLOCK_SET (0x00000001u)

#define CSL_DDR2_SDBCR_NM_MASK (0x00004000u)
#define CSL_DDR2_SDBCR_NM_SHIFT (0x0000000Eu)
#define CSL_DDR2_SDBCR_NM_RESETVAL (0x00000000u)
/*----NM Tokens----*/
#define CSL_DDR2_SDBCR_NM_32BIT (0x00000000u)
#define CSL_DDR2_SDBCR_NM_16BIT (0x00000001u)


#define CSL_DDR2_SDBCR_CL_MASK (0x00000E00u)
#define CSL_DDR2_SDBCR_CL_SHIFT (0x00000009u)
#define CSL_DDR2_SDBCR_CL_RESETVAL (0x00000005u)
/*----CL Tokens----*/
#define CSL_DDR2_SDBCR_CL_TWO (0x00000002u)
#define CSL_DDR2_SDBCR_CL_THREE (0x00000003u)
#define CSL_DDR2_SDBCR_CL_FOUR (0x00000004u)
#define CSL_DDR2_SDBCR_CL_FIVE (0x00000005u)


#define CSL_DDR2_SDBCR_IBANK_MASK (0x00000070u)
#define CSL_DDR2_SDBCR_IBANK_SHIFT (0x00000004u)
#define CSL_DDR2_SDBCR_IBANK_RESETVAL (0x00000002u)
/*----IBANK Tokens----*/
#define CSL_DDR2_SDBCR_IBANK_ONE (0x00000000u)
#define CSL_DDR2_SDBCR_IBANK_TWO (0x00000001u)
#define CSL_DDR2_SDBCR_IBANK_FOUR (0x00000002u)
#define CSL_DDR2_SDBCR_IBANK_EIGHT (0x00000003u)


#define CSL_DDR2_SDBCR_PAGESIZE_MASK (0x00000007u)
#define CSL_DDR2_SDBCR_PAGESIZE_SHIFT (0x00000000u)
#define CSL_DDR2_SDBCR_PAGESIZE_RESETVAL (0x00000000u)
/*----PAGESIZE Tokens----*/
#define CSL_DDR2_SDBCR_PAGESIZE_P256 (0x00000000u)
#define CSL_DDR2_SDBCR_PAGESIZE_P512 (0x00000001u)
#define CSL_DDR2_SDBCR_PAGESIZE_P1024 (0x00000002u)
#define CSL_DDR2_SDBCR_PAGESIZE_P2048 (0x00000003u)

#define CSL_DDR2_SDBCR_RESETVAL (0x01170A20u)

/* SDRCR */

#define CSL_DDR2_SDRCR_SR_MASK (0x80000000u)
#define CSL_DDR2_SDRCR_SR_SHIFT (0x0000001Fu)
#define CSL_DDR2_SDRCR_SR_RESETVAL (0x00000000u)
/*----SR Tokens----*/
#define CSL_DDR2_SDRCR_SR_DISABLE (0x00000000u)
#define CSL_DDR2_SDRCR_SR_ENABLE (0x00000001u)

#define CSL_DDR2_SDRCR_MCLKSTOPEN_MASK (0x40000000u)
#define CSL_DDR2_SDRCR_MCLKSTOPEN_SHIFT (0x0000001Eu)
#define CSL_DDR2_SDRCR_MCLKSTOPEN_RESETVAL (0x00000000u)
/*----MCLKSTOPEN Tokens----*/
#define CSL_DDR2_SDRCR_MCLKSTOPEN_DISABLE (0x00000000u)
#define CSL_DDR2_SDRCR_MCLKSTOPEN_ENABLE (0x00000001u)


#define CSL_DDR2_SDRCR_RR_MASK (0x0000FFFFu)
#define CSL_DDR2_SDRCR_RR_SHIFT (0x00000000u)
#define CSL_DDR2_SDRCR_RR_RESETVAL (0x00000884u)

#define CSL_DDR2_SDRCR_RESETVAL (0x00000884u)

/* SDTIMR */

#define CSL_DDR2_SDTIMR_T_RFC_MASK (0xFE000000u)
#define CSL_DDR2_SDTIMR_T_RFC_SHIFT (0x00000019u)
#define CSL_DDR2_SDTIMR_T_RFC_RESETVAL (0x0000001Au)

#define CSL_DDR2_SDTIMR_T_RP_MASK (0x01C00000u)
#define CSL_DDR2_SDTIMR_T_RP_SHIFT (0x00000016u)
#define CSL_DDR2_SDTIMR_T_RP_RESETVAL (0x00000005u)

#define CSL_DDR2_SDTIMR_T_RCD_MASK (0x00380000u)
#define CSL_DDR2_SDTIMR_T_RCD_SHIFT (0x00000013u)
#define CSL_DDR2_SDTIMR_T_RCD_RESETVAL (0x00000005u)

#define CSL_DDR2_SDTIMR_T_WR_MASK (0x00070000u)
#define CSL_DDR2_SDTIMR_T_WR_SHIFT (0x00000010u)
#define CSL_DDR2_SDTIMR_T_WR_RESETVAL (0x00000003u)

#define CSL_DDR2_SDTIMR_T_RAS_MASK (0x0000F800u)
#define CSL_DDR2_SDTIMR_T_RAS_SHIFT (0x0000000Bu)
#define CSL_DDR2_SDTIMR_T_RAS_RESETVAL (0x00000009u)

#define CSL_DDR2_SDTIMR_T_RC_MASK (0x000007C0u)
#define CSL_DDR2_SDTIMR_T_RC_SHIFT (0x00000006u)
#define CSL_DDR2_SDTIMR_T_RC_RESETVAL (0x0000000Eu)

#define CSL_DDR2_SDTIMR_T_RRD_MASK (0x00000038u)
#define CSL_DDR2_SDTIMR_T_RRD_SHIFT (0x00000003u)
#define CSL_DDR2_SDTIMR_T_RRD_RESETVAL (0x00000003u)


#define CSL_DDR2_SDTIMR_T_WTR_MASK (0x00000003u)
#define CSL_DDR2_SDTIMR_T_WTR_SHIFT (0x00000000u)
#define CSL_DDR2_SDTIMR_T_WTR_RESETVAL (0x00000003u)

#define CSL_DDR2_SDTIMR_RESETVAL (0x356B4B9Bu)

/* SDTIMR2 */


#define CSL_DDR2_SDTIMR2_T_XSNR_MASK (0x007F0000u)
#define CSL_DDR2_SDTIMR2_T_XSNR_SHIFT (0x00000010u)
#define CSL_DDR2_SDTIMR2_T_XSNR_RESETVAL (0x0000001Du)

#define CSL_DDR2_SDTIMR2_T_XSRD_MASK (0x0000FF00u)
#define CSL_DDR2_SDTIMR2_T_XSRD_SHIFT (0x00000008u)
#define CSL_DDR2_SDTIMR2_T_XSRD_RESETVAL (0x000000F1u)

#define CSL_DDR2_SDTIMR2_T_RTP_MASK (0x000000E0u)
#define CSL_DDR2_SDTIMR2_T_RTP_SHIFT (0x00000005u)
#define CSL_DDR2_SDTIMR2_T_RTP_RESETVAL (0x00000002u)

#define CSL_DDR2_SDTIMR2_T_CKE_MASK (0x0000001Fu)
#define CSL_DDR2_SDTIMR2_T_CKE_SHIFT (0x00000000u)
#define CSL_DDR2_SDTIMR2_T_CKE_RESETVAL (0x00000005u)

#define CSL_DDR2_SDTIMR2_RESETVAL (0x001DF145u)

/* PBBPR */


#define CSL_DDR2_PBBPR_PR_OLD_COUNT_MASK (0x000000FFu)
#define CSL_DDR2_PBBPR_PR_OLD_COUNT_SHIFT (0x00000000u)
#define CSL_DDR2_PBBPR_PR_OLD_COUNT_RESETVAL (0x000000FFu)
/*----PR_OLD_COUNT Tokens----*/
#define CSL_DDR2_PBBPR_PR_OLD_COUNT_DISABLE (0x000000FFu)

#define CSL_DDR2_PBBPR_RESETVAL (0x000000FFu)

/* IRR */


#define CSL_DDR2_IRR_LT_MASK (0x00000004u)
#define CSL_DDR2_IRR_LT_SHIFT (0x00000002u)
#define CSL_DDR2_IRR_LT_RESETVAL (0x00000000u)
/*----LT Tokens----*/
#define CSL_DDR2_IRR_LT_NO (0x00000000u)
#define CSL_DDR2_IRR_LT_ILLEGAL (0x00000001u)


#define CSL_DDR2_IRR_RESETVAL (0x00000000u)

/* IMR */


#define CSL_DDR2_IMR_LTM_MASK (0x00000004u)
#define CSL_DDR2_IMR_LTM_SHIFT (0x00000002u)
#define CSL_DDR2_IMR_LTM_RESETVAL (0x00000000u)
/*----LTM Tokens----*/
#define CSL_DDR2_IMR_LTM_NO (0x00000000u)
#define CSL_DDR2_IMR_LTM_ILLEGAL (0x00000001u)


#define CSL_DDR2_IMR_RESETVAL (0x00000000u)

/* IMSR */


#define CSL_DDR2_IMSR_LTMSET_MASK (0x00000004u)
#define CSL_DDR2_IMSR_LTMSET_SHIFT (0x00000002u)
#define CSL_DDR2_IMSR_LTMSET_RESETVAL (0x00000000u)
/*----LTMSET Tokens----*/
#define CSL_DDR2_IMSR_LTMSET_DISABLE (0x00000000u)
#define CSL_DDR2_IMSR_LTMSET_ENABLE (0x00000001u)


#define CSL_DDR2_IMSR_RESETVAL (0x00000000u)

/* IMCR */


#define CSL_DDR2_IMCR_LTMCLR_MASK (0x00000004u)
#define CSL_DDR2_IMCR_LTMCLR_SHIFT (0x00000002u)
#define CSL_DDR2_IMCR_LTMCLR_RESETVAL (0x00000000u)
/*----LTMCLR Tokens----*/
#define CSL_DDR2_IMCR_LTMCLR_DISABLE (0x00000000u)
#define CSL_DDR2_IMCR_LTMCLR_ENABLE (0x00000001u)


#define CSL_DDR2_IMCR_RESETVAL (0x00000000u)

/* DDRPHYCR */


#define CSL_DDR2_DDRPHYCR_DLLRESET_MASK (0x00000020u)
#define CSL_DDR2_DDRPHYCR_DLLRESET_SHIFT (0x00000005u)
#define CSL_DDR2_DDRPHYCR_DLLRESET_RESETVAL (0x00000000u)
/*----DLLRESET Tokens----*/
#define CSL_DDR2_DDRPHYCR_DLLRESET_OUTOFRESET (0x00000000u)
#define CSL_DDR2_DDRPHYCR_DLLRESET_RESET (0x00000001u)

#define CSL_DDR2_DDRPHYCR_DLLPWRDN_MASK (0x00000010u)
#define CSL_DDR2_DDRPHYCR_DLLPWRDN_SHIFT (0x00000004u)
#define CSL_DDR2_DDRPHYCR_DLLPWRDN_RESETVAL (0x00000001u)
/*----DLLPWRDN Tokens----*/
#define CSL_DDR2_DDRPHYCR_DLLPWRDN_DISABLE (0x00000000u)
#define CSL_DDR2_DDRPHYCR_DLLPWRDN_ENABLE (0x00000001u)


#define CSL_DDR2_DDRPHYCR_READLAT_MASK (0x00000007u)
#define CSL_DDR2_DDRPHYCR_READLAT_SHIFT (0x00000000u)
#define CSL_DDR2_DDRPHYCR_READLAT_RESETVAL (0x00000007u)

#define CSL_DDR2_DDRPHYCR_RESETVAL (0x4000641Fu)

/* VTPIOCR */


#define CSL_DDR2_VTPIOCR_RECAL_MASK (0x00008000u)
#define CSL_DDR2_VTPIOCR_RECAL_SHIFT (0x0000000Fu)
#define CSL_DDR2_VTPIOCR_RECAL_RESETVAL (0x00000000u)
/*----RECAL Tokens----*/
#define CSL_DDR2_VTPIOCR_RECAL_NORMAL (0x00000000u)
#define CSL_DDR2_VTPIOCR_RECAL_VTPIO (0x00000001u)


#define CSL_DDR2_VTPIOCR_EN_MASK (0x00002000u)
#define CSL_DDR2_VTPIOCR_EN_SHIFT (0x0000000Du)
#define CSL_DDR2_VTPIOCR_EN_RESETVAL (0x00000000u)
/*----EN Tokens----*/
#define CSL_DDR2_VTPIOCR_EN_DISABLED (0x00000000u)
#define CSL_DDR2_VTPIOCR_EN_ENABLED (0x00000001u)


#define CSL_DDR2_VTPIOCR_PCH_MASK (0x000003E0u)
#define CSL_DDR2_VTPIOCR_PCH_SHIFT (0x00000005u)
#define CSL_DDR2_VTPIOCR_PCH_RESETVAL (0x00000000u)

#define CSL_DDR2_VTPIOCR_NCH_MASK (0x0000001Fu)
#define CSL_DDR2_VTPIOCR_NCH_SHIFT (0x00000000u)
#define CSL_DDR2_VTPIOCR_NCH_RESETVAL (0x0000001Fu)

#define CSL_DDR2_VTPIOCR_RESETVAL (0x0000001Fu)


#ifdef __cplusplus
}
#endif

#endif

