/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005, 2006
 *
 *   Use of this software is controlled by the terms and conditions found in the
 *   license agreement under which this software has been supplied.
 *   ===========================================================================
 */
/** ============================================================================
 *   @file  cslr_emif2.h
 *
 *   @path  $(CSLPATH)\inc
 *
 *   @desc  This file contains the Register Descriptions for EMIF2
 *          Reference: User Guide SPRU984
 *  ============================================================================
 */
#ifndef _CSLR_EMIF2_H_
#define _CSLR_EMIF2_H_

#ifdef __cplusplus
extern "C" {
#endif

#include <ti/sdo/pspdrivers/soc/c6424/dsp/cslr.h>
#include <ti/sdo/pspdrivers/soc/c6424/dsp/tistdtypes.h>


/* Minimum unit = 1 byte */

/**************************************************************************\
* Register Overlay Structure
\**************************************************************************/
typedef struct  {
    volatile Uint32 RCSR;
    volatile Uint32 AWCCR;
    volatile Uint8 RSVD0[8];
    volatile Uint32 A1CR;
    volatile Uint32 A2CR;
    volatile Uint32 A3CR;
    volatile Uint32 A4CR;
    volatile Uint8 RSVD1[32];
    volatile Uint32 EIRR;
    volatile Uint32 EIMR;
    volatile Uint32 EIMSR;
    volatile Uint32 EIMCR;
    volatile Uint8 RSVD2[16];
    volatile Uint32 NANDFCR;
    volatile Uint32 NANDFSR;
    volatile Uint8 RSVD3[8];
    volatile Uint32 NANDF1ECC;
    volatile Uint32 NANDF2ECC;
    volatile Uint32 NANDF3ECC;
    volatile Uint32 NANDF4ECC;
} CSL_Emif2Regs;

/**************************************************************************\
* Overlay structure typedef definition
\**************************************************************************/
typedef volatile CSL_Emif2Regs         *CSL_Emif2RegsOvly;

/**************************************************************************\
* Field Definition Macros
\**************************************************************************/

/* RCSR */

#define CSL_EMIF2_RCSR_BE_MASK (0x80000000u)
#define CSL_EMIF2_RCSR_BE_SHIFT (0x0000001Fu)
#define CSL_EMIF2_RCSR_BE_RESETVAL (0x00000001u)
/*----BE Tokens----*/
#define CSL_EMIF2_RCSR_BE_LITTLE (0x00000000u)
#define CSL_EMIF2_RCSR_BE_BIG (0x00000001u)

#define CSL_EMIF2_RCSR_FR_MASK (0x40000000u)
#define CSL_EMIF2_RCSR_FR_SHIFT (0x0000001Eu)
#define CSL_EMIF2_RCSR_FR_RESETVAL (0x00000001u)
/*----FR Tokens----*/
#define CSL_EMIF2_RCSR_FR_HALFRATE (0x00000000u)
#define CSL_EMIF2_RCSR_FR_FULLRATE (0x00000001u)

#define CSL_EMIF2_RCSR_MODULE_ID_MASK (0x3FFF0000u)
#define CSL_EMIF2_RCSR_MODULE_ID_SHIFT (0x00000010u)
#define CSL_EMIF2_RCSR_MODULE_ID_RESETVAL (0x0000000Fu)

#define CSL_EMIF2_RCSR_MAJOR_REVISION_MASK (0x0000FF00u)
#define CSL_EMIF2_RCSR_MAJOR_REVISION_SHIFT (0x00000008u)
#define CSL_EMIF2_RCSR_MAJOR_REVISION_RESETVAL (0x00000002u)

#define CSL_EMIF2_RCSR_MINOR_REVISION_MASK (0x000000FFu)
#define CSL_EMIF2_RCSR_MINOR_REVISION_SHIFT (0x00000000u)
#define CSL_EMIF2_RCSR_MINOR_REVISION_RESETVAL (0x00000001u)

#define CSL_EMIF2_RCSR_RESETVAL (0xC00F0201u)

/* AWCCR */


#define CSL_EMIF2_AWCCR_WP0_MASK (0x10000000u)
#define CSL_EMIF2_AWCCR_WP0_SHIFT (0x0000001Cu)
#define CSL_EMIF2_AWCCR_WP0_RESETVAL (0x00000001u)
/*----WP0 Tokens----*/
#define CSL_EMIF2_AWCCR_WP0_WAITLOW (0x00000000u)
#define CSL_EMIF2_AWCCR_WP0_WAITHIGH (0x00000001u)


#define CSL_EMIF2_AWCCR_MEWC_MASK (0x000000FFu)
#define CSL_EMIF2_AWCCR_MEWC_SHIFT (0x00000000u)
#define CSL_EMIF2_AWCCR_MEWC_RESETVAL (0x00000080u)

#define CSL_EMIF2_AWCCR_RESETVAL (0x10000080u)

/* A1CR */

#define CSL_EMIF2_A1CR_SS_MASK (0x80000000u)
#define CSL_EMIF2_A1CR_SS_SHIFT (0x0000001Fu)
#define CSL_EMIF2_A1CR_SS_RESETVAL (0x00000000u)
/*----SS Tokens----*/
#define CSL_EMIF2_A1CR_SS_NORMAL (0x00000000u)
#define CSL_EMIF2_A1CR_SS_STROBE (0x00000001u)

#define CSL_EMIF2_A1CR_EW_MASK (0x40000000u)
#define CSL_EMIF2_A1CR_EW_SHIFT (0x0000001Eu)
#define CSL_EMIF2_A1CR_EW_RESETVAL (0x00000000u)
/*----EW Tokens----*/
#define CSL_EMIF2_A1CR_EW_DISABLE (0x00000000u)
#define CSL_EMIF2_A1CR_EW_ENABLE (0x00000001u)

#define CSL_EMIF2_A1CR_W_SETUP_MASK (0x3C000000u)
#define CSL_EMIF2_A1CR_W_SETUP_SHIFT (0x0000001Au)
#define CSL_EMIF2_A1CR_W_SETUP_RESETVAL (0x0000000Fu)

#define CSL_EMIF2_A1CR_W_STROBE_MASK (0x03F00000u)
#define CSL_EMIF2_A1CR_W_STROBE_SHIFT (0x00000014u)
#define CSL_EMIF2_A1CR_W_STROBE_RESETVAL (0x0000003Fu)

#define CSL_EMIF2_A1CR_W_HOLD_MASK (0x000E0000u)
#define CSL_EMIF2_A1CR_W_HOLD_SHIFT (0x00000011u)
#define CSL_EMIF2_A1CR_W_HOLD_RESETVAL (0x00000007u)

#define CSL_EMIF2_A1CR_R_SETUP_MASK (0x0001E000u)
#define CSL_EMIF2_A1CR_R_SETUP_SHIFT (0x0000000Du)
#define CSL_EMIF2_A1CR_R_SETUP_RESETVAL (0x0000000Fu)

#define CSL_EMIF2_A1CR_R_STROBE_MASK (0x00001F80u)
#define CSL_EMIF2_A1CR_R_STROBE_SHIFT (0x00000007u)
#define CSL_EMIF2_A1CR_R_STROBE_RESETVAL (0x0000003Fu)

#define CSL_EMIF2_A1CR_R_HOLD_MASK (0x00000070u)
#define CSL_EMIF2_A1CR_R_HOLD_SHIFT (0x00000004u)
#define CSL_EMIF2_A1CR_R_HOLD_RESETVAL (0x00000007u)

#define CSL_EMIF2_A1CR_TA_MASK (0x0000000Cu)
#define CSL_EMIF2_A1CR_TA_SHIFT (0x00000002u)
#define CSL_EMIF2_A1CR_TA_RESETVAL (0x00000003u)

#define CSL_EMIF2_A1CR_ASIZE_MASK (0x00000003u)
#define CSL_EMIF2_A1CR_ASIZE_SHIFT (0x00000000u)
#define CSL_EMIF2_A1CR_ASIZE_RESETVAL (0x00000000u)
#define CSL_EMIF2_A1CR_ASIZE_ASIZE_8BITS (0x00000000u)
#define CSL_EMIF2_A1CR_ASIZE_ASIZE_16BITS (0x00000001u)

#define CSL_EMIF2_A1CR_RESETVAL (0x3FFFFFFCu)

/* A2CR */

#define CSL_EMIF2_A2CR_SS_MASK (0x80000000u)
#define CSL_EMIF2_A2CR_SS_SHIFT (0x0000001Fu)
#define CSL_EMIF2_A2CR_SS_RESETVAL (0x00000000u)
/*----SS Tokens----*/
#define CSL_EMIF2_A2CR_SS_NORMAL (0x00000000u)
#define CSL_EMIF2_A2CR_SS_STROBE (0x00000001u)

#define CSL_EMIF2_A2CR_EW_MASK (0x40000000u)
#define CSL_EMIF2_A2CR_EW_SHIFT (0x0000001Eu)
#define CSL_EMIF2_A2CR_EW_RESETVAL (0x00000000u)
/*----EW Tokens----*/
#define CSL_EMIF2_A2CR_EW_DISABLE (0x00000000u)
#define CSL_EMIF2_A2CR_EW_ENABLE (0x00000001u)

#define CSL_EMIF2_A2CR_W_SETUP_MASK (0x3C000000u)
#define CSL_EMIF2_A2CR_W_SETUP_SHIFT (0x0000001Au)
#define CSL_EMIF2_A2CR_W_SETUP_RESETVAL (0x0000000Fu)

#define CSL_EMIF2_A2CR_W_STROBE_MASK (0x03F00000u)
#define CSL_EMIF2_A2CR_W_STROBE_SHIFT (0x00000014u)
#define CSL_EMIF2_A2CR_W_STROBE_RESETVAL (0x0000003Fu)

#define CSL_EMIF2_A2CR_W_HOLD_MASK (0x000E0000u)
#define CSL_EMIF2_A2CR_W_HOLD_SHIFT (0x00000011u)
#define CSL_EMIF2_A2CR_W_HOLD_RESETVAL (0x00000007u)

#define CSL_EMIF2_A2CR_R_SETUP_MASK (0x0001E000u)
#define CSL_EMIF2_A2CR_R_SETUP_SHIFT (0x0000000Du)
#define CSL_EMIF2_A2CR_R_SETUP_RESETVAL (0x0000000Fu)

#define CSL_EMIF2_A2CR_R_STROBE_MASK (0x00001F80u)
#define CSL_EMIF2_A2CR_R_STROBE_SHIFT (0x00000007u)
#define CSL_EMIF2_A2CR_R_STROBE_RESETVAL (0x0000003Fu)

#define CSL_EMIF2_A2CR_R_HOLD_MASK (0x00000070u)
#define CSL_EMIF2_A2CR_R_HOLD_SHIFT (0x00000004u)
#define CSL_EMIF2_A2CR_R_HOLD_RESETVAL (0x00000007u)

#define CSL_EMIF2_A2CR_TA_MASK (0x0000000Cu)
#define CSL_EMIF2_A2CR_TA_SHIFT (0x00000002u)
#define CSL_EMIF2_A2CR_TA_RESETVAL (0x00000003u)

#define CSL_EMIF2_A2CR_ASIZE_MASK (0x00000003u)
#define CSL_EMIF2_A2CR_ASIZE_SHIFT (0x00000000u)
#define CSL_EMIF2_A2CR_ASIZE_RESETVAL (0x00000000u)
#define CSL_EMIF2_A2CR_ASIZE_ASIZE_8BITS (0x00000000u)
#define CSL_EMIF2_A2CR_ASIZE_ASIZE_16BITS (0x00000001u)

#define CSL_EMIF2_A2CR_RESETVAL (0x3FFFFFFCu)

/* A3CR */

#define CSL_EMIF2_A3CR_SS_MASK (0x80000000u)
#define CSL_EMIF2_A3CR_SS_SHIFT (0x0000001Fu)
#define CSL_EMIF2_A3CR_SS_RESETVAL (0x00000000u)
/*----SS Tokens----*/
#define CSL_EMIF2_A3CR_SS_NORMAL (0x00000000u)
#define CSL_EMIF2_A3CR_SS_STROBE (0x00000001u)

#define CSL_EMIF2_A3CR_EW_MASK (0x40000000u)
#define CSL_EMIF2_A3CR_EW_SHIFT (0x0000001Eu)
#define CSL_EMIF2_A3CR_EW_RESETVAL (0x00000000u)
/*----EW Tokens----*/
#define CSL_EMIF2_A3CR_EW_DISABLE (0x00000000u)
#define CSL_EMIF2_A3CR_EW_ENABLE (0x00000001u)

#define CSL_EMIF2_A3CR_W_SETUP_MASK (0x3C000000u)
#define CSL_EMIF2_A3CR_W_SETUP_SHIFT (0x0000001Au)
#define CSL_EMIF2_A3CR_W_SETUP_RESETVAL (0x0000000Fu)

#define CSL_EMIF2_A3CR_W_STROBE_MASK (0x03F00000u)
#define CSL_EMIF2_A3CR_W_STROBE_SHIFT (0x00000014u)
#define CSL_EMIF2_A3CR_W_STROBE_RESETVAL (0x0000003Fu)

#define CSL_EMIF2_A3CR_W_HOLD_MASK (0x000E0000u)
#define CSL_EMIF2_A3CR_W_HOLD_SHIFT (0x00000011u)
#define CSL_EMIF2_A3CR_W_HOLD_RESETVAL (0x00000007u)

#define CSL_EMIF2_A3CR_R_SETUP_MASK (0x0001E000u)
#define CSL_EMIF2_A3CR_R_SETUP_SHIFT (0x0000000Du)
#define CSL_EMIF2_A3CR_R_SETUP_RESETVAL (0x0000000Fu)

#define CSL_EMIF2_A3CR_R_STROBE_MASK (0x00001F80u)
#define CSL_EMIF2_A3CR_R_STROBE_SHIFT (0x00000007u)
#define CSL_EMIF2_A3CR_R_STROBE_RESETVAL (0x0000003Fu)

#define CSL_EMIF2_A3CR_R_HOLD_MASK (0x00000070u)
#define CSL_EMIF2_A3CR_R_HOLD_SHIFT (0x00000004u)
#define CSL_EMIF2_A3CR_R_HOLD_RESETVAL (0x00000007u)

#define CSL_EMIF2_A3CR_TA_MASK (0x0000000Cu)
#define CSL_EMIF2_A3CR_TA_SHIFT (0x00000002u)
#define CSL_EMIF2_A3CR_TA_RESETVAL (0x00000003u)

#define CSL_EMIF2_A3CR_ASIZE_MASK (0x00000003u)
#define CSL_EMIF2_A3CR_ASIZE_SHIFT (0x00000000u)
#define CSL_EMIF2_A3CR_ASIZE_RESETVAL (0x00000000u)
#define CSL_EMIF2_A3CR_ASIZE_ASIZE_8BITS (0x00000000u)
#define CSL_EMIF2_A3CR_ASIZE_ASIZE_16BITS (0x00000001u)

#define CSL_EMIF2_A3CR_RESETVAL (0x3FFFFFFCu)

/* A4CR */

#define CSL_EMIF2_A4CR_SS_MASK (0x80000000u)
#define CSL_EMIF2_A4CR_SS_SHIFT (0x0000001Fu)
#define CSL_EMIF2_A4CR_SS_RESETVAL (0x00000000u)
/*----SS Tokens----*/
#define CSL_EMIF2_A4CR_SS_NORMAL (0x00000000u)
#define CSL_EMIF2_A4CR_SS_STROBE (0x00000001u)

#define CSL_EMIF2_A4CR_EW_MASK (0x40000000u)
#define CSL_EMIF2_A4CR_EW_SHIFT (0x0000001Eu)
#define CSL_EMIF2_A4CR_EW_RESETVAL (0x00000000u)
/*----EW Tokens----*/
#define CSL_EMIF2_A4CR_EW_DISABLE (0x00000000u)
#define CSL_EMIF2_A4CR_EW_ENABLE (0x00000001u)

#define CSL_EMIF2_A4CR_W_SETUP_MASK (0x3C000000u)
#define CSL_EMIF2_A4CR_W_SETUP_SHIFT (0x0000001Au)
#define CSL_EMIF2_A4CR_W_SETUP_RESETVAL (0x0000000Fu)

#define CSL_EMIF2_A4CR_W_STROBE_MASK (0x03F00000u)
#define CSL_EMIF2_A4CR_W_STROBE_SHIFT (0x00000014u)
#define CSL_EMIF2_A4CR_W_STROBE_RESETVAL (0x0000003Fu)

#define CSL_EMIF2_A4CR_W_HOLD_MASK (0x000E0000u)
#define CSL_EMIF2_A4CR_W_HOLD_SHIFT (0x00000011u)
#define CSL_EMIF2_A4CR_W_HOLD_RESETVAL (0x00000007u)

#define CSL_EMIF2_A4CR_R_SETUP_MASK (0x0001E000u)
#define CSL_EMIF2_A4CR_R_SETUP_SHIFT (0x0000000Du)
#define CSL_EMIF2_A4CR_R_SETUP_RESETVAL (0x0000000Fu)

#define CSL_EMIF2_A4CR_R_STROBE_MASK (0x00001F80u)
#define CSL_EMIF2_A4CR_R_STROBE_SHIFT (0x00000007u)
#define CSL_EMIF2_A4CR_R_STROBE_RESETVAL (0x0000003Fu)

#define CSL_EMIF2_A4CR_R_HOLD_MASK (0x00000070u)
#define CSL_EMIF2_A4CR_R_HOLD_SHIFT (0x00000004u)
#define CSL_EMIF2_A4CR_R_HOLD_RESETVAL (0x00000007u)

#define CSL_EMIF2_A4CR_TA_MASK (0x0000000Cu)
#define CSL_EMIF2_A4CR_TA_SHIFT (0x00000002u)
#define CSL_EMIF2_A4CR_TA_RESETVAL (0x00000003u)

#define CSL_EMIF2_A4CR_ASIZE_MASK (0x00000003u)
#define CSL_EMIF2_A4CR_ASIZE_SHIFT (0x00000000u)
#define CSL_EMIF2_A4CR_ASIZE_RESETVAL (0x00000000u)
#define CSL_EMIF2_A4CR_ASIZE_ASIZE_8BITS (0x00000000u)
#define CSL_EMIF2_A4CR_ASIZE_ASIZE_16BITS (0x00000001u)

#define CSL_EMIF2_A4CR_RESETVAL (0x3FFFFFFCu)

/* EIRR */


#define CSL_EMIF2_EIRR_WR_MASK (0x00000004u)
#define CSL_EMIF2_EIRR_WR_SHIFT (0x00000002u)
#define CSL_EMIF2_EIRR_WR_RESETVAL (0x00000000u)
/*----WR Tokens----*/
#define CSL_EMIF2_EIRR_WR_CLEAR (0x00000001u)


#define CSL_EMIF2_EIRR_AT_MASK (0x00000001u)
#define CSL_EMIF2_EIRR_AT_SHIFT (0x00000000u)
#define CSL_EMIF2_EIRR_AT_RESETVAL (0x00000000u)
/*----AT Tokens----*/
#define CSL_EMIF2_EIRR_AT_CLEAR (0x00000001u)

#define CSL_EMIF2_EIRR_RESETVAL (0x00000000u)

/* EIMR */


#define CSL_EMIF2_EIMR_WRM_MASK (0x00000004u)
#define CSL_EMIF2_EIMR_WRM_SHIFT (0x00000002u)
#define CSL_EMIF2_EIMR_WRM_RESETVAL (0x00000000u)
/*----WRM Tokens----*/
#define CSL_EMIF2_EIMR_WRM_CLEAR (0x00000001u)


#define CSL_EMIF2_EIMR_ATM_MASK (0x00000001u)
#define CSL_EMIF2_EIMR_ATM_SHIFT (0x00000000u)
#define CSL_EMIF2_EIMR_ATM_RESETVAL (0x00000000u)
/*----ATM Tokens----*/
#define CSL_EMIF2_EIMR_ATM_CLEAR (0x00000001u)

#define CSL_EMIF2_EIMR_RESETVAL (0x00000000u)

/* EIMSR */


#define CSL_EMIF2_EIMSR_WRMSET_MASK (0x00000004u)
#define CSL_EMIF2_EIMSR_WRMSET_SHIFT (0x00000002u)
#define CSL_EMIF2_EIMSR_WRMSET_RESETVAL (0x00000000u)
/*----WRMSET Tokens----*/
#define CSL_EMIF2_EIMSR_WRMSET_SET (0x00000001u)


#define CSL_EMIF2_EIMSR_ATMSET_MASK (0x00000001u)
#define CSL_EMIF2_EIMSR_ATMSET_SHIFT (0x00000000u)
#define CSL_EMIF2_EIMSR_ATMSET_RESETVAL (0x00000000u)
/*----ATMSET Tokens----*/
#define CSL_EMIF2_EIMSR_ATMSET_SET (0x00000001u)

#define CSL_EMIF2_EIMSR_RESETVAL (0x00000000u)

/* EIMCR */


#define CSL_EMIF2_EIMCR_WRMCLR_MASK (0x00000004u)
#define CSL_EMIF2_EIMCR_WRMCLR_SHIFT (0x00000002u)
#define CSL_EMIF2_EIMCR_WRMCLR_RESETVAL (0x00000000u)
/*----WRMCLR Tokens----*/
#define CSL_EMIF2_EIMCR_WRMCLR_CLEAR (0x00000001u)


#define CSL_EMIF2_EIMCR_ATMCLR_MASK (0x00000001u)
#define CSL_EMIF2_EIMCR_ATMCLR_SHIFT (0x00000000u)
#define CSL_EMIF2_EIMCR_ATMCLR_RESETVAL (0x00000000u)
/*----ATMCLR Tokens----*/
#define CSL_EMIF2_EIMCR_ATMCLR_CLEAR (0x00000001u)

#define CSL_EMIF2_EIMCR_RESETVAL (0x00000000u)

/* NANDFCR */


#define CSL_EMIF2_NANDFCR_CS5ECC_MASK (0x00000800u)
#define CSL_EMIF2_NANDFCR_CS5ECC_SHIFT (0x0000000Bu)
#define CSL_EMIF2_NANDFCR_CS5ECC_RESETVAL (0x00000000u)
/*----CS5ECC Tokens----*/
#define CSL_EMIF2_NANDFCR_CS5ECC_NO_ECC (0x00000000u)
#define CSL_EMIF2_NANDFCR_CS5ECC_ECC_START (0x00000001u)

#define CSL_EMIF2_NANDFCR_CS4ECC_MASK (0x00000400u)
#define CSL_EMIF2_NANDFCR_CS4ECC_SHIFT (0x0000000Au)
#define CSL_EMIF2_NANDFCR_CS4ECC_RESETVAL (0x00000000u)
/*----CS4ECC Tokens----*/
#define CSL_EMIF2_NANDFCR_CS4ECC_NO_ECC (0x00000000u)
#define CSL_EMIF2_NANDFCR_CS4ECC_ECC_START (0x00000001u)

#define CSL_EMIF2_NANDFCR_CS3ECC_MASK (0x00000200u)
#define CSL_EMIF2_NANDFCR_CS3ECC_SHIFT (0x00000009u)
#define CSL_EMIF2_NANDFCR_CS3ECC_RESETVAL (0x00000000u)
/*----CS3ECC Tokens----*/
#define CSL_EMIF2_NANDFCR_CS3ECC_NO_ECC (0x00000000u)
#define CSL_EMIF2_NANDFCR_CS3ECC_ECC_START (0x00000001u)

#define CSL_EMIF2_NANDFCR_CS2ECC_MASK (0x00000100u)
#define CSL_EMIF2_NANDFCR_CS2ECC_SHIFT (0x00000008u)
#define CSL_EMIF2_NANDFCR_CS2ECC_RESETVAL (0x00000000u)
/*----CS2ECC Tokens----*/
#define CSL_EMIF2_NANDFCR_CS2ECC_NO_ECC (0x00000000u)
#define CSL_EMIF2_NANDFCR_CS2ECC_ECC_START (0x00000001u)


#define CSL_EMIF2_NANDFCR_CS5NAND_MASK (0x00000008u)
#define CSL_EMIF2_NANDFCR_CS5NAND_SHIFT (0x00000003u)
#define CSL_EMIF2_NANDFCR_CS5NAND_RESETVAL (0x00000000u)
/*----CS5NAND Tokens----*/
#define CSL_EMIF2_NANDFCR_CS5NAND_NO_NAND (0x00000000u)
#define CSL_EMIF2_NANDFCR_CS5NAND_NAND (0x00000001u)

#define CSL_EMIF2_NANDFCR_CS4NAND_MASK (0x00000004u)
#define CSL_EMIF2_NANDFCR_CS4NAND_SHIFT (0x00000002u)
#define CSL_EMIF2_NANDFCR_CS4NAND_RESETVAL (0x00000000u)
/*----CS4NAND Tokens----*/
#define CSL_EMIF2_NANDFCR_CS4NAND_NO_NAND (0x00000000u)
#define CSL_EMIF2_NANDFCR_CS4NAND_NAND (0x00000001u)

#define CSL_EMIF2_NANDFCR_CS3NAND_MASK (0x00000002u)
#define CSL_EMIF2_NANDFCR_CS3NAND_SHIFT (0x00000001u)
#define CSL_EMIF2_NANDFCR_CS3NAND_RESETVAL (0x00000000u)
/*----CS3NAND Tokens----*/
#define CSL_EMIF2_NANDFCR_CS3NAND_NO_NAND (0x00000000u)
#define CSL_EMIF2_NANDFCR_CS3NAND_NAND (0x00000001u)

#define CSL_EMIF2_NANDFCR_CS2NAND_MASK (0x00000001u)
#define CSL_EMIF2_NANDFCR_CS2NAND_SHIFT (0x00000000u)
#define CSL_EMIF2_NANDFCR_CS2NAND_RESETVAL (0x00000000u)
/*----CS2NAND Tokens----*/
#define CSL_EMIF2_NANDFCR_CS2NAND_NO_NAND (0x00000000u)
#define CSL_EMIF2_NANDFCR_CS2NAND_NAND (0x00000001u)

#define CSL_EMIF2_NANDFCR_RESETVAL (0x00000000u)

/* NANDFSR */


#define CSL_EMIF2_NANDFSR_WAITST_MASK (0x0000000Fu)
#define CSL_EMIF2_NANDFSR_WAITST_SHIFT (0x00000000u)
#define CSL_EMIF2_NANDFSR_WAITST_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDFSR_RESETVAL (0x00000000u)

/* NANDF1ECC */


#define CSL_EMIF2_NANDF1ECC_P2048O_MASK (0x08000000u)
#define CSL_EMIF2_NANDF1ECC_P2048O_SHIFT (0x0000001Bu)
#define CSL_EMIF2_NANDF1ECC_P2048O_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF1ECC_P1024O_MASK (0x04000000u)
#define CSL_EMIF2_NANDF1ECC_P1024O_SHIFT (0x0000001Au)
#define CSL_EMIF2_NANDF1ECC_P1024O_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF1ECC_P512O_MASK (0x02000000u)
#define CSL_EMIF2_NANDF1ECC_P512O_SHIFT (0x00000019u)
#define CSL_EMIF2_NANDF1ECC_P512O_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF1ECC_P256O_MASK (0x01000000u)
#define CSL_EMIF2_NANDF1ECC_P256O_SHIFT (0x00000018u)
#define CSL_EMIF2_NANDF1ECC_P256O_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF1ECC_P128O_MASK (0x00800000u)
#define CSL_EMIF2_NANDF1ECC_P128O_SHIFT (0x00000017u)
#define CSL_EMIF2_NANDF1ECC_P128O_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF1ECC_P64O_MASK (0x00400000u)
#define CSL_EMIF2_NANDF1ECC_P64O_SHIFT (0x00000016u)
#define CSL_EMIF2_NANDF1ECC_P64O_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF1ECC_P32O_MASK (0x00200000u)
#define CSL_EMIF2_NANDF1ECC_P32O_SHIFT (0x00000015u)
#define CSL_EMIF2_NANDF1ECC_P32O_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF1ECC_P16O_MASK (0x00100000u)
#define CSL_EMIF2_NANDF1ECC_P16O_SHIFT (0x00000014u)
#define CSL_EMIF2_NANDF1ECC_P16O_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF1ECC_P8O_MASK (0x00080000u)
#define CSL_EMIF2_NANDF1ECC_P8O_SHIFT (0x00000013u)
#define CSL_EMIF2_NANDF1ECC_P8O_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF1ECC_P4O_MASK (0x00040000u)
#define CSL_EMIF2_NANDF1ECC_P4O_SHIFT (0x00000012u)
#define CSL_EMIF2_NANDF1ECC_P4O_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF1ECC_P2O_MASK (0x00020000u)
#define CSL_EMIF2_NANDF1ECC_P2O_SHIFT (0x00000011u)
#define CSL_EMIF2_NANDF1ECC_P2O_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF1ECC_P1O_MASK (0x00010000u)
#define CSL_EMIF2_NANDF1ECC_P1O_SHIFT (0x00000010u)
#define CSL_EMIF2_NANDF1ECC_P1O_RESETVAL (0x00000000u)


#define CSL_EMIF2_NANDF1ECC_P2048E_MASK (0x00000800u)
#define CSL_EMIF2_NANDF1ECC_P2048E_SHIFT (0x0000000Bu)
#define CSL_EMIF2_NANDF1ECC_P2048E_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF1ECC_P1024E_MASK (0x00000400u)
#define CSL_EMIF2_NANDF1ECC_P1024E_SHIFT (0x0000000Au)
#define CSL_EMIF2_NANDF1ECC_P1024E_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF1ECC_P512E_MASK (0x00000200u)
#define CSL_EMIF2_NANDF1ECC_P512E_SHIFT (0x00000009u)
#define CSL_EMIF2_NANDF1ECC_P512E_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF1ECC_P256E_MASK (0x00000100u)
#define CSL_EMIF2_NANDF1ECC_P256E_SHIFT (0x00000008u)
#define CSL_EMIF2_NANDF1ECC_P256E_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF1ECC_P128E_MASK (0x00000080u)
#define CSL_EMIF2_NANDF1ECC_P128E_SHIFT (0x00000007u)
#define CSL_EMIF2_NANDF1ECC_P128E_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF1ECC_P64E_MASK (0x00000040u)
#define CSL_EMIF2_NANDF1ECC_P64E_SHIFT (0x00000006u)
#define CSL_EMIF2_NANDF1ECC_P64E_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF1ECC_P32E_MASK (0x00000020u)
#define CSL_EMIF2_NANDF1ECC_P32E_SHIFT (0x00000005u)
#define CSL_EMIF2_NANDF1ECC_P32E_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF1ECC_P16E_MASK (0x00000010u)
#define CSL_EMIF2_NANDF1ECC_P16E_SHIFT (0x00000004u)
#define CSL_EMIF2_NANDF1ECC_P16E_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF1ECC_P8E_MASK (0x00000008u)
#define CSL_EMIF2_NANDF1ECC_P8E_SHIFT (0x00000003u)
#define CSL_EMIF2_NANDF1ECC_P8E_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF1ECC_P4E_MASK (0x00000004u)
#define CSL_EMIF2_NANDF1ECC_P4E_SHIFT (0x00000002u)
#define CSL_EMIF2_NANDF1ECC_P4E_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF1ECC_P2E_MASK (0x00000002u)
#define CSL_EMIF2_NANDF1ECC_P2E_SHIFT (0x00000001u)
#define CSL_EMIF2_NANDF1ECC_P2E_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF1ECC_P1E_MASK (0x00000001u)
#define CSL_EMIF2_NANDF1ECC_P1E_SHIFT (0x00000000u)
#define CSL_EMIF2_NANDF1ECC_P1E_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF1ECC_RESETVAL (0x00000000u)

/* NANDF2ECC */


#define CSL_EMIF2_NANDF2ECC_P2048O_MASK (0x08000000u)
#define CSL_EMIF2_NANDF2ECC_P2048O_SHIFT (0x0000001Bu)
#define CSL_EMIF2_NANDF2ECC_P2048O_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF2ECC_P1024O_MASK (0x04000000u)
#define CSL_EMIF2_NANDF2ECC_P1024O_SHIFT (0x0000001Au)
#define CSL_EMIF2_NANDF2ECC_P1024O_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF2ECC_P512O_MASK (0x02000000u)
#define CSL_EMIF2_NANDF2ECC_P512O_SHIFT (0x00000019u)
#define CSL_EMIF2_NANDF2ECC_P512O_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF2ECC_P256O_MASK (0x01000000u)
#define CSL_EMIF2_NANDF2ECC_P256O_SHIFT (0x00000018u)
#define CSL_EMIF2_NANDF2ECC_P256O_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF2ECC_P128O_MASK (0x00800000u)
#define CSL_EMIF2_NANDF2ECC_P128O_SHIFT (0x00000017u)
#define CSL_EMIF2_NANDF2ECC_P128O_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF2ECC_P64O_MASK (0x00400000u)
#define CSL_EMIF2_NANDF2ECC_P64O_SHIFT (0x00000016u)
#define CSL_EMIF2_NANDF2ECC_P64O_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF2ECC_P32O_MASK (0x00200000u)
#define CSL_EMIF2_NANDF2ECC_P32O_SHIFT (0x00000015u)
#define CSL_EMIF2_NANDF2ECC_P32O_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF2ECC_P16O_MASK (0x00100000u)
#define CSL_EMIF2_NANDF2ECC_P16O_SHIFT (0x00000014u)
#define CSL_EMIF2_NANDF2ECC_P16O_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF2ECC_P8O_MASK (0x00080000u)
#define CSL_EMIF2_NANDF2ECC_P8O_SHIFT (0x00000013u)
#define CSL_EMIF2_NANDF2ECC_P8O_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF2ECC_P4O_MASK (0x00040000u)
#define CSL_EMIF2_NANDF2ECC_P4O_SHIFT (0x00000012u)
#define CSL_EMIF2_NANDF2ECC_P4O_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF2ECC_P2O_MASK (0x00020000u)
#define CSL_EMIF2_NANDF2ECC_P2O_SHIFT (0x00000011u)
#define CSL_EMIF2_NANDF2ECC_P2O_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF2ECC_P1O_MASK (0x00010000u)
#define CSL_EMIF2_NANDF2ECC_P1O_SHIFT (0x00000010u)
#define CSL_EMIF2_NANDF2ECC_P1O_RESETVAL (0x00000000u)


#define CSL_EMIF2_NANDF2ECC_P2048E_MASK (0x00000800u)
#define CSL_EMIF2_NANDF2ECC_P2048E_SHIFT (0x0000000Bu)
#define CSL_EMIF2_NANDF2ECC_P2048E_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF2ECC_P1024E_MASK (0x00000400u)
#define CSL_EMIF2_NANDF2ECC_P1024E_SHIFT (0x0000000Au)
#define CSL_EMIF2_NANDF2ECC_P1024E_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF2ECC_P512E_MASK (0x00000200u)
#define CSL_EMIF2_NANDF2ECC_P512E_SHIFT (0x00000009u)
#define CSL_EMIF2_NANDF2ECC_P512E_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF2ECC_P256E_MASK (0x00000100u)
#define CSL_EMIF2_NANDF2ECC_P256E_SHIFT (0x00000008u)
#define CSL_EMIF2_NANDF2ECC_P256E_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF2ECC_P128E_MASK (0x00000080u)
#define CSL_EMIF2_NANDF2ECC_P128E_SHIFT (0x00000007u)
#define CSL_EMIF2_NANDF2ECC_P128E_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF2ECC_P64E_MASK (0x00000040u)
#define CSL_EMIF2_NANDF2ECC_P64E_SHIFT (0x00000006u)
#define CSL_EMIF2_NANDF2ECC_P64E_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF2ECC_P32E_MASK (0x00000020u)
#define CSL_EMIF2_NANDF2ECC_P32E_SHIFT (0x00000005u)
#define CSL_EMIF2_NANDF2ECC_P32E_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF2ECC_P16E_MASK (0x00000010u)
#define CSL_EMIF2_NANDF2ECC_P16E_SHIFT (0x00000004u)
#define CSL_EMIF2_NANDF2ECC_P16E_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF2ECC_P8E_MASK (0x00000008u)
#define CSL_EMIF2_NANDF2ECC_P8E_SHIFT (0x00000003u)
#define CSL_EMIF2_NANDF2ECC_P8E_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF2ECC_P4E_MASK (0x00000004u)
#define CSL_EMIF2_NANDF2ECC_P4E_SHIFT (0x00000002u)
#define CSL_EMIF2_NANDF2ECC_P4E_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF2ECC_P2E_MASK (0x00000002u)
#define CSL_EMIF2_NANDF2ECC_P2E_SHIFT (0x00000001u)
#define CSL_EMIF2_NANDF2ECC_P2E_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF2ECC_P1E_MASK (0x00000001u)
#define CSL_EMIF2_NANDF2ECC_P1E_SHIFT (0x00000000u)
#define CSL_EMIF2_NANDF2ECC_P1E_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF2ECC_RESETVAL (0x00000000u)

/* NANDF3ECC */


#define CSL_EMIF2_NANDF3ECC_P2048O_MASK (0x08000000u)
#define CSL_EMIF2_NANDF3ECC_P2048O_SHIFT (0x0000001Bu)
#define CSL_EMIF2_NANDF3ECC_P2048O_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF3ECC_P1024O_MASK (0x04000000u)
#define CSL_EMIF2_NANDF3ECC_P1024O_SHIFT (0x0000001Au)
#define CSL_EMIF2_NANDF3ECC_P1024O_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF3ECC_P512O_MASK (0x02000000u)
#define CSL_EMIF2_NANDF3ECC_P512O_SHIFT (0x00000019u)
#define CSL_EMIF2_NANDF3ECC_P512O_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF3ECC_P256O_MASK (0x01000000u)
#define CSL_EMIF2_NANDF3ECC_P256O_SHIFT (0x00000018u)
#define CSL_EMIF2_NANDF3ECC_P256O_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF3ECC_P128O_MASK (0x00800000u)
#define CSL_EMIF2_NANDF3ECC_P128O_SHIFT (0x00000017u)
#define CSL_EMIF2_NANDF3ECC_P128O_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF3ECC_P64O_MASK (0x00400000u)
#define CSL_EMIF2_NANDF3ECC_P64O_SHIFT (0x00000016u)
#define CSL_EMIF2_NANDF3ECC_P64O_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF3ECC_P32O_MASK (0x00200000u)
#define CSL_EMIF2_NANDF3ECC_P32O_SHIFT (0x00000015u)
#define CSL_EMIF2_NANDF3ECC_P32O_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF3ECC_P16O_MASK (0x00100000u)
#define CSL_EMIF2_NANDF3ECC_P16O_SHIFT (0x00000014u)
#define CSL_EMIF2_NANDF3ECC_P16O_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF3ECC_P8O_MASK (0x00080000u)
#define CSL_EMIF2_NANDF3ECC_P8O_SHIFT (0x00000013u)
#define CSL_EMIF2_NANDF3ECC_P8O_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF3ECC_P4O_MASK (0x00040000u)
#define CSL_EMIF2_NANDF3ECC_P4O_SHIFT (0x00000012u)
#define CSL_EMIF2_NANDF3ECC_P4O_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF3ECC_P2O_MASK (0x00020000u)
#define CSL_EMIF2_NANDF3ECC_P2O_SHIFT (0x00000011u)
#define CSL_EMIF2_NANDF3ECC_P2O_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF3ECC_P1O_MASK (0x00010000u)
#define CSL_EMIF2_NANDF3ECC_P1O_SHIFT (0x00000010u)
#define CSL_EMIF2_NANDF3ECC_P1O_RESETVAL (0x00000000u)


#define CSL_EMIF2_NANDF3ECC_P2048E_MASK (0x00000800u)
#define CSL_EMIF2_NANDF3ECC_P2048E_SHIFT (0x0000000Bu)
#define CSL_EMIF2_NANDF3ECC_P2048E_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF3ECC_P1024E_MASK (0x00000400u)
#define CSL_EMIF2_NANDF3ECC_P1024E_SHIFT (0x0000000Au)
#define CSL_EMIF2_NANDF3ECC_P1024E_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF3ECC_P512E_MASK (0x00000200u)
#define CSL_EMIF2_NANDF3ECC_P512E_SHIFT (0x00000009u)
#define CSL_EMIF2_NANDF3ECC_P512E_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF3ECC_P256E_MASK (0x00000100u)
#define CSL_EMIF2_NANDF3ECC_P256E_SHIFT (0x00000008u)
#define CSL_EMIF2_NANDF3ECC_P256E_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF3ECC_P128E_MASK (0x00000080u)
#define CSL_EMIF2_NANDF3ECC_P128E_SHIFT (0x00000007u)
#define CSL_EMIF2_NANDF3ECC_P128E_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF3ECC_P64E_MASK (0x00000040u)
#define CSL_EMIF2_NANDF3ECC_P64E_SHIFT (0x00000006u)
#define CSL_EMIF2_NANDF3ECC_P64E_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF3ECC_P32E_MASK (0x00000020u)
#define CSL_EMIF2_NANDF3ECC_P32E_SHIFT (0x00000005u)
#define CSL_EMIF2_NANDF3ECC_P32E_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF3ECC_P16E_MASK (0x00000010u)
#define CSL_EMIF2_NANDF3ECC_P16E_SHIFT (0x00000004u)
#define CSL_EMIF2_NANDF3ECC_P16E_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF3ECC_P8E_MASK (0x00000008u)
#define CSL_EMIF2_NANDF3ECC_P8E_SHIFT (0x00000003u)
#define CSL_EMIF2_NANDF3ECC_P8E_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF3ECC_P4E_MASK (0x00000004u)
#define CSL_EMIF2_NANDF3ECC_P4E_SHIFT (0x00000002u)
#define CSL_EMIF2_NANDF3ECC_P4E_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF3ECC_P2E_MASK (0x00000002u)
#define CSL_EMIF2_NANDF3ECC_P2E_SHIFT (0x00000001u)
#define CSL_EMIF2_NANDF3ECC_P2E_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF3ECC_P1E_MASK (0x00000001u)
#define CSL_EMIF2_NANDF3ECC_P1E_SHIFT (0x00000000u)
#define CSL_EMIF2_NANDF3ECC_P1E_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF3ECC_RESETVAL (0x00000000u)

/* NANDF4ECC */


#define CSL_EMIF2_NANDF4ECC_P2048O_MASK (0x08000000u)
#define CSL_EMIF2_NANDF4ECC_P2048O_SHIFT (0x0000001Bu)
#define CSL_EMIF2_NANDF4ECC_P2048O_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF4ECC_P1024O_MASK (0x04000000u)
#define CSL_EMIF2_NANDF4ECC_P1024O_SHIFT (0x0000001Au)
#define CSL_EMIF2_NANDF4ECC_P1024O_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF4ECC_P512O_MASK (0x02000000u)
#define CSL_EMIF2_NANDF4ECC_P512O_SHIFT (0x00000019u)
#define CSL_EMIF2_NANDF4ECC_P512O_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF4ECC_P256O_MASK (0x01000000u)
#define CSL_EMIF2_NANDF4ECC_P256O_SHIFT (0x00000018u)
#define CSL_EMIF2_NANDF4ECC_P256O_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF4ECC_P128O_MASK (0x00800000u)
#define CSL_EMIF2_NANDF4ECC_P128O_SHIFT (0x00000017u)
#define CSL_EMIF2_NANDF4ECC_P128O_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF4ECC_P64O_MASK (0x00400000u)
#define CSL_EMIF2_NANDF4ECC_P64O_SHIFT (0x00000016u)
#define CSL_EMIF2_NANDF4ECC_P64O_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF4ECC_P32O_MASK (0x00200000u)
#define CSL_EMIF2_NANDF4ECC_P32O_SHIFT (0x00000015u)
#define CSL_EMIF2_NANDF4ECC_P32O_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF4ECC_P16O_MASK (0x00100000u)
#define CSL_EMIF2_NANDF4ECC_P16O_SHIFT (0x00000014u)
#define CSL_EMIF2_NANDF4ECC_P16O_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF4ECC_P8O_MASK (0x00080000u)
#define CSL_EMIF2_NANDF4ECC_P8O_SHIFT (0x00000013u)
#define CSL_EMIF2_NANDF4ECC_P8O_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF4ECC_P4O_MASK (0x00040000u)
#define CSL_EMIF2_NANDF4ECC_P4O_SHIFT (0x00000012u)
#define CSL_EMIF2_NANDF4ECC_P4O_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF4ECC_P2O_MASK (0x00020000u)
#define CSL_EMIF2_NANDF4ECC_P2O_SHIFT (0x00000011u)
#define CSL_EMIF2_NANDF4ECC_P2O_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF4ECC_P1O_MASK (0x00010000u)
#define CSL_EMIF2_NANDF4ECC_P1O_SHIFT (0x00000010u)
#define CSL_EMIF2_NANDF4ECC_P1O_RESETVAL (0x00000000u)


#define CSL_EMIF2_NANDF4ECC_P2048E_MASK (0x00000800u)
#define CSL_EMIF2_NANDF4ECC_P2048E_SHIFT (0x0000000Bu)
#define CSL_EMIF2_NANDF4ECC_P2048E_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF4ECC_P1024E_MASK (0x00000400u)
#define CSL_EMIF2_NANDF4ECC_P1024E_SHIFT (0x0000000Au)
#define CSL_EMIF2_NANDF4ECC_P1024E_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF4ECC_P512E_MASK (0x00000200u)
#define CSL_EMIF2_NANDF4ECC_P512E_SHIFT (0x00000009u)
#define CSL_EMIF2_NANDF4ECC_P512E_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF4ECC_P256E_MASK (0x00000100u)
#define CSL_EMIF2_NANDF4ECC_P256E_SHIFT (0x00000008u)
#define CSL_EMIF2_NANDF4ECC_P256E_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF4ECC_P128E_MASK (0x00000080u)
#define CSL_EMIF2_NANDF4ECC_P128E_SHIFT (0x00000007u)
#define CSL_EMIF2_NANDF4ECC_P128E_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF4ECC_P64E_MASK (0x00000040u)
#define CSL_EMIF2_NANDF4ECC_P64E_SHIFT (0x00000006u)
#define CSL_EMIF2_NANDF4ECC_P64E_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF4ECC_P32E_MASK (0x00000020u)
#define CSL_EMIF2_NANDF4ECC_P32E_SHIFT (0x00000005u)
#define CSL_EMIF2_NANDF4ECC_P32E_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF4ECC_P16E_MASK (0x00000010u)
#define CSL_EMIF2_NANDF4ECC_P16E_SHIFT (0x00000004u)
#define CSL_EMIF2_NANDF4ECC_P16E_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF4ECC_P8E_MASK (0x00000008u)
#define CSL_EMIF2_NANDF4ECC_P8E_SHIFT (0x00000003u)
#define CSL_EMIF2_NANDF4ECC_P8E_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF4ECC_P4E_MASK (0x00000004u)
#define CSL_EMIF2_NANDF4ECC_P4E_SHIFT (0x00000002u)
#define CSL_EMIF2_NANDF4ECC_P4E_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF4ECC_P2E_MASK (0x00000002u)
#define CSL_EMIF2_NANDF4ECC_P2E_SHIFT (0x00000001u)
#define CSL_EMIF2_NANDF4ECC_P2E_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF4ECC_P1E_MASK (0x00000001u)
#define CSL_EMIF2_NANDF4ECC_P1E_SHIFT (0x00000000u)
#define CSL_EMIF2_NANDF4ECC_P1E_RESETVAL (0x00000000u)

#define CSL_EMIF2_NANDF4ECC_RESETVAL (0x00000000u)

#ifdef __cplusplus
}
#endif

#endif


