/* =============================================================================
 *  Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005, 2006
 *
 *  Use of this software is controlled by the terms and conditions found in the
 *  license agreement under which this software has been supplied.
 *  ============================================================================
 */
/** ============================================================================
 *   file   cslr_sys.h
 *
 *   @path  $(CSLPATH)\inc
 *
 *  @desc  This file contains the Register Desciptions for SYS
 *  ============================================================================
 */
#ifndef _CSLR_SYS_H_
#define _CSLR_SYS_H_

#ifdef __cplusplus
extern "C" {
#endif

#include <ti/sdo/pspdrivers/soc/c6424/dsp/cslr.h>

#include <ti/sdo/pspdrivers/soc/c6424/dsp/tistdtypes.h>


/* Minimum unit = 1 byte */

/**************************************************************************\
* Register Overlay Structure
\**************************************************************************/
typedef struct  {
    volatile Uint32 PINMUX0;
    volatile Uint32 PINMUX1;
    volatile Uint32 DSPBOOTADDR;
    volatile Uint32 BOOTCOMPLT;
    volatile Uint8 RSVD0[4];
    volatile Uint32 BOOTCFG;
    volatile Uint8 RSVD1[16];
    volatile Uint32 DEVICE_ID;
    volatile Uint8 RSVD2[4];
    volatile Uint32 UHPICTL;
    volatile Uint8 RSVD3[8];
    volatile Uint32 MSTPRI0;
    volatile Uint32 MSTPRI1;
    volatile Uint32 VPSS_CLKCTL;
    volatile Uint32 VDD3P3V_PWDN;
    volatile Uint32 DDRVTPER;
    volatile Uint8 RSVD4[52];
    volatile Uint32 TIMERCTL ;
    volatile Uint32 EDMATCCFG ;
    volatile Uint8 RSVD5[8108];
    volatile Uint32 DDRVTPR;
} CSL_SysRegs;

/**************************************************************************\
* Overlay structure typedef definition
\**************************************************************************/
typedef volatile CSL_SysRegs  *CSL_SysRegsOvly;

/**************************************************************************\
* Field Definition Macros
\**************************************************************************/

/* PINMUX0 */


#define CSL_SYS_PINMUX0_CI10SEL_MASK (0x40000000u)
#define CSL_SYS_PINMUX0_CI10SEL_SHIFT (0x0000001Eu)
#define CSL_SYS_PINMUX0_CI10SEL_RESETVAL (0x00000000u)


#define CSL_SYS_PINMUX0_CI32SEL_MASK (0x10000000u)
#define CSL_SYS_PINMUX0_CI32SEL_SHIFT (0x0000001Cu)
#define CSL_SYS_PINMUX0_CI32SEL_RESETVAL (0x00000000u)


#define CSL_SYS_PINMUX0_CI54SEL_MASK (0x04000000u)
#define CSL_SYS_PINMUX0_CI54SEL_SHIFT (0x0000001Au)
#define CSL_SYS_PINMUX0_CI54SEL_RESETVAL (0x00000000u)

#define CSL_SYS_PINMUX0_CI76SEL_MASK (0x02000000u)
#define CSL_SYS_PINMUX0_CI76SEL_SHIFT (0x00000019u)
#define CSL_SYS_PINMUX0_CI76SEL_RESETVAL (0x00000000u)

#define CSL_SYS_PINMUX0_CFLDSEL_MASK (0x01000000u)
#define CSL_SYS_PINMUX0_CFLDSEL_SHIFT (0x00000018u)
#define CSL_SYS_PINMUX0_CFLDSEL_RESETVAL (0x00000000u)

#define CSL_SYS_PINMUX0_CWENSEL_MASK (0x00800000u)
#define CSL_SYS_PINMUX0_CWENSEL_SHIFT (0x00000017u)
#define CSL_SYS_PINMUX0_CWENSEL_RESETVAL (0x00000000u)

#define CSL_SYS_PINMUX0_HVDSEL_MASK (0x00400000u)
#define CSL_SYS_PINMUX0_HVDSEL_SHIFT (0x00000016u)
#define CSL_SYS_PINMUX0_HVDSEL_RESETVAL (0x00000000u)


#define CSL_SYS_PINMUX0_CCDCSEL_MASK (0x00100000u)
#define CSL_SYS_PINMUX0_CCDCSEL_SHIFT (0x00000014u)
#define CSL_SYS_PINMUX0_CCDCSEL_RESETVAL (0x00000000u)


#define CSL_SYS_PINMUX0_AEAW_MASK (0x00070000u)
#define CSL_SYS_PINMUX0_AEAW_SHIFT (0x00000010u)
#define CSL_SYS_PINMUX0_AEAW_RESETVAL (0x00000000u)

#define CSL_SYS_PINMUX0_VPBECKEN_MASK (0x00008000u)
#define CSL_SYS_PINMUX0_VPBECKEN_SHIFT (0x0000000Fu)
#define CSL_SYS_PINMUX0_VPBECKEN_RESETVAL (0x00000000u)

#define CSL_SYS_PINMUX0_RGBSEL_MASK (0x00007000u)
#define CSL_SYS_PINMUX0_RGBSEL_SHIFT (0x0000000Cu)
#define CSL_SYS_PINMUX0_RGBSEL_RESETVAL (0x00000000u)

#define CSL_SYS_PINMUX0_CS3SEL_MASK (0x00000C00u)
#define CSL_SYS_PINMUX0_CS3SEL_SHIFT (0x0000000Au)
#define CSL_SYS_PINMUX0_CS3SEL_RESETVAL (0x00000000u)

#define CSL_SYS_PINMUX0_CS4SEL_MASK (0x00000300u)
#define CSL_SYS_PINMUX0_CS4SEL_SHIFT (0x00000008u)
#define CSL_SYS_PINMUX0_CS4SEL_RESETVAL (0x00000000u)

#define CSL_SYS_PINMUX0_CS5SEL_MASK (0x000000C0u)
#define CSL_SYS_PINMUX0_CS5SEL_SHIFT (0x00000006u)
#define CSL_SYS_PINMUX0_CS5SEL_RESETVAL (0x00000000u)

#define CSL_SYS_PINMUX0_VENCSEL_MASK (0x00000030u)
#define CSL_SYS_PINMUX0_VENCSEL_SHIFT (0x00000004u)
#define CSL_SYS_PINMUX0_VENCSEL_RESETVAL (0x00000000u)

#define CSL_SYS_PINMUX0_RMII_MASK (0x00000008u)
#define CSL_SYS_PINMUX0_RMII_SHIFT (0x00000003u)
#define CSL_SYS_PINMUX0_RMII_RESETVAL (0x00000000u)

#define CSL_SYS_PINMUX0_AEM_MASK (0x00000007u)
#define CSL_SYS_PINMUX0_AEM_SHIFT (0x00000000u)
#define CSL_SYS_PINMUX0_AEM_RESETVAL (0x00000000u)
/*----AEM Tokens----*/
#define CSL_SYS_PINMUX0_AEM_NO_AEMIF (0x00000000u)
#define CSL_SYS_PINMUX0_AEM_8BIT (0x00000001u)
#define CSL_SYS_PINMUX0_AEM_16BIT_ASYNC_EMIF (0x00000002u)

#define CSL_SYS_PINMUX0_RESETVAL (0x00000000u)

/* PINMUX1 */


#define CSL_SYS_PINMUX1_SPBK1_MASK (0x03000000u)
#define CSL_SYS_PINMUX1_SPBK1_SHIFT (0x00000018u)
#define CSL_SYS_PINMUX1_SPBK1_RESETVAL (0x00000000u)

#define CSL_SYS_PINMUX1_SPBK0_MASK (0x00C00000u)
#define CSL_SYS_PINMUX1_SPBK0_SHIFT (0x00000016u)
#define CSL_SYS_PINMUX1_SPBK0_RESETVAL (0x00000000u)

#define CSL_SYS_PINMUX1_TIM1BK_MASK (0x00300000u)
#define CSL_SYS_PINMUX1_TIM1BK_SHIFT (0x00000014u)
#define CSL_SYS_PINMUX1_TIM1BK_RESETVAL (0x00000000u)


#define CSL_SYS_PINMUX1_TIM0BK_MASK (0x00030000u)
#define CSL_SYS_PINMUX1_TIM0BK_SHIFT (0x00000010u)
#define CSL_SYS_PINMUX1_TIM0BK_RESETVAL (0x00000000u)

#define CSL_SYS_PINMUX1_CKOBK_MASK (0x0000C000u)
#define CSL_SYS_PINMUX1_CKOBK_SHIFT (0x0000000Eu)
#define CSL_SYS_PINMUX1_CKOBK_RESETVAL (0x00000000u)


#define CSL_SYS_PINMUX1_PWM1BK_MASK (0x00001000u)
#define CSL_SYS_PINMUX1_PWM1BK_SHIFT (0x0000000Cu)
#define CSL_SYS_PINMUX1_PWM1BK_RESETVAL (0x00000000u)

#define CSL_SYS_PINMUX1_UR0FCBK_MASK (0x00000C00u)
#define CSL_SYS_PINMUX1_UR0FCBK_SHIFT (0x0000000Au)
#define CSL_SYS_PINMUX1_UR0FCBK_RESETVAL (0x00000000u)


#define CSL_SYS_PINMUX1_UR0DBK_MASK (0x00000100u)
#define CSL_SYS_PINMUX1_UR0DBK_SHIFT (0x00000008u)
#define CSL_SYS_PINMUX1_UR0DBK_RESETVAL (0x00000000u)


#define CSL_SYS_PINMUX1_HOSTBK_MASK (0x00000070u)
#define CSL_SYS_PINMUX1_HOSTBK_SHIFT (0x00000004u)
#define CSL_SYS_PINMUX1_HOSTBK_RESETVAL (0x00000000u)


#define CSL_SYS_PINMUX1_PCIEN_MASK (0x00000001u)
#define CSL_SYS_PINMUX1_PCIEN_SHIFT (0x00000000u)
#define CSL_SYS_PINMUX1_PCIEN_RESETVAL (0x00000000u)

#define CSL_SYS_PINMUX1_RESETVAL (0x00000000u)

/* DSPBOOTADDR */

#define CSL_SYS_DSPBOOTADDR_DSPBOOTADDR_MASK (0xFFFFFFFFu)
#define CSL_SYS_DSPBOOTADDR_DSPBOOTADDR_SHIFT (0x00000000u)
#define CSL_SYS_DSPBOOTADDR_DSPBOOTADDR_RESETVAL (0x00000000u)

#define CSL_SYS_DSPBOOTADDR_RESETVAL (0x00000000u)

/* BOOTCOMPLT */


#define CSL_SYS_BOOTCOMPLT_ERR_MASK (0x000F0000u)
#define CSL_SYS_BOOTCOMPLT_ERR_SHIFT (0x00000010u)
#define CSL_SYS_BOOTCOMPLT_ERR_RESETVAL (0x00000000u)


#define CSL_SYS_BOOTCOMPLT_BC_MASK (0x00000001u)
#define CSL_SYS_BOOTCOMPLT_BC_SHIFT (0x00000000u)
#define CSL_SYS_BOOTCOMPLT_BC_RESETVAL (0x00000000u)

#define CSL_SYS_BOOTCOMPLT_RESETVAL (0x00000000u)

/* BOOTCFG */


#define CSL_SYS_BOOTCFG_LENDIAN_MASK (0x00100000u)
#define CSL_SYS_BOOTCFG_LENDIAN_SHIFT (0x00000014u)
#define CSL_SYS_BOOTCFG_LENDIAN_RESETVAL (0x00000000u)

#define CSL_SYS_BOOTCFG_FASTBOOT_MASK (0x00080000u)
#define CSL_SYS_BOOTCFG_FASTBOOT_SHIFT (0x00000013u)
#define CSL_SYS_BOOTCFG_FASTBOOT_RESETVAL (0x00000000u)


#define CSL_SYS_BOOTCFG_DPCIEN_MASK (0x00020000u)
#define CSL_SYS_BOOTCFG_DPCIEN_SHIFT (0x00000011u)
#define CSL_SYS_BOOTCFG_DPCIEN_RESETVAL (0x00000000u)

#define CSL_SYS_BOOTCFG_8_16_MASK (0x00010000u)
#define CSL_SYS_BOOTCFG_8_16_SHIFT (0x00000010u)
#define CSL_SYS_BOOTCFG_8_16_RESETVAL (0x00000000u)


#define CSL_SYS_BOOTCFG_PLLMS_MASK (0x00007000u)
#define CSL_SYS_BOOTCFG_PLLMS_SHIFT (0x0000000Cu)
#define CSL_SYS_BOOTCFG_PLLMS_RESETVAL (0x00000000u)


#define CSL_SYS_BOOTCFG_DAEM_MASK (0x00000700u)
#define CSL_SYS_BOOTCFG_DAEM_SHIFT (0x00000008u)
#define CSL_SYS_BOOTCFG_DAEM_RESETVAL (0x00000000u)


#define CSL_SYS_BOOTCFG_BOOTMODE_MASK (0x0000000Fu)
#define CSL_SYS_BOOTCFG_BOOTMODE_SHIFT (0x00000000u)
#define CSL_SYS_BOOTCFG_BOOTMODE_RESETVAL (0x00000000u)

#define CSL_SYS_BOOTCFG_RESETVAL (0x00000000u)

/* DEVICE_ID */

#define CSL_SYS_DEVICE_ID_VARIANT_MASK (0xF0000000u)
#define CSL_SYS_DEVICE_ID_VARIANT_SHIFT (0x0000001Cu)
#define CSL_SYS_DEVICE_ID_VARIANT_RESETVAL (0x00000000u)

#define CSL_SYS_DEVICE_ID_PARTNUMBER_MASK (0x0FFFF000u)
#define CSL_SYS_DEVICE_ID_PARTNUMBER_SHIFT (0x0000000Cu)
#define CSL_SYS_DEVICE_ID_PARTNUMBER_RESETVAL (0x0000B700u)

#define CSL_SYS_DEVICE_ID_MANUFACTURER_MASK (0x00000FFEu)
#define CSL_SYS_DEVICE_ID_MANUFACTURER_SHIFT (0x00000001u)
#define CSL_SYS_DEVICE_ID_MANUFACTURER_RESETVAL (0x00000000u)


#define CSL_SYS_DEVICE_ID_RESETVAL (0x0B700001u)

/* UHPICTL */


#define CSL_SYS_UHPICTL_TIMOUT_MASK (0x000000FFu)
#define CSL_SYS_UHPICTL_TIMOUT_SHIFT (0x00000000u)
#define CSL_SYS_UHPICTL_TIMOUT_RESETVAL (0x00000080u)

#define CSL_SYS_UHPICTL_RESETVAL (0x00000080u)

/* MSTPRI0 */




#define CSL_SYS_MSTPRI0_C64XPLUS_CFGP_MASK (0x00000700u)
#define CSL_SYS_MSTPRI0_C64XPLUS_CFGP_SHIFT (0x00000008u)
#define CSL_SYS_MSTPRI0_C64XPLUS_CFGP_RESETVAL (0x00000001u)


#define CSL_SYS_MSTPRI0_RESETVAL (0x00050100u)

/* MSTPRI1 */


#define CSL_SYS_MSTPRI1_PCIP_MASK (0x07000000u)
#define CSL_SYS_MSTPRI1_PCIP_SHIFT (0x00000018u)
#define CSL_SYS_MSTPRI1_PCIP_RESETVAL (0x00000000u)


#define CSL_SYS_MSTPRI1_HPIP_MASK (0x00700000u)
#define CSL_SYS_MSTPRI1_HPIP_SHIFT (0x00000014u)
#define CSL_SYS_MSTPRI1_HPIP_RESETVAL (0x00000000u)


#define CSL_SYS_MSTPRI1_VLYNQP_MASK (0x00070000u)
#define CSL_SYS_MSTPRI1_VLYNQP_SHIFT (0x00000010u)
#define CSL_SYS_MSTPRI1_VLYNQP_RESETVAL (0x00000000u)


#define CSL_SYS_MSTPRI1_EMACP_MASK (0x00000007u)
#define CSL_SYS_MSTPRI1_EMACP_SHIFT (0x00000000u)
#define CSL_SYS_MSTPRI1_EMACP_RESETVAL (0x00000004u)

#define CSL_SYS_MSTPRI1_RESETVAL (0x00000004u)

/* VPSS_CLKCTL */


#define CSL_SYS_VPSS_CLKCTL_DACCLKEN_MASK (0x00000010u)
#define CSL_SYS_VPSS_CLKCTL_DACCLKEN_SHIFT (0x00000004u)
#define CSL_SYS_VPSS_CLKCTL_DACCLKEN_RESETVAL (0x00000000u)
/*----DACCLKEN Tokens----*/
#define CSL_SYS_VPSS_CLKCTL_DACCLKEN_DISABLE (0x00000000u)
#define CSL_SYS_VPSS_CLKCTL_DACCLKEN_ENABLE (0x00000001u)

#define CSL_SYS_VPSS_CLKCTL_VENCLKEN_MASK (0x00000008u)
#define CSL_SYS_VPSS_CLKCTL_VENCLKEN_SHIFT (0x00000003u)
#define CSL_SYS_VPSS_CLKCTL_VENCLKEN_RESETVAL (0x00000000u)
/*----VENCLKEN Tokens----*/
#define CSL_SYS_VPSS_CLKCTL_VENCLKEN_DISABLE (0x00000000u)
#define CSL_SYS_VPSS_CLKCTL_VENCLKEN_ENABLE (0x00000001u)

#define CSL_SYS_VPSS_CLKCTL_PCLKINV_MASK (0x00000004u)
#define CSL_SYS_VPSS_CLKCTL_PCLKINV_SHIFT (0x00000002u)
#define CSL_SYS_VPSS_CLKCTL_PCLKINV_RESETVAL (0x00000000u)
/*----PCLKINV Tokens----*/
#define CSL_SYS_VPSS_CLKCTL_PCLKINV_DISABLE (0x00000000u)
#define CSL_SYS_VPSS_CLKCTL_PCLKINV_ENABLE (0x00000001u)

#define CSL_SYS_VPSS_CLKCTL_MUXSEL_MASK (0x00000003u)
#define CSL_SYS_VPSS_CLKCTL_MUXSEL_SHIFT (0x00000000u)
#define CSL_SYS_VPSS_CLKCTL_MUXSEL_RESETVAL (0x00000000u)
/*----MUXSEL Tokens----*/
#define CSL_SYS_VPSS_CLKCTL_MUXSEL_27MHZ (0x00000000u)
#define CSL_SYS_VPSS_CLKCTL_MUXSEL_54MHZ (0x00000001u)
#define CSL_SYS_VPSS_CLKCTL_MUXSEL_VPBECLK (0x00000002u)
#define CSL_SYS_VPSS_CLKCTL_MUXSEL_PCLK (0x00000003u)

#define CSL_SYS_VPSS_CLKCTL_RESETVAL (0x00000000u)

/* VDD3P3V_PWDN */


#define CSL_SYS_VDD3P3V_PWDN_PCIDAT_MASK (0x00002000u)
#define CSL_SYS_VDD3P3V_PWDN_PCIDAT_SHIFT (0x0000000Du)
#define CSL_SYS_VDD3P3V_PWDN_PCIDAT_RESETVAL (0x00000000u)
/*----PCIDAT Tokens----*/
#define CSL_SYS_VDD3P3V_PWDN_PCIDAT_POWERUP (0x00000000u)
#define CSL_SYS_VDD3P3V_PWDN_PCIDAT_POWERDOWN (0x00000001u)

#define CSL_SYS_VDD3P3V_PWDN_EMBK3_MASK (0x00001000u)
#define CSL_SYS_VDD3P3V_PWDN_EMBK3_SHIFT (0x0000000Cu)
#define CSL_SYS_VDD3P3V_PWDN_EMBK3_RESETVAL (0x00000000u)
/*----EMBK3 Tokens----*/
#define CSL_SYS_VDD3P3V_PWDN_EMBK3_POWERUP (0x00000000u)
#define CSL_SYS_VDD3P3V_PWDN_EMBK3_POWERDOWN (0x00000001u)

#define CSL_SYS_VDD3P3V_PWDN_UR0FC_MASK (0x00000800u)
#define CSL_SYS_VDD3P3V_PWDN_UR0FC_SHIFT (0x0000000Bu)
#define CSL_SYS_VDD3P3V_PWDN_UR0FC_RESETVAL (0x00000001u)
/*----UR0FC Tokens----*/
#define CSL_SYS_VDD3P3V_PWDN_UR0FC_POWERUP (0x00000000u)
#define CSL_SYS_VDD3P3V_PWDN_UR0FC_POWERDOWN (0x00000001u)

#define CSL_SYS_VDD3P3V_PWDN_UR0DAT_MASK (0x00000400u)
#define CSL_SYS_VDD3P3V_PWDN_UR0DAT_SHIFT (0x0000000Au)
#define CSL_SYS_VDD3P3V_PWDN_UR0DAT_RESETVAL (0x00000001u)
/*----UR0DAT Tokens----*/
#define CSL_SYS_VDD3P3V_PWDN_UR0DAT_POWERUP (0x00000000u)
#define CSL_SYS_VDD3P3V_PWDN_UR0DAT_POWERDOWN (0x00000001u)

#define CSL_SYS_VDD3P3V_PWDN_TIMER1_MASK (0x00000200u)
#define CSL_SYS_VDD3P3V_PWDN_TIMER1_SHIFT (0x00000009u)
#define CSL_SYS_VDD3P3V_PWDN_TIMER1_RESETVAL (0x00000001u)
/*----TIMER1 Tokens----*/
#define CSL_SYS_VDD3P3V_PWDN_TIMER1_POWERUP (0x00000000u)
#define CSL_SYS_VDD3P3V_PWDN_TIMER1_POWERDOWN (0x00000001u)

#define CSL_SYS_VDD3P3V_PWDN_TIMER0_MASK (0x00000100u)
#define CSL_SYS_VDD3P3V_PWDN_TIMER0_SHIFT (0x00000008u)
#define CSL_SYS_VDD3P3V_PWDN_TIMER0_RESETVAL (0x00000001u)
/*----TIMER0 Tokens----*/
#define CSL_SYS_VDD3P3V_PWDN_TIMER0_POWERUP (0x00000000u)
#define CSL_SYS_VDD3P3V_PWDN_TIMER0_POWERDOWN (0x00000001u)

#define CSL_SYS_VDD3P3V_PWDN_SP_MASK (0x00000080u)
#define CSL_SYS_VDD3P3V_PWDN_SP_SHIFT (0x00000007u)
#define CSL_SYS_VDD3P3V_PWDN_SP_RESETVAL (0x00000001u)
/*----SP Tokens----*/
#define CSL_SYS_VDD3P3V_PWDN_SP_POWERUP (0x00000000u)
#define CSL_SYS_VDD3P3V_PWDN_SP_POWERDOWN (0x00000001u)

#define CSL_SYS_VDD3P3V_PWDN_PWM1_MASK (0x00000040u)
#define CSL_SYS_VDD3P3V_PWDN_PWM1_SHIFT (0x00000006u)
#define CSL_SYS_VDD3P3V_PWDN_PWM1_RESETVAL (0x00000001u)
/*----PWM1 Tokens----*/
#define CSL_SYS_VDD3P3V_PWDN_PWM1_POWERUP (0x00000000u)
#define CSL_SYS_VDD3P3V_PWDN_PWM1_POWERDOWN (0x00000001u)

#define CSL_SYS_VDD3P3V_PWDN_GPIO_MASK (0x00000020u)
#define CSL_SYS_VDD3P3V_PWDN_GPIO_SHIFT (0x00000005u)
#define CSL_SYS_VDD3P3V_PWDN_GPIO_RESETVAL (0x00000000u)
/*----GPIO Tokens----*/
#define CSL_SYS_VDD3P3V_PWDN_GPIO_POWERUP (0x00000000u)
#define CSL_SYS_VDD3P3V_PWDN_GPIO_POWERDOWN (0x00000001u)

#define CSL_SYS_VDD3P3V_PWDN_HOST_MASK (0x00000010u)
#define CSL_SYS_VDD3P3V_PWDN_HOST_SHIFT (0x00000004u)
#define CSL_SYS_VDD3P3V_PWDN_HOST_RESETVAL (0x00000000u)
/*----HOST Tokens----*/
#define CSL_SYS_VDD3P3V_PWDN_HOST_POWERUP (0x00000000u)
#define CSL_SYS_VDD3P3V_PWDN_HOST_POWERDOWN (0x00000001u)

#define CSL_SYS_VDD3P3V_PWDN_EMBK2_MASK (0x00000008u)
#define CSL_SYS_VDD3P3V_PWDN_EMBK2_SHIFT (0x00000003u)
#define CSL_SYS_VDD3P3V_PWDN_EMBK2_RESETVAL (0x00000000u)
/*----EMBK2 Tokens----*/
#define CSL_SYS_VDD3P3V_PWDN_EMBK2_POWERUP (0x00000000u)
#define CSL_SYS_VDD3P3V_PWDN_EMBK2_POWERDOWN (0x00000001u)

#define CSL_SYS_VDD3P3V_PWDN_EMBK1_MASK (0x00000004u)
#define CSL_SYS_VDD3P3V_PWDN_EMBK1_SHIFT (0x00000002u)
#define CSL_SYS_VDD3P3V_PWDN_EMBK1_RESETVAL (0x00000000u)
/*----EMBK1 Tokens----*/
#define CSL_SYS_VDD3P3V_PWDN_EMBK1_POWERUP (0x00000000u)
#define CSL_SYS_VDD3P3V_PWDN_EMBK1_POWERDOWN (0x00000001u)

#define CSL_SYS_VDD3P3V_PWDN_EMBK0_MASK (0x00000002u)
#define CSL_SYS_VDD3P3V_PWDN_EMBK0_SHIFT (0x00000001u)
#define CSL_SYS_VDD3P3V_PWDN_EMBK0_RESETVAL (0x00000000u)
/*----EMBK0 Tokens----*/
#define CSL_SYS_VDD3P3V_PWDN_EMBK0_POWERUP (0x00000000u)
#define CSL_SYS_VDD3P3V_PWDN_EMBK0_POWERDOWN (0x00000001u)

#define CSL_SYS_VDD3P3V_PWDN_CLKOUT_MASK (0x00000001u)
#define CSL_SYS_VDD3P3V_PWDN_CLKOUT_SHIFT (0x00000000u)
#define CSL_SYS_VDD3P3V_PWDN_CLKOUT_RESETVAL (0x00000000u)
/*----CLKOUT Tokens----*/
#define CSL_SYS_VDD3P3V_PWDN_CLKOUT_POWERUP (0x00000000u)
#define CSL_SYS_VDD3P3V_PWDN_CLKOUT_POWERDOWN (0x00000001u)

#define CSL_SYS_VDD3P3V_PWDN_RESETVAL (0x00000FC0u)

/* DDRVTPER */


#define CSL_SYS_DDRVTPER_EN_MASK (0x00000001u)
#define CSL_SYS_DDRVTPER_EN_SHIFT (0x00000000u)
#define CSL_SYS_DDRVTPER_EN_RESETVAL (0x00000000u)

#define CSL_SYS_DDRVTPER_RESETVAL (0x00000000u)

/* TIMERCTL  */


#define CSL_SYS_TIMERCTL_TINP0SEL_MASK (0x00000002u)
#define CSL_SYS_TIMERCTL_TINP0SEL_SHIFT (0x00000001u)
#define CSL_SYS_TIMERCTL_TINP0SEL_RESETVAL (0x00000000u)

#define CSL_SYS_TIMERCTL_WDRST_MASK (0x00000001u)
#define CSL_SYS_TIMERCTL_WDRST_SHIFT (0x00000000u)
#define CSL_SYS_TIMERCTL_WDRST_RESETVAL (0x00000000u)

#define CSL_SYS_TIMERCTL_RESETVAL (0x00000000u)

/* EDMATCCFG  */


#define CSL_SYS_EDMATCCFG_TC2DBS_MASK (0x00000060u)
#define CSL_SYS_EDMATCCFG_TC2DBS_SHIFT (0x00000005u)
#define CSL_SYS_EDMATCCFG_TC2DBS_RESETVAL (0x00000000u)

#define CSL_SYS_EDMATCCFG_TC1DBS_MASK (0x00000018u)
#define CSL_SYS_EDMATCCFG_TC1DBS_SHIFT (0x00000003u)
#define CSL_SYS_EDMATCCFG_TC1DBS_RESETVAL (0x00000000u)


#define CSL_SYS_EDMATCCFG_TC0DBS_MASK (0x00000003u)
#define CSL_SYS_EDMATCCFG_TC0DBS_SHIFT (0x00000000u)
#define CSL_SYS_EDMATCCFG_TC0DBS_RESETVAL (0x00000000u)

#define CSL_SYS_EDMATCCFG_RESETVAL (0x00000000u)

/* DDRVTPR */


#define CSL_SYS_DDRVTPR_PCH_MASK (0x000003E0u)
#define CSL_SYS_DDRVTPR_PCH_SHIFT (0x00000005u)
#define CSL_SYS_DDRVTPR_PCH_RESETVAL (0x00000000u)

#define CSL_SYS_DDRVTPR_NCH_MASK (0x0000001Fu)
#define CSL_SYS_DDRVTPR_NCH_SHIFT (0x00000000u)
#define CSL_SYS_DDRVTPR_NCH_RESETVAL (0x00000000u)

#define CSL_SYS_DDRVTPR_RESETVAL (0x00000000u)

#ifdef __cplusplus
}
#endif

#endif

