/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005, 2006, 2007
 *
 *   Use of this software is controlled by the terms and conditions found
 *   in the license agreement under which this software has been supplied.
 *  ============================================================================
 */

/** ============================================================================
 *
 *   @file  Pinmux_example.c
 *
 *	 @path (CSL_EXAMPLE_PATH)/pinmux/src
 *
 *   @desc  example for pinmux Register layer usage.
 *
 * =============================================================================
 *   @n Target Platform: EVM
 *  ============================================================================
 *   @n <b> Example Description </b>
 *   @verbatim
 *    This Example, 
 *      1. configures pinmux regster through "Setup_Pin_Mux()" function 
 * =============================================================================
 */
/* =============================================================================
 *  Revision History
 *  ===============
 *
 *  22-March-2007 File Created.
 *
 * =============================================================================
 */
#include <tistdtypes.h>
#include <soc.h>
#include <cslr_sys.h>
#include <stdio.h>

/*
 * =============================================================================
 *   @func   setup_pinmux
 *
 *   @desc
 *     This is the example code for PINMUX module register layer macro usage.
 *
 * =============================================================================
 */
void setup_pinmux (void)
{
    CSL_SysRegsOvly sysRegs = (CSL_SysRegsOvly)CSL_SYS_0_REGS;
    
    printf( "pinmux setup.. " );
    
    /* PINMUX settings for normal operation
    
    * EVM switch settings:
    * AEM0 = Off, AEM1 = On, AEM2 = On (EMIFA enabled)
    * AEAW2 = Off (20-bit address mode)
    * BOOTM0 = Off, BOOTM1 = Off, BOOTM2 = On, BOOTM3 = Off (direct EMIFA boot at 0x42000000)
    
    * 8-bit EMIFA (full address mode)
    * 8-bit video input on YI[7:0]
    * Digital video outputs disabled
    * CS3-CS5 disabled
    * McBSP0, McBSP1 enabled
    * UART1 enabled
    * Timer 0 enabled
    * PWM1 disabled, I2C_INT on GIO004
    * VLYNQ enabled
    * MII/MDIO enabled
    * PCI disabled */
    
    /* test DPCIEN field (bit[17]) to see if PCI is disabled*/
    if (CSL_FMKR(17, 17, sysRegs->BOOTCFG) == 0) {
        /* PCI disabled */
        sysRegs->PINMUX0 = CSL_FMKR( 30, 30, 0 )  // CI10SEL   - No CI[1:0]
                     | CSL_FMKR( 28, 28, 0 )  // CI32SEL   - No CI[3:2]
                     | CSL_FMKR( 26, 26, 0 )  // CI54SEL   - No CI[5:4]
                     | CSL_FMKR( 25, 25, 0 )  // CI76SEL   - No CI[7:6]
                     | CSL_FMKR( 24, 24, 0 )  // CFLDSEL   - No C_FIELD
                     | CSL_FMKR( 23, 23, 0 )  // CWENSEL   - No C_WEN
                     | CSL_FMKR( 22, 22, 0 )  // HDVSEL    - No CCDC HD and VD
                     | CSL_FMKR( 20, 20, 1 )  // CCDCSEL   - CCDC PCLK, YI[7:0] enabled
                     | CSL_FMKR( 18, 16, 4 )  // AEAW      - EMIFA full address mode
                     | CSL_FMKR( 15, 15, 1 )  // VPBECLK   - VPBECLK enabled
                     | CSL_FMKR( 14, 12, 0 )  // RGBSEL    - No digital outputs
                     | CSL_FMKR( 11, 10, 0 )  // CS3SEL    - LCD_OE/EM_CS3 disabled
                     | CSL_FMKR(  9,  8, 0 )  // CS4SEL    - CS4/VSYNC disabled
                     | CSL_FMKR(  7,  6, 0 )  // CS5SEL    - CS5/HSYNC disabled
                     | CSL_FMKR(  5,  4, 0 )  // VENCSEL   - Video encoder outputs disabled
                     | CSL_FMKR(  2,  0, 1 ); // AEM       - 8-bit EMIFA, 8-bit CCDC in
    
    } 
    else { 
    /* PINMUX settings for PCI operation*/
    sysRegs->PINMUX0 = CSL_FMKR( 30, 30, 0 )  // CI10SEL   - No CI[1:0]
                     | CSL_FMKR( 28, 28, 0 )  // CI32SEL   - No CI[3:2]
                     | CSL_FMKR( 26, 26, 0 )  // CI54SEL   - No CI[5:4]
                     | CSL_FMKR( 25, 25, 0 )  // CI76SEL   - No CI[7:6]
                     | CSL_FMKR( 24, 24, 0 )  // CFLDSEL   - No C_FIELD
                     | CSL_FMKR( 23, 23, 0 )  // CWENSEL   - No C_WEN
                     | CSL_FMKR( 22, 22, 0 )  // HDVSEL    - No CCDC HD and VD
                     | CSL_FMKR( 20, 20, 1 )  // CCDCSEL   - CCDC PCLK, YI[7:0] enabled
                     | CSL_FMKR( 18, 16, 4 )  // AEAW      - EMIFA full address mode
                     | CSL_FMKR( 15, 15, 1 )  // VPBECLK   - VPBECLK enabled
                     | CSL_FMKR( 14, 12, 0 )  // RGBSEL    - No digital outputs
                     | CSL_FMKR( 11, 10, 0 )  // CS3SEL    - LCD_OE/EM_CS3 disabled
                     | CSL_FMKR(  9,  8, 0 )  // CS4SEL    - CS4/VSYNC disabled
                     | CSL_FMKR(  7,  6, 0 )  // CS5SEL    - CS5/HSYNC disabled
                     | CSL_FMKR(  5,  4, 0 )  // VENCSEL   - Video encoder outputs disabled
                     | CSL_FMKR(  2,  0, 0 ); // AEM       - N/A
    }
    
    sysRegs->PINMUX1 = CSL_FMKR( 25, 24, 1 )  // SPBK1     - McBSP1 enabled
                   | CSL_FMKR( 23, 22, 1 )  // SPBK0     - McBSP0 enabled
                   | CSL_FMKR( 21, 20, 2 )  // TIM1BK    - UART1 enabled, Timer1 disabled
                   | CSL_FMKR( 17, 16, 1 )  // TIM0BK    - Timer0 enabled 
                   | CSL_FMKR( 15, 14, 2 )  // CKOBK     - CLKOUT disabled, PWM2 enabled
                   | CSL_FMKR( 12, 12, 0 )  // PWM1BK    - PWM1 disabled, GIO84 enabled
                   | CSL_FMKR( 11, 10, 1 )  // UR0FCBK   - UART0 HW flow control enabled
                   | CSL_FMKR(  8,  8, 1 )  // UR0DBK    - UART0 data enabled
                   | CSL_FMKR(  7,  7, 0 )  // GIOBK     - GIO(4) or PCI(4) depending on PCIEN (bit[0])
                   | CSL_FMKR(  6,  4, 3 )  // HOSTBK    - VLYNQ + MII + MDIO Mode
                   | CSL_FMKR(  0,  0, 0 ); // PCIEN     - PCI disabled
    
    sysRegs->VDD3P3V_PWDN = 0x00000000; // Everything on  
    
    printf( "[Done]\n" );
}


/*
 * =============================================================================
 *   @func   main
 *
 *   @desc
 *     This is the main routine for the file.
 *
 * =============================================================================
 */
void main (void) 
{
    setup_pinmux();
    return;
}


