/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005, 2006, 2007
 *
 *   Use of this software is controlled by the terms and conditions found in the
 *   license agreement under which this software has been supplied.
 *   ===========================================================================
 */
/** ============================================================================
 *   @file  cslr_tsip.h
 *
 *   @path  $(CSLPATH)\inc
 *
 *   @desc  This file contains the Register Descriptions for TSIP
 *
 *  ============================================================================
 */
#ifndef _CSLR_TSIP_H_
#define _CSLR_TSIP_H_

#ifdef __cplusplus
extern "C" {
#endif

#include <ti/sdo/pspdrivers/soc/c6452/dsp/cslr.h>
#include <ti/sdo/pspdrivers/soc/c6452/dsp/tistdtypes.h>

/* Minimum unit = 1 byte */

/**************************************************************************\
* Register Overlay Structure for ERR
\**************************************************************************/
typedef struct  {
    volatile Uint32 ERRCTL;
    volatile Uint32 ERRCNT;
    volatile Uint32 ERRQ;
    volatile Uint8 RSVD6[4];
} CSL_TsipErrRegs;

/**************************************************************************\
* Register Overlay Structure for TX/RX Channel Enable
\**************************************************************************/
typedef struct  {
    volatile Uint32 CHEN;
    volatile Uint8 RSVD8[28];
} CSL_TsipChenRegs;

/**************************************************************************\
* Register Overlay Structure for TX/RX DMATCU Channel
\**************************************************************************/
typedef struct  {
    volatile Uint32 ABASE;
    volatile Uint32 AFALLOC;
    volatile Uint32 AFSIZE;
    volatile Uint32 AFCNT;
    volatile Uint8 RSVD0[16];
    volatile Uint32 BBASE;
    volatile Uint32 BFALLOC;
    volatile Uint32 BFSIZE;
    volatile Uint32 BFCNT;
    volatile Uint8 RSVD12[16];
} CSL_TsipDchRegs;


/**************************************************************************\
* Register Overlay Structure for TX/RX channel Bitmap
\**************************************************************************/
typedef struct  {
    volatile Uint32 BMA[64];
    volatile Uint32 BMB[64];
} CSL_TsipBmRegs;


/**************************************************************************\
* Register Overlay Structure for TX/RX Channel Buffer
\**************************************************************************/
typedef struct  {
    volatile Uint8 PING[1024];
    volatile Uint8 PONG[1024];
} CSL_TsipCbRegs;


/**************************************************************************\
* Register Overlay Structure
\**************************************************************************/
typedef struct  {
    volatile Uint32 PID;
    volatile Uint32 EMUTST;
    volatile Uint32 RST;
    volatile Uint8 RSVD0[116];
    volatile Uint32 SIUCTL;
    volatile Uint8 RSVD1[28];
    volatile Uint32 XCLK;
    volatile Uint32 XCTL;
    volatile Uint32 XSIZE;
    volatile Uint8 RSVD2[20];
    volatile Uint32 RCLK;
    volatile Uint32 RCTL;
    volatile Uint32 RSIZE;
    volatile Uint8 RSVD3[52];
    volatile Uint32 TDMUCTL;
    volatile Uint32 XFRFC;
    volatile Uint32 RFRFC;
    volatile Uint32 TDMUCFG;
    volatile Uint32 XBMST;
    volatile Uint32 RBMST;
    volatile Uint8 RSVD4[104];
    volatile Uint32 DMACTL;
    volatile Uint32 XDLY;
    volatile Uint32 RDLY;
    volatile Uint8 RSVD5[4];
    volatile Uint32 XCHST;
    volatile Uint32 RCHST;
    volatile Uint8 RSVD7[104];
    CSL_TsipErrRegs ERR0;
    volatile Uint8 RSVD9[1520];
    CSL_TsipChenRegs XCHEN0;
    volatile Uint8 RSVD11[992];
    CSL_TsipChenRegs RCHEN0;
    volatile Uint8 RSVD13[992];
    CSL_TsipDchRegs DXCH0;
    volatile Uint8 RSVD15[1984];
    CSL_TsipDchRegs DRCH0;
    volatile Uint8 RSVD16[26560];
    CSL_TsipBmRegs XBM0;
    volatile Uint8 RSVD17[15872];
    CSL_TsipBmRegs RBM0;
    volatile Uint8 RSVD18[15872];
    CSL_TsipCbRegs XCB0;
    volatile Uint8 RSVD19[30720];
    CSL_TsipCbRegs RCB0;
} CSL_TsipRegs;

/**************************************************************************\
* Overlay structure typedef definition
\**************************************************************************/
typedef volatile CSL_TsipRegs *CSL_TsipRegsOvly;

/**************************************************************************\
* Field Definition Macros
\**************************************************************************/

/* ERRCTL */


#define CSL_TSIP_ERRCTL_CLRQOV_MASK (0x00000100u)
#define CSL_TSIP_ERRCTL_CLRQOV_SHIFT (0x00000008u)
#define CSL_TSIP_ERRCTL_CLRQOV_RESETVAL (0x00000000u)
/*----CLRQOV Tokens----*/
#define CSL_TSIP_ERRCTL_CLRQOV_CLR (0x00000001u)


#define CSL_TSIP_ERRCTL_CLRQ_MASK (0x00000002u)
#define CSL_TSIP_ERRCTL_CLRQ_SHIFT (0x00000001u)
#define CSL_TSIP_ERRCTL_CLRQ_RESETVAL (0x00000000u)
/*----CLRQ Tokens----*/
#define CSL_TSIP_ERRCTL_CLRQ_CLR (0x00000001u)

#define CSL_TSIP_ERRCTL_POPQ_MASK (0x00000001u)
#define CSL_TSIP_ERRCTL_POPQ_SHIFT (0x00000000u)
#define CSL_TSIP_ERRCTL_POPQ_RESETVAL (0x00000000u)
/*----POPQ Tokens----*/
#define CSL_TSIP_ERRCTL_POPQ_POP (0x00000001u)

#define CSL_TSIP_ERRCTL_RESETVAL (0x00000000u)

/* ERRCNT */


#define CSL_TSIP_ERRCNT_QOV_MASK (0x00000100u)
#define CSL_TSIP_ERRCNT_QOV_SHIFT (0x00000008u)
#define CSL_TSIP_ERRCNT_QOV_RESETVAL (0x00000000u)


#define CSL_TSIP_ERRCNT_CNT_MASK (0x0000001Fu)
#define CSL_TSIP_ERRCNT_CNT_SHIFT (0x00000000u)
#define CSL_TSIP_ERRCNT_CNT_RESETVAL (0x00000000u)

#define CSL_TSIP_ERRCNT_RESETVAL (0x00000000u)

/* ERRQ */

#define CSL_TSIP_ERRQ_ERRCODE_MASK (0xFF000000u)
#define CSL_TSIP_ERRQ_ERRCODE_SHIFT (0x00000018u)
#define CSL_TSIP_ERRQ_ERRCODE_RESETVAL (0x00000000u)

#define CSL_TSIP_ERRQ_INFO_MASK (0x00FFFFFFu)
#define CSL_TSIP_ERRQ_INFO_SHIFT (0x00000000u)
#define CSL_TSIP_ERRQ_INFO_RESETVAL (0x00000000u)

#define CSL_TSIP_ERRQ_RESETVAL (0x00000000u)

/* CHEN */


#define CSL_TSIP_CHEN_CID_MASK (0x0000FF00u)
#define CSL_TSIP_CHEN_CID_SHIFT (0x00000008u)
#define CSL_TSIP_CHEN_CID_RESETVAL (0x00000000u)


#define CSL_TSIP_CHEN_CHENB_MASK (0x00000001u)
#define CSL_TSIP_CHEN_CHENB_SHIFT (0x00000000u)
#define CSL_TSIP_CHEN_CHENB_RESETVAL (0x00000000u)
/*----CHENB Tokens----*/
#define CSL_TSIP_CHEN_CHENB_ENB (0x00000001u)
#define CSL_TSIP_CHEN_CHENB_DIS (0x00000000u)

#define CSL_TSIP_CHEN_RESETVAL (0x00000000u)

/* CHEN */


#define CSL_TSIP_CHEN_CID_MASK (0x0000FF00u)
#define CSL_TSIP_CHEN_CID_SHIFT (0x00000008u)
#define CSL_TSIP_CHEN_CID_RESETVAL (0x00000000u)


#define CSL_TSIP_CHEN_CHENB_MASK (0x00000001u)
#define CSL_TSIP_CHEN_CHENB_SHIFT (0x00000000u)
#define CSL_TSIP_CHEN_CHENB_RESETVAL (0x00000000u)
/*----CHENB Tokens----*/
#define CSL_TSIP_CHEN_CHENB_ENB (0x00000001u)
#define CSL_TSIP_CHEN_CHENB_DIS (0x00000000u)

#define CSL_TSIP_CHEN_RESETVAL (0x00000000u)

/* ABASE */

#define CSL_TSIP_ABASE_ADDR_MASK (0xFFFFFFFFu)
#define CSL_TSIP_ABASE_ADDR_SHIFT (0x00000000u)
#define CSL_TSIP_ABASE_ADDR_RESETVAL (0x00000000u)

#define CSL_TSIP_ABASE_RESETVAL (0x00000000u)

/* AFALLOC */


#define CSL_TSIP_AFALLOC_FALLOC_MASK (0x00000FFFu)
#define CSL_TSIP_AFALLOC_FALLOC_SHIFT (0x00000000u)
#define CSL_TSIP_AFALLOC_FALLOC_RESETVAL (0x00000000u)

#define CSL_TSIP_AFALLOC_RESETVAL (0x00000000u)

/* AFSIZE */


#define CSL_TSIP_AFSIZE_FSIZE_MASK (0x00000FFFu)
#define CSL_TSIP_AFSIZE_FSIZE_SHIFT (0x00000000u)
#define CSL_TSIP_AFSIZE_FSIZE_RESETVAL (0x00000000u)

#define CSL_TSIP_AFSIZE_RESETVAL (0x00000000u)

/* AFCNT */


#define CSL_TSIP_AFCNT_FCOUNT_MASK (0x000000FFu)
#define CSL_TSIP_AFCNT_FCOUNT_SHIFT (0x00000000u)
#define CSL_TSIP_AFCNT_FCOUNT_RESETVAL (0x00000000u)

#define CSL_TSIP_AFCNT_RESETVAL (0x00000000u)

/* BBASE */

#define CSL_TSIP_BBASE_ADDR_MASK (0xFFFFFFFFu)
#define CSL_TSIP_BBASE_ADDR_SHIFT (0x00000000u)
#define CSL_TSIP_BBASE_ADDR_RESETVAL (0x00000000u)

#define CSL_TSIP_BBASE_RESETVAL (0x00000000u)

/* BFALLOC */


#define CSL_TSIP_BFALLOC_FALLOC_MASK (0x00000FFFu)
#define CSL_TSIP_BFALLOC_FALLOC_SHIFT (0x00000000u)
#define CSL_TSIP_BFALLOC_FALLOC_RESETVAL (0x00000000u)

#define CSL_TSIP_BFALLOC_RESETVAL (0x00000000u)

/* BFSIZE */


#define CSL_TSIP_BFSIZE_FSIZE_MASK (0x00000FFFu)
#define CSL_TSIP_BFSIZE_FSIZE_SHIFT (0x00000000u)
#define CSL_TSIP_BFSIZE_FSIZE_RESETVAL (0x00000000u)

#define CSL_TSIP_BFSIZE_RESETVAL (0x00000000u)

/* BFCNT */


#define CSL_TSIP_BFCNT_FCOUNT_MASK (0x000000FFu)
#define CSL_TSIP_BFCNT_FCOUNT_SHIFT (0x00000000u)
#define CSL_TSIP_BFCNT_FCOUNT_RESETVAL (0x00000000u)

#define CSL_TSIP_BFCNT_RESETVAL (0x00000000u)

/* ABASE */

#define CSL_TSIP_ABASE_ADDR_MASK (0xFFFFFFFFu)
#define CSL_TSIP_ABASE_ADDR_SHIFT (0x00000000u)
#define CSL_TSIP_ABASE_ADDR_RESETVAL (0x00000000u)

#define CSL_TSIP_ABASE_RESETVAL (0x00000000u)

/* AFALLOC */


#define CSL_TSIP_AFALLOC_FALLOC_MASK (0x00000FFFu)
#define CSL_TSIP_AFALLOC_FALLOC_SHIFT (0x00000000u)
#define CSL_TSIP_AFALLOC_FALLOC_RESETVAL (0x00000000u)

#define CSL_TSIP_AFALLOC_RESETVAL (0x00000000u)

/* AFSIZE */


#define CSL_TSIP_AFSIZE_FSIZE_MASK (0x00000FFFu)
#define CSL_TSIP_AFSIZE_FSIZE_SHIFT (0x00000000u)
#define CSL_TSIP_AFSIZE_FSIZE_RESETVAL (0x00000000u)

#define CSL_TSIP_AFSIZE_RESETVAL (0x00000000u)

/* AFCNT */


#define CSL_TSIP_AFCNT_FCOUNT_MASK (0x000000FFu)
#define CSL_TSIP_AFCNT_FCOUNT_SHIFT (0x00000000u)
#define CSL_TSIP_AFCNT_FCOUNT_RESETVAL (0x00000000u)

#define CSL_TSIP_AFCNT_RESETVAL (0x00000000u)

/* BBASE */

#define CSL_TSIP_BBASE_ADDR_MASK (0xFFFFFFFFu)
#define CSL_TSIP_BBASE_ADDR_SHIFT (0x00000000u)
#define CSL_TSIP_BBASE_ADDR_RESETVAL (0x00000000u)

#define CSL_TSIP_BBASE_RESETVAL (0x00000000u)

/* BFALLOC */


#define CSL_TSIP_BFALLOC_FALLOC_MASK (0x00000FFFu)
#define CSL_TSIP_BFALLOC_FALLOC_SHIFT (0x00000000u)
#define CSL_TSIP_BFALLOC_FALLOC_RESETVAL (0x00000000u)

#define CSL_TSIP_BFALLOC_RESETVAL (0x00000000u)

/* BFSIZE */


#define CSL_TSIP_BFSIZE_FSIZE_MASK (0x00000FFFu)
#define CSL_TSIP_BFSIZE_FSIZE_SHIFT (0x00000000u)
#define CSL_TSIP_BFSIZE_FSIZE_RESETVAL (0x00000000u)

#define CSL_TSIP_BFSIZE_RESETVAL (0x00000000u)

/* BFCNT */


#define CSL_TSIP_BFCNT_FCOUNT_MASK (0x000000FFu)
#define CSL_TSIP_BFCNT_FCOUNT_SHIFT (0x00000000u)
#define CSL_TSIP_BFCNT_FCOUNT_RESETVAL (0x00000000u)

#define CSL_TSIP_BFCNT_RESETVAL (0x00000000u)

/* BMA */


#define CSL_TSIP_BMA_RESETVAL (0x00000000u)

/* BMB */


#define CSL_TSIP_BMB_RESETVAL (0x00000000u)

/* BMA */


#define CSL_TSIP_BMA_RESETVAL (0x00000000u)

/* BMB */


#define CSL_TSIP_BMB_RESETVAL (0x00000000u)

/* PING */


#define CSL_TSIP_PING_RESETVAL (0x00u)

/* PONG */


#define CSL_TSIP_PONG_RESETVAL (0x00u)

/* PING */


#define CSL_TSIP_PING_RESETVAL (0x00u)

/* PONG */


#define CSL_TSIP_PONG_RESETVAL (0x00u)

/* PID */

#define CSL_TSIP_PID_MODID_MASK (0xFFFF0000u)
#define CSL_TSIP_PID_MODID_SHIFT (0x00000010u)
#define CSL_TSIP_PID_MODID_RESETVAL (0x00000060u)

#define CSL_TSIP_PID_MAJOR_MASK (0x0000FF00u)
#define CSL_TSIP_PID_MAJOR_SHIFT (0x00000008u)
#define CSL_TSIP_PID_MAJOR_RESETVAL (0x00000001u)

#define CSL_TSIP_PID_MINOR_MASK (0x000000FFu)
#define CSL_TSIP_PID_MINOR_SHIFT (0x00000000u)
#define CSL_TSIP_PID_MINOR_RESETVAL (0x00000000u)

#define CSL_TSIP_PID_RESETVAL (0x00600100u)

/* EMUTST */


#define CSL_TSIP_EMUTST_TSTDIV_MASK (0x01F00000u)
#define CSL_TSIP_EMUTST_TSTDIV_SHIFT (0x00000014u)
#define CSL_TSIP_EMUTST_TSTDIV_RESETVAL (0x00000000u)

#define CSL_TSIP_EMUTST_TSTCLK_MASK (0x00080000u)
#define CSL_TSIP_EMUTST_TSTCLK_SHIFT (0x00000013u)
#define CSL_TSIP_EMUTST_TSTCLK_RESETVAL (0x00000000u)

#define CSL_TSIP_EMUTST_IOLB_MASK (0x00040000u)
#define CSL_TSIP_EMUTST_IOLB_SHIFT (0x00000012u)
#define CSL_TSIP_EMUTST_IOLB_RESETVAL (0x00000000u)

#define CSL_TSIP_EMUTST_LBS_MASK (0x00020000u)
#define CSL_TSIP_EMUTST_LBS_SHIFT (0x00000011u)
#define CSL_TSIP_EMUTST_LBS_RESETVAL (0x00000000u)

#define CSL_TSIP_EMUTST_SIUTST_MASK (0x00010000u)
#define CSL_TSIP_EMUTST_SIUTST_SHIFT (0x00000010u)
#define CSL_TSIP_EMUTST_SIUTST_RESETVAL (0x00000000u)

#define CSL_TSIP_EMUTST_TSTKEY_MASK (0x0000FF00u)
#define CSL_TSIP_EMUTST_TSTKEY_SHIFT (0x00000008u)
#define CSL_TSIP_EMUTST_TSTKEY_RESETVAL (0x00000000u)


#define CSL_TSIP_EMUTST_SOFT_MASK (0x00000002u)
#define CSL_TSIP_EMUTST_SOFT_SHIFT (0x00000001u)
#define CSL_TSIP_EMUTST_SOFT_RESETVAL (0x00000000u)

#define CSL_TSIP_EMUTST_FREE_MASK (0x00000001u)
#define CSL_TSIP_EMUTST_FREE_SHIFT (0x00000000u)
#define CSL_TSIP_EMUTST_FREE_RESETVAL (0x00000001u)

#define CSL_TSIP_EMUTST_RESETVAL (0x00000001u)

/* RST */


#define CSL_TSIP_RST_DMA_MASK (0x00000002u)
#define CSL_TSIP_RST_DMA_SHIFT (0x00000001u)
#define CSL_TSIP_RST_DMA_RESETVAL (0x00000000u)
/*----DMA Tokens----*/
#define CSL_TSIP_RST_DMA_RST (0x00000001u)

#define CSL_TSIP_RST_SIU_MASK (0x00000001u)
#define CSL_TSIP_RST_SIU_SHIFT (0x00000000u)
#define CSL_TSIP_RST_SIU_RESETVAL (0x00000000u)
/*----SIU Tokens----*/
#define CSL_TSIP_RST_SIU_RST (0x00000001u)

#define CSL_TSIP_RST_RESETVAL (0x00000000u)

/* SIUCTL */


#define CSL_TSIP_SIUCTL_CLKD_MASK (0x00000010u)
#define CSL_TSIP_SIUCTL_CLKD_SHIFT (0x00000004u)
#define CSL_TSIP_SIUCTL_CLKD_RESETVAL (0x00000000u)
/*----CLKD Tokens----*/
#define CSL_TSIP_SIUCTL_CLKD_REDUN (0x00000000u)
#define CSL_TSIP_SIUCTL_CLKD_DUAL (0x00000001u)


#define CSL_TSIP_SIUCTL_RENB_MASK (0x00000002u)
#define CSL_TSIP_SIUCTL_RENB_SHIFT (0x00000001u)
#define CSL_TSIP_SIUCTL_RENB_RESETVAL (0x00000000u)
/*----RENB Tokens----*/
#define CSL_TSIP_SIUCTL_RENB_ENB (0x00000001u)
#define CSL_TSIP_SIUCTL_RENB_DIS (0x00000000u)

#define CSL_TSIP_SIUCTL_XENB_MASK (0x00000001u)
#define CSL_TSIP_SIUCTL_XENB_SHIFT (0x00000000u)
#define CSL_TSIP_SIUCTL_XENB_RESETVAL (0x00000000u)
/*----XENB Tokens----*/
#define CSL_TSIP_SIUCTL_XENB_ENB (0x00000001u)
#define CSL_TSIP_SIUCTL_XENB_DIS (0x00000000u)

#define CSL_TSIP_SIUCTL_RESETVAL (0x00000000u)

/* XCLK */


#define CSL_TSIP_XCLK_SRC_MASK (0x00000001u)
#define CSL_TSIP_XCLK_SRC_SHIFT (0x00000000u)
#define CSL_TSIP_XCLK_SRC_RESETVAL (0x00000000u)
/*----SRC Tokens----*/
#define CSL_TSIP_XCLK_SRC_ACLK (0x00000000u)
#define CSL_TSIP_XCLK_SRC_BCLK (0x00000001u)

#define CSL_TSIP_XCLK_RESETVAL (0x00000000u)

/* XCTL */


#define CSL_TSIP_XCTL_DATD_MASK (0x3FFF0000u)
#define CSL_TSIP_XCTL_DATD_SHIFT (0x00000010u)
#define CSL_TSIP_XCTL_DATD_RESETVAL (0x00000000u)


#define CSL_TSIP_XCTL_DLY_MASK (0x00000400u)
#define CSL_TSIP_XCTL_DLY_SHIFT (0x0000000Au)
#define CSL_TSIP_XCTL_DLY_RESETVAL (0x00000000u)

#define CSL_TSIP_XCTL_DIS_MASK (0x00000300u)
#define CSL_TSIP_XCTL_DIS_SHIFT (0x00000008u)
#define CSL_TSIP_XCTL_DIS_RESETVAL (0x00000000u)
/*----DIS Tokens----*/
#define CSL_TSIP_XCTL_DIS_HIMPED (0x00000000u)
#define CSL_TSIP_XCTL_DIS_LOW (0x00000002u)
#define CSL_TSIP_XCTL_DIS_HIGH (0x00000003u)

#define CSL_TSIP_XCTL_FSYNCP_MASK (0x00000080u)
#define CSL_TSIP_XCTL_FSYNCP_SHIFT (0x00000007u)
#define CSL_TSIP_XCTL_FSYNCP_RESETVAL (0x00000000u)
/*----FSYNCP Tokens----*/
#define CSL_TSIP_XCTL_FSYNCP_ALOW (0x00000000u)
#define CSL_TSIP_XCTL_FSYNCP_AHIGH (0x00000001u)

#define CSL_TSIP_XCTL_FCLKP_MASK (0x00000040u)
#define CSL_TSIP_XCTL_FCLKP_SHIFT (0x00000006u)
#define CSL_TSIP_XCTL_FCLKP_RESETVAL (0x00000000u)
/*----FCLKP Tokens----*/
#define CSL_TSIP_XCTL_FCLKP_RISING (0x00000000u)
#define CSL_TSIP_XCTL_FCLKP_FALLING (0x00000001u)

#define CSL_TSIP_XCTL_DCLKP_MASK (0x00000020u)
#define CSL_TSIP_XCTL_DCLKP_SHIFT (0x00000005u)
#define CSL_TSIP_XCTL_DCLKP_RESETVAL (0x00000000u)
/*----DCLKP Tokens----*/
#define CSL_TSIP_XCTL_DCLKP_RISING (0x00000000u)
#define CSL_TSIP_XCTL_DCLKP_FALLING (0x00000001u)


#define CSL_TSIP_XCTL_DRATE_MASK (0x00000006u)
#define CSL_TSIP_XCTL_DRATE_SHIFT (0x00000001u)
#define CSL_TSIP_XCTL_DRATE_RESETVAL (0x00000000u)
/*----DRATE Tokens----*/
#define CSL_TSIP_XCTL_DRATE_8M (0x00000000u)
#define CSL_TSIP_XCTL_DRATE_16M (0x00000001u)
#define CSL_TSIP_XCTL_DRATE_32M (0x00000002u)

#define CSL_TSIP_XCTL_CLKM_MASK (0x00000001u)
#define CSL_TSIP_XCTL_CLKM_SHIFT (0x00000000u)
#define CSL_TSIP_XCTL_CLKM_RESETVAL (0x00000000u)
/*----CLKM Tokens----*/
#define CSL_TSIP_XCTL_CLKM_DBL (0x00000000u)
#define CSL_TSIP_XCTL_CLKM_SGL (0x00000001u)

#define CSL_TSIP_XCTL_RESETVAL (0x00000000u)

/* XSIZE */


#define CSL_TSIP_XSIZE_FCNT_MASK (0x00FF0000u)
#define CSL_TSIP_XSIZE_FCNT_SHIFT (0x00000010u)
#define CSL_TSIP_XSIZE_FCNT_RESETVAL (0x00000003u)


#define CSL_TSIP_XSIZE_FSIZ_MASK (0x0000007Fu)
#define CSL_TSIP_XSIZE_FSIZ_SHIFT (0x00000000u)
#define CSL_TSIP_XSIZE_FSIZ_RESETVAL (0x0000007Fu)

#define CSL_TSIP_XSIZE_RESETVAL (0x0003007Fu)

/* RCLK */


#define CSL_TSIP_RCLK_SRC_MASK (0x00000001u)
#define CSL_TSIP_RCLK_SRC_SHIFT (0x00000000u)
#define CSL_TSIP_RCLK_SRC_RESETVAL (0x00000000u)
/*----SRC Tokens----*/
#define CSL_TSIP_RCLK_SRC_ACLK (0x00000000u)
#define CSL_TSIP_RCLK_SRC_BCLK (0x00000001u)

#define CSL_TSIP_RCLK_RESETVAL (0x00000000u)

/* RCTL */


#define CSL_TSIP_RCTL_DATD_MASK (0x3FFF0000u)
#define CSL_TSIP_RCTL_DATD_SHIFT (0x00000010u)
#define CSL_TSIP_RCTL_DATD_RESETVAL (0x00000000u)


#define CSL_TSIP_RCTL_FSYNCP_MASK (0x00000080u)
#define CSL_TSIP_RCTL_FSYNCP_SHIFT (0x00000007u)
#define CSL_TSIP_RCTL_FSYNCP_RESETVAL (0x00000000u)
/*----FSYNCP Tokens----*/
#define CSL_TSIP_RCTL_FSYNCP_ALOW (0x00000000u)
#define CSL_TSIP_RCTL_FSYNCP_AHIGH (0x00000001u)

#define CSL_TSIP_RCTL_FCLKP_MASK (0x00000040u)
#define CSL_TSIP_RCTL_FCLKP_SHIFT (0x00000006u)
#define CSL_TSIP_RCTL_FCLKP_RESETVAL (0x00000000u)
/*----FCLKP Tokens----*/
#define CSL_TSIP_RCTL_FCLKP_RISING (0x00000000u)
#define CSL_TSIP_RCTL_FCLKP_FALLING (0x00000001u)

#define CSL_TSIP_RCTL_DCLKP_MASK (0x00000020u)
#define CSL_TSIP_RCTL_DCLKP_SHIFT (0x00000005u)
#define CSL_TSIP_RCTL_DCLKP_RESETVAL (0x00000000u)
/*----DCLKP Tokens----*/
#define CSL_TSIP_RCTL_DCLKP_RISING (0x00000000u)
#define CSL_TSIP_RCTL_DCLKP_FALLING (0x00000001u)


#define CSL_TSIP_RCTL_DRATE_MASK (0x00000006u)
#define CSL_TSIP_RCTL_DRATE_SHIFT (0x00000001u)
#define CSL_TSIP_RCTL_DRATE_RESETVAL (0x00000000u)
/*----DRATE Tokens----*/
#define CSL_TSIP_RCTL_DRATE_8M (0x00000000u)
#define CSL_TSIP_RCTL_DRATE_16M (0x00000001u)
#define CSL_TSIP_RCTL_DRATE_32M (0x00000002u)

#define CSL_TSIP_RCTL_CLKM_MASK (0x00000001u)
#define CSL_TSIP_RCTL_CLKM_SHIFT (0x00000000u)
#define CSL_TSIP_RCTL_CLKM_RESETVAL (0x00000000u)
/*----CLKM Tokens----*/
#define CSL_TSIP_RCTL_CLKM_DBL (0x00000000u)
#define CSL_TSIP_RCTL_CLKM_SGL (0x00000001u)

#define CSL_TSIP_RCTL_RESETVAL (0x00000000u)

/* RSIZE */


#define CSL_TSIP_RSIZE_FCNT_MASK (0x00FF0000u)
#define CSL_TSIP_RSIZE_FCNT_SHIFT (0x00000010u)
#define CSL_TSIP_RSIZE_FCNT_RESETVAL (0x00000003u)


#define CSL_TSIP_RSIZE_FSIZ_MASK (0x0000007Fu)
#define CSL_TSIP_RSIZE_FSIZ_SHIFT (0x00000000u)
#define CSL_TSIP_RSIZE_FSIZ_RESETVAL (0x0000007Fu)

#define CSL_TSIP_RSIZE_RESETVAL (0x0003007Fu)

/* TDMUCTL */


#define CSL_TSIP_TDMUCTL_DMAENB_MASK (0x00000001u)
#define CSL_TSIP_TDMUCTL_DMAENB_SHIFT (0x00000000u)
#define CSL_TSIP_TDMUCTL_DMAENB_RESETVAL (0x00000000u)
/*----DMAENB Tokens----*/
#define CSL_TSIP_TDMUCTL_DMAENB_ENB (0x00000001u)
#define CSL_TSIP_TDMUCTL_DMAENB_DIS (0x00000000u)

#define CSL_TSIP_TDMUCTL_RESETVAL (0x00000000u)

/* XFRFC */


#define CSL_TSIP_XFRFC_FRFC_MASK (0x00FFFFFFu)
#define CSL_TSIP_XFRFC_FRFC_SHIFT (0x00000000u)
#define CSL_TSIP_XFRFC_FRFC_RESETVAL (0x00000000u)

#define CSL_TSIP_XFRFC_RESETVAL (0x00000000u)

/* RFRFC */


#define CSL_TSIP_RFRFC_FRFC_MASK (0x00FFFFFFu)
#define CSL_TSIP_RFRFC_FRFC_SHIFT (0x00000000u)
#define CSL_TSIP_RFRFC_FRFC_RESETVAL (0x00000000u)

#define CSL_TSIP_RFRFC_RESETVAL (0x00000000u)

/* TDMUCFG */


#define CSL_TSIP_TDMUCFG_BEND_MASK (0x00000001u)
#define CSL_TSIP_TDMUCFG_BEND_SHIFT (0x00000000u)
#define CSL_TSIP_TDMUCFG_BEND_RESETVAL (0x00000000u)
/*----BEND Tokens----*/
#define CSL_TSIP_TDMUCFG_BEND_LITTLE (0x00000000u)
#define CSL_TSIP_TDMUCFG_BEND_BIG (0x00000001u)

#define CSL_TSIP_TDMUCFG_RESETVAL (0x00000000u)

/* XBMST */


#define CSL_TSIP_XBMST_CH0BMS_MASK (0x00000003u)
#define CSL_TSIP_XBMST_CH0BMS_SHIFT (0x00000000u)
#define CSL_TSIP_XBMST_CH0BMS_RESETVAL (0x00000000u)

#define CSL_TSIP_XBMST_RESETVAL (0x00000000u)

/* RBMST */


#define CSL_TSIP_RBMST_CH0BMS_MASK (0x00000003u)
#define CSL_TSIP_RBMST_CH0BMS_SHIFT (0x00000000u)
#define CSL_TSIP_RBMST_CH0BMS_RESETVAL (0x00000000u)

#define CSL_TSIP_RBMST_RESETVAL (0x00000000u)

/* DMACTL */


#define CSL_TSIP_DMACTL_MAXPRI_MASK (0x00000070u)
#define CSL_TSIP_DMACTL_MAXPRI_SHIFT (0x00000004u)
#define CSL_TSIP_DMACTL_MAXPRI_RESETVAL (0x00000007u)


#define CSL_TSIP_DMACTL_PRI_MASK (0x00000007u)
#define CSL_TSIP_DMACTL_PRI_SHIFT (0x00000000u)
#define CSL_TSIP_DMACTL_PRI_RESETVAL (0x00000007u)

#define CSL_TSIP_DMACTL_RESETVAL (0x00000077u)

/* XDLY */


#define CSL_TSIP_XDLY_SFINT_MASK (0x0000C000u)
#define CSL_TSIP_XDLY_SFINT_SHIFT (0x0000000Eu)
#define CSL_TSIP_XDLY_SFINT_RESETVAL (0x00000000u)
/*----SFINT Tokens----*/
#define CSL_TSIP_XDLY_SFINT_ACK (0x00000000u)
#define CSL_TSIP_XDLY_SFINT_DLY (0x00000001u)
#define CSL_TSIP_XDLY_SFINT_ACKORDLY (0x00000002u)
#define CSL_TSIP_XDLY_SFINT_ACKNDLY (0x00000003u)

#define CSL_TSIP_XDLY_FRINT_MASK (0x00003000u)
#define CSL_TSIP_XDLY_FRINT_SHIFT (0x0000000Cu)
#define CSL_TSIP_XDLY_FRINT_RESETVAL (0x00000000u)
/*----FRINT Tokens----*/
#define CSL_TSIP_XDLY_FRINT_ACK (0x00000000u)
#define CSL_TSIP_XDLY_FRINT_DLY (0x00000001u)
#define CSL_TSIP_XDLY_FRINT_ACKORDLY (0x00000002u)
#define CSL_TSIP_XDLY_FRINT_ACKNDLY (0x00000003u)


#define CSL_TSIP_XDLY_FDLY_MASK (0x0000007Fu)
#define CSL_TSIP_XDLY_FDLY_SHIFT (0x00000000u)
#define CSL_TSIP_XDLY_FDLY_RESETVAL (0x0000007Fu)

#define CSL_TSIP_XDLY_RESETVAL (0x0000007Fu)

/* RDLY */


#define CSL_TSIP_RDLY_SFINT_MASK (0x0000C000u)
#define CSL_TSIP_RDLY_SFINT_SHIFT (0x0000000Eu)
#define CSL_TSIP_RDLY_SFINT_RESETVAL (0x00000000u)
/*----SFINT Tokens----*/
#define CSL_TSIP_RDLY_SFINT_ACK (0x00000000u)
#define CSL_TSIP_RDLY_SFINT_DLY (0x00000001u)
#define CSL_TSIP_RDLY_SFINT_ACKORDLY (0x00000002u)
#define CSL_TSIP_RDLY_SFINT_ACKNDLY (0x00000003u)

#define CSL_TSIP_RDLY_FRINT_MASK (0x00003000u)
#define CSL_TSIP_RDLY_FRINT_SHIFT (0x0000000Cu)
#define CSL_TSIP_RDLY_FRINT_RESETVAL (0x00000000u)
/*----FRINT Tokens----*/
#define CSL_TSIP_RDLY_FRINT_ACK (0x00000000u)
#define CSL_TSIP_RDLY_FRINT_DLY (0x00000001u)
#define CSL_TSIP_RDLY_FRINT_ACKORDLY (0x00000002u)
#define CSL_TSIP_RDLY_FRINT_ACKNDLY (0x00000003u)


#define CSL_TSIP_RDLY_FDLY_MASK (0x0000007Fu)
#define CSL_TSIP_RDLY_FDLY_SHIFT (0x00000000u)
#define CSL_TSIP_RDLY_FDLY_RESETVAL (0x0000007Fu)

#define CSL_TSIP_RDLY_RESETVAL (0x0000007Fu)

/* XCHST */


#define CSL_TSIP_XCHST_CH0CS_MASK (0x00000003u)
#define CSL_TSIP_XCHST_CH0CS_SHIFT (0x00000000u)
#define CSL_TSIP_XCHST_CH0CS_RESETVAL (0x00000000u)

#define CSL_TSIP_XCHST_RESETVAL (0x00000000u)

/* RCHST */


#define CSL_TSIP_RCHST_CH0CS_MASK (0x00000003u)
#define CSL_TSIP_RCHST_CH0CS_SHIFT (0x00000000u)
#define CSL_TSIP_RCHST_CH0CS_RESETVAL (0x00000000u)

#define CSL_TSIP_RCHST_RESETVAL (0x00000000u)

#ifdef __cplusplus
}
#endif

#endif
