/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005. 2006
 *
 *   Use of this software is controlled by the terms and conditions found in the
 *   license agreement under which this software has been supplied.
 *   ===========================================================================
 */
/** ============================================================================
 *   @file  cslr_osd.h
 *
 *   @path  $(CSLPATH)\inc
 *
 *   @desc  This file contains the Register Desciptions for OSD
 *  ============================================================================
 */
#ifndef _CSLR_OSD_H_
#define _CSLR_OSD_H_

#ifdef __cplusplus
extern "C" {
#endif

#include <ti/sdo/pspdrivers/soc/dm6437/dsp/cslr.h>
#include <ti/sdo/pspdrivers/soc/dm6437/dsp/tistdtypes.h>

/* Minimum unit = 4 byte */

/**************************************************************************\
* Register Overlay Structure
\**************************************************************************/
typedef struct  {
    volatile Uint32 MODE;
    volatile Uint32 VIDWINMD;
    volatile Uint32 OSDWIN0MD;
    volatile Uint32 OSDWIN1MD;
    volatile Uint32 RECTCUR;
    volatile Uint8 RSVD0[4];
    volatile Uint32 VIDWIN0OFST;
    volatile Uint32 VIDWIN1OFST;
    volatile Uint32 OSDWIN0OFST;
    volatile Uint32 OSDWIN1OFST;
    volatile Uint32 RSV1;
    volatile Uint32 VIDWIN0ADR;
    volatile Uint32 VIDWIN1ADR;
    volatile Uint8 RSVD1[4];
    volatile Uint32 OSDWIN0ADR;
    volatile Uint32 OSDWIN1ADR;
    volatile Uint32 BASEPX;
    volatile Uint32 BASEPY;
    volatile Uint32 VIDWIN0XP;
    volatile Uint32 VIDWIN0YP;
    volatile Uint32 VIDWIN0XL;
    volatile Uint32 VIDWIN0YL;
    volatile Uint32 VIDWIN1XP;
    volatile Uint32 VIDWIN1YP;
    volatile Uint32 VIDWIN1XL;
    volatile Uint32 VIDWIN1YL;
    volatile Uint32 OSDWIN0XP;
    volatile Uint32 OSDWIN0YP;
    volatile Uint32 OSDWIN0XL;
    volatile Uint32 OSDWIN0YL;
    volatile Uint32 OSDWIN1XP;
    volatile Uint32 OSDWIN1YP;
    volatile Uint32 OSDWIN1XL;
    volatile Uint32 OSDWIN1YL;
    volatile Uint32 CURXP;
    volatile Uint32 CURYP;
    volatile Uint32 CURXL;
    volatile Uint32 CURYL;
    volatile Uint8 RSVD2[8];
    volatile Uint32 W0BMP01;
    volatile Uint32 W0BMP23;
    volatile Uint32 W0BMP45;
    volatile Uint32 W0BMP67;
    volatile Uint32 W0BMP89;
    volatile Uint32 W0BMPAB;
    volatile Uint32 W0BMPCD;
    volatile Uint32 W0BMPEF;
    volatile Uint32 W1BMP01;
    volatile Uint32 W1BMP23;
    volatile Uint32 W1BMP45;
    volatile Uint32 W1BMP67;
    volatile Uint32 W1BMP89;
    volatile Uint32 W1BMPAB;
    volatile Uint32 W1BMPCD;
    volatile Uint32 W1BMPEF;
    volatile Uint8 RSVD3[8];
    volatile Uint32 MISCCTL;
    volatile Uint32 CLUTRAMYCB;
    volatile Uint32 CLUTRAMCR;
    volatile Uint32 TRANSPVAL;
    volatile Uint8 RSVD4[4];
    volatile Uint32 PPVWIN0ADR;
} CSL_OsdRegs;

/**************************************************************************\
* Overlay structure typedef definition
\**************************************************************************/
typedef volatile CSL_OsdRegs  *CSL_OsdRegsOvly;

/**************************************************************************\
* Field Definition Macros
\**************************************************************************/

/* MODE */


#define CSL_OSD_MODE_CS_MASK (0x00008000u)
#define CSL_OSD_MODE_CS_SHIFT (0x0000000Fu)
#define CSL_OSD_MODE_CS_RESETVAL (0x00000000u)
/*----CS Tokens----*/
#define CSL_OSD_MODE_CS_CB_CR (0x00000000u)
#define CSL_OSD_MODE_CS_CR_CB (0x00000001u)

#define CSL_OSD_MODE_OVRSZ_MASK (0x00004000u)
#define CSL_OSD_MODE_OVRSZ_SHIFT (0x0000000Eu)
#define CSL_OSD_MODE_OVRSZ_RESETVAL (0x00000000u)
/*----OVRSZ Tokens----*/
#define CSL_OSD_MODE_OVRSZ_X1 (0x00000000u)
#define CSL_OSD_MODE_OVRSZ_X6_5 (0x00000001u)

#define CSL_OSD_MODE_OHRSZ_MASK (0x00002000u)
#define CSL_OSD_MODE_OHRSZ_SHIFT (0x0000000Du)
#define CSL_OSD_MODE_OHRSZ_RESETVAL (0x00000000u)
/*----OHRSZ Tokens----*/
#define CSL_OSD_MODE_OHRSZ_X1 (0x00000000u)
#define CSL_OSD_MODE_OHRSZ_X9_8 (0x00000001u)

#define CSL_OSD_MODE_EF_MASK (0x00001000u)
#define CSL_OSD_MODE_EF_SHIFT (0x0000000Cu)
#define CSL_OSD_MODE_EF_RESETVAL (0x00000000u)
/*----EF Tokens----*/
#define CSL_OSD_MODE_EF_OFF (0x00000000u)
#define CSL_OSD_MODE_EF_ON (0x00000001u)

#define CSL_OSD_MODE_VVRSZ_MASK (0x00000800u)
#define CSL_OSD_MODE_VVRSZ_SHIFT (0x0000000Bu)
#define CSL_OSD_MODE_VVRSZ_RESETVAL (0x00000000u)
/*----VVRSZ Tokens----*/
#define CSL_OSD_MODE_VVRSZ_X1 (0x00000000u)
#define CSL_OSD_MODE_VVRSZ_X6_5 (0x00000001u)

#define CSL_OSD_MODE_VHRSZ_MASK (0x00000400u)
#define CSL_OSD_MODE_VHRSZ_SHIFT (0x0000000Au)
#define CSL_OSD_MODE_VHRSZ_RESETVAL (0x00000000u)
/*----VHRSZ Tokens----*/
#define CSL_OSD_MODE_VHRSZ_X1 (0x00000000u)
#define CSL_OSD_MODE_VHRSZ_X9_8 (0x00000001u)

#define CSL_OSD_MODE_FSINV_MASK (0x00000200u)
#define CSL_OSD_MODE_FSINV_SHIFT (0x00000009u)
#define CSL_OSD_MODE_FSINV_RESETVAL (0x00000000u)
/*----FSINV Tokens----*/
#define CSL_OSD_MODE_FSINV_UNINVERTED (0x00000000u)
#define CSL_OSD_MODE_FSINV_INVERTED (0x00000001u)

#define CSL_OSD_MODE_BCLUT_MASK (0x00000100u)
#define CSL_OSD_MODE_BCLUT_SHIFT (0x00000008u)
#define CSL_OSD_MODE_BCLUT_RESETVAL (0x00000000u)
/*----BCLUT Tokens----*/
#define CSL_OSD_MODE_BCLUT_ROM (0x00000000u)
#define CSL_OSD_MODE_BCLUT_RAM (0x00000001u)

#define CSL_OSD_MODE_CABG_MASK (0x000000FFu)
#define CSL_OSD_MODE_CABG_SHIFT (0x00000000u)
#define CSL_OSD_MODE_CABG_RESETVAL (0x00000000u)

#define CSL_OSD_MODE_RESETVAL (0x00000000u)

/* VIDWINMD */

#define CSL_OSD_VIDWINMD_V1EFC_MASK (0x00004000u)
#define CSL_OSD_VIDWINMD_V1EFC_SHIFT (0x0000000Eu)
#define CSL_OSD_VIDWINMD_V1EFC_RESETVAL (0x00000000u)
/*----V1EFC Tokens----*/
#define CSL_OSD_VIDWINMD_V1EFC_SAME4BOTH (0x00000000u)
#define CSL_OSD_VIDWINMD_V1EFC_DIFFERENT (0x00000001u)

#define CSL_OSD_VIDWINMD_VHZ1_MASK (0x00003000u)
#define CSL_OSD_VIDWINMD_VHZ1_SHIFT (0x0000000Cu)
#define CSL_OSD_VIDWINMD_VHZ1_RESETVAL (0x00000000u)
/*----VHZ1 Tokens----*/
#define CSL_OSD_VIDWINMD_VHZ1_X1 (0x00000000u)
#define CSL_OSD_VIDWINMD_VHZ1_X2 (0x00000001u)
#define CSL_OSD_VIDWINMD_VHZ1_X4 (0x00000002u)
#define CSL_OSD_VIDWINMD_VHZ1_RESERVED (0x00000003u)

#define CSL_OSD_VIDWINMD_VVZ1_MASK (0x00000C00u)
#define CSL_OSD_VIDWINMD_VVZ1_SHIFT (0x0000000Au)
#define CSL_OSD_VIDWINMD_VVZ1_RESETVAL (0x00000000u)
/*----VVZ1 Tokens----*/
#define CSL_OSD_VIDWINMD_VVZ1_X1 (0x00000000u)
#define CSL_OSD_VIDWINMD_VVZ1_X2 (0x00000001u)
#define CSL_OSD_VIDWINMD_VVZ1_X4 (0x00000002u)
#define CSL_OSD_VIDWINMD_VVZ1_RESERVED (0x00000003u)

#define CSL_OSD_VIDWINMD_VFF1_MASK (0x00000200u)
#define CSL_OSD_VIDWINMD_VFF1_SHIFT (0x00000009u)
#define CSL_OSD_VIDWINMD_VFF1_RESETVAL (0x00000000u)
/*----VFF1 Tokens----*/
#define CSL_OSD_VIDWINMD_VFF1_FIELDMODE (0x00000000u)
#define CSL_OSD_VIDWINMD_VFF1_FRAMEMODE (0x00000001u)

#define CSL_OSD_VIDWINMD_ACT1_MASK (0x00000100u)
#define CSL_OSD_VIDWINMD_ACT1_SHIFT (0x00000008u)
#define CSL_OSD_VIDWINMD_ACT1_RESETVAL (0x00000000u)
/*----ACT1 Tokens----*/
#define CSL_OSD_VIDWINMD_ACT1_OFF (0x00000000u)
#define CSL_OSD_VIDWINMD_ACT1_ON (0x00000001u)

#define CSL_OSD_VIDWINMD_V0EFC_MASK (0x00000040u)
#define CSL_OSD_VIDWINMD_V0EFC_SHIFT (0x00000006u)
#define CSL_OSD_VIDWINMD_V0EFC_RESETVAL (0x00000000u)
/*----V0EFC Tokens----*/
#define CSL_OSD_VIDWINMD_V0EFC_SAME4BOTH (0x00000000u)
#define CSL_OSD_VIDWINMD_V0EFC_DIFFERENT (0x00000001u)

#define CSL_OSD_VIDWINMD_VHZ0_MASK (0x00000030u)
#define CSL_OSD_VIDWINMD_VHZ0_SHIFT (0x00000004u)
#define CSL_OSD_VIDWINMD_VHZ0_RESETVAL (0x00000000u)
/*----VHZ0 Tokens----*/
#define CSL_OSD_VIDWINMD_VHZ0_X1 (0x00000000u)
#define CSL_OSD_VIDWINMD_VHZ0_X2 (0x00000001u)
#define CSL_OSD_VIDWINMD_VHZ0_X4 (0x00000002u)
#define CSL_OSD_VIDWINMD_VHZ0_RESERVED (0x00000003u)

#define CSL_OSD_VIDWINMD_VVZ0_MASK (0x0000000Cu)
#define CSL_OSD_VIDWINMD_VVZ0_SHIFT (0x00000002u)
#define CSL_OSD_VIDWINMD_VVZ0_RESETVAL (0x00000000u)
/*----VVZ0 Tokens----*/
#define CSL_OSD_VIDWINMD_VVZ0_X1 (0x00000000u)
#define CSL_OSD_VIDWINMD_VVZ0_X2 (0x00000001u)
#define CSL_OSD_VIDWINMD_VVZ0_X4 (0x00000002u)
#define CSL_OSD_VIDWINMD_VVZ0_RESERVED (0x00000003u)

#define CSL_OSD_VIDWINMD_VFF0_MASK (0x00000002u)
#define CSL_OSD_VIDWINMD_VFF0_SHIFT (0x00000001u)
#define CSL_OSD_VIDWINMD_VFF0_RESETVAL (0x00000000u)
/*----VFF0 Tokens----*/
#define CSL_OSD_VIDWINMD_VFF0_FIELDMODE (0x00000000u)
#define CSL_OSD_VIDWINMD_VFF0_FRAMEMODE (0x00000001u)

#define CSL_OSD_VIDWINMD_ACT0_MASK (0x00000001u)
#define CSL_OSD_VIDWINMD_ACT0_SHIFT (0x00000000u)
#define CSL_OSD_VIDWINMD_ACT0_RESETVAL (0x00000000u)
/*----ACT0 Tokens----*/
#define CSL_OSD_VIDWINMD_ACT0_OFF (0x00000000u)
#define CSL_OSD_VIDWINMD_ACT0_ON (0x00000001u)

#define CSL_OSD_VIDWINMD_RESETVAL (0x00000000u)

/* OSDWIN0MD */



#define CSL_OSD_OSDWIN0MD_DVDE0_MASK (0x00004000u)
#define CSL_OSD_OSDWIN0MD_DVDE0_SHIFT (0x0000000Eu)
#define CSL_OSD_OSDWIN0MD_DVDE0_RESETVAL (0x00000000u)
/*----DVDE0 Tokens----*/
#define CSL_OSD_OSDWIN0MD_DVDE0_NORMALBMP (0x00000000u)
#define CSL_OSD_OSDWIN0MD_DVDE0_DVDBMP (0x00000001u)

#define CSL_OSD_OSDWIN0MD_RGB0E_MASK (0x00002000u)
#define CSL_OSD_OSDWIN0MD_RGB0E_SHIFT (0x0000000Du)
#define CSL_OSD_OSDWIN0MD_RGB0E_RESETVAL (0x00000000u)
/*----RGB0E Tokens----*/
#define CSL_OSD_OSDWIN0MD_RGB0E_BMPLUT_MODE (0x00000000u)
#define CSL_OSD_OSDWIN0MD_RGB0E_RGB16_MODE (0x00000001u)

#define CSL_OSD_OSDWIN0MD_CLUTS0_MASK (0x00001000u)
#define CSL_OSD_OSDWIN0MD_CLUTS0_SHIFT (0x0000000Cu)
#define CSL_OSD_OSDWIN0MD_CLUTS0_RESETVAL (0x00000000u)
/*----CLUTS0 Tokens----*/
#define CSL_OSD_OSDWIN0MD_CLUTS0_ROM_LUT (0x00000000u)
#define CSL_OSD_OSDWIN0MD_CLUTS0_RAM_LUT (0x00000001u)

#define CSL_OSD_OSDWIN0MD_OHZ0_MASK (0x00000C00u)
#define CSL_OSD_OSDWIN0MD_OHZ0_SHIFT (0x0000000Au)
#define CSL_OSD_OSDWIN0MD_OHZ0_RESETVAL (0x00000000u)
/*----OHZ0 Tokens----*/
#define CSL_OSD_OSDWIN0MD_OHZ0_X1 (0x00000000u)
#define CSL_OSD_OSDWIN0MD_OHZ0_X2 (0x00000001u)
#define CSL_OSD_OSDWIN0MD_OHZ0_X4 (0x00000002u)
#define CSL_OSD_OSDWIN0MD_OHZ0_RESERVED (0x00000003u)

#define CSL_OSD_OSDWIN0MD_OVZ0_MASK (0x00000300u)
#define CSL_OSD_OSDWIN0MD_OVZ0_SHIFT (0x00000008u)
#define CSL_OSD_OSDWIN0MD_OVZ0_RESETVAL (0x00000000u)
/*----OVZ0 Tokens----*/
#define CSL_OSD_OSDWIN0MD_OVZ0_X1 (0x00000000u)
#define CSL_OSD_OSDWIN0MD_OVZ0_X2 (0x00000001u)
#define CSL_OSD_OSDWIN0MD_OVZ0_X4 (0x00000002u)
#define CSL_OSD_OSDWIN0MD_OVZ0_RESERVED (0x00000003u)

#define CSL_OSD_OSDWIN0MD_BMW0_MASK (0x000000C0u)
#define CSL_OSD_OSDWIN0MD_BMW0_SHIFT (0x00000006u)
#define CSL_OSD_OSDWIN0MD_BMW0_RESETVAL (0x00000000u)
/*----BMW0 Tokens----*/
#define CSL_OSD_OSDWIN0MD_BMW0_1_BIT (0x00000000u)
#define CSL_OSD_OSDWIN0MD_BMW0_2_BITS (0x00000001u)
#define CSL_OSD_OSDWIN0MD_BMW0_4_BITS (0x00000002u)
#define CSL_OSD_OSDWIN0MD_BMW0_8_BITS (0x00000003u)

#define CSL_OSD_OSDWIN0MD_BLND0_MASK (0x00000038u)
#define CSL_OSD_OSDWIN0MD_BLND0_SHIFT (0x00000003u)
#define CSL_OSD_OSDWIN0MD_BLND0_RESETVAL (0x00000000u)
/*----BLND0 Tokens----*/
#define CSL_OSD_OSDWIN0MD_BLND0_OSD0_VID1 (0x00000000u)
#define CSL_OSD_OSDWIN0MD_BLND0_OSD1_VID7 (0x00000001u)
#define CSL_OSD_OSDWIN0MD_BLND0_OSD2_VID6 (0x00000002u)
#define CSL_OSD_OSDWIN0MD_BLND0_OSD3_VID5 (0x00000003u)
#define CSL_OSD_OSDWIN0MD_BLND0_OSD4_VID4 (0x00000004u)
#define CSL_OSD_OSDWIN0MD_BLND0_OSD5_VID3 (0x00000005u)
#define CSL_OSD_OSDWIN0MD_BLND0_OSD6_VID2 (0x00000006u)
#define CSL_OSD_OSDWIN0MD_BLND0_OSD1_VID0 (0x00000007u)

#define CSL_OSD_OSDWIN0MD_TE0_MASK (0x00000004u)
#define CSL_OSD_OSDWIN0MD_TE0_SHIFT (0x00000002u)
#define CSL_OSD_OSDWIN0MD_TE0_RESETVAL (0x00000000u)
/*----TE0 Tokens----*/
#define CSL_OSD_OSDWIN0MD_TE0_DISABLE (0x00000000u)
#define CSL_OSD_OSDWIN0MD_TE0_ENABLE (0x00000001u)

#define CSL_OSD_OSDWIN0MD_OFF0_MASK (0x00000002u)
#define CSL_OSD_OSDWIN0MD_OFF0_SHIFT (0x00000001u)
#define CSL_OSD_OSDWIN0MD_OFF0_RESETVAL (0x00000000u)
/*----OFF0 Tokens----*/
#define CSL_OSD_OSDWIN0MD_OFF0_FIELDMODE (0x00000000u)
#define CSL_OSD_OSDWIN0MD_OFF0_FRAMEMODE (0x00000001u)

#define CSL_OSD_OSDWIN0MD_OACT0_MASK (0x00000001u)
#define CSL_OSD_OSDWIN0MD_OACT0_SHIFT (0x00000000u)
#define CSL_OSD_OSDWIN0MD_OACT0_RESETVAL (0x00000000u)
/*----OACT0 Tokens----*/
#define CSL_OSD_OSDWIN0MD_OACT0_OFF (0x00000000u)
#define CSL_OSD_OSDWIN0MD_OACT0_ON (0x00000001u)

#define CSL_OSD_OSDWIN0MD_RESETVAL (0x00000000u)

/* OSDWIN1MD */


#define CSL_OSD_OSDWIN1MD_OASW_MASK (0x00008000u)
#define CSL_OSD_OSDWIN1MD_OASW_SHIFT (0x0000000Fu)
#define CSL_OSD_OSDWIN1MD_OASW_RESETVAL (0x00000000u)
/*----OASW Tokens----*/
#define CSL_OSD_OSDWIN1MD_OASW_OSDWINDOW1 (0x00000000u)
#define CSL_OSD_OSDWIN1MD_OASW_ATTRIBUTEWINDOW (0x00000001u)

#define CSL_OSD_OSDWIN1MD_DVDE1_MASK (0x00004000u)
#define CSL_OSD_OSDWIN1MD_DVDE1_SHIFT (0x0000000Eu)
#define CSL_OSD_OSDWIN1MD_DVDE1_RESETVAL (0x00000000u)
/*----DVDE1 Tokens----*/
#define CSL_OSD_OSDWIN1MD_DVDE1_NORMALBMP (0x00000000u)
#define CSL_OSD_OSDWIN1MD_DVDE1_DVDBMP (0x00000001u)

#define CSL_OSD_OSDWIN1MD_RGB1E_MASK (0x00002000u)
#define CSL_OSD_OSDWIN1MD_RGB1E_SHIFT (0x0000000Du)
#define CSL_OSD_OSDWIN1MD_RGB1E_RESETVAL (0x00000000u)
/*----RGB1E Tokens----*/
#define CSL_OSD_OSDWIN1MD_RGB1E_BMPLUT_MODE (0x00000000u)
#define CSL_OSD_OSDWIN1MD_RGB1E_RGB16_MODE (0x00000001u)

#define CSL_OSD_OSDWIN1MD_CLUTS1_MASK (0x00001000u)
#define CSL_OSD_OSDWIN1MD_CLUTS1_SHIFT (0x0000000Cu)
#define CSL_OSD_OSDWIN1MD_CLUTS1_RESETVAL (0x00000000u)
/*----CLUTS1 Tokens----*/
#define CSL_OSD_OSDWIN1MD_CLUTS1_ROM_LUT (0x00000000u)
#define CSL_OSD_OSDWIN1MD_CLUTS1_RAM_LUT (0x00000001u)

#define CSL_OSD_OSDWIN1MD_OHZ1_MASK (0x00000C00u)
#define CSL_OSD_OSDWIN1MD_OHZ1_SHIFT (0x0000000Au)
#define CSL_OSD_OSDWIN1MD_OHZ1_RESETVAL (0x00000000u)
/*----OHZ1 Tokens----*/
#define CSL_OSD_OSDWIN1MD_OHZ1_X1 (0x00000000u)
#define CSL_OSD_OSDWIN1MD_OHZ1_X2 (0x00000001u)
#define CSL_OSD_OSDWIN1MD_OHZ1_X4 (0x00000002u)
#define CSL_OSD_OSDWIN1MD_OHZ1_RESERVED (0x00000003u)

#define CSL_OSD_OSDWIN1MD_OVZ1_MASK (0x00000300u)
#define CSL_OSD_OSDWIN1MD_OVZ1_SHIFT (0x00000008u)
#define CSL_OSD_OSDWIN1MD_OVZ1_RESETVAL (0x00000000u)
/*----OVZ1 Tokens----*/
#define CSL_OSD_OSDWIN1MD_OVZ1_X1 (0x00000000u)
#define CSL_OSD_OSDWIN1MD_OVZ1_X2 (0x00000001u)
#define CSL_OSD_OSDWIN1MD_OVZ1_X4 (0x00000002u)
#define CSL_OSD_OSDWIN1MD_OVZ1_RESERVED (0x00000003u)

#define CSL_OSD_OSDWIN1MD_BMW1_MASK (0x000000C0u)
#define CSL_OSD_OSDWIN1MD_BMW1_SHIFT (0x00000006u)
#define CSL_OSD_OSDWIN1MD_BMW1_RESETVAL (0x00000000u)
/*----BMW1 Tokens----*/
#define CSL_OSD_OSDWIN1MD_BMW1_1_BIT (0x00000000u)
#define CSL_OSD_OSDWIN1MD_BMW1_2_BITS (0x00000001u)
#define CSL_OSD_OSDWIN1MD_BMW1_4_BITS (0x00000002u)
#define CSL_OSD_OSDWIN1MD_BMW1_8_BITS (0x00000003u)

#define CSL_OSD_OSDWIN1MD_BLND1_MASK (0x00000038u)
#define CSL_OSD_OSDWIN1MD_BLND1_SHIFT (0x00000003u)
#define CSL_OSD_OSDWIN1MD_BLND1_RESETVAL (0x00000000u)
/*----BLND1 Tokens----*/
#define CSL_OSD_OSDWIN1MD_BLND1_OSD0_VID1 (0x00000000u)
#define CSL_OSD_OSDWIN1MD_BLND1_OSD1_VID7 (0x00000001u)
#define CSL_OSD_OSDWIN1MD_BLND1_OSD2_VID6 (0x00000002u)
#define CSL_OSD_OSDWIN1MD_BLND1_OSD3_VID5 (0x00000003u)
#define CSL_OSD_OSDWIN1MD_BLND1_OSD4_VID4 (0x00000004u)
#define CSL_OSD_OSDWIN1MD_BLND1_OSD5_VID3 (0x00000005u)
#define CSL_OSD_OSDWIN1MD_BLND1_OSD6_VID2 (0x00000006u)
#define CSL_OSD_OSDWIN1MD_BLND1_OSD1_VID0 (0x00000007u)

#define CSL_OSD_OSDWIN1MD_TE1_MASK (0x00000004u)
#define CSL_OSD_OSDWIN1MD_TE1_SHIFT (0x00000002u)
#define CSL_OSD_OSDWIN1MD_TE1_RESETVAL (0x00000000u)
/*----TE1 Tokens----*/
#define CSL_OSD_OSDWIN1MD_TE1_DISABLE (0x00000000u)
#define CSL_OSD_OSDWIN1MD_TE1_ENABLE (0x00000001u)

#define CSL_OSD_OSDWIN1MD_OFF1_MASK (0x00000002u)
#define CSL_OSD_OSDWIN1MD_OFF1_SHIFT (0x00000001u)
#define CSL_OSD_OSDWIN1MD_OFF1_RESETVAL (0x00000000u)
/*----OFF1 Tokens----*/
#define CSL_OSD_OSDWIN1MD_OFF1_FIELDMODE (0x00000000u)
#define CSL_OSD_OSDWIN1MD_OFF1_FRAMEMODE (0x00000001u)

#define CSL_OSD_OSDWIN1MD_OACT1_MASK (0x00000001u)
#define CSL_OSD_OSDWIN1MD_OACT1_SHIFT (0x00000000u)
#define CSL_OSD_OSDWIN1MD_OACT1_RESETVAL (0x00000000u)
/*----OACT1 Tokens----*/
#define CSL_OSD_OSDWIN1MD_OACT1_OFF (0x00000000u)
#define CSL_OSD_OSDWIN1MD_OACT1_ON (0x00000001u)

#define CSL_OSD_OSDWIN1MD_RESETVAL (0x00000000u)

/* OSDATRMD */


#define CSL_OSD_OSDATRMD_OASW_MASK (0x00008000u)
#define CSL_OSD_OSDATRMD_OASW_SHIFT (0x0000000Fu)
#define CSL_OSD_OSDATRMD_OASW_RESETVAL (0x00000000u)
/*----OASW Tokens----*/
#define CSL_OSD_OSDATRMD_OASW_OSDWINDOW1 (0x00000000u)
#define CSL_OSD_OSDATRMD_OASW_ATTRIBUTEWINDOW (0x00000001u)




#define CSL_OSD_OSDATRMD_OHZA_MASK (0x00000C00u)
#define CSL_OSD_OSDATRMD_OHZA_SHIFT (0x0000000Au)
#define CSL_OSD_OSDATRMD_OHZA_RESETVAL (0x00000000u)
/*----OHZA Tokens----*/
#define CSL_OSD_OSDATRMD_OHZA_X1 (0x00000000u)
#define CSL_OSD_OSDATRMD_OHZA_X2 (0x00000001u)
#define CSL_OSD_OSDATRMD_OHZA_X4 (0x00000002u)
#define CSL_OSD_OSDATRMD_OHZA_RESERVED (0x00000003u)

#define CSL_OSD_OSDATRMD_OVZA_MASK (0x00000300u)
#define CSL_OSD_OSDATRMD_OVZA_SHIFT (0x00000008u)
#define CSL_OSD_OSDATRMD_OVZA_RESETVAL (0x00000000u)
/*----OVZA Tokens----*/
#define CSL_OSD_OSDATRMD_OVZA_X1 (0x00000000u)
#define CSL_OSD_OSDATRMD_OVZA_X2 (0x00000001u)
#define CSL_OSD_OSDATRMD_OVZA_X4 (0x00000002u)
#define CSL_OSD_OSDATRMD_OVZA_RESERVED (0x00000003u)

#define CSL_OSD_OSDATRMD_BLNKINT_MASK (0x000000C0u)
#define CSL_OSD_OSDATRMD_BLNKINT_SHIFT (0x00000006u)
#define CSL_OSD_OSDATRMD_BLNKINT_RESETVAL (0x00000000u)
/*----BLNKINT Tokens----*/
#define CSL_OSD_OSDATRMD_BLNKINT_1_UNIT (0x00000000u)
#define CSL_OSD_OSDATRMD_BLNKINT_2_UNITS (0x00000001u)
#define CSL_OSD_OSDATRMD_BLNKINT_3_UNITS (0x00000002u)
#define CSL_OSD_OSDATRMD_BLNKINT_4_UNITS (0x00000003u)



#define CSL_OSD_OSDATRMD_OFFA_MASK (0x00000002u)
#define CSL_OSD_OSDATRMD_OFFA_SHIFT (0x00000001u)
#define CSL_OSD_OSDATRMD_OFFA_RESETVAL (0x00000000u)
/*----OFFA Tokens----*/
#define CSL_OSD_OSDATRMD_OFFA_FIELDMODE (0x00000000u)
#define CSL_OSD_OSDATRMD_OFFA_FRAMEMODE (0x00000001u)

#define CSL_OSD_OSDATRMD_BLNK_MASK (0x00000001u)
#define CSL_OSD_OSDATRMD_BLNK_SHIFT (0x00000000u)
#define CSL_OSD_OSDATRMD_BLNK_RESETVAL (0x00000000u)
/*----BLNK Tokens----*/
#define CSL_OSD_OSDATRMD_BLNK_OFF (0x00000000u)
#define CSL_OSD_OSDATRMD_BLNK_ON (0x00000001u)

#define CSL_OSD_OSDATRMD_RESETVAL (0x00000000u)

/* RECTCUR */


#define CSL_OSD_RECTCUR_RCAD_MASK (0x0000FF00u)
#define CSL_OSD_RECTCUR_RCAD_SHIFT (0x00000008u)
#define CSL_OSD_RECTCUR_RCAD_RESETVAL (0x00000000u)

#define CSL_OSD_RECTCUR_CLUTSR_MASK (0x00000080u)
#define CSL_OSD_RECTCUR_CLUTSR_SHIFT (0x00000007u)
#define CSL_OSD_RECTCUR_CLUTSR_RESETVAL (0x00000000u)
/*----CLUTSR Tokens----*/
#define CSL_OSD_RECTCUR_CLUTSR_ROM_LUT (0x00000000u)
#define CSL_OSD_RECTCUR_CLUTSR_RAM_LUT (0x00000001u)

#define CSL_OSD_RECTCUR_RCHW_MASK (0x00000070u)
#define CSL_OSD_RECTCUR_RCHW_SHIFT (0x00000004u)
#define CSL_OSD_RECTCUR_RCHW_RESETVAL (0x00000000u)

#define CSL_OSD_RECTCUR_RCVW_MASK (0x0000000Eu)
#define CSL_OSD_RECTCUR_RCVW_SHIFT (0x00000001u)
#define CSL_OSD_RECTCUR_RCVW_RESETVAL (0x00000000u)

#define CSL_OSD_RECTCUR_RCACT_MASK (0x00000001u)
#define CSL_OSD_RECTCUR_RCACT_SHIFT (0x00000000u)
#define CSL_OSD_RECTCUR_RCACT_RESETVAL (0x00000000u)
/*----RCACT Tokens----*/
#define CSL_OSD_RECTCUR_RCACT_OFF (0x00000000u)
#define CSL_OSD_RECTCUR_RCACT_ON (0x00000001u)

#define CSL_OSD_RECTCUR_RESETVAL (0x00000000u)

/* VIDWIN0OFST */


#define CSL_OSD_VIDWIN0OFST_V0LO_MASK (0x000001FFu)
#define CSL_OSD_VIDWIN0OFST_V0LO_SHIFT (0x00000000u)
#define CSL_OSD_VIDWIN0OFST_V0LO_RESETVAL (0x00000000u)

#define CSL_OSD_VIDWIN0OFST_RESETVAL (0x00000000u)

/* VIDWIN1OFST */


#define CSL_OSD_VIDWIN1OFST_V1LO_MASK (0x000001FFu)
#define CSL_OSD_VIDWIN1OFST_V1LO_SHIFT (0x00000000u)
#define CSL_OSD_VIDWIN1OFST_V1LO_RESETVAL (0x00000000u)

#define CSL_OSD_VIDWIN1OFST_RESETVAL (0x00000000u)

/* OSDWIN0OFST */


#define CSL_OSD_OSDWIN0OFST_O0LO_MASK (0x000001FFu)
#define CSL_OSD_OSDWIN0OFST_O0LO_SHIFT (0x00000000u)
#define CSL_OSD_OSDWIN0OFST_O0LO_RESETVAL (0x00000000u)

#define CSL_OSD_OSDWIN0OFST_RESETVAL (0x00000000u)

/* OSDWIN1OFST */


#define CSL_OSD_OSDWIN1OFST_O1LO_MASK (0x000001FFu)
#define CSL_OSD_OSDWIN1OFST_O1LO_SHIFT (0x00000000u)
#define CSL_OSD_OSDWIN1OFST_O1LO_RESETVAL (0x00000000u)

#define CSL_OSD_OSDWIN1OFST_RESETVAL (0x00000000u)

/* RSV1 */

#define CSL_OSD_RSV1_RSV1_MASK (0xFFFFFFFFu)
#define CSL_OSD_RSV1_RSV1_SHIFT (0x00000000u)
#define CSL_OSD_RSV1_RSV1_RESETVAL (0x00000000u)

#define CSL_OSD_RSV1_RESETVAL (0x00000000u)

/* VIDWIN0ADR */

#define CSL_OSD_VIDWIN0ADR_VIDWIN0ADR_MASK (0xFFFFFFFFu)
#define CSL_OSD_VIDWIN0ADR_VIDWIN0ADR_SHIFT (0x00000000u)
#define CSL_OSD_VIDWIN0ADR_VIDWIN0ADR_RESETVAL (0x00000000u)

#define CSL_OSD_VIDWIN0ADR_RESETVAL (0x00000000u)

/* VIDWIN1ADR */

#define CSL_OSD_VIDWIN1ADR_VIDWIN1ADR_MASK (0xFFFFFFFFu)
#define CSL_OSD_VIDWIN1ADR_VIDWIN1ADR_SHIFT (0x00000000u)
#define CSL_OSD_VIDWIN1ADR_VIDWIN1ADR_RESETVAL (0x00000000u)

#define CSL_OSD_VIDWIN1ADR_RESETVAL (0x00000000u)

/* OSDWIN0ADR */

#define CSL_OSD_OSDWIN0ADR_OSDWIN0ADR_MASK (0xFFFFFFFFu)
#define CSL_OSD_OSDWIN0ADR_OSDWIN0ADR_SHIFT (0x00000000u)
#define CSL_OSD_OSDWIN0ADR_OSDWIN0ADR_RESETVAL (0x00000000u)

#define CSL_OSD_OSDWIN0ADR_RESETVAL (0x00000000u)

/* OSDWIN1ADR */

#define CSL_OSD_OSDWIN1ADR_OSDWIN1ADR_MASK (0xFFFFFFFFu)
#define CSL_OSD_OSDWIN1ADR_OSDWIN1ADR_SHIFT (0x00000000u)
#define CSL_OSD_OSDWIN1ADR_OSDWIN1ADR_RESETVAL (0x00000000u)

#define CSL_OSD_OSDWIN1ADR_RESETVAL (0x00000000u)

/* BASEPX */


#define CSL_OSD_BASEPX_BPX_MASK (0x000003FFu)
#define CSL_OSD_BASEPX_BPX_SHIFT (0x00000000u)
#define CSL_OSD_BASEPX_BPX_RESETVAL (0x00000000u)

#define CSL_OSD_BASEPX_RESETVAL (0x00000000u)

/* BASEPY */


#define CSL_OSD_BASEPY_BPY_MASK (0x000001FFu)
#define CSL_OSD_BASEPY_BPY_SHIFT (0x00000000u)
#define CSL_OSD_BASEPY_BPY_RESETVAL (0x00000000u)

#define CSL_OSD_BASEPY_RESETVAL (0x00000000u)

/* VIDWIN0XP */


#define CSL_OSD_VIDWIN0XP_V0X_MASK (0x000003FFu)
#define CSL_OSD_VIDWIN0XP_V0X_SHIFT (0x00000000u)
#define CSL_OSD_VIDWIN0XP_V0X_RESETVAL (0x00000000u)

#define CSL_OSD_VIDWIN0XP_RESETVAL (0x00000000u)

/* VIDWIN0YP */


#define CSL_OSD_VIDWIN0YP_V0Y_MASK (0x000001FFu)
#define CSL_OSD_VIDWIN0YP_V0Y_SHIFT (0x00000000u)
#define CSL_OSD_VIDWIN0YP_V0Y_RESETVAL (0x00000000u)

#define CSL_OSD_VIDWIN0YP_RESETVAL (0x00000000u)

/* VIDWIN0XL */


#define CSL_OSD_VIDWIN0XL_V0W_MASK (0x00000FFFu)
#define CSL_OSD_VIDWIN0XL_V0W_SHIFT (0x00000000u)
#define CSL_OSD_VIDWIN0XL_V0W_RESETVAL (0x00000000u)

#define CSL_OSD_VIDWIN0XL_RESETVAL (0x00000000u)

/* VIDWIN0YL */


#define CSL_OSD_VIDWIN0YL_V0H_MASK (0x000007FFu)
#define CSL_OSD_VIDWIN0YL_V0H_SHIFT (0x00000000u)
#define CSL_OSD_VIDWIN0YL_V0H_RESETVAL (0x00000000u)

#define CSL_OSD_VIDWIN0YL_RESETVAL (0x00000000u)

/* VIDWIN1XP */


#define CSL_OSD_VIDWIN1XP_V1X_MASK (0x000003FFu)
#define CSL_OSD_VIDWIN1XP_V1X_SHIFT (0x00000000u)
#define CSL_OSD_VIDWIN1XP_V1X_RESETVAL (0x00000000u)

#define CSL_OSD_VIDWIN1XP_RESETVAL (0x00000000u)

/* VIDWIN1YP */


#define CSL_OSD_VIDWIN1YP_V1Y_MASK (0x000001FFu)
#define CSL_OSD_VIDWIN1YP_V1Y_SHIFT (0x00000000u)
#define CSL_OSD_VIDWIN1YP_V1Y_RESETVAL (0x00000000u)

#define CSL_OSD_VIDWIN1YP_RESETVAL (0x00000000u)

/* VIDWIN1XL */


#define CSL_OSD_VIDWIN1XL_V1W_MASK (0x00000FFFu)
#define CSL_OSD_VIDWIN1XL_V1W_SHIFT (0x00000000u)
#define CSL_OSD_VIDWIN1XL_V1W_RESETVAL (0x00000000u)

#define CSL_OSD_VIDWIN1XL_RESETVAL (0x00000000u)

/* VIDWIN1YL */


#define CSL_OSD_VIDWIN1YL_V1H_MASK (0x000007FFu)
#define CSL_OSD_VIDWIN1YL_V1H_SHIFT (0x00000000u)
#define CSL_OSD_VIDWIN1YL_V1H_RESETVAL (0x00000000u)

#define CSL_OSD_VIDWIN1YL_RESETVAL (0x00000000u)

/* OSDWIN0XP */


#define CSL_OSD_OSDWIN0XP_W0X_MASK (0x000003FFu)
#define CSL_OSD_OSDWIN0XP_W0X_SHIFT (0x00000000u)
#define CSL_OSD_OSDWIN0XP_W0X_RESETVAL (0x00000000u)

#define CSL_OSD_OSDWIN0XP_RESETVAL (0x00000000u)

/* OSDWIN0YP */


#define CSL_OSD_OSDWIN0YP_W0Y_MASK (0x000001FFu)
#define CSL_OSD_OSDWIN0YP_W0Y_SHIFT (0x00000000u)
#define CSL_OSD_OSDWIN0YP_W0Y_RESETVAL (0x00000000u)

#define CSL_OSD_OSDWIN0YP_RESETVAL (0x00000000u)

/* OSDWIN0XL */


#define CSL_OSD_OSDWIN0XL_W0W_MASK (0x00000FFFu)
#define CSL_OSD_OSDWIN0XL_W0W_SHIFT (0x00000000u)
#define CSL_OSD_OSDWIN0XL_W0W_RESETVAL (0x00000000u)

#define CSL_OSD_OSDWIN0XL_RESETVAL (0x00000000u)

/* OSDWIN0YL */



#define CSL_OSD_OSDWIN0YL_W0H_MASK (0x000007FFu)
#define CSL_OSD_OSDWIN0YL_W0H_SHIFT (0x00000000u)
#define CSL_OSD_OSDWIN0YL_W0H_RESETVAL (0x00000000u)

#define CSL_OSD_OSDWIN0YL_RESETVAL (0x00000000u)

/* OSDWIN1XP */


#define CSL_OSD_OSDWIN1XP_W1X_MASK (0x000003FFu)
#define CSL_OSD_OSDWIN1XP_W1X_SHIFT (0x00000000u)
#define CSL_OSD_OSDWIN1XP_W1X_RESETVAL (0x00000000u)

#define CSL_OSD_OSDWIN1XP_RESETVAL (0x00000000u)

/* OSDWIN1YP */


#define CSL_OSD_OSDWIN1YP_W1Y_MASK (0x000001FFu)
#define CSL_OSD_OSDWIN1YP_W1Y_SHIFT (0x00000000u)
#define CSL_OSD_OSDWIN1YP_W1Y_RESETVAL (0x00000000u)

#define CSL_OSD_OSDWIN1YP_RESETVAL (0x00000000u)

/* OSDWIN1XL */


#define CSL_OSD_OSDWIN1XL_W1W_MASK (0x00000FFFu)
#define CSL_OSD_OSDWIN1XL_W1W_SHIFT (0x00000000u)
#define CSL_OSD_OSDWIN1XL_W1W_RESETVAL (0x00000000u)

#define CSL_OSD_OSDWIN1XL_RESETVAL (0x00000000u)

/* OSDWIN1YL */


#define CSL_OSD_OSDWIN1YL_W1H_MASK (0x000007FFu)
#define CSL_OSD_OSDWIN1YL_W1H_SHIFT (0x00000000u)
#define CSL_OSD_OSDWIN1YL_W1H_RESETVAL (0x00000000u)

#define CSL_OSD_OSDWIN1YL_RESETVAL (0x00000000u)

/* CURXP */


#define CSL_OSD_CURXP_RCSX_MASK (0x000003FFu)
#define CSL_OSD_CURXP_RCSX_SHIFT (0x00000000u)
#define CSL_OSD_CURXP_RCSX_RESETVAL (0x00000000u)

#define CSL_OSD_CURXP_RESETVAL (0x00000000u)

/* CURYP */


#define CSL_OSD_CURYP_RCSY_MASK (0x000001FFu)
#define CSL_OSD_CURYP_RCSY_SHIFT (0x00000000u)
#define CSL_OSD_CURYP_RCSY_RESETVAL (0x00000000u)

#define CSL_OSD_CURYP_RESETVAL (0x00000000u)

/* CURXL */


#define CSL_OSD_CURXL_RCSW_MASK (0x00000FFFu)
#define CSL_OSD_CURXL_RCSW_SHIFT (0x00000000u)
#define CSL_OSD_CURXL_RCSW_RESETVAL (0x00000000u)

#define CSL_OSD_CURXL_RESETVAL (0x00000000u)

/* CURYL */


#define CSL_OSD_CURYL_RCSH_MASK (0x000007FFu)
#define CSL_OSD_CURYL_RCSH_SHIFT (0x00000000u)
#define CSL_OSD_CURYL_RCSH_RESETVAL (0x00000000u)

#define CSL_OSD_CURYL_RESETVAL (0x00000000u)

/* W0BMP01 */


#define CSL_OSD_W0BMP01_PAL01_MASK (0x0000FF00u)
#define CSL_OSD_W0BMP01_PAL01_SHIFT (0x00000008u)
#define CSL_OSD_W0BMP01_PAL01_RESETVAL (0x00000000u)

#define CSL_OSD_W0BMP01_PAL00_MASK (0x000000FFu)
#define CSL_OSD_W0BMP01_PAL00_SHIFT (0x00000000u)
#define CSL_OSD_W0BMP01_PAL00_RESETVAL (0x00000000u)

#define CSL_OSD_W0BMP01_RESETVAL (0x00000000u)

/* W0BMP23 */


#define CSL_OSD_W0BMP23_PAL03_MASK (0x0000FF00u)
#define CSL_OSD_W0BMP23_PAL03_SHIFT (0x00000008u)
#define CSL_OSD_W0BMP23_PAL03_RESETVAL (0x00000000u)

#define CSL_OSD_W0BMP23_PAL02_MASK (0x000000FFu)
#define CSL_OSD_W0BMP23_PAL02_SHIFT (0x00000000u)
#define CSL_OSD_W0BMP23_PAL02_RESETVAL (0x00000000u)

#define CSL_OSD_W0BMP23_RESETVAL (0x00000000u)

/* W0BMP45 */


#define CSL_OSD_W0BMP45_PAL05_MASK (0x0000FF00u)
#define CSL_OSD_W0BMP45_PAL05_SHIFT (0x00000008u)
#define CSL_OSD_W0BMP45_PAL05_RESETVAL (0x00000000u)

#define CSL_OSD_W0BMP45_PAL04_MASK (0x000000FFu)
#define CSL_OSD_W0BMP45_PAL04_SHIFT (0x00000000u)
#define CSL_OSD_W0BMP45_PAL04_RESETVAL (0x00000000u)

#define CSL_OSD_W0BMP45_RESETVAL (0x00000000u)

/* W0BMP67 */


#define CSL_OSD_W0BMP67_PAL07_MASK (0x0000FF00u)
#define CSL_OSD_W0BMP67_PAL07_SHIFT (0x00000008u)
#define CSL_OSD_W0BMP67_PAL07_RESETVAL (0x00000000u)

#define CSL_OSD_W0BMP67_PAL06_MASK (0x000000FFu)
#define CSL_OSD_W0BMP67_PAL06_SHIFT (0x00000000u)
#define CSL_OSD_W0BMP67_PAL06_RESETVAL (0x00000000u)

#define CSL_OSD_W0BMP67_RESETVAL (0x00000000u)

/* W0BMP89 */


#define CSL_OSD_W0BMP89_PAL09_MASK (0x0000FF00u)
#define CSL_OSD_W0BMP89_PAL09_SHIFT (0x00000008u)
#define CSL_OSD_W0BMP89_PAL09_RESETVAL (0x00000000u)

#define CSL_OSD_W0BMP89_PAL08_MASK (0x000000FFu)
#define CSL_OSD_W0BMP89_PAL08_SHIFT (0x00000000u)
#define CSL_OSD_W0BMP89_PAL08_RESETVAL (0x00000000u)

#define CSL_OSD_W0BMP89_RESETVAL (0x00000000u)

/* W0BMPAB */


#define CSL_OSD_W0BMPAB_PAL11_MASK (0x0000FF00u)
#define CSL_OSD_W0BMPAB_PAL11_SHIFT (0x00000008u)
#define CSL_OSD_W0BMPAB_PAL11_RESETVAL (0x00000000u)

#define CSL_OSD_W0BMPAB_PAL10_MASK (0x000000FFu)
#define CSL_OSD_W0BMPAB_PAL10_SHIFT (0x00000000u)
#define CSL_OSD_W0BMPAB_PAL10_RESETVAL (0x00000000u)

#define CSL_OSD_W0BMPAB_RESETVAL (0x00000000u)

/* W0BMPCD */


#define CSL_OSD_W0BMPCD_PAL13_MASK (0x0000FF00u)
#define CSL_OSD_W0BMPCD_PAL13_SHIFT (0x00000008u)
#define CSL_OSD_W0BMPCD_PAL13_RESETVAL (0x00000000u)

#define CSL_OSD_W0BMPCD_PAL12_MASK (0x000000FFu)
#define CSL_OSD_W0BMPCD_PAL12_SHIFT (0x00000000u)
#define CSL_OSD_W0BMPCD_PAL12_RESETVAL (0x00000000u)

#define CSL_OSD_W0BMPCD_RESETVAL (0x00000000u)

/* W0BMPEF */


#define CSL_OSD_W0BMPEF_PAL15_MASK (0x0000FF00u)
#define CSL_OSD_W0BMPEF_PAL15_SHIFT (0x00000008u)
#define CSL_OSD_W0BMPEF_PAL15_RESETVAL (0x00000000u)

#define CSL_OSD_W0BMPEF_PAL14_MASK (0x000000FFu)
#define CSL_OSD_W0BMPEF_PAL14_SHIFT (0x00000000u)
#define CSL_OSD_W0BMPEF_PAL14_RESETVAL (0x00000000u)

#define CSL_OSD_W0BMPEF_RESETVAL (0x00000000u)

/* W1BMP01 */


#define CSL_OSD_W1BMP01_PAL01_MASK (0x0000FF00u)
#define CSL_OSD_W1BMP01_PAL01_SHIFT (0x00000008u)
#define CSL_OSD_W1BMP01_PAL01_RESETVAL (0x00000000u)

#define CSL_OSD_W1BMP01_PAL00_MASK (0x000000FFu)
#define CSL_OSD_W1BMP01_PAL00_SHIFT (0x00000000u)
#define CSL_OSD_W1BMP01_PAL00_RESETVAL (0x00000000u)

#define CSL_OSD_W1BMP01_RESETVAL (0x00000000u)

/* W1BMP23 */


#define CSL_OSD_W1BMP23_PAL03_MASK (0x0000FF00u)
#define CSL_OSD_W1BMP23_PAL03_SHIFT (0x00000008u)
#define CSL_OSD_W1BMP23_PAL03_RESETVAL (0x00000000u)

#define CSL_OSD_W1BMP23_PAL02_MASK (0x000000FFu)
#define CSL_OSD_W1BMP23_PAL02_SHIFT (0x00000000u)
#define CSL_OSD_W1BMP23_PAL02_RESETVAL (0x00000000u)

#define CSL_OSD_W1BMP23_RESETVAL (0x00000000u)

/* W1BMP45 */


#define CSL_OSD_W1BMP45_PAL05_MASK (0x0000FF00u)
#define CSL_OSD_W1BMP45_PAL05_SHIFT (0x00000008u)
#define CSL_OSD_W1BMP45_PAL05_RESETVAL (0x00000000u)

#define CSL_OSD_W1BMP45_PAL04_MASK (0x000000FFu)
#define CSL_OSD_W1BMP45_PAL04_SHIFT (0x00000000u)
#define CSL_OSD_W1BMP45_PAL04_RESETVAL (0x00000000u)

#define CSL_OSD_W1BMP45_RESETVAL (0x00000000u)

/* W1BMP67 */


#define CSL_OSD_W1BMP67_PAL07_MASK (0x0000FF00u)
#define CSL_OSD_W1BMP67_PAL07_SHIFT (0x00000008u)
#define CSL_OSD_W1BMP67_PAL07_RESETVAL (0x00000000u)

#define CSL_OSD_W1BMP67_PAL06_MASK (0x000000FFu)
#define CSL_OSD_W1BMP67_PAL06_SHIFT (0x00000000u)
#define CSL_OSD_W1BMP67_PAL06_RESETVAL (0x00000000u)

#define CSL_OSD_W1BMP67_RESETVAL (0x00000000u)

/* W1BMP89 */


#define CSL_OSD_W1BMP89_PAL09_MASK (0x0000FF00u)
#define CSL_OSD_W1BMP89_PAL09_SHIFT (0x00000008u)
#define CSL_OSD_W1BMP89_PAL09_RESETVAL (0x00000000u)

#define CSL_OSD_W1BMP89_PAL08_MASK (0x000000FFu)
#define CSL_OSD_W1BMP89_PAL08_SHIFT (0x00000000u)
#define CSL_OSD_W1BMP89_PAL08_RESETVAL (0x00000000u)

#define CSL_OSD_W1BMP89_RESETVAL (0x00000000u)

/* W1BMPAB */


#define CSL_OSD_W1BMPAB_PAL11_MASK (0x0000FF00u)
#define CSL_OSD_W1BMPAB_PAL11_SHIFT (0x00000008u)
#define CSL_OSD_W1BMPAB_PAL11_RESETVAL (0x00000000u)

#define CSL_OSD_W1BMPAB_PAL10_MASK (0x000000FFu)
#define CSL_OSD_W1BMPAB_PAL10_SHIFT (0x00000000u)
#define CSL_OSD_W1BMPAB_PAL10_RESETVAL (0x00000000u)

#define CSL_OSD_W1BMPAB_RESETVAL (0x00000000u)

/* W1BMPCD */


#define CSL_OSD_W1BMPCD_PAL13_MASK (0x0000FF00u)
#define CSL_OSD_W1BMPCD_PAL13_SHIFT (0x00000008u)
#define CSL_OSD_W1BMPCD_PAL13_RESETVAL (0x00000000u)

#define CSL_OSD_W1BMPCD_PAL12_MASK (0x000000FFu)
#define CSL_OSD_W1BMPCD_PAL12_SHIFT (0x00000000u)
#define CSL_OSD_W1BMPCD_PAL12_RESETVAL (0x00000000u)

#define CSL_OSD_W1BMPCD_RESETVAL (0x00000000u)

/* W1BMPEF */


#define CSL_OSD_W1BMPEF_PAL15_MASK (0x0000FF00u)
#define CSL_OSD_W1BMPEF_PAL15_SHIFT (0x00000008u)
#define CSL_OSD_W1BMPEF_PAL15_RESETVAL (0x00000000u)

#define CSL_OSD_W1BMPEF_PAL14_MASK (0x000000FFu)
#define CSL_OSD_W1BMPEF_PAL14_SHIFT (0x00000000u)
#define CSL_OSD_W1BMPEF_PAL14_RESETVAL (0x00000000u)

#define CSL_OSD_W1BMPEF_RESETVAL (0x00000000u)

/* MISCCTL */


#define CSL_OSD_MISCCTL_VIDOVRLMODE_MASK (0x00001000u)
#define CSL_OSD_MISCCTL_VIDOVRLMODE_SHIFT (0x0000000Cu)
#define CSL_OSD_MISCCTL_VIDOVRLMODE_RESETVAL (0x00000000u)
/*----VIDOVRLMODE  Tokens----*/
#define CSL_OSD_MISCCTL_VIDOVRLMODE_NORMAL (0x00000000u)
#define CSL_OSD_MISCCTL_VIDOVRLMODE_ENABLED (0x00000001u)

#define CSL_OSD_MISCCTL_VFINV_MASK (0x00000800u)
#define CSL_OSD_MISCCTL_VFINV_SHIFT (0x0000000Bu)
#define CSL_OSD_MISCCTL_VFINV_RESETVAL (0x00000000u)
/*----VFINV Tokens----*/
#define CSL_OSD_MISCCTL_VFINV_INVERSED (0x00000000u)
#define CSL_OSD_MISCCTL_VFINV_NORMAL (0x00000001u)

#define CSL_OSD_MISCCTL_CLUTWR_DVD_MASK (0x00000400u)
#define CSL_OSD_MISCCTL_CLUTWR_DVD_SHIFT (0x0000000Au)
#define CSL_OSD_MISCCTL_CLUTWR_DVD_RESETVAL (0x00000000u)
/*----CLUTWR_DVD Tokens----*/
#define CSL_OSD_MISCCTL_CLUTWR_DVD_NORMAL (0x00000000u)
#define CSL_OSD_MISCCTL_CLUTWR_DVD_DVDMODE (0x00000001u)

#define CSL_OSD_MISCCTL_ATN0E_MASK (0x00000200u)
#define CSL_OSD_MISCCTL_ATN0E_SHIFT (0x00000009u)
#define CSL_OSD_MISCCTL_ATN0E_RESETVAL (0x00000000u)
/*----ATN0E Tokens----*/
#define CSL_OSD_MISCCTL_ATN0E_NORMAL (0x00000000u)
#define CSL_OSD_MISCCTL_ATN0E_ATTEN (0x00000001u)

#define CSL_OSD_MISCCTL_ATN1E_MASK (0x00000100u)
#define CSL_OSD_MISCCTL_ATN1E_SHIFT (0x00000008u)
#define CSL_OSD_MISCCTL_ATN1E_RESETVAL (0x00000000u)
/*----ATN1E Tokens----*/
#define CSL_OSD_MISCCTL_ATN1E_NORMAL (0x00000000u)
#define CSL_OSD_MISCCTL_ATN1E_ATTEN (0x00000001u)

#define CSL_OSD_MISCCTL_RGBEN_MASK (0x00000080u)
#define CSL_OSD_MISCCTL_RGBEN_SHIFT (0x00000007u)
#define CSL_OSD_MISCCTL_RGBEN_RESETVAL (0x00000000u)
/*----RGBEN Tokens----*/
#define CSL_OSD_MISCCTL_RGBEN_DISABLE (0x00000000u)
#define CSL_OSD_MISCCTL_RGBEN_ENABLE (0x00000001u)

#define CSL_OSD_MISCCTL_RGBWIN_MASK (0x00000040u)
#define CSL_OSD_MISCCTL_RGBWIN_SHIFT (0x00000006u)
#define CSL_OSD_MISCCTL_RGBWIN_RESETVAL (0x00000000u)
/*----RGBWIN Tokens----*/
#define CSL_OSD_MISCCTL_RGBWIN_VIDWIN0 (0x00000000u)
#define CSL_OSD_MISCCTL_RGBWIN_VIDWIN1 (0x00000001u)


#define CSL_OSD_MISCCTL_RSEL_MASK (0x00000010u)
#define CSL_OSD_MISCCTL_RSEL_SHIFT (0x00000004u)
#define CSL_OSD_MISCCTL_RSEL_RESETVAL (0x00000000u)
/*----RSEL Tokens----*/
#define CSL_OSD_MISCCTL_RSEL_CLUT0_DM270 (0x00000000u)
#define CSL_OSD_MISCCTL_RSEL_CLUT1_DM320 (0x00000001u)

#define CSL_OSD_MISCCTL_CPBSY_MASK (0x00000008u)
#define CSL_OSD_MISCCTL_CPBSY_SHIFT (0x00000003u)
#define CSL_OSD_MISCCTL_CPBSY_RESETVAL (0x00000000u)
/*----CPBSY Tokens----*/
#define CSL_OSD_MISCCTL_CPBSY_NOTBUSY (0x00000000u)
#define CSL_OSD_MISCCTL_CPBSY_BUSY (0x00000001u)

#define CSL_OSD_MISCCTL_PPSW_MASK (0x00000004u)
#define CSL_OSD_MISCCTL_PPSW_SHIFT (0x00000002u)
#define CSL_OSD_MISCCTL_PPSW_RESETVAL (0x00000000u)
/*----PPSW Tokens----*/
#define CSL_OSD_MISCCTL_PPSW_PPRV0_V0ADR_PPRV1_PPADR (0x00000000u)
#define CSL_OSD_MISCCTL_PPSW_PPRV0_PPADR_PPRV1_V0ADR (0x00000001u)

#define CSL_OSD_MISCCTL_PPRV_MASK (0x00000002u)
#define CSL_OSD_MISCCTL_PPRV_SHIFT (0x00000001u)
#define CSL_OSD_MISCCTL_PPRV_RESETVAL (0x00000000u)


#define CSL_OSD_MISCCTL_RESETVAL (0x00000000u)

/* CLUTRAMYCB */


#define CSL_OSD_CLUTRAMYCB_Y_MASK (0x0000FF00u)
#define CSL_OSD_CLUTRAMYCB_Y_SHIFT (0x00000008u)
#define CSL_OSD_CLUTRAMYCB_Y_RESETVAL (0x00000000u)

#define CSL_OSD_CLUTRAMYCB_CB_MASK (0x000000FFu)
#define CSL_OSD_CLUTRAMYCB_CB_SHIFT (0x00000000u)
#define CSL_OSD_CLUTRAMYCB_CB_RESETVAL (0x00000000u)

#define CSL_OSD_CLUTRAMYCB_RESETVAL (0x00000000u)

/* CLUTRAMCR */


#define CSL_OSD_CLUTRAMCR_CR_MASK (0x0000FF00u)
#define CSL_OSD_CLUTRAMCR_CR_SHIFT (0x00000008u)
#define CSL_OSD_CLUTRAMCR_CR_RESETVAL (0x00000000u)

#define CSL_OSD_CLUTRAMCR_CADDR_MASK (0x000000FFu)
#define CSL_OSD_CLUTRAMCR_CADDR_SHIFT (0x00000000u)
#define CSL_OSD_CLUTRAMCR_CADDR_RESETVAL (0x00000000u)

#define CSL_OSD_CLUTRAMCR_RESETVAL (0x00000000u)

/* TRANSPVAL */


#define CSL_OSD_TRANSPVAL_RGBTRANS_MASK (0x0000FFFFu)
#define CSL_OSD_TRANSPVAL_RGBTRANS_SHIFT (0x00000000u)
#define CSL_OSD_TRANSPVAL_RGBTRANS_RESETVAL (0x00000000u)

#define CSL_OSD_TRANSPVAL_RESETVAL (0x00000000u)

/* PPVWIN0ADR */

#define CSL_OSD_PPVWIN0ADR_PPVWIN0ADR_MASK (0xFFFFFFFFu)
#define CSL_OSD_PPVWIN0ADR_PPVWIN0ADR_SHIFT (0x00000000u)
#define CSL_OSD_PPVWIN0ADR_PPVWIN0ADR_RESETVAL (0x00000000u)

#define CSL_OSD_PPVWIN0ADR_RESETVAL (0x00000000u)

#ifdef __cplusplus
}
#endif

#endif

