/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005, 2006
 *
 *   Use of this software is controlled by the terms and conditions found in the
 *   license agreement under which this software has been supplied.
 *   ===========================================================================
 */
/** ============================================================================
 *   @file  cslr_prev.h
 *
 *   @path  $(CSLPATH)\inc
 *
 *   @desc  This file contains the Register Descriptions for PREV
 *  ============================================================================
 */
#ifndef _CSLR_PREV_H_
#define _CSLR_PREV_H_

#ifdef __cplusplus
extern "C" {
#endif

#include <ti/sdo/pspdrivers/soc/dm6437/dsp/cslr.h>
#include <ti/sdo/pspdrivers/soc/dm6437/dsp/tistdtypes.h>

/* Minimum unit = 1 byte */

/**************************************************************************\
* Register Overlay Structure
\**************************************************************************/
typedef struct  {
    volatile Uint32 PID;
    volatile Uint32 PCR;
    volatile Uint32 HORZ_INFO;
    volatile Uint32 VERT_INFO;
    volatile Uint32 RSDR_ADDR;
    volatile Uint32 RADR_OFFSET;
    volatile Uint32 DSDR_ADDR;
    volatile Uint32 DRKF_OFFSET;
    volatile Uint32 WSDR_ADDR;
    volatile Uint32 WADD_OFFSET;
    volatile Uint32 AVE;
    volatile Uint32 HMED;
    volatile Uint32 NF;
    volatile Uint32 WB_DGAIN;
    volatile Uint32 WBGAIN;
    volatile Uint32 WBSEL;
    volatile Uint32 CFA;
    volatile Uint32 BLKADJOFF;
    volatile Uint32 RGB_MAT1;
    volatile Uint32 RGB_MAT2;
    volatile Uint32 RGB_MAT3;
    volatile Uint32 RGB_MAT4;
    volatile Uint32 RGB_MAT5;
    volatile Uint32 RGB_OFF1;
    volatile Uint32 RGB_OFF2;
    volatile Uint32 CSC0;
    volatile Uint32 CSC1;
    volatile Uint32 CSC2;
    volatile Uint32 CSC_OFFSET;
    volatile Uint32 CNT_BRT;
    volatile Uint32 CSUP;
    volatile Uint32 SETUP_YC;
    volatile Uint32 SET_TBL_ADDRESS;
    volatile Uint32 SET_TBL_DATA;
} CSL_PrevRegs;
/**************************************************************************\
* Overlay structure typedef definition
\**************************************************************************/
typedef volatile CSL_PrevRegs         *CSL_PrevRegsOvly;

/**************************************************************************\
* Field Definition Macros
\**************************************************************************/

/* PID */


#define CSL_PREV_PID_TID_MASK (0x00FF0000u)
#define CSL_PREV_PID_TID_SHIFT (0x00000010u)
#define CSL_PREV_PID_TID_RESETVAL (0x00000002u)

#define CSL_PREV_PID_CID_MASK (0x0000FF00u)
#define CSL_PREV_PID_CID_SHIFT (0x00000008u)
#define CSL_PREV_PID_CID_RESETVAL (0x000000FEu)

#define CSL_PREV_PID_PREV_MASK (0x000000FFu)
#define CSL_PREV_PID_PREV_SHIFT (0x00000000u)
#define CSL_PREV_PID_PREV_RESETVAL (0x00000000u)

#define CSL_PREV_PID_RESETVAL (0x0002FE00u)

/* PCR */

#define CSL_PREV_PCR_DRK_FAIL_MASK (0x80000000u)
#define CSL_PREV_PCR_DRK_FAIL_SHIFT (0x0000001Fu)
#define CSL_PREV_PCR_DRK_FAIL_RESETVAL (0x00000000u)
/*----DRK_FAIL Tokens----*/
#define CSL_PREV_PCR_DRK_FAIL_PASS (0x00000000u)
#define CSL_PREV_PCR_DRK_FAIL_FAIL (0x00000001u)


#define CSL_PREV_PCR_GAMMA_BYPASS_MASK (0x04000000u)
#define CSL_PREV_PCR_GAMMA_BYPASS_SHIFT (0x0000001Au)
#define CSL_PREV_PCR_GAMMA_BYPASS_RESETVAL (0x00000000u)
/*----GAMMA_BYPASS Tokens----*/
#define CSL_PREV_PCR_GAMMA_BYPASS_NO_BYPASS (0x00000000u)
#define CSL_PREV_PCR_GAMMA_BYPASS_BYPASS (0x00000001u)


#define CSL_PREV_PCR_SHADE_SFT_MASK (0x01C00000u)
#define CSL_PREV_PCR_SHADE_SFT_SHIFT (0x00000016u)
#define CSL_PREV_PCR_SHADE_SFT_RESETVAL (0x00000000u)

#define CSL_PREV_PCR_SHADE_COMP_MASK (0x00200000u)
#define CSL_PREV_PCR_SHADE_COMP_SHIFT (0x00000015u)
#define CSL_PREV_PCR_SHADE_COMP_RESETVAL (0x00000000u)
/*----SHADE_COMP Tokens----*/
#define CSL_PREV_PCR_SHADE_COMP_DISABLE (0x00000000u)
#define CSL_PREV_PCR_SHADE_COMP_ENABLE (0x00000001u)

#define CSL_PREV_PCR_SDRPORT_MASK (0x00100000u)
#define CSL_PREV_PCR_SDRPORT_SHIFT (0x00000014u)
#define CSL_PREV_PCR_SDRPORT_RESETVAL (0x00000001u)
/*----SDRPORT Tokens----*/
#define CSL_PREV_PCR_SDRPORT_DISABLE (0x00000000u)
#define CSL_PREV_PCR_SDRPORT_ENABLE (0x00000001u)

#define CSL_PREV_PCR_RSZPORT_MASK (0x00080000u)
#define CSL_PREV_PCR_RSZPORT_SHIFT (0x00000013u)
#define CSL_PREV_PCR_RSZPORT_RESETVAL (0x00000000u)
/*----RSZPORT Tokens----*/
#define CSL_PREV_PCR_RSZPORT_DISABLE (0x00000000u)
#define CSL_PREV_PCR_RSZPORT_ENABLE (0x00000001u)

#define CSL_PREV_PCR_YCPOS_MASK (0x00060000u)
#define CSL_PREV_PCR_YCPOS_SHIFT (0x00000011u)
#define CSL_PREV_PCR_YCPOS_RESETVAL (0x00000000u)
/*----YCPOS Tokens----*/
#define CSL_PREV_PCR_YCPOS_YCRYCB (0x00000000u)
#define CSL_PREV_PCR_YCPOS_YCBYCR (0x00000001u)
#define CSL_PREV_PCR_YCPOS_CBYCRY (0x00000002u)
#define CSL_PREV_PCR_YCPOS_CRYCBY (0x00000003u)

#define CSL_PREV_PCR_SUPEN_MASK (0x00010000u)
#define CSL_PREV_PCR_SUPEN_SHIFT (0x00000010u)
#define CSL_PREV_PCR_SUPEN_RESETVAL (0x00000000u)
/*----SUPEN Tokens----*/
#define CSL_PREV_PCR_SUPEN_DISABLE (0x00000000u)
#define CSL_PREV_PCR_SUPEN_ENABLE (0x00000001u)

#define CSL_PREV_PCR_YNENHEN_MASK (0x00008000u)
#define CSL_PREV_PCR_YNENHEN_SHIFT (0x0000000Fu)
#define CSL_PREV_PCR_YNENHEN_RESETVAL (0x00000000u)
/*----YNENHEN Tokens----*/
#define CSL_PREV_PCR_YNENHEN_DISABLE (0x00000000u)
#define CSL_PREV_PCR_YNENHEN_ENABLE (0x00000001u)

#define CSL_PREV_PCR_CFAFMT_MASK (0x00007800u)
#define CSL_PREV_PCR_CFAFMT_SHIFT (0x0000000Bu)
#define CSL_PREV_PCR_CFAFMT_RESETVAL (0x00000000u)
/*----CFAFMT Tokens----*/
#define CSL_PREV_PCR_CFAFMT_CONV_BAYER (0x00000000u)
#define CSL_PREV_PCR_CFAFMT_V_AND_H_2X_DNSAMPLE (0x00000003u)

#define CSL_PREV_PCR_CFAEN_MASK (0x00000400u)
#define CSL_PREV_PCR_CFAEN_SHIFT (0x0000000Au)
#define CSL_PREV_PCR_CFAEN_RESETVAL (0x00000000u)
/*----CFAEN Tokens----*/
#define CSL_PREV_PCR_CFAEN_DISABLE (0x00000000u)
#define CSL_PREV_PCR_CFAEN_ENABLE (0x00000001u)

#define CSL_PREV_PCR_NFEN_MASK (0x00000200u)
#define CSL_PREV_PCR_NFEN_SHIFT (0x00000009u)
#define CSL_PREV_PCR_NFEN_RESETVAL (0x00000000u)
/*----NFEN Tokens----*/
#define CSL_PREV_PCR_NFEN_DISABLE (0x00000000u)
#define CSL_PREV_PCR_NFEN_ENABLE (0x00000001u)

#define CSL_PREV_PCR_HMEDEN_MASK (0x00000100u)
#define CSL_PREV_PCR_HMEDEN_SHIFT (0x00000008u)
#define CSL_PREV_PCR_HMEDEN_RESETVAL (0x00000000u)
/*----HMEDEN Tokens----*/
#define CSL_PREV_PCR_HMEDEN_DISABLE (0x00000000u)
#define CSL_PREV_PCR_HMEDEN_ENABLE (0x00000001u)

#define CSL_PREV_PCR_DRKFCAP_MASK (0x00000080u)
#define CSL_PREV_PCR_DRKFCAP_SHIFT (0x00000007u)
#define CSL_PREV_PCR_DRKFCAP_RESETVAL (0x00000000u)
/*----DRKFCAP Tokens----*/
#define CSL_PREV_PCR_DRKFCAP_NORMAL (0x00000000u)
#define CSL_PREV_PCR_DRKFCAP_CAPT_DK_FRM (0x00000001u)

#define CSL_PREV_PCR_DRKFEN_MASK (0x00000040u)
#define CSL_PREV_PCR_DRKFEN_SHIFT (0x00000006u)
#define CSL_PREV_PCR_DRKFEN_RESETVAL (0x00000000u)
/*----DRKFEN Tokens----*/
#define CSL_PREV_PCR_DRKFEN_DISABLE (0x00000000u)
#define CSL_PREV_PCR_DRKFEN_ENABLE (0x00000001u)

#define CSL_PREV_PCR_INVALAW_MASK (0x00000020u)
#define CSL_PREV_PCR_INVALAW_SHIFT (0x00000005u)
#define CSL_PREV_PCR_INVALAW_RESETVAL (0x00000000u)
/*----INVALAW Tokens----*/
#define CSL_PREV_PCR_INVALAW_DISABLE (0x00000000u)
#define CSL_PREV_PCR_INVALAW_ENABLE (0x00000001u)

#define CSL_PREV_PCR_WIDTH_MASK (0x00000010u)
#define CSL_PREV_PCR_WIDTH_SHIFT (0x00000004u)
#define CSL_PREV_PCR_WIDTH_RESETVAL (0x00000000u)
/*----WIDTH Tokens----*/
#define CSL_PREV_PCR_WIDTH_10_BITWIDE (0x00000000u)
#define CSL_PREV_PCR_WIDTH_8_BITWIDE (0x00000001u)

#define CSL_PREV_PCR_ONESHOT_MASK (0x00000008u)
#define CSL_PREV_PCR_ONESHOT_SHIFT (0x00000003u)
#define CSL_PREV_PCR_ONESHOT_RESETVAL (0x00000000u)
/*----ONESHOT Tokens----*/
#define CSL_PREV_PCR_ONESHOT_CONTINUOUS_VIA_VPORT (0x00000000u)
#define CSL_PREV_PCR_ONESHOT_ONESHOTMODE (0x00000001u)

#define CSL_PREV_PCR_SOURCE_MASK (0x00000004u)
#define CSL_PREV_PCR_SOURCE_SHIFT (0x00000002u)
#define CSL_PREV_PCR_SOURCE_RESETVAL (0x00000000u)
/*----SOURCE Tokens----*/
#define CSL_PREV_PCR_SOURCE_VPORT_VIA_CCDC (0x00000000u)
#define CSL_PREV_PCR_SOURCE_SDRAM (0x00000001u)

#define CSL_PREV_PCR_BUSY_MASK (0x00000002u)
#define CSL_PREV_PCR_BUSY_SHIFT (0x00000001u)
#define CSL_PREV_PCR_BUSY_RESETVAL (0x00000000u)
/*----BUSY Tokens----*/
#define CSL_PREV_PCR_BUSY_NOTBUSY (0x00000000u)
#define CSL_PREV_PCR_BUSY_BUSY (0x00000001u)

#define CSL_PREV_PCR_ENABLE_MASK (0x00000001u)
#define CSL_PREV_PCR_ENABLE_SHIFT (0x00000000u)
#define CSL_PREV_PCR_ENABLE_RESETVAL (0x00000000u)
/*----ENABLE Tokens----*/
#define CSL_PREV_PCR_ENABLE_PREV_DISABLE (0x00000000u)
#define CSL_PREV_PCR_ENABLE_PREV_ENABLE (0x00000001u)

#define CSL_PREV_PCR_RESETVAL (0x00100000u)

/* HORZ_INFO */


#define CSL_PREV_HORZ_INFO_SPH_MASK (0x3FFF0000u)
#define CSL_PREV_HORZ_INFO_SPH_SHIFT (0x00000010u)
#define CSL_PREV_HORZ_INFO_SPH_RESETVAL (0x00000000u)


#define CSL_PREV_HORZ_INFO_EPH_MASK (0x00003FFFu)
#define CSL_PREV_HORZ_INFO_EPH_SHIFT (0x00000000u)
#define CSL_PREV_HORZ_INFO_EPH_RESETVAL (0x00000000u)

#define CSL_PREV_HORZ_INFO_RESETVAL (0x00000000u)

/* VERT_INFO */


#define CSL_PREV_VERT_INFO_SLV_MASK (0x3FFF0000u)
#define CSL_PREV_VERT_INFO_SLV_SHIFT (0x00000010u)
#define CSL_PREV_VERT_INFO_SLV_RESETVAL (0x00000000u)


#define CSL_PREV_VERT_INFO_ELV_MASK (0x00003FFFu)
#define CSL_PREV_VERT_INFO_ELV_SHIFT (0x00000000u)
#define CSL_PREV_VERT_INFO_ELV_RESETVAL (0x00000000u)

#define CSL_PREV_VERT_INFO_RESETVAL (0x00000000u)

/* RSDR_ADDR */

#define CSL_PREV_RSDR_ADDR_RADR_MASK (0xFFFFFFFFu)
#define CSL_PREV_RSDR_ADDR_RADR_SHIFT (0x00000000u)
#define CSL_PREV_RSDR_ADDR_RADR_RESETVAL (0x00000000u)

#define CSL_PREV_RSDR_ADDR_RESETVAL (0x00000000u)

/* RADR_OFFSET */


#define CSL_PREV_RADR_OFFSET_OFFSET_MASK (0x0000FFFFu)
#define CSL_PREV_RADR_OFFSET_OFFSET_SHIFT (0x00000000u)
#define CSL_PREV_RADR_OFFSET_OFFSET_RESETVAL (0x00000000u)

#define CSL_PREV_RADR_OFFSET_RESETVAL (0x00000000u)

/* DSDR_ADDR */

#define CSL_PREV_DSDR_ADDR_DRKF_MASK (0xFFFFFFFFu)
#define CSL_PREV_DSDR_ADDR_DRKF_SHIFT (0x00000000u)
#define CSL_PREV_DSDR_ADDR_DRKF_RESETVAL (0x00000000u)

#define CSL_PREV_DSDR_ADDR_RESETVAL (0x00000000u)

/* DRKF_OFFSET */


#define CSL_PREV_DRKF_OFFSET_OFFSET_MASK (0x0000FFFFu)
#define CSL_PREV_DRKF_OFFSET_OFFSET_SHIFT (0x00000000u)
#define CSL_PREV_DRKF_OFFSET_OFFSET_RESETVAL (0x00000000u)

#define CSL_PREV_DRKF_OFFSET_RESETVAL (0x00000000u)

/* WSDR_ADDR */

#define CSL_PREV_WSDR_ADDR_ADDR_MASK (0xFFFFFFFFu)
#define CSL_PREV_WSDR_ADDR_ADDR_SHIFT (0x00000000u)
#define CSL_PREV_WSDR_ADDR_ADDR_RESETVAL (0x00000000u)

#define CSL_PREV_WSDR_ADDR_RESETVAL (0x00000000u)

/* WADD_OFFSET */


#define CSL_PREV_WADD_OFFSET_OFFSET_MASK (0x0000FFFFu)
#define CSL_PREV_WADD_OFFSET_OFFSET_SHIFT (0x00000000u)
#define CSL_PREV_WADD_OFFSET_OFFSET_RESETVAL (0x00000000u)

#define CSL_PREV_WADD_OFFSET_RESETVAL (0x00000000u)

/* AVE */


#define CSL_PREV_AVE_ODDDIST_MASK (0x00000030u)
#define CSL_PREV_AVE_ODDDIST_SHIFT (0x00000004u)
#define CSL_PREV_AVE_ODDDIST_RESETVAL (0x00000000u)
/*----ODDDIST Tokens----*/
#define CSL_PREV_AVE_ODDDIST_1PIXEL (0x00000000u)
#define CSL_PREV_AVE_ODDDIST_2PIXELS (0x00000001u)
#define CSL_PREV_AVE_ODDDIST_3PIXELS (0x00000002u)
#define CSL_PREV_AVE_ODDDIST_4PIXELS (0x00000003u)

#define CSL_PREV_AVE_EVENDIST_MASK (0x0000000Cu)
#define CSL_PREV_AVE_EVENDIST_SHIFT (0x00000002u)
#define CSL_PREV_AVE_EVENDIST_RESETVAL (0x00000000u)
/*----EVENDIST Tokens----*/
#define CSL_PREV_AVE_EVENDIST_1PIXEL (0x00000000u)
#define CSL_PREV_AVE_EVENDIST_2PIXELS (0x00000001u)
#define CSL_PREV_AVE_EVENDIST_3PIXELS (0x00000002u)
#define CSL_PREV_AVE_EVENDIST_4PIXELS (0x00000003u)

#define CSL_PREV_AVE_COUNT_MASK (0x00000003u)
#define CSL_PREV_AVE_COUNT_SHIFT (0x00000000u)
#define CSL_PREV_AVE_COUNT_RESETVAL (0x00000000u)
/*----COUNT Tokens----*/
#define CSL_PREV_AVE_COUNT_NOAVERAGING (0x00000000u)
#define CSL_PREV_AVE_COUNT_2PIXEL_AVG (0x00000001u)
#define CSL_PREV_AVE_COUNT_4PIXEL_AVG (0x00000002u)
#define CSL_PREV_AVE_COUNT_8PIXEL_AVG (0x00000003u)

#define CSL_PREV_AVE_RESETVAL (0x00000000u)

/* HMED */


#define CSL_PREV_HMED_ODDDIST_MASK (0x00000200u)
#define CSL_PREV_HMED_ODDDIST_SHIFT (0x00000009u)
#define CSL_PREV_HMED_ODDDIST_RESETVAL (0x00000000u)
/*----ODDDIST Tokens----*/
#define CSL_PREV_HMED_ODDDIST_1PIXEL (0x00000000u)
#define CSL_PREV_HMED_ODDDIST_2PIXELS (0x00000001u)

#define CSL_PREV_HMED_EVENDIST_MASK (0x00000100u)
#define CSL_PREV_HMED_EVENDIST_SHIFT (0x00000008u)
#define CSL_PREV_HMED_EVENDIST_RESETVAL (0x00000000u)
/*----EVENDIST Tokens----*/
#define CSL_PREV_HMED_EVENDIST_1PIXEL (0x00000000u)
#define CSL_PREV_HMED_EVENDIST_2PIXELS (0x00000001u)

#define CSL_PREV_HMED_THRESHOLD_MASK (0x000000FFu)
#define CSL_PREV_HMED_THRESHOLD_SHIFT (0x00000000u)
#define CSL_PREV_HMED_THRESHOLD_RESETVAL (0x00000000u)

#define CSL_PREV_HMED_RESETVAL (0x00000000u)

/* NF */


#define CSL_PREV_NF_STRNGTH_MASK (0x0000000Fu)
#define CSL_PREV_NF_STRNGTH_SHIFT (0x00000000u)
#define CSL_PREV_NF_STRNGTH_RESETVAL (0x00000000u)

#define CSL_PREV_NF_RESETVAL (0x00000000u)

/* WB_DGAIN */


#define CSL_PREV_WB_DGAIN_DGAIN_MASK (0x000003FFu)
#define CSL_PREV_WB_DGAIN_DGAIN_SHIFT (0x00000000u)
#define CSL_PREV_WB_DGAIN_DGAIN_RESETVAL (0x00000100u)

#define CSL_PREV_WB_DGAIN_RESETVAL (0x00000100u)

/* WBGAIN */

#define CSL_PREV_WBGAIN_COEF3_MASK (0xFF000000u)
#define CSL_PREV_WBGAIN_COEF3_SHIFT (0x00000018u)
#define CSL_PREV_WBGAIN_COEF3_RESETVAL (0x00000020u)

#define CSL_PREV_WBGAIN_COEF2_MASK (0x00FF0000u)
#define CSL_PREV_WBGAIN_COEF2_SHIFT (0x00000010u)
#define CSL_PREV_WBGAIN_COEF2_RESETVAL (0x00000020u)

#define CSL_PREV_WBGAIN_COEF1_MASK (0x0000FF00u)
#define CSL_PREV_WBGAIN_COEF1_SHIFT (0x00000008u)
#define CSL_PREV_WBGAIN_COEF1_RESETVAL (0x00000020u)

#define CSL_PREV_WBGAIN_COEF0_MASK (0x000000FFu)
#define CSL_PREV_WBGAIN_COEF0_SHIFT (0x00000000u)
#define CSL_PREV_WBGAIN_COEF0_RESETVAL (0x00000020u)

#define CSL_PREV_WBGAIN_RESETVAL (0x20202020u)

/* WBSEL */

#define CSL_PREV_WBSEL_3_3_MASK (0xC0000000u)
#define CSL_PREV_WBSEL_3_3_SHIFT (0x0000001Eu)
#define CSL_PREV_WBSEL_3_3_RESETVAL (0x00000003u)
/*----3_3 Tokens----*/
#define CSL_PREV_WBSEL_3_3_COEF0 (0x00000000u)
#define CSL_PREV_WBSEL_3_3_COEF1 (0x00000001u)
#define CSL_PREV_WBSEL_3_3_COEF2 (0x00000002u)
#define CSL_PREV_WBSEL_3_3_COEF3 (0x00000003u)

#define CSL_PREV_WBSEL_3_2_MASK (0x30000000u)
#define CSL_PREV_WBSEL_3_2_SHIFT (0x0000001Cu)
#define CSL_PREV_WBSEL_3_2_RESETVAL (0x00000002u)
/*----3_2 Tokens----*/
#define CSL_PREV_WBSEL_3_2_COEF0 (0x00000000u)
#define CSL_PREV_WBSEL_3_2_COEF1 (0x00000001u)
#define CSL_PREV_WBSEL_3_2_COEF2 (0x00000002u)
#define CSL_PREV_WBSEL_3_2_COEF3 (0x00000003u)

#define CSL_PREV_WBSEL_3_1_MASK (0x0C000000u)
#define CSL_PREV_WBSEL_3_1_SHIFT (0x0000001Au)
#define CSL_PREV_WBSEL_3_1_RESETVAL (0x00000003u)
/*----3_1 Tokens----*/
#define CSL_PREV_WBSEL_3_1_COEF0 (0x00000000u)
#define CSL_PREV_WBSEL_3_1_COEF1 (0x00000001u)
#define CSL_PREV_WBSEL_3_1_COEF2 (0x00000002u)
#define CSL_PREV_WBSEL_3_1_COEF3 (0x00000003u)

#define CSL_PREV_WBSEL_3_0_MASK (0x03000000u)
#define CSL_PREV_WBSEL_3_0_SHIFT (0x00000018u)
#define CSL_PREV_WBSEL_3_0_RESETVAL (0x00000002u)
/*----3_0 Tokens----*/
#define CSL_PREV_WBSEL_3_0_COEF0 (0x00000000u)
#define CSL_PREV_WBSEL_3_0_COEF1 (0x00000001u)
#define CSL_PREV_WBSEL_3_0_COEF2 (0x00000002u)
#define CSL_PREV_WBSEL_3_0_COEF3 (0x00000003u)

#define CSL_PREV_WBSEL_2_3_MASK (0x00C00000u)
#define CSL_PREV_WBSEL_2_3_SHIFT (0x00000016u)
#define CSL_PREV_WBSEL_2_3_RESETVAL (0x00000001u)
/*----2_3 Tokens----*/
#define CSL_PREV_WBSEL_2_3_COEF0 (0x00000000u)
#define CSL_PREV_WBSEL_2_3_COEF1 (0x00000001u)
#define CSL_PREV_WBSEL_2_3_COEF2 (0x00000002u)
#define CSL_PREV_WBSEL_2_3_COEF3 (0x00000003u)

#define CSL_PREV_WBSEL_2_2_MASK (0x00300000u)
#define CSL_PREV_WBSEL_2_2_SHIFT (0x00000014u)
#define CSL_PREV_WBSEL_2_2_RESETVAL (0x00000000u)
/*----2_2 Tokens----*/
#define CSL_PREV_WBSEL_2_2_COEF0 (0x00000000u)
#define CSL_PREV_WBSEL_2_2_COEF1 (0x00000001u)
#define CSL_PREV_WBSEL_2_2_COEF2 (0x00000002u)
#define CSL_PREV_WBSEL_2_2_COEF3 (0x00000003u)

#define CSL_PREV_WBSEL_2_1_MASK (0x000C0000u)
#define CSL_PREV_WBSEL_2_1_SHIFT (0x00000012u)
#define CSL_PREV_WBSEL_2_1_RESETVAL (0x00000001u)
/*----2_1 Tokens----*/
#define CSL_PREV_WBSEL_2_1_COEF0 (0x00000000u)
#define CSL_PREV_WBSEL_2_1_COEF1 (0x00000001u)
#define CSL_PREV_WBSEL_2_1_COEF2 (0x00000002u)
#define CSL_PREV_WBSEL_2_1_COEF3 (0x00000003u)

#define CSL_PREV_WBSEL_2_0_MASK (0x00030000u)
#define CSL_PREV_WBSEL_2_0_SHIFT (0x00000010u)
#define CSL_PREV_WBSEL_2_0_RESETVAL (0x00000000u)
/*----2_0 Tokens----*/
#define CSL_PREV_WBSEL_2_0_COEF0 (0x00000000u)
#define CSL_PREV_WBSEL_2_0_COEF1 (0x00000001u)
#define CSL_PREV_WBSEL_2_0_COEF2 (0x00000002u)
#define CSL_PREV_WBSEL_2_0_COEF3 (0x00000003u)

#define CSL_PREV_WBSEL_1_3_MASK (0x0000C000u)
#define CSL_PREV_WBSEL_1_3_SHIFT (0x0000000Eu)
#define CSL_PREV_WBSEL_1_3_RESETVAL (0x00000003u)
/*----1_3 Tokens----*/
#define CSL_PREV_WBSEL_1_3_COEF0 (0x00000000u)
#define CSL_PREV_WBSEL_1_3_COEF1 (0x00000001u)
#define CSL_PREV_WBSEL_1_3_COEF2 (0x00000002u)
#define CSL_PREV_WBSEL_1_3_COEF3 (0x00000003u)

#define CSL_PREV_WBSEL_1_2_MASK (0x00003000u)
#define CSL_PREV_WBSEL_1_2_SHIFT (0x0000000Cu)
#define CSL_PREV_WBSEL_1_2_RESETVAL (0x00000002u)
/*----1_2 Tokens----*/
#define CSL_PREV_WBSEL_1_2_COEF0 (0x00000000u)
#define CSL_PREV_WBSEL_1_2_COEF1 (0x00000001u)
#define CSL_PREV_WBSEL_1_2_COEF2 (0x00000002u)
#define CSL_PREV_WBSEL_1_2_COEF3 (0x00000003u)

#define CSL_PREV_WBSEL_1_1_MASK (0x00000C00u)
#define CSL_PREV_WBSEL_1_1_SHIFT (0x0000000Au)
#define CSL_PREV_WBSEL_1_1_RESETVAL (0x00000003u)
/*----1_1 Tokens----*/
#define CSL_PREV_WBSEL_1_1_COEF0 (0x00000000u)
#define CSL_PREV_WBSEL_1_1_COEF1 (0x00000001u)
#define CSL_PREV_WBSEL_1_1_COEF2 (0x00000002u)
#define CSL_PREV_WBSEL_1_1_COEF3 (0x00000003u)

#define CSL_PREV_WBSEL_1_0_MASK (0x00000300u)
#define CSL_PREV_WBSEL_1_0_SHIFT (0x00000008u)
#define CSL_PREV_WBSEL_1_0_RESETVAL (0x00000002u)
/*----1_0 Tokens----*/
#define CSL_PREV_WBSEL_1_0_COEF0 (0x00000000u)
#define CSL_PREV_WBSEL_1_0_COEF1 (0x00000001u)
#define CSL_PREV_WBSEL_1_0_COEF2 (0x00000002u)
#define CSL_PREV_WBSEL_1_0_COEF3 (0x00000003u)

#define CSL_PREV_WBSEL_0_3_MASK (0x000000C0u)
#define CSL_PREV_WBSEL_0_3_SHIFT (0x00000006u)
#define CSL_PREV_WBSEL_0_3_RESETVAL (0x00000001u)
/*----0_3 Tokens----*/
#define CSL_PREV_WBSEL_0_3_COEF0 (0x00000000u)
#define CSL_PREV_WBSEL_0_3_COEF1 (0x00000001u)
#define CSL_PREV_WBSEL_0_3_COEF2 (0x00000002u)
#define CSL_PREV_WBSEL_0_3_COEF3 (0x00000003u)

#define CSL_PREV_WBSEL_0_2_MASK (0x00000030u)
#define CSL_PREV_WBSEL_0_2_SHIFT (0x00000004u)
#define CSL_PREV_WBSEL_0_2_RESETVAL (0x00000000u)
/*----0_2 Tokens----*/
#define CSL_PREV_WBSEL_0_2_COEF0 (0x00000000u)
#define CSL_PREV_WBSEL_0_2_COEF1 (0x00000001u)
#define CSL_PREV_WBSEL_0_2_COEF2 (0x00000002u)
#define CSL_PREV_WBSEL_0_2_COEF3 (0x00000003u)

#define CSL_PREV_WBSEL_0_1_MASK (0x0000000Cu)
#define CSL_PREV_WBSEL_0_1_SHIFT (0x00000002u)
#define CSL_PREV_WBSEL_0_1_RESETVAL (0x00000001u)
/*----0_1 Tokens----*/
#define CSL_PREV_WBSEL_0_1_COEF0 (0x00000000u)
#define CSL_PREV_WBSEL_0_1_COEF1 (0x00000001u)
#define CSL_PREV_WBSEL_0_1_COEF2 (0x00000002u)
#define CSL_PREV_WBSEL_0_1_COEF3 (0x00000003u)

#define CSL_PREV_WBSEL_0_0_MASK (0x00000003u)
#define CSL_PREV_WBSEL_0_0_SHIFT (0x00000000u)
#define CSL_PREV_WBSEL_0_0_RESETVAL (0x00000000u)
/*----0_0 Tokens----*/
#define CSL_PREV_WBSEL_0_0_COEF0 (0x00000000u)
#define CSL_PREV_WBSEL_0_0_COEF1 (0x00000001u)
#define CSL_PREV_WBSEL_0_0_COEF2 (0x00000002u)
#define CSL_PREV_WBSEL_0_0_COEF3 (0x00000003u)

#define CSL_PREV_WBSEL_RESETVAL (0xEE44EE44u)

/* CFA */


#define CSL_PREV_CFA_GRADTH_VER_MASK (0x0000FF00u)
#define CSL_PREV_CFA_GRADTH_VER_SHIFT (0x00000008u)
#define CSL_PREV_CFA_GRADTH_VER_RESETVAL (0x00000000u)

#define CSL_PREV_CFA_GRADTH_HOR_MASK (0x000000FFu)
#define CSL_PREV_CFA_GRADTH_HOR_SHIFT (0x00000000u)
#define CSL_PREV_CFA_GRADTH_HOR_RESETVAL (0x00000000u)

#define CSL_PREV_CFA_RESETVAL (0x00000000u)

/* BLKADJOFF */


#define CSL_PREV_BLKADJOFF_R_MASK (0x00FF0000u)
#define CSL_PREV_BLKADJOFF_R_SHIFT (0x00000010u)
#define CSL_PREV_BLKADJOFF_R_RESETVAL (0x00000000u)

#define CSL_PREV_BLKADJOFF_G_MASK (0x0000FF00u)
#define CSL_PREV_BLKADJOFF_G_SHIFT (0x00000008u)
#define CSL_PREV_BLKADJOFF_G_RESETVAL (0x00000000u)

#define CSL_PREV_BLKADJOFF_B_MASK (0x000000FFu)
#define CSL_PREV_BLKADJOFF_B_SHIFT (0x00000000u)
#define CSL_PREV_BLKADJOFF_B_RESETVAL (0x00000000u)

#define CSL_PREV_BLKADJOFF_RESETVAL (0x00000000u)

/* RGB_MAT1 */


#define CSL_PREV_RGB_MAT1_MTX_GR_MASK (0x0FFF0000u)
#define CSL_PREV_RGB_MAT1_MTX_GR_SHIFT (0x00000010u)
#define CSL_PREV_RGB_MAT1_MTX_GR_RESETVAL (0x00000100u)


#define CSL_PREV_RGB_MAT1_MTX_RR_MASK (0x00000FFFu)
#define CSL_PREV_RGB_MAT1_MTX_RR_SHIFT (0x00000000u)
#define CSL_PREV_RGB_MAT1_MTX_RR_RESETVAL (0x00000100u)

#define CSL_PREV_RGB_MAT1_RESETVAL (0x01000100u)

/* RGB_MAT2 */


#define CSL_PREV_RGB_MAT2_MTX_RG_MASK (0x0FFF0000u)
#define CSL_PREV_RGB_MAT2_MTX_RG_SHIFT (0x00000010u)
#define CSL_PREV_RGB_MAT2_MTX_RG_RESETVAL (0x00000100u)


#define CSL_PREV_RGB_MAT2_MTX_BR_MASK (0x00000FFFu)
#define CSL_PREV_RGB_MAT2_MTX_BR_SHIFT (0x00000000u)
#define CSL_PREV_RGB_MAT2_MTX_BR_RESETVAL (0x00000100u)

#define CSL_PREV_RGB_MAT2_RESETVAL (0x01000100u)

/* RGB_MAT3 */


#define CSL_PREV_RGB_MAT3_MTX_BG_MASK (0x0FFF0000u)
#define CSL_PREV_RGB_MAT3_MTX_BG_SHIFT (0x00000010u)
#define CSL_PREV_RGB_MAT3_MTX_BG_RESETVAL (0x00000100u)


#define CSL_PREV_RGB_MAT3_MTX_GG_MASK (0x00000FFFu)
#define CSL_PREV_RGB_MAT3_MTX_GG_SHIFT (0x00000000u)
#define CSL_PREV_RGB_MAT3_MTX_GG_RESETVAL (0x00000100u)

#define CSL_PREV_RGB_MAT3_RESETVAL (0x01000100u)

/* RGB_MAT4 */


#define CSL_PREV_RGB_MAT4_MTX_GB_MASK (0x0FFF0000u)
#define CSL_PREV_RGB_MAT4_MTX_GB_SHIFT (0x00000010u)
#define CSL_PREV_RGB_MAT4_MTX_GB_RESETVAL (0x00000100u)


#define CSL_PREV_RGB_MAT4_MTX_RB_MASK (0x00000FFFu)
#define CSL_PREV_RGB_MAT4_MTX_RB_SHIFT (0x00000000u)
#define CSL_PREV_RGB_MAT4_MTX_RB_RESETVAL (0x00000100u)

#define CSL_PREV_RGB_MAT4_RESETVAL (0x01000100u)

/* RGB_MAT5 */


#define CSL_PREV_RGB_MAT5_MTX_BB_MASK (0x00000FFFu)
#define CSL_PREV_RGB_MAT5_MTX_BB_SHIFT (0x00000000u)
#define CSL_PREV_RGB_MAT5_MTX_BB_RESETVAL (0x00000100u)

#define CSL_PREV_RGB_MAT5_RESETVAL (0x00000100u)

/* RGB_OFF1 */


#define CSL_PREV_RGB_OFF1_MTX_OFFR_MASK (0x03FF0000u)
#define CSL_PREV_RGB_OFF1_MTX_OFFR_SHIFT (0x00000010u)
#define CSL_PREV_RGB_OFF1_MTX_OFFR_RESETVAL (0x00000000u)


#define CSL_PREV_RGB_OFF1_MTX_OFFG_MASK (0x000003FFu)
#define CSL_PREV_RGB_OFF1_MTX_OFFG_SHIFT (0x00000000u)
#define CSL_PREV_RGB_OFF1_MTX_OFFG_RESETVAL (0x00000000u)

#define CSL_PREV_RGB_OFF1_RESETVAL (0x00000000u)

/* RGB_OFF2 */


#define CSL_PREV_RGB_OFF2_MTX_OFFB_MASK (0x000003FFu)
#define CSL_PREV_RGB_OFF2_MTX_OFFB_SHIFT (0x00000000u)
#define CSL_PREV_RGB_OFF2_MTX_OFFB_RESETVAL (0x00000000u)

#define CSL_PREV_RGB_OFF2_RESETVAL (0x00000000u)

/* CSC0 */


#define CSL_PREV_CSC0_CSCBY_MASK (0x3FF00000u)
#define CSL_PREV_CSC0_CSCBY_SHIFT (0x00000014u)
#define CSL_PREV_CSC0_CSCBY_RESETVAL (0x0000001Cu)

#define CSL_PREV_CSC0_CSCGY_MASK (0x000FFC00u)
#define CSL_PREV_CSC0_CSCGY_SHIFT (0x0000000Au)
#define CSL_PREV_CSC0_CSCGY_RESETVAL (0x00000098u)

#define CSL_PREV_CSC0_CSCRY_MASK (0x000003FFu)
#define CSL_PREV_CSC0_CSCRY_SHIFT (0x00000000u)
#define CSL_PREV_CSC0_CSCRY_RESETVAL (0x0000004Cu)

#define CSL_PREV_CSC0_RESETVAL (0x01C2604Cu)

/* CSC1 */


#define CSL_PREV_CSC1_CSCBCB_MASK (0x3FF00000u)
#define CSL_PREV_CSC1_CSCBCB_SHIFT (0x00000014u)
#define CSL_PREV_CSC1_CSCBCB_RESETVAL (0x00000080u)

#define CSL_PREV_CSC1_CSCGCB_MASK (0x000FFC00u)
#define CSL_PREV_CSC1_CSCGCB_SHIFT (0x0000000Au)
#define CSL_PREV_CSC1_CSCGCB_RESETVAL (0x000003ACu)

#define CSL_PREV_CSC1_CSCRCB_MASK (0x000003FFu)
#define CSL_PREV_CSC1_CSCRCB_SHIFT (0x00000000u)
#define CSL_PREV_CSC1_CSCRCB_RESETVAL (0x000003D4u)

#define CSL_PREV_CSC1_RESETVAL (0x080EB3D4u)

/* CSC2 */


#define CSL_PREV_CSC2_CSCBCR_MASK (0x3FF00000u)
#define CSL_PREV_CSC2_CSCBCR_SHIFT (0x00000014u)
#define CSL_PREV_CSC2_CSCBCR_RESETVAL (0x000003ECu)

#define CSL_PREV_CSC2_CSCGCR_MASK (0x000FFC00u)
#define CSL_PREV_CSC2_CSCGCR_SHIFT (0x0000000Au)
#define CSL_PREV_CSC2_CSCGCR_RESETVAL (0x00000080u)

#define CSL_PREV_CSC2_CSCRCR_MASK (0x000003FFu)
#define CSL_PREV_CSC2_CSCRCR_SHIFT (0x00000000u)
#define CSL_PREV_CSC2_CSCRCR_RESETVAL (0x0000039Eu)

#define CSL_PREV_CSC2_RESETVAL (0x3EC2039Eu)

/* CSC_OFFSET */


#define CSL_PREV_CSC_OFFSET_YOFST_MASK (0x03FF0000u)
#define CSL_PREV_CSC_OFFSET_YOFST_SHIFT (0x00000010u)
#define CSL_PREV_CSC_OFFSET_YOFST_RESETVAL (0x00000000u)

#define CSL_PREV_CSC_OFFSET_OFSTCB_MASK (0x0000FF00u)
#define CSL_PREV_CSC_OFFSET_OFSTCB_SHIFT (0x00000008u)
#define CSL_PREV_CSC_OFFSET_OFSTCB_RESETVAL (0x00000000u)

#define CSL_PREV_CSC_OFFSET_OFSTCR_MASK (0x000000FFu)
#define CSL_PREV_CSC_OFFSET_OFSTCR_SHIFT (0x00000000u)
#define CSL_PREV_CSC_OFFSET_OFSTCR_RESETVAL (0x00000000u)

#define CSL_PREV_CSC_OFFSET_RESETVAL (0x00000000u)

/* CNT_BRT */


#define CSL_PREV_CNT_BRT_CNT_MASK (0x0000FF00u)
#define CSL_PREV_CNT_BRT_CNT_SHIFT (0x00000008u)
#define CSL_PREV_CNT_BRT_CNT_RESETVAL (0x00000010u)

#define CSL_PREV_CNT_BRT_BRT_MASK (0x000000FFu)
#define CSL_PREV_CNT_BRT_BRT_SHIFT (0x00000000u)
#define CSL_PREV_CNT_BRT_BRT_RESETVAL (0x00000000u)

#define CSL_PREV_CNT_BRT_RESETVAL (0x00001000u)

/* CSUP */


#define CSL_PREV_CSUP_HPFY_MASK (0x00010000u)
#define CSL_PREV_CSUP_HPFY_SHIFT (0x00000010u)
#define CSL_PREV_CSUP_HPFY_RESETVAL (0x00000000u)
/*----HPFY Tokens----*/
#define CSL_PREV_CSUP_HPFY_DISABLE (0x00000000u)
#define CSL_PREV_CSUP_HPFY_ENABLE (0x00000001u)

#define CSL_PREV_CSUP_CSUPTH_MASK (0x0000FF00u)
#define CSL_PREV_CSUP_CSUPTH_SHIFT (0x00000008u)
#define CSL_PREV_CSUP_CSUPTH_RESETVAL (0x00000000u)

#define CSL_PREV_CSUP_CSUPG_MASK (0x000000FFu)
#define CSL_PREV_CSUP_CSUPG_SHIFT (0x00000000u)
#define CSL_PREV_CSUP_CSUPG_RESETVAL (0x00000000u)

#define CSL_PREV_CSUP_RESETVAL (0x00000000u)

/* SETUP_YC */

#define CSL_PREV_SETUP_YC_MAXY_MASK (0xFF000000u)
#define CSL_PREV_SETUP_YC_MAXY_SHIFT (0x00000018u)
#define CSL_PREV_SETUP_YC_MAXY_RESETVAL (0x000000FFu)

#define CSL_PREV_SETUP_YC_MINY_MASK (0x00FF0000u)
#define CSL_PREV_SETUP_YC_MINY_SHIFT (0x00000010u)
#define CSL_PREV_SETUP_YC_MINY_RESETVAL (0x00000000u)

#define CSL_PREV_SETUP_YC_MAXC_MASK (0x0000FF00u)
#define CSL_PREV_SETUP_YC_MAXC_SHIFT (0x00000008u)
#define CSL_PREV_SETUP_YC_MAXC_RESETVAL (0x000000FFu)

#define CSL_PREV_SETUP_YC_MINC_MASK (0x000000FFu)
#define CSL_PREV_SETUP_YC_MINC_SHIFT (0x00000000u)
#define CSL_PREV_SETUP_YC_MINC_RESETVAL (0x00000000u)

#define CSL_PREV_SETUP_YC_RESETVAL (0xFF00FF00u)

/* SET_TBL_ADDRESS */


#define CSL_PREV_SET_TBL_ADDRESS_ADDR_MASK (0x00001FFFu)
#define CSL_PREV_SET_TBL_ADDRESS_ADDR_SHIFT (0x00000000u)
#define CSL_PREV_SET_TBL_ADDRESS_ADDR_RESETVAL (0x00000000u)

#define CSL_PREV_SET_TBL_ADDRESS_RESETVAL (0x00000000u)

/* SET_TBL_DATA */


#define CSL_PREV_SET_TBL_DATA_DATA_MASK (0x000FFFFFu)
#define CSL_PREV_SET_TBL_DATA_DATA_SHIFT (0x00000000u)
#define CSL_PREV_SET_TBL_DATA_DATA_RESETVAL (0x00000000u)

#define CSL_PREV_SET_TBL_DATA_RESETVAL (0x00000000u)

#ifdef __cplusplus
}
#endif

#endif



