/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005. 2006
 *
 *   Use of this software is controlled by the terms and conditions found in the
 *   license agreement under which this software has been supplied.
 *   ===========================================================================
 */
 
/** ============================================================================
 *   @file  cslr_venc.h
 *
 *   @path  $(CSLPATH)\inc
 *
 *   @desc  This file contains the Register Desciptions for VENC
 *  ============================================================================
 */
#ifndef _CSLR_VENC_H_
#define _CSLR_VENC_H_

#ifdef __cplusplus
extern "C" {
#endif

#include <ti/sdo/pspdrivers/soc/dm6437/dsp/cslr.h>
#include <ti/sdo/pspdrivers/soc/dm6437/dsp/tistdtypes.h>

/* Minimum unit = 1 byte */

/**************************************************************************\
* Register Overlay Structure
\**************************************************************************/
typedef struct  {
    volatile Uint32 VMOD;
    volatile Uint32 VIDCTL;
    volatile Uint32 VDPRO;
    volatile Uint32 SYNCCTL;
    volatile Uint32 HSPLS;
    volatile Uint32 VSPLS;
    volatile Uint32 HINT;
    volatile Uint32 HSTART;
    volatile Uint32 HVALID;
    volatile Uint32 VINT;
    volatile Uint32 VSTART;
    volatile Uint32 VVALID;
    volatile Uint32 HSDLY;
    volatile Uint32 VSDLY;
    volatile Uint32 YCCCTL;
    volatile Uint32 RGBCTL;
    volatile Uint32 RGBCLP;
    volatile Uint32 LINECTL;
    volatile Uint32 CULLLINE;
    volatile Uint32 LCDOUT;
    volatile Uint32 BRTS;
    volatile Uint32 BRTW;
    volatile Uint32 ACCTL;
    volatile Uint32 PWMP;
    volatile Uint32 PWMW;
    volatile Uint32 DCLKCTL;
    volatile Uint32 DCLKPTN0;
    volatile Uint32 DCLKPTN1;
    volatile Uint32 DCLKPTN2;
    volatile Uint32 DCLKPTN3;
    volatile Uint32 DCLKPTN0A;
    volatile Uint32 DCLKPTN1A;
    volatile Uint32 DCLKPTN2A;
    volatile Uint32 DCLKPTN3A;
    volatile Uint32 DCLKHS;
    volatile Uint32 DCLKHSA;
    volatile Uint32 DCLKHR;
    volatile Uint32 DCLKVS;
    volatile Uint32 DCLKVR;
    volatile Uint32 CAPCTL;
    volatile Uint32 CAPDO;
    volatile Uint32 CAPDE;
    volatile Uint32 ATR0;
    volatile Uint32 ATR1;
    volatile Uint32 ATR2;
    volatile Uint8 RSVD0[4];
    volatile Uint32 VSTAT;
    volatile Uint8 RSVD1[8];
    volatile Uint32 DACTST;
    volatile Uint32 YCOLVL;
    volatile Uint32 SCPROG;
    volatile Uint32 RSV1;
    volatile Uint32 RSV2;
    volatile Uint32 RSV3;
    volatile Uint32 CVBS;
    volatile Uint32 CMPNT;
    volatile Uint32 ETMG0;
    volatile Uint32 ETMG1;
    volatile Uint32 ETMG2;
    volatile Uint32 ETMG3;
    volatile Uint32 DACSEL;
    volatile Uint32 RSV4;
    volatile Uint32 RSV5;
    volatile Uint32 ARGBX0;
    volatile Uint32 ARGBX1;
    volatile Uint32 ARGBX2;
    volatile Uint32 ARGBX3;
    volatile Uint32 ARGBX4;
    volatile Uint32 DRGBX0;
    volatile Uint32 DRGBX1;
    volatile Uint32 DRGBX2;
    volatile Uint32 DRGBX3;
    volatile Uint32 DRGBX4;
    volatile Uint32 VSTARTA;
    volatile Uint32 OSDCLK0;
    volatile Uint32 OSDCLK1;
    volatile Uint32 HVLDCL0;
    volatile Uint32 HVLDCL1;
    volatile Uint32 OSDHADV;
} CSL_VencRegs;

/**************************************************************************\
* Overlay structure typedef definition
\**************************************************************************/
typedef volatile CSL_VencRegs  *CSL_VencRegsOvly;

/**************************************************************************\
* Field Definition Macros
\**************************************************************************/

/* VMOD */


#define CSL_VENC_VMOD_VDMD_MASK (0x0000F000u)
#define CSL_VENC_VMOD_VDMD_SHIFT (0x0000000Cu)
#define CSL_VENC_VMOD_VDMD_RESETVAL (0x00000000u)
/*----VDMD Tokens----*/
#define CSL_VENC_VMOD_VDMD_YCBCR_16BIT (0x00000000u)
#define CSL_VENC_VMOD_VDMD_YCBCR_8BIT (0x00000001u)
#define CSL_VENC_VMOD_VDMD_RGB666_18BIT (0x00000002u)
#define CSL_VENC_VMOD_VDMD_RGB8_8BIT (0x00000003u)
#define CSL_VENC_VMOD_VDMD_EPSON (0x00000004u)
#define CSL_VENC_VMOD_VDMD_CASIO (0x00000005u)
#define CSL_VENC_VMOD_VDMD_UDISP_QVGA (0x00000006u)
#define CSL_VENC_VMOD_VDMD_STN_LCD (0x00000007u)

#define CSL_VENC_VMOD_ITLCL_MASK (0x00000800u)
#define CSL_VENC_VMOD_ITLCL_SHIFT (0x0000000Bu)
#define CSL_VENC_VMOD_ITLCL_RESETVAL (0x00000000u)
/*----ITLCL Tokens----*/
#define CSL_VENC_VMOD_ITLCL_262NTSC_312PAL (0x00000000u)
#define CSL_VENC_VMOD_ITLCL_263NTSC_313PAL (0x00000001u)

#define CSL_VENC_VMOD_ITLC_MASK (0x00000400u)
#define CSL_VENC_VMOD_ITLC_SHIFT (0x0000000Au)
#define CSL_VENC_VMOD_ITLC_RESETVAL (0x00000000u)
/*----ITLC Tokens----*/
#define CSL_VENC_VMOD_ITLC_INTERLACE (0x00000000u)
#define CSL_VENC_VMOD_ITLC_NON_INTERLACE (0x00000001u)

#define CSL_VENC_VMOD_NSIT_MASK (0x00000200u)
#define CSL_VENC_VMOD_NSIT_SHIFT (0x00000009u)
#define CSL_VENC_VMOD_NSIT_RESETVAL (0x00000000u)
/*----NSIT Tokens----*/
#define CSL_VENC_VMOD_NSIT_PROGRESSIVE (0x00000000u)
#define CSL_VENC_VMOD_NSIT_INTERLACE (0x00000001u)

#define CSL_VENC_VMOD_HDMD_MASK (0x00000100u)
#define CSL_VENC_VMOD_HDMD_SHIFT (0x00000008u)
#define CSL_VENC_VMOD_HDMD_RESETVAL (0x00000000u)
/*----HDMD Tokens----*/
#define CSL_VENC_VMOD_HDMD_SDTV (0x00000000u)
#define CSL_VENC_VMOD_HDMD_HDTV (0x00000001u)

#define CSL_VENC_VMOD_TVTYP_MASK (0x000000C0u)
#define CSL_VENC_VMOD_TVTYP_SHIFT (0x00000006u)
#define CSL_VENC_VMOD_TVTYP_RESETVAL (0x00000000u)
/*----TVTYP Tokens----*/
#define CSL_VENC_VMOD_TVTYP_SDTV_NTSC (0x00000000u)
#define CSL_VENC_VMOD_TVTYP_SDTV_PAL (0x00000001u)
#define CSL_VENC_VMOD_TVTYP_SDTV_RESERVEDS1 (0x00000002u)
#define CSL_VENC_VMOD_TVTYP_SDTV_RESERVEDS2 (0x00000003u)
#define CSL_VENC_VMOD_TVTYP_HDTV_525P (0x00000000u)
#define CSL_VENC_VMOD_TVTYP_HDTV_625P (0x00000001u)
#define CSL_VENC_VMOD_TVTYP_HDTV_RESERVEDH1 (0x00000002u)
#define CSL_VENC_VMOD_TVTYP_HDTV_RESERVEDH2 (0x00000003u)

#define CSL_VENC_VMOD_SLAVE_MASK (0x00000020u)
#define CSL_VENC_VMOD_SLAVE_SHIFT (0x00000005u)
#define CSL_VENC_VMOD_SLAVE_RESETVAL (0x00000000u)
/*----SLAVE Tokens----*/
#define CSL_VENC_VMOD_SLAVE_MASTERMODE (0x00000000u)
#define CSL_VENC_VMOD_SLAVE_SLAVEMODE (0x00000001u)

#define CSL_VENC_VMOD_VMD_MASK (0x00000010u)
#define CSL_VENC_VMOD_VMD_SHIFT (0x00000004u)
#define CSL_VENC_VMOD_VMD_RESETVAL (0x00000000u)
/*----VMD Tokens----*/
#define CSL_VENC_VMOD_VMD_NTSC_PALTIMING (0x00000000u)
#define CSL_VENC_VMOD_VMD_NOTNTSC_PALTIMING (0x00000001u)

#define CSL_VENC_VMOD_BLNK_MASK (0x00000008u)
#define CSL_VENC_VMOD_BLNK_SHIFT (0x00000003u)
#define CSL_VENC_VMOD_BLNK_RESETVAL (0x00000000u)
/*----BLNK Tokens----*/
#define CSL_VENC_VMOD_BLNK_NORMAL (0x00000000u)
#define CSL_VENC_VMOD_BLNK_FORCEBLANKING (0x00000001u)


#define CSL_VENC_VMOD_VIE_MASK (0x00000002u)
#define CSL_VENC_VMOD_VIE_SHIFT (0x00000001u)
#define CSL_VENC_VMOD_VIE_RESETVAL (0x00000000u)
/*----VIE Tokens----*/
#define CSL_VENC_VMOD_VIE_FIXED_L_LEVEL_OUT (0x00000000u)
#define CSL_VENC_VMOD_VIE_NORMAL_COMPOSITE_OUT (0x00000001u)

#define CSL_VENC_VMOD_VENC_MASK (0x00000001u)
#define CSL_VENC_VMOD_VENC_SHIFT (0x00000000u)
#define CSL_VENC_VMOD_VENC_RESETVAL (0x00000000u)
/*----VENC Tokens----*/
#define CSL_VENC_VMOD_VENC_DISABLE (0x00000000u)
#define CSL_VENC_VMOD_VENC_ENABLE (0x00000001u)

#define CSL_VENC_VMOD_RESETVAL (0x00000000u)

/* VIDCTL */


#define CSL_VENC_VIDCTL_VCLKP_MASK (0x00004000u)
#define CSL_VENC_VIDCTL_VCLKP_SHIFT (0x0000000Eu)
#define CSL_VENC_VIDCTL_VCLKP_RESETVAL (0x00000000u)
/*----VCLKP Tokens----*/
#define CSL_VENC_VIDCTL_VCLKP_NON_INVERSE (0x00000000u)
#define CSL_VENC_VIDCTL_VCLKP_INVERSE (0x00000001u)

#define CSL_VENC_VIDCTL_VCLKE_MASK (0x00002000u)
#define CSL_VENC_VIDCTL_VCLKE_SHIFT (0x0000000Du)
#define CSL_VENC_VIDCTL_VCLKE_RESETVAL (0x00000000u)
/*----VCLKE Tokens----*/
#define CSL_VENC_VIDCTL_VCLKE_OFF (0x00000000u)
#define CSL_VENC_VIDCTL_VCLKE_ON (0x00000001u)

#define CSL_VENC_VIDCTL_VCLKZ_MASK (0x00001000u)
#define CSL_VENC_VIDCTL_VCLKZ_SHIFT (0x0000000Cu)
#define CSL_VENC_VIDCTL_VCLKZ_RESETVAL (0x00000001u)
/*----VCLKZ Tokens----*/
#define CSL_VENC_VIDCTL_VCLKZ_OUTPUT (0x00000000u)
#define CSL_VENC_VIDCTL_VCLKZ_HIGHIMPEDENCE (0x00000001u)


#define CSL_VENC_VIDCTL_SYDIR_MASK (0x00000100u)
#define CSL_VENC_VIDCTL_SYDIR_SHIFT (0x00000008u)
#define CSL_VENC_VIDCTL_SYDIR_RESETVAL (0x00000001u)
/*----SYDIR Tokens----*/
#define CSL_VENC_VIDCTL_SYDIR_OUTPUT (0x00000000u)
#define CSL_VENC_VIDCTL_SYDIR_INPUT (0x00000001u)


#define CSL_VENC_VIDCTL_DOMD_MASK (0x00000030u)
#define CSL_VENC_VIDCTL_DOMD_SHIFT (0x00000004u)
#define CSL_VENC_VIDCTL_DOMD_RESETVAL (0x00000000u)
/*----DOMD Tokens----*/
#define CSL_VENC_VIDCTL_DOMD_NORMAL_OUT (0x00000000u)
#define CSL_VENC_VIDCTL_DOMD_INVERSE_OUT (0x00000001u)
#define CSL_VENC_VIDCTL_DOMD_L_LEVEL_OUT (0x00000002u)
#define CSL_VENC_VIDCTL_DOMD_H_LEVEL_OUT (0x00000003u)

#define CSL_VENC_VIDCTL_YCSWAP_MASK (0x00000008u)
#define CSL_VENC_VIDCTL_YCSWAP_SHIFT (0x00000003u)
#define CSL_VENC_VIDCTL_YCSWAP_RESETVAL (0x00000000u)
/*----YCSWAP Tokens----*/
#define CSL_VENC_VIDCTL_YCSWAP_NORMAL (0x00000000u)
#define CSL_VENC_VIDCTL_YCSWAP_SWAP_YC (0x00000001u)

#define CSL_VENC_VIDCTL_YCOL_MASK (0x00000004u)
#define CSL_VENC_VIDCTL_YCOL_SHIFT (0x00000002u)
#define CSL_VENC_VIDCTL_YCOL_RESETVAL (0x00000000u)
/*----YCOL Tokens----*/
#define CSL_VENC_VIDCTL_YCOL_NORMAL_OUT (0x00000000u)
#define CSL_VENC_VIDCTL_YCOL_DCLEVEL_OUT (0x00000001u)

#define CSL_VENC_VIDCTL_YCOMD_MASK (0x00000002u)
#define CSL_VENC_VIDCTL_YCOMD_SHIFT (0x00000001u)
#define CSL_VENC_VIDCTL_YCOMD_RESETVAL (0x00000000u)
/*----YCOMD Tokens----*/
#define CSL_VENC_VIDCTL_YCOMD_DIGITAL_VIDEO_OUT (0x00000000u)
#define CSL_VENC_VIDCTL_YCOMD_YC_INPUT_PASSTHRU (0x00000001u)

#define CSL_VENC_VIDCTL_YCDIR_MASK (0x00000001u)
#define CSL_VENC_VIDCTL_YCDIR_SHIFT (0x00000000u)
#define CSL_VENC_VIDCTL_YCDIR_RESETVAL (0x00000001u)
/*----YCDIR Tokens----*/
#define CSL_VENC_VIDCTL_YCDIR_OUTPUT (0x00000000u)
#define CSL_VENC_VIDCTL_YCDIR_INPUT (0x00000001u)

#define CSL_VENC_VIDCTL_RESETVAL (0x00001101u)

/* VDPRO */


#define CSL_VENC_VDPRO_PFLTC_MASK (0x0000C000u)
#define CSL_VENC_VDPRO_PFLTC_SHIFT (0x0000000Eu)
#define CSL_VENC_VDPRO_PFLTC_RESETVAL (0x00000000u)
/*----PFLTC Tokens----*/
#define CSL_VENC_VDPRO_PFLTC_NOFILTER (0x00000000u)
#define CSL_VENC_VDPRO_PFLTC_1_1 (0x00000001u)
#define CSL_VENC_VDPRO_PFLTC_1_2_1 (0x00000002u)
#define CSL_VENC_VDPRO_PFLTC_RESERVED (0x00000003u)

#define CSL_VENC_VDPRO_PFLTY_MASK (0x00003000u)
#define CSL_VENC_VDPRO_PFLTY_SHIFT (0x0000000Cu)
#define CSL_VENC_VDPRO_PFLTY_RESETVAL (0x00000000u)
/*----PFLTY Tokens----*/
#define CSL_VENC_VDPRO_PFLTY_NOFILTER (0x00000000u)
#define CSL_VENC_VDPRO_PFLTY_1_1 (0x00000001u)
#define CSL_VENC_VDPRO_PFLTY_1_2_1 (0x00000002u)
#define CSL_VENC_VDPRO_PFLTY_RESERVED (0x00000003u)

#define CSL_VENC_VDPRO_PFLTR_MASK (0x00000800u)
#define CSL_VENC_VDPRO_PFLTR_SHIFT (0x0000000Bu)
#define CSL_VENC_VDPRO_PFLTR_RESETVAL (0x00000000u)
/*----PFLTR Tokens----*/
#define CSL_VENC_VDPRO_PFLTR_ENCCLOCK_2 (0x00000000u)
#define CSL_VENC_VDPRO_PFLTR_ENCCLOCK (0x00000001u)


#define CSL_VENC_VDPRO_CBTYP_MASK (0x00000200u)
#define CSL_VENC_VDPRO_CBTYP_SHIFT (0x00000009u)
#define CSL_VENC_VDPRO_CBTYP_RESETVAL (0x00000000u)
/*----CBTYP Tokens----*/
#define CSL_VENC_VDPRO_CBTYP_75PCT (0x00000000u)
#define CSL_VENC_VDPRO_CBTYP_100PCT (0x00000001u)

#define CSL_VENC_VDPRO_CBMD_MASK (0x00000100u)
#define CSL_VENC_VDPRO_CBMD_SHIFT (0x00000008u)
#define CSL_VENC_VDPRO_CBMD_RESETVAL (0x00000000u)
/*----CBMD Tokens----*/
#define CSL_VENC_VDPRO_CBMD_NORMAL (0x00000000u)
#define CSL_VENC_VDPRO_CBMD_COLORBAR (0x00000001u)


#define CSL_VENC_VDPRO_ATRGB_MASK (0x00000040u)
#define CSL_VENC_VDPRO_ATRGB_SHIFT (0x00000006u)
#define CSL_VENC_VDPRO_ATRGB_RESETVAL (0x00000000u)
/*----ATRGB Tokens----*/
#define CSL_VENC_VDPRO_ATRGB_NOATTENUATION (0x00000000u)
#define CSL_VENC_VDPRO_ATRGB_REC601_LVL (0x00000001u)

#define CSL_VENC_VDPRO_ATYCC_MASK (0x00000020u)
#define CSL_VENC_VDPRO_ATYCC_SHIFT (0x00000005u)
#define CSL_VENC_VDPRO_ATYCC_RESETVAL (0x00000000u)
/*----ATYCC Tokens----*/
#define CSL_VENC_VDPRO_ATYCC_NOATTENUATION (0x00000000u)
#define CSL_VENC_VDPRO_ATYCC_REC601_LVL (0x00000001u)

#define CSL_VENC_VDPRO_ATCOM_MASK (0x00000010u)
#define CSL_VENC_VDPRO_ATCOM_SHIFT (0x00000004u)
#define CSL_VENC_VDPRO_ATCOM_RESETVAL (0x00000000u)
/*----ATCOM Tokens----*/
#define CSL_VENC_VDPRO_ATCOM_NOATTENUATION (0x00000000u)
#define CSL_VENC_VDPRO_ATCOM_REC601_LVL (0x00000001u)

#define CSL_VENC_VDPRO_DAFRQ_MASK (0x00000008u)
#define CSL_VENC_VDPRO_DAFRQ_SHIFT (0x00000003u)
#define CSL_VENC_VDPRO_DAFRQ_RESETVAL (0x00000000u)
/*----DAFRQ Tokens----*/
#define CSL_VENC_VDPRO_DAFRQ_27MHZ (0x00000000u)
#define CSL_VENC_VDPRO_DAFRQ_54MHZ (0x00000001u)

#define CSL_VENC_VDPRO_DAUPS_MASK (0x00000004u)
#define CSL_VENC_VDPRO_DAUPS_SHIFT (0x00000002u)
#define CSL_VENC_VDPRO_DAUPS_RESETVAL (0x00000000u)
/*----DAUPS Tokens----*/
#define CSL_VENC_VDPRO_DAUPS_OFF (0x00000000u)
#define CSL_VENC_VDPRO_DAUPS_ON (0x00000001u)

#define CSL_VENC_VDPRO_CUPS_MASK (0x00000002u)
#define CSL_VENC_VDPRO_CUPS_SHIFT (0x00000001u)
#define CSL_VENC_VDPRO_CUPS_RESETVAL (0x00000000u)
/*----CUPS Tokens----*/
#define CSL_VENC_VDPRO_CUPS_OFF (0x00000000u)
#define CSL_VENC_VDPRO_CUPS_ON (0x00000001u)

#define CSL_VENC_VDPRO_YUPS_MASK (0x00000001u)
#define CSL_VENC_VDPRO_YUPS_SHIFT (0x00000000u)
#define CSL_VENC_VDPRO_YUPS_RESETVAL (0x00000000u)
/*----YUPS Tokens----*/
#define CSL_VENC_VDPRO_YUPS_OFF (0x00000000u)
#define CSL_VENC_VDPRO_YUPS_ON (0x00000001u)

#define CSL_VENC_VDPRO_RESETVAL (0x00000000u)

/* SYNCCTL */


#define CSL_VENC_SYNCCTL_OVD_MASK (0x00004000u)
#define CSL_VENC_SYNCCTL_OVD_SHIFT (0x0000000Eu)
#define CSL_VENC_SYNCCTL_OVD_RESETVAL (0x00000000u)
/*----OVD Tokens----*/
#define CSL_VENC_SYNCCTL_OVD_NODELAY (0x00000000u)
#define CSL_VENC_SYNCCTL_OVD_DELAY (0x00000001u)

#define CSL_VENC_SYNCCTL_EXFMD_MASK (0x00003000u)
#define CSL_VENC_SYNCCTL_EXFMD_SHIFT (0x0000000Cu)
#define CSL_VENC_SYNCCTL_EXFMD_RESETVAL (0x00000000u)
/*----EXFMD Tokens----*/
#define CSL_VENC_SYNCCTL_EXFMD_LATCH_EXT_FLD_AT_VDHIGH (0x00000000u)
#define CSL_VENC_SYNCCTL_EXFMD_USE_RAW_EXT_FLD (0x00000001u)
#define CSL_VENC_SYNCCTL_EXFMD_USE_EXT_VSYNC_AS_FLDID (0x00000002u)
#define CSL_VENC_SYNCCTL_EXFMD_DET_EXT_VSYNC_PH (0x00000003u)

#define CSL_VENC_SYNCCTL_EXFIV_MASK (0x00000800u)
#define CSL_VENC_SYNCCTL_EXFIV_SHIFT (0x0000000Bu)
#define CSL_VENC_SYNCCTL_EXFIV_RESETVAL (0x00000000u)
/*----EXFIV Tokens----*/
#define CSL_VENC_SYNCCTL_EXFIV_NON_INVERSE (0x00000000u)
#define CSL_VENC_SYNCCTL_EXFIV_INVERSE (0x00000001u)

#define CSL_VENC_SYNCCTL_EXSYNC_MASK (0x00000400u)
#define CSL_VENC_SYNCCTL_EXSYNC_SHIFT (0x0000000Au)
#define CSL_VENC_SYNCCTL_EXSYNC_RESETVAL (0x00000000u)
/*----EXSYNC Tokens----*/
#define CSL_VENC_SYNCCTL_EXSYNC_HSYNC_VSYNCPIN (0x00000000u)
#define CSL_VENC_SYNCCTL_EXSYNC_CCDSYNCSIGNAL (0x00000001u)

#define CSL_VENC_SYNCCTL_EXVIV_MASK (0x00000200u)
#define CSL_VENC_SYNCCTL_EXVIV_SHIFT (0x00000009u)
#define CSL_VENC_SYNCCTL_EXVIV_RESETVAL (0x00000000u)
/*----EXVIV Tokens----*/
#define CSL_VENC_SYNCCTL_EXVIV_ACTIVEH (0x00000000u)
#define CSL_VENC_SYNCCTL_EXVIV_ACTIVEL (0x00000001u)

#define CSL_VENC_SYNCCTL_EXHIV_MASK (0x00000100u)
#define CSL_VENC_SYNCCTL_EXHIV_SHIFT (0x00000008u)
#define CSL_VENC_SYNCCTL_EXHIV_RESETVAL (0x00000000u)
/*----EXHIV Tokens----*/
#define CSL_VENC_SYNCCTL_EXHIV_ACTIVEH (0x00000000u)
#define CSL_VENC_SYNCCTL_EXHIV_ACTIVEL (0x00000001u)

#define CSL_VENC_SYNCCTL_CSP_MASK (0x00000080u)
#define CSL_VENC_SYNCCTL_CSP_SHIFT (0x00000007u)
#define CSL_VENC_SYNCCTL_CSP_RESETVAL (0x00000000u)
/*----CSP Tokens----*/
#define CSL_VENC_SYNCCTL_CSP_ACTIVEH (0x00000000u)
#define CSL_VENC_SYNCCTL_CSP_ACTIVEL (0x00000001u)

#define CSL_VENC_SYNCCTL_CSE_MASK (0x00000040u)
#define CSL_VENC_SYNCCTL_CSE_SHIFT (0x00000006u)
#define CSL_VENC_SYNCCTL_CSE_RESETVAL (0x00000000u)
/*----CSE Tokens----*/
#define CSL_VENC_SYNCCTL_CSE_OFF (0x00000000u)
#define CSL_VENC_SYNCCTL_CSE_ON (0x00000001u)

#define CSL_VENC_SYNCCTL_SYSW_MASK (0x00000020u)
#define CSL_VENC_SYNCCTL_SYSW_SHIFT (0x00000005u)
#define CSL_VENC_SYNCCTL_SYSW_RESETVAL (0x00000000u)
/*----SYSW Tokens----*/
#define CSL_VENC_SYNCCTL_SYSW_NORMAL (0x00000000u)
#define CSL_VENC_SYNCCTL_SYSW_SYNC_PW_PROC (0x00000001u)

#define CSL_VENC_SYNCCTL_VSYNCS_MASK (0x00000010u)
#define CSL_VENC_SYNCCTL_VSYNCS_SHIFT (0x00000004u)
#define CSL_VENC_SYNCCTL_VSYNCS_RESETVAL (0x00000000u)
/*----VSYNCS Tokens----*/
#define CSL_VENC_SYNCCTL_VSYNCS_VSYNC (0x00000000u)
#define CSL_VENC_SYNCCTL_VSYNCS_COMPOSITE_SYNC (0x00000001u)

#define CSL_VENC_SYNCCTL_VPL_MASK (0x00000008u)
#define CSL_VENC_SYNCCTL_VPL_SHIFT (0x00000003u)
#define CSL_VENC_SYNCCTL_VPL_RESETVAL (0x00000000u)
/*----VPL Tokens----*/
#define CSL_VENC_SYNCCTL_VPL_ACTIVEH (0x00000000u)
#define CSL_VENC_SYNCCTL_VPL_ACTIVEL (0x00000001u)

#define CSL_VENC_SYNCCTL_HPL_MASK (0x00000004u)
#define CSL_VENC_SYNCCTL_HPL_SHIFT (0x00000002u)
#define CSL_VENC_SYNCCTL_HPL_RESETVAL (0x00000000u)
/*----HPL Tokens----*/
#define CSL_VENC_SYNCCTL_HPL_ACTIVEH (0x00000000u)
#define CSL_VENC_SYNCCTL_HPL_ACTIVEL (0x00000001u)

#define CSL_VENC_SYNCCTL_SYEV_MASK (0x00000002u)
#define CSL_VENC_SYNCCTL_SYEV_SHIFT (0x00000001u)
#define CSL_VENC_SYNCCTL_SYEV_RESETVAL (0x00000000u)
/*----SYEV Tokens----*/
#define CSL_VENC_SYNCCTL_SYEV_OFF (0x00000000u)
#define CSL_VENC_SYNCCTL_SYEV_ON (0x00000001u)

#define CSL_VENC_SYNCCTL_SYEH_MASK (0x00000001u)
#define CSL_VENC_SYNCCTL_SYEH_SHIFT (0x00000000u)
#define CSL_VENC_SYNCCTL_SYEH_RESETVAL (0x00000000u)
/*----SYEH Tokens----*/
#define CSL_VENC_SYNCCTL_SYEH_OFF (0x00000000u)
#define CSL_VENC_SYNCCTL_SYEH_ON (0x00000001u)

#define CSL_VENC_SYNCCTL_RESETVAL (0x00000000u)

/* HSPLS */


#define CSL_VENC_HSPLS_HSPLS_MASK (0x00001FFFu)
#define CSL_VENC_HSPLS_HSPLS_SHIFT (0x00000000u)
#define CSL_VENC_HSPLS_HSPLS_RESETVAL (0x00000000u)

#define CSL_VENC_HSPLS_RESETVAL (0x00000000u)

/* VSPLS */


#define CSL_VENC_VSPLS_VSPLS_MASK (0x00001FFFu)
#define CSL_VENC_VSPLS_VSPLS_SHIFT (0x00000000u)
#define CSL_VENC_VSPLS_VSPLS_RESETVAL (0x00000000u)

#define CSL_VENC_VSPLS_RESETVAL (0x00000000u)

/* HINT */


#define CSL_VENC_HINT_HINT_MASK (0x00001FFFu)
#define CSL_VENC_HINT_HINT_SHIFT (0x00000000u)
#define CSL_VENC_HINT_HINT_RESETVAL (0x00000000u)

#define CSL_VENC_HINT_RESETVAL (0x00000000u)

/* HSTART */


#define CSL_VENC_HSTART_HSTART_MASK (0x00001FFFu)
#define CSL_VENC_HSTART_HSTART_SHIFT (0x00000000u)
#define CSL_VENC_HSTART_HSTART_RESETVAL (0x00000000u)

#define CSL_VENC_HSTART_RESETVAL (0x00000000u)

/* HVALID */


#define CSL_VENC_HVALID_HVALID_MASK (0x00001FFFu)
#define CSL_VENC_HVALID_HVALID_SHIFT (0x00000000u)
#define CSL_VENC_HVALID_HVALID_RESETVAL (0x00000000u)

#define CSL_VENC_HVALID_RESETVAL (0x00000000u)

/* VINT */


#define CSL_VENC_VINT_VINT_MASK (0x00001FFFu)
#define CSL_VENC_VINT_VINT_SHIFT (0x00000000u)
#define CSL_VENC_VINT_VINT_RESETVAL (0x00000000u)

#define CSL_VENC_VINT_RESETVAL (0x00000000u)

/* VSTART */


#define CSL_VENC_VSTART_VSTART_MASK (0x00001FFFu)
#define CSL_VENC_VSTART_VSTART_SHIFT (0x00000000u)
#define CSL_VENC_VSTART_VSTART_RESETVAL (0x00000000u)

#define CSL_VENC_VSTART_RESETVAL (0x00000000u)

/* VVALID */


#define CSL_VENC_VVALID_VVALID_MASK (0x00001FFFu)
#define CSL_VENC_VVALID_VVALID_SHIFT (0x00000000u)
#define CSL_VENC_VVALID_VVALID_RESETVAL (0x00000000u)

#define CSL_VENC_VVALID_RESETVAL (0x00000000u)

/* HSDLY */


#define CSL_VENC_HSDLY_HSDLY_MASK (0x00001FFFu)
#define CSL_VENC_HSDLY_HSDLY_SHIFT (0x00000000u)
#define CSL_VENC_HSDLY_HSDLY_RESETVAL (0x00000000u)

#define CSL_VENC_HSDLY_RESETVAL (0x00000000u)

/* VSDLY */


#define CSL_VENC_VSDLY_VSDLY_MASK (0x00001FFFu)
#define CSL_VENC_VSDLY_VSDLY_SHIFT (0x00000000u)
#define CSL_VENC_VSDLY_VSDLY_RESETVAL (0x00000000u)

#define CSL_VENC_VSDLY_RESETVAL (0x00000000u)

/* YCCCTL */


#define CSL_VENC_YCCCTL_CHM_MASK (0x00000010u)
#define CSL_VENC_YCCCTL_CHM_SHIFT (0x00000004u)
#define CSL_VENC_YCCCTL_CHM_RESETVAL (0x00000000u)
/*----CHM Tokens----*/
#define CSL_VENC_YCCCTL_CHM_NOLATCH (0x00000000u)
#define CSL_VENC_YCCCTL_CHM_LATCH (0x00000001u)

#define CSL_VENC_YCCCTL_YCP_MASK (0x0000000Cu)
#define CSL_VENC_YCCCTL_YCP_SHIFT (0x00000002u)
#define CSL_VENC_YCCCTL_YCP_RESETVAL (0x00000000u)
/*----YCP Tokens----*/
#define CSL_VENC_YCCCTL_YCP_YCC16_CBCR (0x00000000u)
#define CSL_VENC_YCCCTL_YCP_YCC16_CRCB (0x00000001u)
#define CSL_VENC_YCCCTL_YCP_YCC8_CB_Y_CR_Y (0x00000000u)
#define CSL_VENC_YCCCTL_YCP_YCC8_Y_CR_Y_CB (0x00000001u)
#define CSL_VENC_YCCCTL_YCP_YCC8_CR_Y_CB_Y (0x00000002u)
#define CSL_VENC_YCCCTL_YCP_YCC8_Y_CB_Y_CR (0x00000003u)


#define CSL_VENC_YCCCTL_R656_MASK (0x00000001u)
#define CSL_VENC_YCCCTL_R656_SHIFT (0x00000000u)
#define CSL_VENC_YCCCTL_R656_RESETVAL (0x00000000u)
/*----R656 Tokens----*/
#define CSL_VENC_YCCCTL_R656_NORMAL (0x00000000u)
#define CSL_VENC_YCCCTL_R656_REC656 (0x00000001u)

#define CSL_VENC_YCCCTL_RESETVAL (0x00000000u)

/* RGBCTL */





#define CSL_VENC_RGBCTL_DFLTR_MASK (0x00000400u)
#define CSL_VENC_RGBCTL_DFLTR_SHIFT (0x0000000Au)
#define CSL_VENC_RGBCTL_DFLTR_RESETVAL (0x00000000u)
/*----DFLTR Tokens----*/
#define CSL_VENC_RGBCTL_DFLTR_ENCCLOCK_2 (0x00000000u)
#define CSL_VENC_RGBCTL_DFLTR_ENCCLOCK (0x00000001u)

#define CSL_VENC_RGBCTL_DFLTS_MASK (0x00000300u)
#define CSL_VENC_RGBCTL_DFLTS_SHIFT (0x00000008u)
#define CSL_VENC_RGBCTL_DFLTS_RESETVAL (0x00000000u)
/*----DFLTS Tokens----*/
#define CSL_VENC_RGBCTL_DFLTS_NOFILTER (0x00000000u)
#define CSL_VENC_RGBCTL_DFLTS_1_2_1 (0x00000001u)
#define CSL_VENC_RGBCTL_DFLTS_1_2_4_2_1 (0x00000002u)
#define CSL_VENC_RGBCTL_DFLTS_RESERVED (0x00000003u)





#define CSL_VENC_RGBCTL_RESETVAL (0x00000000u)

/* RGBCLP */


#define CSL_VENC_RGBCLP_UCLIP_MASK (0x0000FF00u)
#define CSL_VENC_RGBCLP_UCLIP_SHIFT (0x00000008u)
#define CSL_VENC_RGBCLP_UCLIP_RESETVAL (0x000000FFu)

#define CSL_VENC_RGBCLP_OFST_MASK (0x000000FFu)
#define CSL_VENC_RGBCLP_OFST_SHIFT (0x00000000u)
#define CSL_VENC_RGBCLP_OFST_RESETVAL (0x00000000u)

#define CSL_VENC_RGBCLP_RESETVAL (0x0000FF00u)

/* LINECTL */





#define CSL_VENC_LINECTL_VSTF_MASK (0x00000800u)
#define CSL_VENC_LINECTL_VSTF_SHIFT (0x0000000Bu)
#define CSL_VENC_LINECTL_VSTF_RESETVAL (0x00000000u)
/*----VSTF Tokens----*/
#define CSL_VENC_LINECTL_VSTF_NORMALMODE (0x00000000u)
#define CSL_VENC_LINECTL_VSTF_FIELDMODE (0x00000001u)

#define CSL_VENC_LINECTL_VCLID_MASK (0x00000700u)
#define CSL_VENC_LINECTL_VCLID_SHIFT (0x00000008u)
#define CSL_VENC_LINECTL_VCLID_RESETVAL (0x00000000u)

#define CSL_VENC_LINECTL_VCLRD_MASK (0x00000080u)
#define CSL_VENC_LINECTL_VCLRD_SHIFT (0x00000007u)
#define CSL_VENC_LINECTL_VCLRD_RESETVAL (0x00000000u)
/*----VCLRD Tokens----*/
#define CSL_VENC_LINECTL_VCLRD_RESET_0 (0x00000000u)
#define CSL_VENC_LINECTL_VCLRD_RESET_RAND (0x00000001u)

#define CSL_VENC_LINECTL_VCL56_MASK (0x00000040u)
#define CSL_VENC_LINECTL_VCL56_SHIFT (0x00000006u)
#define CSL_VENC_LINECTL_VCL56_RESETVAL (0x00000000u)
/*----VCL56 Tokens----*/
#define CSL_VENC_LINECTL_VCL56_NOCULLING (0x00000000u)
#define CSL_VENC_LINECTL_VCL56_5_6CULLING (0x00000001u)

#define CSL_VENC_LINECTL_HLDF_MASK (0x00000020u)
#define CSL_VENC_LINECTL_HLDF_SHIFT (0x00000005u)
#define CSL_VENC_LINECTL_HLDF_RESETVAL (0x00000000u)
/*----HLDF Tokens----*/
#define CSL_VENC_LINECTL_HLDF_NORMAL (0x00000000u)
#define CSL_VENC_LINECTL_HLDF_OUTPUTHOLD (0x00000001u)

#define CSL_VENC_LINECTL_HLDL_MASK (0x00000010u)
#define CSL_VENC_LINECTL_HLDL_SHIFT (0x00000004u)
#define CSL_VENC_LINECTL_HLDL_RESETVAL (0x00000000u)
/*----HLDL Tokens----*/
#define CSL_VENC_LINECTL_HLDL_NORMAL (0x00000000u)
#define CSL_VENC_LINECTL_HLDL_OUTPUTHOLD (0x00000001u)

#define CSL_VENC_LINECTL_LINID_MASK (0x00000008u)
#define CSL_VENC_LINECTL_LINID_SHIFT (0x00000003u)
#define CSL_VENC_LINECTL_LINID_RESETVAL (0x00000000u)
/*----LINID Tokens----*/
#define CSL_VENC_LINECTL_LINID_LINEID_0 (0x00000000u)
#define CSL_VENC_LINECTL_LINID_LINEID_1 (0x00000001u)

#define CSL_VENC_LINECTL_DCKCLP_MASK (0x00000004u)
#define CSL_VENC_LINECTL_DCKCLP_SHIFT (0x00000002u)
#define CSL_VENC_LINECTL_DCKCLP_RESETVAL (0x00000000u)
/*----DCKCLP Tokens----*/
#define CSL_VENC_LINECTL_DCKCLP_OFF (0x00000000u)
#define CSL_VENC_LINECTL_DCKCLP_ON (0x00000001u)

#define CSL_VENC_LINECTL_DCKCLI_MASK (0x00000002u)
#define CSL_VENC_LINECTL_DCKCLI_SHIFT (0x00000001u)
#define CSL_VENC_LINECTL_DCKCLI_RESETVAL (0x00000000u)
/*----DCKCLI Tokens----*/
#define CSL_VENC_LINECTL_DCKCLI_OFF (0x00000000u)
#define CSL_VENC_LINECTL_DCKCLI_ON (0x00000001u)

#define CSL_VENC_LINECTL_RGBCL_MASK (0x00000001u)
#define CSL_VENC_LINECTL_RGBCL_SHIFT (0x00000000u)
#define CSL_VENC_LINECTL_RGBCL_RESETVAL (0x00000000u)
/*----RGBCL Tokens----*/
#define CSL_VENC_LINECTL_RGBCL_OFF (0x00000000u)
#define CSL_VENC_LINECTL_RGBCL_ON (0x00000001u)

#define CSL_VENC_LINECTL_RESETVAL (0x00000000u)

/* CULLLINE */


#define CSL_VENC_CULLLINE_CLOF_MASK (0x0000F000u)
#define CSL_VENC_CULLLINE_CLOF_SHIFT (0x0000000Cu)
#define CSL_VENC_CULLLINE_CLOF_RESETVAL (0x00000000u)

#define CSL_VENC_CULLLINE_CLEF_MASK (0x00000F00u)
#define CSL_VENC_CULLLINE_CLEF_SHIFT (0x00000008u)
#define CSL_VENC_CULLLINE_CLEF_RESETVAL (0x00000000u)


#define CSL_VENC_CULLLINE_CULI_MASK (0x0000000Fu)
#define CSL_VENC_CULLLINE_CULI_SHIFT (0x00000000u)
#define CSL_VENC_CULLLINE_CULI_RESETVAL (0x00000000u)

#define CSL_VENC_CULLLINE_RESETVAL (0x00000000u)

/* LCDOUT */


#define CSL_VENC_LCDOUT_FIDS_MASK (0x00000100u)
#define CSL_VENC_LCDOUT_FIDS_SHIFT (0x00000008u)
#define CSL_VENC_LCDOUT_FIDS_RESETVAL (0x00000000u)
/*----FIDS Tokens----*/
#define CSL_VENC_LCDOUT_FIDS_LCD_OE (0x00000000u)
#define CSL_VENC_LCDOUT_FIDS_BRIGHT (0x00000001u)

#define CSL_VENC_LCDOUT_FIDP_MASK (0x00000080u)
#define CSL_VENC_LCDOUT_FIDP_SHIFT (0x00000007u)
#define CSL_VENC_LCDOUT_FIDP_RESETVAL (0x00000000u)
/*----FIDP Tokens----*/
#define CSL_VENC_LCDOUT_FIDP_NON_INVERSE (0x00000000u)
#define CSL_VENC_LCDOUT_FIDP_INVERSE (0x00000001u)

#define CSL_VENC_LCDOUT_PWMP_MASK (0x00000040u)
#define CSL_VENC_LCDOUT_PWMP_SHIFT (0x00000006u)
#define CSL_VENC_LCDOUT_PWMP_RESETVAL (0x00000000u)
/*----PWMP Tokens----*/
#define CSL_VENC_LCDOUT_PWMP_ACTIVEH (0x00000000u)
#define CSL_VENC_LCDOUT_PWMP_ACTIVEL (0x00000001u)

#define CSL_VENC_LCDOUT_PWME_MASK (0x00000020u)
#define CSL_VENC_LCDOUT_PWME_SHIFT (0x00000005u)
#define CSL_VENC_LCDOUT_PWME_RESETVAL (0x00000000u)
/*----PWME Tokens----*/
#define CSL_VENC_LCDOUT_PWME_OFF (0x00000000u)
#define CSL_VENC_LCDOUT_PWME_ON (0x00000001u)

#define CSL_VENC_LCDOUT_ACE_MASK (0x00000010u)
#define CSL_VENC_LCDOUT_ACE_SHIFT (0x00000004u)
#define CSL_VENC_LCDOUT_ACE_RESETVAL (0x00000000u)
/*----ACE Tokens----*/
#define CSL_VENC_LCDOUT_ACE_OFF (0x00000000u)
#define CSL_VENC_LCDOUT_ACE_ON (0x00000001u)

#define CSL_VENC_LCDOUT_BRP_MASK (0x00000008u)
#define CSL_VENC_LCDOUT_BRP_SHIFT (0x00000003u)
#define CSL_VENC_LCDOUT_BRP_RESETVAL (0x00000000u)
/*----BRP Tokens----*/
#define CSL_VENC_LCDOUT_BRP_NON_INVERSE (0x00000000u)
#define CSL_VENC_LCDOUT_BRP_INVERSE (0x00000001u)

#define CSL_VENC_LCDOUT_BRE_MASK (0x00000004u)
#define CSL_VENC_LCDOUT_BRE_SHIFT (0x00000002u)
#define CSL_VENC_LCDOUT_BRE_RESETVAL (0x00000000u)
/*----BRE Tokens----*/
#define CSL_VENC_LCDOUT_BRE_OFF (0x00000000u)
#define CSL_VENC_LCDOUT_BRE_ON (0x00000001u)

#define CSL_VENC_LCDOUT_OEP_MASK (0x00000002u)
#define CSL_VENC_LCDOUT_OEP_SHIFT (0x00000001u)
#define CSL_VENC_LCDOUT_OEP_RESETVAL (0x00000000u)
/*----OEP Tokens----*/
#define CSL_VENC_LCDOUT_OEP_ACTIVEH (0x00000000u)
#define CSL_VENC_LCDOUT_OEP_ACTIVEL (0x00000001u)

#define CSL_VENC_LCDOUT_OEE_MASK (0x00000001u)
#define CSL_VENC_LCDOUT_OEE_SHIFT (0x00000000u)
#define CSL_VENC_LCDOUT_OEE_RESETVAL (0x00000000u)
/*----OEE Tokens----*/
#define CSL_VENC_LCDOUT_OEE_OFF (0x00000000u)
#define CSL_VENC_LCDOUT_OEE_ON (0x00000001u)

#define CSL_VENC_LCDOUT_RESETVAL (0x00000000u)

/* BRTS */


#define CSL_VENC_BRTS_BRTS_MASK (0x00001FFFu)
#define CSL_VENC_BRTS_BRTS_SHIFT (0x00000000u)
#define CSL_VENC_BRTS_BRTS_RESETVAL (0x00000000u)

#define CSL_VENC_BRTS_RESETVAL (0x00000000u)

/* BRTW */


#define CSL_VENC_BRTW_BRTW_MASK (0x00001FFFu)
#define CSL_VENC_BRTW_BRTW_SHIFT (0x00000000u)
#define CSL_VENC_BRTW_BRTW_RESETVAL (0x00000000u)

#define CSL_VENC_BRTW_RESETVAL (0x00000000u)

/* ACCTL */


#define CSL_VENC_ACCTL_ACTF_MASK (0x0000E000u)
#define CSL_VENC_ACCTL_ACTF_SHIFT (0x0000000Du)
#define CSL_VENC_ACCTL_ACTF_RESETVAL (0x00000000u)

#define CSL_VENC_ACCTL_ACTH_MASK (0x00001FFFu)
#define CSL_VENC_ACCTL_ACTH_SHIFT (0x00000000u)
#define CSL_VENC_ACCTL_ACTH_RESETVAL (0x00000000u)

#define CSL_VENC_ACCTL_RESETVAL (0x00000000u)

/* PWMP */


#define CSL_VENC_PWMP_PWMP_MASK (0x00001FFFu)
#define CSL_VENC_PWMP_PWMP_SHIFT (0x00000000u)
#define CSL_VENC_PWMP_PWMP_RESETVAL (0x00000000u)

#define CSL_VENC_PWMP_RESETVAL (0x00000000u)

/* PWMW */


#define CSL_VENC_PWMW_PWMW_MASK (0x00001FFFu)
#define CSL_VENC_PWMW_PWMW_SHIFT (0x00000000u)
#define CSL_VENC_PWMW_PWMW_RESETVAL (0x00000000u)

#define CSL_VENC_PWMW_RESETVAL (0x00000000u)

/* DCLKCTL */


#define CSL_VENC_DCLKCTL_DCKIM_MASK (0x00008000u)
#define CSL_VENC_DCLKCTL_DCKIM_SHIFT (0x0000000Fu)
#define CSL_VENC_DCLKCTL_DCKIM_RESETVAL (0x00000000u)
/*----DCKIM Tokens----*/
#define CSL_VENC_DCLKCTL_DCKIM_OFF (0x00000000u)
#define CSL_VENC_DCLKCTL_DCKIM_ON (0x00000001u)


#define CSL_VENC_DCLKCTL_DOFST_MASK (0x00003000u)
#define CSL_VENC_DCLKCTL_DOFST_SHIFT (0x0000000Cu)
#define CSL_VENC_DCLKCTL_DOFST_RESETVAL (0x00000000u)
/*----DOFST Tokens----*/
#define CSL_VENC_DCLKCTL_DOFST_ZERO (0x00000000u)
#define CSL_VENC_DCLKCTL_DOFST_MINUS_HALF (0x00000001u)
#define CSL_VENC_DCLKCTL_DOFST_PLUS_HALF (0x00000002u)
#define CSL_VENC_DCLKCTL_DOFST_PLUS_ONE (0x00000003u)

#define CSL_VENC_DCLKCTL_DCKEC_MASK (0x00000800u)
#define CSL_VENC_DCLKCTL_DCKEC_SHIFT (0x0000000Bu)
#define CSL_VENC_DCLKCTL_DCKEC_RESETVAL (0x00000000u)
/*----DCKEC Tokens----*/
#define CSL_VENC_DCLKCTL_DCKEC_LEVEL (0x00000000u)
#define CSL_VENC_DCLKCTL_DCKEC_ENABLE (0x00000001u)

#define CSL_VENC_DCLKCTL_DCKME_MASK (0x00000400u)
#define CSL_VENC_DCLKCTL_DCKME_SHIFT (0x0000000Au)
#define CSL_VENC_DCLKCTL_DCKME_RESETVAL (0x00000000u)
/*----DCKME Tokens----*/
#define CSL_VENC_DCLKCTL_DCKME_OFF (0x00000000u)
#define CSL_VENC_DCLKCTL_DCKME_ON (0x00000001u)

#define CSL_VENC_DCLKCTL_DCKOH_MASK (0x00000200u)
#define CSL_VENC_DCLKCTL_DCKOH_SHIFT (0x00000009u)
#define CSL_VENC_DCLKCTL_DCKOH_RESETVAL (0x00000000u)
/*----DCKOH Tokens----*/
#define CSL_VENC_DCLKCTL_DCKOH_DIV_BY_1 (0x00000000u)
#define CSL_VENC_DCLKCTL_DCKOH_DIV_BY_2 (0x00000001u)

#define CSL_VENC_DCLKCTL_DCKIH_MASK (0x00000100u)
#define CSL_VENC_DCLKCTL_DCKIH_SHIFT (0x00000008u)
#define CSL_VENC_DCLKCTL_DCKIH_RESETVAL (0x00000000u)
/*----DCKIH Tokens----*/
#define CSL_VENC_DCLKCTL_DCKIH_DIV_BY_1 (0x00000000u)
#define CSL_VENC_DCLKCTL_DCKIH_DIV_BY_2 (0x00000001u)


#define CSL_VENC_DCLKCTL_DCKPW_MASK (0x0000003Fu)
#define CSL_VENC_DCLKCTL_DCKPW_SHIFT (0x00000000u)
#define CSL_VENC_DCLKCTL_DCKPW_RESETVAL (0x00000000u)

#define CSL_VENC_DCLKCTL_RESETVAL (0x00000000u)

/* DCLKPTN0 */


#define CSL_VENC_DCLKPTN0_DCPTN0_MASK (0x0000FFFFu)
#define CSL_VENC_DCLKPTN0_DCPTN0_SHIFT (0x00000000u)
#define CSL_VENC_DCLKPTN0_DCPTN0_RESETVAL (0x00000000u)

#define CSL_VENC_DCLKPTN0_RESETVAL (0x00000000u)

/* DCLKPTN1 */


#define CSL_VENC_DCLKPTN1_DCPTN1_MASK (0x0000FFFFu)
#define CSL_VENC_DCLKPTN1_DCPTN1_SHIFT (0x00000000u)
#define CSL_VENC_DCLKPTN1_DCPTN1_RESETVAL (0x00000000u)

#define CSL_VENC_DCLKPTN1_RESETVAL (0x00000000u)

/* DCLKPTN2 */


#define CSL_VENC_DCLKPTN2_DCPTN2_MASK (0x0000FFFFu)
#define CSL_VENC_DCLKPTN2_DCPTN2_SHIFT (0x00000000u)
#define CSL_VENC_DCLKPTN2_DCPTN2_RESETVAL (0x00000000u)

#define CSL_VENC_DCLKPTN2_RESETVAL (0x00000000u)

/* DCLKPTN3 */


#define CSL_VENC_DCLKPTN3_DCPTN3_MASK (0x0000FFFFu)
#define CSL_VENC_DCLKPTN3_DCPTN3_SHIFT (0x00000000u)
#define CSL_VENC_DCLKPTN3_DCPTN3_RESETVAL (0x00000000u)

#define CSL_VENC_DCLKPTN3_RESETVAL (0x00000000u)

/* DCLKPTN0A */


#define CSL_VENC_DCLKPTN0A_DCPTN0A_MASK (0x0000FFFFu)
#define CSL_VENC_DCLKPTN0A_DCPTN0A_SHIFT (0x00000000u)
#define CSL_VENC_DCLKPTN0A_DCPTN0A_RESETVAL (0x00000000u)

#define CSL_VENC_DCLKPTN0A_RESETVAL (0x00000000u)

/* DCLKPTN1A */


#define CSL_VENC_DCLKPTN1A_DCPTN1A_MASK (0x0000FFFFu)
#define CSL_VENC_DCLKPTN1A_DCPTN1A_SHIFT (0x00000000u)
#define CSL_VENC_DCLKPTN1A_DCPTN1A_RESETVAL (0x00000000u)

#define CSL_VENC_DCLKPTN1A_RESETVAL (0x00000000u)

/* DCLKPTN2A */


#define CSL_VENC_DCLKPTN2A_DCPTN2A_MASK (0x0000FFFFu)
#define CSL_VENC_DCLKPTN2A_DCPTN2A_SHIFT (0x00000000u)
#define CSL_VENC_DCLKPTN2A_DCPTN2A_RESETVAL (0x00000000u)

#define CSL_VENC_DCLKPTN2A_RESETVAL (0x00000000u)

/* DCLKPTN3A */


#define CSL_VENC_DCLKPTN3A_DCPTN3A_MASK (0x0000FFFFu)
#define CSL_VENC_DCLKPTN3A_DCPTN3A_SHIFT (0x00000000u)
#define CSL_VENC_DCLKPTN3A_DCPTN3A_RESETVAL (0x00000000u)

#define CSL_VENC_DCLKPTN3A_RESETVAL (0x00000000u)

/* DCLKHS */


#define CSL_VENC_DCLKHS_DCHS_MASK (0x00001FFFu)
#define CSL_VENC_DCLKHS_DCHS_SHIFT (0x00000000u)
#define CSL_VENC_DCLKHS_DCHS_RESETVAL (0x00000000u)

#define CSL_VENC_DCLKHS_RESETVAL (0x00000000u)

/* DCLKHSA */


#define CSL_VENC_DCLKHSA_DCHS_MASK (0x00001FFFu)
#define CSL_VENC_DCLKHSA_DCHS_SHIFT (0x00000000u)
#define CSL_VENC_DCLKHSA_DCHS_RESETVAL (0x00000000u)

#define CSL_VENC_DCLKHSA_RESETVAL (0x00000000u)

/* DCLKHR */


#define CSL_VENC_DCLKHR_DCHR_MASK (0x00001FFFu)
#define CSL_VENC_DCLKHR_DCHR_SHIFT (0x00000000u)
#define CSL_VENC_DCLKHR_DCHR_RESETVAL (0x00000000u)

#define CSL_VENC_DCLKHR_RESETVAL (0x00000000u)

/* DCLKVS */


#define CSL_VENC_DCLKVS_DCVS_MASK (0x00001FFFu)
#define CSL_VENC_DCLKVS_DCVS_SHIFT (0x00000000u)
#define CSL_VENC_DCLKVS_DCVS_RESETVAL (0x00000000u)

#define CSL_VENC_DCLKVS_RESETVAL (0x00000000u)

/* DCLKVR */


#define CSL_VENC_DCLKVR_DCVR_MASK (0x00001FFFu)
#define CSL_VENC_DCLKVR_DCVR_SHIFT (0x00000000u)
#define CSL_VENC_DCLKVR_DCVR_RESETVAL (0x00000000u)

#define CSL_VENC_DCLKVR_RESETVAL (0x00000000u)

/* CAPCTL */


#define CSL_VENC_CAPCTL_CADF_MASK (0x00007F00u)
#define CSL_VENC_CAPCTL_CADF_SHIFT (0x00000008u)
#define CSL_VENC_CAPCTL_CADF_RESETVAL (0x00000000u)


#define CSL_VENC_CAPCTL_CAPF_MASK (0x00000003u)
#define CSL_VENC_CAPCTL_CAPF_SHIFT (0x00000000u)
#define CSL_VENC_CAPCTL_CAPF_RESETVAL (0x00000000u)
/*----CAPF Tokens----*/
#define CSL_VENC_CAPCTL_CAPF_NODATA (0x00000000u)
#define CSL_VENC_CAPCTL_CAPF_ODD (0x00000001u)
#define CSL_VENC_CAPCTL_CAPF_EVEN (0x00000002u)
#define CSL_VENC_CAPCTL_CAPF_DUAL (0x00000003u)

#define CSL_VENC_CAPCTL_RESETVAL (0x00000000u)

/* CAPDO */


#define CSL_VENC_CAPDO_CADO0_MASK (0x00007F00u)
#define CSL_VENC_CAPDO_CADO0_SHIFT (0x00000008u)
#define CSL_VENC_CAPDO_CADO0_RESETVAL (0x00000000u)


#define CSL_VENC_CAPDO_CADO1_MASK (0x0000007Fu)
#define CSL_VENC_CAPDO_CADO1_SHIFT (0x00000000u)
#define CSL_VENC_CAPDO_CADO1_RESETVAL (0x00000000u)

#define CSL_VENC_CAPDO_RESETVAL (0x00000000u)

/* CAPDE */


#define CSL_VENC_CAPDE_CADE0_MASK (0x00007F00u)
#define CSL_VENC_CAPDE_CADE0_SHIFT (0x00000008u)
#define CSL_VENC_CAPDE_CADE0_RESETVAL (0x00000000u)


#define CSL_VENC_CAPDE_CADE1_MASK (0x0000007Fu)
#define CSL_VENC_CAPDE_CADE1_SHIFT (0x00000000u)
#define CSL_VENC_CAPDE_CADE1_RESETVAL (0x00000000u)

#define CSL_VENC_CAPDE_RESETVAL (0x00000000u)

/* ATR0 */


#define CSL_VENC_ATR0_ATR0_MASK (0x000000FFu)
#define CSL_VENC_ATR0_ATR0_SHIFT (0x00000000u)
#define CSL_VENC_ATR0_ATR0_RESETVAL (0x00000000u)

#define CSL_VENC_ATR0_RESETVAL (0x00000000u)

/* ATR1 */


#define CSL_VENC_ATR1_ATR1_MASK (0x000000FFu)
#define CSL_VENC_ATR1_ATR1_SHIFT (0x00000000u)
#define CSL_VENC_ATR1_ATR1_RESETVAL (0x00000000u)

#define CSL_VENC_ATR1_RESETVAL (0x00000000u)

/* ATR2 */


#define CSL_VENC_ATR2_ATR2_MASK (0x000000FFu)
#define CSL_VENC_ATR2_ATR2_SHIFT (0x00000000u)
#define CSL_VENC_ATR2_ATR2_RESETVAL (0x00000000u)

#define CSL_VENC_ATR2_RESETVAL (0x00000000u)

/* VSTAT */


#define CSL_VENC_VSTAT_CAEST_MASK (0x00000200u)
#define CSL_VENC_VSTAT_CAEST_SHIFT (0x00000009u)
#define CSL_VENC_VSTAT_CAEST_RESETVAL (0x00000000u)

#define CSL_VENC_VSTAT_CAOST_MASK (0x00000100u)
#define CSL_VENC_VSTAT_CAOST_SHIFT (0x00000008u)
#define CSL_VENC_VSTAT_CAOST_RESETVAL (0x00000000u)


#define CSL_VENC_VSTAT_FIDST_MASK (0x00000010u)
#define CSL_VENC_VSTAT_FIDST_SHIFT (0x00000004u)
#define CSL_VENC_VSTAT_FIDST_RESETVAL (0x00000000u)


#define CSL_VENC_VSTAT_UDBAL_MASK (0x00000002u)
#define CSL_VENC_VSTAT_UDBAL_SHIFT (0x00000001u)
#define CSL_VENC_VSTAT_UDBAL_RESETVAL (0x00000000u)

#define CSL_VENC_VSTAT_UDFUL_MASK (0x00000001u)
#define CSL_VENC_VSTAT_UDFUL_SHIFT (0x00000000u)
#define CSL_VENC_VSTAT_UDFUL_RESETVAL (0x00000000u)

#define CSL_VENC_VSTAT_RESETVAL (0x00000000u)

/* DACTST */


#define CSL_VENC_DACTST_DAPD3_MASK (0x00008000u)
#define CSL_VENC_DACTST_DAPD3_SHIFT (0x0000000Fu)
#define CSL_VENC_DACTST_DAPD3_RESETVAL (0x00000001u)
/*----DAPD3 Tokens----*/
#define CSL_VENC_DACTST_DAPD3_NORMAL (0x00000000u)
#define CSL_VENC_DACTST_DAPD3_PWRDN (0x00000001u)

#define CSL_VENC_DACTST_DAPD2_MASK (0x00004000u)
#define CSL_VENC_DACTST_DAPD2_SHIFT (0x0000000Eu)
#define CSL_VENC_DACTST_DAPD2_RESETVAL (0x00000001u)
/*----DAPD2 Tokens----*/
#define CSL_VENC_DACTST_DAPD2_NORMAL (0x00000000u)
#define CSL_VENC_DACTST_DAPD2_PWRDN (0x00000001u)

#define CSL_VENC_DACTST_DAPD1_MASK (0x00002000u)
#define CSL_VENC_DACTST_DAPD1_SHIFT (0x0000000Du)
#define CSL_VENC_DACTST_DAPD1_RESETVAL (0x00000001u)
/*----DAPD1 Tokens----*/
#define CSL_VENC_DACTST_DAPD1_NORMAL (0x00000000u)
#define CSL_VENC_DACTST_DAPD1_PWRDN (0x00000001u)

#define CSL_VENC_DACTST_DAPD0_MASK (0x00001000u)
#define CSL_VENC_DACTST_DAPD0_SHIFT (0x0000000Cu)
#define CSL_VENC_DACTST_DAPD0_RESETVAL (0x00000001u)
/*----DAPD0 Tokens----*/
#define CSL_VENC_DACTST_DAPD0_NORMAL (0x00000000u)
#define CSL_VENC_DACTST_DAPD0_PWRDN (0x00000001u)



#define CSL_VENC_DACTST_RESETVAL (0x0000F000u)

/* YCOLVL */


#define CSL_VENC_YCOLVL_YLVL_MASK (0x0000FF00u)
#define CSL_VENC_YCOLVL_YLVL_SHIFT (0x00000008u)
#define CSL_VENC_YCOLVL_YLVL_RESETVAL (0x00000000u)

#define CSL_VENC_YCOLVL_CLVL_MASK (0x000000FFu)
#define CSL_VENC_YCOLVL_CLVL_SHIFT (0x00000000u)
#define CSL_VENC_YCOLVL_CLVL_RESETVAL (0x00000000u)

#define CSL_VENC_YCOLVL_RESETVAL (0x00000000u)

/* SCPROG */


#define CSL_VENC_SCPROG_SCSD_MASK (0x000003FFu)
#define CSL_VENC_SCPROG_SCSD_SHIFT (0x00000000u)
#define CSL_VENC_SCPROG_SCSD_RESETVAL (0x0000017Au)

#define CSL_VENC_SCPROG_RESETVAL (0x0000017Au)

/* RSV1 */

#define CSL_VENC_RSV1_RSV1_MASK (0xFFFFFFFFu)
#define CSL_VENC_RSV1_RSV1_SHIFT (0x00000000u)
#define CSL_VENC_RSV1_RSV1_RESETVAL (0x00000000u)

#define CSL_VENC_RSV1_RESETVAL (0x00000000u)

/* RSV2 */

#define CSL_VENC_RSV2_RSV2_MASK (0xFFFFFFFFu)
#define CSL_VENC_RSV2_RSV2_SHIFT (0x00000000u)
#define CSL_VENC_RSV2_RSV2_RESETVAL (0x00000000u)

#define CSL_VENC_RSV2_RESETVAL (0x00000000u)

/* RSV3 */

#define CSL_VENC_RSV3_RSV3_MASK (0xFFFFFFFFu)
#define CSL_VENC_RSV3_RSV3_SHIFT (0x00000000u)
#define CSL_VENC_RSV3_RSV3_RESETVAL (0x00000000u)

#define CSL_VENC_RSV3_RESETVAL (0x00000000u)

/* CVBS */


#define CSL_VENC_CVBS_YCDLY_MASK (0x00007000u)
#define CSL_VENC_CVBS_YCDLY_SHIFT (0x0000000Cu)
#define CSL_VENC_CVBS_YCDLY_RESETVAL (0x00000000u)
/*----YCDLY Tokens----*/
#define CSL_VENC_CVBS_YCDLY_0 (0x00000000u)
#define CSL_VENC_CVBS_YCDLY_PLUS_1 (0x00000001u)
#define CSL_VENC_CVBS_YCDLY_PLUS_2 (0x00000002u)
#define CSL_VENC_CVBS_YCDLY_PLUS_3 (0x00000003u)
#define CSL_VENC_CVBS_YCDLY_MINUS_4 (0x00000004u)
#define CSL_VENC_CVBS_YCDLY_MINUS_3 (0x00000005u)
#define CSL_VENC_CVBS_YCDLY_MINUS_2 (0x00000006u)
#define CSL_VENC_CVBS_YCDLY_MINUS_1 (0x00000007u)


#define CSL_VENC_CVBS_CVLVL_MASK (0x00000020u)
#define CSL_VENC_CVBS_CVLVL_SHIFT (0x00000005u)
#define CSL_VENC_CVBS_CVLVL_RESETVAL (0x00000000u)
/*----CVLVL Tokens----*/
#define CSL_VENC_CVBS_CVLVL_286MV_714MV (0x00000000u)
#define CSL_VENC_CVBS_CVLVL_300MV_700MV (0x00000001u)

#define CSL_VENC_CVBS_CSTUP_MASK (0x00000010u)
#define CSL_VENC_CVBS_CSTUP_SHIFT (0x00000004u)
#define CSL_VENC_CVBS_CSTUP_RESETVAL (0x00000000u)
/*----CSTUP Tokens----*/
#define CSL_VENC_CVBS_CSTUP_0_PCT (0x00000000u)
#define CSL_VENC_CVBS_CSTUP_7P5_PCT (0x00000001u)

#define CSL_VENC_CVBS_CBLS_MASK (0x00000008u)
#define CSL_VENC_CVBS_CBLS_SHIFT (0x00000003u)
#define CSL_VENC_CVBS_CBLS_RESETVAL (0x00000000u)
/*----CBLS Tokens----*/
#define CSL_VENC_CVBS_CBLS_ENABLE (0x00000000u)
#define CSL_VENC_CVBS_CBLS_DISABLE (0x00000001u)

#define CSL_VENC_CVBS_CRCUT_MASK (0x00000004u)
#define CSL_VENC_CVBS_CRCUT_SHIFT (0x00000002u)
#define CSL_VENC_CVBS_CRCUT_RESETVAL (0x00000000u)
/*----CRCUT Tokens----*/
#define CSL_VENC_CVBS_CRCUT_1P5MHZ_CUT0FF (0x00000000u)
#define CSL_VENC_CVBS_CRCUT_3MHZ_CUTOFF (0x00000001u)

#define CSL_VENC_CVBS_CBBLD_MASK (0x00000002u)
#define CSL_VENC_CVBS_CBBLD_SHIFT (0x00000001u)
#define CSL_VENC_CVBS_CBBLD_RESETVAL (0x00000000u)
/*----CBBLD Tokens----*/
#define CSL_VENC_CVBS_CBBLD_140US (0x00000000u)
#define CSL_VENC_CVBS_CBBLD_300US (0x00000001u)

#define CSL_VENC_CVBS_CSBLD_MASK (0x00000001u)
#define CSL_VENC_CVBS_CSBLD_SHIFT (0x00000000u)
#define CSL_VENC_CVBS_CSBLD_RESETVAL (0x00000000u)
/*----CSBLD Tokens----*/
#define CSL_VENC_CVBS_CSBLD_140US (0x00000000u)
#define CSL_VENC_CVBS_CSBLD_200US (0x00000001u)

#define CSL_VENC_CVBS_RESETVAL (0x00000000u)

/* CMPNT */


#define CSL_VENC_CMPNT_MRGB_MASK (0x00008000u)
#define CSL_VENC_CMPNT_MRGB_SHIFT (0x0000000Fu)
#define CSL_VENC_CMPNT_MRGB_RESETVAL (0x00000000u)
/*----MRGB Tokens----*/
#define CSL_VENC_CMPNT_MRGB_YPBPR (0x00000000u)
#define CSL_VENC_CMPNT_MRGB_RGB (0x00000001u)

#define CSL_VENC_CMPNT_MYDLY_MASK (0x00007000u)
#define CSL_VENC_CMPNT_MYDLY_SHIFT (0x0000000Cu)
#define CSL_VENC_CMPNT_MYDLY_RESETVAL (0x00000000u)
/*----MYDLY Tokens----*/
#define CSL_VENC_CMPNT_MYDLY_0 (0x00000000u)
#define CSL_VENC_CMPNT_MYDLY_PLUS_1 (0x00000001u)
#define CSL_VENC_CMPNT_MYDLY_PLUS_2 (0x00000002u)
#define CSL_VENC_CMPNT_MYDLY_PLUS_3 (0x00000003u)
#define CSL_VENC_CMPNT_MYDLY_MINUS_4 (0x00000004u)
#define CSL_VENC_CMPNT_MYDLY_MINUS_3 (0x00000005u)
#define CSL_VENC_CMPNT_MYDLY_MINUS_2 (0x00000006u)
#define CSL_VENC_CMPNT_MYDLY_MINUS_1 (0x00000007u)


#define CSL_VENC_CMPNT_MSYR_MASK (0x00000400u)
#define CSL_VENC_CMPNT_MSYR_SHIFT (0x0000000Au)
#define CSL_VENC_CMPNT_MSYR_RESETVAL (0x00000000u)
/*----MSYR Tokens----*/
#define CSL_VENC_CMPNT_MSYR_NOSYNC (0x00000000u)
#define CSL_VENC_CMPNT_MSYR_SYNCON (0x00000001u)

#define CSL_VENC_CMPNT_MSYB_MASK (0x00000200u)
#define CSL_VENC_CMPNT_MSYB_SHIFT (0x00000009u)
#define CSL_VENC_CMPNT_MSYB_RESETVAL (0x00000000u)
/*----MSYB Tokens----*/
#define CSL_VENC_CMPNT_MSYB_NOSYNC (0x00000000u)
#define CSL_VENC_CMPNT_MSYB_SYNCON (0x00000001u)

#define CSL_VENC_CMPNT_MSYG_MASK (0x00000100u)
#define CSL_VENC_CMPNT_MSYG_SHIFT (0x00000008u)
#define CSL_VENC_CMPNT_MSYG_RESETVAL (0x00000001u)
/*----MSYG Tokens----*/
#define CSL_VENC_CMPNT_MSYG_NOSYNC (0x00000000u)
#define CSL_VENC_CMPNT_MSYG_SYNCON (0x00000001u)

#define CSL_VENC_CMPNT_MCLVL_MASK (0x000000C0u)
#define CSL_VENC_CMPNT_MCLVL_SHIFT (0x00000006u)
#define CSL_VENC_CMPNT_MCLVL_RESETVAL (0x00000000u)
/*----MCLVL Tokens----*/
#define CSL_VENC_CMPNT_MCLVL_350MV_SMPTEN10 (0x00000000u)
#define CSL_VENC_CMPNT_MCLVL_467MV_BETACAM (0x00000001u)
#define CSL_VENC_CMPNT_MCLVL_324MV_MII (0x00000002u)
#define CSL_VENC_CMPNT_MCLVL_RESERVED (0x00000003u)

#define CSL_VENC_CMPNT_MYLVL_MASK (0x00000020u)
#define CSL_VENC_CMPNT_MYLVL_SHIFT (0x00000005u)
#define CSL_VENC_CMPNT_MYLVL_RESETVAL (0x00000000u)
/*----MYLVL Tokens----*/
#define CSL_VENC_CMPNT_MYLVL_286MV_714MV (0x00000000u)
#define CSL_VENC_CMPNT_MYLVL_300MV_700MV (0x00000001u)

#define CSL_VENC_CMPNT_MSTUP_MASK (0x00000010u)
#define CSL_VENC_CMPNT_MSTUP_SHIFT (0x00000004u)
#define CSL_VENC_CMPNT_MSTUP_RESETVAL (0x00000000u)
/*----MSTUP Tokens----*/
#define CSL_VENC_CMPNT_MSTUP_0_PCT (0x00000000u)
#define CSL_VENC_CMPNT_MSTUP_7P5_PCT (0x00000001u)

#define CSL_VENC_CMPNT_MBLS_MASK (0x00000008u)
#define CSL_VENC_CMPNT_MBLS_SHIFT (0x00000003u)
#define CSL_VENC_CMPNT_MBLS_RESETVAL (0x00000000u)
/*----MBLS Tokens----*/
#define CSL_VENC_CMPNT_MBLS_ENABLE (0x00000000u)
#define CSL_VENC_CMPNT_MBLS_DISABLE (0x00000001u)


#define CSL_VENC_CMPNT_MBBLD_MASK (0x00000002u)
#define CSL_VENC_CMPNT_MBBLD_SHIFT (0x00000001u)
#define CSL_VENC_CMPNT_MBBLD_RESETVAL (0x00000000u)
/*----MBBLD Tokens----*/
#define CSL_VENC_CMPNT_MBBLD_140US (0x00000000u)
#define CSL_VENC_CMPNT_MBBLD_300US (0x00000001u)
#define CSL_VENC_CMPNT_MBBLD_70US (0x00000000u)
#define CSL_VENC_CMPNT_MBBLD_150US (0x00000001u)

#define CSL_VENC_CMPNT_MSBLD_MASK (0x00000001u)
#define CSL_VENC_CMPNT_MSBLD_SHIFT (0x00000000u)
#define CSL_VENC_CMPNT_MSBLD_RESETVAL (0x00000000u)
/*----MSBLD Tokens----*/
#define CSL_VENC_CMPNT_MSBLD_140US (0x00000000u)
#define CSL_VENC_CMPNT_MSBLD_200US (0x00000001u)
#define CSL_VENC_CMPNT_MSBLD_70US (0x00000000u)
#define CSL_VENC_CMPNT_MSBLD_100US (0x00000001u)

#define CSL_VENC_CMPNT_RESETVAL (0x00000100u)

/* ETMG0 */


#define CSL_VENC_ETMG0_CEPW_MASK (0x00000F00u)
#define CSL_VENC_ETMG0_CEPW_SHIFT (0x00000008u)
#define CSL_VENC_ETMG0_CEPW_RESETVAL (0x00000000u)

#define CSL_VENC_ETMG0_CFSW_MASK (0x000000F0u)
#define CSL_VENC_ETMG0_CFSW_SHIFT (0x00000004u)
#define CSL_VENC_ETMG0_CFSW_RESETVAL (0x00000000u)

#define CSL_VENC_ETMG0_CLSW_MASK (0x0000000Fu)
#define CSL_VENC_ETMG0_CLSW_SHIFT (0x00000000u)
#define CSL_VENC_ETMG0_CLSW_RESETVAL (0x00000000u)

#define CSL_VENC_ETMG0_RESETVAL (0x00000000u)

/* ETMG1 */


#define CSL_VENC_ETMG1_CBSE_MASK (0x0000F000u)
#define CSL_VENC_ETMG1_CBSE_SHIFT (0x0000000Cu)
#define CSL_VENC_ETMG1_CBSE_RESETVAL (0x00000000u)

#define CSL_VENC_ETMG1_CBST_MASK (0x00000F00u)
#define CSL_VENC_ETMG1_CBST_SHIFT (0x00000008u)
#define CSL_VENC_ETMG1_CBST_RESETVAL (0x00000000u)

#define CSL_VENC_ETMG1_CFPW_MASK (0x000000F0u)
#define CSL_VENC_ETMG1_CFPW_SHIFT (0x00000004u)
#define CSL_VENC_ETMG1_CFPW_RESETVAL (0x00000000u)

#define CSL_VENC_ETMG1_CLBI_MASK (0x0000000Fu)
#define CSL_VENC_ETMG1_CLBI_SHIFT (0x00000000u)
#define CSL_VENC_ETMG1_CLBI_RESETVAL (0x00000000u)

#define CSL_VENC_ETMG1_RESETVAL (0x00000000u)

/* ETMG2 */


#define CSL_VENC_ETMG2_MEPW_MASK (0x00000F00u)
#define CSL_VENC_ETMG2_MEPW_SHIFT (0x00000008u)
#define CSL_VENC_ETMG2_MEPW_RESETVAL (0x00000000u)

#define CSL_VENC_ETMG2_MFSW_MASK (0x000000F0u)
#define CSL_VENC_ETMG2_MFSW_SHIFT (0x00000004u)
#define CSL_VENC_ETMG2_MFSW_RESETVAL (0x00000000u)

#define CSL_VENC_ETMG2_MLSW_MASK (0x0000000Fu)
#define CSL_VENC_ETMG2_MLSW_SHIFT (0x00000000u)
#define CSL_VENC_ETMG2_MLSW_RESETVAL (0x00000000u)

#define CSL_VENC_ETMG2_RESETVAL (0x00000000u)

/* ETMG3 */


#define CSL_VENC_ETMG3_CFPW_MASK (0x000000F0u)
#define CSL_VENC_ETMG3_CFPW_SHIFT (0x00000004u)
#define CSL_VENC_ETMG3_CFPW_RESETVAL (0x00000000u)

#define CSL_VENC_ETMG3_CLBI_MASK (0x0000000Fu)
#define CSL_VENC_ETMG3_CLBI_SHIFT (0x00000000u)
#define CSL_VENC_ETMG3_CLBI_RESETVAL (0x00000000u)

#define CSL_VENC_ETMG3_RESETVAL (0x00000000u)

/* DACSEL */


#define CSL_VENC_DACSEL_DA3S_MASK (0x0000F000u)
#define CSL_VENC_DACSEL_DA3S_SHIFT (0x0000000Cu)
#define CSL_VENC_DACSEL_DA3S_RESETVAL (0x00000000u)
/*----DA3S Tokens----*/
#define CSL_VENC_DACSEL_DA3S_CVBS (0x00000000u)
#define CSL_VENC_DACSEL_DA3S_SVIDEO_Y (0x00000001u)
#define CSL_VENC_DACSEL_DA3S_SVIDEO_C (0x00000002u)
#define CSL_VENC_DACSEL_DA3S_Y_G (0x00000003u)
#define CSL_VENC_DACSEL_DA3S_PB_B (0x00000004u)
#define CSL_VENC_DACSEL_DA3S_PR_R (0x00000005u)

#define CSL_VENC_DACSEL_DA2S_MASK (0x00000F00u)
#define CSL_VENC_DACSEL_DA2S_SHIFT (0x00000008u)
#define CSL_VENC_DACSEL_DA2S_RESETVAL (0x00000000u)
/*----DA2S Tokens----*/
#define CSL_VENC_DACSEL_DA2S_CVBS (0x00000000u)
#define CSL_VENC_DACSEL_DA2S_SVIDEO_Y (0x00000001u)
#define CSL_VENC_DACSEL_DA2S_SVIDEO_C (0x00000002u)
#define CSL_VENC_DACSEL_DA2S_Y_G (0x00000003u)
#define CSL_VENC_DACSEL_DA2S_PB_B (0x00000004u)
#define CSL_VENC_DACSEL_DA2S_PR_R (0x00000005u)

#define CSL_VENC_DACSEL_DA1S_MASK (0x000000F0u)
#define CSL_VENC_DACSEL_DA1S_SHIFT (0x00000004u)
#define CSL_VENC_DACSEL_DA1S_RESETVAL (0x00000000u)
/*----DA1S Tokens----*/
#define CSL_VENC_DACSEL_DA1S_CVBS (0x00000000u)
#define CSL_VENC_DACSEL_DA1S_SVIDEO_Y (0x00000001u)
#define CSL_VENC_DACSEL_DA1S_SVIDEO_C (0x00000002u)
#define CSL_VENC_DACSEL_DA1S_Y_G (0x00000003u)
#define CSL_VENC_DACSEL_DA1S_PB_B (0x00000004u)
#define CSL_VENC_DACSEL_DA1S_PR_R (0x00000005u)

#define CSL_VENC_DACSEL_DA0S_MASK (0x0000000Fu)
#define CSL_VENC_DACSEL_DA0S_SHIFT (0x00000000u)
#define CSL_VENC_DACSEL_DA0S_RESETVAL (0x00000000u)
/*----DA0S Tokens----*/
#define CSL_VENC_DACSEL_DA0S_CVBS (0x00000000u)
#define CSL_VENC_DACSEL_DA0S_SVIDEO_Y (0x00000001u)
#define CSL_VENC_DACSEL_DA0S_SVIDEO_C (0x00000002u)
#define CSL_VENC_DACSEL_DA0S_Y_G (0x00000003u)
#define CSL_VENC_DACSEL_DA0S_PB_B (0x00000004u)
#define CSL_VENC_DACSEL_DA0S_PR_R (0x00000005u)

#define CSL_VENC_DACSEL_RESETVAL (0x00000000u)

/* RSV4 */

#define CSL_VENC_RSV4_RSV4_MASK (0xFFFFFFFFu)
#define CSL_VENC_RSV4_RSV4_SHIFT (0x00000000u)
#define CSL_VENC_RSV4_RSV4_RESETVAL (0x00000000u)

#define CSL_VENC_RSV4_RESETVAL (0x00000000u)

/* RSV5 */

#define CSL_VENC_RSV5_RSV5_MASK (0xFFFFFFFFu)
#define CSL_VENC_RSV5_RSV5_SHIFT (0x00000000u)
#define CSL_VENC_RSV5_RSV5_RESETVAL (0x00000000u)

#define CSL_VENC_RSV5_RESETVAL (0x00000000u)

/* ARGBX0 */


#define CSL_VENC_ARGBX0_AGY_MASK (0x000007FFu)
#define CSL_VENC_ARGBX0_AGY_SHIFT (0x00000000u)
#define CSL_VENC_ARGBX0_AGY_RESETVAL (0x00000400u)

#define CSL_VENC_ARGBX0_RESETVAL (0x00000400u)

/* ARGBX1 */


#define CSL_VENC_ARGBX1_ARV_MASK (0x000007FFu)
#define CSL_VENC_ARGBX1_ARV_SHIFT (0x00000000u)
#define CSL_VENC_ARGBX1_ARV_RESETVAL (0x0000057Cu)

#define CSL_VENC_ARGBX1_RESETVAL (0x0000057Cu)

/* ARGBX2 */


#define CSL_VENC_ARGBX2_AGU_MASK (0x000007FFu)
#define CSL_VENC_ARGBX2_AGU_SHIFT (0x00000000u)
#define CSL_VENC_ARGBX2_AGU_RESETVAL (0x00000159u)

#define CSL_VENC_ARGBX2_RESETVAL (0x00000159u)

/* ARGBX3 */


#define CSL_VENC_ARGBX3_AGV_MASK (0x000007FFu)
#define CSL_VENC_ARGBX3_AGV_SHIFT (0x00000000u)
#define CSL_VENC_ARGBX3_AGV_RESETVAL (0x000002CBu)

#define CSL_VENC_ARGBX3_RESETVAL (0x000002CBu)

/* ARGBX4 */


#define CSL_VENC_ARGBX4_ABU_MASK (0x000007FFu)
#define CSL_VENC_ARGBX4_ABU_SHIFT (0x00000000u)
#define CSL_VENC_ARGBX4_ABU_RESETVAL (0x000006EEu)

#define CSL_VENC_ARGBX4_RESETVAL (0x000006EEu)

/* DRGBX0 */


#define CSL_VENC_DRGBX0_DGY_MASK (0x000007FFu)
#define CSL_VENC_DRGBX0_DGY_SHIFT (0x00000000u)
#define CSL_VENC_DRGBX0_DGY_RESETVAL (0x00000400u)

#define CSL_VENC_DRGBX0_RESETVAL (0x00000400u)

/* DRGBX1 */


#define CSL_VENC_DRGBX1_DRV_MASK (0x000007FFu)
#define CSL_VENC_DRGBX1_DRV_SHIFT (0x00000000u)
#define CSL_VENC_DRGBX1_DRV_RESETVAL (0x0000057Cu)

#define CSL_VENC_DRGBX1_RESETVAL (0x0000057Cu)

/* DRGBX2 */


#define CSL_VENC_DRGBX2_DGU_MASK (0x000007FFu)
#define CSL_VENC_DRGBX2_DGU_SHIFT (0x00000000u)
#define CSL_VENC_DRGBX2_DGU_RESETVAL (0x00000159u)

#define CSL_VENC_DRGBX2_RESETVAL (0x00000159u)

/* DRGBX3 */


#define CSL_VENC_DRGBX3_DGV_MASK (0x000007FFu)
#define CSL_VENC_DRGBX3_DGV_SHIFT (0x00000000u)
#define CSL_VENC_DRGBX3_DGV_RESETVAL (0x000002CBu)

#define CSL_VENC_DRGBX3_RESETVAL (0x000002CBu)

/* DRGBX4 */


#define CSL_VENC_DRGBX4_DBU_MASK (0x000007FFu)
#define CSL_VENC_DRGBX4_DBU_SHIFT (0x00000000u)
#define CSL_VENC_DRGBX4_DBU_RESETVAL (0x000006EEu)

#define CSL_VENC_DRGBX4_RESETVAL (0x000006EEu)

/* VSTARTA */


#define CSL_VENC_VSTARTA_VSTARTA_MASK (0x00001FFFu)
#define CSL_VENC_VSTARTA_VSTARTA_SHIFT (0x00000000u)
#define CSL_VENC_VSTARTA_VSTARTA_RESETVAL (0x00000000u)

#define CSL_VENC_VSTARTA_RESETVAL (0x00000000u)

/* OSDCLK0 */


#define CSL_VENC_OSDCLK0_OCPW_MASK (0x0000000Fu)
#define CSL_VENC_OSDCLK0_OCPW_SHIFT (0x00000000u)
#define CSL_VENC_OSDCLK0_OCPW_RESETVAL (0x00000001u)

#define CSL_VENC_OSDCLK0_RESETVAL (0x00000001u)

/* OSDCLK1 */


#define CSL_VENC_OSDCLK1_OCPT_MASK (0x0000FFFFu)
#define CSL_VENC_OSDCLK1_OCPT_SHIFT (0x00000000u)
#define CSL_VENC_OSDCLK1_OCPT_RESETVAL (0x00000002u)

#define CSL_VENC_OSDCLK1_RESETVAL (0x00000002u)

/* HVLDCL0 */


#define CSL_VENC_HVLDCL0_HCM_MASK (0x00000010u)
#define CSL_VENC_HVLDCL0_HCM_SHIFT (0x00000004u)
#define CSL_VENC_HVLDCL0_HCM_RESETVAL (0x00000000u)
/*----HCM Tokens----*/
#define CSL_VENC_HVLDCL0_HCM_NORMAL_MODE (0x00000000u)
#define CSL_VENC_HVLDCL0_HCM_HORIZ_VALID_CULL_MODE (0x00000001u)

#define CSL_VENC_HVLDCL0_HCPW_MASK (0x0000000Fu)
#define CSL_VENC_HVLDCL0_HCPW_SHIFT (0x00000000u)
#define CSL_VENC_HVLDCL0_HCPW_RESETVAL (0x00000000u)

#define CSL_VENC_HVLDCL0_RESETVAL (0x00000000u)

/* HVLDCL1 */


#define CSL_VENC_HVLDCL1_HCPT_MASK (0x0000FFFFu)
#define CSL_VENC_HVLDCL1_HCPT_SHIFT (0x00000000u)
#define CSL_VENC_HVLDCL1_HCPT_RESETVAL (0x00000000u)

#define CSL_VENC_HVLDCL1_RESETVAL (0x00000000u)

/* OSDHADV */


#define CSL_VENC_OSDHADV_OHAD_MASK (0x000000FFu)
#define CSL_VENC_OSDHADV_OHAD_SHIFT (0x00000000u)
#define CSL_VENC_OSDHADV_OHAD_RESETVAL (0x00000000u)

#define CSL_VENC_OSDHADV_RESETVAL (0x00000000u)

#ifdef __cplusplus
}
#endif

#endif

