/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005, 2006, 2007
 *
 *   Use of this software is controlled by the terms and conditions found in
 *   the license agreement under which this software has been supplied.
 *   ===========================================================================
 */
/** ============================================================================
 *   @file  Tsc_example.c
 *
 *   @path $(CSL_EXAMPLE_PATH)\tsc\src
 *
 *   @desc  Example of TSC CSL
 *
 *  ============================================================================
 *   @n Target Platform: EVM
 *  ============================================================================
 *   @n <b> Example Description </b>
 *   @n The example shows how to test the TSC.
 *       1. Enable the counter.
 *       2. Wait for some time.
 *       3. Read the timer counter value
  *      4. Wait for some time.
 *       5. Read the timer counter value
 *       6. Then check the value if it is incremented or not.
 *  ============================================================================
 *
 *   <b> Procedure to run the example </b>
 *   @verbatim
 *      1. Configure the CCS setup to work with the emulator being used
 *      2. Please refer CCS manual for setup configuration and loading
 *         proper GEL file
 *      3. Launch CCS window
 *      4. Open project Tsc_example.pjt
 *      5. Build the project and load the .out file of the project.
 *      6. The example can be executed from the main().
 *
 *   @endverbatim
 *
 *
 * =============================================================================
 */

#include <stdio.h>
#include <csl.h>


/* Macro that gives 1 CLK delay cycles */
#define WAIT_FOR_1_CLK  do {                               \
                            volatile int delayCnt = 1;      \
                            while(delayCnt > 0) --delayCnt; \
                           }while (0)

/* Forward declaration */
static int tsc_example(void);
extern void  CSL_tscEnable(void);
extern CSL_Uint64 CSL_tscRead(void);

/*
 * ============================================================================
 *   @func   main
 *
 *   @desc
 *     This is the main routine for the file.
 *
 * ============================================================================
 */
int main(void)
{
	/* Invoke example , returns 0 for pass and 1 for fail */
    return(tsc_example());
}

/*
 * =============================================================================
 *   @func  tsc_example
 *
 *   @arg
 *      NONE
 *
 *   @desc
 *      This is the routine which perform tsc test
 *
 *   @return
 *      NONE
 *
 * =============================================================================
 */
int tsc_example (void)
{
    CSL_Uint64          counterVal;

    printf("Running TSC CSL example\n");

    printf("Enable the Time Stamp Counter\n");

    /* Enable the TSC */
    CSL_tscEnable();

    /* Give small delay */
    WAIT_FOR_1_CLK;

    /* Read the counter value */
    counterVal = CSL_tscRead();

    /* Give small delay */
    WAIT_FOR_1_CLK;

    /* Read the counter value */
    counterVal = CSL_tscRead();

    /* Verify the counter value incremented or not */
    if(counterVal > 0) {
        printf("Increment in the time stamp counter value\n");
        printf ("counterVal = 0x%x\n", counterVal);
        printf ("Time Stamp Counter Example Passed\n");
		return(0);
    }
    else {
        printf("Not increment in the  time stamp counter value\n");
        printf ("counterVal = 0x%x\n", counterVal);
        printf ("Time Stamp Counter Example Failed\n");
        return(1);
    }
}

