/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005, 2006, 2007
 *
 *   Use of this software is controlled by the terms and conditions found in the
 *   license agreement under which this software has been supplied.
 *   ===========================================================================
 */
/** ============================================================================
 *   @file  cslr_emifa.h
 *
 *   @path  $(CSLPATH)\inc
 *
 *   @desc  This file contains the Register Descriptions for EMIFA
 *
 *  ============================================================================
 */
#ifndef _CSLR_EMIFA_H_
#define _CSLR_EMIFA_H_

#ifdef __cplusplus
extern "C" {
#endif

#include <ti/sdo/pspdrivers/soc/dm648/dsp/cslr.h>
#include <ti/sdo/pspdrivers/soc/dm648/dsp/tistdtypes.h>


/* Minimum unit = 1 byte */

/**************************************************************************\
* Register Overlay Structure
\**************************************************************************/
typedef struct  {
    volatile Uint32 MIDR;
    volatile Uint32 STAT;
    volatile Uint8 RSVD0[24];
    volatile Uint32 BPRIO;
    volatile Uint8 RSVD1[92];
    volatile Uint32 CE2CFG;
    volatile Uint32 CE3CFG;
    volatile Uint8 RSVD2[24];
    volatile Uint32 AWCC;
    volatile Uint8 RSVD3[28];
    volatile Uint32 INTRAW;
    volatile Uint32 INTMSK;
    volatile Uint32 INTMSKSET;
    volatile Uint32 INTMSKCLR;
} CSL_EmifaRegs;

/**************************************************************************\
* Overlay structure typedef definition
\**************************************************************************/
typedef volatile CSL_EmifaRegs         *CSL_EmifaRegsOvly;

/**************************************************************************\
* Field Definition Macros
\**************************************************************************/

/* MIDR */


#define CSL_EMIFA_MIDR_MODULE_ID_MASK (0x3FFF0000u)
#define CSL_EMIFA_MIDR_MODULE_ID_SHIFT (0x00000010u)
#define CSL_EMIFA_MIDR_MODULE_ID_RESETVAL (0x00000000u)

#define CSL_EMIFA_MIDR_MAJOR_REVISION_MASK (0x0000FF00u)
#define CSL_EMIFA_MIDR_MAJOR_REVISION_SHIFT (0x00000008u)
#define CSL_EMIFA_MIDR_MAJOR_REVISION_RESETVAL (0x00000000u)

#define CSL_EMIFA_MIDR_MINOR_REVISION_MASK (0x000000FFu)
#define CSL_EMIFA_MIDR_MINOR_REVISION_SHIFT (0x00000000u)
#define CSL_EMIFA_MIDR_MINOR_REVISION_RESETVAL (0x00000000u)

#define CSL_EMIFA_MIDR_RESETVAL (0x00000000u)

/* STAT */

#define CSL_EMIFA_STAT_BE_MASK (0x80000000u)
#define CSL_EMIFA_STAT_BE_SHIFT (0x0000001Fu)
#define CSL_EMIFA_STAT_BE_RESETVAL (0x00000000u)
/*----BE Tokens----*/
#define CSL_EMIFA_STAT_BE_B_ENDIAN (0x00000001u)
#define CSL_EMIFA_STAT_BE_L_ENDIAN (0x00000000u)

#define CSL_EMIFA_STAT_DUAL_CLK_MODE_MASK (0x40000000u)
#define CSL_EMIFA_STAT_DUAL_CLK_MODE_SHIFT (0x0000001Eu)
#define CSL_EMIFA_STAT_DUAL_CLK_MODE_RESETVAL (0x00000000u)
/*----DUAL_CLK_MODE Tokens----*/
#define CSL_EMIFA_STAT_DUAL_CLK_MODE_ASYNC (0x00000001u)
#define CSL_EMIFA_STAT_DUAL_CLK_MODE_SYNC (0x00000000u)

#define CSL_EMIFA_STAT_FAST_INIT_MASK (0x20000000u)
#define CSL_EMIFA_STAT_FAST_INIT_SHIFT (0x0000001Du)
#define CSL_EMIFA_STAT_FAST_INIT_RESETVAL (0x00000000u)
/*----FAST_INIT Tokens----*/
#define CSL_EMIFA_STAT_FAST_INIT_NORMAL (0x00000000u)
#define CSL_EMIFA_STAT_FAST_INIT_TEST (0x00000001u)


#define CSL_EMIFA_STAT_PHY_DLL_READY_MASK (0x00000004u)
#define CSL_EMIFA_STAT_PHY_DLL_READY_SHIFT (0x00000002u)
#define CSL_EMIFA_STAT_PHY_DLL_READY_RESETVAL (0x00000000u)
/*----PHY_DLL_READY Tokens----*/
#define CSL_EMIFA_STAT_PHY_DLL_READY_DEASSERTED (0x00000000u)
#define CSL_EMIFA_STAT_PHY_DLL_READY_ASSERTED (0x00000001u)


#define CSL_EMIFA_STAT_RESETVAL (0x00000000u)

/* BPRIO */


#define CSL_EMIFA_BPRIO_PR_OLD_COUNT_MASK (0x000000FFu)
#define CSL_EMIFA_BPRIO_PR_OLD_COUNT_SHIFT (0x00000000u)
#define CSL_EMIFA_BPRIO_PR_OLD_COUNT_RESETVAL (0x000000FFu)

#define CSL_EMIFA_BPRIO_RESETVAL (0x000000FFu)

/* CE2CFG */

#define CSL_EMIFA_CE2CFG_SSEL_MASK (0x80000000u)
#define CSL_EMIFA_CE2CFG_SSEL_SHIFT (0x0000001Fu)
#define CSL_EMIFA_CE2CFG_SSEL_RESETVAL (0x00000000u)
/*----SSEL Tokens----*/
#define CSL_EMIFA_CE2CFG_SSEL_ASYNC_MEM (0x00000000u)
#define CSL_EMIFA_CE2CFG_SSEL_SYNC_MEM (0x00000001u)

#define CSL_EMIFA_CE2CFG_SS_MASK (0x40000000u)
#define CSL_EMIFA_CE2CFG_SS_SHIFT (0x0000001Eu)
#define CSL_EMIFA_CE2CFG_SS_RESETVAL (0x00000000u)
/*----SS Tokens----*/
#define CSL_EMIFA_CE2CFG_SS_SELSTRB_DISABLE (0x00000000u)
#define CSL_EMIFA_CE2CFG_SS_SELSTRB_ENALBE (0x00000001u)

#define CSL_EMIFA_CE2CFG_BWEM_MASK (0x20000000u)
#define CSL_EMIFA_CE2CFG_BWEM_SHIFT (0x0000001Du)
#define CSL_EMIFA_CE2CFG_BWEM_RESETVAL (0x00000000u)
/*----BWEM Tokens----*/
#define CSL_EMIFA_CE2CFG_BWEM_BYTE_ENABLES (0x00000000u)
#define CSL_EMIFA_CE2CFG_BWEM_BYTE_WRITE_ENABLES (0x00000001u)

#define CSL_EMIFA_CE2CFG_EW_MASK (0x10000000u)
#define CSL_EMIFA_CE2CFG_EW_SHIFT (0x0000001Cu)
#define CSL_EMIFA_CE2CFG_EW_RESETVAL (0x00000000u)
/*----EW Tokens----*/
#define CSL_EMIFA_CE2CFG_EW_EXT_WAIT_DISABLE (0x00000000u)
#define CSL_EMIFA_CE2CFG_EW_EXT_WAIT_ENABLE (0x00000001u)

#define CSL_EMIFA_CE2CFG_W_SETUP_MASK (0x0F000000u)
#define CSL_EMIFA_CE2CFG_W_SETUP_SHIFT (0x00000018u)
#define CSL_EMIFA_CE2CFG_W_SETUP_RESETVAL (0x0000000Fu)

#define CSL_EMIFA_CE2CFG_W_STROBE_MASK (0x00FC0000u)
#define CSL_EMIFA_CE2CFG_W_STROBE_SHIFT (0x00000012u)
#define CSL_EMIFA_CE2CFG_W_STROBE_RESETVAL (0x0000003Fu)

#define CSL_EMIFA_CE2CFG_W_HOLD_MASK (0x00038000u)
#define CSL_EMIFA_CE2CFG_W_HOLD_SHIFT (0x0000000Fu)
#define CSL_EMIFA_CE2CFG_W_HOLD_RESETVAL (0x00000007u)

#define CSL_EMIFA_CE2CFG_R_SETUP_MASK (0x00007800u)
#define CSL_EMIFA_CE2CFG_R_SETUP_SHIFT (0x0000000Bu)
#define CSL_EMIFA_CE2CFG_R_SETUP_RESETVAL (0x0000000Fu)

#define CSL_EMIFA_CE2CFG_R_STROBE_MASK (0x000007E0u)
#define CSL_EMIFA_CE2CFG_R_STROBE_SHIFT (0x00000005u)
#define CSL_EMIFA_CE2CFG_R_STROBE_RESETVAL (0x0000003Fu)

#define CSL_EMIFA_CE2CFG_R_HOLD_MASK (0x0000001Cu)
#define CSL_EMIFA_CE2CFG_R_HOLD_SHIFT (0x00000002u)
#define CSL_EMIFA_CE2CFG_R_HOLD_RESETVAL (0x00000007u)

#define CSL_EMIFA_CE2CFG_ASIZE_MASK (0x00000003u)
#define CSL_EMIFA_CE2CFG_ASIZE_SHIFT (0x00000000u)
#define CSL_EMIFA_CE2CFG_ASIZE_RESETVAL (0x00000000u)
/*----ASIZE Tokens----*/
#define CSL_EMIFA_CE2CFG_ASIZE_8BIT (0x00000000u)
#define CSL_EMIFA_CE2CFG_ASIZE_16BIT (0x00000001u)
#define CSL_EMIFA_CE2CFG_ASIZE_32BIT (0x00000002u)
#define CSL_EMIFA_CE2CFG_ASIZE_64BIT (0x00000003u)

#define CSL_EMIFA_CE2CFG_RESETVAL (0x0FFFFFFCu)

/* CE3CFG */

#define CSL_EMIFA_CE3CFG_SSEL_MASK (0x80000000u)
#define CSL_EMIFA_CE3CFG_SSEL_SHIFT (0x0000001Fu)
#define CSL_EMIFA_CE3CFG_SSEL_RESETVAL (0x00000000u)
/*----SSEL Tokens----*/
#define CSL_EMIFA_CE3CFG_SSEL_ASYNC_MEM (0x00000000u)
#define CSL_EMIFA_CE3CFG_SSEL_SYNC_MEM (0x00000001u)

#define CSL_EMIFA_CE3CFG_SS_MASK (0x40000000u)
#define CSL_EMIFA_CE3CFG_SS_SHIFT (0x0000001Eu)
#define CSL_EMIFA_CE3CFG_SS_RESETVAL (0x00000000u)
/*----SS Tokens----*/
#define CSL_EMIFA_CE3CFG_SS_SELSTRB_DISABLE (0x00000000u)
#define CSL_EMIFA_CE3CFG_SS_SELSTRB_ENALBE (0x00000001u)

#define CSL_EMIFA_CE3CFG_BWEM_MASK (0x20000000u)
#define CSL_EMIFA_CE3CFG_BWEM_SHIFT (0x0000001Du)
#define CSL_EMIFA_CE3CFG_BWEM_RESETVAL (0x00000000u)
/*----BWEM Tokens----*/
#define CSL_EMIFA_CE3CFG_BWEM_BYTE_ENABLES (0x00000000u)
#define CSL_EMIFA_CE3CFG_BWEM_BYTE_WRITE_ENABLES (0x00000001u)

#define CSL_EMIFA_CE3CFG_EW_MASK (0x10000000u)
#define CSL_EMIFA_CE3CFG_EW_SHIFT (0x0000001Cu)
#define CSL_EMIFA_CE3CFG_EW_RESETVAL (0x00000000u)
/*----EW Tokens----*/
#define CSL_EMIFA_CE3CFG_EW_EXT_WAIT_DISABLE (0x00000000u)
#define CSL_EMIFA_CE3CFG_EW_EXT_WAIT_ENABLE (0x00000001u)

#define CSL_EMIFA_CE3CFG_W_SETUP_MASK (0x0F000000u)
#define CSL_EMIFA_CE3CFG_W_SETUP_SHIFT (0x00000018u)
#define CSL_EMIFA_CE3CFG_W_SETUP_RESETVAL (0x0000000Fu)

#define CSL_EMIFA_CE3CFG_W_STROBE_MASK (0x00FC0000u)
#define CSL_EMIFA_CE3CFG_W_STROBE_SHIFT (0x00000012u)
#define CSL_EMIFA_CE3CFG_W_STROBE_RESETVAL (0x0000003Fu)

#define CSL_EMIFA_CE3CFG_W_HOLD_MASK (0x00038000u)
#define CSL_EMIFA_CE3CFG_W_HOLD_SHIFT (0x0000000Fu)
#define CSL_EMIFA_CE3CFG_W_HOLD_RESETVAL (0x00000007u)

#define CSL_EMIFA_CE3CFG_R_SETUP_MASK (0x00007800u)
#define CSL_EMIFA_CE3CFG_R_SETUP_SHIFT (0x0000000Bu)
#define CSL_EMIFA_CE3CFG_R_SETUP_RESETVAL (0x0000000Fu)

#define CSL_EMIFA_CE3CFG_R_STROBE_MASK (0x000007E0u)
#define CSL_EMIFA_CE3CFG_R_STROBE_SHIFT (0x00000005u)
#define CSL_EMIFA_CE3CFG_R_STROBE_RESETVAL (0x0000003Fu)

#define CSL_EMIFA_CE3CFG_R_HOLD_MASK (0x0000001Cu)
#define CSL_EMIFA_CE3CFG_R_HOLD_SHIFT (0x00000002u)
#define CSL_EMIFA_CE3CFG_R_HOLD_RESETVAL (0x00000007u)

#define CSL_EMIFA_CE3CFG_ASIZE_MASK (0x00000003u)
#define CSL_EMIFA_CE3CFG_ASIZE_SHIFT (0x00000000u)
#define CSL_EMIFA_CE3CFG_ASIZE_RESETVAL (0x00000000u)
/*----ASIZE Tokens----*/
#define CSL_EMIFA_CE3CFG_ASIZE_8BIT (0x00000000u)
#define CSL_EMIFA_CE3CFG_ASIZE_16BIT (0x00000001u)
#define CSL_EMIFA_CE3CFG_ASIZE_64BIT (0x00000003u)

#define CSL_EMIFA_CE3CFG_RESETVAL (0x0FFFFFFCu)

/* AWCC */


#define CSL_EMIFA_AWCC_WP_MASK (0x40000000u)
#define CSL_EMIFA_AWCC_WP_SHIFT (0x0000001Eu)
#define CSL_EMIFA_AWCC_WP_RESETVAL (0x00000001u)
/*----WP Tokens----*/
#define CSL_EMIFA_AWCC_WP_WAIT_ONLOW (0x00000000u)


#define CSL_EMIFA_AWCC_TA_MASK (0x00000700u)
#define CSL_EMIFA_AWCC_TA_SHIFT (0x00000008u)
#define CSL_EMIFA_AWCC_TA_RESETVAL (0x00000003u)

#define CSL_EMIFA_AWCC_MAX_EXT_WAIT_MASK (0x000000FFu)
#define CSL_EMIFA_AWCC_MAX_EXT_WAIT_SHIFT (0x00000000u)
#define CSL_EMIFA_AWCC_MAX_EXT_WAIT_RESETVAL (0x00000080u)

#define CSL_EMIFA_AWCC_RESETVAL (0x40000380u)

/* INTRAW */


#define CSL_EMIFA_INTRAW_IT_MASK (0x00000004u)
#define CSL_EMIFA_INTRAW_IT_SHIFT (0x00000002u)
#define CSL_EMIFA_INTRAW_IT_RESETVAL (0x00000000u)
/*----IT Tokens----*/
#define CSL_EMIFA_INTRAW_IT_CLEAR (0x00000001u)


#define CSL_EMIFA_INTRAW_AT_MASK (0x00000001u)
#define CSL_EMIFA_INTRAW_AT_SHIFT (0x00000000u)
#define CSL_EMIFA_INTRAW_AT_RESETVAL (0x00000000u)

#define CSL_EMIFA_INTRAW_RESETVAL (0x00000000u)

/* INTMSK */


#define CSL_EMIFA_INTMSK_IT_MASKED_MASK (0x00000004u)
#define CSL_EMIFA_INTMSK_IT_MASKED_SHIFT (0x00000002u)
#define CSL_EMIFA_INTMSK_IT_MASKED_RESETVAL (0x00000000u)
/*----IT_MASKED Tokens----*/
#define CSL_EMIFA_INTMSK_IT_MASKED_CLEAR (0x00000001u)


#define CSL_EMIFA_INTMSK_AT_MASKED_MASK (0x00000001u)
#define CSL_EMIFA_INTMSK_AT_MASKED_SHIFT (0x00000000u)
#define CSL_EMIFA_INTMSK_AT_MASKED_RESETVAL (0x00000000u)

#define CSL_EMIFA_INTMSK_RESETVAL (0x00000000u)

/* INTMSKSET */


#define CSL_EMIFA_INTMSKSET_IT_MASK_SET_MASK (0x00000004u)
#define CSL_EMIFA_INTMSKSET_IT_MASK_SET_SHIFT (0x00000002u)
#define CSL_EMIFA_INTMSKSET_IT_MASK_SET_RESETVAL (0x00000000u)
/*----IT_MASK_SET Tokens----*/
#define CSL_EMIFA_INTMSKSET_IT_MASK_SET_SET (0x00000001u)


#define CSL_EMIFA_INTMSKSET_AT_MASK_SET_MASK (0x00000001u)
#define CSL_EMIFA_INTMSKSET_AT_MASK_SET_SHIFT (0x00000000u)
#define CSL_EMIFA_INTMSKSET_AT_MASK_SET_RESETVAL (0x00000000u)

#define CSL_EMIFA_INTMSKSET_RESETVAL (0x00000000u)

/* INTMSKCLR */


#define CSL_EMIFA_INTMSKCLR_IT_MASK_CLR_MASK (0x00000004u)
#define CSL_EMIFA_INTMSKCLR_IT_MASK_CLR_SHIFT (0x00000002u)
#define CSL_EMIFA_INTMSKCLR_IT_MASK_CLR_RESETVAL (0x00000000u)
/*----IT_MASK_CLR Tokens----*/
#define CSL_EMIFA_INTMSKCLR_IT_MASK_CLR_CLEAR (0x00000001u)


#define CSL_EMIFA_INTMSKCLR_AT_MASK_CLR_MASK (0x00000001u)
#define CSL_EMIFA_INTMSKCLR_AT_MASK_CLR_SHIFT (0x00000000u)
#define CSL_EMIFA_INTMSKCLR_AT_MASK_CLR_RESETVAL (0x00000000u)

#define CSL_EMIFA_INTMSKCLR_RESETVAL (0x00000000u)

#ifdef __cplusplus
}
#endif

#endif

