/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005, 2006, 2007
 *
 *   Use of this software is controlled by the terms and conditions found in the
 *   license agreement under which this software has been supplied.
 *   ===========================================================================
 */
/** ============================================================================
 *   @file  cslr_pci.h
 *
 *   @path  $(CSLPATH)\inc
 *
 *   @desc  This file contains the Register Descriptions for PCI
 *  ============================================================================
 */

#ifndef _CSLR_PCI_H_
#define _CSLR_PCI_H_

#ifdef __cplusplus
extern "C" {
#endif

#include <ti/sdo/pspdrivers/soc/dm648/dsp/cslr.h>
#include <ti/sdo/pspdrivers/soc/dm648/dsp/tistdtypes.h>



/* Minimum unit = 1 byte */

/**************************************************************************\
* Register Overlay Structure
\**************************************************************************/
typedef struct  {
    volatile Uint8 RSVD0[16];
    volatile Uint32 PCISTATSET;
    volatile Uint32 PCISTATCLR;
    volatile Uint8 RSVD1[8];
    volatile Uint32 PCIHINTSET;
    volatile Uint32 PCIHINTCLR;
    volatile Uint8 RSVD2[8];
    volatile Uint32 PCIDINTSET;
    volatile Uint32 PCIDINTCLR;
    volatile Uint8 RSVD3[200];
    volatile Uint32 PCIVENDEVMIR;
    volatile Uint32 PCICSRMIR;
    volatile Uint32 PCICLREVMIR;
    volatile Uint32 PCICLINEMIR;
    volatile Uint32 PCIBAR0MSK;
    volatile Uint32 PCIBAR1MSK;
    volatile Uint32 PCIBAR2MSK;
    volatile Uint32 PCIBAR3MSK;
    volatile Uint32 PCIBAR4MSK;
    volatile Uint32 PCIBAR5MSK;
    volatile Uint8 RSVD4[4];
    volatile Uint32 PCISUBIDMIR;
    volatile Uint8 RSVD5[4];
    volatile Uint32 PCICPBPTRMIR;
    volatile Uint8 RSVD6[4];
    volatile Uint32 PCILGINTMIR;
    volatile Uint8 RSVD7[64];
    volatile Uint32 PCISLVCNTL;
    volatile Uint8 RSVD8[60];
    volatile Uint32 PCIBAR0TRL;
    volatile Uint32 PCIBAR1TRL;
    volatile Uint32 PCIBAR2TRL;
    volatile Uint32 PCIBAR3TRL;
    volatile Uint32 PCIBAR4TRL;
    volatile Uint32 PCIBAR5TRL;
    volatile Uint8 RSVD9[8];
    volatile Uint32 PCIBAR0MIR;
    volatile Uint32 PCIBAR1MIR;
    volatile Uint32 PCIBAR2MIR;
    volatile Uint32 PCIBAR3MIR;
    volatile Uint32 PCIBAR4MIR;
    volatile Uint32 PCIBAR5MIR;
    volatile Uint8 RSVD10[264];
    volatile Uint32 PCIMCFGDAT;
    volatile Uint32 PCIMCFGADR;
    volatile Uint32 PCIMCFGCMD;
    volatile Uint8 RSVD11[4];
    volatile Uint32 PCIMSTCFG;
    volatile Uint32 PCIADDSUB[32];
    volatile Uint32 PCIVENDEVPRG;
    volatile Uint8 RSVD12[4];
    volatile Uint32 PCICLREVPRG;
    volatile Uint32 PCISUBIDPRG;
    volatile Uint32 PCIMAXLGPRG;
    volatile Uint8 RSVD13[4];
    volatile Uint32 PCICFGDONE;
} CSL_PciRegs;

/**************************************************************************\
* Overlay structure typedef definition
\**************************************************************************/
typedef volatile CSL_PciRegs         *CSL_PciRegsOvly;

/**************************************************************************\
* Field Definition Macros
\**************************************************************************/

/* PCISTATSET */



#define CSL_PCI_PCISTATSET_SOFT_INT3_MASK (0x08000000u)
#define CSL_PCI_PCISTATSET_SOFT_INT3_SHIFT (0x0000001Bu)
#define CSL_PCI_PCISTATSET_SOFT_INT3_RESETVAL (0x00000000u)
/*----SOFT_INT3 Tokens----*/
#define CSL_PCI_PCISTATSET_SOFT_INT3_NOT_SET (0x00000000u)
#define CSL_PCI_PCISTATSET_SOFT_INT3_SET (0x00000001u)

#define CSL_PCI_PCISTATSET_SOFT_INT2_MASK (0x04000000u)
#define CSL_PCI_PCISTATSET_SOFT_INT2_SHIFT (0x0000001Au)
#define CSL_PCI_PCISTATSET_SOFT_INT2_RESETVAL (0x00000000u)
/*----SOFT_INT2 Tokens----*/
#define CSL_PCI_PCISTATSET_SOFT_INT2_NOT_SET (0x00000000u)
#define CSL_PCI_PCISTATSET_SOFT_INT2_SET (0x00000001u)

#define CSL_PCI_PCISTATSET_SOFT_INT1_MASK (0x02000000u)
#define CSL_PCI_PCISTATSET_SOFT_INT1_SHIFT (0x00000019u)
#define CSL_PCI_PCISTATSET_SOFT_INT1_RESETVAL (0x00000000u)
/*----SOFT_INT1 Tokens----*/
#define CSL_PCI_PCISTATSET_SOFT_INT1_NOT_SET (0x00000000u)
#define CSL_PCI_PCISTATSET_SOFT_INT1_SET (0x00000001u)

#define CSL_PCI_PCISTATSET_SOFT_INT0_MASK (0x01000000u)
#define CSL_PCI_PCISTATSET_SOFT_INT0_SHIFT (0x00000018u)
#define CSL_PCI_PCISTATSET_SOFT_INT0_RESETVAL (0x00000000u)
/*----SOFT_INT0 Tokens----*/
#define CSL_PCI_PCISTATSET_SOFT_INT0_NOT_SET (0x00000000u)
#define CSL_PCI_PCISTATSET_SOFT_INT0_SET (0x00000001u)




#define CSL_PCI_PCISTATSET_PERR_DET_MASK (0x00000040u)
#define CSL_PCI_PCISTATSET_PERR_DET_SHIFT (0x00000006u)
#define CSL_PCI_PCISTATSET_PERR_DET_RESETVAL (0x00000000u)
/*----PERR_DET Tokens----*/
#define CSL_PCI_PCISTATSET_PERR_DET_NOT_SET (0x00000000u)
#define CSL_PCI_PCISTATSET_PERR_DET_SET (0x00000001u)

#define CSL_PCI_PCISTATSET_SERR_DET_MASK (0x00000020u)
#define CSL_PCI_PCISTATSET_SERR_DET_SHIFT (0x00000005u)
#define CSL_PCI_PCISTATSET_SERR_DET_RESETVAL (0x00000000u)
/*----SERR_DET Tokens----*/
#define CSL_PCI_PCISTATSET_SERR_DET_NOT_SET (0x00000000u)
#define CSL_PCI_PCISTATSET_SERR_DET_SET (0x00000001u)


#define CSL_PCI_PCISTATSET_MS_ABRT_DET_MASK (0x00000004u)
#define CSL_PCI_PCISTATSET_MS_ABRT_DET_SHIFT (0x00000002u)
#define CSL_PCI_PCISTATSET_MS_ABRT_DET_RESETVAL (0x00000000u)
/*----MS_ABRT_DET Tokens----*/
#define CSL_PCI_PCISTATSET_MS_ABRT_DET_NOT_SET (0x00000000u)
#define CSL_PCI_PCISTATSET_MS_ABRT_DET_SET (0x00000001u)

#define CSL_PCI_PCISTATSET_TGT_ABRT_DET_MASK (0x00000002u)
#define CSL_PCI_PCISTATSET_TGT_ABRT_DET_SHIFT (0x00000001u)
#define CSL_PCI_PCISTATSET_TGT_ABRT_DET_RESETVAL (0x00000000u)
/*----TGT_ABRT_DET Tokens----*/
#define CSL_PCI_PCISTATSET_TGT_ABRT_DET_NOT_SET (0x00000000u)
#define CSL_PCI_PCISTATSET_TGT_ABRT_DET_SET (0x00000001u)


#define CSL_PCI_PCISTATSET_RESETVAL (0x00000000u)

/* PCISTATCLR */



#define CSL_PCI_PCISTATCLR_SOFT_INT3_MASK (0x08000000u)
#define CSL_PCI_PCISTATCLR_SOFT_INT3_SHIFT (0x0000001Bu)
#define CSL_PCI_PCISTATCLR_SOFT_INT3_RESETVAL (0x00000000u)
/*----SOFT_INT3 Tokens----*/
#define CSL_PCI_PCISTATCLR_SOFT_INT3_NOT_SET (0x00000000u)
#define CSL_PCI_PCISTATCLR_SOFT_INT3_CLEAR (0x00000001u)

#define CSL_PCI_PCISTATCLR_SOFT_INT2_MASK (0x04000000u)
#define CSL_PCI_PCISTATCLR_SOFT_INT2_SHIFT (0x0000001Au)
#define CSL_PCI_PCISTATCLR_SOFT_INT2_RESETVAL (0x00000000u)
/*----SOFT_INT2 Tokens----*/
#define CSL_PCI_PCISTATCLR_SOFT_INT2_NOT_SET (0x00000000u)
#define CSL_PCI_PCISTATCLR_SOFT_INT2_CLEAR (0x00000001u)

#define CSL_PCI_PCISTATCLR_SOFT_INT1_MASK (0x02000000u)
#define CSL_PCI_PCISTATCLR_SOFT_INT1_SHIFT (0x00000019u)
#define CSL_PCI_PCISTATCLR_SOFT_INT1_RESETVAL (0x00000000u)
/*----SOFT_INT1 Tokens----*/
#define CSL_PCI_PCISTATCLR_SOFT_INT1_NOT_SET (0x00000000u)
#define CSL_PCI_PCISTATCLR_SOFT_INT1_CLEAR (0x00000001u)

#define CSL_PCI_PCISTATCLR_SOFT_INT0_MASK (0x01000000u)
#define CSL_PCI_PCISTATCLR_SOFT_INT0_SHIFT (0x00000018u)
#define CSL_PCI_PCISTATCLR_SOFT_INT0_RESETVAL (0x00000000u)
/*----SOFT_INT0 Tokens----*/
#define CSL_PCI_PCISTATCLR_SOFT_INT0_NOT_SET (0x00000000u)
#define CSL_PCI_PCISTATCLR_SOFT_INT0_CLEAR (0x00000001u)


#define CSL_PCI_PCISTATCLR_PERR_DET_MASK (0x00000040u)
#define CSL_PCI_PCISTATCLR_PERR_DET_SHIFT (0x00000006u)
#define CSL_PCI_PCISTATCLR_PERR_DET_RESETVAL (0x00000000u)
/*----PERR_DET Tokens----*/
#define CSL_PCI_PCISTATCLR_PERR_DET_NOT_SET (0x00000000u)
#define CSL_PCI_PCISTATCLR_PERR_DET_CLEAR (0x00000001u)

#define CSL_PCI_PCISTATCLR_SERR_DET_MASK (0x00000020u)
#define CSL_PCI_PCISTATCLR_SERR_DET_SHIFT (0x00000005u)
#define CSL_PCI_PCISTATCLR_SERR_DET_RESETVAL (0x00000000u)
/*----SERR_DET Tokens----*/
#define CSL_PCI_PCISTATCLR_SERR_DET_NOT_SET (0x00000000u)
#define CSL_PCI_PCISTATCLR_SERR_DET_CLEAR (0x00000001u)


#define CSL_PCI_PCISTATCLR_MS_ABRT_DET_MASK (0x00000004u)
#define CSL_PCI_PCISTATCLR_MS_ABRT_DET_SHIFT (0x00000002u)
#define CSL_PCI_PCISTATCLR_MS_ABRT_DET_RESETVAL (0x00000000u)
/*----MS_ABRT_DET Tokens----*/
#define CSL_PCI_PCISTATCLR_MS_ABRT_DET_NOT_SET (0x00000000u)
#define CSL_PCI_PCISTATCLR_MS_ABRT_DET_CLEAR (0x00000001u)

#define CSL_PCI_PCISTATCLR_TGT_ABRT_DET_MASK (0x00000002u)
#define CSL_PCI_PCISTATCLR_TGT_ABRT_DET_SHIFT (0x00000001u)
#define CSL_PCI_PCISTATCLR_TGT_ABRT_DET_RESETVAL (0x00000000u)
/*----TGT_ABRT_DET Tokens----*/
#define CSL_PCI_PCISTATCLR_TGT_ABRT_DET_NOT_SET (0x00000000u)
#define CSL_PCI_PCISTATCLR_TGT_ABRT_DET_CLEAR (0x00000001u)


#define CSL_PCI_PCISTATCLR_RESETVAL (0x00000000u)

/* PCIHINTSET */


#define CSL_PCI_PCIHINTSET_SOFT_INT3_MASK (0x08000000u)
#define CSL_PCI_PCIHINTSET_SOFT_INT3_SHIFT (0x0000001Bu)
#define CSL_PCI_PCIHINTSET_SOFT_INT3_RESETVAL (0x00000000u)
/*----SOFT_INT3 Tokens----*/
#define CSL_PCI_PCIHINTSET_SOFT_INT3_SET (0x00000001u)

#define CSL_PCI_PCIHINTSET_SOFT_INT2_MASK (0x04000000u)
#define CSL_PCI_PCIHINTSET_SOFT_INT2_SHIFT (0x0000001Au)
#define CSL_PCI_PCIHINTSET_SOFT_INT2_RESETVAL (0x00000000u)
/*----SOFT_INT2 Tokens----*/
#define CSL_PCI_PCIHINTSET_SOFT_INT2_SET (0x00000001u)

#define CSL_PCI_PCIHINTSET_SOFT_INT1_MASK (0x02000000u)
#define CSL_PCI_PCIHINTSET_SOFT_INT1_SHIFT (0x00000019u)
#define CSL_PCI_PCIHINTSET_SOFT_INT1_RESETVAL (0x00000000u)
/*----SOFT_INT1 Tokens----*/
#define CSL_PCI_PCIHINTSET_SOFT_INT1_SET (0x00000001u)

#define CSL_PCI_PCIHINTSET_SOFT_INT0_MASK (0x01000000u)
#define CSL_PCI_PCIHINTSET_SOFT_INT0_SHIFT (0x00000018u)
#define CSL_PCI_PCIHINTSET_SOFT_INT0_RESETVAL (0x00000000u)
/*----SOFT_INT0 Tokens----*/
#define CSL_PCI_PCIHINTSET_SOFT_INT0_SET (0x00000001u)


#define CSL_PCI_PCIHINTSET_PERR_DET_MASK (0x00000040u)
#define CSL_PCI_PCIHINTSET_PERR_DET_SHIFT (0x00000006u)
#define CSL_PCI_PCIHINTSET_PERR_DET_RESETVAL (0x00000000u)
/*----PERR_DET Tokens----*/
#define CSL_PCI_PCIHINTSET_PERR_DET_SET (0x00000001u)

#define CSL_PCI_PCIHINTSET_SERR_DET_MASK (0x00000020u)
#define CSL_PCI_PCIHINTSET_SERR_DET_SHIFT (0x00000005u)
#define CSL_PCI_PCIHINTSET_SERR_DET_RESETVAL (0x00000000u)
/*----SERR_DET Tokens----*/
#define CSL_PCI_PCIHINTSET_SERR_DET_SET (0x00000001u)


#define CSL_PCI_PCIHINTSET_MS_ABRT_DET_MASK (0x00000004u)
#define CSL_PCI_PCIHINTSET_MS_ABRT_DET_SHIFT (0x00000002u)
#define CSL_PCI_PCIHINTSET_MS_ABRT_DET_RESETVAL (0x00000000u)
/*----MS_ABRT_DET Tokens----*/
#define CSL_PCI_PCIHINTSET_MS_ABRT_DET_SET (0x00000001u)

#define CSL_PCI_PCIHINTSET_TGT_ABRT_DET_MASK (0x00000002u)
#define CSL_PCI_PCIHINTSET_TGT_ABRT_DET_SHIFT (0x00000001u)
#define CSL_PCI_PCIHINTSET_TGT_ABRT_DET_RESETVAL (0x00000000u)
/*----TGT_ABRT_DET Tokens----*/
#define CSL_PCI_PCIHINTSET_TGT_ABRT_DET_SET (0x00000001u)


#define CSL_PCI_PCIHINTSET_RESETVAL (0x00000000u)

/* PCIHINTCLR */


#define CSL_PCI_PCIHINTCLR_SOFT_INT3_MASK (0x08000000u)
#define CSL_PCI_PCIHINTCLR_SOFT_INT3_SHIFT (0x0000001Bu)
#define CSL_PCI_PCIHINTCLR_SOFT_INT3_RESETVAL (0x00000000u)
/*----SOFT_INT3 Tokens----*/
#define CSL_PCI_PCIHINTCLR_SOFT_INT3_CLEAR (0x00000001u)

#define CSL_PCI_PCIHINTCLR_SOFT_INT2_MASK (0x04000000u)
#define CSL_PCI_PCIHINTCLR_SOFT_INT2_SHIFT (0x0000001Au)
#define CSL_PCI_PCIHINTCLR_SOFT_INT2_RESETVAL (0x00000000u)
/*----SOFT_INT2 Tokens----*/
#define CSL_PCI_PCIHINTCLR_SOFT_INT2_CLEAR (0x00000001u)

#define CSL_PCI_PCIHINTCLR_SOFT_INT1_MASK (0x02000000u)
#define CSL_PCI_PCIHINTCLR_SOFT_INT1_SHIFT (0x00000019u)
#define CSL_PCI_PCIHINTCLR_SOFT_INT1_RESETVAL (0x00000000u)
/*----SOFT_INT1 Tokens----*/
#define CSL_PCI_PCIHINTCLR_SOFT_INT1_CLEAR (0x00000001u)

#define CSL_PCI_PCIHINTCLR_SOFT_INT0_MASK (0x01000000u)
#define CSL_PCI_PCIHINTCLR_SOFT_INT0_SHIFT (0x00000018u)
#define CSL_PCI_PCIHINTCLR_SOFT_INT0_RESETVAL (0x00000000u)
/*----SOFT_INT0 Tokens----*/
#define CSL_PCI_PCIHINTCLR_SOFT_INT0_CLEAR (0x00000001u)


#define CSL_PCI_PCIHINTCLR_PERR_DET_MASK (0x00000040u)
#define CSL_PCI_PCIHINTCLR_PERR_DET_SHIFT (0x00000006u)
#define CSL_PCI_PCIHINTCLR_PERR_DET_RESETVAL (0x00000000u)
/*----PERR_DET Tokens----*/
#define CSL_PCI_PCIHINTCLR_PERR_DET_CLEAR (0x00000001u)

#define CSL_PCI_PCIHINTCLR_SERR_DET_MASK (0x00000020u)
#define CSL_PCI_PCIHINTCLR_SERR_DET_SHIFT (0x00000005u)
#define CSL_PCI_PCIHINTCLR_SERR_DET_RESETVAL (0x00000000u)
/*----SERR_DET Tokens----*/
#define CSL_PCI_PCIHINTCLR_SERR_DET_CLEAR (0x00000001u)


#define CSL_PCI_PCIHINTCLR_MS_ABRT_DET_MASK (0x00000004u)
#define CSL_PCI_PCIHINTCLR_MS_ABRT_DET_SHIFT (0x00000002u)
#define CSL_PCI_PCIHINTCLR_MS_ABRT_DET_RESETVAL (0x00000000u)
/*----MS_ABRT_DET Tokens----*/
#define CSL_PCI_PCIHINTCLR_MS_ABRT_DET_CLEAR (0x00000001u)

#define CSL_PCI_PCIHINTCLR_TGT_ABRT_DET_MASK (0x00000002u)
#define CSL_PCI_PCIHINTCLR_TGT_ABRT_DET_SHIFT (0x00000001u)
#define CSL_PCI_PCIHINTCLR_TGT_ABRT_DET_RESETVAL (0x00000000u)
/*----TGT_ABRT_DET Tokens----*/
#define CSL_PCI_PCIHINTCLR_TGT_ABRT_DET_CLEAR (0x00000001u)


#define CSL_PCI_PCIHINTCLR_RESETVAL (0x00000000u)

/* PCIDINTSET */


#define CSL_PCI_PCIDINTSET_SOFT_INT3_MASK (0x08000000u)
#define CSL_PCI_PCIDINTSET_SOFT_INT3_SHIFT (0x0000001Bu)
#define CSL_PCI_PCIDINTSET_SOFT_INT3_RESETVAL (0x00000000u)
/*----SOFT_INT3 Tokens----*/
#define CSL_PCI_PCIDINTSET_SOFT_INT3_ENABLE (0x00000001u)

#define CSL_PCI_PCIDINTSET_SOFT_INT2_MASK (0x04000000u)
#define CSL_PCI_PCIDINTSET_SOFT_INT2_SHIFT (0x0000001Au)
#define CSL_PCI_PCIDINTSET_SOFT_INT2_RESETVAL (0x00000000u)
/*----SOFT_INT2 Tokens----*/
#define CSL_PCI_PCIDINTSET_SOFT_INT2_ENABLE (0x00000001u)

#define CSL_PCI_PCIDINTSET_SOFT_INT1_MASK (0x02000000u)
#define CSL_PCI_PCIDINTSET_SOFT_INT1_SHIFT (0x00000019u)
#define CSL_PCI_PCIDINTSET_SOFT_INT1_RESETVAL (0x00000000u)
/*----SOFT_INT1 Tokens----*/
#define CSL_PCI_PCIDINTSET_SOFT_INT1_ENABLE (0x00000001u)

#define CSL_PCI_PCIDINTSET_SOFT_INT0_MASK (0x01000000u)
#define CSL_PCI_PCIDINTSET_SOFT_INT0_SHIFT (0x00000018u)
#define CSL_PCI_PCIDINTSET_SOFT_INT0_RESETVAL (0x00000000u)
/*----SOFT_INT0 Tokens----*/
#define CSL_PCI_PCIDINTSET_SOFT_INT0_ENABLE (0x00000001u)


#define CSL_PCI_PCIDINTSET_PERR_DET_MASK (0x00000040u)
#define CSL_PCI_PCIDINTSET_PERR_DET_SHIFT (0x00000006u)
#define CSL_PCI_PCIDINTSET_PERR_DET_RESETVAL (0x00000000u)
/*----PERR_DET Tokens----*/
#define CSL_PCI_PCIDINTSET_PERR_DET_ENABLE (0x00000001u)

#define CSL_PCI_PCIDINTSET_SERR_DET_MASK (0x00000020u)
#define CSL_PCI_PCIDINTSET_SERR_DET_SHIFT (0x00000005u)
#define CSL_PCI_PCIDINTSET_SERR_DET_RESETVAL (0x00000000u)
/*----SERR_DET Tokens----*/
#define CSL_PCI_PCIDINTSET_SERR_DET_ENABLE (0x00000001u)


#define CSL_PCI_PCIDINTSET_MS_ABRT_DET_MASK (0x00000004u)
#define CSL_PCI_PCIDINTSET_MS_ABRT_DET_SHIFT (0x00000002u)
#define CSL_PCI_PCIDINTSET_MS_ABRT_DET_RESETVAL (0x00000000u)
/*----MS_ABRT_DET Tokens----*/
#define CSL_PCI_PCIDINTSET_MS_ABRT_DET_ENABLE (0x00000001u)

#define CSL_PCI_PCIDINTSET_TGT_ABRT_DET_MASK (0x00000002u)
#define CSL_PCI_PCIDINTSET_TGT_ABRT_DET_SHIFT (0x00000001u)
#define CSL_PCI_PCIDINTSET_TGT_ABRT_DET_RESETVAL (0x00000000u)
/*----TGT_ABRT_DET Tokens----*/
#define CSL_PCI_PCIDINTSET_TGT_ABRT_DET_ENABLE (0x00000001u)


#define CSL_PCI_PCIDINTSET_RESETVAL (0x00000000u)

/* PCIDINTCLR */


#define CSL_PCI_PCIDINTCLR_SOFT_INT3_MASK (0x08000000u)
#define CSL_PCI_PCIDINTCLR_SOFT_INT3_SHIFT (0x0000001Bu)
#define CSL_PCI_PCIDINTCLR_SOFT_INT3_RESETVAL (0x00000000u)
/*----SOFT_INT3 Tokens----*/
#define CSL_PCI_PCIDINTCLR_SOFT_INT3_DISABLE (0x00000001u)

#define CSL_PCI_PCIDINTCLR_SOFT_INT2_MASK (0x04000000u)
#define CSL_PCI_PCIDINTCLR_SOFT_INT2_SHIFT (0x0000001Au)
#define CSL_PCI_PCIDINTCLR_SOFT_INT2_RESETVAL (0x00000000u)
/*----SOFT_INT2 Tokens----*/
#define CSL_PCI_PCIDINTCLR_SOFT_INT2_DISABLE (0x00000001u)

#define CSL_PCI_PCIDINTCLR_SOFT_INT1_MASK (0x02000000u)
#define CSL_PCI_PCIDINTCLR_SOFT_INT1_SHIFT (0x00000019u)
#define CSL_PCI_PCIDINTCLR_SOFT_INT1_RESETVAL (0x00000000u)
/*----SOFT_INT1 Tokens----*/
#define CSL_PCI_PCIDINTCLR_SOFT_INT1_DISABLE (0x00000001u)

#define CSL_PCI_PCIDINTCLR_SOFT_INT0_MASK (0x01000000u)
#define CSL_PCI_PCIDINTCLR_SOFT_INT0_SHIFT (0x00000018u)
#define CSL_PCI_PCIDINTCLR_SOFT_INT0_RESETVAL (0x00000000u)
/*----SOFT_INT0 Tokens----*/
#define CSL_PCI_PCIDINTCLR_SOFT_INT0_DISABLE (0x00000001u)


#define CSL_PCI_PCIDINTCLR_PERR_DET_MASK (0x00000040u)
#define CSL_PCI_PCIDINTCLR_PERR_DET_SHIFT (0x00000006u)
#define CSL_PCI_PCIDINTCLR_PERR_DET_RESETVAL (0x00000000u)
/*----PERR_DET Tokens----*/
#define CSL_PCI_PCIDINTCLR_PERR_DET_DISABLE (0x00000001u)

#define CSL_PCI_PCIDINTCLR_SERR_DET_MASK (0x00000020u)
#define CSL_PCI_PCIDINTCLR_SERR_DET_SHIFT (0x00000005u)
#define CSL_PCI_PCIDINTCLR_SERR_DET_RESETVAL (0x00000000u)
/*----SERR_DET Tokens----*/
#define CSL_PCI_PCIDINTCLR_SERR_DET_DISABLE (0x00000001u)


#define CSL_PCI_PCIDINTCLR_MS_ABRT_DET_MASK (0x00000004u)
#define CSL_PCI_PCIDINTCLR_MS_ABRT_DET_SHIFT (0x00000002u)
#define CSL_PCI_PCIDINTCLR_MS_ABRT_DET_RESETVAL (0x00000000u)
/*----MS_ABRT_DET Tokens----*/
#define CSL_PCI_PCIDINTCLR_MS_ABRT_DET_DISABLE (0x00000001u)

#define CSL_PCI_PCIDINTCLR_TGT_ABRT_DET_MASK (0x00000002u)
#define CSL_PCI_PCIDINTCLR_TGT_ABRT_DET_SHIFT (0x00000001u)
#define CSL_PCI_PCIDINTCLR_TGT_ABRT_DET_RESETVAL (0x00000000u)
/*----TGT_ABRT_DET Tokens----*/
#define CSL_PCI_PCIDINTCLR_TGT_ABRT_DET_DISABLE (0x00000001u)


#define CSL_PCI_PCIDINTCLR_RESETVAL (0x00000000u)

/* PCIVENDEVMIR */

#define CSL_PCI_PCIVENDEVMIR_DEV_ID_MASK (0xFFFF0000u)
#define CSL_PCI_PCIVENDEVMIR_DEV_ID_SHIFT (0x00000010u)
#define CSL_PCI_PCIVENDEVMIR_DEV_ID_RESETVAL (0x0000B000u)

#define CSL_PCI_PCIVENDEVMIR_VEN_ID_MASK (0x0000FFFFu)
#define CSL_PCI_PCIVENDEVMIR_VEN_ID_SHIFT (0x00000000u)
#define CSL_PCI_PCIVENDEVMIR_VEN_ID_RESETVAL (0x0000104Cu)

#define CSL_PCI_PCIVENDEVMIR_RESETVAL (0xB000104Cu)

/* PCICSRMIR */

#define CSL_PCI_PCICSRMIR_DET_PAR_ERR_MASK (0x80000000u)
#define CSL_PCI_PCICSRMIR_DET_PAR_ERR_SHIFT (0x0000001Fu)
#define CSL_PCI_PCICSRMIR_DET_PAR_ERR_RESETVAL (0x00000000u)
#define CSL_PCI_PCICSRMIR_DET_PAR_ERR_CLEAR (0x00000001u)
#define CSL_PCI_PCICSRMIR_DET_PAR_ERR_ERROR (0x00000001u)

#define CSL_PCI_PCICSRMIR_SIG_SYS_ERR_MASK (0x40000000u)
#define CSL_PCI_PCICSRMIR_SIG_SYS_ERR_SHIFT (0x0000001Eu)
#define CSL_PCI_PCICSRMIR_SIG_SYS_ERR_RESETVAL (0x00000000u)
#define CSL_PCI_PCICSRMIR_SIG_SYS_ERR_CLEAR (0x00000001u)
#define CSL_PCI_PCICSRMIR_SIG_SYS_ERR_ERROR (0x00000001u)

#define CSL_PCI_PCICSRMIR_RCV_MS_ABRT_MASK (0x20000000u)
#define CSL_PCI_PCICSRMIR_RCV_MS_ABRT_SHIFT (0x0000001Du)
#define CSL_PCI_PCICSRMIR_RCV_MS_ABRT_RESETVAL (0x00000000u)
#define CSL_PCI_PCICSRMIR_RCV_MS_ABRT_CLEAR (0x00000001u)
#define CSL_PCI_PCICSRMIR_RCV_MS_ABRT_ERROR (0x00000001u)

#define CSL_PCI_PCICSRMIR_RCV_TGT_ABRT_MASK (0x10000000u)
#define CSL_PCI_PCICSRMIR_RCV_TGT_ABRT_SHIFT (0x0000001Cu)
#define CSL_PCI_PCICSRMIR_RCV_TGT_ABRT_RESETVAL (0x00000000u)
#define CSL_PCI_PCICSRMIR_RCV_TGT_ABRT_CLEAR (0x00000001u)
#define CSL_PCI_PCICSRMIR_RCV_TGT_ABRT_ERROR (0x00000001u)

#define CSL_PCI_PCICSRMIR_SIG_TGT_ABRT_MASK (0x08000000u)
#define CSL_PCI_PCICSRMIR_SIG_TGT_ABRT_SHIFT (0x0000001Bu)
#define CSL_PCI_PCICSRMIR_SIG_TGT_ABRT_RESETVAL (0x00000000u)
#define CSL_PCI_PCICSRMIR_SIG_TGT_ABRT_CLEAR (0x00000001u)

#define CSL_PCI_PCICSRMIR_DEVSEL_TIM_MASK (0x06000000u)
#define CSL_PCI_PCICSRMIR_DEVSEL_TIM_SHIFT (0x00000019u)
#define CSL_PCI_PCICSRMIR_DEVSEL_TIM_RESETVAL (0x00000001u)

#define CSL_PCI_PCICSRMIR_MS_DPAR_REP_MASK (0x01000000u)
#define CSL_PCI_PCICSRMIR_MS_DPAR_REP_SHIFT (0x00000018u)
#define CSL_PCI_PCICSRMIR_MS_DPAR_REP_RESETVAL (0x00000000u)

#define CSL_PCI_PCICSRMIR_FAST_BTOB_CAP_MASK (0x00800000u)
#define CSL_PCI_PCICSRMIR_FAST_BTOB_CAP_SHIFT (0x00000017u)
#define CSL_PCI_PCICSRMIR_FAST_BTOB_CAP_RESETVAL (0x00000000u)


#define CSL_PCI_PCICSRMIR_66MHZ_CAP_MASK (0x00200000u)
#define CSL_PCI_PCICSRMIR_66MHZ_CAP_SHIFT (0x00000015u)
#define CSL_PCI_PCICSRMIR_66MHZ_CAP_RESETVAL (0x00000000u)

#define CSL_PCI_PCICSRMIR_CAP_LIST_IMPL_MASK (0x00100000u)
#define CSL_PCI_PCICSRMIR_CAP_LIST_IMPL_SHIFT (0x00000014u)
#define CSL_PCI_PCICSRMIR_CAP_LIST_IMPL_RESETVAL (0x00000001u)

#define CSL_PCI_PCICSRMIR_INT_STAT_MASK (0x00080000u)
#define CSL_PCI_PCICSRMIR_INT_STAT_SHIFT (0x00000013u)
#define CSL_PCI_PCICSRMIR_INT_STAT_RESETVAL (0x00000000u)
/*----INT_STAT Tokens----*/
#define CSL_PCI_PCICSRMIR_INT_STAT_CLEARED (0x00000000u)
#define CSL_PCI_PCICSRMIR_INT_STAT_SET (0x00000001u)


#define CSL_PCI_PCICSRMIR_INT_DIS_MASK (0x00000400u)
#define CSL_PCI_PCICSRMIR_INT_DIS_SHIFT (0x0000000Au)
#define CSL_PCI_PCICSRMIR_INT_DIS_RESETVAL (0x00000000u)
/*----INT_DIS Tokens----*/
#define CSL_PCI_PCICSRMIR_INT_DIS_CLEARED (0x00000000u)
#define CSL_PCI_PCICSRMIR_INT_DIS_SET (0x00000001u)

#define CSL_PCI_PCICSRMIR_FAST_BTOB_EN_MASK (0x00000200u)
#define CSL_PCI_PCICSRMIR_FAST_BTOB_EN_SHIFT (0x00000009u)
#define CSL_PCI_PCICSRMIR_FAST_BTOB_EN_RESETVAL (0x00000000u)

#define CSL_PCI_PCICSRMIR_SERR_EN_MASK (0x00000100u)
#define CSL_PCI_PCICSRMIR_SERR_EN_SHIFT (0x00000008u)
#define CSL_PCI_PCICSRMIR_SERR_EN_RESETVAL (0x00000000u)
/*----SERR_N_EN Tokens----*/
#define CSL_PCI_PCICSRMIR_SERR_EN_CLEARED (0x00000000u)
#define CSL_PCI_PCICSRMIR_SERR_EN_SET (0x00000001u)

#define CSL_PCI_PCICSRMIR_WAITCYCLECNTL_MASK (0x00000080u)
#define CSL_PCI_PCICSRMIR_WAITCYCLECNTL_SHIFT (0x00000007u)
#define CSL_PCI_PCICSRMIR_WAITCYCLECNTL_RESETVAL (0x00000000u)

#define CSL_PCI_PCICSRMIR_PAR_ERR_RES_MASK (0x00000040u)
#define CSL_PCI_PCICSRMIR_PAR_ERR_RES_SHIFT (0x00000006u)
#define CSL_PCI_PCICSRMIR_PAR_ERR_RES_RESETVAL (0x00000000u)
/*----PAR_ERR_RES Tokens----*/
#define CSL_PCI_PCICSRMIR_PAR_ERR_RES_CLEARED (0x00000000u)
#define CSL_PCI_PCICSRMIR_PAR_ERR_RES_SET (0x00000001u)

#define CSL_PCI_PCICSRMIR_VGA_PAL_SNP_MASK (0x00000020u)
#define CSL_PCI_PCICSRMIR_VGA_PAL_SNP_SHIFT (0x00000005u)
#define CSL_PCI_PCICSRMIR_VGA_PAL_SNP_RESETVAL (0x00000000u)

#define CSL_PCI_PCICSRMIR_MEM_WRINV_EN_MASK (0x00000010u)
#define CSL_PCI_PCICSRMIR_MEM_WRINV_EN_SHIFT (0x00000004u)
#define CSL_PCI_PCICSRMIR_MEM_WRINV_EN_RESETVAL (0x00000000u)
/*----MEM_WRINV_EN Tokens----*/
#define CSL_PCI_PCICSRMIR_MEM_WRINV_EN_CLEARED (0x00000000u)
#define CSL_PCI_PCICSRMIR_MEM_WRINV_EN_SET (0x00000001u)

#define CSL_PCI_PCICSRMIR_SP_CYCL_MASK (0x00000008u)
#define CSL_PCI_PCICSRMIR_SP_CYCL_SHIFT (0x00000003u)
#define CSL_PCI_PCICSRMIR_SP_CYCL_RESETVAL (0x00000000u)
/*----SP_CYCL Tokens----*/
#define CSL_PCI_PCICSRMIR_SP_CYCL_CLEARED (0x00000000u)
#define CSL_PCI_PCICSRMIR_SP_CYCL_SET (0x00000001u)

#define CSL_PCI_PCICSRMIR_BUS_MS_MASK (0x00000004u)
#define CSL_PCI_PCICSRMIR_BUS_MS_SHIFT (0x00000002u)
#define CSL_PCI_PCICSRMIR_BUS_MS_RESETVAL (0x00000000u)
/*----BUS_MS Tokens----*/
#define CSL_PCI_PCICSRMIR_BUS_MS_SLAVE (0x00000000u)
#define CSL_PCI_PCICSRMIR_BUS_MS_MASTER (0x00000001u)

#define CSL_PCI_PCICSRMIR_MEM_SP_MASK (0x00000002u)
#define CSL_PCI_PCICSRMIR_MEM_SP_SHIFT (0x00000001u)
#define CSL_PCI_PCICSRMIR_MEM_SP_RESETVAL (0x00000000u)
/*----MEM_SP Tokens----*/
#define CSL_PCI_PCICSRMIR_MEM_SP_CLEARED (0x00000000u)
#define CSL_PCI_PCICSRMIR_MEM_SP_SET (0x00000001u)

#define CSL_PCI_PCICSRMIR_IO_SP_MASK (0x00000001u)
#define CSL_PCI_PCICSRMIR_IO_SP_SHIFT (0x00000000u)
#define CSL_PCI_PCICSRMIR_IO_SP_RESETVAL (0x00000000u)

#define CSL_PCI_PCICSRMIR_RESETVAL (0x02100000u)

/* PCICLREVMIR */

#define CSL_PCI_PCICLREVMIR_BASE_CLASS_MASK (0xFF000000u)
#define CSL_PCI_PCICLREVMIR_BASE_CLASS_SHIFT (0x00000018u)
#define CSL_PCI_PCICLREVMIR_BASE_CLASS_RESETVAL (0x00000011u)

#define CSL_PCI_PCICLREVMIR_SUB_CLASS_MASK (0x00FF0000u)
#define CSL_PCI_PCICLREVMIR_SUB_CLASS_SHIFT (0x00000010u)
#define CSL_PCI_PCICLREVMIR_SUB_CLASS_RESETVAL (0x00000080u)

#define CSL_PCI_PCICLREVMIR_REG_LVL_MASK (0x0000FF00u)
#define CSL_PCI_PCICLREVMIR_REG_LVL_SHIFT (0x00000008u)
#define CSL_PCI_PCICLREVMIR_REG_LVL_RESETVAL (0x00000000u)

#define CSL_PCI_PCICLREVMIR_REV_ID_MASK (0x000000FFu)
#define CSL_PCI_PCICLREVMIR_REV_ID_SHIFT (0x00000000u)
#define CSL_PCI_PCICLREVMIR_REV_ID_RESETVAL (0x00000001u)

#define CSL_PCI_PCICLREVMIR_RESETVAL (0x11800001u)

/* PCICLINEMIR */

#define CSL_PCI_PCICLINEMIR_BIST_MASK (0xFF000000u)
#define CSL_PCI_PCICLINEMIR_BIST_SHIFT (0x00000018u)
#define CSL_PCI_PCICLINEMIR_BIST_RESETVAL (0x00000000u)

#define CSL_PCI_PCICLINEMIR_HDR_TYPE_MASK (0x00FF0000u)
#define CSL_PCI_PCICLINEMIR_HDR_TYPE_SHIFT (0x00000010u)
#define CSL_PCI_PCICLINEMIR_HDR_TYPE_RESETVAL (0x00000000u)

#define CSL_PCI_PCICLINEMIR_LAT_TMR_MASK (0x0000FF00u)
#define CSL_PCI_PCICLINEMIR_LAT_TMR_SHIFT (0x00000008u)
#define CSL_PCI_PCICLINEMIR_LAT_TMR_RESETVAL (0x00000000u)

#define CSL_PCI_PCICLINEMIR_CACHELN_SIZ_MASK (0x000000FFu)
#define CSL_PCI_PCICLINEMIR_CACHELN_SIZ_SHIFT (0x00000000u)
#define CSL_PCI_PCICLINEMIR_CACHELN_SIZ_RESETVAL (0x00000000u)
/*----CACHELN_SIZ Tokens----*/
#define CSL_PCI_PCICLINEMIR_CACHELN_SIZ_DISABLED (0x00000000u)
#define CSL_PCI_PCICLINEMIR_CACHELN_SIZ_16BYTES (0x00000004u)
#define CSL_PCI_PCICLINEMIR_CACHELN_SIZ_32BYTES (0x00000008u)
#define CSL_PCI_PCICLINEMIR_CACHELN_SIZ_64BYTES (0x00000010u)
#define CSL_PCI_PCICLINEMIR_CACHELN_SIZ_128BYTES (0x00000020u)

#define CSL_PCI_PCICLINEMIR_RESETVAL (0x00000000u)

/* PCIBAR0MSK */

#define CSL_PCI_PCIBAR0MSK_ADDRMASK_MASK (0xFFFFFFF0u)
#define CSL_PCI_PCIBAR0MSK_ADDRMASK_SHIFT (0x00000004u)
#define CSL_PCI_PCIBAR0MSK_ADDRMASK_RESETVAL (0x0FF80000u)

#define CSL_PCI_PCIBAR0MSK_PREFETCH_EN_MASK (0x00000008u)
#define CSL_PCI_PCIBAR0MSK_PREFETCH_EN_SHIFT (0x00000003u)
#define CSL_PCI_PCIBAR0MSK_PREFETCH_EN_RESETVAL (0x00000001u)
/*----PREFETCH_EN Tokens----*/
#define CSL_PCI_PCIBAR0MSK_PREFETCH_EN_NONPREFETCH (0x00000000u)
#define CSL_PCI_PCIBAR0MSK_PREFETCH_EN_PREFETCH (0x00000001u)


#define CSL_PCI_PCIBAR0MSK_RESETVAL (0xFF800008u)

/* PCIBAR1MSK */

#define CSL_PCI_PCIBAR1MSK_ADDRMASK_MASK (0xFFFFFFF0u)
#define CSL_PCI_PCIBAR1MSK_ADDRMASK_SHIFT (0x00000004u)
#define CSL_PCI_PCIBAR1MSK_ADDRMASK_RESETVAL (0x0FFFF000u)

#define CSL_PCI_PCIBAR1MSK_PREFETCH_EN_MASK (0x00000008u)
#define CSL_PCI_PCIBAR1MSK_PREFETCH_EN_SHIFT (0x00000003u)
#define CSL_PCI_PCIBAR1MSK_PREFETCH_EN_RESETVAL (0x00000000u)
/*----PREFETCH_EN Tokens----*/
#define CSL_PCI_PCIBAR1MSK_PREFETCH_EN_NONPREFETCH (0x00000000u)
#define CSL_PCI_PCIBAR1MSK_PREFETCH_EN_PREFETCH (0x00000001u)


#define CSL_PCI_PCIBAR1MSK_RESETVAL (0xFFFF0000u)

/* PCIBAR2MSK */

#define CSL_PCI_PCIBAR2MSK_ADDRMASK_MASK (0xFFFFFFF0u)
#define CSL_PCI_PCIBAR2MSK_ADDRMASK_SHIFT (0x00000004u)
#define CSL_PCI_PCIBAR2MSK_ADDRMASK_RESETVAL (0x0FFC0000u)

#define CSL_PCI_PCIBAR2MSK_PREFETCH_EN_MASK (0x00000008u)
#define CSL_PCI_PCIBAR2MSK_PREFETCH_EN_SHIFT (0x00000003u)
#define CSL_PCI_PCIBAR2MSK_PREFETCH_EN_RESETVAL (0x00000000u)
/*----PREFETCH_EN Tokens----*/
#define CSL_PCI_PCIBAR2MSK_PREFETCH_EN_NONPREFETCH (0x00000000u)
#define CSL_PCI_PCIBAR2MSK_PREFETCH_EN_PREFETCH (0x00000001u)


#define CSL_PCI_PCIBAR2MSK_RESETVAL (0xFFC00000u)

/* PCIBAR3MSK */

#define CSL_PCI_PCIBAR3MSK_ADDRMASK_MASK (0xFFFFFFF0u)
#define CSL_PCI_PCIBAR3MSK_ADDRMASK_SHIFT (0x00000004u)
#define CSL_PCI_PCIBAR3MSK_ADDRMASK_RESETVAL (0x0FF80000u)

#define CSL_PCI_PCIBAR3MSK_PREFETCH_EN_MASK (0x00000008u)
#define CSL_PCI_PCIBAR3MSK_PREFETCH_EN_SHIFT (0x00000003u)
#define CSL_PCI_PCIBAR3MSK_PREFETCH_EN_RESETVAL (0x00000001u)
/*----PREFETCH_EN Tokens----*/
#define CSL_PCI_PCIBAR3MSK_PREFETCH_EN_NONPREFETCH (0x00000000u)
#define CSL_PCI_PCIBAR3MSK_PREFETCH_EN_PREFETCH (0x00000001u)


#define CSL_PCI_PCIBAR3MSK_RESETVAL (0xFF800008u)

/* PCIBAR4MSK */

#define CSL_PCI_PCIBAR4MSK_ADDRMASK_MASK (0xFFFFFFF0u)
#define CSL_PCI_PCIBAR4MSK_ADDRMASK_SHIFT (0x00000004u)
#define CSL_PCI_PCIBAR4MSK_ADDRMASK_RESETVAL (0x0FF80000u)

#define CSL_PCI_PCIBAR4MSK_PREFETCH_EN_MASK (0x00000008u)
#define CSL_PCI_PCIBAR4MSK_PREFETCH_EN_SHIFT (0x00000003u)
#define CSL_PCI_PCIBAR4MSK_PREFETCH_EN_RESETVAL (0x00000001u)
/*----PREFETCH_EN Tokens----*/
#define CSL_PCI_PCIBAR4MSK_PREFETCH_EN_NONPREFETCH (0x00000000u)
#define CSL_PCI_PCIBAR4MSK_PREFETCH_EN_PREFETCH (0x00000001u)


#define CSL_PCI_PCIBAR4MSK_RESETVAL (0xFF800008u)

/* PCIBAR5MSK */

#define CSL_PCI_PCIBAR5MSK_ADDRMASK_MASK (0xFFFFFFF0u)
#define CSL_PCI_PCIBAR5MSK_ADDRMASK_SHIFT (0x00000004u)
#define CSL_PCI_PCIBAR5MSK_ADDRMASK_RESETVAL (0x0FF80000u)

#define CSL_PCI_PCIBAR5MSK_PREFETCH_EN_MASK (0x00000008u)
#define CSL_PCI_PCIBAR5MSK_PREFETCH_EN_SHIFT (0x00000003u)
#define CSL_PCI_PCIBAR5MSK_PREFETCH_EN_RESETVAL (0x00000001u)
/*----PREFETCH_EN Tokens----*/
#define CSL_PCI_PCIBAR5MSK_PREFETCH_EN_NONPREFETCH (0x00000000u)
#define CSL_PCI_PCIBAR5MSK_PREFETCH_EN_PREFETCH (0x00000001u)


#define CSL_PCI_PCIBAR5MSK_RESETVAL (0xFF800008u)

/* PCISUBIDMIR */

#define CSL_PCI_PCISUBIDMIR_SUBSYS_ID_MASK (0xFFFF0000u)
#define CSL_PCI_PCISUBIDMIR_SUBSYS_ID_SHIFT (0x00000010u)
#define CSL_PCI_PCISUBIDMIR_SUBSYS_ID_RESETVAL (0x00000000u)

#define CSL_PCI_PCISUBIDMIR_SUBSYS_VEN_ID_MASK (0x0000FFFFu)
#define CSL_PCI_PCISUBIDMIR_SUBSYS_VEN_ID_SHIFT (0x00000000u)
#define CSL_PCI_PCISUBIDMIR_SUBSYS_VEN_ID_RESETVAL (0x00000000u)

#define CSL_PCI_PCISUBIDMIR_RESETVAL (0x00000000u)

/* PCICPBPTRMIR */


#define CSL_PCI_PCICPBPTRMIR_CAP_MASK (0x000000FFu)
#define CSL_PCI_PCICPBPTRMIR_CAP_SHIFT (0x00000000u)
#define CSL_PCI_PCICPBPTRMIR_CAP_RESETVAL (0x00000040u)

#define CSL_PCI_PCICPBPTRMIR_RESETVAL (0x00000040u)

/* PCILGINTMIR */

#define CSL_PCI_PCILGINTMIR_MAX_LAT_MASK (0xFF000000u)
#define CSL_PCI_PCILGINTMIR_MAX_LAT_SHIFT (0x00000018u)
#define CSL_PCI_PCILGINTMIR_MAX_LAT_RESETVAL (0x00000000u)

#define CSL_PCI_PCILGINTMIR_MIN_GRNT_MASK (0x00FF0000u)
#define CSL_PCI_PCILGINTMIR_MIN_GRNT_SHIFT (0x00000010u)
#define CSL_PCI_PCILGINTMIR_MIN_GRNT_RESETVAL (0x00000000u)

#define CSL_PCI_PCILGINTMIR_INT_PIN_MASK (0x0000FF00u)
#define CSL_PCI_PCILGINTMIR_INT_PIN_SHIFT (0x00000008u)
#define CSL_PCI_PCILGINTMIR_INT_PIN_RESETVAL (0x00000001u)

#define CSL_PCI_PCILGINTMIR_INT_LINE_MASK (0x000000FFu)
#define CSL_PCI_PCILGINTMIR_INT_LINE_SHIFT (0x00000000u)
#define CSL_PCI_PCILGINTMIR_INT_LINE_RESETVAL (0x00000000u)

#define CSL_PCI_PCILGINTMIR_RESETVAL (0x00000100u)

/* PCISLVCNTL */


#define CSL_PCI_PCISLVCNTL_BASE5_EN_MASK (0x00200000u)
#define CSL_PCI_PCISLVCNTL_BASE5_EN_SHIFT (0x00000015u)
#define CSL_PCI_PCISLVCNTL_BASE5_EN_RESETVAL (0x0000001Bu)
/*----BASE5_EN Tokens----*/
#define CSL_PCI_PCISLVCNTL_BASE5_EN_DISABLE (0x00000000u)
#define CSL_PCI_PCISLVCNTL_BASE5_EN_ENABLE (0x00000001u)

#define CSL_PCI_PCISLVCNTL_BASE4_EN_MASK (0x00100000u)
#define CSL_PCI_PCISLVCNTL_BASE4_EN_SHIFT (0x00000014u)
#define CSL_PCI_PCISLVCNTL_BASE4_EN_RESETVAL (0x0000001Bu)
/*----BASE4_EN Tokens----*/
#define CSL_PCI_PCISLVCNTL_BASE4_EN_DISABLE (0x00000000u)
#define CSL_PCI_PCISLVCNTL_BASE4_EN_ENABLE (0x00000001u)

#define CSL_PCI_PCISLVCNTL_BASE3_EN_MASK (0x00080000u)
#define CSL_PCI_PCISLVCNTL_BASE3_EN_SHIFT (0x00000013u)
#define CSL_PCI_PCISLVCNTL_BASE3_EN_RESETVAL (0x0000001Bu)
/*----BASE3_EN Tokens----*/
#define CSL_PCI_PCISLVCNTL_BASE3_EN_DISABLE (0x00000000u)
#define CSL_PCI_PCISLVCNTL_BASE3_EN_ENABLE (0x00000001u)

#define CSL_PCI_PCISLVCNTL_BASE2_EN_MASK (0x00040000u)
#define CSL_PCI_PCISLVCNTL_BASE2_EN_SHIFT (0x00000012u)
#define CSL_PCI_PCISLVCNTL_BASE2_EN_RESETVAL (0x0000001Bu)
/*----BASE2_EN Tokens----*/
#define CSL_PCI_PCISLVCNTL_BASE2_EN_DISABLE (0x00000000u)
#define CSL_PCI_PCISLVCNTL_BASE2_EN_ENABLE (0x00000001u)

#define CSL_PCI_PCISLVCNTL_BASE1_EN_MASK (0x00020000u)
#define CSL_PCI_PCISLVCNTL_BASE1_EN_SHIFT (0x00000011u)
#define CSL_PCI_PCISLVCNTL_BASE1_EN_RESETVAL (0x0000001Bu)
/*----BASE1_EN Tokens----*/
#define CSL_PCI_PCISLVCNTL_BASE1_EN_DISABLE (0x00000000u)
#define CSL_PCI_PCISLVCNTL_BASE1_EN_ENABLE (0x00000001u)

#define CSL_PCI_PCISLVCNTL_BASE0_EN_MASK (0x00010000u)
#define CSL_PCI_PCISLVCNTL_BASE0_EN_SHIFT (0x00000010u)
#define CSL_PCI_PCISLVCNTL_BASE0_EN_RESETVAL (0x0000001Bu)
/*----BASE0_EN Tokens----*/
#define CSL_PCI_PCISLVCNTL_BASE0_EN_DISABLE (0x00000000u)
#define CSL_PCI_PCISLVCNTL_BASE0_EN_ENABLE (0x00000001u)


#define CSL_PCI_PCISLVCNTL_FORCE_DEL_READ_MUL_MASK (0x00000010u)
#define CSL_PCI_PCISLVCNTL_FORCE_DEL_READ_MUL_SHIFT (0x00000004u)
#define CSL_PCI_PCISLVCNTL_FORCE_DEL_READ_MUL_RESETVAL (0x00000000u)
/*----FORCE_DEL_READ_MUL Tokens----*/
#define CSL_PCI_PCISLVCNTL_FORCE_DEL_READ_MUL_16CLK (0x00000000u)
#define CSL_PCI_PCISLVCNTL_FORCE_DEL_READ_MUL_IMMEDIATE (0x00000001u)

#define CSL_PCI_PCISLVCNTL_FORCE_DEL_READ_LN_MASK (0x00000008u)
#define CSL_PCI_PCISLVCNTL_FORCE_DEL_READ_LN_SHIFT (0x00000003u)
#define CSL_PCI_PCISLVCNTL_FORCE_DEL_READ_LN_RESETVAL (0x00000000u)
/*----FORCE_DEL_READ_LN Tokens----*/
#define CSL_PCI_PCISLVCNTL_FORCE_DEL_READ_LN_16CLK (0x00000000u)
#define CSL_PCI_PCISLVCNTL_FORCE_DEL_READ_LN_IMMEDIATE (0x00000001u)

#define CSL_PCI_PCISLVCNTL_FORCE_DEL_READ_MASK (0x00000004u)
#define CSL_PCI_PCISLVCNTL_FORCE_DEL_READ_SHIFT (0x00000002u)
#define CSL_PCI_PCISLVCNTL_FORCE_DEL_READ_RESETVAL (0x00000000u)
/*----FORCE_DEL_READ Tokens----*/
#define CSL_PCI_PCISLVCNTL_FORCE_DEL_READ_16CLK (0x00000000u)
#define CSL_PCI_PCISLVCNTL_FORCE_DEL_READ_IMMEDIATE (0x00000001u)

#define CSL_PCI_PCISLVCNTL_DIS_SLV_TOUT_MASK (0x00000002u)
#define CSL_PCI_PCISLVCNTL_DIS_SLV_TOUT_SHIFT (0x00000001u)
#define CSL_PCI_PCISLVCNTL_DIS_SLV_TOUT_RESETVAL (0x00000000u)
/*----DIS_SLV_TOUT Tokens----*/
#define CSL_PCI_PCISLVCNTL_DIS_SLV_TOUT_16CLK (0x00000000u)
#define CSL_PCI_PCISLVCNTL_DIS_SLV_TOUT_IMMEDIATE (0x00000001u)

#define CSL_PCI_PCISLVCNTL_CFG_DONE_MASK (0x00000001u)
#define CSL_PCI_PCISLVCNTL_CFG_DONE_SHIFT (0x00000000u)
#define CSL_PCI_PCISLVCNTL_CFG_DONE_RESETVAL (0x00000000u)
/*----CFG_DONE Tokens----*/
#define CSL_PCI_PCISLVCNTL_CFG_DONE_PROGRESS (0x00000000u)
#define CSL_PCI_PCISLVCNTL_CFG_DONE_COMPLETE (0x00000001u)

#define CSL_PCI_PCISLVCNTL_RESETVAL (0x003F0000u)

/* PCIBAR0TRL */

#define CSL_PCI_PCIBAR0TRL_TRANS_ADDR_MASK (0xFFFFFFF0u)
#define CSL_PCI_PCIBAR0TRL_TRANS_ADDR_SHIFT (0x00000004u)
#define CSL_PCI_PCIBAR0TRL_TRANS_ADDR_RESETVAL (0x01080000u)


#define CSL_PCI_PCIBAR0TRL_RESETVAL (0x10800000u)

/* PCIBAR1TRL */

#define CSL_PCI_PCIBAR1TRL_TRANS_ADDR_MASK (0xFFFFFFF0u)
#define CSL_PCI_PCIBAR1TRL_TRANS_ADDR_SHIFT (0x00000004u)
#define CSL_PCI_PCIBAR1TRL_TRANS_ADDR_RESETVAL (0x02000000u)


#define CSL_PCI_PCIBAR1TRL_RESETVAL (0x20000000u)

/* PCIBAR2TRL */

#define CSL_PCI_PCIBAR2TRL_TRANS_ADDR_MASK (0xFFFFFFF0u)
#define CSL_PCI_PCIBAR2TRL_TRANS_ADDR_SHIFT (0x00000004u)
#define CSL_PCI_PCIBAR2TRL_TRANS_ADDR_RESETVAL (0x001C0000u)


#define CSL_PCI_PCIBAR2TRL_RESETVAL (0x01C00000u)

/* PCIBAR3TRL */

#define CSL_PCI_PCIBAR3TRL_TRANS_ADDR_MASK (0xFFFFFFF0u)
#define CSL_PCI_PCIBAR3TRL_TRANS_ADDR_SHIFT (0x00000004u)
#define CSL_PCI_PCIBAR3TRL_TRANS_ADDR_RESETVAL (0x01080000u)


#define CSL_PCI_PCIBAR3TRL_RESETVAL (0x10800000u)

/* PCIBAR4TRL */

#define CSL_PCI_PCIBAR4TRL_TRANS_ADDR_MASK (0xFFFFFFF0u)
#define CSL_PCI_PCIBAR4TRL_TRANS_ADDR_SHIFT (0x00000004u)
#define CSL_PCI_PCIBAR4TRL_TRANS_ADDR_RESETVAL (0x01080000u)


#define CSL_PCI_PCIBAR4TRL_RESETVAL (0x10800000u)

/* PCIBAR5TRL */

#define CSL_PCI_PCIBAR5TRL_TRANS_ADDR_MASK (0xFFFFFFF0u)
#define CSL_PCI_PCIBAR5TRL_TRANS_ADDR_SHIFT (0x00000004u)
#define CSL_PCI_PCIBAR5TRL_TRANS_ADDR_RESETVAL (0x08000000u)


#define CSL_PCI_PCIBAR5TRL_RESETVAL (0x80000000u)

/* PCIBAR0MIR */

#define CSL_PCI_PCIBAR0MIR_ADDR_MASK (0xFFFFFFF0u)
#define CSL_PCI_PCIBAR0MIR_ADDR_SHIFT (0x00000004u)
#define CSL_PCI_PCIBAR0MIR_ADDR_RESETVAL (0x00000000u)

#define CSL_PCI_PCIBAR0MIR_PREFETCH_MASK (0x00000008u)
#define CSL_PCI_PCIBAR0MIR_PREFETCH_SHIFT (0x00000003u)
#define CSL_PCI_PCIBAR0MIR_PREFETCH_RESETVAL (0x00000001u)
/*----PREFETCH Tokens----*/
#define CSL_PCI_PCIBAR0MIR_PREFETCH_NONPREFETCH (0x00000000u)
#define CSL_PCI_PCIBAR0MIR_PREFETCH_PREFETCH (0x00000001u)

#define CSL_PCI_PCIBAR0MIR_TYPE_MASK (0x00000006u)
#define CSL_PCI_PCIBAR0MIR_TYPE_SHIFT (0x00000001u)
#define CSL_PCI_PCIBAR0MIR_TYPE_RESETVAL (0x00000000u)

#define CSL_PCI_PCIBAR0MIR_IOMEM_SP_IND_MASK (0x00000001u)
#define CSL_PCI_PCIBAR0MIR_IOMEM_SP_IND_SHIFT (0x00000000u)
#define CSL_PCI_PCIBAR0MIR_IOMEM_SP_IND_RESETVAL (0x00000000u)

#define CSL_PCI_PCIBAR0MIR_RESETVAL (0x00000008u)

/* PCIBAR1MIR */

#define CSL_PCI_PCIBAR1MIR_ADDR_MASK (0xFFFFFFF0u)
#define CSL_PCI_PCIBAR1MIR_ADDR_SHIFT (0x00000004u)
#define CSL_PCI_PCIBAR1MIR_ADDR_RESETVAL (0x00000000u)

#define CSL_PCI_PCIBAR1MIR_PREFETCH_MASK (0x00000008u)
#define CSL_PCI_PCIBAR1MIR_PREFETCH_SHIFT (0x00000003u)
#define CSL_PCI_PCIBAR1MIR_PREFETCH_RESETVAL (0x00000000u)
/*----PREFETCH Tokens----*/
#define CSL_PCI_PCIBAR1MIR_PREFETCH_NONPREFETCH (0x00000000u)
#define CSL_PCI_PCIBAR1MIR_PREFETCH_PREFETCH (0x00000001u)

#define CSL_PCI_PCIBAR1MIR_TYPE_MASK (0x00000006u)
#define CSL_PCI_PCIBAR1MIR_TYPE_SHIFT (0x00000001u)
#define CSL_PCI_PCIBAR1MIR_TYPE_RESETVAL (0x00000000u)

#define CSL_PCI_PCIBAR1MIR_IOMEM_SP_IND_MASK (0x00000001u)
#define CSL_PCI_PCIBAR1MIR_IOMEM_SP_IND_SHIFT (0x00000000u)
#define CSL_PCI_PCIBAR1MIR_IOMEM_SP_IND_RESETVAL (0x00000000u)

#define CSL_PCI_PCIBAR1MIR_RESETVAL (0x00000000u)

/* PCIBAR2MIR */

#define CSL_PCI_PCIBAR2MIR_ADDR_MASK (0xFFFFFFF0u)
#define CSL_PCI_PCIBAR2MIR_ADDR_SHIFT (0x00000004u)
#define CSL_PCI_PCIBAR2MIR_ADDR_RESETVAL (0x00000000u)

#define CSL_PCI_PCIBAR2MIR_PREFETCH_MASK (0x00000008u)
#define CSL_PCI_PCIBAR2MIR_PREFETCH_SHIFT (0x00000003u)
#define CSL_PCI_PCIBAR2MIR_PREFETCH_RESETVAL (0x00000000u)
/*----PREFETCH Tokens----*/
#define CSL_PCI_PCIBAR2MIR_PREFETCH_NONPREFETCH (0x00000000u)
#define CSL_PCI_PCIBAR2MIR_PREFETCH_PREFETCH (0x00000001u)

#define CSL_PCI_PCIBAR2MIR_TYPE_MASK (0x00000006u)
#define CSL_PCI_PCIBAR2MIR_TYPE_SHIFT (0x00000001u)
#define CSL_PCI_PCIBAR2MIR_TYPE_RESETVAL (0x00000000u)

#define CSL_PCI_PCIBAR2MIR_IOMEM_SP_IND_MASK (0x00000001u)
#define CSL_PCI_PCIBAR2MIR_IOMEM_SP_IND_SHIFT (0x00000000u)
#define CSL_PCI_PCIBAR2MIR_IOMEM_SP_IND_RESETVAL (0x00000000u)

#define CSL_PCI_PCIBAR2MIR_RESETVAL (0x00000000u)

/* PCIBAR3MIR */

#define CSL_PCI_PCIBAR3MIR_ADDR_MASK (0xFFFFFFF0u)
#define CSL_PCI_PCIBAR3MIR_ADDR_SHIFT (0x00000004u)
#define CSL_PCI_PCIBAR3MIR_ADDR_RESETVAL (0x00000000u)

#define CSL_PCI_PCIBAR3MIR_PREFETCH_MASK (0x00000008u)
#define CSL_PCI_PCIBAR3MIR_PREFETCH_SHIFT (0x00000003u)
#define CSL_PCI_PCIBAR3MIR_PREFETCH_RESETVAL (0x00000001u)
/*----PREFETCH Tokens----*/
#define CSL_PCI_PCIBAR3MIR_PREFETCH_NONPREFETCH (0x00000000u)
#define CSL_PCI_PCIBAR3MIR_PREFETCH_PREFETCH (0x00000001u)

#define CSL_PCI_PCIBAR3MIR_TYPE_MASK (0x00000006u)
#define CSL_PCI_PCIBAR3MIR_TYPE_SHIFT (0x00000001u)
#define CSL_PCI_PCIBAR3MIR_TYPE_RESETVAL (0x00000000u)

#define CSL_PCI_PCIBAR3MIR_IOMEM_SP_IND_MASK (0x00000001u)
#define CSL_PCI_PCIBAR3MIR_IOMEM_SP_IND_SHIFT (0x00000000u)
#define CSL_PCI_PCIBAR3MIR_IOMEM_SP_IND_RESETVAL (0x00000000u)

#define CSL_PCI_PCIBAR3MIR_RESETVAL (0x00000008u)

/* PCIBAR4MIR */

#define CSL_PCI_PCIBAR4MIR_ADDR_MASK (0xFFFFFFF0u)
#define CSL_PCI_PCIBAR4MIR_ADDR_SHIFT (0x00000004u)
#define CSL_PCI_PCIBAR4MIR_ADDR_RESETVAL (0x00000000u)

#define CSL_PCI_PCIBAR4MIR_PREFETCH_MASK (0x00000008u)
#define CSL_PCI_PCIBAR4MIR_PREFETCH_SHIFT (0x00000003u)
#define CSL_PCI_PCIBAR4MIR_PREFETCH_RESETVAL (0x00000001u)
/*----PREFETCH Tokens----*/
#define CSL_PCI_PCIBAR4MIR_PREFETCH_NONPREFETCH (0x00000000u)
#define CSL_PCI_PCIBAR4MIR_PREFETCH_PREFETCH (0x00000001u)

#define CSL_PCI_PCIBAR4MIR_TYPE_MASK (0x00000006u)
#define CSL_PCI_PCIBAR4MIR_TYPE_SHIFT (0x00000001u)
#define CSL_PCI_PCIBAR4MIR_TYPE_RESETVAL (0x00000000u)

#define CSL_PCI_PCIBAR4MIR_IOMEM_SP_IND_MASK (0x00000001u)
#define CSL_PCI_PCIBAR4MIR_IOMEM_SP_IND_SHIFT (0x00000000u)
#define CSL_PCI_PCIBAR4MIR_IOMEM_SP_IND_RESETVAL (0x00000000u)

#define CSL_PCI_PCIBAR4MIR_RESETVAL (0x00000008u)

/* PCIBAR5MIR */

#define CSL_PCI_PCIBAR5MIR_ADDR_MASK (0xFFFFFFF0u)
#define CSL_PCI_PCIBAR5MIR_ADDR_SHIFT (0x00000004u)
#define CSL_PCI_PCIBAR5MIR_ADDR_RESETVAL (0x00000000u)

#define CSL_PCI_PCIBAR5MIR_PREFETCH_MASK (0x00000008u)
#define CSL_PCI_PCIBAR5MIR_PREFETCH_SHIFT (0x00000003u)
#define CSL_PCI_PCIBAR5MIR_PREFETCH_RESETVAL (0x00000001u)
/*----PREFETCH Tokens----*/
#define CSL_PCI_PCIBAR5MIR_PREFETCH_NONPREFETCH (0x00000000u)
#define CSL_PCI_PCIBAR5MIR_PREFETCH_PREFETCH (0x00000001u)

#define CSL_PCI_PCIBAR5MIR_TYPE_MASK (0x00000006u)
#define CSL_PCI_PCIBAR5MIR_TYPE_SHIFT (0x00000001u)
#define CSL_PCI_PCIBAR5MIR_TYPE_RESETVAL (0x00000000u)

#define CSL_PCI_PCIBAR5MIR_IOMEM_SP_IND_MASK (0x00000001u)
#define CSL_PCI_PCIBAR5MIR_IOMEM_SP_IND_SHIFT (0x00000000u)
#define CSL_PCI_PCIBAR5MIR_IOMEM_SP_IND_RESETVAL (0x00000000u)

#define CSL_PCI_PCIBAR5MIR_RESETVAL (0x00000008u)

/* PCIMCFGDAT */

#define CSL_PCI_PCIMCFGDAT_DATA_MASK (0xFFFFFFFFu)
#define CSL_PCI_PCIMCFGDAT_DATA_SHIFT (0x00000000u)
#define CSL_PCI_PCIMCFGDAT_DATA_RESETVAL (0x00000000u)

#define CSL_PCI_PCIMCFGDAT_RESETVAL (0x00000000u)

/* PCIMCFGADR */

#define CSL_PCI_PCIMCFGADR_ADDR_MASK (0xFFFFFFFFu)
#define CSL_PCI_PCIMCFGADR_ADDR_SHIFT (0x00000000u)
#define CSL_PCI_PCIMCFGADR_ADDR_RESETVAL (0x00000000u)

#define CSL_PCI_PCIMCFGADR_RESETVAL (0x00000000u)

/* PCIMCFGCMD */

#define CSL_PCI_PCIMCFGCMD_READY_MASK (0x80000000u)
#define CSL_PCI_PCIMCFGCMD_READY_SHIFT (0x0000001Fu)
#define CSL_PCI_PCIMCFGCMD_READY_RESETVAL (0x00000001u)
/*----READY Tokens----*/
#define CSL_PCI_PCIMCFGCMD_READY_NOTREADY (0x00000000u)
#define CSL_PCI_PCIMCFGCMD_READY_READY (0x00000001u)


#define CSL_PCI_PCIMCFGCMD_BYTE_EN_MASK (0x000000F0u)
#define CSL_PCI_PCIMCFGCMD_BYTE_EN_SHIFT (0x00000004u)
#define CSL_PCI_PCIMCFGCMD_BYTE_EN_RESETVAL (0x00000000u)


#define CSL_PCI_PCIMCFGCMD_TYPE_MASK (0x00000004u)
#define CSL_PCI_PCIMCFGCMD_TYPE_SHIFT (0x00000002u)
#define CSL_PCI_PCIMCFGCMD_TYPE_RESETVAL (0x00000000u)
/*----TYPE Tokens----*/
#define CSL_PCI_PCIMCFGCMD_TYPE_CONFIG_SPACE (0x00000000u)
#define CSL_PCI_PCIMCFGCMD_TYPE_IO_SPACE (0x00000001u)


#define CSL_PCI_PCIMCFGCMD_RD_WR_MASK (0x00000001u)
#define CSL_PCI_PCIMCFGCMD_RD_WR_SHIFT (0x00000000u)
#define CSL_PCI_PCIMCFGCMD_RD_WR_RESETVAL (0x00000000u)
/*----RD_WR Tokens----*/
#define CSL_PCI_PCIMCFGCMD_RD_WR_WRITE (0x00000000u)
#define CSL_PCI_PCIMCFGCMD_RD_WR_READ (0x00000001u)

#define CSL_PCI_PCIMCFGCMD_RESETVAL (0x80000000u)

/* PCIMSTCFG */


#define CSL_PCI_PCIMSTCFG_CFG_FLUSH_IF_NOT_ENABLED_MASK (0x00000400u)
#define CSL_PCI_PCIMSTCFG_CFG_FLUSH_IF_NOT_ENABLED_SHIFT (0x0000000Au)
#define CSL_PCI_PCIMSTCFG_CFG_FLUSH_IF_NOT_ENABLED_RESETVAL (0x00000000u)
/*----CFG_FLUSH_IF_NOT_ENABLED  Tokens----*/
#define CSL_PCI_PCIMSTCFG_CFG_FLUSH_IF_NOT_ENABLED_NO_FLUSH (0x00000000u)
#define CSL_PCI_PCIMSTCFG_CFG_FLUSH_IF_NOT_ENABLED_FLUSH (0x00000001u)

#define CSL_PCI_PCIMSTCFG_IO_FLUSH_IF_NOT_ENABLED_MASK (0x00000200u)
#define CSL_PCI_PCIMSTCFG_IO_FLUSH_IF_NOT_ENABLED_SHIFT (0x00000009u)
#define CSL_PCI_PCIMSTCFG_IO_FLUSH_IF_NOT_ENABLED_RESETVAL (0x00000000u)
/*----IO_FLUSH_IF_NOT_ENABLED  Tokens----*/
#define CSL_PCI_PCIMSTCFG_IO_FLUSH_IF_NOT_ENABLED_NO_FLUSH (0x00000000u)
#define CSL_PCI_PCIMSTCFG_IO_FLUSH_IF_NOT_ENABLED_FLUSH (0x00000001u)

#define CSL_PCI_PCIMSTCFG_MEM_FLUSH_IF_NOT_ENABLED_MASK (0x00000100u)
#define CSL_PCI_PCIMSTCFG_MEM_FLUSH_IF_NOT_ENABLED_SHIFT (0x00000008u)
#define CSL_PCI_PCIMSTCFG_MEM_FLUSH_IF_NOT_ENABLED_RESETVAL (0x00000000u)
/*----MEM_FLUSH_IF_NOT_ENABLED  Tokens----*/
#define CSL_PCI_PCIMSTCFG_MEM_FLUSH_IF_NOT_ENABLED_NO_FLUSH (0x00000000u)
#define CSL_PCI_PCIMSTCFG_MEM_FLUSH_IF_NOT_ENABLED_FLUSH (0x00000001u)


#define CSL_PCI_PCIMSTCFG_SW_MEM_RD_MULT_EN_MASK (0x00000004u)
#define CSL_PCI_PCIMSTCFG_SW_MEM_RD_MULT_EN_SHIFT (0x00000002u)
#define CSL_PCI_PCIMSTCFG_SW_MEM_RD_MULT_EN_RESETVAL (0x00000001u)
/*----SW_MEM_RD_MULT_EN  Tokens----*/
#define CSL_PCI_PCIMSTCFG_SW_MEM_RD_MULT_EN_DISABLE_MRM (0x00000000u)
#define CSL_PCI_PCIMSTCFG_SW_MEM_RD_MULT_EN_ENABLE_MRM (0x00000001u)

#define CSL_PCI_PCIMSTCFG_SW_MEM_RD_LINE_EN_MASK (0x00000002u)
#define CSL_PCI_PCIMSTCFG_SW_MEM_RD_LINE_EN_SHIFT (0x00000001u)
#define CSL_PCI_PCIMSTCFG_SW_MEM_RD_LINE_EN_RESETVAL (0x00000001u)
/*----SW_MEM_RD_LINE_EN  Tokens----*/
#define CSL_PCI_PCIMSTCFG_SW_MEM_RD_LINE_EN_DISABLE_MRL (0x00000000u)
#define CSL_PCI_PCIMSTCFG_SW_MEM_RD_LINE_EN_ENABLE_MRL (0x00000001u)

#define CSL_PCI_PCIMSTCFG_SW_MEM_RD_WRINV_EN_MASK (0x00000001u)
#define CSL_PCI_PCIMSTCFG_SW_MEM_RD_WRINV_EN_SHIFT (0x00000000u)
#define CSL_PCI_PCIMSTCFG_SW_MEM_RD_WRINV_EN_RESETVAL (0x00000001u)
/*----SW_MEM_RD_WRINV_EN  Tokens----*/
#define CSL_PCI_PCIMSTCFG_SW_MEM_RD_WRINV_EN_DISABLE_MWI (0x00000000u)
#define CSL_PCI_PCIMSTCFG_SW_MEM_RD_WRINV_EN_ENABLE_MWI (0x00000001u)

#define CSL_PCI_PCIMSTCFG_RESETVAL (0x00000007u)

/* PCIADDSUB */

#define CSL_PCI_PCIADDSUB_ADD_SUBS_MASK (0xFF800000u)
#define CSL_PCI_PCIADDSUB_ADD_SUBS_SHIFT (0x00000017u)
#define CSL_PCI_PCIADDSUB_ADD_SUBS_RESETVAL (0x00000000u)


#define CSL_PCI_PCIADDSUB_RESETVAL (0x00000000u)

/* PCIVENDEVPRG */

#define CSL_PCI_PCIVENDEVPRG_VENDOR_DEVICE_ID_PROG_MASK (0xFFFFFFFFu)
#define CSL_PCI_PCIVENDEVPRG_VENDOR_DEVICE_ID_PROG_SHIFT (0x00000000u)
#define CSL_PCI_PCIVENDEVPRG_VENDOR_DEVICE_ID_PROG_RESETVAL (0xB001104Cu)

#define CSL_PCI_PCIVENDEVPRG_RESETVAL (0x00000000u)

/* PCICLREVPRG */

#define CSL_PCI_PCICLREVPRG_CLASS_CODE_REV_ID_PROG_MASK (0xFFFFFFFFu)
#define CSL_PCI_PCICLREVPRG_CLASS_CODE_REV_ID_PROG_SHIFT (0x00000000u)
#define CSL_PCI_PCICLREVPRG_CLASS_CODE_REV_ID_PROG_RESETVAL (0x11800001u)

#define CSL_PCI_PCICLREVPRG_RESETVAL (0x11800001u)

/* PCISUBIDPRG */

#define CSL_PCI_PCISUBIDPRG_SUBSYS_VENDOR_ID_SUBSYS_ID_PROG_MASK (0xFFFFFFFFu)
#define CSL_PCI_PCISUBIDPRG_SUBSYS_VENDOR_ID_SUBSYS_ID_PROG_SHIFT (0x00000000u)
#define CSL_PCI_PCISUBIDPRG_SUBSYS_VENDOR_ID_SUBSYS_ID_PROG_RESETVAL (0x00000000u)

#define CSL_PCI_PCISUBIDPRG_RESETVAL (0x00000000u)

/* PCIMAXLGPRG */


#define CSL_PCI_PCIMAXLGPRG_MAX_LAT_MIN_GRANT_PROG_MASK (0x0000FFFFu)
#define CSL_PCI_PCIMAXLGPRG_MAX_LAT_MIN_GRANT_PROG_SHIFT (0x00000000u)
#define CSL_PCI_PCIMAXLGPRG_MAX_LAT_MIN_GRANT_PROG_RESETVAL (0x00000000u)

#define CSL_PCI_PCIMAXLGPRG_RESETVAL (0x00000000u)

/* PCICFGDONE */


#define CSL_PCI_PCICFGDONE_CONFIG_DONE_MASK (0x00000001u)
#define CSL_PCI_PCICFGDONE_CONFIG_DONE_SHIFT (0x00000000u)
#define CSL_PCI_PCICFGDONE_CONFIG_DONE_RESETVAL (0x00000000u)
/*----CONFIG_DONE Tokens----*/
#define CSL_PCI_PCICFGDONE_CONFIG_DONE_PROGRESS (0x00000000u)
#define CSL_PCI_PCICFGDONE_CONFIG_DONE_COMPLETE (0x00000001u)

#define CSL_PCI_PCICFGDONE_RESETVAL (0x00000000u)

#ifdef __cplusplus
}
#endif

#endif

