/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005, 2006, 2007
 *
 *   Use of this software is controlled by the terms and conditions found in the
 *   license agreement under which this software has been supplied.
 *   ===========================================================================
 */
/** ============================================================================
 *   @file  cslr_pllc2.h
 *
 *   @path  $(CSLPATH)\inc
 *
 *   @desc  This file contains the Register Descriptions for PLLC2
 *  ============================================================================
 */
#ifndef _CSLR_PLLC2_H_
#define _CSLR_PLLC2_H_

#ifdef __cplusplus
extern "C" {
#endif

#include <ti/sdo/pspdrivers/soc/dm648/dsp/cslr.h>
#include <ti/sdo/pspdrivers/soc/dm648/dsp/tistdtypes.h>


/* Minimum unit = 1 byte */

/**************************************************************************\
* Register Overlay Structure
\**************************************************************************/
typedef struct  {
    volatile Uint32 PID;
    volatile Uint8 RSVD0[224];
    volatile Uint32 RSTYPE;
    volatile Uint8 RSVD1[24];
    volatile Uint32 PLLCTL;
    volatile Uint8 RSVD2[12];
    volatile Uint32 PLLM;
    volatile Uint8 RSVD3[4];
    volatile Uint32 PLLDIV1;
    volatile Uint32 PLLDIV2;
    volatile Uint32 PLLDIV3;
    volatile Uint32 OSCDIV1;
    volatile Uint8 RSVD4[4];
    volatile Uint32 BPDIV;
    volatile Uint8 RSVD5[8];
    volatile Uint32 PLLCMD;
    volatile Uint32 PLLSTAT;
    volatile Uint32 ALNCTL;
    volatile Uint32 DCHANGE;
    volatile Uint32 CKEN;
    volatile Uint32 CKSTAT;
    volatile Uint32 SYSTAT;
} CSL_Pllc2Regs;

/**************************************************************************\
* Overlay structure typedef definition
\**************************************************************************/
typedef volatile CSL_Pllc2Regs         *CSL_Pllc2RegsOvly;

/**************************************************************************\
* Field Definition Macros
\**************************************************************************/

/* PID */


#define CSL_PLLC2_PID_TYPE_MASK (0x00FF0000u)
#define CSL_PLLC2_PID_TYPE_SHIFT (0x00000010u)
#define CSL_PLLC2_PID_TYPE_RESETVAL (0x00000001u)

#define CSL_PLLC2_PID_CLASS_MASK (0x0000FF00u)
#define CSL_PLLC2_PID_CLASS_SHIFT (0x00000008u)
#define CSL_PLLC2_PID_CLASS_RESETVAL (0x00000008u)

#define CSL_PLLC2_PID_REV_MASK (0x000000FFu)
#define CSL_PLLC2_PID_REV_SHIFT (0x00000000u)
#define CSL_PLLC2_PID_REV_RESETVAL (0x0000000Du)

#define CSL_PLLC2_PID_RESETVAL (0x0001080Du)

/* RSTYPE */


#define CSL_PLLC2_RSTYPE_MRST_MASK (0x00000004u)
#define CSL_PLLC2_RSTYPE_MRST_SHIFT (0x00000002u)
#define CSL_PLLC2_RSTYPE_MRST_RESETVAL (0x00000000u)
/*----MRST Tokens----*/
#define CSL_PLLC2_RSTYPE_MRST_NO (0x00000000u)
#define CSL_PLLC2_RSTYPE_MRST_YES (0x00000001u)

#define CSL_PLLC2_RSTYPE_XWRST_MASK (0x00000002u)
#define CSL_PLLC2_RSTYPE_XWRST_SHIFT (0x00000001u)
#define CSL_PLLC2_RSTYPE_XWRST_RESETVAL (0x00000000u)
/*----XWRST Tokens----*/
#define CSL_PLLC2_RSTYPE_XWRST_NO (0x00000000u)
#define CSL_PLLC2_RSTYPE_XWRST_YES (0x00000001u)

#define CSL_PLLC2_RSTYPE_POR_MASK (0x00000001u)
#define CSL_PLLC2_RSTYPE_POR_SHIFT (0x00000000u)
#define CSL_PLLC2_RSTYPE_POR_RESETVAL (0x00000000u)
/*----POR Tokens----*/
#define CSL_PLLC2_RSTYPE_POR_NO (0x00000000u)
#define CSL_PLLC2_RSTYPE_POR_YES (0x00000001u)

#define CSL_PLLC2_RSTYPE_RESETVAL (0x00000000u)

/* PLLCTL */


#define CSL_PLLC2_PLLCTL_CLKMODE_MASK (0x00000100u)
#define CSL_PLLC2_PLLCTL_CLKMODE_SHIFT (0x00000008u)
#define CSL_PLLC2_PLLCTL_CLKMODE_RESETVAL (0x00000000u)
/*----CLKMODE Tokens----*/
#define CSL_PLLC2_PLLCTL_CLKMODE_OSCIN (0x00000000u)
#define CSL_PLLC2_PLLCTL_CLKMODE_CLKIN (0x00000001u)


#define CSL_PLLC2_PLLCTL_PLLENSRC_MASK (0x00000020u)
#define CSL_PLLC2_PLLCTL_PLLENSRC_SHIFT (0x00000005u)
#define CSL_PLLC2_PLLCTL_PLLENSRC_RESETVAL (0x00000001u)
/*----PLLENSRC Tokens----*/
#define CSL_PLLC2_PLLCTL_PLLENSRC_CLEAR (0x00000000u)

#define CSL_PLLC2_PLLCTL_PLLDIS_MASK (0x00000010u)
#define CSL_PLLC2_PLLCTL_PLLDIS_SHIFT (0x00000004u)
#define CSL_PLLC2_PLLCTL_PLLDIS_RESETVAL (0x00000001u)
/*----PLLDIS Tokens----*/
#define CSL_PLLC2_PLLCTL_PLLDIS_DEASSERT (0x00000000u)
#define CSL_PLLC2_PLLCTL_PLLDIS_ASSERT (0x00000001u)

#define CSL_PLLC2_PLLCTL_PLLRST_MASK (0x00000008u)
#define CSL_PLLC2_PLLCTL_PLLRST_SHIFT (0x00000003u)
#define CSL_PLLC2_PLLCTL_PLLRST_RESETVAL (0x00000000u)
/*----PLLRST Tokens----*/
#define CSL_PLLC2_PLLCTL_PLLRST_ASSERT (0x00000000u)
#define CSL_PLLC2_PLLCTL_PLLRST_DEASSERT (0x00000001u)


#define CSL_PLLC2_PLLCTL_PLLPWRDN_MASK (0x00000002u)
#define CSL_PLLC2_PLLCTL_PLLPWRDN_SHIFT (0x00000001u)
#define CSL_PLLC2_PLLCTL_PLLPWRDN_RESETVAL (0x00000001u)
/*----PLLPWRDN Tokens----*/
#define CSL_PLLC2_PLLCTL_PLLPWRDN_DISABLE (0x00000000u)
#define CSL_PLLC2_PLLCTL_PLLPWRDN_ENABLE (0x00000001u)
#define CSL_PLLC2_PLLCTL_PLLPWRDN_POWERED_UP (0x00000000u)
#define CSL_PLLC2_PLLCTL_PLLPWRDN_POWERED_DOWN (0x00000001u)

#define CSL_PLLC2_PLLCTL_PLLEN_MASK (0x00000001u)
#define CSL_PLLC2_PLLCTL_PLLEN_SHIFT (0x00000000u)
#define CSL_PLLC2_PLLCTL_PLLEN_RESETVAL (0x00000000u)
/*----PLLEN Tokens----*/
#define CSL_PLLC2_PLLCTL_PLLEN_BYPASS (0x00000000u)
#define CSL_PLLC2_PLLCTL_PLLEN_PLL (0x00000001u)

#define CSL_PLLC2_PLLCTL_RESETVAL (0x00000072u)

/* PLLM */


#define CSL_PLLC2_PLLM_PLLM_MASK (0x0000001Fu)
#define CSL_PLLC2_PLLM_PLLM_SHIFT (0x00000000u)
#define CSL_PLLC2_PLLM_PLLM_RESETVAL (0x00000010u)

#define CSL_PLLC2_PLLM_RESETVAL (0x00000010u)

/* PLLDIV1 */


#define CSL_PLLC2_PLLDIV1_D1EN_MASK (0x00008000u)
#define CSL_PLLC2_PLLDIV1_D1EN_SHIFT (0x0000000Fu)
#define CSL_PLLC2_PLLDIV1_D1EN_RESETVAL (0x00000000u)
/*----D1EN Tokens----*/
#define CSL_PLLC2_PLLDIV1_D1EN_DISABLE (0x00000000u)
#define CSL_PLLC2_PLLDIV1_D1EN_ENABLE (0x00000001u)


#define CSL_PLLC2_PLLDIV1_RATIO_MASK (0x0000001Fu)
#define CSL_PLLC2_PLLDIV1_RATIO_SHIFT (0x00000000u)
#define CSL_PLLC2_PLLDIV1_RATIO_RESETVAL (0x00000000u)

#define CSL_PLLC2_PLLDIV1_RESETVAL (0x00000000u)

/* PLLDIV2 */


#define CSL_PLLC2_PLLDIV2_D2EN_MASK (0x00008000u)
#define CSL_PLLC2_PLLDIV2_D2EN_SHIFT (0x0000000Fu)
#define CSL_PLLC2_PLLDIV2_D2EN_RESETVAL (0x00000001u)
/*----D2EN Tokens----*/
#define CSL_PLLC2_PLLDIV2_D2EN_DISABLE (0x00000000u)
#define CSL_PLLC2_PLLDIV2_D2EN_ENABLE (0x00000001u)


#define CSL_PLLC2_PLLDIV2_RATIO_MASK (0x0000001Fu)
#define CSL_PLLC2_PLLDIV2_RATIO_SHIFT (0x00000000u)
#define CSL_PLLC2_PLLDIV2_RATIO_RESETVAL (0x00000002u)

#define CSL_PLLC2_PLLDIV2_RESETVAL (0x00008002u)

/* PLLDIV3 */


#define CSL_PLLC2_PLLDIV3_D3EN_MASK (0x00008000u)
#define CSL_PLLC2_PLLDIV3_D3EN_SHIFT (0x0000000Fu)
#define CSL_PLLC2_PLLDIV3_D3EN_RESETVAL (0x00000001u)
/*----D3EN Tokens----*/
#define CSL_PLLC2_PLLDIV3_D3EN_DISABLE (0x00000000u)
#define CSL_PLLC2_PLLDIV3_D3EN_ENABLE (0x00000001u)


#define CSL_PLLC2_PLLDIV3_RATIO_MASK (0x0000001Fu)
#define CSL_PLLC2_PLLDIV3_RATIO_SHIFT (0x00000000u)
#define CSL_PLLC2_PLLDIV3_RATIO_RESETVAL (0x00000005u)

#define CSL_PLLC2_PLLDIV3_RESETVAL (0x00008005u)

/* OSCDIV1 */


#define CSL_PLLC2_OSCDIV1_OD1EN_MASK (0x00008000u)
#define CSL_PLLC2_OSCDIV1_OD1EN_SHIFT (0x0000000Fu)
#define CSL_PLLC2_OSCDIV1_OD1EN_RESETVAL (0x00000001u)
/*----OD1EN Tokens----*/
#define CSL_PLLC2_OSCDIV1_OD1EN_DISABLE (0x00000000u)
#define CSL_PLLC2_OSCDIV1_OD1EN_ENABLE (0x00000001u)


#define CSL_PLLC2_OSCDIV1_RATIO_MASK (0x0000001Fu)
#define CSL_PLLC2_OSCDIV1_RATIO_SHIFT (0x00000000u)
#define CSL_PLLC2_OSCDIV1_RATIO_RESETVAL (0x00000000u)

#define CSL_PLLC2_OSCDIV1_RESETVAL (0x00008000u)

/* BPDIV */


#define CSL_PLLC2_BPDIV_BPDEN_MASK (0x00008000u)
#define CSL_PLLC2_BPDIV_BPDEN_SHIFT (0x0000000Fu)
#define CSL_PLLC2_BPDIV_BPDEN_RESETVAL (0x00000001u)
/*----BPDEN Tokens----*/
#define CSL_PLLC2_BPDIV_BPDEN_DISABLE (0x00000000u)
#define CSL_PLLC2_BPDIV_BPDEN_ENABLE (0x00000001u)


#define CSL_PLLC2_BPDIV_RATIO_MASK (0x0000001Fu)
#define CSL_PLLC2_BPDIV_RATIO_SHIFT (0x00000000u)
#define CSL_PLLC2_BPDIV_RATIO_RESETVAL (0x00000000u)

#define CSL_PLLC2_BPDIV_RESETVAL (0x00008000u)

/* PLLCMD */


#define CSL_PLLC2_PLLCMD_GOSET_MASK (0x00000001u)
#define CSL_PLLC2_PLLCMD_GOSET_SHIFT (0x00000000u)
#define CSL_PLLC2_PLLCMD_GOSET_RESETVAL (0x00000000u)
/*----GOSET Tokens----*/
#define CSL_PLLC2_PLLCMD_GOSET_CLRBIT (0x00000000u)
#define CSL_PLLC2_PLLCMD_GOSET_PHASE_ALIGN (0x00000001u)

#define CSL_PLLC2_PLLCMD_RESETVAL (0x00000000u)

/* PLLSTAT */


#define CSL_PLLC2_PLLSTAT_STABLE_MASK (0x00000004u)
#define CSL_PLLC2_PLLSTAT_STABLE_SHIFT (0x00000002u)
#define CSL_PLLC2_PLLSTAT_STABLE_RESETVAL (0x00000000u)
/*----STABLE Tokens----*/
#define CSL_PLLC2_PLLSTAT_STABLE_OSC_NOT_STABLE (0x00000000u)
#define CSL_PLLC2_PLLSTAT_STABLE_OSC_STABLE (0x00000001u)


#define CSL_PLLC2_PLLSTAT_GOSTAT_MASK (0x00000001u)
#define CSL_PLLC2_PLLSTAT_GOSTAT_SHIFT (0x00000000u)
#define CSL_PLLC2_PLLSTAT_GOSTAT_RESETVAL (0x00000000u)
/*----GOSTAT Tokens----*/
#define CSL_PLLC2_PLLSTAT_GOSTAT_NONE (0x00000000u)
#define CSL_PLLC2_PLLSTAT_GOSTAT_INPROG (0x00000001u)

#define CSL_PLLC2_PLLSTAT_RESETVAL (0x00000000u)

/* ALNCTL */


#define CSL_PLLC2_ALNCTL_ALN3_MASK (0x00000004u)
#define CSL_PLLC2_ALNCTL_ALN3_SHIFT (0x00000002u)
#define CSL_PLLC2_ALNCTL_ALN3_RESETVAL (0x00000001u)
/*----ALN3 Tokens----*/
#define CSL_PLLC2_ALNCTL_ALN3_NO (0x00000000u)
#define CSL_PLLC2_ALNCTL_ALN3_YES (0x00000001u)

#define CSL_PLLC2_ALNCTL_ALN2_MASK (0x00000002u)
#define CSL_PLLC2_ALNCTL_ALN2_SHIFT (0x00000001u)
#define CSL_PLLC2_ALNCTL_ALN2_RESETVAL (0x00000001u)
/*----ALN2 Tokens----*/
#define CSL_PLLC2_ALNCTL_ALN2_NO (0x00000000u)
#define CSL_PLLC2_ALNCTL_ALN2_YES (0x00000001u)

#define CSL_PLLC2_ALNCTL_ALN1_MASK (0x00000001u)
#define CSL_PLLC2_ALNCTL_ALN1_SHIFT (0x00000000u)
#define CSL_PLLC2_ALNCTL_ALN1_RESETVAL (0x00000001u)
/*----ALN1 Tokens----*/
#define CSL_PLLC2_ALNCTL_ALN1_NO (0x00000000u)
#define CSL_PLLC2_ALNCTL_ALN1_YES (0x00000001u)

#define CSL_PLLC2_ALNCTL_RESETVAL (0x0000001Fu)

/* DCHANGE */


#define CSL_PLLC2_DCHANGE_SYS3_MASK (0x00000004u)
#define CSL_PLLC2_DCHANGE_SYS3_SHIFT (0x00000002u)
#define CSL_PLLC2_DCHANGE_SYS3_RESETVAL (0x00000000u)
/*----SYS3 Tokens----*/
#define CSL_PLLC2_DCHANGE_SYS3_NO (0x00000000u)
#define CSL_PLLC2_DCHANGE_SYS3_YES (0x00000001u)

#define CSL_PLLC2_DCHANGE_SYS2_MASK (0x00000002u)
#define CSL_PLLC2_DCHANGE_SYS2_SHIFT (0x00000001u)
#define CSL_PLLC2_DCHANGE_SYS2_RESETVAL (0x00000000u)
/*----SYS2 Tokens----*/
#define CSL_PLLC2_DCHANGE_SYS2_NO (0x00000000u)
#define CSL_PLLC2_DCHANGE_SYS2_YES (0x00000001u)

#define CSL_PLLC2_DCHANGE_SYS1_MASK (0x00000001u)
#define CSL_PLLC2_DCHANGE_SYS1_SHIFT (0x00000000u)
#define CSL_PLLC2_DCHANGE_SYS1_RESETVAL (0x00000000u)
/*----SYS1 Tokens----*/
#define CSL_PLLC2_DCHANGE_SYS1_NO (0x00000000u)
#define CSL_PLLC2_DCHANGE_SYS1_YES (0x00000001u)

#define CSL_PLLC2_DCHANGE_RESETVAL (0x00000000u)

/* CKEN */


#define CSL_PLLC2_CKEN_OBSEN_MASK (0x00000002u)
#define CSL_PLLC2_CKEN_OBSEN_SHIFT (0x00000001u)
#define CSL_PLLC2_CKEN_OBSEN_RESETVAL (0x00000001u)
/*----OBSEN Tokens----*/
#define CSL_PLLC2_CKEN_OBSEN_DISABLE (0x00000000u)
#define CSL_PLLC2_CKEN_OBSEN_ENABLE (0x00000001u)

#define CSL_PLLC2_CKEN_AUXEN_MASK (0x00000001u)
#define CSL_PLLC2_CKEN_AUXEN_SHIFT (0x00000000u)
#define CSL_PLLC2_CKEN_AUXEN_RESETVAL (0x00000001u)
/*----AUXEN Tokens----*/
#define CSL_PLLC2_CKEN_AUXEN_DISABLE (0x00000000u)
#define CSL_PLLC2_CKEN_AUXEN_ENABLE (0x00000001u)

#define CSL_PLLC2_CKEN_RESETVAL (0x00000003u)

/* CKSTAT */


#define CSL_PLLC2_CKSTAT_BPON_MASK (0x00000008u)
#define CSL_PLLC2_CKSTAT_BPON_SHIFT (0x00000003u)
#define CSL_PLLC2_CKSTAT_BPON_RESETVAL (0x00000001u)
/*----BPON Tokens----*/
#define CSL_PLLC2_CKSTAT_BPON_OFF (0x00000000u)
#define CSL_PLLC2_CKSTAT_BPON_ON (0x00000001u)


#define CSL_PLLC2_CKSTAT_OBSEN_MASK (0x00000002u)
#define CSL_PLLC2_CKSTAT_OBSEN_SHIFT (0x00000001u)
#define CSL_PLLC2_CKSTAT_OBSEN_RESETVAL (0x00000001u)
/*----OBSEN Tokens----*/
#define CSL_PLLC2_CKSTAT_OBSEN_OFF (0x00000000u)
#define CSL_PLLC2_CKSTAT_OBSEN_ON (0x00000001u)

#define CSL_PLLC2_CKSTAT_AUXEN_MASK (0x00000001u)
#define CSL_PLLC2_CKSTAT_AUXEN_SHIFT (0x00000000u)
#define CSL_PLLC2_CKSTAT_AUXEN_RESETVAL (0x00000001u)
/*----AUXEN Tokens----*/
#define CSL_PLLC2_CKSTAT_AUXEN_OFF (0x00000000u)
#define CSL_PLLC2_CKSTAT_AUXEN_ON (0x00000001u)

#define CSL_PLLC2_CKSTAT_RESETVAL (0x0000000Bu)

/* SYSTAT */


#define CSL_PLLC2_SYSTAT_SYS3ON_MASK (0x00000004u)
#define CSL_PLLC2_SYSTAT_SYS3ON_SHIFT (0x00000002u)
#define CSL_PLLC2_SYSTAT_SYS3ON_RESETVAL (0x00000001u)
/*----SYS3ON Tokens----*/
#define CSL_PLLC2_SYSTAT_SYS3ON_OFF (0x00000000u)
#define CSL_PLLC2_SYSTAT_SYS3ON_ON (0x00000001u)

#define CSL_PLLC2_SYSTAT_SYS2ON_MASK (0x00000002u)
#define CSL_PLLC2_SYSTAT_SYS2ON_SHIFT (0x00000001u)
#define CSL_PLLC2_SYSTAT_SYS2ON_RESETVAL (0x00000001u)
/*----SYS2ON Tokens----*/
#define CSL_PLLC2_SYSTAT_SYS2ON_OFF (0x00000000u)
#define CSL_PLLC2_SYSTAT_SYS2ON_ON (0x00000001u)

#define CSL_PLLC2_SYSTAT_SYS1ON_MASK (0x00000001u)
#define CSL_PLLC2_SYSTAT_SYS1ON_SHIFT (0x00000000u)
#define CSL_PLLC2_SYSTAT_SYS1ON_RESETVAL (0x00000001u)
/*----SYS1ON Tokens----*/
#define CSL_PLLC2_SYSTAT_SYS1ON_OFF (0x00000000u)
#define CSL_PLLC2_SYSTAT_SYS1ON_ON (0x00000001u)

#define CSL_PLLC2_SYSTAT_RESETVAL (0x00000007u)


#ifdef __cplusplus
}
#endif

#endif

