/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005, 2006, 2007
 *
 *   Use of this software is controlled by the terms and conditions found in the
 *   license agreement under which this software has been supplied.
 *   ===========================================================================
 */
/** ============================================================================
 *   @file  cslr_spi.h
 *
 *   @path  $(CSLPATH)\inc
 *
 *   @desc  This file contains the Register Descriptions for SPI
 *
 *  ============================================================================
 */
#ifndef _CSLR_SPI_H_
#define _CSLR_SPI_H_

#ifdef __cplusplus
extern "C" {
#endif

#include <ti/sdo/pspdrivers/soc/dm648/dsp/cslr.h>
#include <ti/sdo/pspdrivers/soc/dm648/dsp/tistdtypes.h>


/* Minimum unit = 1 byte */

/**************************************************************************\
* Register Overlay Structure
\**************************************************************************/
typedef struct  {
    volatile Uint32 SPIGCR0;
    volatile Uint32 SPIGCR1;
    volatile Uint32 SPIINT0;
    volatile Uint32 SPILVL;
    volatile Uint32 SPIFLG;
    volatile Uint32 SPIPC0;
    volatile Uint32 SPIPC1;
    volatile Uint32 SPIPC2;
    volatile Uint32 SPIPC3;
    volatile Uint32 SPIPC4;
    volatile Uint32 SPIPC5;
    volatile Uint32 SPIPC6;
    volatile Uint32 SPIPC7;
    volatile Uint32 SPIPC8;
    volatile Uint32 SPIDAT0;
    volatile Uint32 SPIDAT1;
    volatile Uint32 SPIBUF;
    volatile Uint32 SPIEMU;
    volatile Uint32 SPIDELAY;
    volatile Uint32 SPIDEF;
    volatile Uint32 SPIFMT[4];
    volatile Uint32 TGINTVECT[2];
} CSL_SpiRegs;

/**************************************************************************\
* Overlay structure typedef definition
\**************************************************************************/
typedef volatile CSL_SpiRegs         *CSL_SpiRegsOvly;

/**************************************************************************\
* Field Definition Macros
\**************************************************************************/

/* SPIGCR0 */


#define CSL_SPI_SPIGCR0_RESET_MASK (0x00000001u)
#define CSL_SPI_SPIGCR0_RESET_SHIFT (0x00000000u)
#define CSL_SPI_SPIGCR0_RESET_RESETVAL (0x00000000u)
/*----RESET Tokens----*/
#define CSL_SPI_SPIGCR0_RESET_IN_RESET (0x00000000u)
#define CSL_SPI_SPIGCR0_RESET_OUT_OF_RESET (0x00000001u)

#define CSL_SPI_SPIGCR0_RESETVAL (0x00000000u)

/* SPIGCR1 */


#define CSL_SPI_SPIGCR1_SPIEN_MASK (0x01000000u)
#define CSL_SPI_SPIGCR1_SPIEN_SHIFT (0x00000018u)
#define CSL_SPI_SPIGCR1_SPIEN_RESETVAL (0x00000000u)
/*----SPIEN Tokens----*/
#define CSL_SPI_SPIGCR1_SPIEN_DISABLED (0x00000000u)
#define CSL_SPI_SPIGCR1_SPIEN_ENABLED (0x00000001u)


#define CSL_SPI_SPIGCR1_LOOPBACK_MASK (0x00010000u)
#define CSL_SPI_SPIGCR1_LOOPBACK_SHIFT (0x00000010u)
#define CSL_SPI_SPIGCR1_LOOPBACK_RESETVAL (0x00000000u)
/*----LOOPBACK Tokens----*/
#define CSL_SPI_SPIGCR1_LOOPBACK_DISABLE (0x00000000u)
#define CSL_SPI_SPIGCR1_LOOPBACK_ENABLE (0x00000001u)


#define CSL_SPI_SPIGCR1_POWERDOWN_MASK (0x00000100u)
#define CSL_SPI_SPIGCR1_POWERDOWN_SHIFT (0x00000008u)
#define CSL_SPI_SPIGCR1_POWERDOWN_RESETVAL (0x00000000u)
/*----POWERDOWN Tokens----*/
#define CSL_SPI_SPIGCR1_POWERDOWN_ACTIVE (0x00000000u)
#define CSL_SPI_SPIGCR1_POWERDOWN_POWERDOWN (0x00000001u)


#define CSL_SPI_SPIGCR1_CLKMOD_MASK (0x00000002u)
#define CSL_SPI_SPIGCR1_CLKMOD_SHIFT (0x00000001u)
#define CSL_SPI_SPIGCR1_CLKMOD_RESETVAL (0x00000000u)
/*----CLKMOD Tokens----*/
#define CSL_SPI_SPIGCR1_CLKMOD_EXTERNAL (0x00000000u)
#define CSL_SPI_SPIGCR1_CLKMOD_INTERNAL (0x00000001u)

#define CSL_SPI_SPIGCR1_MASTER_MASK (0x00000001u)
#define CSL_SPI_SPIGCR1_MASTER_SHIFT (0x00000000u)
#define CSL_SPI_SPIGCR1_MASTER_RESETVAL (0x00000000u)
/*----MASTER Tokens----*/
#define CSL_SPI_SPIGCR1_MASTER_SPISIMO_OUTPUT_SPISOMI_OUTPUT (0x00000000u)
#define CSL_SPI_SPIGCR1_MASTER_SPISOMI_INPUT_SPISIMO_OUTPUT (0x00000001u)

#define CSL_SPI_SPIGCR1_RESETVAL (0x00000000u)

/* SPIINT0 */


#define CSL_SPI_SPIINT0_ENABLEHIGHZ_MASK (0x01000000u)
#define CSL_SPI_SPIINT0_ENABLEHIGHZ_SHIFT (0x00000018u)
#define CSL_SPI_SPIINT0_ENABLEHIGHZ_RESETVAL (0x00000000u)
/*----ENABLEHIGHZ Tokens----*/
#define CSL_SPI_SPIINT0_ENABLEHIGHZ_SPIENA_VALUE (0x00000000u)
#define CSL_SPI_SPIINT0_ENABLEHIGHZ_SPIENA_HIZ (0x00000001u)


#define CSL_SPI_SPIINT0_DMAREQEN_MASK (0x00010000u)
#define CSL_SPI_SPIINT0_DMAREQEN_SHIFT (0x00000010u)
#define CSL_SPI_SPIINT0_DMAREQEN_RESETVAL (0x00000000u)
/*----DMAREQEN Tokens----*/
#define CSL_SPI_SPIINT0_DMAREQEN_DISABLED (0x00000000u)
#define CSL_SPI_SPIINT0_DMAREQEN_ENABLED (0x00000001u)


#define CSL_SPI_SPIINT0_RXINTEN_MASK (0x00000100u)
#define CSL_SPI_SPIINT0_RXINTEN_SHIFT (0x00000008u)
#define CSL_SPI_SPIINT0_RXINTEN_RESETVAL (0x00000000u)
/*----RXINTEN Tokens----*/
#define CSL_SPI_SPIINT0_RXINTEN_DISABLED (0x00000000u)
#define CSL_SPI_SPIINT0_RXINTEN_ENABLED (0x00000001u)


#define CSL_SPI_SPIINT0_OVRNINTEN_MASK (0x00000040u)
#define CSL_SPI_SPIINT0_OVRNINTEN_SHIFT (0x00000006u)
#define CSL_SPI_SPIINT0_OVRNINTEN_RESETVAL (0x00000000u)
/*----OVRNINTEN Tokens----*/
#define CSL_SPI_SPIINT0_OVRNINTEN_DISABLED (0x00000000u)
#define CSL_SPI_SPIINT0_OVRNINTEN_ENABLED (0x00000001u)


#define CSL_SPI_SPIINT0_BITERRENA_MASK (0x00000010u)
#define CSL_SPI_SPIINT0_BITERRENA_SHIFT (0x00000004u)
#define CSL_SPI_SPIINT0_BITERRENA_RESETVAL (0x00000000u)
/*----BITERRENA Tokens----*/
#define CSL_SPI_SPIINT0_BITERRENA_DISABLED (0x00000000u)
#define CSL_SPI_SPIINT0_BITERRENA_ENABLED (0x00000001u)

#define CSL_SPI_SPIINT0_DESYNCENA_MASK (0x00000008u)
#define CSL_SPI_SPIINT0_DESYNCENA_SHIFT (0x00000003u)
#define CSL_SPI_SPIINT0_DESYNCENA_RESETVAL (0x00000000u)
/*----DESYNCENA Tokens----*/
#define CSL_SPI_SPIINT0_DESYNCENA_DISABLED (0x00000000u)
#define CSL_SPI_SPIINT0_DESYNCENA_ENABLED (0x00000001u)

#define CSL_SPI_SPIINT0_PARERRENA_MASK (0x00000004u)
#define CSL_SPI_SPIINT0_PARERRENA_SHIFT (0x00000002u)
#define CSL_SPI_SPIINT0_PARERRENA_RESETVAL (0x00000000u)
/*----PARERRENA Tokens----*/
#define CSL_SPI_SPIINT0_PARERRENA_DISABLED (0x00000000u)
#define CSL_SPI_SPIINT0_PARERRENA_ENABLED (0x00000001u)

#define CSL_SPI_SPIINT0_TIMEOUTENA_MASK (0x00000002u)
#define CSL_SPI_SPIINT0_TIMEOUTENA_SHIFT (0x00000001u)
#define CSL_SPI_SPIINT0_TIMEOUTENA_RESETVAL (0x00000000u)
/*----TIMEOUTENA Tokens----*/
#define CSL_SPI_SPIINT0_TIMEOUTENA_DISABLED (0x00000000u)
#define CSL_SPI_SPIINT0_TIMEOUTENA_ENABLED (0x00000001u)


#define CSL_SPI_SPIINT0_RESETVAL (0x00000000u)

/* SPILVL */


#define CSL_SPI_SPILVL_RXINTLVL_MASK (0x00000100u)
#define CSL_SPI_SPILVL_RXINTLVL_SHIFT (0x00000008u)
#define CSL_SPI_SPILVL_RXINTLVL_RESETVAL (0x00000000u)
/*----RXINTLVL Tokens----*/
#define CSL_SPI_SPILVL_RXINTLVL_RCV_INT0 (0x00000000u)
#define CSL_SPI_SPILVL_RXINTLVL_RCV_INT1 (0x00000001u)


#define CSL_SPI_SPILVL_OVRNINTLVL_MASK (0x00000040u)
#define CSL_SPI_SPILVL_OVRNINTLVL_SHIFT (0x00000006u)
#define CSL_SPI_SPILVL_OVRNINTLVL_RESETVAL (0x00000000u)
/*----OVRNINTLVL Tokens----*/
#define CSL_SPI_SPILVL_OVRNINTLVL_RCV_INT0 (0x00000000u)
#define CSL_SPI_SPILVL_OVRNINTLVL_RCV_INT1 (0x00000001u)


#define CSL_SPI_SPILVL_BITERRLVL_MASK (0x00000010u)
#define CSL_SPI_SPILVL_BITERRLVL_SHIFT (0x00000004u)
#define CSL_SPI_SPILVL_BITERRLVL_RESETVAL (0x00000000u)
/*----BITERRLVL Tokens----*/
#define CSL_SPI_SPILVL_BITERRLVL_INT0 (0x00000000u)
#define CSL_SPI_SPILVL_BITERRLVL_INT1 (0x00000001u)

#define CSL_SPI_SPILVL_DESYNCLVL_MASK (0x00000008u)
#define CSL_SPI_SPILVL_DESYNCLVL_SHIFT (0x00000003u)
#define CSL_SPI_SPILVL_DESYNCLVL_RESETVAL (0x00000000u)
/*----DESYNCLVL Tokens----*/
#define CSL_SPI_SPILVL_DESYNCLVL_INT0 (0x00000000u)
#define CSL_SPI_SPILVL_DESYNCLVL_INT1 (0x00000001u)

#define CSL_SPI_SPILVL_PARERRLVL_MASK (0x00000004u)
#define CSL_SPI_SPILVL_PARERRLVL_SHIFT (0x00000002u)
#define CSL_SPI_SPILVL_PARERRLVL_RESETVAL (0x00000000u)
/*----PARERRLVL Tokens----*/
#define CSL_SPI_SPILVL_PARERRLVL_INT0 (0x00000000u)
#define CSL_SPI_SPILVL_PARERRLVL_INT1 (0x00000001u)

#define CSL_SPI_SPILVL_TIMEOUTLVL_MASK (0x00000002u)
#define CSL_SPI_SPILVL_TIMEOUTLVL_SHIFT (0x00000001u)
#define CSL_SPI_SPILVL_TIMEOUTLVL_RESETVAL (0x00000000u)
/*----TIMEOUTLVL Tokens----*/
#define CSL_SPI_SPILVL_TIMEOUTLVL_INT0 (0x00000000u)
#define CSL_SPI_SPILVL_TIMEOUTLVL_INT1 (0x00000001u)


#define CSL_SPI_SPILVL_RESETVAL (0x00000000u)

/* SPIFLG */


#define CSL_SPI_SPIFLG_RXINTFLAG_MASK (0x00000100u)
#define CSL_SPI_SPIFLG_RXINTFLAG_SHIFT (0x00000008u)
#define CSL_SPI_SPIFLG_RXINTFLAG_RESETVAL (0x00000000u)
/*----RXINTFLAG Tokens----*/
#define CSL_SPI_SPIFLG_RXINTFLAG_ENABLED (0x00000000u)
#define CSL_SPI_SPIFLG_RXINTFLAG_DISABLED (0x00000001u)


#define CSL_SPI_SPIFLG_RCVROVRN_MASK (0x00000040u)
#define CSL_SPI_SPIFLG_RCVROVRN_SHIFT (0x00000006u)
#define CSL_SPI_SPIFLG_RCVROVRN_RESETVAL (0x00000000u)
/*----RCVROVRN Tokens----*/
#define CSL_SPI_SPIFLG_RCVROVRN_ENABLED (0x00000000u)
#define CSL_SPI_SPIFLG_RCVROVRN_DISABLED (0x00000001u)


#define CSL_SPI_SPIFLG_BITERR_MASK (0x00000010u)
#define CSL_SPI_SPIFLG_BITERR_SHIFT (0x00000004u)
#define CSL_SPI_SPIFLG_BITERR_RESETVAL (0x00000000u)
/*----BITERR Tokens----*/
#define CSL_SPI_SPIFLG_BITERR_NO_ERROR (0x00000000u)
#define CSL_SPI_SPIFLG_BITERR_ERROR (0x00000001u)

#define CSL_SPI_SPIFLG_DESYNC_MASK (0x00000008u)
#define CSL_SPI_SPIFLG_DESYNC_SHIFT (0x00000003u)
#define CSL_SPI_SPIFLG_DESYNC_RESETVAL (0x00000000u)
/*----DESYNC Tokens----*/
#define CSL_SPI_SPIFLG_DESYNC_ENABLED (0x00000000u)
#define CSL_SPI_SPIFLG_DESYNC_DISABLED (0x00000001u)

#define CSL_SPI_SPIFLG_PARITYERR_MASK (0x00000004u)
#define CSL_SPI_SPIFLG_PARITYERR_SHIFT (0x00000002u)
#define CSL_SPI_SPIFLG_PARITYERR_RESETVAL (0x00000000u)
/*----PARITYERR Tokens----*/
#define CSL_SPI_SPIFLG_PARITYERR_NO_ERROR (0x00000000u)
#define CSL_SPI_SPIFLG_PARITYERR_ERROR (0x00000001u)

#define CSL_SPI_SPIFLG_TIMEOUT_MASK (0x00000002u)
#define CSL_SPI_SPIFLG_TIMEOUT_SHIFT (0x00000001u)
#define CSL_SPI_SPIFLG_TIMEOUT_RESETVAL (0x00000000u)
/*----TIMEOUT Tokens----*/
#define CSL_SPI_SPIFLG_TIMEOUT_DISABLED (0x00000000u)
#define CSL_SPI_SPIFLG_TIMEOUT_ENABLED (0x00000001u)


#define CSL_SPI_SPIFLG_RESETVAL (0x00000000u)

/* SPIPC0 */


#define CSL_SPI_SPIPC0_SOMIFUN_MASK (0x00000800u)
#define CSL_SPI_SPIPC0_SOMIFUN_SHIFT (0x0000000Bu)
#define CSL_SPI_SPIPC0_SOMIFUN_RESETVAL (0x00000000u)
/*----SOMIFUN Tokens----*/
#define CSL_SPI_SPIPC0_SOMIFUN_GPIO (0x00000000u)
#define CSL_SPI_SPIPC0_SOMIFUN_SPI (0x00000001u)

#define CSL_SPI_SPIPC0_SIMOFUN_MASK (0x00000400u)
#define CSL_SPI_SPIPC0_SIMOFUN_SHIFT (0x0000000Au)
#define CSL_SPI_SPIPC0_SIMOFUN_RESETVAL (0x00000000u)
/*----SIMOFUN Tokens----*/
#define CSL_SPI_SPIPC0_SIMOFUN_GPIO (0x00000000u)
#define CSL_SPI_SPIPC0_SIMOFUN_SPI (0x00000001u)

#define CSL_SPI_SPIPC0_CLKFUN_MASK (0x00000200u)
#define CSL_SPI_SPIPC0_CLKFUN_SHIFT (0x00000009u)
#define CSL_SPI_SPIPC0_CLKFUN_RESETVAL (0x00000000u)
/*----CLKFUN Tokens----*/
#define CSL_SPI_SPIPC0_CLKFUN_GPIO (0x00000000u)
#define CSL_SPI_SPIPC0_CLKFUN_SPI (0x00000001u)

#define CSL_SPI_SPIPC0_ENAFUN_MASK (0x00000100u)
#define CSL_SPI_SPIPC0_ENAFUN_SHIFT (0x00000008u)
#define CSL_SPI_SPIPC0_ENAFUN_RESETVAL (0x00000000u)
/*----ENAFUN Tokens----*/
#define CSL_SPI_SPIPC0_ENAFUN_GPIO (0x00000000u)
#define CSL_SPI_SPIPC0_ENAFUN_SPI (0x00000001u)

#define CSL_SPI_SPIPC0_SCSFUN7_MASK (0x00000080u)
#define CSL_SPI_SPIPC0_SCSFUN7_SHIFT (0x00000007u)
#define CSL_SPI_SPIPC0_SCSFUN7_RESETVAL (0x00000000u)
/*----SCSFUN7 Tokens----*/
#define CSL_SPI_SPIPC0_SCSFUN7_GPIO (0x00000000u)
#define CSL_SPI_SPIPC0_SCSFUN7_SPI (0x00000001u)

#define CSL_SPI_SPIPC0_SCSFUN6_MASK (0x00000040u)
#define CSL_SPI_SPIPC0_SCSFUN6_SHIFT (0x00000006u)
#define CSL_SPI_SPIPC0_SCSFUN6_RESETVAL (0x00000000u)
/*----SCSFUN6 Tokens----*/
#define CSL_SPI_SPIPC0_SCSFUN6_GPIO (0x00000000u)
#define CSL_SPI_SPIPC0_SCSFUN6_SPI (0x00000001u)

#define CSL_SPI_SPIPC0_SCSFUN5_MASK (0x00000020u)
#define CSL_SPI_SPIPC0_SCSFUN5_SHIFT (0x00000005u)
#define CSL_SPI_SPIPC0_SCSFUN5_RESETVAL (0x00000000u)
/*----SCSFUN5 Tokens----*/
#define CSL_SPI_SPIPC0_SCSFUN5_GPIO (0x00000000u)
#define CSL_SPI_SPIPC0_SCSFUN5_SPI (0x00000001u)

#define CSL_SPI_SPIPC0_SCSFUN4_MASK (0x00000010u)
#define CSL_SPI_SPIPC0_SCSFUN4_SHIFT (0x00000004u)
#define CSL_SPI_SPIPC0_SCSFUN4_RESETVAL (0x00000000u)
/*----SCSFUN4 Tokens----*/
#define CSL_SPI_SPIPC0_SCSFUN4_GPIO (0x00000000u)
#define CSL_SPI_SPIPC0_SCSFUN4_SPI (0x00000001u)

#define CSL_SPI_SPIPC0_SCSFUN3_MASK (0x00000008u)
#define CSL_SPI_SPIPC0_SCSFUN3_SHIFT (0x00000003u)
#define CSL_SPI_SPIPC0_SCSFUN3_RESETVAL (0x00000000u)
/*----SCSFUN3 Tokens----*/
#define CSL_SPI_SPIPC0_SCSFUN3_GPIO (0x00000000u)
#define CSL_SPI_SPIPC0_SCSFUN3_SPI (0x00000001u)

#define CSL_SPI_SPIPC0_SCSFUN2_MASK (0x00000004u)
#define CSL_SPI_SPIPC0_SCSFUN2_SHIFT (0x00000002u)
#define CSL_SPI_SPIPC0_SCSFUN2_RESETVAL (0x00000000u)
/*----SCSFUN2 Tokens----*/
#define CSL_SPI_SPIPC0_SCSFUN2_GPIO (0x00000000u)
#define CSL_SPI_SPIPC0_SCSFUN2_SPI (0x00000001u)

#define CSL_SPI_SPIPC0_SCSFUN1_MASK (0x00000002u)
#define CSL_SPI_SPIPC0_SCSFUN1_SHIFT (0x00000001u)
#define CSL_SPI_SPIPC0_SCSFUN1_RESETVAL (0x00000000u)
/*----SCSFUN1 Tokens----*/
#define CSL_SPI_SPIPC0_SCSFUN1_GPIO (0x00000000u)
#define CSL_SPI_SPIPC0_SCSFUN1_SPI (0x00000001u)

#define CSL_SPI_SPIPC0_SCSFUN0_MASK (0x00000001u)
#define CSL_SPI_SPIPC0_SCSFUN0_SHIFT (0x00000000u)
#define CSL_SPI_SPIPC0_SCSFUN0_RESETVAL (0x00000000u)
/*----SCSFUN0 Tokens----*/
#define CSL_SPI_SPIPC0_SCSFUN0_GPIO (0x00000000u)
#define CSL_SPI_SPIPC0_SCSFUN0_SPI (0x00000001u)

#define CSL_SPI_SPIPC0_RESETVAL (0x00000000u)

/* SPIPC1 */


#define CSL_SPI_SPIPC1_SOMIDIR_MASK (0x00000800u)
#define CSL_SPI_SPIPC1_SOMIDIR_SHIFT (0x0000000Bu)
#define CSL_SPI_SPIPC1_SOMIDIR_RESETVAL (0x00000000u)
/*----SOMIDIR Tokens----*/
#define CSL_SPI_SPIPC1_SOMIDIR_INPUT (0x00000000u)
#define CSL_SPI_SPIPC1_SOMIDIR_OUTPUT (0x00000001u)

#define CSL_SPI_SPIPC1_SIMODIR_MASK (0x00000400u)
#define CSL_SPI_SPIPC1_SIMODIR_SHIFT (0x0000000Au)
#define CSL_SPI_SPIPC1_SIMODIR_RESETVAL (0x00000000u)
/*----SIMODIR Tokens----*/
#define CSL_SPI_SPIPC1_SIMODIR_INPUT (0x00000000u)
#define CSL_SPI_SPIPC1_SIMODIR_OUTPUT (0x00000001u)

#define CSL_SPI_SPIPC1_CLKDIR_MASK (0x00000200u)
#define CSL_SPI_SPIPC1_CLKDIR_SHIFT (0x00000009u)
#define CSL_SPI_SPIPC1_CLKDIR_RESETVAL (0x00000000u)
/*----CLKDIR Tokens----*/
#define CSL_SPI_SPIPC1_CLKDIR_INPUT (0x00000000u)
#define CSL_SPI_SPIPC1_CLKDIR_OUTPUT (0x00000001u)

#define CSL_SPI_SPIPC1_ENADIR_MASK (0x00000100u)
#define CSL_SPI_SPIPC1_ENADIR_SHIFT (0x00000008u)
#define CSL_SPI_SPIPC1_ENADIR_RESETVAL (0x00000000u)
/*----ENADIR Tokens----*/
#define CSL_SPI_SPIPC1_ENADIR_INPUT (0x00000000u)
#define CSL_SPI_SPIPC1_ENADIR_OUTPUT (0x00000001u)

#define CSL_SPI_SPIPC1_SCSDIR7_MASK (0x00000080u)
#define CSL_SPI_SPIPC1_SCSDIR7_SHIFT (0x00000007u)
#define CSL_SPI_SPIPC1_SCSDIR7_RESETVAL (0x00000000u)
/*----SCSDIR7 Tokens----*/
#define CSL_SPI_SPIPC1_SCSDIR7_INPUT (0x00000000u)
#define CSL_SPI_SPIPC1_SCSDIR7_OUTPUT (0x00000001u)

#define CSL_SPI_SPIPC1_SCSDIR6_MASK (0x00000040u)
#define CSL_SPI_SPIPC1_SCSDIR6_SHIFT (0x00000006u)
#define CSL_SPI_SPIPC1_SCSDIR6_RESETVAL (0x00000000u)
/*----SCSDIR6 Tokens----*/
#define CSL_SPI_SPIPC1_SCSDIR6_INPUT (0x00000000u)
#define CSL_SPI_SPIPC1_SCSDIR6_OUTPUT (0x00000001u)

#define CSL_SPI_SPIPC1_SCSDIR5_MASK (0x00000020u)
#define CSL_SPI_SPIPC1_SCSDIR5_SHIFT (0x00000005u)
#define CSL_SPI_SPIPC1_SCSDIR5_RESETVAL (0x00000000u)
/*----SCSDIR5 Tokens----*/
#define CSL_SPI_SPIPC1_SCSDIR5_INPUT (0x00000000u)
#define CSL_SPI_SPIPC1_SCSDIR5_OUTPUT (0x00000001u)

#define CSL_SPI_SPIPC1_SCSDIR4_MASK (0x00000010u)
#define CSL_SPI_SPIPC1_SCSDIR4_SHIFT (0x00000004u)
#define CSL_SPI_SPIPC1_SCSDIR4_RESETVAL (0x00000000u)
/*----SCSDIR4 Tokens----*/
#define CSL_SPI_SPIPC1_SCSDIR4_INPUT (0x00000000u)
#define CSL_SPI_SPIPC1_SCSDIR4_OUTPUT (0x00000001u)

#define CSL_SPI_SPIPC1_SCSDIR3_MASK (0x00000008u)
#define CSL_SPI_SPIPC1_SCSDIR3_SHIFT (0x00000003u)
#define CSL_SPI_SPIPC1_SCSDIR3_RESETVAL (0x00000000u)
/*----SCSDIR3 Tokens----*/
#define CSL_SPI_SPIPC1_SCSDIR3_INPUT (0x00000000u)
#define CSL_SPI_SPIPC1_SCSDIR3_OUTPUT (0x00000001u)

#define CSL_SPI_SPIPC1_SCSDIR2_MASK (0x00000004u)
#define CSL_SPI_SPIPC1_SCSDIR2_SHIFT (0x00000002u)
#define CSL_SPI_SPIPC1_SCSDIR2_RESETVAL (0x00000000u)
/*----SCSDIR2 Tokens----*/
#define CSL_SPI_SPIPC1_SCSDIR2_INPUT (0x00000000u)
#define CSL_SPI_SPIPC1_SCSDIR2_OUTPUT (0x00000001u)

#define CSL_SPI_SPIPC1_SCSDIR1_MASK (0x00000002u)
#define CSL_SPI_SPIPC1_SCSDIR1_SHIFT (0x00000001u)
#define CSL_SPI_SPIPC1_SCSDIR1_RESETVAL (0x00000000u)
/*----SCSDIR1 Tokens----*/
#define CSL_SPI_SPIPC1_SCSDIR1_INPUT (0x00000000u)
#define CSL_SPI_SPIPC1_SCSDIR1_OUTPUT (0x00000001u)

#define CSL_SPI_SPIPC1_SCSDIR0_MASK (0x00000001u)
#define CSL_SPI_SPIPC1_SCSDIR0_SHIFT (0x00000000u)
#define CSL_SPI_SPIPC1_SCSDIR0_RESETVAL (0x00000000u)
/*----SCSDIR0 Tokens----*/
#define CSL_SPI_SPIPC1_SCSDIR0_INPUT (0x00000000u)
#define CSL_SPI_SPIPC1_SCSDIR0_OUTPUT (0x00000001u)

#define CSL_SPI_SPIPC1_RESETVAL (0x00000000u)

/* SPIPC2 */


#define CSL_SPI_SPIPC2_SOMIDIN_MASK (0x00000800u)
#define CSL_SPI_SPIPC2_SOMIDIN_SHIFT (0x0000000Bu)
#define CSL_SPI_SPIPC2_SOMIDIN_RESETVAL (0x00000000u)
/*----SOMIDIN Tokens----*/
#define CSL_SPI_SPIPC2_SOMIDIN_LOW (0x00000000u)
#define CSL_SPI_SPIPC2_SOMIDIN_HIGH (0x00000001u)

#define CSL_SPI_SPIPC2_SIMODIN_MASK (0x00000400u)
#define CSL_SPI_SPIPC2_SIMODIN_SHIFT (0x0000000Au)
#define CSL_SPI_SPIPC2_SIMODIN_RESETVAL (0x00000000u)
/*----SIMODIN Tokens----*/
#define CSL_SPI_SPIPC2_SIMODIN_LOW (0x00000000u)
#define CSL_SPI_SPIPC2_SIMODIN_HIGH (0x00000001u)

#define CSL_SPI_SPIPC2_CLKDIN_MASK (0x00000200u)
#define CSL_SPI_SPIPC2_CLKDIN_SHIFT (0x00000009u)
#define CSL_SPI_SPIPC2_CLKDIN_RESETVAL (0x00000000u)
/*----CLKDIN Tokens----*/
#define CSL_SPI_SPIPC2_CLKDIN_LOW (0x00000000u)
#define CSL_SPI_SPIPC2_CLKDIN_HIGH (0x00000001u)

#define CSL_SPI_SPIPC2_ENADIN_MASK (0x00000100u)
#define CSL_SPI_SPIPC2_ENADIN_SHIFT (0x00000008u)
#define CSL_SPI_SPIPC2_ENADIN_RESETVAL (0x00000000u)
/*----ENADIN Tokens----*/
#define CSL_SPI_SPIPC2_ENADIN_LOW (0x00000000u)
#define CSL_SPI_SPIPC2_ENADIN_HIGH (0x00000001u)

#define CSL_SPI_SPIPC2_SCSDIN7_MASK (0x00000080u)
#define CSL_SPI_SPIPC2_SCSDIN7_SHIFT (0x00000007u)
#define CSL_SPI_SPIPC2_SCSDIN7_RESETVAL (0x00000000u)
/*----SCSDIN7 Tokens----*/
#define CSL_SPI_SPIPC2_SCSDIN7_LOW (0x00000000u)
#define CSL_SPI_SPIPC2_SCSDIN7_HIGH (0x00000001u)

#define CSL_SPI_SPIPC2_SCSDIN6_MASK (0x00000040u)
#define CSL_SPI_SPIPC2_SCSDIN6_SHIFT (0x00000006u)
#define CSL_SPI_SPIPC2_SCSDIN6_RESETVAL (0x00000000u)
/*----SCSDIN6 Tokens----*/
#define CSL_SPI_SPIPC2_SCSDIN6_LOW (0x00000000u)
#define CSL_SPI_SPIPC2_SCSDIN6_HIGH (0x00000001u)

#define CSL_SPI_SPIPC2_SCSDIN5_MASK (0x00000020u)
#define CSL_SPI_SPIPC2_SCSDIN5_SHIFT (0x00000005u)
#define CSL_SPI_SPIPC2_SCSDIN5_RESETVAL (0x00000000u)
/*----SCSDIN5 Tokens----*/
#define CSL_SPI_SPIPC2_SCSDIN5_LOW (0x00000000u)
#define CSL_SPI_SPIPC2_SCSDIN5_HIGH (0x00000001u)

#define CSL_SPI_SPIPC2_SCSDIN4_MASK (0x00000010u)
#define CSL_SPI_SPIPC2_SCSDIN4_SHIFT (0x00000004u)
#define CSL_SPI_SPIPC2_SCSDIN4_RESETVAL (0x00000000u)
/*----SCSDIN4 Tokens----*/
#define CSL_SPI_SPIPC2_SCSDIN4_LOW (0x00000000u)
#define CSL_SPI_SPIPC2_SCSDIN4_HIGH (0x00000001u)

#define CSL_SPI_SPIPC2_SCSDIN3_MASK (0x00000008u)
#define CSL_SPI_SPIPC2_SCSDIN3_SHIFT (0x00000003u)
#define CSL_SPI_SPIPC2_SCSDIN3_RESETVAL (0x00000000u)
/*----SCSDIN3 Tokens----*/
#define CSL_SPI_SPIPC2_SCSDIN3_LOW (0x00000000u)
#define CSL_SPI_SPIPC2_SCSDIN3_HIGH (0x00000001u)

#define CSL_SPI_SPIPC2_SCSDIN2_MASK (0x00000004u)
#define CSL_SPI_SPIPC2_SCSDIN2_SHIFT (0x00000002u)
#define CSL_SPI_SPIPC2_SCSDIN2_RESETVAL (0x00000000u)
/*----SCSDIN2 Tokens----*/
#define CSL_SPI_SPIPC2_SCSDIN2_LOW (0x00000000u)
#define CSL_SPI_SPIPC2_SCSDIN2_HIGH (0x00000001u)

#define CSL_SPI_SPIPC2_SCSDIN1_MASK (0x00000002u)
#define CSL_SPI_SPIPC2_SCSDIN1_SHIFT (0x00000001u)
#define CSL_SPI_SPIPC2_SCSDIN1_RESETVAL (0x00000000u)
/*----SCSDIN1 Tokens----*/
#define CSL_SPI_SPIPC2_SCSDIN1_LOW (0x00000000u)
#define CSL_SPI_SPIPC2_SCSDIN1_HIGH (0x00000001u)

#define CSL_SPI_SPIPC2_SCSDIN0_MASK (0x00000001u)
#define CSL_SPI_SPIPC2_SCSDIN0_SHIFT (0x00000000u)
#define CSL_SPI_SPIPC2_SCSDIN0_RESETVAL (0x00000000u)
/*----SCSDIN0 Tokens----*/
#define CSL_SPI_SPIPC2_SCSDIN0_LOW (0x00000000u)
#define CSL_SPI_SPIPC2_SCSDIN0_HIGH (0x00000001u)

#define CSL_SPI_SPIPC2_RESETVAL (0x00000000u)

/* SPIPC3 */


#define CSL_SPI_SPIPC3_SOMIDOUT_MASK (0x00000800u)
#define CSL_SPI_SPIPC3_SOMIDOUT_SHIFT (0x0000000Bu)
#define CSL_SPI_SPIPC3_SOMIDOUT_RESETVAL (0x00000000u)
/*----SOMIDOUT Tokens----*/
#define CSL_SPI_SPIPC3_SOMIDOUT_LOW (0x00000000u)
#define CSL_SPI_SPIPC3_SOMIDOUT_HIGH (0x00000001u)

#define CSL_SPI_SPIPC3_SIMODOUT_MASK (0x00000400u)
#define CSL_SPI_SPIPC3_SIMODOUT_SHIFT (0x0000000Au)
#define CSL_SPI_SPIPC3_SIMODOUT_RESETVAL (0x00000000u)
/*----SIMODOUT Tokens----*/
#define CSL_SPI_SPIPC3_SIMODOUT_LOW (0x00000000u)
#define CSL_SPI_SPIPC3_SIMODOUT_HIGH (0x00000001u)

#define CSL_SPI_SPIPC3_CLKDOUT_MASK (0x00000200u)
#define CSL_SPI_SPIPC3_CLKDOUT_SHIFT (0x00000009u)
#define CSL_SPI_SPIPC3_CLKDOUT_RESETVAL (0x00000000u)
/*----CLKDOUT Tokens----*/
#define CSL_SPI_SPIPC3_CLKDOUT_LOW (0x00000000u)
#define CSL_SPI_SPIPC3_CLKDOUT_HIGH (0x00000001u)

#define CSL_SPI_SPIPC3_ENADOUT_MASK (0x00000100u)
#define CSL_SPI_SPIPC3_ENADOUT_SHIFT (0x00000008u)
#define CSL_SPI_SPIPC3_ENADOUT_RESETVAL (0x00000000u)
/*----ENADOUT Tokens----*/
#define CSL_SPI_SPIPC3_ENADOUT_LOW (0x00000000u)
#define CSL_SPI_SPIPC3_ENADOUT_HIGH (0x00000001u)

#define CSL_SPI_SPIPC3_SCSDOUT7_MASK (0x00000080u)
#define CSL_SPI_SPIPC3_SCSDOUT7_SHIFT (0x00000007u)
#define CSL_SPI_SPIPC3_SCSDOUT7_RESETVAL (0x00000000u)
/*----SCSDOUT7 Tokens----*/
#define CSL_SPI_SPIPC3_SCSDOUT7_LOW (0x00000000u)
#define CSL_SPI_SPIPC3_SCSDOUT7_HIGH (0x00000001u)

#define CSL_SPI_SPIPC3_SCSDOUT6_MASK (0x00000040u)
#define CSL_SPI_SPIPC3_SCSDOUT6_SHIFT (0x00000006u)
#define CSL_SPI_SPIPC3_SCSDOUT6_RESETVAL (0x00000000u)
/*----SCSDOUT6 Tokens----*/
#define CSL_SPI_SPIPC3_SCSDOUT6_LOW (0x00000000u)
#define CSL_SPI_SPIPC3_SCSDOUT6_HIGH (0x00000001u)

#define CSL_SPI_SPIPC3_SCSDOUT5_MASK (0x00000020u)
#define CSL_SPI_SPIPC3_SCSDOUT5_SHIFT (0x00000005u)
#define CSL_SPI_SPIPC3_SCSDOUT5_RESETVAL (0x00000000u)
/*----SCSDOUT5 Tokens----*/
#define CSL_SPI_SPIPC3_SCSDOUT5_LOW (0x00000000u)
#define CSL_SPI_SPIPC3_SCSDOUT5_HIGH (0x00000001u)

#define CSL_SPI_SPIPC3_SCSDOUT4_MASK (0x00000010u)
#define CSL_SPI_SPIPC3_SCSDOUT4_SHIFT (0x00000004u)
#define CSL_SPI_SPIPC3_SCSDOUT4_RESETVAL (0x00000000u)
/*----SCSDOUT4 Tokens----*/
#define CSL_SPI_SPIPC3_SCSDOUT4_LOW (0x00000000u)
#define CSL_SPI_SPIPC3_SCSDOUT4_HIGH (0x00000001u)

#define CSL_SPI_SPIPC3_SCSDOUT3_MASK (0x00000008u)
#define CSL_SPI_SPIPC3_SCSDOUT3_SHIFT (0x00000003u)
#define CSL_SPI_SPIPC3_SCSDOUT3_RESETVAL (0x00000000u)
/*----SCSDOUT3 Tokens----*/
#define CSL_SPI_SPIPC3_SCSDOUT3_LOW (0x00000000u)
#define CSL_SPI_SPIPC3_SCSDOUT3_HIGH (0x00000001u)

#define CSL_SPI_SPIPC3_SCSDOUT2_MASK (0x00000004u)
#define CSL_SPI_SPIPC3_SCSDOUT2_SHIFT (0x00000002u)
#define CSL_SPI_SPIPC3_SCSDOUT2_RESETVAL (0x00000000u)
/*----SCSDOUT2 Tokens----*/
#define CSL_SPI_SPIPC3_SCSDOUT2_LOW (0x00000000u)
#define CSL_SPI_SPIPC3_SCSDOUT2_HIGH (0x00000001u)

#define CSL_SPI_SPIPC3_SCSDOUT1_MASK (0x00000002u)
#define CSL_SPI_SPIPC3_SCSDOUT1_SHIFT (0x00000001u)
#define CSL_SPI_SPIPC3_SCSDOUT1_RESETVAL (0x00000000u)
/*----SCSDOUT1 Tokens----*/
#define CSL_SPI_SPIPC3_SCSDOUT1_LOW (0x00000000u)
#define CSL_SPI_SPIPC3_SCSDOUT1_HIGH (0x00000001u)

#define CSL_SPI_SPIPC3_SCSDOUT0_MASK (0x00000001u)
#define CSL_SPI_SPIPC3_SCSDOUT0_SHIFT (0x00000000u)
#define CSL_SPI_SPIPC3_SCSDOUT0_RESETVAL (0x00000000u)
/*----SCSDOUT0 Tokens----*/
#define CSL_SPI_SPIPC3_SCSDOUT0_LOW (0x00000000u)
#define CSL_SPI_SPIPC3_SCSDOUT0_HIGH (0x00000001u)

#define CSL_SPI_SPIPC3_RESETVAL (0x00000000u)

/* SPIPC4 */


#define CSL_SPI_SPIPC4_SOMISET_MASK (0x00000800u)
#define CSL_SPI_SPIPC4_SOMISET_SHIFT (0x0000000Bu)
#define CSL_SPI_SPIPC4_SOMISET_RESETVAL (0x00000000u)
/*----SOMISET Tokens----*/
#define CSL_SPI_SPIPC4_SOMISET_LOW (0x00000000u)
#define CSL_SPI_SPIPC4_SOMISET_HIGH (0x00000001u)

#define CSL_SPI_SPIPC4_SIMOSET_MASK (0x00000400u)
#define CSL_SPI_SPIPC4_SIMOSET_SHIFT (0x0000000Au)
#define CSL_SPI_SPIPC4_SIMOSET_RESETVAL (0x00000000u)
/*----SIMOSET Tokens----*/
#define CSL_SPI_SPIPC4_SIMOSET_LOW (0x00000000u)
#define CSL_SPI_SPIPC4_SIMOSET_HIGH (0x00000001u)

#define CSL_SPI_SPIPC4_CLKSET_MASK (0x00000200u)
#define CSL_SPI_SPIPC4_CLKSET_SHIFT (0x00000009u)
#define CSL_SPI_SPIPC4_CLKSET_RESETVAL (0x00000000u)
/*----CLKSET Tokens----*/
#define CSL_SPI_SPIPC4_CLKSET_LOW (0x00000000u)
#define CSL_SPI_SPIPC4_CLKSET_HIGH (0x00000001u)

#define CSL_SPI_SPIPC4_ENASET_MASK (0x00000100u)
#define CSL_SPI_SPIPC4_ENASET_SHIFT (0x00000008u)
#define CSL_SPI_SPIPC4_ENASET_RESETVAL (0x00000000u)
/*----ENASET Tokens----*/
#define CSL_SPI_SPIPC4_ENASET_LOW (0x00000000u)
#define CSL_SPI_SPIPC4_ENASET_HIGH (0x00000001u)

#define CSL_SPI_SPIPC4_SCSOUTSET7_MASK (0x00000080u)
#define CSL_SPI_SPIPC4_SCSOUTSET7_SHIFT (0x00000007u)
#define CSL_SPI_SPIPC4_SCSOUTSET7_RESETVAL (0x00000000u)
/*----SCSOUTSET7 Tokens----*/
#define CSL_SPI_SPIPC4_SCSOUTSET7_LOW (0x00000000u)
#define CSL_SPI_SPIPC4_SCSOUTSET7_HIGH (0x00000001u)

#define CSL_SPI_SPIPC4_SCSOUTSET6_MASK (0x00000040u)
#define CSL_SPI_SPIPC4_SCSOUTSET6_SHIFT (0x00000006u)
#define CSL_SPI_SPIPC4_SCSOUTSET6_RESETVAL (0x00000000u)
/*----SCSOUTSET6 Tokens----*/
#define CSL_SPI_SPIPC4_SCSOUTSET6_LOW (0x00000000u)
#define CSL_SPI_SPIPC4_SCSOUTSET6_HIGH (0x00000001u)

#define CSL_SPI_SPIPC4_SCSOUTSET5_MASK (0x00000020u)
#define CSL_SPI_SPIPC4_SCSOUTSET5_SHIFT (0x00000005u)
#define CSL_SPI_SPIPC4_SCSOUTSET5_RESETVAL (0x00000000u)
/*----SCSOUTSET5 Tokens----*/
#define CSL_SPI_SPIPC4_SCSOUTSET5_LOW (0x00000000u)
#define CSL_SPI_SPIPC4_SCSOUTSET5_HIGH (0x00000001u)

#define CSL_SPI_SPIPC4_SCSOUTSET4_MASK (0x00000010u)
#define CSL_SPI_SPIPC4_SCSOUTSET4_SHIFT (0x00000004u)
#define CSL_SPI_SPIPC4_SCSOUTSET4_RESETVAL (0x00000000u)
/*----SCSOUTSET4 Tokens----*/
#define CSL_SPI_SPIPC4_SCSOUTSET4_LOW (0x00000000u)
#define CSL_SPI_SPIPC4_SCSOUTSET4_HIGH (0x00000001u)

#define CSL_SPI_SPIPC4_SCSOUTSET3_MASK (0x00000008u)
#define CSL_SPI_SPIPC4_SCSOUTSET3_SHIFT (0x00000003u)
#define CSL_SPI_SPIPC4_SCSOUTSET3_RESETVAL (0x00000000u)
/*----SCSOUTSET3 Tokens----*/
#define CSL_SPI_SPIPC4_SCSOUTSET3_LOW (0x00000000u)
#define CSL_SPI_SPIPC4_SCSOUTSET3_HIGH (0x00000001u)

#define CSL_SPI_SPIPC4_SCSOUTSET2_MASK (0x00000004u)
#define CSL_SPI_SPIPC4_SCSOUTSET2_SHIFT (0x00000002u)
#define CSL_SPI_SPIPC4_SCSOUTSET2_RESETVAL (0x00000000u)
/*----SCSOUTSET2 Tokens----*/
#define CSL_SPI_SPIPC4_SCSOUTSET2_LOW (0x00000000u)
#define CSL_SPI_SPIPC4_SCSOUTSET2_HIGH (0x00000001u)

#define CSL_SPI_SPIPC4_SCSOUTSET1_MASK (0x00000002u)
#define CSL_SPI_SPIPC4_SCSOUTSET1_SHIFT (0x00000001u)
#define CSL_SPI_SPIPC4_SCSOUTSET1_RESETVAL (0x00000000u)
/*----SCSOUTSET1 Tokens----*/
#define CSL_SPI_SPIPC4_SCSOUTSET1_LOW (0x00000000u)
#define CSL_SPI_SPIPC4_SCSOUTSET1_HIGH (0x00000001u)

#define CSL_SPI_SPIPC4_SCSOUTSET0_MASK (0x00000001u)
#define CSL_SPI_SPIPC4_SCSOUTSET0_SHIFT (0x00000000u)
#define CSL_SPI_SPIPC4_SCSOUTSET0_RESETVAL (0x00000000u)
/*----SCSOUTSET0 Tokens----*/
#define CSL_SPI_SPIPC4_SCSOUTSET0_LOW (0x00000000u)
#define CSL_SPI_SPIPC4_SCSOUTSET0_HIGH (0x00000001u)

#define CSL_SPI_SPIPC4_RESETVAL (0x00000000u)

/* SPIPC5 */


#define CSL_SPI_SPIPC5_SOMICLR_MASK (0x00000800u)
#define CSL_SPI_SPIPC5_SOMICLR_SHIFT (0x0000000Bu)
#define CSL_SPI_SPIPC5_SOMICLR_RESETVAL (0x00000000u)
/*----SOMICLR Tokens----*/
#define CSL_SPI_SPIPC5_SOMICLR_LOW (0x00000000u)
#define CSL_SPI_SPIPC5_SOMICLR_HIGH (0x00000001u)

#define CSL_SPI_SPIPC5_SIMOCLR_MASK (0x00000400u)
#define CSL_SPI_SPIPC5_SIMOCLR_SHIFT (0x0000000Au)
#define CSL_SPI_SPIPC5_SIMOCLR_RESETVAL (0x00000000u)
/*----SIMOCLR Tokens----*/
#define CSL_SPI_SPIPC5_SIMOCLR_LOW (0x00000000u)
#define CSL_SPI_SPIPC5_SIMOCLR_HIGH (0x00000001u)

#define CSL_SPI_SPIPC5_CLKCLR_MASK (0x00000200u)
#define CSL_SPI_SPIPC5_CLKCLR_SHIFT (0x00000009u)
#define CSL_SPI_SPIPC5_CLKCLR_RESETVAL (0x00000000u)
/*----CLKCLR Tokens----*/
#define CSL_SPI_SPIPC5_CLKCLR_LOW (0x00000000u)
#define CSL_SPI_SPIPC5_CLKCLR_HIGH (0x00000001u)

#define CSL_SPI_SPIPC5_ENACLR_MASK (0x00000100u)
#define CSL_SPI_SPIPC5_ENACLR_SHIFT (0x00000008u)
#define CSL_SPI_SPIPC5_ENACLR_RESETVAL (0x00000000u)
/*----ENACLR Tokens----*/
#define CSL_SPI_SPIPC5_ENACLR_LOW (0x00000000u)
#define CSL_SPI_SPIPC5_ENACLR_HIGH (0x00000001u)

#define CSL_SPI_SPIPC5_SCSCLR7_MASK (0x00000080u)
#define CSL_SPI_SPIPC5_SCSCLR7_SHIFT (0x00000007u)
#define CSL_SPI_SPIPC5_SCSCLR7_RESETVAL (0x00000000u)
/*----SCSCLR7 Tokens----*/
#define CSL_SPI_SPIPC5_SCSCLR7_LOW (0x00000000u)
#define CSL_SPI_SPIPC5_SCSCLR7_HIGH (0x00000001u)

#define CSL_SPI_SPIPC5_SCSCLR6_MASK (0x00000040u)
#define CSL_SPI_SPIPC5_SCSCLR6_SHIFT (0x00000006u)
#define CSL_SPI_SPIPC5_SCSCLR6_RESETVAL (0x00000000u)
/*----SCSCLR6 Tokens----*/
#define CSL_SPI_SPIPC5_SCSCLR6_LOW (0x00000000u)
#define CSL_SPI_SPIPC5_SCSCLR6_HIGH (0x00000001u)

#define CSL_SPI_SPIPC5_SCSCLR5_MASK (0x00000020u)
#define CSL_SPI_SPIPC5_SCSCLR5_SHIFT (0x00000005u)
#define CSL_SPI_SPIPC5_SCSCLR5_RESETVAL (0x00000000u)
/*----SCSCLR5 Tokens----*/
#define CSL_SPI_SPIPC5_SCSCLR5_LOW (0x00000000u)
#define CSL_SPI_SPIPC5_SCSCLR5_HIGH (0x00000001u)

#define CSL_SPI_SPIPC5_SCSCLR4_MASK (0x00000010u)
#define CSL_SPI_SPIPC5_SCSCLR4_SHIFT (0x00000004u)
#define CSL_SPI_SPIPC5_SCSCLR4_RESETVAL (0x00000000u)
/*----SCSCLR4 Tokens----*/
#define CSL_SPI_SPIPC5_SCSCLR4_LOW (0x00000000u)
#define CSL_SPI_SPIPC5_SCSCLR4_HIGH (0x00000001u)

#define CSL_SPI_SPIPC5_SCSCLR3_MASK (0x00000008u)
#define CSL_SPI_SPIPC5_SCSCLR3_SHIFT (0x00000003u)
#define CSL_SPI_SPIPC5_SCSCLR3_RESETVAL (0x00000000u)
/*----SCSCLR3 Tokens----*/
#define CSL_SPI_SPIPC5_SCSCLR3_LOW (0x00000000u)
#define CSL_SPI_SPIPC5_SCSCLR3_HIGH (0x00000001u)

#define CSL_SPI_SPIPC5_SCSCLR2_MASK (0x00000004u)
#define CSL_SPI_SPIPC5_SCSCLR2_SHIFT (0x00000002u)
#define CSL_SPI_SPIPC5_SCSCLR2_RESETVAL (0x00000000u)
/*----SCSCLR2 Tokens----*/
#define CSL_SPI_SPIPC5_SCSCLR2_LOW (0x00000000u)
#define CSL_SPI_SPIPC5_SCSCLR2_HIGH (0x00000001u)

#define CSL_SPI_SPIPC5_SCSCLR1_MASK (0x00000002u)
#define CSL_SPI_SPIPC5_SCSCLR1_SHIFT (0x00000001u)
#define CSL_SPI_SPIPC5_SCSCLR1_RESETVAL (0x00000000u)
/*----SCSCLR1 Tokens----*/
#define CSL_SPI_SPIPC5_SCSCLR1_LOW (0x00000000u)
#define CSL_SPI_SPIPC5_SCSCLR1_HIGH (0x00000001u)

#define CSL_SPI_SPIPC5_SCSCLR0_MASK (0x00000001u)
#define CSL_SPI_SPIPC5_SCSCLR0_SHIFT (0x00000000u)
#define CSL_SPI_SPIPC5_SCSCLR0_RESETVAL (0x00000000u)
/*----SCSCLR0 Tokens----*/
#define CSL_SPI_SPIPC5_SCSCLR0_LOW (0x00000000u)
#define CSL_SPI_SPIPC5_SCSCLR0_HIGH (0x00000001u)

#define CSL_SPI_SPIPC5_RESETVAL (0x00000000u)

/* SPIPC6 */


#define CSL_SPI_SPIPC6_SOMIPDR_MASK (0x00000800u)
#define CSL_SPI_SPIPC6_SOMIPDR_SHIFT (0x0000000Bu)
#define CSL_SPI_SPIPC6_SOMIPDR_RESETVAL (0x00000000u)
/*----SOMIPDR Tokens----*/
#define CSL_SPI_SPIPC6_SOMIPDR_HIGH (0x00000000u)
#define CSL_SPI_SPIPC6_SOMIPDR_HIZ (0x00000001u)

#define CSL_SPI_SPIPC6_SIMOPDR_MASK (0x00000400u)
#define CSL_SPI_SPIPC6_SIMOPDR_SHIFT (0x0000000Au)
#define CSL_SPI_SPIPC6_SIMOPDR_RESETVAL (0x00000000u)
/*----SIMOPDR Tokens----*/
#define CSL_SPI_SPIPC6_SIMOPDR_HIGH (0x00000000u)
#define CSL_SPI_SPIPC6_SIMOPDR_HIZ (0x00000001u)

#define CSL_SPI_SPIPC6_CLKPDR_MASK (0x00000200u)
#define CSL_SPI_SPIPC6_CLKPDR_SHIFT (0x00000009u)
#define CSL_SPI_SPIPC6_CLKPDR_RESETVAL (0x00000000u)
/*----CLKPDR Tokens----*/
#define CSL_SPI_SPIPC6_CLKPDR_HIGH (0x00000000u)
#define CSL_SPI_SPIPC6_CLKPDR_HIZ (0x00000001u)

#define CSL_SPI_SPIPC6_ENAPDR_MASK (0x00000100u)
#define CSL_SPI_SPIPC6_ENAPDR_SHIFT (0x00000008u)
#define CSL_SPI_SPIPC6_ENAPDR_RESETVAL (0x00000000u)
/*----ENAPDR Tokens----*/
#define CSL_SPI_SPIPC6_ENAPDR_HIGH (0x00000000u)
#define CSL_SPI_SPIPC6_ENAPDR_HIZ (0x00000001u)

#define CSL_SPI_SPIPC6_SCSPDR7_MASK (0x00000080u)
#define CSL_SPI_SPIPC6_SCSPDR7_SHIFT (0x00000007u)
#define CSL_SPI_SPIPC6_SCSPDR7_RESETVAL (0x00000000u)
/*----SCSPDR7 Tokens----*/
#define CSL_SPI_SPIPC6_SCSPDR7_HIGH (0x00000000u)
#define CSL_SPI_SPIPC6_SCSPDR7_HIZ (0x00000001u)

#define CSL_SPI_SPIPC6_SCSPDR6_MASK (0x00000040u)
#define CSL_SPI_SPIPC6_SCSPDR6_SHIFT (0x00000006u)
#define CSL_SPI_SPIPC6_SCSPDR6_RESETVAL (0x00000000u)
/*----SCSPDR6 Tokens----*/
#define CSL_SPI_SPIPC6_SCSPDR6_HIGH (0x00000000u)
#define CSL_SPI_SPIPC6_SCSPDR6_HIZ (0x00000001u)

#define CSL_SPI_SPIPC6_SCSPDR5_MASK (0x00000020u)
#define CSL_SPI_SPIPC6_SCSPDR5_SHIFT (0x00000005u)
#define CSL_SPI_SPIPC6_SCSPDR5_RESETVAL (0x00000000u)
/*----SCSPDR5 Tokens----*/
#define CSL_SPI_SPIPC6_SCSPDR5_HIGH (0x00000000u)
#define CSL_SPI_SPIPC6_SCSPDR5_HIZ (0x00000001u)

#define CSL_SPI_SPIPC6_SCSPDR4_MASK (0x00000010u)
#define CSL_SPI_SPIPC6_SCSPDR4_SHIFT (0x00000004u)
#define CSL_SPI_SPIPC6_SCSPDR4_RESETVAL (0x00000000u)
/*----SCSPDR4 Tokens----*/
#define CSL_SPI_SPIPC6_SCSPDR4_HIGH (0x00000000u)
#define CSL_SPI_SPIPC6_SCSPDR4_HIZ (0x00000001u)

#define CSL_SPI_SPIPC6_SCSPDR3_MASK (0x00000008u)
#define CSL_SPI_SPIPC6_SCSPDR3_SHIFT (0x00000003u)
#define CSL_SPI_SPIPC6_SCSPDR3_RESETVAL (0x00000000u)
/*----SCSPDR3 Tokens----*/
#define CSL_SPI_SPIPC6_SCSPDR3_HIGH (0x00000000u)
#define CSL_SPI_SPIPC6_SCSPDR3_HIZ (0x00000001u)

#define CSL_SPI_SPIPC6_SCSPDR2_MASK (0x00000004u)
#define CSL_SPI_SPIPC6_SCSPDR2_SHIFT (0x00000002u)
#define CSL_SPI_SPIPC6_SCSPDR2_RESETVAL (0x00000000u)
/*----SCSPDR2 Tokens----*/
#define CSL_SPI_SPIPC6_SCSPDR2_HIGH (0x00000000u)
#define CSL_SPI_SPIPC6_SCSPDR2_HIZ (0x00000001u)

#define CSL_SPI_SPIPC6_SCSPDR1_MASK (0x00000002u)
#define CSL_SPI_SPIPC6_SCSPDR1_SHIFT (0x00000001u)
#define CSL_SPI_SPIPC6_SCSPDR1_RESETVAL (0x00000000u)
/*----SCSPDR1 Tokens----*/
#define CSL_SPI_SPIPC6_SCSPDR1_HIGH (0x00000000u)
#define CSL_SPI_SPIPC6_SCSPDR1_HIZ (0x00000001u)

#define CSL_SPI_SPIPC6_SCSPDR0_MASK (0x00000001u)
#define CSL_SPI_SPIPC6_SCSPDR0_SHIFT (0x00000000u)
#define CSL_SPI_SPIPC6_SCSPDR0_RESETVAL (0x00000000u)
/*----SCSPDR0 Tokens----*/
#define CSL_SPI_SPIPC6_SCSPDR0_HIGH (0x00000000u)
#define CSL_SPI_SPIPC6_SCSPDR0_HIZ (0x00000001u)

#define CSL_SPI_SPIPC6_RESETVAL (0x00000000u)

/* SPIPC7 */


#define CSL_SPI_SPIPC7_SOMIPSEL_MASK (0x00000800u)
#define CSL_SPI_SPIPC7_SOMIPSEL_SHIFT (0x0000000Bu)
#define CSL_SPI_SPIPC7_SOMIPSEL_RESETVAL (0x00000000u)
/*----SOMIPSEL Tokens----*/
#define CSL_SPI_SPIPC7_SOMIPSEL_PULL_CTRL_ENABLED (0x00000000u)
#define CSL_SPI_SPIPC7_SOMIPSEL_PULL_CNTRL_DISABLED (0x00000001u)

#define CSL_SPI_SPIPC7_SIMOPSEL_MASK (0x00000400u)
#define CSL_SPI_SPIPC7_SIMOPSEL_SHIFT (0x0000000Au)
#define CSL_SPI_SPIPC7_SIMOPSEL_RESETVAL (0x00000000u)
/*----SIMOPSEL Tokens----*/
#define CSL_SPI_SPIPC7_SIMOPSEL_PULL_CTRL_ENABLED (0x00000000u)
#define CSL_SPI_SPIPC7_SIMOPSEL_PULL_CNTRL_DISABLED (0x00000001u)

#define CSL_SPI_SPIPC7_CLKPSEL_MASK (0x00000200u)
#define CSL_SPI_SPIPC7_CLKPSEL_SHIFT (0x00000009u)
#define CSL_SPI_SPIPC7_CLKPSEL_RESETVAL (0x00000000u)
/*----CLKPSEL Tokens----*/
#define CSL_SPI_SPIPC7_CLKPSEL_PULL_CTRL_ENABLED (0x00000000u)
#define CSL_SPI_SPIPC7_CLKPSEL_PULL_CNTRL_DISABLED (0x00000001u)

#define CSL_SPI_SPIPC7_ENAPSEL_MASK (0x00000100u)
#define CSL_SPI_SPIPC7_ENAPSEL_SHIFT (0x00000008u)
#define CSL_SPI_SPIPC7_ENAPSEL_RESETVAL (0x00000000u)
/*----ENAPSEL Tokens----*/
#define CSL_SPI_SPIPC7_ENAPSEL_PULL_CTRL_ENABLED (0x00000000u)
#define CSL_SPI_SPIPC7_ENAPSEL_PULL_CNTRL_DISABLED (0x00000001u)

#define CSL_SPI_SPIPC7_SCSPSEL7_MASK (0x00000080u)
#define CSL_SPI_SPIPC7_SCSPSEL7_SHIFT (0x00000007u)
#define CSL_SPI_SPIPC7_SCSPSEL7_RESETVAL (0x00000000u)
/*----SCSPSEL7 Tokens----*/
#define CSL_SPI_SPIPC7_SCSPSEL7_PULL_CTRL_ENABLED (0x00000000u)
#define CSL_SPI_SPIPC7_SCSPSEL7_PULL_CNTRL_DISABLED (0x00000001u)

#define CSL_SPI_SPIPC7_SCSPSEL6_MASK (0x00000040u)
#define CSL_SPI_SPIPC7_SCSPSEL6_SHIFT (0x00000006u)
#define CSL_SPI_SPIPC7_SCSPSEL6_RESETVAL (0x00000000u)
/*----SCSPSEL6 Tokens----*/
#define CSL_SPI_SPIPC7_SCSPSEL6_PULL_CTRL_ENABLED (0x00000000u)
#define CSL_SPI_SPIPC7_SCSPSEL6_PULL_CNTRL_DISABLED (0x00000001u)

#define CSL_SPI_SPIPC7_SCSPSEL5_MASK (0x00000020u)
#define CSL_SPI_SPIPC7_SCSPSEL5_SHIFT (0x00000005u)
#define CSL_SPI_SPIPC7_SCSPSEL5_RESETVAL (0x00000000u)
/*----SCSPSEL5 Tokens----*/
#define CSL_SPI_SPIPC7_SCSPSEL5_PULL_CTRL_ENABLED (0x00000000u)
#define CSL_SPI_SPIPC7_SCSPSEL5_PULL_CNTRL_DISABLED (0x00000001u)

#define CSL_SPI_SPIPC7_SCSPSEL4_MASK (0x00000010u)
#define CSL_SPI_SPIPC7_SCSPSEL4_SHIFT (0x00000004u)
#define CSL_SPI_SPIPC7_SCSPSEL4_RESETVAL (0x00000000u)
/*----SCSPSEL4 Tokens----*/
#define CSL_SPI_SPIPC7_SCSPSEL4_PULL_CTRL_ENABLED (0x00000000u)
#define CSL_SPI_SPIPC7_SCSPSEL4_PULL_CNTRL_DISABLED (0x00000001u)

#define CSL_SPI_SPIPC7_SCSPSEL3_MASK (0x00000008u)
#define CSL_SPI_SPIPC7_SCSPSEL3_SHIFT (0x00000003u)
#define CSL_SPI_SPIPC7_SCSPSEL3_RESETVAL (0x00000000u)
/*----SCSPSEL3 Tokens----*/
#define CSL_SPI_SPIPC7_SCSPSEL3_PULL_CTRL_ENABLED (0x00000000u)
#define CSL_SPI_SPIPC7_SCSPSEL3_PULL_CNTRL_DISABLED (0x00000001u)

#define CSL_SPI_SPIPC7_SCSPSEL2_MASK (0x00000004u)
#define CSL_SPI_SPIPC7_SCSPSEL2_SHIFT (0x00000002u)
#define CSL_SPI_SPIPC7_SCSPSEL2_RESETVAL (0x00000000u)
/*----SCSPSEL2 Tokens----*/
#define CSL_SPI_SPIPC7_SCSPSEL2_PULL_CTRL_ENABLED (0x00000000u)
#define CSL_SPI_SPIPC7_SCSPSEL2_PULL_CNTRL_DISABLED (0x00000001u)

#define CSL_SPI_SPIPC7_SCSPSEL1_MASK (0x00000002u)
#define CSL_SPI_SPIPC7_SCSPSEL1_SHIFT (0x00000001u)
#define CSL_SPI_SPIPC7_SCSPSEL1_RESETVAL (0x00000000u)
/*----SCSPSEL1 Tokens----*/
#define CSL_SPI_SPIPC7_SCSPSEL1_PULL_CTRL_ENABLED (0x00000000u)
#define CSL_SPI_SPIPC7_SCSPSEL1_PULL_CNTRL_DISABLED (0x00000001u)

#define CSL_SPI_SPIPC7_SCSPSEL0_MASK (0x00000001u)
#define CSL_SPI_SPIPC7_SCSPSEL0_SHIFT (0x00000000u)
#define CSL_SPI_SPIPC7_SCSPSEL0_RESETVAL (0x00000000u)
/*----SCSPSEL0 Tokens----*/
#define CSL_SPI_SPIPC7_SCSPSEL0_PULL_CTRL_ENABLED (0x00000000u)
#define CSL_SPI_SPIPC7_SCSPSEL0_PULL_CNTRL_DISABLED (0x00000001u)

#define CSL_SPI_SPIPC7_RESETVAL (0x00000000u)

/* SPIPC8 */


#define CSL_SPI_SPIPC8_SOMIPSL_MASK (0x00000800u)
#define CSL_SPI_SPIPC8_SOMIPSL_SHIFT (0x0000000Bu)
#define CSL_SPI_SPIPC8_SOMIPSL_RESETVAL (0x00000001u)
/*----SOMIPSL Tokens----*/
#define CSL_SPI_SPIPC8_SOMIPSL_PULLDOWN (0x00000000u)
#define CSL_SPI_SPIPC8_SOMIPSL_PULLUP (0x00000001u)

#define CSL_SPI_SPIPC8_SIMOPSL_MASK (0x00000400u)
#define CSL_SPI_SPIPC8_SIMOPSL_SHIFT (0x0000000Au)
#define CSL_SPI_SPIPC8_SIMOPSL_RESETVAL (0x00000001u)
/*----SIMOPSL Tokens----*/
#define CSL_SPI_SPIPC8_SIMOPSL_PULLDOWN (0x00000000u)
#define CSL_SPI_SPIPC8_SIMOPSL_PULLUP (0x00000001u)

#define CSL_SPI_SPIPC8_CLKPSL_MASK (0x00000200u)
#define CSL_SPI_SPIPC8_CLKPSL_SHIFT (0x00000009u)
#define CSL_SPI_SPIPC8_CLKPSL_RESETVAL (0x00000001u)
/*----CLKPSL Tokens----*/
#define CSL_SPI_SPIPC8_CLKPSL_PULLDOWN (0x00000000u)
#define CSL_SPI_SPIPC8_CLKPSL_PULLUP (0x00000001u)

#define CSL_SPI_SPIPC8_ENAPSL_MASK (0x00000100u)
#define CSL_SPI_SPIPC8_ENAPSL_SHIFT (0x00000008u)
#define CSL_SPI_SPIPC8_ENAPSL_RESETVAL (0x00000001u)
/*----ENAPSL Tokens----*/
#define CSL_SPI_SPIPC8_ENAPSL_PULLDOWN (0x00000000u)
#define CSL_SPI_SPIPC8_ENAPSL_PULLUP (0x00000001u)

#define CSL_SPI_SPIPC8_SCSPSL7_MASK (0x00000080u)
#define CSL_SPI_SPIPC8_SCSPSL7_SHIFT (0x00000007u)
#define CSL_SPI_SPIPC8_SCSPSL7_RESETVAL (0x00000001u)
/*----SCSPSL7 Tokens----*/
#define CSL_SPI_SPIPC8_SCSPSL7_PULLDOWN (0x00000000u)
#define CSL_SPI_SPIPC8_SCSPSL7_PULLUP (0x00000001u)

#define CSL_SPI_SPIPC8_SCSPSL6_MASK (0x00000040u)
#define CSL_SPI_SPIPC8_SCSPSL6_SHIFT (0x00000006u)
#define CSL_SPI_SPIPC8_SCSPSL6_RESETVAL (0x00000001u)
/*----SCSPSL6 Tokens----*/
#define CSL_SPI_SPIPC8_SCSPSL6_PULLDOWN (0x00000000u)
#define CSL_SPI_SPIPC8_SCSPSL6_PULLUP (0x00000001u)

#define CSL_SPI_SPIPC8_SCSPSL5_MASK (0x00000020u)
#define CSL_SPI_SPIPC8_SCSPSL5_SHIFT (0x00000005u)
#define CSL_SPI_SPIPC8_SCSPSL5_RESETVAL (0x00000001u)
/*----SCSPSL5 Tokens----*/
#define CSL_SPI_SPIPC8_SCSPSL5_PULLDOWN (0x00000000u)
#define CSL_SPI_SPIPC8_SCSPSL5_PULLUP (0x00000001u)

#define CSL_SPI_SPIPC8_SCSPSL4_MASK (0x00000010u)
#define CSL_SPI_SPIPC8_SCSPSL4_SHIFT (0x00000004u)
#define CSL_SPI_SPIPC8_SCSPSL4_RESETVAL (0x00000001u)
/*----SCSPSL4 Tokens----*/
#define CSL_SPI_SPIPC8_SCSPSL4_PULLDOWN (0x00000000u)
#define CSL_SPI_SPIPC8_SCSPSL4_PULLUP (0x00000001u)

#define CSL_SPI_SPIPC8_SCSPSL3_MASK (0x00000008u)
#define CSL_SPI_SPIPC8_SCSPSL3_SHIFT (0x00000003u)
#define CSL_SPI_SPIPC8_SCSPSL3_RESETVAL (0x00000001u)
/*----SCSPSL3 Tokens----*/
#define CSL_SPI_SPIPC8_SCSPSL3_PULLDOWN (0x00000000u)
#define CSL_SPI_SPIPC8_SCSPSL3_PULLUP (0x00000001u)

#define CSL_SPI_SPIPC8_SCSPSL2_MASK (0x00000004u)
#define CSL_SPI_SPIPC8_SCSPSL2_SHIFT (0x00000002u)
#define CSL_SPI_SPIPC8_SCSPSL2_RESETVAL (0x00000001u)
/*----SCSPSL2 Tokens----*/
#define CSL_SPI_SPIPC8_SCSPSL2_PULLDOWN (0x00000000u)
#define CSL_SPI_SPIPC8_SCSPSL2_PULLUP (0x00000001u)

#define CSL_SPI_SPIPC8_SCSPSL1_MASK (0x00000002u)
#define CSL_SPI_SPIPC8_SCSPSL1_SHIFT (0x00000001u)
#define CSL_SPI_SPIPC8_SCSPSL1_RESETVAL (0x00000001u)
/*----SCSPSL1 Tokens----*/
#define CSL_SPI_SPIPC8_SCSPSL1_PULLDOWN (0x00000000u)
#define CSL_SPI_SPIPC8_SCSPSL1_PULLUP (0x00000001u)

#define CSL_SPI_SPIPC8_SCSPSL0_MASK (0x00000001u)
#define CSL_SPI_SPIPC8_SCSPSL0_SHIFT (0x00000000u)
#define CSL_SPI_SPIPC8_SCSPSL0_RESETVAL (0x00000001u)
/*----SCSPSL0 Tokens----*/
#define CSL_SPI_SPIPC8_SCSPSL0_PULLDOWN (0x00000000u)
#define CSL_SPI_SPIPC8_SCSPSL0_PULLUP (0x00000001u)

#define CSL_SPI_SPIPC8_RESETVAL (0x00000FFFu)

/* SPIDAT0 */


#define CSL_SPI_SPIDAT0_SPIDAT0_MASK (0x0000FFFFu)
#define CSL_SPI_SPIDAT0_SPIDAT0_SHIFT (0x00000000u)
#define CSL_SPI_SPIDAT0_SPIDAT0_RESETVAL (0x00000000u)

#define CSL_SPI_SPIDAT0_RESETVAL (0x00000000u)

/* SPIDAT1 */


#define CSL_SPI_SPIDAT1_CSHOLD_MASK (0x10000000u)
#define CSL_SPI_SPIDAT1_CSHOLD_SHIFT (0x0000001Cu)
#define CSL_SPI_SPIDAT1_CSHOLD_RESETVAL (0x00000000u)
/*----CSHOLD Tokens----*/
#define CSL_SPI_SPIDAT1_CSHOLD_DISABLED (0x00000000u)
#define CSL_SPI_SPIDAT1_CSHOLD_ENABLED (0x00000001u)


#define CSL_SPI_SPIDAT1_WDEL_MASK (0x04000000u)
#define CSL_SPI_SPIDAT1_WDEL_SHIFT (0x0000001Au)
#define CSL_SPI_SPIDAT1_WDEL_RESETVAL (0x00000000u)
/*----WDEL Tokens----*/
#define CSL_SPI_SPIDAT1_WDEL_NODELAY (0x00000000u)
#define CSL_SPI_SPIDAT1_WDEL_DELAY (0x00000001u)

#define CSL_SPI_SPIDAT1_DFSEL_MASK (0x03000000u)
#define CSL_SPI_SPIDAT1_DFSEL_SHIFT (0x00000018u)
#define CSL_SPI_SPIDAT1_DFSEL_RESETVAL (0x00000000u)
/*----DFSEL Tokens----*/
#define CSL_SPI_SPIDAT1_DFSEL_FORMAT0 (0x00000000u)
#define CSL_SPI_SPIDAT1_DFSEL_FORMAT1 (0x00000001u)
#define CSL_SPI_SPIDAT1_DFSEL_FORMAT2 (0x0000000Au)
#define CSL_SPI_SPIDAT1_DFSEL_FORMAT3 (0x0000000Bu)

#define CSL_SPI_SPIDAT1_CSNR_MASK (0x00FF0000u)
#define CSL_SPI_SPIDAT1_CSNR_SHIFT (0x00000010u)
#define CSL_SPI_SPIDAT1_CSNR_RESETVAL (0x00000000u)

#define CSL_SPI_SPIDAT1_SPIDAT1_MASK (0x0000FFFFu)
#define CSL_SPI_SPIDAT1_SPIDAT1_SHIFT (0x00000000u)
#define CSL_SPI_SPIDAT1_SPIDAT1_RESETVAL (0x00000000u)

#define CSL_SPI_SPIDAT1_RESETVAL (0x00000000u)

/* SPIBUF */

#define CSL_SPI_SPIBUF_RXEMPTY_MASK (0x80000000u)
#define CSL_SPI_SPIBUF_RXEMPTY_SHIFT (0x0000001Fu)
#define CSL_SPI_SPIBUF_RXEMPTY_RESETVAL (0x00000001u)
/*----RXEMPTY Tokens----*/
#define CSL_SPI_SPIBUF_RXEMPTY_YES (0x00000001u)
#define CSL_SPI_SPIBUF_RXEMPTY_NO (0x00000000u)

#define CSL_SPI_SPIBUF_RXOVR_MASK (0x40000000u)
#define CSL_SPI_SPIBUF_RXOVR_SHIFT (0x0000001Eu)
#define CSL_SPI_SPIBUF_RXOVR_RESETVAL (0x00000000u)
/*----RXOVR Tokens----*/
#define CSL_SPI_SPIBUF_RXOVR_NO (0x00000000u)
#define CSL_SPI_SPIBUF_RXOVR_YES (0x00000001u)

#define CSL_SPI_SPIBUF_TXFULL_MASK (0x20000000u)
#define CSL_SPI_SPIBUF_TXFULL_SHIFT (0x0000001Du)
#define CSL_SPI_SPIBUF_TXFULL_RESETVAL (0x00000000u)
/*----TXFULL Tokens----*/
#define CSL_SPI_SPIBUF_TXFULL_NO (0x00000000u)
#define CSL_SPI_SPIBUF_TXFULL_YES (0x00000001u)

#define CSL_SPI_SPIBUF_BITERR_MASK (0x10000000u)
#define CSL_SPI_SPIBUF_BITERR_SHIFT (0x0000001Cu)
#define CSL_SPI_SPIBUF_BITERR_RESETVAL (0x00000000u)
/*----BITERR Tokens----*/
#define CSL_SPI_SPIBUF_BITERR_NO (0x00000000u)
#define CSL_SPI_SPIBUF_BITERR_YES (0x00000001u)

#define CSL_SPI_SPIBUF_DESYNC_MASK (0x08000000u)
#define CSL_SPI_SPIBUF_DESYNC_SHIFT (0x0000001Bu)
#define CSL_SPI_SPIBUF_DESYNC_RESETVAL (0x00000000u)
/*----DESYNC Tokens----*/
#define CSL_SPI_SPIBUF_DESYNC_NO (0x00000000u)
#define CSL_SPI_SPIBUF_DESYNC_YES (0x00000001u)

#define CSL_SPI_SPIBUF_PARITYERR_MASK (0x04000000u)
#define CSL_SPI_SPIBUF_PARITYERR_SHIFT (0x0000001Au)
#define CSL_SPI_SPIBUF_PARITYERR_RESETVAL (0x00000000u)
/*----PARITYERR Tokens----*/
#define CSL_SPI_SPIBUF_PARITYERR_NO (0x00000000u)
#define CSL_SPI_SPIBUF_PARITYERR_YES (0x00000001u)

#define CSL_SPI_SPIBUF_TIMEOUT_MASK (0x02000000u)
#define CSL_SPI_SPIBUF_TIMEOUT_SHIFT (0x00000019u)
#define CSL_SPI_SPIBUF_TIMEOUT_RESETVAL (0x00000000u)
/*----TIMEOUT Tokens----*/
#define CSL_SPI_SPIBUF_TIMEOUT_NO (0x00000000u)
#define CSL_SPI_SPIBUF_TIMEOUT_YES (0x00000001u)


#define CSL_SPI_SPIBUF_LCSNR_MASK (0x00FF0000u)
#define CSL_SPI_SPIBUF_LCSNR_SHIFT (0x00000010u)
#define CSL_SPI_SPIBUF_LCSNR_RESETVAL (0x00000000u)

#define CSL_SPI_SPIBUF_SPIBUF_MASK (0x0000FFFFu)
#define CSL_SPI_SPIBUF_SPIBUF_SHIFT (0x00000000u)
#define CSL_SPI_SPIBUF_SPIBUF_RESETVAL (0x00000000u)

#define CSL_SPI_SPIBUF_RESETVAL (0x80000000u)

/* SPIEMU */


#define CSL_SPI_SPIEMU_SPIEMU_MASK (0x0000FFFFu)
#define CSL_SPI_SPIEMU_SPIEMU_SHIFT (0x00000000u)
#define CSL_SPI_SPIEMU_SPIEMU_RESETVAL (0x00000000u)

#define CSL_SPI_SPIEMU_RESETVAL (0x00000000u)

/* SPIDELAY */


#define CSL_SPI_SPIDELAY_C2TDELAY_MASK (0x1F000000u)
#define CSL_SPI_SPIDELAY_C2TDELAY_SHIFT (0x00000018u)
#define CSL_SPI_SPIDELAY_C2TDELAY_RESETVAL (0x00000000u)


#define CSL_SPI_SPIDELAY_T2CDELAY_MASK (0x001F0000u)
#define CSL_SPI_SPIDELAY_T2CDELAY_SHIFT (0x00000010u)
#define CSL_SPI_SPIDELAY_T2CDELAY_RESETVAL (0x00000000u)

#define CSL_SPI_SPIDELAY_T2EDELAY_MASK (0x0000FF00u)
#define CSL_SPI_SPIDELAY_T2EDELAY_SHIFT (0x00000008u)
#define CSL_SPI_SPIDELAY_T2EDELAY_RESETVAL (0x00000000u)

#define CSL_SPI_SPIDELAY_C2EDELAY_MASK (0x000000FFu)
#define CSL_SPI_SPIDELAY_C2EDELAY_SHIFT (0x00000000u)
#define CSL_SPI_SPIDELAY_C2EDELAY_RESETVAL (0x00000000u)

#define CSL_SPI_SPIDELAY_RESETVAL (0x00000000u)

/* SPIDEF */


#define CSL_SPI_SPIDEF_CSDEF7_MASK (0x00000080u)
#define CSL_SPI_SPIDEF_CSDEF7_SHIFT (0x00000007u)
#define CSL_SPI_SPIDEF_CSDEF7_RESETVAL (0x00000001u)
/*----CSDEF7 Tokens----*/
#define CSL_SPI_SPIDEF_CSDEF7_CS_0 (0x00000000u)
#define CSL_SPI_SPIDEF_CSDEF7_CS_1 (0x00000001u)

#define CSL_SPI_SPIDEF_CSDEF6_MASK (0x00000040u)
#define CSL_SPI_SPIDEF_CSDEF6_SHIFT (0x00000006u)
#define CSL_SPI_SPIDEF_CSDEF6_RESETVAL (0x00000001u)
/*----CSDEF6 Tokens----*/
#define CSL_SPI_SPIDEF_CSDEF6_CS_0 (0x00000000u)
#define CSL_SPI_SPIDEF_CSDEF6_CS_1 (0x00000001u)

#define CSL_SPI_SPIDEF_CSDEF5_MASK (0x00000020u)
#define CSL_SPI_SPIDEF_CSDEF5_SHIFT (0x00000005u)
#define CSL_SPI_SPIDEF_CSDEF5_RESETVAL (0x00000001u)
/*----CSDEF5 Tokens----*/
#define CSL_SPI_SPIDEF_CSDEF5_CS_0 (0x00000000u)
#define CSL_SPI_SPIDEF_CSDEF5_CS_1 (0x00000001u)

#define CSL_SPI_SPIDEF_CSDEF4_MASK (0x00000010u)
#define CSL_SPI_SPIDEF_CSDEF4_SHIFT (0x00000004u)
#define CSL_SPI_SPIDEF_CSDEF4_RESETVAL (0x00000001u)
/*----CSDEF4 Tokens----*/
#define CSL_SPI_SPIDEF_CSDEF4_CS_0 (0x00000000u)
#define CSL_SPI_SPIDEF_CSDEF4_CS_1 (0x00000001u)

#define CSL_SPI_SPIDEF_CSDEF3_MASK (0x00000008u)
#define CSL_SPI_SPIDEF_CSDEF3_SHIFT (0x00000003u)
#define CSL_SPI_SPIDEF_CSDEF3_RESETVAL (0x00000001u)
/*----CSDEF3 Tokens----*/
#define CSL_SPI_SPIDEF_CSDEF3_CS_0 (0x00000000u)
#define CSL_SPI_SPIDEF_CSDEF3_CS_1 (0x00000001u)

#define CSL_SPI_SPIDEF_CSDEF2_MASK (0x00000004u)
#define CSL_SPI_SPIDEF_CSDEF2_SHIFT (0x00000002u)
#define CSL_SPI_SPIDEF_CSDEF2_RESETVAL (0x00000001u)
/*----CSDEF2 Tokens----*/
#define CSL_SPI_SPIDEF_CSDEF2_CS_0 (0x00000000u)
#define CSL_SPI_SPIDEF_CSDEF2_CS_1 (0x00000001u)

#define CSL_SPI_SPIDEF_CSDEF1_MASK (0x00000002u)
#define CSL_SPI_SPIDEF_CSDEF1_SHIFT (0x00000001u)
#define CSL_SPI_SPIDEF_CSDEF1_RESETVAL (0x00000001u)
/*----CSDEF1 Tokens----*/
#define CSL_SPI_SPIDEF_CSDEF1_CS_0 (0x00000000u)
#define CSL_SPI_SPIDEF_CSDEF1_CS_1 (0x00000001u)

#define CSL_SPI_SPIDEF_CSDEF0_MASK (0x00000001u)
#define CSL_SPI_SPIDEF_CSDEF0_SHIFT (0x00000000u)
#define CSL_SPI_SPIDEF_CSDEF0_RESETVAL (0x00000001u)
/*----CSDEF0 Tokens----*/
#define CSL_SPI_SPIDEF_CSDEF0_CS_0 (0x00000000u)
#define CSL_SPI_SPIDEF_CSDEF0_CS_1 (0x00000001u)

#define CSL_SPI_SPIDEF_RESETVAL (0x000000FFu)

/* SPIFMT */


#define CSL_SPI_SPIFMT_WDELAY_MASK       (0x3F000000u)
#define CSL_SPI_SPIFMT_WDELAY_SHIFT      (0x00000018u)
#define CSL_SPI_SPIFMT_WDELAY_RESETVAL   (0x00000000u)

#define CSL_SPI_SPIFMT_PARPOL_MASK       (0x00800000u)
#define CSL_SPI_SPIFMT_PARPOL_SHIFT      (0x00000017u)
#define CSL_SPI_SPIFMT_PARPOL_RESETVAL   (0x00000000u)
/*----PARPOL0 Tokens----*/
#define CSL_SPI_SPIFMT_PARPOL_EVEN       (0x00000000u)
#define CSL_SPI_SPIFMT_PARPOL_ODD        (0x00000001u)

#define CSL_SPI_SPIFMT_PARITY_MASK       (0x00400000u)
#define CSL_SPI_SPIFMT_PARITY_SHIFT      (0x00000016u)
#define CSL_SPI_SPIFMT_PARITY_RESETVAL   (0x00000000u)
/*----PARITY0 Tokens----*/
#define CSL_SPI_SPIFMT_PARITY_NOPARITY (0x00000000u)
#define CSL_SPI_SPIFMT_PARITY_PARITY (0x00000001u)

#define CSL_SPI_SPIFMT_WAITENA_MASK (0x00200000u)
#define CSL_SPI_SPIFMT_WAITENA_SHIFT (0x00000015u)
#define CSL_SPI_SPIFMT_WAITENA_RESETVAL (0x00000000u)

/*----WAITEN Tokens----*/
#define CSL_SPI_SPIFMT_WAITENA_NO_WAIT (0x00000000u)
#define CSL_SPI_SPIFMT_WAITENA_WAIT (0x00000001u)

#define CSL_SPI_SPIFMT_SHIFTDIR_MASK     (0x00100000u)
#define CSL_SPI_SPIFMT_SHIFTDIR_SHIFT    (0x00000014u)
#define CSL_SPI_SPIFMT_SHIFTDIR_RESETVAL (0x00000000u)
/*----SHIFTDIR0 Tokens----*/
#define CSL_SPI_SPIFMT_SHIFTDIR_MSB (0x00000000u)
#define CSL_SPI_SPIFMT_SHIFTDIR_LSB (0x00000001u)


#define CSL_SPI_SPIFMT_POLARITY_MASK     (0x00020000u)
#define CSL_SPI_SPIFMT_POLARITY_SHIFT    (0x00000011u)
#define CSL_SPI_SPIFMT_POLARITY_RESETVAL (0x00000000u)
/*----POLARITY0 Tokens----*/
#define CSL_SPI_SPIFMT_POLARITY_LOW (0x00000000u)
#define CSL_SPI_SPIFMT_POLARITY_HIGH (0x00000001u)

#define CSL_SPI_SPIFMT_PHASE_MASK        (0x00010000u)
#define CSL_SPI_SPIFMT_PHASE_SHIFT       (0x00000010u)
#define CSL_SPI_SPIFMT_PHASE_RESETVAL    (0x00000000u)
/*----PHASE0 Tokens----*/
#define CSL_SPI_SPIFMT_PHASE_NO_DELAY (0x00000000u)
#define CSL_SPI_SPIFMT_PHASE_DELAY (0x00000001u)

#define CSL_SPI_SPIFMT_PRESCALE_MASK     (0x0000FF00u)
#define CSL_SPI_SPIFMT_PRESCALE_SHIFT    (0x00000008u)
#define CSL_SPI_SPIFMT_PRESCALE_RESETVAL (0x00000000u)


#define CSL_SPI_SPIFMT_CHARLEN_MASK      (0x0000001Fu)
#define CSL_SPI_SPIFMT_CHARLEN_SHIFT     (0x00000000u)
#define CSL_SPI_SPIFMT_CHARLEN_RESETVAL  (0x00000000u)

#define CSL_SPI_SPIFMT_RESETVAL          (0x00000000u)


/* TGINTVECT */


#define CSL_SPI_TGINTVECT_INTVECT_MASK    (0x0000003Eu)
#define CSL_SPI_TGINTVECT_INTVECT_SHIFT   (0x00000001u)
#define CSL_SPI_TGINTVECT_INTVECT_RESETVAL (0x00000000u)

#define CSL_SPI_TGINTVECT_SUSPEND_MASK    (0x00000001u)
#define CSL_SPI_TGINTVECT_SUSPEND_SHIFT   (0x00000000u)
#define CSL_SPI_TGINTVECT_SUSPEND_RESETVAL (0x00000000u)

/*----SUSPEND Tokens----*/
#define CSL_SPI_TGINTVECT_SUSPEND_TRANSFER_FINISHED (0x00000000u)
#define CSL_SPI_TGINTVECT_SUSPEND_TRANSFER_SUSPENDED (0x00000001u)

#define CSL_SPI_TGINTVECT_RESETVAL        (0x00000000u)


#ifdef __cplusplus
}
#endif

#endif

