/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005, 2006, 2007
 *
 *   Use of this software is controlled by the terms and conditions found in the
 *   license agreement under which this software has been supplied.
 *   ===========================================================================
 */
/** ============================================================================
 *   @file  cslr_vport.h
 *
 *   @path  $(CSLPATH)\inc
 *
 *   @desc  This file contains the Register Descriptions for VIDEO PORT
 */
/* =============================================================================
 *  Revision History
 *  ===============
 *  01-Apr-2007 NS file created.
 * =============================================================================
 */

#ifndef _CSLR_VPORT_H_
#define _CSLR_VPORT_H_

#ifdef __cplusplus
extern "C" {
#endif

#include <ti/sdo/pspdrivers/soc/dm648/dsp/cslr.h>
#include <ti/sdo/pspdrivers/soc/dm648/dsp/tistdtypes.h>

/**************************************************************************\
* Register Overlay Structure
\**************************************************************************/
typedef struct {
    volatile Uint32 VC_STAT;
    volatile Uint32 VC_CTL;
    volatile Uint32 VC_STRT1;
    volatile Uint32 VC_STOP1;
    volatile Uint32 VC_STRT2;
    volatile Uint32 VC_STOP2;
    volatile Uint32 VC_VINT;
    volatile Uint32 VC_THRLD;
    volatile Uint32 VC_EVTCT;
} CSL_VportCaptureRegs;

typedef struct  {
    volatile Uint32 PID;
    volatile Uint32 PCR;
    volatile Uint8 RSVD0[8];
    volatile Uint32 TLGC;
    volatile Uint32 TLMR;
    volatile Uint8 RSVD1[8];
    volatile Uint32 PFUNC;
    volatile Uint32 PDIR;
    volatile Uint32 PDIN;
    volatile Uint32 PDOUT;
    volatile Uint32 PDSET;
    volatile Uint32 PDCLR;
    volatile Uint32 PIEN;
    volatile Uint32 PIPOL;
    volatile Uint32 PISTAT;
    volatile Uint32 PICLR;
    volatile Uint8 RSVD2[120];
    volatile Uint32 VP_CTL;
    volatile Uint32 VP_STAT;
    volatile Uint32 VP_IE;
    volatile Uint32 VP_IS;
    volatile Uint8 RSVD3[48];
    volatile CSL_VportCaptureRegs  CSL_VportCapARegs;
    volatile Uint8 RSVD4[28];
    volatile CSL_VportCaptureRegs  CSL_VportCapBRegs;
    volatile Uint8 RSVD5[28];
    volatile Uint32 TC_CTL;
    volatile Uint32 TC_CLKINITL;
    volatile Uint32 TC_CLKINITM;
    volatile Uint32 TC_STCLKL;
    volatile Uint32 TC_STCLKM;
    volatile Uint32 TC_STCMPL;
    volatile Uint32 TC_STCMPM;
    volatile Uint32 TC_STMSKL;
    volatile Uint32 TC_STMSKM;
    volatile Uint32 TC_TICKS;
    volatile Uint8 RSVD6[88];
    volatile Uint32 VD_STAT;
    volatile Uint32 VD_CTL;
    volatile Uint32 VD_FRMSZ;
    volatile Uint32 VD_HBLNK;
    volatile Uint32 VD_VBLKS1;
    volatile Uint32 VD_VBLKE1;
    volatile Uint32 VD_VBLKS2;
    volatile Uint32 VD_VBLKE2;
    volatile Uint32 VD_IMGOFF1;
    volatile Uint32 VD_IMGSZ1;
    volatile Uint32 VD_IMGOFF2;
    volatile Uint32 VD_IMGSZ2;
    volatile Uint32 VD_FLDT1;
    volatile Uint32 VD_FLDT2;
    volatile Uint32 VD_THRLD;
    volatile Uint32 VD_HSYNC;
    volatile Uint32 VD_VSYNS1;
    volatile Uint32 VD_VSYNE1;
    volatile Uint32 VD_VSYNS2;
    volatile Uint32 VD_VSYNE2;
    volatile Uint32 VD_RELOAD;
    volatile Uint32 VD_DISPEVT;
    volatile Uint32 VD_CLIP;
    volatile Uint32 VD_DEFVAL;
    volatile Uint32 VD_VINT;
    volatile Uint32 VD_FBIT;
    volatile Uint32 VD_VBIT1;
    volatile Uint32 VD_VBIT2;
} CSL_VportRegs;

typedef struct {
    volatile Uint32 YSRCA;
    volatile Uint8 RSVD1[28];
    volatile Uint32 CBSRCA;
    volatile Uint8 RSVD2[28];
    volatile Uint32 CRSRCA;
    volatile Uint8 RSVD3[60];
    volatile Uint32 YDSTA;
    volatile Uint8 RSVD4[28];
    volatile Uint32 CBDST;
    volatile Uint8 RSVD5[28];
    volatile Uint32 CRDST;
} CSL_VportChannelARegs;

typedef struct {
    volatile Uint32 YSRCB;
    volatile Uint8 RSVD1[28];
    volatile Uint32 CBSRCB;
    volatile Uint8 RSVD2[28];
    volatile Uint32 CRSRCB;
    volatile Uint8 RSVD3[60];
    volatile Uint32 YDSTB;
} CSL_VportChannelBRegs;


/**************************************************************************\
* Overlay structure typedef definition
\**************************************************************************/
typedef volatile CSL_VportRegs          *CSL_VportRegsOvly;


/**************************************************************************\
* Field Definition Macros
\**************************************************************************/

/* PID */


#define CSL_VPORT_PID_TYPE_MASK          (0x00FF0000u)
#define CSL_VPORT_PID_TYPE_SHIFT         (0x00000010u)
#define CSL_VPORT_PID_TYPE_RESETVAL      (0x00000000u)

#define CSL_VPORT_PID_CLASS_MASK         (0x0000FF00u)
#define CSL_VPORT_PID_CLASS_SHIFT        (0x00000008u)
#define CSL_VPORT_PID_CLASS_RESETVAL     (0x00000000u)

#define CSL_VPORT_PID_REVISION_MASK      (0x000000FFu)
#define CSL_VPORT_PID_REVISION_SHIFT     (0x00000000u)
#define CSL_VPORT_PID_REVISION_RESETVAL  (0x00000000u)

#define CSL_VPORT_PID_RESETVAL           (0x00000000u)

/* PCR */


#define CSL_VPORT_PCR_PEREN_MASK         (0x00000004u)
#define CSL_VPORT_PCR_PEREN_SHIFT        (0x00000002u)
#define CSL_VPORT_PCR_PEREN_RESETVAL     (0x00000000u)
/*----PEREN Tokens----*/
#define CSL_VPORT_PCR_PEREN_INP_DIS      (0x00000000u)
#define CSL_VPORT_PCR_PEREN_PORT_FUNC    (0x00000001u)

#define CSL_VPORT_PCR_SOFT_MASK          (0x00000002u)
#define CSL_VPORT_PCR_SOFT_SHIFT         (0x00000001u)
#define CSL_VPORT_PCR_SOFT_RESETVAL      (0x00000000u)
/*----SOFT Tokens----*/
#define CSL_VPORT_PCR_SOFT_FLD_COMP_EMU_SUS (0x00000000u)
#define CSL_VPORT_PCR_SOFT_ND            (0x00000001u)

#define CSL_VPORT_PCR_FREE_MASK          (0x00000001u)
#define CSL_VPORT_PCR_FREE_SHIFT         (0x00000000u)
#define CSL_VPORT_PCR_FREE_RESETVAL      (0x00000001u)
/*----FREE Tokens----*/
#define CSL_VPORT_PCR_FREE_SOFT_DET      (0x00000000u)
#define CSL_VPORT_PCR_FREE_PORT_ENA_EMU_SUS (0x00000001u)

#define CSL_VPORT_PCR_RESETVAL           (0x00000001u)

/* TLGC */


#define CSL_VPORT_TLGC_MMS_MASK          (0x00000100u)
#define CSL_VPORT_TLGC_MMS_SHIFT         (0x00000008u)
#define CSL_VPORT_TLGC_MMS_RESETVAL      (0x00000000u)
/*----MMS Tokens----*/
#define CSL_VPORT_TLGC_MMS_REG_SEL       (0x00000000u)
#define CSL_VPORT_TLGC_MMS_INP_CAP_SEL   (0x00000001u)

#define CSL_VPORT_TLGC_ESEL_MASK         (0x00000080u)
#define CSL_VPORT_TLGC_ESEL_SHIFT        (0x00000007u)
#define CSL_VPORT_TLGC_ESEL_RESETVAL     (0x00000001u)
/*----ESEL Tokens----*/
#define CSL_VPORT_TLGC_ESEL_OEN_OFF      (0x00000000u)
#define CSL_VPORT_TLGC_ESEL_NORM_MODE    (0x00000001u)

#define CSL_VPORT_TLGC_TOEN_MASK         (0x00000040u)
#define CSL_VPORT_TLGC_TOEN_SHIFT        (0x00000006u)
#define CSL_VPORT_TLGC_TOEN_RESETVAL     (0x00000000u)
/*----TOEN Tokens----*/
#define CSL_VPORT_TLGC_TOEN_ENABLE       (0x00000000u)
#define CSL_VPORT_TLGC_TOEN_DISABLE      (0x00000001u)


#define CSL_VPORT_TLGC_MC_MASK           (0x00000030u)
#define CSL_VPORT_TLGC_MC_SHIFT          (0x00000004u)
#define CSL_VPORT_TLGC_MC_RESETVAL       (0x00000001u)
/*----MC Tokens----*/
#define CSL_VPORT_TLGC_MC_DISABLE        (0x00000000u)
#define CSL_VPORT_TLGC_MC_ENABLE         (0x00000001u)

#define CSL_VPORT_TLGC_PC_MASK           (0x0000000Eu)
#define CSL_VPORT_TLGC_PC_SHIFT          (0x00000001u)
#define CSL_VPORT_TLGC_PC_RESETVAL       (0x00000000u)
/*----PC Tokens----*/
#define CSL_VPORT_TLGC_PC_DISABLE        (0x00000000u)
#define CSL_VPORT_TLGC_PC_ENABLE         (0x00000001u)

#define CSL_VPORT_TLGC_TM_MASK           (0x00000001u)
#define CSL_VPORT_TLGC_TM_SHIFT          (0x00000000u)
#define CSL_VPORT_TLGC_TM_RESETVAL       (0x00000001u)

#define CSL_VPORT_TLGC_RESETVAL          (0x00000011u)

/* TLMR */

#define CSL_VPORT_TLMR_TLMR_MASK         (0xFFFFFFFFu)
#define CSL_VPORT_TLMR_TLMR_SHIFT        (0x00000000u)
#define CSL_VPORT_TLMR_TLMR_RESETVAL     (0x00000000u)

#define CSL_VPORT_TLMR_RESETVAL          (0x00000000u)

/* PFUNC */


#define CSL_VPORT_PFUNC_PFUNC22_MASK     (0x00400000u)
#define CSL_VPORT_PFUNC_PFUNC22_SHIFT    (0x00000016u)
#define CSL_VPORT_PFUNC_PFUNC22_RESETVAL (0x00000000u)

#define CSL_VPORT_PFUNC_PFUNC21_MASK     (0x00200000u)
#define CSL_VPORT_PFUNC_PFUNC21_SHIFT    (0x00000015u)
#define CSL_VPORT_PFUNC_PFUNC21_RESETVAL (0x00000000u)
/*----PFUNC21 Tokens----*/
#define CSL_VPORT_PFUNC_PFUNC21_14BYTE   (0x0000000Bu)

#define CSL_VPORT_PFUNC_PFUNC20_MASK     (0x00100000u)
#define CSL_VPORT_PFUNC_PFUNC20_SHIFT    (0x00000014u)
#define CSL_VPORT_PFUNC_PFUNC20_RESETVAL (0x00000000u)
/*----PFUNC20 Tokens----*/
#define CSL_VPORT_PFUNC_PFUNC20_8BYTE    (0x0000000Au)


#define CSL_VPORT_PFUNC_PFUNC10_MASK     (0x00000400u)
#define CSL_VPORT_PFUNC_PFUNC10_SHIFT    (0x0000000Au)
#define CSL_VPORT_PFUNC_PFUNC10_RESETVAL (0x00000000u)
/*----PFUNC10 Tokens----*/
#define CSL_VPORT_PFUNC_PFUNC10_1BYTE    (0x00000000u)


#define CSL_VPORT_PFUNC_PFUNC0_MASK      (0x00000001u)
#define CSL_VPORT_PFUNC_PFUNC0_SHIFT     (0x00000000u)
#define CSL_VPORT_PFUNC_PFUNC0_RESETVAL  (0x00000000u)

#define CSL_VPORT_PFUNC_RESETVAL         (0x00000000u)

/* PDIR */


#define CSL_VPORT_PDIR_PDIR22_MASK       (0x00400000u)
#define CSL_VPORT_PDIR_PDIR22_SHIFT      (0x00000016u)
#define CSL_VPORT_PDIR_PDIR22_RESETVAL   (0x00000000u)

#define CSL_VPORT_PDIR_PDIR21_MASK       (0x00200000u)
#define CSL_VPORT_PDIR_PDIR21_SHIFT      (0x00000015u)
#define CSL_VPORT_PDIR_PDIR21_RESETVAL   (0x00000000u)

#define CSL_VPORT_PDIR_PDIR20_MASK       (0x00100000u)
#define CSL_VPORT_PDIR_PDIR20_SHIFT      (0x00000014u)
#define CSL_VPORT_PDIR_PDIR20_RESETVAL   (0x00000000u)


#define CSL_VPORT_PDIR_PDIR16_MASK       (0x00010000u)
#define CSL_VPORT_PDIR_PDIR16_SHIFT      (0x00000010u)
#define CSL_VPORT_PDIR_PDIR16_RESETVAL   (0x00000000u)


#define CSL_VPORT_PDIR_PDIR12_MASK       (0x00001000u)
#define CSL_VPORT_PDIR_PDIR12_SHIFT      (0x0000000Cu)
#define CSL_VPORT_PDIR_PDIR12_RESETVAL   (0x00000000u)


#define CSL_VPORT_PDIR_PDIR10_MASK       (0x00000400u)
#define CSL_VPORT_PDIR_PDIR10_SHIFT      (0x0000000Au)
#define CSL_VPORT_PDIR_PDIR10_RESETVAL   (0x00000000u)


#define CSL_VPORT_PDIR_PDIR8_MASK        (0x00000100u)
#define CSL_VPORT_PDIR_PDIR8_SHIFT       (0x00000008u)
#define CSL_VPORT_PDIR_PDIR8_RESETVAL    (0x00000000u)


#define CSL_VPORT_PDIR_PDIR4_MASK        (0x00000010u)
#define CSL_VPORT_PDIR_PDIR4_SHIFT       (0x00000004u)
#define CSL_VPORT_PDIR_PDIR4_RESETVAL    (0x00000000u)
/*----PDIR4 Tokens----*/
#define CSL_VPORT_PDIR_PDIR4_DISABLE     (0x00000000u)


#define CSL_VPORT_PDIR_PDIR0_MASK        (0x00000001u)
#define CSL_VPORT_PDIR_PDIR0_SHIFT       (0x00000000u)
#define CSL_VPORT_PDIR_PDIR0_RESETVAL    (0x00000000u)

#define CSL_VPORT_PDIR_RESETVAL          (0x00000000u)

/* PDIN */


#define CSL_VPORT_PDIN_PDIN22_MASK       (0x00400000u)
#define CSL_VPORT_PDIN_PDIN22_SHIFT      (0x00000016u)
#define CSL_VPORT_PDIN_PDIN22_RESETVAL   (0x00000000u)

#define CSL_VPORT_PDIN_PDIN21_MASK       (0x00200000u)
#define CSL_VPORT_PDIN_PDIN21_SHIFT      (0x00000015u)
#define CSL_VPORT_PDIN_PDIN21_RESETVAL   (0x00000000u)

#define CSL_VPORT_PDIN_PDIN20_MASK       (0x00100000u)
#define CSL_VPORT_PDIN_PDIN20_SHIFT      (0x00000014u)
#define CSL_VPORT_PDIN_PDIN20_RESETVAL   (0x00000000u)

#define CSL_VPORT_PDIN_PDIN19_MASK       (0x00080000u)
#define CSL_VPORT_PDIN_PDIN19_SHIFT      (0x00000013u)
#define CSL_VPORT_PDIN_PDIN19_RESETVAL   (0x00000000u)

#define CSL_VPORT_PDIN_PDIN18_MASK       (0x00040000u)
#define CSL_VPORT_PDIN_PDIN18_SHIFT      (0x00000012u)
#define CSL_VPORT_PDIN_PDIN18_RESETVAL   (0x00000000u)

#define CSL_VPORT_PDIN_PDIN17_MASK       (0x00020000u)
#define CSL_VPORT_PDIN_PDIN17_SHIFT      (0x00000011u)
#define CSL_VPORT_PDIN_PDIN17_RESETVAL   (0x00000000u)

#define CSL_VPORT_PDIN_PDIN16_MASK       (0x00010000u)
#define CSL_VPORT_PDIN_PDIN16_SHIFT      (0x00000010u)
#define CSL_VPORT_PDIN_PDIN16_RESETVAL   (0x00000000u)

#define CSL_VPORT_PDIN_PDIN15_MASK       (0x00008000u)
#define CSL_VPORT_PDIN_PDIN15_SHIFT      (0x0000000Fu)
#define CSL_VPORT_PDIN_PDIN15_RESETVAL   (0x00000000u)

#define CSL_VPORT_PDIN_PDIN14_MASK       (0x00004000u)
#define CSL_VPORT_PDIN_PDIN14_SHIFT      (0x0000000Eu)
#define CSL_VPORT_PDIN_PDIN14_RESETVAL   (0x00000000u)

#define CSL_VPORT_PDIN_PDIN13_MASK       (0x00002000u)
#define CSL_VPORT_PDIN_PDIN13_SHIFT      (0x0000000Du)
#define CSL_VPORT_PDIN_PDIN13_RESETVAL   (0x00000000u)

#define CSL_VPORT_PDIN_PDIN12_MASK       (0x00001000u)
#define CSL_VPORT_PDIN_PDIN12_SHIFT      (0x0000000Cu)
#define CSL_VPORT_PDIN_PDIN12_RESETVAL   (0x00000000u)

#define CSL_VPORT_PDIN_PDIN11_MASK       (0x00000800u)
#define CSL_VPORT_PDIN_PDIN11_SHIFT      (0x0000000Bu)
#define CSL_VPORT_PDIN_PDIN11_RESETVAL   (0x00000000u)

#define CSL_VPORT_PDIN_PDIN10_MASK       (0x00000400u)
#define CSL_VPORT_PDIN_PDIN10_SHIFT      (0x0000000Au)
#define CSL_VPORT_PDIN_PDIN10_RESETVAL   (0x00000000u)

#define CSL_VPORT_PDIN_PDIN9_MASK        (0x00000200u)
#define CSL_VPORT_PDIN_PDIN9_SHIFT       (0x00000009u)
#define CSL_VPORT_PDIN_PDIN9_RESETVAL    (0x00000000u)

#define CSL_VPORT_PDIN_PDIN8_MASK        (0x00000100u)
#define CSL_VPORT_PDIN_PDIN8_SHIFT       (0x00000008u)
#define CSL_VPORT_PDIN_PDIN8_RESETVAL    (0x00000000u)

#define CSL_VPORT_PDIN_PDIN7_MASK        (0x00000080u)
#define CSL_VPORT_PDIN_PDIN7_SHIFT       (0x00000007u)
#define CSL_VPORT_PDIN_PDIN7_RESETVAL    (0x00000000u)

#define CSL_VPORT_PDIN_PDIN6_MASK        (0x00000040u)
#define CSL_VPORT_PDIN_PDIN6_SHIFT       (0x00000006u)
#define CSL_VPORT_PDIN_PDIN6_RESETVAL    (0x00000000u)

#define CSL_VPORT_PDIN_PDIN5_MASK        (0x00000020u)
#define CSL_VPORT_PDIN_PDIN5_SHIFT       (0x00000005u)
#define CSL_VPORT_PDIN_PDIN5_RESETVAL    (0x00000000u)

#define CSL_VPORT_PDIN_PDIN4_MASK        (0x00000010u)
#define CSL_VPORT_PDIN_PDIN4_SHIFT       (0x00000004u)
#define CSL_VPORT_PDIN_PDIN4_RESETVAL    (0x00000000u)

#define CSL_VPORT_PDIN_PDIN3_MASK        (0x00000008u)
#define CSL_VPORT_PDIN_PDIN3_SHIFT       (0x00000003u)
#define CSL_VPORT_PDIN_PDIN3_RESETVAL    (0x00000000u)

#define CSL_VPORT_PDIN_PDIN2_MASK        (0x00000004u)
#define CSL_VPORT_PDIN_PDIN2_SHIFT       (0x00000002u)
#define CSL_VPORT_PDIN_PDIN2_RESETVAL    (0x00000000u)

#define CSL_VPORT_PDIN_PDIN1_MASK        (0x00000002u)
#define CSL_VPORT_PDIN_PDIN1_SHIFT       (0x00000001u)
#define CSL_VPORT_PDIN_PDIN1_RESETVAL    (0x00000000u)

#define CSL_VPORT_PDIN_PDIN0_MASK        (0x00000001u)
#define CSL_VPORT_PDIN_PDIN0_SHIFT       (0x00000000u)
#define CSL_VPORT_PDIN_PDIN0_RESETVAL    (0x00000000u)

#define CSL_VPORT_PDIN_RESETVAL          (0x00000000u)

/* PDOUT */


#define CSL_VPORT_PDOUT_PDOUT22_MASK     (0x00400000u)
#define CSL_VPORT_PDOUT_PDOUT22_SHIFT    (0x00000016u)
#define CSL_VPORT_PDOUT_PDOUT22_RESETVAL (0x00000000u)

#define CSL_VPORT_PDOUT_PDOUT21_MASK     (0x00200000u)
#define CSL_VPORT_PDOUT_PDOUT21_SHIFT    (0x00000015u)
#define CSL_VPORT_PDOUT_PDOUT21_RESETVAL (0x00000000u)

#define CSL_VPORT_PDOUT_PDOUT20_MASK     (0x00100000u)
#define CSL_VPORT_PDOUT_PDOUT20_SHIFT    (0x00000014u)
#define CSL_VPORT_PDOUT_PDOUT20_RESETVAL (0x00000000u)

#define CSL_VPORT_PDOUT_PDOUT19_MASK     (0x00080000u)
#define CSL_VPORT_PDOUT_PDOUT19_SHIFT    (0x00000013u)
#define CSL_VPORT_PDOUT_PDOUT19_RESETVAL (0x00000000u)

#define CSL_VPORT_PDOUT_PDOUT18_MASK     (0x00040000u)
#define CSL_VPORT_PDOUT_PDOUT18_SHIFT    (0x00000012u)
#define CSL_VPORT_PDOUT_PDOUT18_RESETVAL (0x00000000u)

#define CSL_VPORT_PDOUT_PDOUT17_MASK     (0x00020000u)
#define CSL_VPORT_PDOUT_PDOUT17_SHIFT    (0x00000011u)
#define CSL_VPORT_PDOUT_PDOUT17_RESETVAL (0x00000000u)

#define CSL_VPORT_PDOUT_PDOUT16_MASK     (0x00010000u)
#define CSL_VPORT_PDOUT_PDOUT16_SHIFT    (0x00000010u)
#define CSL_VPORT_PDOUT_PDOUT16_RESETVAL (0x00000000u)

#define CSL_VPORT_PDOUT_PDOUT15_MASK     (0x00008000u)
#define CSL_VPORT_PDOUT_PDOUT15_SHIFT    (0x0000000Fu)
#define CSL_VPORT_PDOUT_PDOUT15_RESETVAL (0x00000000u)

#define CSL_VPORT_PDOUT_PDOUT14_MASK     (0x00004000u)
#define CSL_VPORT_PDOUT_PDOUT14_SHIFT    (0x0000000Eu)
#define CSL_VPORT_PDOUT_PDOUT14_RESETVAL (0x00000000u)

#define CSL_VPORT_PDOUT_PDOUT13_MASK     (0x00002000u)
#define CSL_VPORT_PDOUT_PDOUT13_SHIFT    (0x0000000Du)
#define CSL_VPORT_PDOUT_PDOUT13_RESETVAL (0x00000000u)

#define CSL_VPORT_PDOUT_PDOUT12_MASK     (0x00001000u)
#define CSL_VPORT_PDOUT_PDOUT12_SHIFT    (0x0000000Cu)
#define CSL_VPORT_PDOUT_PDOUT12_RESETVAL (0x00000000u)

#define CSL_VPORT_PDOUT_PDOUT11_MASK     (0x00000800u)
#define CSL_VPORT_PDOUT_PDOUT11_SHIFT    (0x0000000Bu)
#define CSL_VPORT_PDOUT_PDOUT11_RESETVAL (0x00000000u)

#define CSL_VPORT_PDOUT_PDOUT10_MASK     (0x00000400u)
#define CSL_VPORT_PDOUT_PDOUT10_SHIFT    (0x0000000Au)
#define CSL_VPORT_PDOUT_PDOUT10_RESETVAL (0x00000000u)

#define CSL_VPORT_PDOUT_PDOUT9_MASK      (0x00000200u)
#define CSL_VPORT_PDOUT_PDOUT9_SHIFT     (0x00000009u)
#define CSL_VPORT_PDOUT_PDOUT9_RESETVAL  (0x00000000u)

#define CSL_VPORT_PDOUT_PDOUT8_MASK      (0x00000100u)
#define CSL_VPORT_PDOUT_PDOUT8_SHIFT     (0x00000008u)
#define CSL_VPORT_PDOUT_PDOUT8_RESETVAL  (0x00000000u)

#define CSL_VPORT_PDOUT_PDOUT7_MASK      (0x00000080u)
#define CSL_VPORT_PDOUT_PDOUT7_SHIFT     (0x00000007u)
#define CSL_VPORT_PDOUT_PDOUT7_RESETVAL  (0x00000000u)

#define CSL_VPORT_PDOUT_PDOUT6_MASK      (0x00000040u)
#define CSL_VPORT_PDOUT_PDOUT6_SHIFT     (0x00000006u)
#define CSL_VPORT_PDOUT_PDOUT6_RESETVAL  (0x00000000u)

#define CSL_VPORT_PDOUT_PDOUT5_MASK      (0x00000020u)
#define CSL_VPORT_PDOUT_PDOUT5_SHIFT     (0x00000005u)
#define CSL_VPORT_PDOUT_PDOUT5_RESETVAL  (0x00000000u)

#define CSL_VPORT_PDOUT_PDOUT4_MASK      (0x00000010u)
#define CSL_VPORT_PDOUT_PDOUT4_SHIFT     (0x00000004u)
#define CSL_VPORT_PDOUT_PDOUT4_RESETVAL  (0x00000000u)

#define CSL_VPORT_PDOUT_PDOUT3_MASK      (0x00000008u)
#define CSL_VPORT_PDOUT_PDOUT3_SHIFT     (0x00000003u)
#define CSL_VPORT_PDOUT_PDOUT3_RESETVAL  (0x00000000u)

#define CSL_VPORT_PDOUT_PDOUT2_MASK      (0x00000004u)
#define CSL_VPORT_PDOUT_PDOUT2_SHIFT     (0x00000002u)
#define CSL_VPORT_PDOUT_PDOUT2_RESETVAL  (0x00000000u)

#define CSL_VPORT_PDOUT_PDOUT1_MASK      (0x00000002u)
#define CSL_VPORT_PDOUT_PDOUT1_SHIFT     (0x00000001u)
#define CSL_VPORT_PDOUT_PDOUT1_RESETVAL  (0x00000000u)

#define CSL_VPORT_PDOUT_PDOUT0_MASK      (0x00000001u)
#define CSL_VPORT_PDOUT_PDOUT0_SHIFT     (0x00000000u)
#define CSL_VPORT_PDOUT_PDOUT0_RESETVAL  (0x00000000u)

#define CSL_VPORT_PDOUT_RESETVAL         (0x00000000u)

/* PDSET */


#define CSL_VPORT_PDSET_PDSET22_MASK     (0x00400000u)
#define CSL_VPORT_PDSET_PDSET22_SHIFT    (0x00000016u)
#define CSL_VPORT_PDSET_PDSET22_RESETVAL (0x00000000u)

#define CSL_VPORT_PDSET_PDSET21_MASK     (0x00200000u)
#define CSL_VPORT_PDSET_PDSET21_SHIFT    (0x00000015u)
#define CSL_VPORT_PDSET_PDSET21_RESETVAL (0x00000000u)

#define CSL_VPORT_PDSET_PDSET20_MASK     (0x00100000u)
#define CSL_VPORT_PDSET_PDSET20_SHIFT    (0x00000014u)
#define CSL_VPORT_PDSET_PDSET20_RESETVAL (0x00000000u)

#define CSL_VPORT_PDSET_PDSET19_MASK     (0x00080000u)
#define CSL_VPORT_PDSET_PDSET19_SHIFT    (0x00000013u)
#define CSL_VPORT_PDSET_PDSET19_RESETVAL (0x00000000u)

#define CSL_VPORT_PDSET_PDSET18_MASK     (0x00040000u)
#define CSL_VPORT_PDSET_PDSET18_SHIFT    (0x00000012u)
#define CSL_VPORT_PDSET_PDSET18_RESETVAL (0x00000000u)

#define CSL_VPORT_PDSET_PDSET17_MASK     (0x00020000u)
#define CSL_VPORT_PDSET_PDSET17_SHIFT    (0x00000011u)
#define CSL_VPORT_PDSET_PDSET17_RESETVAL (0x00000000u)

#define CSL_VPORT_PDSET_PDSET16_MASK     (0x00010000u)
#define CSL_VPORT_PDSET_PDSET16_SHIFT    (0x00000010u)
#define CSL_VPORT_PDSET_PDSET16_RESETVAL (0x00000000u)

#define CSL_VPORT_PDSET_PDSET15_MASK     (0x00008000u)
#define CSL_VPORT_PDSET_PDSET15_SHIFT    (0x0000000Fu)
#define CSL_VPORT_PDSET_PDSET15_RESETVAL (0x00000000u)

#define CSL_VPORT_PDSET_PDSET14_MASK     (0x00004000u)
#define CSL_VPORT_PDSET_PDSET14_SHIFT    (0x0000000Eu)
#define CSL_VPORT_PDSET_PDSET14_RESETVAL (0x00000000u)

#define CSL_VPORT_PDSET_PDSET13_MASK     (0x00002000u)
#define CSL_VPORT_PDSET_PDSET13_SHIFT    (0x0000000Du)
#define CSL_VPORT_PDSET_PDSET13_RESETVAL (0x00000000u)

#define CSL_VPORT_PDSET_PDSET12_MASK     (0x00001000u)
#define CSL_VPORT_PDSET_PDSET12_SHIFT    (0x0000000Cu)
#define CSL_VPORT_PDSET_PDSET12_RESETVAL (0x00000000u)

#define CSL_VPORT_PDSET_PDSET11_MASK     (0x00000800u)
#define CSL_VPORT_PDSET_PDSET11_SHIFT    (0x0000000Bu)
#define CSL_VPORT_PDSET_PDSET11_RESETVAL (0x00000000u)

#define CSL_VPORT_PDSET_PDSET10_MASK     (0x00000400u)
#define CSL_VPORT_PDSET_PDSET10_SHIFT    (0x0000000Au)
#define CSL_VPORT_PDSET_PDSET10_RESETVAL (0x00000000u)

#define CSL_VPORT_PDSET_PDSET9_MASK      (0x00000200u)
#define CSL_VPORT_PDSET_PDSET9_SHIFT     (0x00000009u)
#define CSL_VPORT_PDSET_PDSET9_RESETVAL  (0x00000000u)

#define CSL_VPORT_PDSET_PDSET8_MASK      (0x00000100u)
#define CSL_VPORT_PDSET_PDSET8_SHIFT     (0x00000008u)
#define CSL_VPORT_PDSET_PDSET8_RESETVAL  (0x00000000u)

#define CSL_VPORT_PDSET_PDSET7_MASK      (0x00000080u)
#define CSL_VPORT_PDSET_PDSET7_SHIFT     (0x00000007u)
#define CSL_VPORT_PDSET_PDSET7_RESETVAL  (0x00000000u)

#define CSL_VPORT_PDSET_PDSET6_MASK      (0x00000040u)
#define CSL_VPORT_PDSET_PDSET6_SHIFT     (0x00000006u)
#define CSL_VPORT_PDSET_PDSET6_RESETVAL  (0x00000000u)

#define CSL_VPORT_PDSET_PDSET5_MASK      (0x00000020u)
#define CSL_VPORT_PDSET_PDSET5_SHIFT     (0x00000005u)
#define CSL_VPORT_PDSET_PDSET5_RESETVAL  (0x00000000u)

#define CSL_VPORT_PDSET_PDSET4_MASK      (0x00000010u)
#define CSL_VPORT_PDSET_PDSET4_SHIFT     (0x00000004u)
#define CSL_VPORT_PDSET_PDSET4_RESETVAL  (0x00000000u)

#define CSL_VPORT_PDSET_PDSET3_MASK      (0x00000008u)
#define CSL_VPORT_PDSET_PDSET3_SHIFT     (0x00000003u)
#define CSL_VPORT_PDSET_PDSET3_RESETVAL  (0x00000000u)

#define CSL_VPORT_PDSET_PDSET2_MASK      (0x00000004u)
#define CSL_VPORT_PDSET_PDSET2_SHIFT     (0x00000002u)
#define CSL_VPORT_PDSET_PDSET2_RESETVAL  (0x00000000u)

#define CSL_VPORT_PDSET_PDSET1_MASK      (0x00000002u)
#define CSL_VPORT_PDSET_PDSET1_SHIFT     (0x00000001u)
#define CSL_VPORT_PDSET_PDSET1_RESETVAL  (0x00000000u)

#define CSL_VPORT_PDSET_PDSET0_MASK      (0x00000001u)
#define CSL_VPORT_PDSET_PDSET0_SHIFT     (0x00000000u)
#define CSL_VPORT_PDSET_PDSET0_RESETVAL  (0x00000000u)

#define CSL_VPORT_PDSET_RESETVAL         (0x00000000u)

/* PDCLR */


#define CSL_VPORT_PDCLR_PDCLR22_MASK     (0x00400000u)
#define CSL_VPORT_PDCLR_PDCLR22_SHIFT    (0x00000016u)
#define CSL_VPORT_PDCLR_PDCLR22_RESETVAL (0x00000000u)

#define CSL_VPORT_PDCLR_PDCLR21_MASK     (0x00200000u)
#define CSL_VPORT_PDCLR_PDCLR21_SHIFT    (0x00000015u)
#define CSL_VPORT_PDCLR_PDCLR21_RESETVAL (0x00000000u)

#define CSL_VPORT_PDCLR_PDCLR20_MASK     (0x00100000u)
#define CSL_VPORT_PDCLR_PDCLR20_SHIFT    (0x00000014u)
#define CSL_VPORT_PDCLR_PDCLR20_RESETVAL (0x00000000u)

#define CSL_VPORT_PDCLR_PDCLR19_MASK     (0x00080000u)
#define CSL_VPORT_PDCLR_PDCLR19_SHIFT    (0x00000013u)
#define CSL_VPORT_PDCLR_PDCLR19_RESETVAL (0x00000000u)

#define CSL_VPORT_PDCLR_PDCLR18_MASK     (0x00040000u)
#define CSL_VPORT_PDCLR_PDCLR18_SHIFT    (0x00000012u)
#define CSL_VPORT_PDCLR_PDCLR18_RESETVAL (0x00000000u)

#define CSL_VPORT_PDCLR_PDCLR17_MASK     (0x00020000u)
#define CSL_VPORT_PDCLR_PDCLR17_SHIFT    (0x00000011u)
#define CSL_VPORT_PDCLR_PDCLR17_RESETVAL (0x00000000u)

#define CSL_VPORT_PDCLR_PDCLR16_MASK     (0x00010000u)
#define CSL_VPORT_PDCLR_PDCLR16_SHIFT    (0x00000010u)
#define CSL_VPORT_PDCLR_PDCLR16_RESETVAL (0x00000000u)

#define CSL_VPORT_PDCLR_PDCLR15_MASK     (0x00008000u)
#define CSL_VPORT_PDCLR_PDCLR15_SHIFT    (0x0000000Fu)
#define CSL_VPORT_PDCLR_PDCLR15_RESETVAL (0x00000000u)

#define CSL_VPORT_PDCLR_PDCLR14_MASK     (0x00004000u)
#define CSL_VPORT_PDCLR_PDCLR14_SHIFT    (0x0000000Eu)
#define CSL_VPORT_PDCLR_PDCLR14_RESETVAL (0x00000000u)

#define CSL_VPORT_PDCLR_PDCLR13_MASK     (0x00002000u)
#define CSL_VPORT_PDCLR_PDCLR13_SHIFT    (0x0000000Du)
#define CSL_VPORT_PDCLR_PDCLR13_RESETVAL (0x00000000u)

#define CSL_VPORT_PDCLR_PDCLR12_MASK     (0x00001000u)
#define CSL_VPORT_PDCLR_PDCLR12_SHIFT    (0x0000000Cu)
#define CSL_VPORT_PDCLR_PDCLR12_RESETVAL (0x00000000u)

#define CSL_VPORT_PDCLR_PDCLR11_MASK     (0x00000800u)
#define CSL_VPORT_PDCLR_PDCLR11_SHIFT    (0x0000000Bu)
#define CSL_VPORT_PDCLR_PDCLR11_RESETVAL (0x00000000u)

#define CSL_VPORT_PDCLR_PDCLR10_MASK     (0x00000400u)
#define CSL_VPORT_PDCLR_PDCLR10_SHIFT    (0x0000000Au)
#define CSL_VPORT_PDCLR_PDCLR10_RESETVAL (0x00000000u)

#define CSL_VPORT_PDCLR_PDCLR9_MASK      (0x00000200u)
#define CSL_VPORT_PDCLR_PDCLR9_SHIFT     (0x00000009u)
#define CSL_VPORT_PDCLR_PDCLR9_RESETVAL  (0x00000000u)

#define CSL_VPORT_PDCLR_PDCLR8_MASK      (0x00000100u)
#define CSL_VPORT_PDCLR_PDCLR8_SHIFT     (0x00000008u)
#define CSL_VPORT_PDCLR_PDCLR8_RESETVAL  (0x00000000u)

#define CSL_VPORT_PDCLR_PDCLR7_MASK      (0x00000080u)
#define CSL_VPORT_PDCLR_PDCLR7_SHIFT     (0x00000007u)
#define CSL_VPORT_PDCLR_PDCLR7_RESETVAL  (0x00000000u)

#define CSL_VPORT_PDCLR_PDCLR6_MASK      (0x00000040u)
#define CSL_VPORT_PDCLR_PDCLR6_SHIFT     (0x00000006u)
#define CSL_VPORT_PDCLR_PDCLR6_RESETVAL  (0x00000000u)

#define CSL_VPORT_PDCLR_PDCLR5_MASK      (0x00000020u)
#define CSL_VPORT_PDCLR_PDCLR5_SHIFT     (0x00000005u)
#define CSL_VPORT_PDCLR_PDCLR5_RESETVAL  (0x00000000u)

#define CSL_VPORT_PDCLR_PDCLR4_MASK      (0x00000010u)
#define CSL_VPORT_PDCLR_PDCLR4_SHIFT     (0x00000004u)
#define CSL_VPORT_PDCLR_PDCLR4_RESETVAL  (0x00000000u)

#define CSL_VPORT_PDCLR_PDCLR3_MASK      (0x00000008u)
#define CSL_VPORT_PDCLR_PDCLR3_SHIFT     (0x00000003u)
#define CSL_VPORT_PDCLR_PDCLR3_RESETVAL  (0x00000000u)

#define CSL_VPORT_PDCLR_PDCLR2_MASK      (0x00000004u)
#define CSL_VPORT_PDCLR_PDCLR2_SHIFT     (0x00000002u)
#define CSL_VPORT_PDCLR_PDCLR2_RESETVAL  (0x00000000u)

#define CSL_VPORT_PDCLR_PDCLR1_MASK      (0x00000002u)
#define CSL_VPORT_PDCLR_PDCLR1_SHIFT     (0x00000001u)
#define CSL_VPORT_PDCLR_PDCLR1_RESETVAL  (0x00000000u)

#define CSL_VPORT_PDCLR_PDSET0_MASK      (0x00000001u)
#define CSL_VPORT_PDCLR_PDSET0_SHIFT     (0x00000000u)
#define CSL_VPORT_PDCLR_PDSET0_RESETVAL  (0x00000000u)

#define CSL_VPORT_PDCLR_RESETVAL         (0x00000000u)

/* PIEN */


#define CSL_VPORT_PIEN_PIEN22_MASK       (0x00400000u)
#define CSL_VPORT_PIEN_PIEN22_SHIFT      (0x00000016u)
#define CSL_VPORT_PIEN_PIEN22_RESETVAL   (0x00000000u)

#define CSL_VPORT_PIEN_PIEN21_MASK       (0x00200000u)
#define CSL_VPORT_PIEN_PIEN21_SHIFT      (0x00000015u)
#define CSL_VPORT_PIEN_PIEN21_RESETVAL   (0x00000000u)

#define CSL_VPORT_PIEN_PIEN20_MASK       (0x00100000u)
#define CSL_VPORT_PIEN_PIEN20_SHIFT      (0x00000014u)
#define CSL_VPORT_PIEN_PIEN20_RESETVAL   (0x00000000u)

#define CSL_VPORT_PIEN_PIEN19_MASK       (0x00080000u)
#define CSL_VPORT_PIEN_PIEN19_SHIFT      (0x00000013u)
#define CSL_VPORT_PIEN_PIEN19_RESETVAL   (0x00000000u)

#define CSL_VPORT_PIEN_PIEN18_MASK       (0x00040000u)
#define CSL_VPORT_PIEN_PIEN18_SHIFT      (0x00000012u)
#define CSL_VPORT_PIEN_PIEN18_RESETVAL   (0x00000000u)

#define CSL_VPORT_PIEN_PIEN17_MASK       (0x00020000u)
#define CSL_VPORT_PIEN_PIEN17_SHIFT      (0x00000011u)
#define CSL_VPORT_PIEN_PIEN17_RESETVAL   (0x00000000u)

#define CSL_VPORT_PIEN_PIEN16_MASK       (0x00010000u)
#define CSL_VPORT_PIEN_PIEN16_SHIFT      (0x00000010u)
#define CSL_VPORT_PIEN_PIEN16_RESETVAL   (0x00000000u)

#define CSL_VPORT_PIEN_PIEN15_MASK       (0x00008000u)
#define CSL_VPORT_PIEN_PIEN15_SHIFT      (0x0000000Fu)
#define CSL_VPORT_PIEN_PIEN15_RESETVAL   (0x00000000u)

#define CSL_VPORT_PIEN_PIEN14_MASK       (0x00004000u)
#define CSL_VPORT_PIEN_PIEN14_SHIFT      (0x0000000Eu)
#define CSL_VPORT_PIEN_PIEN14_RESETVAL   (0x00000000u)

#define CSL_VPORT_PIEN_PIEN13_MASK       (0x00002000u)
#define CSL_VPORT_PIEN_PIEN13_SHIFT      (0x0000000Du)
#define CSL_VPORT_PIEN_PIEN13_RESETVAL   (0x00000000u)

#define CSL_VPORT_PIEN_PIEN12_MASK       (0x00001000u)
#define CSL_VPORT_PIEN_PIEN12_SHIFT      (0x0000000Cu)
#define CSL_VPORT_PIEN_PIEN12_RESETVAL   (0x00000000u)

#define CSL_VPORT_PIEN_PIEN11_MASK       (0x00000800u)
#define CSL_VPORT_PIEN_PIEN11_SHIFT      (0x0000000Bu)
#define CSL_VPORT_PIEN_PIEN11_RESETVAL   (0x00000000u)

#define CSL_VPORT_PIEN_PIEN10_MASK       (0x00000400u)
#define CSL_VPORT_PIEN_PIEN10_SHIFT      (0x0000000Au)
#define CSL_VPORT_PIEN_PIEN10_RESETVAL   (0x00000000u)

#define CSL_VPORT_PIEN_PIEN9_MASK        (0x00000200u)
#define CSL_VPORT_PIEN_PIEN9_SHIFT       (0x00000009u)
#define CSL_VPORT_PIEN_PIEN9_RESETVAL    (0x00000000u)

#define CSL_VPORT_PIEN_PIEN8_MASK        (0x00000100u)
#define CSL_VPORT_PIEN_PIEN8_SHIFT       (0x00000008u)
#define CSL_VPORT_PIEN_PIEN8_RESETVAL    (0x00000000u)

#define CSL_VPORT_PIEN_PIEN7_MASK        (0x00000080u)
#define CSL_VPORT_PIEN_PIEN7_SHIFT       (0x00000007u)
#define CSL_VPORT_PIEN_PIEN7_RESETVAL    (0x00000000u)

#define CSL_VPORT_PIEN_PIEN6_MASK        (0x00000040u)
#define CSL_VPORT_PIEN_PIEN6_SHIFT       (0x00000006u)
#define CSL_VPORT_PIEN_PIEN6_RESETVAL    (0x00000000u)

#define CSL_VPORT_PIEN_PIEN5_MASK        (0x00000020u)
#define CSL_VPORT_PIEN_PIEN5_SHIFT       (0x00000005u)
#define CSL_VPORT_PIEN_PIEN5_RESETVAL    (0x00000000u)

#define CSL_VPORT_PIEN_PIEN4_MASK        (0x00000010u)
#define CSL_VPORT_PIEN_PIEN4_SHIFT       (0x00000004u)
#define CSL_VPORT_PIEN_PIEN4_RESETVAL    (0x00000000u)

#define CSL_VPORT_PIEN_PIEN3_MASK        (0x00000008u)
#define CSL_VPORT_PIEN_PIEN3_SHIFT       (0x00000003u)
#define CSL_VPORT_PIEN_PIEN3_RESETVAL    (0x00000000u)

#define CSL_VPORT_PIEN_PIEN2_MASK        (0x00000004u)
#define CSL_VPORT_PIEN_PIEN2_SHIFT       (0x00000002u)
#define CSL_VPORT_PIEN_PIEN2_RESETVAL    (0x00000000u)

#define CSL_VPORT_PIEN_PIEN1_MASK        (0x00000002u)
#define CSL_VPORT_PIEN_PIEN1_SHIFT       (0x00000001u)
#define CSL_VPORT_PIEN_PIEN1_RESETVAL    (0x00000000u)

#define CSL_VPORT_PIEN_PIEN0_MASK        (0x00000001u)
#define CSL_VPORT_PIEN_PIEN0_SHIFT       (0x00000000u)
#define CSL_VPORT_PIEN_PIEN0_RESETVAL    (0x00000000u)

#define CSL_VPORT_PIEN_PIEN0_MASK        (0x00000001u)
#define CSL_VPORT_PIEN_PIEN0_SHIFT       (0x00000000u)
#define CSL_VPORT_PIEN_PIEN0_RESETVAL    (0x00000000u)

#define CSL_VPORT_PIEN_RESETVAL          (0x00000000u)

/* PIPOL */


#define CSL_VPORT_PIPOL_PIPOL22_MASK     (0x00400000u)
#define CSL_VPORT_PIPOL_PIPOL22_SHIFT    (0x00000016u)
#define CSL_VPORT_PIPOL_PIPOL22_RESETVAL (0x00000000u)

#define CSL_VPORT_PIPOL_PIPOL21_MASK     (0x00200000u)
#define CSL_VPORT_PIPOL_PIPOL21_SHIFT    (0x00000015u)
#define CSL_VPORT_PIPOL_PIPOL21_RESETVAL (0x00000000u)

#define CSL_VPORT_PIPOL_PIPOL20_MASK     (0x00100000u)
#define CSL_VPORT_PIPOL_PIPOL20_SHIFT    (0x00000014u)
#define CSL_VPORT_PIPOL_PIPOL20_RESETVAL (0x00000000u)

#define CSL_VPORT_PIPOL_PIPOL19_MASK     (0x00080000u)
#define CSL_VPORT_PIPOL_PIPOL19_SHIFT    (0x00000013u)
#define CSL_VPORT_PIPOL_PIPOL19_RESETVAL (0x00000000u)

#define CSL_VPORT_PIPOL_PIPOL18_MASK     (0x00040000u)
#define CSL_VPORT_PIPOL_PIPOL18_SHIFT    (0x00000012u)
#define CSL_VPORT_PIPOL_PIPOL18_RESETVAL (0x00000000u)

#define CSL_VPORT_PIPOL_PIPOL17_MASK     (0x00020000u)
#define CSL_VPORT_PIPOL_PIPOL17_SHIFT    (0x00000011u)
#define CSL_VPORT_PIPOL_PIPOL17_RESETVAL (0x00000000u)

#define CSL_VPORT_PIPOL_PIPOL16_MASK     (0x00010000u)
#define CSL_VPORT_PIPOL_PIPOL16_SHIFT    (0x00000010u)
#define CSL_VPORT_PIPOL_PIPOL16_RESETVAL (0x00000000u)

#define CSL_VPORT_PIPOL_PIPOL15_MASK     (0x00008000u)
#define CSL_VPORT_PIPOL_PIPOL15_SHIFT    (0x0000000Fu)
#define CSL_VPORT_PIPOL_PIPOL15_RESETVAL (0x00000000u)

#define CSL_VPORT_PIPOL_PIPOL14_MASK     (0x00004000u)
#define CSL_VPORT_PIPOL_PIPOL14_SHIFT    (0x0000000Eu)
#define CSL_VPORT_PIPOL_PIPOL14_RESETVAL (0x00000000u)

#define CSL_VPORT_PIPOL_PIPOL13_MASK     (0x00002000u)
#define CSL_VPORT_PIPOL_PIPOL13_SHIFT    (0x0000000Du)
#define CSL_VPORT_PIPOL_PIPOL13_RESETVAL (0x00000000u)

#define CSL_VPORT_PIPOL_PIPOL12_MASK     (0x00001000u)
#define CSL_VPORT_PIPOL_PIPOL12_SHIFT    (0x0000000Cu)
#define CSL_VPORT_PIPOL_PIPOL12_RESETVAL (0x00000000u)

#define CSL_VPORT_PIPOL_PIPOL11_MASK     (0x00000800u)
#define CSL_VPORT_PIPOL_PIPOL11_SHIFT    (0x0000000Bu)
#define CSL_VPORT_PIPOL_PIPOL11_RESETVAL (0x00000000u)

#define CSL_VPORT_PIPOL_PIPOL10_MASK     (0x00000400u)
#define CSL_VPORT_PIPOL_PIPOL10_SHIFT    (0x0000000Au)
#define CSL_VPORT_PIPOL_PIPOL10_RESETVAL (0x00000000u)

#define CSL_VPORT_PIPOL_PIPOL9_MASK      (0x00000200u)
#define CSL_VPORT_PIPOL_PIPOL9_SHIFT     (0x00000009u)
#define CSL_VPORT_PIPOL_PIPOL9_RESETVAL  (0x00000000u)

#define CSL_VPORT_PIPOL_PIPOL8_MASK      (0x00000100u)
#define CSL_VPORT_PIPOL_PIPOL8_SHIFT     (0x00000008u)
#define CSL_VPORT_PIPOL_PIPOL8_RESETVAL  (0x00000000u)

#define CSL_VPORT_PIPOL_PIPOL7_MASK      (0x00000080u)
#define CSL_VPORT_PIPOL_PIPOL7_SHIFT     (0x00000007u)
#define CSL_VPORT_PIPOL_PIPOL7_RESETVAL  (0x00000000u)

#define CSL_VPORT_PIPOL_PIPOL6_MASK      (0x00000040u)
#define CSL_VPORT_PIPOL_PIPOL6_SHIFT     (0x00000006u)
#define CSL_VPORT_PIPOL_PIPOL6_RESETVAL  (0x00000000u)

#define CSL_VPORT_PIPOL_PIPOL5_MASK      (0x00000020u)
#define CSL_VPORT_PIPOL_PIPOL5_SHIFT     (0x00000005u)
#define CSL_VPORT_PIPOL_PIPOL5_RESETVAL  (0x00000000u)

#define CSL_VPORT_PIPOL_PIPOL4_MASK      (0x00000010u)
#define CSL_VPORT_PIPOL_PIPOL4_SHIFT     (0x00000004u)
#define CSL_VPORT_PIPOL_PIPOL4_RESETVAL  (0x00000000u)

#define CSL_VPORT_PIPOL_PIPOL3_MASK      (0x00000008u)
#define CSL_VPORT_PIPOL_PIPOL3_SHIFT     (0x00000003u)
#define CSL_VPORT_PIPOL_PIPOL3_RESETVAL  (0x00000000u)

#define CSL_VPORT_PIPOL_PIPOL2_MASK      (0x00000004u)
#define CSL_VPORT_PIPOL_PIPOL2_SHIFT     (0x00000002u)
#define CSL_VPORT_PIPOL_PIPOL2_RESETVAL  (0x00000000u)

#define CSL_VPORT_PIPOL_PIPOL1_MASK      (0x00000002u)
#define CSL_VPORT_PIPOL_PIPOL1_SHIFT     (0x00000001u)
#define CSL_VPORT_PIPOL_PIPOL1_RESETVAL  (0x00000000u)

#define CSL_VPORT_PIPOL_PIPOL0_MASK      (0x00000001u)
#define CSL_VPORT_PIPOL_PIPOL0_SHIFT     (0x00000000u)
#define CSL_VPORT_PIPOL_PIPOL0_RESETVAL  (0x00000000u)

#define CSL_VPORT_PIPOL_RESETVAL         (0x00000000u)

/* PISTAT */


#define CSL_VPORT_PISTAT_PISTAT22_MASK   (0x00400000u)
#define CSL_VPORT_PISTAT_PISTAT22_SHIFT  (0x00000016u)
#define CSL_VPORT_PISTAT_PISTAT22_RESETVAL (0x00000000u)

#define CSL_VPORT_PISTAT_PISTAT21_MASK   (0x00200000u)
#define CSL_VPORT_PISTAT_PISTAT21_SHIFT  (0x00000015u)
#define CSL_VPORT_PISTAT_PISTAT21_RESETVAL (0x00000000u)

#define CSL_VPORT_PISTAT_PISTAT20_MASK   (0x00100000u)
#define CSL_VPORT_PISTAT_PISTAT20_SHIFT  (0x00000014u)
#define CSL_VPORT_PISTAT_PISTAT20_RESETVAL (0x00000000u)

#define CSL_VPORT_PISTAT_PISTAT19_MASK   (0x00080000u)
#define CSL_VPORT_PISTAT_PISTAT19_SHIFT  (0x00000013u)
#define CSL_VPORT_PISTAT_PISTAT19_RESETVAL (0x00000000u)

#define CSL_VPORT_PISTAT_PISTAT18_MASK   (0x00040000u)
#define CSL_VPORT_PISTAT_PISTAT18_SHIFT  (0x00000012u)
#define CSL_VPORT_PISTAT_PISTAT18_RESETVAL (0x00000000u)

#define CSL_VPORT_PISTAT_PISTAT17_MASK   (0x00020000u)
#define CSL_VPORT_PISTAT_PISTAT17_SHIFT  (0x00000011u)
#define CSL_VPORT_PISTAT_PISTAT17_RESETVAL (0x00000000u)

#define CSL_VPORT_PISTAT_PISTAT16_MASK   (0x00010000u)
#define CSL_VPORT_PISTAT_PISTAT16_SHIFT  (0x00000010u)
#define CSL_VPORT_PISTAT_PISTAT16_RESETVAL (0x00000000u)

#define CSL_VPORT_PISTAT_PISTAT15_MASK   (0x00008000u)
#define CSL_VPORT_PISTAT_PISTAT15_SHIFT  (0x0000000Fu)
#define CSL_VPORT_PISTAT_PISTAT15_RESETVAL (0x00000000u)

#define CSL_VPORT_PISTAT_PISTAT14_MASK   (0x00004000u)
#define CSL_VPORT_PISTAT_PISTAT14_SHIFT  (0x0000000Eu)
#define CSL_VPORT_PISTAT_PISTAT14_RESETVAL (0x00000000u)

#define CSL_VPORT_PISTAT_PISTAT13_MASK   (0x00002000u)
#define CSL_VPORT_PISTAT_PISTAT13_SHIFT  (0x0000000Du)
#define CSL_VPORT_PISTAT_PISTAT13_RESETVAL (0x00000000u)

#define CSL_VPORT_PISTAT_PISTAT12_MASK   (0x00001000u)
#define CSL_VPORT_PISTAT_PISTAT12_SHIFT  (0x0000000Cu)
#define CSL_VPORT_PISTAT_PISTAT12_RESETVAL (0x00000000u)

#define CSL_VPORT_PISTAT_PISTAT11_MASK   (0x00000800u)
#define CSL_VPORT_PISTAT_PISTAT11_SHIFT  (0x0000000Bu)
#define CSL_VPORT_PISTAT_PISTAT11_RESETVAL (0x00000000u)

#define CSL_VPORT_PISTAT_PISTAT10_MASK   (0x00000400u)
#define CSL_VPORT_PISTAT_PISTAT10_SHIFT  (0x0000000Au)
#define CSL_VPORT_PISTAT_PISTAT10_RESETVAL (0x00000000u)

#define CSL_VPORT_PISTAT_PISTAT9_MASK    (0x00000200u)
#define CSL_VPORT_PISTAT_PISTAT9_SHIFT   (0x00000009u)
#define CSL_VPORT_PISTAT_PISTAT9_RESETVAL (0x00000000u)

#define CSL_VPORT_PISTAT_PISTAT8_MASK    (0x00000100u)
#define CSL_VPORT_PISTAT_PISTAT8_SHIFT   (0x00000008u)
#define CSL_VPORT_PISTAT_PISTAT8_RESETVAL (0x00000000u)

#define CSL_VPORT_PISTAT_PISTAT7_MASK    (0x00000080u)
#define CSL_VPORT_PISTAT_PISTAT7_SHIFT   (0x00000007u)
#define CSL_VPORT_PISTAT_PISTAT7_RESETVAL (0x00000000u)

#define CSL_VPORT_PISTAT_PISTAT6_MASK    (0x00000040u)
#define CSL_VPORT_PISTAT_PISTAT6_SHIFT   (0x00000006u)
#define CSL_VPORT_PISTAT_PISTAT6_RESETVAL (0x00000000u)

#define CSL_VPORT_PISTAT_PISTAT5_MASK    (0x00000020u)
#define CSL_VPORT_PISTAT_PISTAT5_SHIFT   (0x00000005u)
#define CSL_VPORT_PISTAT_PISTAT5_RESETVAL (0x00000000u)

#define CSL_VPORT_PISTAT_PISTAT4_MASK    (0x00000010u)
#define CSL_VPORT_PISTAT_PISTAT4_SHIFT   (0x00000004u)
#define CSL_VPORT_PISTAT_PISTAT4_RESETVAL (0x00000000u)

#define CSL_VPORT_PISTAT_PISTAT3_MASK    (0x00000008u)
#define CSL_VPORT_PISTAT_PISTAT3_SHIFT   (0x00000003u)
#define CSL_VPORT_PISTAT_PISTAT3_RESETVAL (0x00000000u)

#define CSL_VPORT_PISTAT_PISTAT2_MASK    (0x00000004u)
#define CSL_VPORT_PISTAT_PISTAT2_SHIFT   (0x00000002u)
#define CSL_VPORT_PISTAT_PISTAT2_RESETVAL (0x00000000u)

#define CSL_VPORT_PISTAT_PISTAT1_MASK    (0x00000002u)
#define CSL_VPORT_PISTAT_PISTAT1_SHIFT   (0x00000001u)
#define CSL_VPORT_PISTAT_PISTAT1_RESETVAL (0x00000000u)

#define CSL_VPORT_PISTAT_PISTAT0_MASK    (0x00000001u)
#define CSL_VPORT_PISTAT_PISTAT0_SHIFT   (0x00000000u)
#define CSL_VPORT_PISTAT_PISTAT0_RESETVAL (0x00000000u)

#define CSL_VPORT_PISTAT_RESETVAL        (0x00000000u)

/* PICLR */


#define CSL_VPORT_PICLR_PICLR22_MASK     (0x00400000u)
#define CSL_VPORT_PICLR_PICLR22_SHIFT    (0x00000016u)
#define CSL_VPORT_PICLR_PICLR22_RESETVAL (0x00000000u)

#define CSL_VPORT_PICLR_PICLR21_MASK     (0x00200000u)
#define CSL_VPORT_PICLR_PICLR21_SHIFT    (0x00000015u)
#define CSL_VPORT_PICLR_PICLR21_RESETVAL (0x00000000u)

#define CSL_VPORT_PICLR_PICLR20_MASK     (0x00100000u)
#define CSL_VPORT_PICLR_PICLR20_SHIFT    (0x00000014u)
#define CSL_VPORT_PICLR_PICLR20_RESETVAL (0x00000000u)

#define CSL_VPORT_PICLR_PICLR19_MASK     (0x00080000u)
#define CSL_VPORT_PICLR_PICLR19_SHIFT    (0x00000013u)
#define CSL_VPORT_PICLR_PICLR19_RESETVAL (0x00000000u)

#define CSL_VPORT_PICLR_PICLR18_MASK     (0x00040000u)
#define CSL_VPORT_PICLR_PICLR18_SHIFT    (0x00000012u)
#define CSL_VPORT_PICLR_PICLR18_RESETVAL (0x00000000u)

#define CSL_VPORT_PICLR_PICLR17_MASK     (0x00020000u)
#define CSL_VPORT_PICLR_PICLR17_SHIFT    (0x00000011u)
#define CSL_VPORT_PICLR_PICLR17_RESETVAL (0x00000000u)

#define CSL_VPORT_PICLR_PICLR16_MASK     (0x00010000u)
#define CSL_VPORT_PICLR_PICLR16_SHIFT    (0x00000010u)
#define CSL_VPORT_PICLR_PICLR16_RESETVAL (0x00000000u)

#define CSL_VPORT_PICLR_PICLR15_MASK     (0x00008000u)
#define CSL_VPORT_PICLR_PICLR15_SHIFT    (0x0000000Fu)
#define CSL_VPORT_PICLR_PICLR15_RESETVAL (0x00000000u)

#define CSL_VPORT_PICLR_PICLR14_MASK     (0x00004000u)
#define CSL_VPORT_PICLR_PICLR14_SHIFT    (0x0000000Eu)
#define CSL_VPORT_PICLR_PICLR14_RESETVAL (0x00000000u)

#define CSL_VPORT_PICLR_PICLR13_MASK     (0x00002000u)
#define CSL_VPORT_PICLR_PICLR13_SHIFT    (0x0000000Du)
#define CSL_VPORT_PICLR_PICLR13_RESETVAL (0x00000000u)

#define CSL_VPORT_PICLR_PICLR12_MASK     (0x00001000u)
#define CSL_VPORT_PICLR_PICLR12_SHIFT    (0x0000000Cu)
#define CSL_VPORT_PICLR_PICLR12_RESETVAL (0x00000000u)

#define CSL_VPORT_PICLR_PICLR11_MASK     (0x00000800u)
#define CSL_VPORT_PICLR_PICLR11_SHIFT    (0x0000000Bu)
#define CSL_VPORT_PICLR_PICLR11_RESETVAL (0x00000000u)

#define CSL_VPORT_PICLR_PICLR10_MASK     (0x00000400u)
#define CSL_VPORT_PICLR_PICLR10_SHIFT    (0x0000000Au)
#define CSL_VPORT_PICLR_PICLR10_RESETVAL (0x00000000u)

#define CSL_VPORT_PICLR_PICLR9_MASK      (0x00000200u)
#define CSL_VPORT_PICLR_PICLR9_SHIFT     (0x00000009u)
#define CSL_VPORT_PICLR_PICLR9_RESETVAL  (0x00000000u)

#define CSL_VPORT_PICLR_PICLR8_MASK      (0x00000100u)
#define CSL_VPORT_PICLR_PICLR8_SHIFT     (0x00000008u)
#define CSL_VPORT_PICLR_PICLR8_RESETVAL  (0x00000000u)

#define CSL_VPORT_PICLR_PICLR7_MASK      (0x00000080u)
#define CSL_VPORT_PICLR_PICLR7_SHIFT     (0x00000007u)
#define CSL_VPORT_PICLR_PICLR7_RESETVAL  (0x00000000u)

#define CSL_VPORT_PICLR_PICLR6_MASK      (0x00000040u)
#define CSL_VPORT_PICLR_PICLR6_SHIFT     (0x00000006u)
#define CSL_VPORT_PICLR_PICLR6_RESETVAL  (0x00000000u)

#define CSL_VPORT_PICLR_PICLR5_MASK      (0x00000020u)
#define CSL_VPORT_PICLR_PICLR5_SHIFT     (0x00000005u)
#define CSL_VPORT_PICLR_PICLR5_RESETVAL  (0x00000000u)

#define CSL_VPORT_PICLR_PICLR4_MASK      (0x00000010u)
#define CSL_VPORT_PICLR_PICLR4_SHIFT     (0x00000004u)
#define CSL_VPORT_PICLR_PICLR4_RESETVAL  (0x00000000u)

#define CSL_VPORT_PICLR_PICLR3_MASK      (0x00000008u)
#define CSL_VPORT_PICLR_PICLR3_SHIFT     (0x00000003u)
#define CSL_VPORT_PICLR_PICLR3_RESETVAL  (0x00000000u)

#define CSL_VPORT_PICLR_PICLR2_MASK      (0x00000004u)
#define CSL_VPORT_PICLR_PICLR2_SHIFT     (0x00000002u)
#define CSL_VPORT_PICLR_PICLR2_RESETVAL  (0x00000000u)

#define CSL_VPORT_PICLR_PICLR1_MASK      (0x00000002u)
#define CSL_VPORT_PICLR_PICLR1_SHIFT     (0x00000001u)
#define CSL_VPORT_PICLR_PICLR1_RESETVAL  (0x00000000u)

#define CSL_VPORT_PICLR_PICLR0_MASK      (0x00000001u)
#define CSL_VPORT_PICLR_PICLR0_SHIFT     (0x00000000u)
#define CSL_VPORT_PICLR_PICLR0_RESETVAL  (0x00000000u)

#define CSL_VPORT_PICLR_RESETVAL         (0x00000000u)

/* VP_CTL */


#define CSL_VPORT_VP_CTL_VPRST_MASK      (0x00008000u)
#define CSL_VPORT_VP_CTL_VPRST_SHIFT     (0x0000000Fu)
#define CSL_VPORT_VP_CTL_VPRST_RESETVAL  (0x00000000u)

#define CSL_VPORT_VP_CTL_VPHLT_MASK      (0x00004000u)
#define CSL_VPORT_VP_CTL_VPHLT_SHIFT     (0x0000000Eu)
#define CSL_VPORT_VP_CTL_VPHLT_RESETVAL  (0x00000001u)


#define CSL_VPORT_VP_CTL_VCLK2P_MASK     (0x00000080u)
#define CSL_VPORT_VP_CTL_VCLK2P_SHIFT    (0x00000007u)
#define CSL_VPORT_VP_CTL_VCLK2P_RESETVAL (0x00000000u)

#define CSL_VPORT_VP_CTL_VCT3P_MASK      (0x00000040u)
#define CSL_VPORT_VP_CTL_VCT3P_SHIFT     (0x00000006u)
#define CSL_VPORT_VP_CTL_VCT3P_RESETVAL  (0x00000000u)

#define CSL_VPORT_VP_CTL_VCT2P_MASK      (0x00000020u)
#define CSL_VPORT_VP_CTL_VCT2P_SHIFT     (0x00000005u)
#define CSL_VPORT_VP_CTL_VCT2P_RESETVAL  (0x00000000u)

#define CSL_VPORT_VP_CTL_VCT1P_MASK      (0x00000010u)
#define CSL_VPORT_VP_CTL_VCT1P_SHIFT     (0x00000004u)
#define CSL_VPORT_VP_CTL_VCT1P_RESETVAL  (0x00000000u)


#define CSL_VPORT_VP_CTL_TCI_MASK        (0x00000004u)
#define CSL_VPORT_VP_CTL_TCI_SHIFT       (0x00000002u)
#define CSL_VPORT_VP_CTL_TCI_RESETVAL    (0x00000000u)

#define CSL_VPORT_VP_CTL_DISP_MASK       (0x00000002u)
#define CSL_VPORT_VP_CTL_DISP_SHIFT      (0x00000001u)
#define CSL_VPORT_VP_CTL_DISP_RESETVAL   (0x00000000u)

#define CSL_VPORT_VP_CTL_2CHNL_MASK      (0x00000001u)
#define CSL_VPORT_VP_CTL_2CHNL_SHIFT     (0x00000000u)
#define CSL_VPORT_VP_CTL_2CHNL_RESETVAL  (0x00000000u)

#define CSL_VPORT_VP_CTL_RESETVAL        (0x00004000u)

/* VP_STAT */



#define CSL_VPORT_VP_STAT_2CDIS_MASK     (0x00000008u)
#define CSL_VPORT_VP_STAT_2CDIS_SHIFT    (0x00000003u)
#define CSL_VPORT_VP_STAT_2CDIS_RESETVAL (0x00000000u)

#define CSL_VPORT_VP_STAT_PWDTH_MASK     (0x00000003u)
#define CSL_VPORT_VP_STAT_PWDTH_SHIFT    (0x00000000u)
#define CSL_VPORT_VP_STAT_PWDTH_RESETVAL (0x00000000u)

#define CSL_VPORT_VP_STAT_HIDATA_MASK    (0x00000004u)
#define CSL_VPORT_VP_STAT_HIDATA_SHIFT   (0x00000002u)
#define CSL_VPORT_VP_STAT_HIDATA_RESETVAL (0x00000000u)


#define CSL_VPORT_VP_STAT_RESETVAL       (0x00000000u)

/* VP_IE */


#define CSL_VPORT_VP_IE_LFDB_MASK        (0x00800000u)
#define CSL_VPORT_VP_IE_LFDB_SHIFT       (0x00000017u)
#define CSL_VPORT_VP_IE_LFDB_RESETVAL    (0x00000000u)

#define CSL_VPORT_VP_IE_SFDB_MASK        (0x00400000u)
#define CSL_VPORT_VP_IE_SFDB_SHIFT       (0x00000016u)
#define CSL_VPORT_VP_IE_SFDB_RESETVAL    (0x00000000u)

#define CSL_VPORT_VP_IE_VINTB2_MASK      (0x00200000u)
#define CSL_VPORT_VP_IE_VINTB2_SHIFT     (0x00000015u)
#define CSL_VPORT_VP_IE_VINTB2_RESETVAL  (0x00000000u)

#define CSL_VPORT_VP_IE_VINTB1_MASK      (0x00100000u)
#define CSL_VPORT_VP_IE_VINTB1_SHIFT     (0x00000014u)
#define CSL_VPORT_VP_IE_VINTB1_RESETVAL  (0x00000000u)

#define CSL_VPORT_VP_IE_SERRB_MASK       (0x00080000u)
#define CSL_VPORT_VP_IE_SERRB_SHIFT      (0x00000013u)
#define CSL_VPORT_VP_IE_SERRB_RESETVAL   (0x00000000u)

#define CSL_VPORT_VP_IE_CCMPB_MASK       (0x00040000u)
#define CSL_VPORT_VP_IE_CCMPB_SHIFT      (0x00000012u)
#define CSL_VPORT_VP_IE_CCMPB_RESETVAL   (0x00000000u)

#define CSL_VPORT_VP_IE_COVRB_MASK       (0x00020000u)
#define CSL_VPORT_VP_IE_COVRB_SHIFT      (0x00000011u)
#define CSL_VPORT_VP_IE_COVRB_RESETVAL   (0x00000000u)

#define CSL_VPORT_VP_IE_GPIO_MASK        (0x00010000u)
#define CSL_VPORT_VP_IE_GPIO_SHIFT       (0x00000010u)
#define CSL_VPORT_VP_IE_GPIO_RESETVAL    (0x00000000u)


#define CSL_VPORT_VP_IE_DCNA_MASK        (0x00004000u)
#define CSL_VPORT_VP_IE_DCNA_SHIFT       (0x0000000Eu)
#define CSL_VPORT_VP_IE_DCNA_RESETVAL    (0x00000000u)

#define CSL_VPORT_VP_IE_DCMP_MASK        (0x00002000u)
#define CSL_VPORT_VP_IE_DCMP_SHIFT       (0x0000000Du)
#define CSL_VPORT_VP_IE_DCMP_RESETVAL    (0x00000000u)

#define CSL_VPORT_VP_IE_DUND_MASK        (0x00001000u)
#define CSL_VPORT_VP_IE_DUND_SHIFT       (0x0000000Cu)
#define CSL_VPORT_VP_IE_DUND_RESETVAL    (0x00000000u)

#define CSL_VPORT_VP_IE_TICK_MASK        (0x00000800u)
#define CSL_VPORT_VP_IE_TICK_SHIFT       (0x0000000Bu)
#define CSL_VPORT_VP_IE_TICK_RESETVAL    (0x00000000u)

#define CSL_VPORT_VP_IE_STC_MASK         (0x00000400u)
#define CSL_VPORT_VP_IE_STC_SHIFT        (0x0000000Au)
#define CSL_VPORT_VP_IE_STC_RESETVAL     (0x00000000u)


#define CSL_VPORT_VP_IE_LFDA_MASK        (0x00000080u)
#define CSL_VPORT_VP_IE_LFDA_SHIFT       (0x00000007u)
#define CSL_VPORT_VP_IE_LFDA_RESETVAL    (0x00000000u)

#define CSL_VPORT_VP_IE_SFDA_MASK        (0x00000040u)
#define CSL_VPORT_VP_IE_SFDA_SHIFT       (0x00000006u)
#define CSL_VPORT_VP_IE_SFDA_RESETVAL    (0x00000000u)

#define CSL_VPORT_VP_IE_VINTA2_MASK      (0x00000020u)
#define CSL_VPORT_VP_IE_VINTA2_SHIFT     (0x00000005u)
#define CSL_VPORT_VP_IE_VINTA2_RESETVAL  (0x00000000u)

#define CSL_VPORT_VP_IE_VINTA1_MASK      (0x00000010u)
#define CSL_VPORT_VP_IE_VINTA1_SHIFT     (0x00000004u)
#define CSL_VPORT_VP_IE_VINTA1_RESETVAL  (0x00000000u)

#define CSL_VPORT_VP_IE_SERRA_MASK       (0x00000008u)
#define CSL_VPORT_VP_IE_SERRA_SHIFT      (0x00000003u)
#define CSL_VPORT_VP_IE_SERRA_RESETVAL   (0x00000000u)

#define CSL_VPORT_VP_IE_CCMPA_MASK       (0x00000004u)
#define CSL_VPORT_VP_IE_CCMPA_SHIFT      (0x00000002u)
#define CSL_VPORT_VP_IE_CCMPA_RESETVAL   (0x00000000u)

#define CSL_VPORT_VP_IE_COVRA_MASK       (0x00000002u)
#define CSL_VPORT_VP_IE_COVRA_SHIFT      (0x00000001u)
#define CSL_VPORT_VP_IE_COVRA_RESETVAL   (0x00000000u)

#define CSL_VPORT_VP_IE_VIE_MASK         (0x00000001u)
#define CSL_VPORT_VP_IE_VIE_SHIFT        (0x00000000u)
#define CSL_VPORT_VP_IE_VIE_RESETVAL     (0x00000000u)

#define CSL_VPORT_VP_IE_RESETVAL         (0x00000000u)

/* VP_IS */


#define CSL_VPORT_VP_IS_LFDB_MASK        (0x00800000u)
#define CSL_VPORT_VP_IS_LFDB_SHIFT       (0x00000017u)
#define CSL_VPORT_VP_IS_LFDB_RESETVAL    (0x00000000u)

#define CSL_VPORT_VP_IS_SFDB_MASK        (0x00400000u)
#define CSL_VPORT_VP_IS_SFDB_SHIFT       (0x00000016u)
#define CSL_VPORT_VP_IS_SFDB_RESETVAL    (0x00000000u)

#define CSL_VPORT_VP_IS_VINTB2_MASK      (0x00200000u)
#define CSL_VPORT_VP_IS_VINTB2_SHIFT     (0x00000015u)
#define CSL_VPORT_VP_IS_VINTB2_RESETVAL  (0x00000000u)

#define CSL_VPORT_VP_IS_VINTB1_MASK      (0x00100000u)
#define CSL_VPORT_VP_IS_VINTB1_SHIFT     (0x00000014u)
#define CSL_VPORT_VP_IS_VINTB1_RESETVAL  (0x00000000u)

#define CSL_VPORT_VP_IS_SERRB_MASK       (0x00080000u)
#define CSL_VPORT_VP_IS_SERRB_SHIFT      (0x00000013u)
#define CSL_VPORT_VP_IS_SERRB_RESETVAL   (0x00000000u)

#define CSL_VPORT_VP_IS_CCMPB_MASK       (0x00040000u)
#define CSL_VPORT_VP_IS_CCMPB_SHIFT      (0x00000012u)
#define CSL_VPORT_VP_IS_CCMPB_RESETVAL   (0x00000000u)

#define CSL_VPORT_VP_IS_COVRB_MASK       (0x00020000u)
#define CSL_VPORT_VP_IS_COVRB_SHIFT      (0x00000011u)
#define CSL_VPORT_VP_IS_COVRB_RESETVAL   (0x00000000u)

#define CSL_VPORT_VP_IS_GPIO_MASK        (0x00010000u)
#define CSL_VPORT_VP_IS_GPIO_SHIFT       (0x00000010u)
#define CSL_VPORT_VP_IS_GPIO_RESETVAL    (0x00000000u)


#define CSL_VPORT_VP_IS_DCNA_MASK        (0x00004000u)
#define CSL_VPORT_VP_IS_DCNA_SHIFT       (0x0000000Eu)
#define CSL_VPORT_VP_IS_DCNA_RESETVAL    (0x00000000u)

#define CSL_VPORT_VP_IS_DCMP_MASK        (0x00002000u)
#define CSL_VPORT_VP_IS_DCMP_SHIFT       (0x0000000Du)
#define CSL_VPORT_VP_IS_DCMP_RESETVAL    (0x00000000u)

#define CSL_VPORT_VP_IS_DUND_MASK        (0x00001000u)
#define CSL_VPORT_VP_IS_DUND_SHIFT       (0x0000000Cu)
#define CSL_VPORT_VP_IS_DUND_RESETVAL    (0x00000000u)

#define CSL_VPORT_VP_IS_TICK_MASK        (0x00000800u)
#define CSL_VPORT_VP_IS_TICK_SHIFT       (0x0000000Bu)
#define CSL_VPORT_VP_IS_TICK_RESETVAL    (0x00000000u)

#define CSL_VPORT_VP_IS_STC_MASK         (0x00000400u)
#define CSL_VPORT_VP_IS_STC_SHIFT        (0x0000000Au)
#define CSL_VPORT_VP_IS_STC_RESETVAL     (0x00000000u)


#define CSL_VPORT_VP_IS_LFDA_MASK        (0x00000080u)
#define CSL_VPORT_VP_IS_LFDA_SHIFT       (0x00000007u)
#define CSL_VPORT_VP_IS_LFDA_RESETVAL    (0x00000000u)

#define CSL_VPORT_VP_IS_SFDA_MASK        (0x00000040u)
#define CSL_VPORT_VP_IS_SFDA_SHIFT       (0x00000006u)
#define CSL_VPORT_VP_IS_SFDA_RESETVAL    (0x00000000u)

#define CSL_VPORT_VP_IS_VINTA2_MASK      (0x00000020u)
#define CSL_VPORT_VP_IS_VINTA2_SHIFT     (0x00000005u)
#define CSL_VPORT_VP_IS_VINTA2_RESETVAL  (0x00000000u)

#define CSL_VPORT_VP_IS_VINTA1_MASK      (0x00000010u)
#define CSL_VPORT_VP_IS_VINTA1_SHIFT     (0x00000004u)
#define CSL_VPORT_VP_IS_VINTA1_RESETVAL  (0x00000000u)

#define CSL_VPORT_VP_IS_SERRA_MASK       (0x00000008u)
#define CSL_VPORT_VP_IS_SERRA_SHIFT      (0x00000003u)
#define CSL_VPORT_VP_IS_SERRA_RESETVAL   (0x00000000u)

#define CSL_VPORT_VP_IS_CCMPA_MASK       (0x00000004u)
#define CSL_VPORT_VP_IS_CCMPA_SHIFT      (0x00000002u)
#define CSL_VPORT_VP_IS_CCMPA_RESETVAL   (0x00000000u)

#define CSL_VPORT_VP_IS_COVRA_MASK       (0x00000002u)
#define CSL_VPORT_VP_IS_COVRA_SHIFT      (0x00000001u)
#define CSL_VPORT_VP_IS_COVRA_RESETVAL   (0x00000000u)


#define CSL_VPORT_VP_IS_RESETVAL         (0x00000000u)

/* VC_STAT */

#define CSL_VPORT_VC_STAT_FSYNC_MASK    (0x80000000u)
#define CSL_VPORT_VC_STAT_FSYNC_SHIFT   (0x0000001Fu)
#define CSL_VPORT_VC_STAT_FSYNC_RESETVAL (0x00000000u)

#define CSL_VPORT_VC_STAT_FRMC_MASK     (0x40000000u)
#define CSL_VPORT_VC_STAT_FRMC_SHIFT    (0x0000001Eu)
#define CSL_VPORT_VC_STAT_FRMC_RESETVAL (0x00000000u)

#define CSL_VPORT_VC_STAT_F2C_MASK      (0x20000000u)
#define CSL_VPORT_VC_STAT_F2C_SHIFT     (0x0000001Du)
#define CSL_VPORT_VC_STAT_F2C_RESETVAL  (0x00000000u)

#define CSL_VPORT_VC_STAT_F1C_MASK      (0x10000000u)
#define CSL_VPORT_VC_STAT_F1C_SHIFT     (0x0000001Cu)
#define CSL_VPORT_VC_STAT_F1C_RESETVAL  (0x00000000u)

#define CSL_VPORT_VC_STAT_VC_YPOS_MASK  (0x0FFF0000u)
#define CSL_VPORT_VC_STAT_VC_YPOS_SHIFT (0x00000010u)
#define CSL_VPORT_VC_STAT_VC_YPOS_RESETVAL (0x00000000u)

//TODO :Check with module owner
#define CSL_VPORT_VC_STAT_VCFLD_MASK       (0x00001000u)
#define CSL_VPORT_VC_STAT_VCFLD_SHIFT      (0x0000000Cu)
#define CSL_VPORT_VC_STAT_VCFLD_RESETVAL   (0x00000000u)

#define CSL_VPORT_VC_STAT_VC_XPOS_MASK  (0x00000FFFu)
#define CSL_VPORT_VC_STAT_VC_XPOS_SHIFT (0x00000000u)
#define CSL_VPORT_VC_STAT_VC_XPOS_RESETVAL (0x00000000u)

#define CSL_VPORT_VC_STAT_RESETVAL      (0x00000000u)

/* VC_CTL */

#define CSL_VPORT_VC_CTL_RSTCH_MASK     (0x80000000u)
#define CSL_VPORT_VC_CTL_RSTCH_SHIFT    (0x0000001Fu)
#define CSL_VPORT_VC_CTL_RSTCH_RESETVAL (0x00000000u)

#define CSL_VPORT_VC_CTL_BLKCAP_MASK    (0x40000000u)
#define CSL_VPORT_VC_CTL_BLKCAP_SHIFT   (0x0000001Eu)
#define CSL_VPORT_VC_CTL_BLKCAP_RESETVAL (0x00000001u)


#define CSL_VPORT_VC_CTL_RDFE_MASK      (0x00200000u)
#define CSL_VPORT_VC_CTL_RDFE_SHIFT     (0x00000015u)
#define CSL_VPORT_VC_CTL_RDFE_RESETVAL  (0x00000000u)

#define CSL_VPORT_VC_CTL_FINV_MASK      (0x00100000u)
#define CSL_VPORT_VC_CTL_FINV_SHIFT     (0x00000014u)
#define CSL_VPORT_VC_CTL_FINV_RESETVAL  (0x00000000u)

#define CSL_VPORT_VC_CTL_EXC_MASK       (0x00080000u)
#define CSL_VPORT_VC_CTL_EXC_SHIFT      (0x00000013u)
#define CSL_VPORT_VC_CTL_EXC_RESETVAL   (0x00000000u)

#define CSL_VPORT_VC_CTL_FLDD_MASK      (0x00040000u)
#define CSL_VPORT_VC_CTL_FLDD_SHIFT     (0x00000012u)
#define CSL_VPORT_VC_CTL_FLDD_RESETVAL  (0x00000000u)

#define CSL_VPORT_VC_CTL_VRST_MASK      (0x00020000u)
#define CSL_VPORT_VC_CTL_VRST_SHIFT     (0x00000011u)
#define CSL_VPORT_VC_CTL_VRST_RESETVAL  (0x00000001u)

#define CSL_VPORT_VC_CTL_HRST_MASK      (0x00010000u)
#define CSL_VPORT_VC_CTL_HRST_SHIFT     (0x00000010u)
#define CSL_VPORT_VC_CTL_HRST_RESETVAL  (0x00000000u)

#define CSL_VPORT_VC_CTL_VCEN_MASK      (0x00008000u)
#define CSL_VPORT_VC_CTL_VCEN_SHIFT     (0x0000000Fu)
#define CSL_VPORT_VC_CTL_VCEN_RESETVAL  (0x00000000u)

#define CSL_VPORT_VC_CTL_10BPK1_MASK    (0x00004000u)
#define CSL_VPORT_VC_CTL_10BPK1_SHIFT   (0x0000000Eu)
#define CSL_VPORT_VC_CTL_10BPK1_RESETVAL (0x00000000u)

#define CSL_VPORT_VC_CTL_10BPK0_MASK    (0x00002000u)
#define CSL_VPORT_VC_CTL_10BPK0_SHIFT   (0x0000000Du)
#define CSL_VPORT_VC_CTL_10BPK0_RESETVAL (0x00000000u)

#define CSL_VPORT_VC_CTL_LFDE_MASK      (0x00001000u)
#define CSL_VPORT_VC_CTL_LFDE_SHIFT     (0x0000000Cu)
#define CSL_VPORT_VC_CTL_LFDE_RESETVAL  (0x00000000u)

#define CSL_VPORT_VC_CTL_SFDE_MASK      (0x00000800u)
#define CSL_VPORT_VC_CTL_SFDE_SHIFT     (0x0000000Bu)
#define CSL_VPORT_VC_CTL_SFDE_RESETVAL  (0x00000000u)

#define CSL_VPORT_VC_CTL_RESMPL_MASK    (0x00000400u)
#define CSL_VPORT_VC_CTL_RESMPL_SHIFT   (0x0000000Au)
#define CSL_VPORT_VC_CTL_RESMPL_RESETVAL (0x00000000u)


#define CSL_VPORT_VC_CTL_SCALE_MASK     (0x00000100u)
#define CSL_VPORT_VC_CTL_SCALE_SHIFT    (0x00000008u)
#define CSL_VPORT_VC_CTL_SCALE_RESETVAL (0x00000000u)

#define CSL_VPORT_VC_CTL_CON_MASK       (0x00000080u)
#define CSL_VPORT_VC_CTL_CON_SHIFT      (0x00000007u)
#define CSL_VPORT_VC_CTL_CON_RESETVAL   (0x00000000u)

#define CSL_VPORT_VC_CTL_FRAME_MASK     (0x00000040u)
#define CSL_VPORT_VC_CTL_FRAME_SHIFT    (0x00000006u)
#define CSL_VPORT_VC_CTL_FRAME_RESETVAL (0x00000000u)

#define CSL_VPORT_VC_CTL_CF2_MASK       (0x00000020u)
#define CSL_VPORT_VC_CTL_CF2_SHIFT      (0x00000005u)
#define CSL_VPORT_VC_CTL_CF2_RESETVAL   (0x00000001u)

#define CSL_VPORT_VC_CTL_CF1_MASK       (0x00000010u)
#define CSL_VPORT_VC_CTL_CF1_SHIFT      (0x00000004u)
#define CSL_VPORT_VC_CTL_CF1_RESETVAL   (0x00000001u)


#define CSL_VPORT_VC_CTL_CMODE_MASK     (0x00000007u)
#define CSL_VPORT_VC_CTL_CMODE_SHIFT    (0x00000000u)
#define CSL_VPORT_VC_CTL_CMODE_RESETVAL (0x00000000u)

#define CSL_VPORT_VC_CTL_RESETVAL       (0x40020030u)

/* VC_STRT1 */


#define CSL_VPORT_VC_STRT1_VC_YSTART_MASK (0x0FFF0000u)
#define CSL_VPORT_VC_STRT1_VC_YSTART_SHIFT (0x00000010u)
#define CSL_VPORT_VC_STRT1_VC_YSTART_RESETVAL (0x00000000u)

#define CSL_VPORT_VC_STRT1_SSE_MASK     (0x00008000u)
#define CSL_VPORT_VC_STRT1_SSE_SHIFT    (0x0000000Fu)
#define CSL_VPORT_VC_STRT1_SSE_RESETVAL (0x00000001u)

#define CSL_VPORT_VC_STRT1_VC_XSTART_MASK  (0x00000FFFu)
#define CSL_VPORT_VC_STRT1_VC_XSTART_SHIFT (0x00000000u)
#define CSL_VPORT_VC_STRT1_VC_XSTART_RESETVAL (0x00000000u)



#define CSL_VPORT_VC_STRT1_RESETVAL     (0x00008000u)

/* VC_STOP1 */


#define CSL_VPORT_VC_STOP1_VC_YSTOP_MASK (0x0FFF0000u)
#define CSL_VPORT_VC_STOP1_VC_YSTOP_SHIFT (0x00000010u)
#define CSL_VPORT_VC_STOP1_VC_YSTOP_RESETVAL (0x00000000u)


#define CSL_VPORT_VC_STOP1_VC_XSTOP_MASK (0x00000FFFu)
#define CSL_VPORT_VC_STOP1_VC_XSTOP_SHIFT (0x00000000u)
#define CSL_VPORT_VC_STOP1_VC_XSTOP_RESETVAL (0x00000000u)


#define CSL_VPORT_VC_STOP1_RESETVAL     (0x00000000u)

/* VC_STRT2 */


#define CSL_VPORT_VC_STRT2_VC_YSTART_MASK (0x0FFF0000u)
#define CSL_VPORT_VC_STRT2_VC_YSTART_SHIFT (0x00000010u)
#define CSL_VPORT_VC_STRT2_VC_YSTART_RESETVAL (0x00000000u)
/*----VC_YSTART Tokens----*/
#define CSL_VPORT_VC_STRT2_VC_YSTART_16XOVER-SAMPLING (0x00000000u)

#define CSL_VPORT_VC_STRT2_VC_XSTART_MASK (0x00000FFFu)
#define CSL_VPORT_VC_STRT2_VC_XSTART_SHIFT (0x00000000u)
#define CSL_VPORT_VC_STRT2_VC_XSTART_RESETVAL (0x00000000u)

#define CSL_VPORT_VC_STRT2_RESETVAL     (0x00000000u)

/* VC_STOP2 */


#define CSL_VPORT_VC_STOP2_VC_YSTOP_MASK (0x0FFF0000u)
#define CSL_VPORT_VC_STOP2_VC_YSTOP_SHIFT (0x00000010u)
#define CSL_VPORT_VC_STOP2_VC_YSTOP_RESETVAL (0x00000000u)

#define CSL_VPORT_VC_STOP2_VC_XSTOP_MASK (0x00000FFFu)
#define CSL_VPORT_VC_STOP2_VC_XSTOP_SHIFT (0x00000000u)
#define CSL_VPORT_VC_STOP2_VC_XSTOP_RESETVAL (0x00000000u)

#define CSL_VPORT_VC_STOP2_RESETVAL     (0x00000000u)

/* VC_VINT */

#define CSL_VPORT_VC_VINT_VIF2_MASK     (0x80000000u)
#define CSL_VPORT_VC_VINT_VIF2_SHIFT    (0x0000001Fu)
#define CSL_VPORT_VC_VINT_VIF2_RESETVAL (0x00000000u)

#define CSL_VPORT_VC_VINT_FSCL2_MASK    (0x40000000u)
#define CSL_VPORT_VC_VINT_FSCL2_SHIFT   (0x0000001Eu)
#define CSL_VPORT_VC_VINT_FSCL2_RESETVAL (0x00000000u)


#define CSL_VPORT_VC_VINT_VINT2_MASK    (0x0FFF0000u)
#define CSL_VPORT_VC_VINT_VINT2_SHIFT   (0x00000010u)
#define CSL_VPORT_VC_VINT_VINT2_RESETVAL (0x00000000u)

#define CSL_VPORT_VC_VINT_VIF1_MASK     (0x00008000u)
#define CSL_VPORT_VC_VINT_VIF1_SHIFT    (0x0000000Fu)
#define CSL_VPORT_VC_VINT_VIF1_RESETVAL (0x00000000u)


#define CSL_VPORT_VC_VINT_VINT1_MASK    (0x00000FFFu)
#define CSL_VPORT_VC_VINT_VINT1_SHIFT   (0x00000000u)
#define CSL_VPORT_VC_VINT_VINT1_RESETVAL (0x00000000u)

#define CSL_VPORT_VC_VINT_RESETVAL      (0x00000000u)

/* VC_THRLD */


#define CSL_VPORT_VC_THRLD_VCTHRLD2_MASK (0x03FF0000u)
#define CSL_VPORT_VC_THRLD_VCTHRLD2_SHIFT (0x00000010u)
#define CSL_VPORT_VC_THRLD_VCTHRLD2_RESETVAL (0x00000000u)

#define CSL_VPORT_VC_THRLD_VCTHRLD1_MASK (0x000003FFu)
#define CSL_VPORT_VC_THRLD_VCTHRLD1_SHIFT (0x00000000u)
#define CSL_VPORT_VC_THRLD_VCTHRLD1_RESETVAL (0x00000000u)

#define CSL_VPORT_VC_THRLD_RESETVAL     (0x00000000u)

/* VC_EVTCT */


#define CSL_VPORT_VC_EVTCT_CAP_EVTCT2_MASK (0x0FFF0000u)
#define CSL_VPORT_VC_EVTCT_CAP_EVTCT2_SHIFT (0x00000010u)
#define CSL_VPORT_VC_EVTCT_CAP_EVTCT2_RESETVAL (0x00000000u)

#define CSL_VPORT_VC_EVTCT_CAP_EVTCT1_MASK  (0x00000FFFu)
#define CSL_VPORT_VC_EVTCT_CAP_EVTCT1_SHIFT (0x00000000u)
#define CSL_VPORT_VC_EVTCT_CAP_EVTCT1_RESETVAL (0x00000000u)



#define CSL_VPORT_VC_EVTCT_RESETVAL     (0x00000000u)

/* TC_CTL */

#define CSL_VPORT_TC_CTL_ENSTC_MASK      (0x00000020u)
#define CSL_VPORT_TC_CTL_ENSTC_SHIFT     (0x00000005u)
#define CSL_VPORT_TC_CTL_ENSTC_RESETVAL  (0x00000000u)
/*----ENSTC Tokens----*/
#define CSL_VPORT_TC_CTL_ENSTC_ENABLE    (0x00000001u)
#define CSL_VPORT_TC_CTL_ENSTC_DISABLE   (0x00000000u)

#define CSL_VPORT_TC_CTL_TCKEN_MASK      (0x00000010u)
#define CSL_VPORT_TC_CTL_TCKEN_SHIFT     (0x00000004u)
#define CSL_VPORT_TC_CTL_TCKEN_RESETVAL  (0x00000000u)
/*----TCKEN Tokens----*/
#define CSL_VPORT_TC_CTL_TCKEN_ENABLE    (0x00000001u)
#define CSL_VPORT_TC_CTL_TCKEN_DISABLE   (0x00000000u)

#define CSL_VPORT_TC_CTL_STEN_MASK       (0x00000008u)
#define CSL_VPORT_TC_CTL_STEN_SHIFT      (0x00000003u)
#define CSL_VPORT_TC_CTL_STEN_RESETVAL   (0x00000000u)
/*----STEN Tokens----*/
#define CSL_VPORT_TC_CTL_STEN_ENABLE     (0x00000001u)
#define CSL_VPORT_TC_CTL_STEN_DISABLE    (0x00000000u)

#define CSL_VPORT_TC_CTL_CTMODE_MASK     (0x00000004u)
#define CSL_VPORT_TC_CTL_CTMODE_SHIFT    (0x00000002u)
#define CSL_VPORT_TC_CTL_CTMODE_RESETVAL (0x00000000u)
/*----CTMODE Tokens----*/
#define CSL_VPORT_TC_CTL_CTMODE_INC-90   (0x00000000u)

#define CSL_VPORT_TC_CTL_ERRFILT_MASK     (0x00000002u)
#define CSL_VPORT_TC_CTL_ERRFILT_SHIFT    (0x00000001u)
#define CSL_VPORT_TC_CTL_ERRFILT_RESETVAL (0x00000000u)

//TODO : Module owner to check this redefinition
//#define CSL_VPORT_TC_CTL_CTMODE_INC-STCLK (0x00000001u)

#define CSL_VPORT_TC_CTL_RESETVAL        (0x00000000u)



/* TC_CLKINITL */

#define CSL_VPORT_TC_CLKINITL_IN_PCR_MASK (0xFFFFFFFFu)
#define CSL_VPORT_TC_CLKINITL_IN_PCR_SHIFT (0x00000000u)
#define CSL_VPORT_TC_CLKINITL_IN_PCR_RESETVAL (0x00000000u)

#define CSL_VPORT_TC_CLKINITL_RESETVAL   (0x00000000u)

/* TC_CLKINITM */


#define CSL_VPORT_TC_CLKINITM_IN_PCRE_MASK (0x000003FEu)
#define CSL_VPORT_TC_CLKINITM_IN_PCRE_SHIFT (0x00000001u)
#define CSL_VPORT_TC_CLKINITM_IN_PCRE_RESETVAL (0x00000000u)

#define CSL_VPORT_TC_CLKINITM_IN_PCRM_MASK (0x00000001u)
#define CSL_VPORT_TC_CLKINITM_IN_PCRM_SHIFT (0x00000000u)
#define CSL_VPORT_TC_CLKINITM_IN_PCRM_RESETVAL (0x00000000u)

#define CSL_VPORT_TC_CLKINITM_RESETVAL   (0x00000000u)

/* TC_STCLKL */

#define CSL_VPORT_TC_STCLKL_PCR_MASK     (0xFFFFFFFFu)
#define CSL_VPORT_TC_STCLKL_PCR_SHIFT    (0x00000000u)
#define CSL_VPORT_TC_STCLKL_PCR_RESETVAL (0x00000000u)

#define CSL_VPORT_TC_STCLKL_RESETVAL     (0x00000000u)

/* TC_STCLKM */


#define CSL_VPORT_TC_STCLKM_PCRE_MASK    (0x000003FEu)
#define CSL_VPORT_TC_STCLKM_PCRE_SHIFT   (0x00000001u)
#define CSL_VPORT_TC_STCLKM_PCRE_RESETVAL (0x00000000u)

#define CSL_VPORT_TC_STCLKM_PCRM_MASK    (0x00000001u)
#define CSL_VPORT_TC_STCLKM_PCRM_SHIFT   (0x00000000u)
#define CSL_VPORT_TC_STCLKM_PCRM_RESETVAL (0x00000000u)

#define CSL_VPORT_TC_STCLKM_RESETVAL     (0x00000000u)

/* TC_STCMPL */

#define CSL_VPORT_TC_STCMPL_ATC_MASK     (0xFFFFFFFFu)
#define CSL_VPORT_TC_STCMPL_ATC_SHIFT    (0x00000000u)
#define CSL_VPORT_TC_STCMPL_ATC_RESETVAL (0x00000000u)

#define CSL_VPORT_TC_STCMPL_RESETVAL     (0x00000000u)

/* TC_STCMPM */


#define CSL_VPORT_TC_STCMPM_ATC_MASK     (0x00000001u)
#define CSL_VPORT_TC_STCMPM_ATC_SHIFT    (0x00000000u)
#define CSL_VPORT_TC_STCMPM_ATC_RESETVAL (0x00000000u)

#define CSL_VPORT_TC_STCMPM_RESETVAL     (0x00000000u)

/* TC_STMSKL */

#define CSL_VPORT_TC_STMSKL_ATCM_MASK    (0xFFFFFFFFu)
#define CSL_VPORT_TC_STMSKL_ATCM_SHIFT   (0x00000000u)
#define CSL_VPORT_TC_STMSKL_ATCM_RESETVAL (0x00000000u)

#define CSL_VPORT_TC_STMSKL_RESETVAL     (0x00000000u)

/* TC_STMSKM */


#define CSL_VPORT_TC_STMSKM_ATCM_MASK    (0x00000001u)
#define CSL_VPORT_TC_STMSKM_ATCM_SHIFT   (0x00000000u)
#define CSL_VPORT_TC_STMSKM_ATCM_RESETVAL (0x00000000u)

#define CSL_VPORT_TC_STMSKM_RESETVAL     (0x00000000u)

/* TC_TICKS */

#define CSL_VPORT_TC_TICKS_TICKCT_MASK   (0xFFFFFFFFu)
#define CSL_VPORT_TC_TICKS_TICKCT_SHIFT  (0x00000000u)
#define CSL_VPORT_TC_TICKS_TICKCT_RESETVAL (0x00000000u)

#define CSL_VPORT_TC_TICKS_RESETVAL      (0x00000000u)

/* VD_STAT */


#define CSL_VPORT_VD_STAT_FRMD_MASK      (0x40000000u)
#define CSL_VPORT_VD_STAT_FRMD_SHIFT     (0x0000001Eu)
#define CSL_VPORT_VD_STAT_FRMD_RESETVAL  (0x00000000u)

#define CSL_VPORT_VD_STAT_F2D_MASK       (0x20000000u)
#define CSL_VPORT_VD_STAT_F2D_SHIFT      (0x0000001Du)
#define CSL_VPORT_VD_STAT_F2D_RESETVAL   (0x00000000u)
/*----F2D Tokens----*/
#define CSL_VPORT_VD_STAT_F2D_FLD2       (0x00000000u)
#define CSL_VPORT_VD_STAT_F2D_CLEAR      (0x00000001u)

#define CSL_VPORT_VD_STAT_F1D_MASK       (0x10000000u)
#define CSL_VPORT_VD_STAT_F1D_SHIFT      (0x0000001Cu)
#define CSL_VPORT_VD_STAT_F1D_RESETVAL   (0x00000000u)
/*----F1D Tokens----*/
#define CSL_VPORT_VD_STAT_F1D_FLD1       (0x00000000u)
#define CSL_VPORT_VD_STAT_F1D_CLEAR      (0x00000001u)

#define CSL_VPORT_VD_STAT_VD_YPOS_MASK   (0x0FFF0000u)
#define CSL_VPORT_VD_STAT_VD_YPOS_SHIFT  (0x00000010u)
#define CSL_VPORT_VD_STAT_VD_YPOS_RESETVAL (0x00000000u)


#define CSL_VPORT_VD_STAT_VBLNK_MASK     (0x00002000u)
#define CSL_VPORT_VD_STAT_VBLNK_SHIFT    (0x0000000Du)
#define CSL_VPORT_VD_STAT_VBLNK_RESETVAL (0x00000000u)

#define CSL_VPORT_VD_STAT_VDFLD_MASK     (0x00001000u)
#define CSL_VPORT_VD_STAT_VDFLD_SHIFT    (0x0000000Cu)
#define CSL_VPORT_VD_STAT_VDFLD_RESETVAL (0x00000000u)
/*----VDFLD Tokens----*/
#define CSL_VPORT_VD_STAT_VDFLD_FLD1     (0x00000000u)
#define CSL_VPORT_VD_STAT_VDFLD_FLD2     (0x00000001u)

#define CSL_VPORT_VD_STAT_VD_XPOS_MASK   (0x00000FFFu)
#define CSL_VPORT_VD_STAT_VD_XPOS_SHIFT  (0x00000000u)
#define CSL_VPORT_VD_STAT_VD_XPOS_RESETVAL (0x00000000u)

#define CSL_VPORT_VD_STAT_RESETVAL       (0x00000000u)

/* VD_CTL */

#define CSL_VPORT_VD_CTL_RSTCH_MASK      (0x80000000u)
#define CSL_VPORT_VD_CTL_RSTCH_SHIFT     (0x0000001Fu)
#define CSL_VPORT_VD_CTL_RSTCH_RESETVAL  (0x00000000u)
/*----RSTCH Tokens----*/
#define CSL_VPORT_VD_CTL_RSTCH_NA        (0x00000000u)
#define CSL_VPORT_VD_CTL_RSTCH_RESET     (0x00000001u)

#define CSL_VPORT_VD_CTL_BLKDIS_MASK     (0x40000000u)
#define CSL_VPORT_VD_CTL_BLKDIS_SHIFT    (0x0000001Eu)
#define CSL_VPORT_VD_CTL_BLKDIS_RESETVAL (0x00000001u)


#define CSL_VPORT_VD_CTL_PVPSYN_MASK     (0x10000000u)
#define CSL_VPORT_VD_CTL_PVPSYN_SHIFT    (0x0000001Cu)
#define CSL_VPORT_VD_CTL_PVPSYN_RESETVAL (0x00000000u)


#define CSL_VPORT_VD_CTL_FXS_MASK        (0x00800000u)
#define CSL_VPORT_VD_CTL_FXS_SHIFT       (0x00000017u)
#define CSL_VPORT_VD_CTL_FXS_RESETVAL    (0x00000000u)
/*----FXS Tokens----*/
#define CSL_VPORT_VD_CTL_FXS_VCTL3O/P    (0x00000000u)
#define CSL_VPORT_VD_CTL_FXS_VCTL3I/P    (0x00000001u)

#define CSL_VPORT_VD_CTL_VXS_MASK        (0x00400000u)
#define CSL_VPORT_VD_CTL_VXS_SHIFT       (0x00000016u)
#define CSL_VPORT_VD_CTL_VXS_RESETVAL    (0x00000000u)
/*----VXS Tokens----*/
#define CSL_VPORT_VD_CTL_VXS_VCTL2O/P    (0x00000000u)
#define CSL_VPORT_VD_CTL_VXS_VCTL2I/P    (0x00000001u)

#define CSL_VPORT_VD_CTL_HXS_MASK        (0x00200000u)
#define CSL_VPORT_VD_CTL_HXS_SHIFT       (0x00000015u)
#define CSL_VPORT_VD_CTL_HXS_RESETVAL    (0x00000000u)
/*----HXS Tokens----*/
#define CSL_VPORT_VD_CTL_HXS_VCTL1O/P    (0x00000000u)
#define CSL_VPORT_VD_CTL_HXS_VCTL1I/P    (0x00000001u)

#define CSL_VPORT_VD_CTL_VCTL3S_MASK     (0x00100000u)
#define CSL_VPORT_VD_CTL_VCTL3S_SHIFT    (0x00000014u)
#define CSL_VPORT_VD_CTL_VCTL3S_RESETVAL (0x00000000u)
/*----VCTL3S Tokens----*/
#define CSL_VPORT_VD_CTL_VCTL3S_CBLNK    (0x00000000u)
#define CSL_VPORT_VD_CTL_VCTL3S_FLD      (0x00000001u)

#define CSL_VPORT_VD_CTL_VCTL2S_MASK     (0x000C0000u)
#define CSL_VPORT_VD_CTL_VCTL2S_SHIFT    (0x00000012u)
#define CSL_VPORT_VD_CTL_VCTL2S_RESETVAL (0x00000000u)

#define CSL_VPORT_VD_CTL_VCTL1S_MASK     (0x00030000u)
#define CSL_VPORT_VD_CTL_VCTL1S_SHIFT    (0x00000010u)
#define CSL_VPORT_VD_CTL_VCTL1S_RESETVAL (0x00000000u)

#define CSL_VPORT_VD_CTL_VDEN_MASK       (0x00008000u)
#define CSL_VPORT_VD_CTL_VDEN_SHIFT      (0x0000000Fu)
#define CSL_VPORT_VD_CTL_VDEN_RESETVAL   (0x00000000u)

#define CSL_VPORT_VD_CTL_DPK_MASK        (0x00004000u)
#define CSL_VPORT_VD_CTL_DPK_SHIFT       (0x0000000Eu)
#define CSL_VPORT_VD_CTL_DPK_RESETVAL    (0x00000000u)
/*----DPK Tokens----*/
#define CSL_VPORT_VD_CTL_DPK_NORMAL      (0x00000000u)
#define CSL_VPORT_VD_CTL_DPK_DENSE       (0x00000001u)

#define CSL_VPORT_VD_CTL_RGBX_MASK       (0x00002000u)
#define CSL_VPORT_VD_CTL_RGBX_SHIFT      (0x0000000Du)
#define CSL_VPORT_VD_CTL_RGBX_RESETVAL   (0x00000000u)

#define CSL_VPORT_VD_CTL_RSYNC_MASK      (0x00001000u)
#define CSL_VPORT_VD_CTL_RSYNC_SHIFT     (0x0000000Cu)
#define CSL_VPORT_VD_CTL_RSYNC_RESETVAL  (0x00000000u)

#define CSL_VPORT_VD_CTL_DVEN_MASK       (0x00000800u)
#define CSL_VPORT_VD_CTL_DVEN_SHIFT      (0x0000000Bu)
#define CSL_VPORT_VD_CTL_DVEN_RESETVAL   (0x00000000u)
/*----DVEN Tokens----*/
#define CSL_VPORT_VD_CTL_DVEN_BLNKOUTPUT (0x00000000u)
#define CSL_VPORT_VD_CTL_DVEN_DEFOUTPUT  (0x00000001u)

#define CSL_VPORT_VD_CTL_RESMPL_MASK     (0x00000400u)
#define CSL_VPORT_VD_CTL_RESMPL_SHIFT    (0x0000000Au)
#define CSL_VPORT_VD_CTL_RESMPL_RESETVAL (0x00000000u)
/*----RESMPL Tokens----*/
#define CSL_VPORT_VD_CTL_RESMPL_DISABLE  (0x00000000u)
#define CSL_VPORT_VD_CTL_RESMPL_ENABLE   (0x00000001u)


#define CSL_VPORT_VD_CTL_SCALE_MASK      (0x00000100u)
#define CSL_VPORT_VD_CTL_SCALE_SHIFT     (0x00000008u)
#define CSL_VPORT_VD_CTL_SCALE_RESETVAL  (0x00000000u)
/*----SCALE Tokens----*/
#define CSL_VPORT_VD_CTL_SCALE_DISABLE   (0x00000000u)
#define CSL_VPORT_VD_CTL_SCALE_ENABLE    (0x00000001u)

#define CSL_VPORT_VD_CTL_CON_MASK        (0x00000080u)
#define CSL_VPORT_VD_CTL_CON_SHIFT       (0x00000007u)
#define CSL_VPORT_VD_CTL_CON_RESETVAL    (0x00000000u)

#define CSL_VPORT_VD_CTL_FRAME_MASK      (0x00000040u)
#define CSL_VPORT_VD_CTL_FRAME_SHIFT     (0x00000006u)
#define CSL_VPORT_VD_CTL_FRAME_RESETVAL  (0x00000000u)

#define CSL_VPORT_VD_CTL_DF2_MASK        (0x00000020u)
#define CSL_VPORT_VD_CTL_DF2_SHIFT       (0x00000005u)
#define CSL_VPORT_VD_CTL_DF2_RESETVAL    (0x00000000u)

#define CSL_VPORT_VD_CTL_DF1_MASK        (0x00000010u)
#define CSL_VPORT_VD_CTL_DF1_SHIFT       (0x00000004u)
#define CSL_VPORT_VD_CTL_DF1_RESETVAL    (0x00000000u)


#define CSL_VPORT_VD_CTL_DMODE_MASK      (0x00000007u)
#define CSL_VPORT_VD_CTL_DMODE_SHIFT     (0x00000000u)
#define CSL_VPORT_VD_CTL_DMODE_RESETVAL  (0x00000000u)

#define CSL_VPORT_VD_CTL_RESETVAL        (0x40000000u)

/* VD_FRMSZ */


#define CSL_VPORT_VD_FRMSZ_FRM_HEIGHT_MASK (0x0FFF0000u)
#define CSL_VPORT_VD_FRMSZ_FRM_HEIGHT_SHIFT (0x00000010u)
#define CSL_VPORT_VD_FRMSZ_FRM_HEIGHT_RESETVAL (0x00000000u)


#define CSL_VPORT_VD_FRMSZ_FRM_WIDTH_MASK (0x00000FFFu)
#define CSL_VPORT_VD_FRMSZ_FRM_WIDTH_SHIFT (0x00000000u)
#define CSL_VPORT_VD_FRMSZ_FRM_WIDTH_RESETVAL (0x00000000u)

#define CSL_VPORT_VD_FRMSZ_RESETVAL      (0x00000000u)

/* VD_HBLNK */


#define CSL_VPORT_VD_HBLNK_HBLNK_STOP_MASK (0x0FFF0000u)
#define CSL_VPORT_VD_HBLNK_HBLNK_STOP_SHIFT (0x00000010u)
#define CSL_VPORT_VD_HBLNK_HBLNK_STOP_RESETVAL (0x00000000u)

#define CSL_VPORT_VD_HBLNK_HBDLA_MASK    (0x00008000u)
#define CSL_VPORT_VD_HBLNK_HBDLA_SHIFT   (0x0000000Fu)
#define CSL_VPORT_VD_HBLNK_HBDLA_RESETVAL (0x00000000u)


#define CSL_VPORT_VD_HBLNK_HBLNK_START_MASK (0x00000FFFu)
#define CSL_VPORT_VD_HBLNK_HBLNK_START_SHIFT (0x00000000u)
#define CSL_VPORT_VD_HBLNK_HBLNK_START_RESETVAL (0x00000000u)

#define CSL_VPORT_VD_HBLNK_RESETVAL      (0x00000000u)

/* VD_VBLKS1 */


#define CSL_VPORT_VD_VBLKS1_VBLNK_YSTART1_MASK (0x0FFF0000u)
#define CSL_VPORT_VD_VBLKS1_VBLNK_YSTART1_SHIFT (0x00000010u)
#define CSL_VPORT_VD_VBLKS1_VBLNK_YSTART1_RESETVAL (0x00000000u)


#define CSL_VPORT_VD_VBLKS1_VBLNK_XSTART1_MASK (0x00000FFFu)
#define CSL_VPORT_VD_VBLKS1_VBLNK_XSTART1_SHIFT (0x00000000u)
#define CSL_VPORT_VD_VBLKS1_VBLNK_XSTART1_RESETVAL (0x00000000u)

#define CSL_VPORT_VD_VBLKS1_RESETVAL     (0x00000000u)

/* VD_VBLKE1 */


#define CSL_VPORT_VD_VBLKE1_VBLNK_YSTOP1_MASK (0x0FFF0000u)
#define CSL_VPORT_VD_VBLKE1_VBLNK_YSTOP1_SHIFT (0x00000010u)
#define CSL_VPORT_VD_VBLKE1_VBLNK_YSTOP1_RESETVAL (0x00000000u)


#define CSL_VPORT_VD_VBLKE1_VBLNK_XSTOP1_MASK (0x00000FFFu)
#define CSL_VPORT_VD_VBLKE1_VBLNK_XSTOP1_SHIFT (0x00000000u)
#define CSL_VPORT_VD_VBLKE1_VBLNK_XSTOP1_RESETVAL (0x00000000u)

#define CSL_VPORT_VD_VBLKE1_RESETVAL     (0x00000000u)

/* VD_VBLKS2 */


#define CSL_VPORT_VD_VBLKS2_VBLNK_YSTART2_MASK (0x0FFF0000u)
#define CSL_VPORT_VD_VBLKS2_VBLNK_YSTART2_SHIFT (0x00000010u)
#define CSL_VPORT_VD_VBLKS2_VBLNK_YSTART2_RESETVAL (0x00000000u)


#define CSL_VPORT_VD_VBLKS2_VBLNK_XSTART2_MASK (0x00000FFFu)
#define CSL_VPORT_VD_VBLKS2_VBLNK_XSTART2_SHIFT (0x00000000u)
#define CSL_VPORT_VD_VBLKS2_VBLNK_XSTART2_RESETVAL (0x00000000u)

#define CSL_VPORT_VD_VBLKS2_RESETVAL     (0x00000000u)

/* VD_VBLKE2 */


#define CSL_VPORT_VD_VBLKE2_VBLNK_YSTOP2_MASK (0x0FFF0000u)
#define CSL_VPORT_VD_VBLKE2_VBLNK_YSTOP2_SHIFT (0x00000010u)
#define CSL_VPORT_VD_VBLKE2_VBLNK_YSTOP2_RESETVAL (0x00000000u)


#define CSL_VPORT_VD_VBLKE2_VBLNK_XSTOP2_MASK (0x00000FFFu)
#define CSL_VPORT_VD_VBLKE2_VBLNK_XSTOP2_SHIFT (0x00000000u)
#define CSL_VPORT_VD_VBLKE2_VBLNK_XSTOP2_RESETVAL (0x00000000u)

#define CSL_VPORT_VD_VBLKE2_RESETVAL     (0x00000000u)

/* VD_IMGOFF1 */

#define CSL_VPORT_VD_IMGOFF1_NV_MASK     (0x80000000u)
#define CSL_VPORT_VD_IMGOFF1_NV_SHIFT    (0x0000001Fu)
#define CSL_VPORT_VD_IMGOFF1_NV_RESETVAL (0x00000000u)


#define CSL_VPORT_VD_IMGOFF1_IMG_VOFF1_MASK (0x0FFF0000u)
#define CSL_VPORT_VD_IMGOFF1_IMG_VOFF1_SHIFT (0x00000010u)
#define CSL_VPORT_VD_IMGOFF1_IMG_VOFF1_RESETVAL (0x00000000u)

#define CSL_VPORT_VD_IMGOFF1_NH_MASK     (0x00008000u)
#define CSL_VPORT_VD_IMGOFF1_NH_SHIFT    (0x0000000Fu)
#define CSL_VPORT_VD_IMGOFF1_NH_RESETVAL (0x00000000u)


#define CSL_VPORT_VD_IMGOFF1_IMG_HOFF1_MASK (0x00000FFFu)
#define CSL_VPORT_VD_IMGOFF1_IMG_HOFF1_SHIFT (0x00000000u)
#define CSL_VPORT_VD_IMGOFF1_IMG_HOFF1_RESETVAL (0x00000000u)

#define CSL_VPORT_VD_IMGOFF1_RESETVAL    (0x00000000u)

/* VD_IMGSZ1 */


#define CSL_VPORT_VD_IMGSZ1_IMG_VSIZE1_MASK (0x0FFF0000u)
#define CSL_VPORT_VD_IMGSZ1_IMG_VSIZE1_SHIFT (0x00000010u)
#define CSL_VPORT_VD_IMGSZ1_IMG_VSIZE1_RESETVAL (0x00000000u)


#define CSL_VPORT_VD_IMGSZ1_IMG_HSIZE1_MASK (0x00000FFFu)
#define CSL_VPORT_VD_IMGSZ1_IMG_HSIZE1_SHIFT (0x00000000u)
#define CSL_VPORT_VD_IMGSZ1_IMG_HSIZE1_RESETVAL (0x00000000u)

#define CSL_VPORT_VD_IMGSZ1_RESETVAL     (0x00000000u)

/* VD_IMGOFF2 */

#define CSL_VPORT_VD_IMGOFF2_NV_MASK     (0x80000000u)
#define CSL_VPORT_VD_IMGOFF2_NV_SHIFT    (0x0000001Fu)
#define CSL_VPORT_VD_IMGOFF2_NV_RESETVAL (0x00000000u)


#define CSL_VPORT_VD_IMGOFF2_IMG_VOFF2_MASK (0x0FFF0000u)
#define CSL_VPORT_VD_IMGOFF2_IMG_VOFF2_SHIFT (0x00000010u)
#define CSL_VPORT_VD_IMGOFF2_IMG_VOFF2_RESETVAL (0x00000000u)

#define CSL_VPORT_VD_IMGOFF2_NH_MASK     (0x00008000u)
#define CSL_VPORT_VD_IMGOFF2_NH_SHIFT    (0x0000000Fu)
#define CSL_VPORT_VD_IMGOFF2_NH_RESETVAL (0x00000000u)


#define CSL_VPORT_VD_IMGOFF2_IMG_HOFF2_MASK (0x00000FFFu)
#define CSL_VPORT_VD_IMGOFF2_IMG_HOFF2_SHIFT (0x00000000u)
#define CSL_VPORT_VD_IMGOFF2_IMG_HOFF2_RESETVAL (0x00000000u)

#define CSL_VPORT_VD_IMGOFF2_RESETVAL    (0x00000000u)

/* VD_IMGSZ2 */


#define CSL_VPORT_VD_IMGSZ2_IMG_VSIZE2_MASK (0x0FFF0000u)
#define CSL_VPORT_VD_IMGSZ2_IMG_VSIZE2_SHIFT (0x00000010u)
#define CSL_VPORT_VD_IMGSZ2_IMG_VSIZE2_RESETVAL (0x00000000u)



#define CSL_VPORT_VD_IMGSZ2_IMG_HSIZE2_MASK (0x00000FFFu)
#define CSL_VPORT_VD_IMGSZ2_IMG_HSIZE2_SHIFT (0x00000000u)
#define CSL_VPORT_VD_IMGSZ2_IMG_HSIZE2_RESETVAL (0x00000000u)

#define CSL_VPORT_VD_IMGSZ2_RESETVAL     (0x00000000u)

/* VD_FLDT1 */


#define CSL_VPORT_VD_FLDT1_FLD1_YSTART_MASK (0x0FFF0000u)
#define CSL_VPORT_VD_FLDT1_FLD1_YSTART_SHIFT (0x00000010u)
#define CSL_VPORT_VD_FLDT1_FLD1_YSTART_RESETVAL (0x00000000u)



#define CSL_VPORT_VD_FLDT1_FLD1_XSTART_MASK (0x00000FFFu)
#define CSL_VPORT_VD_FLDT1_FLD1_XSTART_SHIFT (0x00000000u)
#define CSL_VPORT_VD_FLDT1_FLD1_XSTART_RESETVAL (0x00000000u)

#define CSL_VPORT_VD_FLDT1_RESETVAL      (0x00000000u)

/* VD_FLDT2 */


#define CSL_VPORT_VD_FLDT2_FLD2_YSTART_MASK (0x0FFF0000u)
#define CSL_VPORT_VD_FLDT2_FLD2_YSTART_SHIFT (0x00000010u)
#define CSL_VPORT_VD_FLDT2_FLD2_YSTART_RESETVAL (0x00000000u)



#define CSL_VPORT_VD_FLDT2_FLD2_XSTART_MASK (0x00000FFFu)
#define CSL_VPORT_VD_FLDT2_FLD2_XSTART_SHIFT (0x00000000u)
#define CSL_VPORT_VD_FLDT2_FLD2_XSTART_RESETVAL (0x00000000u)

#define CSL_VPORT_VD_FLDT2_RESETVAL      (0x00000000u)

/* VD_THRLD */


#define CSL_VPORT_VD_THRLD_VDTHRLD2_MASK (0x03FF0000u)
#define CSL_VPORT_VD_THRLD_VDTHRLD2_SHIFT (0x00000010u)
#define CSL_VPORT_VD_THRLD_VDTHRLD2_RESETVAL (0x00000000u)

#define CSL_VPORT_VD_THRLD_INCPIX_MASK   (0x0000F000u)
#define CSL_VPORT_VD_THRLD_INCPIX_SHIFT  (0x0000000Cu)
#define CSL_VPORT_VD_THRLD_INCPIX_RESETVAL (0x00000000u)


#define CSL_VPORT_VD_THRLD_VDTHRLD1_MASK (0x000003FFu)
#define CSL_VPORT_VD_THRLD_VDTHRLD1_SHIFT (0x00000000u)
#define CSL_VPORT_VD_THRLD_VDTHRLD1_RESETVAL (0x00000000u)

#define CSL_VPORT_VD_THRLD_RESETVAL      (0x00000000u)

/* VD_HSYNC */


#define CSL_VPORT_VD_HSYNC_HSYNC_STOP_MASK (0x0FFF0000u)
#define CSL_VPORT_VD_HSYNC_HSYNC_STOP_SHIFT (0x00000010u)
#define CSL_VPORT_VD_HSYNC_HSYNC_STOP_RESETVAL (0x00000000u)



#define CSL_VPORT_VD_HSYNC_HSYNC_START_MASK (0x00000FFFu)
#define CSL_VPORT_VD_HSYNC_HSYNC_START_SHIFT (0x00000000u)
#define CSL_VPORT_VD_HSYNC_HSYNC_START_RESETVAL (0x00000000u)

#define CSL_VPORT_VD_HSYNC_RESETVAL      (0x00000000u)

/* VD_VSYNS1 */


#define CSL_VPORT_VD_VSYNS1_VSYNC_YSTART1_MASK (0x0FFF0000u)
#define CSL_VPORT_VD_VSYNS1_VSYNC_YSTART1_SHIFT (0x00000010u)
#define CSL_VPORT_VD_VSYNS1_VSYNC_YSTART1_RESETVAL (0x00000000u)



#define CSL_VPORT_VD_VSYNS1_VSYNC_XSTART1_MASK (0x00000FFFu)
#define CSL_VPORT_VD_VSYNS1_VSYNC_XSTART1_SHIFT (0x00000000u)
#define CSL_VPORT_VD_VSYNS1_VSYNC_XSTART1_RESETVAL (0x00000000u)

#define CSL_VPORT_VD_VSYNS1_RESETVAL     (0x00000000u)

/* VD_VSYNE1 */


#define CSL_VPORT_VD_VSYNE1_VSYNC_YSTOP1_MASK (0x0FFF0000u)
#define CSL_VPORT_VD_VSYNE1_VSYNC_YSTOP1_SHIFT (0x00000010u)
#define CSL_VPORT_VD_VSYNE1_VSYNC_YSTOP1_RESETVAL (0x00000000u)



#define CSL_VPORT_VD_VSYNE1_VSYNC_XSTOP1_MASK (0x00000FFFu)
#define CSL_VPORT_VD_VSYNE1_VSYNC_XSTOP1_SHIFT (0x00000000u)
#define CSL_VPORT_VD_VSYNE1_VSYNC_XSTOP1_RESETVAL (0x00000000u)

#define CSL_VPORT_VD_VSYNE1_RESETVAL     (0x00000000u)

/* VD_VSYNS2 */


#define CSL_VPORT_VD_VSYNS2_VSYNC_YSTART2_MASK (0x0FFF0000u)
#define CSL_VPORT_VD_VSYNS2_VSYNC_YSTART2_SHIFT (0x00000010u)
#define CSL_VPORT_VD_VSYNS2_VSYNC_YSTART2_RESETVAL (0x00000000u)



#define CSL_VPORT_VD_VSYNS2_VSYNC_XSTART2_MASK (0x00000FFFu)
#define CSL_VPORT_VD_VSYNS2_VSYNC_XSTART2_SHIFT (0x00000000u)
#define CSL_VPORT_VD_VSYNS2_VSYNC_XSTART2_RESETVAL (0x00000000u)

#define CSL_VPORT_VD_VSYNS2_RESETVAL     (0x00000000u)

/* VD_VSYNE2 */


#define CSL_VPORT_VD_VSYNE2_VSYNC_YSTOP2_MASK (0x0FFF0000u)
#define CSL_VPORT_VD_VSYNE2_VSYNC_YSTOP2_SHIFT (0x00000010u)
#define CSL_VPORT_VD_VSYNE2_VSYNC_YSTOP2_RESETVAL (0x00000000u)



#define CSL_VPORT_VD_VSYNE2_VSYNC_XSTOP2_MASK (0x00000FFFu)
#define CSL_VPORT_VD_VSYNE2_VSYNC_XSTOP2_SHIFT (0x00000000u)
#define CSL_VPORT_VD_VSYNE2_VSYNC_XSTOP2_RESETVAL (0x00000000u)

#define CSL_VPORT_VD_VSYNE2_RESETVAL     (0x00000000u)

/* VD_RELOAD */


#define CSL_VPORT_VD_RELOAD_VRLD_MASK    (0x0FFF0000u)
#define CSL_VPORT_VD_RELOAD_VRLD_SHIFT   (0x00000010u)
#define CSL_VPORT_VD_RELOAD_VRLD_RESETVAL (0x00000000u)

#define CSL_VPORT_VD_RELOAD_CRLD_MASK    (0x0000F000u)
#define CSL_VPORT_VD_RELOAD_CRLD_SHIFT   (0x0000000Cu)
#define CSL_VPORT_VD_RELOAD_CRLD_RESETVAL (0x00000000u)

#define CSL_VPORT_VD_RELOAD_HRLD_MASK    (0x00000FFFu)
#define CSL_VPORT_VD_RELOAD_HRLD_SHIFT   (0x00000000u)
#define CSL_VPORT_VD_RELOAD_HRLD_RESETVAL (0x00000000u)

#define CSL_VPORT_VD_RELOAD_RESETVAL     (0x00000000u)

/* VD_DISPEVT */


#define CSL_VPORT_VD_DISPEVT_DISPEVT2_MASK (0x0FFF0000u)
#define CSL_VPORT_VD_DISPEVT_DISPEVT2_SHIFT (0x00000010u)
#define CSL_VPORT_VD_DISPEVT_DISPEVT2_RESETVAL (0x00000000u)


#define CSL_VPORT_VD_DISPEVT_DISPEVT1_MASK (0x00000FFFu)
#define CSL_VPORT_VD_DISPEVT_DISPEVT1_SHIFT (0x00000000u)
#define CSL_VPORT_VD_DISPEVT_DISPEVT1_RESETVAL (0x00000000u)

#define CSL_VPORT_VD_DISPEVT_RESETVAL    (0x00000000u)

/* VD_CLIP */

#define CSL_VPORT_VD_CLIP_CLIPC_HI_MASK  (0xFF000000u)
#define CSL_VPORT_VD_CLIP_CLIPC_HI_SHIFT (0x00000018u)
#define CSL_VPORT_VD_CLIP_CLIPC_HI_RESETVAL (0x000000F0u)

#define CSL_VPORT_VD_CLIP_CLIPC_LO_MASK  (0x00FF0000u)
#define CSL_VPORT_VD_CLIP_CLIPC_LO_SHIFT (0x00000010u)
#define CSL_VPORT_VD_CLIP_CLIPC_LO_RESETVAL (0x00000010u)

#define CSL_VPORT_VD_CLIP_CLIPY_HI_MASK  (0x0000FF00u)
#define CSL_VPORT_VD_CLIP_CLIPY_HI_SHIFT (0x00000008u)
#define CSL_VPORT_VD_CLIP_CLIPY_HI_RESETVAL (0x000000EBu)

#define CSL_VPORT_VD_CLIP_CLIPY_LO_MASK  (0x000000FFu)
#define CSL_VPORT_VD_CLIP_CLIPY_LO_SHIFT (0x00000000u)
#define CSL_VPORT_VD_CLIP_CLIPY_LO_RESETVAL (0x00000010u)

#define CSL_VPORT_VD_CLIP_RESETVAL       (0xF010EB10u)

/* VD_DEFVAL */

#define CSL_VPORT_VD_DEFVAL_CRDEFVAL_MASK (0xFF000000u)
#define CSL_VPORT_VD_DEFVAL_CRDEFVAL_SHIFT (0x00000018u)
#define CSL_VPORT_VD_DEFVAL_CRDEFVAL_RESETVAL (0x00000000u)

#define CSL_VPORT_VD_DEFVAL_CBDEFVAL_MASK (0x00FF0000u)
#define CSL_VPORT_VD_DEFVAL_CBDEFVAL_SHIFT (0x00000010u)
#define CSL_VPORT_VD_DEFVAL_CBDEFVAL_RESETVAL (0x00000000u)

#define CSL_VPORT_VD_DEFVAL_NOTUSED_MASK (0x0000FF00u)
#define CSL_VPORT_VD_DEFVAL_NOTUSED_SHIFT (0x00000008u)
#define CSL_VPORT_VD_DEFVAL_NOTUSED_RESETVAL (0x00000000u)

#define CSL_VPORT_VD_DEFVAL_YDEFVAL_MASK (0x000000FFu)
#define CSL_VPORT_VD_DEFVAL_YDEFVAL_SHIFT (0x00000000u)
#define CSL_VPORT_VD_DEFVAL_YDEFVAL_RESETVAL (0x00000000u)

#define CSL_VPORT_VD_DEFVAL_RESETVAL     (0x00000000u)

/* VD_VINT */

#define CSL_VPORT_VD_VINT_V1F2_MASK      (0x80000000u)
#define CSL_VPORT_VD_VINT_V1F2_SHIFT     (0x0000001Fu)
#define CSL_VPORT_VD_VINT_V1F2_RESETVAL  (0x00000000u)


#define CSL_VPORT_VD_VINT_VINT2_MASK     (0x0FFF0000u)
#define CSL_VPORT_VD_VINT_VINT2_SHIFT    (0x00000010u)
#define CSL_VPORT_VD_VINT_VINT2_RESETVAL (0x00000000u)

#define CSL_VPORT_VD_VINT_V1F1_MASK      (0x00008000u)
#define CSL_VPORT_VD_VINT_V1F1_SHIFT     (0x0000000Fu)
#define CSL_VPORT_VD_VINT_V1F1_RESETVAL  (0x00000000u)


#define CSL_VPORT_VD_VINT_VINT1_MASK     (0x00000FFFu)
#define CSL_VPORT_VD_VINT_VINT1_SHIFT    (0x00000000u)
#define CSL_VPORT_VD_VINT_VINT1_RESETVAL (0x00000000u)

#define CSL_VPORT_VD_VINT_RESETVAL       (0x00000000u)

/* VD_FBIT */


#define CSL_VPORT_VD_FBIT_FBIT_SET_MASK  (0x0FFF0000u)
#define CSL_VPORT_VD_FBIT_FBIT_SET_SHIFT (0x00000010u)
#define CSL_VPORT_VD_FBIT_FBIT_SET_RESETVAL (0x00000000u)

#define CSL_VPORT_VD_FBIT_FBIT_CLR_MASK  (0x00000FFFu)
#define CSL_VPORT_VD_FBIT_FBIT_CLR_SHIFT (0x00000000u)
#define CSL_VPORT_VD_FBIT_FBIT_CLR_RESETVAL (0x00000000u)

#define CSL_VPORT_VD_FBIT_RESETVAL       (0x00000000u)

/* VD_VBIT1 */


#define CSL_VPORT_VD_VBIT1_VBIT_CLR1_MASK (0x0FFF0000u)
#define CSL_VPORT_VD_VBIT1_VBIT_CLR1_SHIFT (0x00000010u)
#define CSL_VPORT_VD_VBIT1_VBIT_CLR1_RESETVAL (0x00000000u)


#define CSL_VPORT_VD_VBIT1_VBIT_SET1_MASK (0x00000FFFu)
#define CSL_VPORT_VD_VBIT1_VBIT_SET1_SHIFT (0x00000000u)
#define CSL_VPORT_VD_VBIT1_VBIT_SET1_RESETVAL (0x00000000u)

#define CSL_VPORT_VD_VBIT1_RESETVAL      (0x00000000u)

/* VD_VBIT2 */


#define CSL_VPORT_VD_VBIT2_VBIT_CLR2_MASK (0x0FFF0000u)
#define CSL_VPORT_VD_VBIT2_VBIT_CLR2_SHIFT (0x00000010u)
#define CSL_VPORT_VD_VBIT2_VBIT_CLR2_RESETVAL (0x00000000u)


#define CSL_VPORT_VD_VBIT2_VBIT_SET2_MASK (0x00000FFFu)
#define CSL_VPORT_VD_VBIT2_VBIT_SET2_SHIFT (0x00000000u)
#define CSL_VPORT_VD_VBIT2_VBIT_SET2_RESETVAL (0x00000000u)

#define CSL_VPORT_VD_VBIT2_RESETVAL      (0x00000000u)

#ifdef __cplusplus
}
#endif

#endif
