/******************************************************************************
**+-------------------------------------------------------------------------+**
**|                            ****                                         |**
**|                            ****                                         |**
**|                            ******o***                                   |**
**|                      ********_///_****                                  |**
**|                      ***** /_//_/ ****                                  |**
**|                       ** ** (__/ ****                                   |**
**|                           *********                                     |**
**|                            ****                                         |**
**|                            ***                                          |**
**|                                                                         |**
**|         Copyright (c) 1998-2006 Texas Instruments Incorporated          |**
**|                        ALL RIGHTS RESERVED                              |**
**|                                                                         |**
**| Permission is hereby granted to licensees of Texas Instruments          |**
**| Incorporated (TI) products to use this computer program for the sole    |**
**| purpose of implementing a licensee product based on TI products.        |**
**| No other rights to reproduce, use, or disseminate this computer         |**
**| program, whether in part or in whole, are granted.                      |**
**|                                                                         |**
**| TI makes no representation or warranties with respect to the            |**
**| performance of this computer program, and specifically disclaims        |**
**| any responsibility for any damages, special or consequential,           |**
**| connected with the use of this program.                                 |**
**|                                                                         |**
**+-------------------------------------------------------------------------+**
******************************************************************************/

/*
 * \file   psp_audio.c
 *
 * \brief  Audio driver file.
 *
 * This file contains the API used as an interface to the underlying
 * McASP or McBSP driver.
 *
 *  (C) Copyright 2006, Texas Instruments, Inc
 *
 *  \note       Set tabstop to 4 (:se ts=4) while viewing this file in an
 *              editor
 *
 *  \author
 *
 *  \version    0.1
 *
 */
#include <std.h>
#include <iom.h>

#include <ti/sdo/pspdrivers/drivers/mcbsp/psp_mcbsp.h>
#include <ti/sdo/pspdrivers/drivers/mcasp/psp_mcasp.h>

#include <ti/sdo/pspdrivers/pal_os/pal_osmem.h>
#include <ti/sdo/pspdrivers/pal_os/bios/psputils.h>
#include <bcache.h>
#include <ti/sdo/pspdrivers/pal_os/pal_oswait.h>

#ifdef CHIP_DM6437
#include <ti/sdo/pspdrivers/system/dm6437/bios/evmDM6437/audio/src/psp_aic33Codec.h>
#include <ti/sdo/pspdrivers/soc/dm6437/dsp/soc.h>
#include <ti/sdo/pspdrivers/soc/dm6437/dsp/cslr_sys.h>
#endif

#ifdef CHIP_C6424
#include <ti/sdo/pspdrivers/system/c6424/bios/evm6424/audio/src/psp_aic33Codec.h>
#include <ti/sdo/pspdrivers/soc/c6424/dsp/soc.h>
#include <ti/sdo/pspdrivers/soc/c6424/dsp/cslr_sys.h>
#endif

#define CACHE_LENGTH             (128u)
#define DEFAULT_BITPERSAMPLE     (16u)

/* McBSP specific directives */
#define PRD_BUF_SIZE             (512u)
#define MCBSPPORT                (1u)
#define MCBSPBLOCK1              (0x01000000u)   /* MCBSP block 1 selection */
/* To select McBSP peripheral through IO expander */
#define MCBSP_SELECTED           (0)

/* McASP specific directives */
#define MCASPPORT                (0u)
#define NUM_OF_SERIALISER        (1u)
#define NUM_TDM_CHANNELS         (2u)
#define NUM_OF_CHANNELS          (2u)
#define LOOP_JOB_BUF_LENGTH      (0u)
#define CLOCK_ENABLE             (0x00000020u)
#define HI_CLOCK_ENABLE          (0x00008000u)
#define HI_CLOCK_SAMPLERATE_MASK (0x00000FFFu)
#define FRAMESYNC_INTERNAL       (0x00000002u)
/* To select McASP peripheral through IO expander */
#define MCASP_SELECTED           (1u)




extern PSP_Handle                hEdma;
static PSP_audio_cfg *audio_cfg;

#pragma DATA_ALIGN(prdInputBuf, CACHE_LENGTH);
static Uint32                   prdInputBuf[PRD_BUF_SIZE/2];
#pragma DATA_ALIGN(prdOutputBuf, CACHE_LENGTH);
static Uint32                   prdOutputBuf[PRD_BUF_SIZE/2];

/*
 * Forward declaration of the IOM interface functions. They are only
 * exposed via the IOM function table to avoid namespace pollution.
 */
static Int audio_mdBindDev(Ptr *devp, Int devid, Ptr devParams);
static Int audio_mdControlChan(Ptr chanp, Uns cmd, Ptr arg);
static Int audio_mdCreateChan(Ptr *chanp, Ptr devp, String name, Int mode,
                         Ptr chanParams, IOM_TiomCallback cbFxn, Ptr cbArg);

static void mcasp_pinmuxConfig ();
static void mcasp_master_rcv_config();
static void mcasp_master_xmt_config();

extern far IOM_Fxns McBSP_IOM_FXNS;
extern far IOM_Fxns McASP_IOM_FXNS;
extern far IOM_Fxns I2CMD_FXNS;
extern void MCBSP_IOM_init();
extern void MCASP_IOM_init();

Int32 audio_PllConfigure(Uint32 samplingRate);

static volatile Ptr             mcBspPortHandle = NULL;
static volatile Ptr             mcAspPortHandle = NULL;
static volatile Ptr             mcBspChInHandle = NULL;
static volatile Ptr             mcBspChOutHandle = NULL;
static volatile Ptr             mcAspChInHandle = NULL;
static volatile Ptr             mcAspChOutHandle = NULL;

static Int MCBSP_Configuration(Ptr chanp,
                               Uint32 inputFreq,
                               Uint32 samplingRate);
static Int MCASP_Configuration(Ptr chanp,
                               Uint32 inputFreq,
                               Uint32 samplingRate);


static PSP_audio_cfg audio_cfg_params = {
        PSP_AUDIO_AIC_MASTER,           /* AIC Mode */
        99000000,                       /* Input Frequency to  McASP module */
        8000,                           /* Sampling Rate */
        50,                             /* Input Gain */
        99,                             /* Output Gain */
        PSP_AUDIO_LINE_IN,              /* Input select */
        PSP_AUDIO_LINE_OUT              /* Output Select */
};

static PSP_mcbspHwCfgRaw    mcbspRawHwCfg = {
                            /**< Serial Port Control Register */
                            0x01C00000u,
                            /**< Receive Control Register */
                            0x000001A0u,
                            /**< Transmit Control Register */
                            0x000001A0u,
                            /**< Sample Rate Generator Register */
                            0x00000000u,
                            /**< Pin Control Register */
                            0x00000000u
                            };

static PSP_mcbspDevParams mcbsp_deviceparams = {
                            /**< Caching enabled                    */
                            TRUE,
                            /**< Internal clock is to be generated  */
                            FALSE,
                            /**< Framesync is to be generated       */
                            FALSE,
                            &mcbspRawHwCfg,
                            PSP_McBSP_McBSP,
                            PSP_OPMODE_DMAINTERRUPT,
                            /**< Pointer to configuration parameters
                             **  to be used for the McBSP */
                             NULL,
                             NULL,
                        };  /* Device parameters structure */

/*
Init configuration for mcasp device - DMA mode
*/
static PSP_McaspHwSetup appMcaspHwSetup = {         \
    {
      /* .pfunc    = */ 0x00000000,      /*mcasp or GPIO pin-will be set by
                                           driver from chanparams*/
      /* .pdir     = */ 0x00000001,      /*Direction of pin -will be set by
                                           driver from chanparams*/
      /* .gblctl   = */ 0x00000000,      /*control clk, hclk, statemachine -
                                           reset and release - driver ctrl*/
      /* .ditctl   = */ 0x00000000,      /*DIT mode seting*/
      /* .dlbctl   = */ 0x00000000,      /*loop back mode setting*/
      /* .amute    = */ 0x00000000,      /*Amute setting*/
      /* .srctl0   = */ 0x00000000,      /* init serialiser*/
      /* .srctl1   = */ 0x00000000       /* init serialiser*/
     },
      {
          /* .rmask    = */ 0xFFFFFFFF,
          /* .rfmt     = */ 0x00000000,
          /* .afsrctl  = */ 0x00000000,
          /* .rtdm     = */ 0x00000001,
          /* .rintctl  = */ 0x00000000,
          /* .rstat    = */ 0x000001FF,  /*reset any existing status bits*/
          /* .revtctl  = */ 0x00000000,
          {
             /* .aclkrctl  = */ 0x00000023,  /* \div = 1, clk = internal*/
             /* .ahclkrctl = */ 0x00008046,  /* div = 63, no inversion before
                                                divider ,Internal*/
             /* .rclkchk   = */ 0x00000000
          },
     },
     {
          /* .xmask    = */ 0xFFFFFFFF,
          /* .xfmt     = */ 0x00000000,
          /* .afsxctl  = */ 0x00000002,
          /* .xtdm     = */ 0x00000001,
          /* .xintctl  = */ 0x00000000,
          /* .xstat    = */ 0x000001FF,      /*reset any existing status bits*/
          /* .xevtctl  = */ 0x00000000,
          {
             /* .aclkxctl  = */ 0x00000023,  /* \div = 1, clk = internal*/
             /* .ahclkxctl = */ 0x00008046,  /* div = 46, no inversion before
                                                divider ,Internal*/
             /* .xclkchk   = */ 0x00000000
          },
     },
           0x00000001              /*emu free*/
} ;


PSP_McaspHwSetupData mcaspXmtSetup = { \
        /* .xmask    = */ 0xFFFFFFFF,    /*all the data bits are used*/
        /* .xfmt     = */ 0x000080F0,    /*no right rotation,
                                           DMA access,
                                           slot size = 32bits,
                                           pad with 0th bit from data,(currently
                                           this option disabled by next field)
                                           pad extra bits with 0,
                                           LSB first,
                                           0 bit delay from between fsync and
                                           data*/
        /* .afsxctl  = */ 0x00000000,    /*burst mode,
                                           frame sync pulse width - 1 clk bit
                                           clk is internal
                                           Rising edge is validated*/

        /* .xtdm     = */ 0x00000003,    /*n-th (2 here)TDM slot will be
                                           accounted - for burst mode no use*/
        /* .xintctl  = */ 0x00000000,    /*reset any existing status bits*/
        /* .xstat    = */ 0x000001FF,    /*reset any existing status bits*/
        /* .xevtctl  = */ 0x00000000,                   /*DMA or INT mode*/
        {
             /* .aclkxctl  = */ 0x00000000,  /* \div = 1, clk = External*/
             /* .ahclkxctl = */ 0x0000003F,  /* div = 63, no inversion before
                                                divider ,External*/
             /* .xclkchk   = */ 0x00000000
        },

};


PSP_McaspHwSetupData mcaspRcvSetup = { \
        /* .rmask    = */ 0xFFFFFFFF,    /*all the data bits are used*/
        /* .rfmt     = */ 0x000080F0,    /*no right rotation,
                                           DMA access,,
                                           slot size = 16bits,
                                           pad with 0th bit from data,(currently
                                           this option disabled by next field)
                                           pad extra bits with 0,
                                           LSB first,
                                           0 bit delay from between fsync and
                                           data*/
        /* .afsrctl  = */ 0x00000000,    /*2slot tdm,
                                           frame sync pulse width - 1 clk bit
                                           clk is internal
                                           Rising edge is validated*/
        /* .rtdm     = */ 0x00000003,    /*n-th (2 here)TDM slot will be
                                           accounted*/
        /* .rintctl  = */ 0x00000000,    /*This will be filled up by driver
                                           internally*/
        /* .rstat    = */ 0x000001FF,    /*reset any existing status bits*/
        /* .revtctl  = */ 0x00000000,    /*DMA or INT mode*/
        {
             /* .aclkrctl  = */ 0x00000000,  /* \div = 1, clk = External*/
             /* .ahclkrctl = */ 0x0000003F,  /* div = 63,
                                                no inversion before divider ,
                                                External*/
             /* .rclkchk   = */ 0x00000000
        }
} ;

/**
 * Device Parameters.
 * This will be passed down during mdBindDev.
 */
PSP_mcaspDevParams appDevParams = {             \
    /** Cache is enabled */
    TRUE,                                       \
    /** Packet Header information not available */
    FALSE,                                      \
   /** McASP HwSetup structure */               \
   &appMcaspHwSetup                             \
} ;

/*
 * The codec driver function table. Notice how we copy most functions
 * from the generic c6x1x edma mcasp driver.
 */
IOM_Fxns AUDIO_AIC33_FXNS = {
    &audio_mdBindDev,                   /* Bind device */
    NULL,                               /* UnBind device */
    &audio_mdControlChan,               /* Control Channel */
    &audio_mdCreateChan,                /* Create Channel */
    NULL,                               /* Delete Channel */
    NULL                                /* Submit Request */
};

/*
 * ======== mdBindDev ========
 * This function allocates and configures the pcm3002 codec.
 */
static Int audio_mdBindDev(Ptr *devp, Int devid, Ptr devParams)
{
    Int                status       = 0;
    PSP_mcbspDevParams *mcbspParams = NULL;
    PSP_mcaspDevParams *mcaspParams = NULL;

    PAL_osMemSet((Ptr)prdInputBuf, 0, (PRD_BUF_SIZE * 2));
    PAL_osMemSet((Ptr)prdOutputBuf, 0, (PRD_BUF_SIZE * 2));

    if(0 == devid)
    {
        if (NULL == devParams)
        {
            mcbspParams = (PSP_mcbspDevParams *)(&mcbsp_deviceparams);
        }
        else
        {
            mcbspParams = (PSP_mcbspDevParams *) devParams;
        }

        if (TRUE == mcbspParams->enablecache)
        {
            /* memset will not perform cache writeback to main memory */
            BCACHE_writeback(prdInputBuf,(PRD_BUF_SIZE * 2));
            BCACHE_writeback(prdOutputBuf,(PRD_BUF_SIZE * 2));
        }

        /* Call the generic mdBindDev to claim mcbsp port MCBSPPORT */
        status = McBSP_IOM_FXNS.mdBindDev(devp, MCBSPPORT, mcbspParams);

        mcBspPortHandle = *devp;
    }
    else
    {
        if (NULL == devParams)
        {
            mcaspParams = (PSP_mcaspDevParams *)(&appDevParams);
        }
        else
        {
            mcaspParams = (PSP_mcaspDevParams *) devParams;
        }

        if (TRUE == mcaspParams->enablecache)
        {
            /* memset will not perform cache writeback to main memory */
            BCACHE_writeback(prdInputBuf,(PRD_BUF_SIZE * 2));
            BCACHE_writeback(prdOutputBuf,(PRD_BUF_SIZE * 2));
        }

        /* Call the generic mdBindDev to claim mcasp port MCASPPORT */
        status = McASP_IOM_FXNS.mdBindDev(devp, MCASPPORT, mcaspParams);

        mcAspPortHandle = *devp;
    }

    return status;
}

/*
 * ======== mdCreateChan ========
 * This function creates and configures a device channel.
 */
/* ARGSUSED */
static Int audio_mdCreateChan(Ptr *chanp, Ptr devp, String name, Int mode,
                        Ptr chanParams, IOM_TiomCallback cbFxn, Ptr cbArg)
{
    static Int              status          = 0;
    PSP_mcbspChanParams     chanparams      = {0};
    PSP_mcaspChanParams     mcaspChanParams = {0};
    Bool                    whilefalse      = FALSE;
    static Int              cfgCodec        = 0;
    Uint32                  *prdBufPtr      = NULL;

    if(NULL == chanParams)
    {
        audio_cfg = &audio_cfg_params;
    }
    else
    {
        audio_cfg = (PSP_audio_cfg *)chanParams;
    }

    if (NULL == hEdma)
    {
        status = PSP_E_RESOURCES;
    }
    else
    {
        if (0 == cfgCodec)
        {
#ifdef PLL_INPUT_CLK
            /* configure the PLL for the required output clock                */
            audio_PllConfigure(audio_cfg->sampleFreq);
#endif
            status = aic33Codec_config(0, audio_cfg);
            cfgCodec = 1;
        }

        if ((-1) != status)
        {
            if(IOM_INPUT == mode)
            {
                prdBufPtr = (Uint32 *)(((Uint32) prdInputBuf + 0x7F) & ~0x7F);
            }
            else
            {
                prdBufPtr = (Uint32 *)(((Uint32) prdOutputBuf + 0x7F) & ~0x7F);
            }
            /* McBSP Initialization */
            if (mcBspPortHandle == devp)
            {
                if (0 != writeToIOExpander (MCBSP_SELECTED))
                {
                    status = PSP_E_RESOURCES;
                }
                else
                {

                    do
                    {
                        whilefalse = FALSE;

                        /* Create the channel */
                        chanparams.userLoopJobBuffer    = prdBufPtr;
                        chanparams.userLoopJobLength    = PRD_BUF_SIZE;
                        chanparams.edmaHandle           = hEdma;
                        chanparams.noOfTdmChans         = NUM_TDM_CHANNELS;
                        chanparams.wordWidth            = PSP_MCBSP_WORDLEN_32;

                        status = (McBSP_IOM_FXNS.mdCreateChan)(chanp,
                                                               devp,
                                                               name,
                                                               mode,
                                                               &chanparams,
                                                               cbFxn,
                                                               cbArg);
                    } while(whilefalse);

                    if (PSP_SOK == status)
                    {
                        status = MCBSP_Configuration(
                                            *chanp,
                                            audio_cfg->inputFreq,
                                            audio_cfg->sampleFreq
                                            );

                        if (PSP_SOK == status)
                        {
                            if(IOM_INPUT == mode)
                            {
                                mcBspChInHandle = *chanp;
                            }
                            else
                            {
                                mcBspChOutHandle = *chanp;
                            }
                        }
                    }
                }
            }
            else /* McASP Initialization */
            {
                if (0 != writeToIOExpander (MCASP_SELECTED))
                {
                    status = PSP_E_RESOURCES;
                }
                else
                {


                    if(IOM_INPUT == mode)
                    {
                        /* configure for the interrupt for overrun */
                        mcaspRcvSetup.intCtl = 0x00000003;

                        if(PSP_AUDIO_AIC_SLAVE == audio_cfg->mode)
                        {
                            mcasp_master_rcv_config();
                        }

                        mcaspChanParams.isDmaDriven             = TRUE;
                        mcaspChanParams.mcaspSetup              = &mcaspRcvSetup;
                        mcaspChanParams.channelMode             = PSP_MCASP_TDM_MODE;
                        mcaspChanParams.noOfChannels            = NUM_TDM_CHANNELS;

                        mcaspChanParams.wordWidth               = PSP_MCASP_WORDLEN_16;
                        mcaspChanParams.noOfSerRequested        = NUM_OF_SERIALISER;

                        mcaspChanParams.indexOfSersRequested[0] = SERIALIZER_1;

                        mcaspChanParams.userLoopJobBuffer       = NULL;
                        mcaspChanParams.userLoopJobLength       = LOOP_JOB_BUF_LENGTH;

                        mcaspChanParams.gblCbk                  = NULL;

                        mcaspChanParams.edmaHandle              = hEdma;
                    }
                    else
                    {
                        /* configure for the interrupt for underrun */
                        mcaspXmtSetup.intCtl = 0x00000003;

                        if(PSP_AUDIO_AIC_SLAVE == audio_cfg->mode)
                        {
                            mcasp_master_xmt_config();
                        }

                        mcaspChanParams.isDmaDriven             = TRUE;
                        mcaspChanParams.mcaspSetup              = &mcaspXmtSetup;
                        mcaspChanParams.channelMode             = PSP_MCASP_TDM_MODE;
                        mcaspChanParams.noOfChannels            = NUM_TDM_CHANNELS;

                        mcaspChanParams.wordWidth               = PSP_MCASP_WORDLEN_16;
                        mcaspChanParams.noOfSerRequested        = NUM_OF_SERIALISER;

                        mcaspChanParams.indexOfSersRequested[0] = SERIALIZER_0;

                        mcaspChanParams.userLoopJobBuffer       = NULL;
                        mcaspChanParams.userLoopJobLength       = LOOP_JOB_BUF_LENGTH;

                        mcaspChanParams.gblCbk                  = NULL;

                        mcaspChanParams.edmaHandle              = hEdma;
                    }

                    status = (McASP_IOM_FXNS.mdCreateChan)(chanp,
                                                           devp,
                                                           name,
                                                           mode,
                                                           &mcaspChanParams,
                                                           cbFxn,
                                                           cbArg);

                    if(IOM_INPUT == mode)
                    {
                        mcAspChInHandle = *chanp;
                    }
                    else
                    {
                        mcAspChOutHandle = *chanp;
                    }
                }
            }
        } /* if ((-1) != status */
        else
        {
            cfgCodec = 0; /* if audio configuration is not correct */
        }
    }

    return (status);
}

/*
 * ======== audio_mdControlChan ========
 * Calls underlying driver with the requested command to perform
 */
static Int audio_mdControlChan(Ptr chanp, Uns cmd, Ptr arg)
{
    Int                     IOMStatus   = IOM_EBADARGS;

    if((mcBspChInHandle == chanp) || (mcBspChOutHandle == chanp))
    {
        switch(cmd)
        {
            default:
                IOMStatus = McBSP_IOM_FXNS.mdControlChan(chanp, cmd, arg);
                break;

            case AUDIO_STOP:
                IOMStatus = McBSP_IOM_FXNS.mdControlChan(
                                                chanp,
                                                PSP_CTRL_McBSP_STOP,
                                                arg
                                                );
                break;

            case AUDIO_START:
                IOMStatus = McBSP_IOM_FXNS.mdControlChan(
                                                chanp,
                                                PSP_CTRL_McBSP_START,
                                                arg
                                                );
                break;

            case AUDIO_MUTEON:
                IOMStatus = McBSP_IOM_FXNS.mdControlChan(
                                                chanp,
                                                PSP_CTRL_McBSP_MUTE_ON,
                                                arg
                                                );
                break;

            case AUDIO_MUTEOFF:
                IOMStatus = McBSP_IOM_FXNS.mdControlChan(
                                                chanp,
                                                PSP_CTRL_McBSP_MUTE_OFF,
                                                arg
                                                );
                break;

            case AUDIO_PAUSE:
                IOMStatus = McBSP_IOM_FXNS.mdControlChan(
                                                chanp,
                                                PSP_CTRL_McBSP_PAUSE,
                                                arg
                                                );
                break;

            case AUDIO_RESUME:
                IOMStatus = McBSP_IOM_FXNS.mdControlChan(chanp,
                                                         PSP_CTRL_McBSP_RESUME,
                                                         arg);
                break;

            /* Loop job enable */
            case AUDIO_MODIFY_LOOPJOB:
                IOMStatus = McBSP_IOM_FXNS.mdControlChan(
                                                  chanp,
                                                  PSP_CTRL_McBSP_MODIFY_LOOPJOB,
                                                  arg);
                break;

            case AUDIO_INPUT_SAMPLERATE:
                if (PSP_AUDIO_AIC_MASTER == audio_cfg->mode)
                {
                    /* configure the PLL for the required output clock        */
                    audio_cfg->sampleFreq =  (*(Uint32 *)arg);

#ifdef PLL_INPUT_CLK

                    IOMStatus = audio_PllConfigure(audio_cfg->sampleFreq);
#endif
                    IOMStatus = aic33_sampleRateControl(audio_cfg);
                }
                else
                {
                    audio_cfg->sampleFreq =  * (Uint32 *)(arg);
                    IOMStatus = aic33_sampleRateControl( audio_cfg );

                    if (IOM_COMPLETED == IOMStatus)
                    {
                        IOMStatus = MCBSP_Configuration(
                                        chanp,
                                        audio_cfg->inputFreq,
                                        (*(Uint32 *)arg)
                                        );
                    }

                }
                break;

            case AUDIO_OUTPUT_SAMPLERATE:
                /* configure for changing sample rate */
                if (PSP_AUDIO_AIC_MASTER == audio_cfg->mode)
                {
                    audio_cfg->sampleFreq =  * (Uint32 *)(arg);

#ifdef PLL_INPUT_CLK
                    IOMStatus = audio_PllConfigure(audio_cfg->sampleFreq);
#endif
                    IOMStatus = aic33_sampleRateControl(audio_cfg);
                }
                else
                {
                    audio_cfg->sampleFreq =  * (Uint32 *)(arg);
                    IOMStatus = aic33_sampleRateControl( audio_cfg );

                    if (IOM_COMPLETED == IOMStatus)
                    {
                        IOMStatus = MCBSP_Configuration(
                                        chanp,
                                        audio_cfg->inputFreq,
                                        (*(Uint32 *) arg)
                                        );
                    }
                }
                break;
            case AUDIO_OUT_SELECT:
                IOMStatus = PSP_E_NOT_SUPPORTED;
                break;

            case AUDIO_IN_SELECT:
                IOMStatus = aic33Codec_config(0, audio_cfg);
                break;

            case AUDIO_IN_GAIN_CONTROL:
                IOMStatus = aic33_inGainControl(( * (Uint8 *) arg), audio_cfg);
                break;

            case AUDIO_OUT_GAIN_CONTROL:
                IOMStatus = aic33_outGainControl(( * (Uint8 *) arg), audio_cfg);
                break;

            case AUDIO_DEVICE_RESET:
                 IOMStatus = McBSP_IOM_FXNS.mdControlChan(
                                                chanp,
                                                PSP_CTRL_McBSP_DEVICE_RESET,
                                                NULL
                                                );

                break;
            case AUDIO_DEVICE_CODEC_REG_READ:
                IOMStatus = aic33ReadWriteIoctl(
                                AIC33_READ_CMD,
                                (aic33_RegData *)arg);
                break;
            case AUDIO_DEVICE_CODEC_REG_WRITE:
                IOMStatus = aic33ReadWriteIoctl(
                                AIC33_WRITE_CMD,
                                (aic33_RegData *)arg);
                break;

        }
    }
    else
    {
        if ((mcAspChInHandle == chanp) || (mcAspChOutHandle == chanp))
        {
            switch (cmd)
            {
                case AUDIO_STOP:
                        IOMStatus = McASP_IOM_FXNS.mdControlChan(
                                                        chanp,
                                                        PSP_MCASP_STOP_PORT,
                                                        NULL
                                                        );
                        break;

                case AUDIO_START:
                        IOMStatus = McASP_IOM_FXNS.mdControlChan(
                                                        chanp,
                                                        PSP_MCASP_START_PORT,
                                                        NULL
                                                        );
                        break;
                /* command to Mute On*/
                case AUDIO_MUTEON:
                        IOMStatus = McASP_IOM_FXNS.mdControlChan(
                                                        chanp,
                                                        PSP_CTRL_McASP_MUTE_ON,
                                                        NULL
                                                        );
                        break;
                /* command to MUTEOFF*/

                case AUDIO_MUTEOFF:
                        IOMStatus = McASP_IOM_FXNS.mdControlChan(
                                                        chanp,
                                                        PSP_CTRL_McASP_MUTE_OFF,
                                                        NULL
                                                        );
                        break;
                    /* Loop job enable/disable*/
                case AUDIO_MODIFY_LOOPJOB:
                        IOMStatus = McASP_IOM_FXNS.mdControlChan(
                                                chanp,
                                                PSP_CTRL_McASP_MODIFY_LOOPJOB,
                                                arg
                                                );
                        break;

                case AUDIO_INPUT_SAMPLERATE:
                    /* configure for changing sample rate */
                    if (PSP_AUDIO_AIC_MASTER == audio_cfg->mode)
                    {
                        audio_cfg->sampleFreq = ( *(Uint32 *)arg);
#ifdef PLL_INPUT_CLK
                        IOMStatus = audio_PllConfigure(audio_cfg->sampleFreq);
#endif
                        IOMStatus = aic33_sampleRateControl(audio_cfg);
                    }
                    else
                    {

                        audio_cfg->sampleFreq =  (*(Uint32 *)arg);
                        IOMStatus = aic33_sampleRateControl( audio_cfg );

                        if (IOM_COMPLETED == IOMStatus)
                        {
                            IOMStatus = MCASP_Configuration(
                                            chanp,
                                            audio_cfg->inputFreq,
                                            ( * (Uint32 *) arg)
                                            );
                        }
                    }
                    break;

                case AUDIO_OUTPUT_SAMPLERATE:
                    /* configure for changing sample rate */
                    if (PSP_AUDIO_AIC_MASTER == audio_cfg->mode)
                    {
                        audio_cfg->sampleFreq =  (*(Uint32 *)arg);
#ifdef PLL_INPUT_CLK
                        IOMStatus = audio_PllConfigure(audio_cfg->sampleFreq);                        
#endif
                        IOMStatus = aic33_sampleRateControl(audio_cfg);
                    }
                    else
                    {
                        audio_cfg->sampleFreq =  * (Uint32 *)(arg);

                        IOMStatus = aic33_sampleRateControl( audio_cfg );

                        if (IOM_COMPLETED == IOMStatus)
                        {
                            IOMStatus = MCASP_Configuration(
                                            chanp,
                                            audio_cfg->inputFreq,
                                            (*(Uint32 *)arg)
                                            );
                        }
                    }
                    break;

                case AUDIO_PAUSE:
                    IOMStatus = McASP_IOM_FXNS.mdControlChan(
                                                    chanp,
                                                    PSP_MCASP_PAUSE,
                                                    arg
                                                    );
                    break;

                case AUDIO_RESUME:
                    IOMStatus = McASP_IOM_FXNS.mdControlChan(
                                                    chanp,
                                                    PSP_MCASP_RESUME,
                                                    arg
                                                    );
                    break;

                case AUDIO_OUT_SELECT:
                    IOMStatus = PSP_E_NOT_SUPPORTED;
                    break;

                case AUDIO_IN_SELECT:
                    IOMStatus = aic33Codec_config(0, arg);
                    break;

                case AUDIO_IN_GAIN_CONTROL:
                    IOMStatus = aic33_inGainControl(( * (Uint8 *) arg), audio_cfg);
                    break;

                case AUDIO_OUT_GAIN_CONTROL:
                    IOMStatus = aic33_outGainControl(( * (Uint8 *) arg), audio_cfg);
                    break;

                case AUDIO_DEVICE_RESET:
                    IOMStatus = McASP_IOM_FXNS.mdControlChan(
                                                chanp,
                                                PSP_MCASP_DEVICE_RESET,
                                                NULL
                                                );
                    break;
                case AUDIO_DEVICE_CODEC_REG_READ:
                    IOMStatus = aic33ReadWriteIoctl(
                                    AIC33_READ_CMD,
                                    (aic33_RegData *)arg);
                    break;
                case AUDIO_DEVICE_CODEC_REG_WRITE:
                    IOMStatus = aic33ReadWriteIoctl(
                                    AIC33_WRITE_CMD,
                                    (aic33_RegData *)arg);
                    break;
                default:
                    IOMStatus = McASP_IOM_FXNS.mdControlChan(chanp, cmd, arg);
                        break;
            }
        }
    }

    return IOMStatus;
}


/*
 * ======== AUDIO_AIC33_init ========
 * This function initializes the driver's structures.
 */
Void AUDIO_AIC33_init0()
{
    CSL_SysRegsOvly sysModuleRegs = (CSL_SysRegsOvly )CSL_SYS_0_REGS;

    /* Pass some IOM fxns straight to the generic driver */
    AUDIO_AIC33_FXNS.mdDeleteChan =
        McBSP_IOM_FXNS.mdDeleteChan;
    AUDIO_AIC33_FXNS.mdSubmitChan =
        McBSP_IOM_FXNS.mdSubmitChan;
    AUDIO_AIC33_FXNS.mdUnBindDev =
        McBSP_IOM_FXNS.mdUnBindDev;

    /* Set the Pin Mux */
    sysModuleRegs->PINMUX1 &= 0xFDFFFFFF;
    sysModuleRegs->PINMUX1 |= MCBSPBLOCK1;

    /* Power up settings
     * MCBSP    =   0; VDD3P3V_PWDN - bit 7
     */
    sysModuleRegs->VDD3P3V_PWDN &= (~(0x00000080u));

    MCBSP_IOM_init();
}

/*
 * ======== AUDIO_AIC33_init ========
 * This function initializes the driver's structures.
 */
Void AUDIO_AIC33_init1()
{
    /* Pass some IOM fxns straight to the generic driver */
    AUDIO_AIC33_FXNS.mdDeleteChan =
        McASP_IOM_FXNS.mdDeleteChan;
    AUDIO_AIC33_FXNS.mdSubmitChan =
        McASP_IOM_FXNS.mdSubmitChan;
    AUDIO_AIC33_FXNS.mdUnBindDev =
        McASP_IOM_FXNS.mdUnBindDev;

    /* Enable pinmux for McASP instance 0 */
    mcasp_pinmuxConfig();
}

/*
 * ======== MCBSP_Configuration ========
 * This function configures McBSP peripheral for
 *    1. Master/slave mode operation
 *    2. Sample rate
 */
static Int MCBSP_Configuration(Ptr chanp, Uint32 inputFreq, Uint32 samplingRate)
{
    Uint8               mdIoCtl;
    PSP_srgConfig       srgConfig =
                                    {
                                        0,
                                        PSP_MCBSP_FSX_DXR_COPY,
                                        0,
                                        0,
                                        0,
                                        0
                                    };

    Int                 status;

    /* Stop the McBSP receiver and transmitter */
    status = McBSP_IOM_FXNS.mdControlChan(chanp, PSP_CTRL_McBSP_STOP, NULL);

    /* Stop the McBSP sample rate generator */
    status |= McBSP_IOM_FXNS.mdControlChan(chanp,
                                           PSP_CTRL_McBSP_SRGR_STOP,
                                           NULL);

    /* Stop the McBSP Frame Sync generator */
    status |= McBSP_IOM_FXNS.mdControlChan(chanp,
                                           PSP_CTRL_McBSP_FSGR_STOP,
                                           NULL);

    if (PSP_AUDIO_AIC_MASTER == audio_cfg->mode)
    {
        mdIoCtl = (PSP_McbspBclkMode)(PSP_MCBSP_BCLKCLKMODE_EXTERNAL);
    }
    else
    {
        mdIoCtl = (PSP_McbspBclkMode)(PSP_MCBSP_BCLKCLKMODE_INTERNAL);
    }
    /* Configure McBSP in master mode to supply the clock and
     * frame sync to AIC codec */
    status |= McBSP_IOM_FXNS.mdControlChan(
                                    chanp,
                                    PSP_CTRL_McBSP_SET_CLKMODE,
                                    (Ptr) &mdIoCtl
                                    );

    if (PSP_AUDIO_AIC_MASTER == audio_cfg->mode)
    {
        mdIoCtl = (PSP_McbspFrSynchMode)( PSP_MCBSP_FRSYNCHMODE_EXTERNAL);
    }
    else
    {
        mdIoCtl = (PSP_McbspFrSynchMode)( PSP_MCBSP_FRSYNCHMODE_INTERNAL);
    }
    status |= McBSP_IOM_FXNS.mdControlChan(
                                    chanp,
                                    PSP_CTRL_McBSP_SET_FRMSYNCMODE,
                                    (Ptr) &mdIoCtl
                                    );

   /*
    * Configure the sample rate generator to generate bit Clock and
    * frame sync signals
    */
    if (PSP_AUDIO_AIC_MASTER == audio_cfg->mode)
    {
        srgConfig.srgInputClkMode = PSP_MCBSP_SRGCLK_CLKX; /* Use CLKX clock */
        srgConfig.srgFsgmMode     = PSP_MCBSP_FSX_DXR_COPY;
    }
    else
    {
        srgConfig.srgInputClkMode = PSP_MCBSP_SRGCLK_CLKCPU; /* Use CPU clock */
        srgConfig.srgFsgmMode     = PSP_MCBSP_FSX_FSG;


        srgConfig.bclkRate
            = (inputFreq / (samplingRate * DEFAULT_BITPERSAMPLE * NUM_OF_CHANNELS))
              - 1u;

        srgConfig.srgClkPolarity = PSP_MCBSP_SRGCLKPOL_RISING_EDGE;

        /* Two 16-bit samples(DSP data format) */
        srgConfig.srgFrmPeriod  = (DEFAULT_BITPERSAMPLE * NUM_OF_CHANNELS - 1u);

        /* Pulse width will be 1 clock cycle */
        srgConfig.srgFrmPulseWidth= 0;
    }

    status |= McBSP_IOM_FXNS.mdControlChan(
                                        chanp,
                                        PSP_CTRL_McBSP_CONFIG_SRGR,
                                        (Ptr)&srgConfig
                                        );

    /* Need to wait 2 clock cycles here.The Worst case delay when sample rate *
     * is 8000 Hz is 2*1/8000 = 0.25Msec,but bios provides a minumum delay of *
     * one msec only hence a delay of 1 msec is used                          */
    PAL_osWaitMsecs(1);

    if (PSP_AUDIO_AIC_SLAVE == audio_cfg->mode)
    {
        /* Start the sample rate generator */
        status |= McBSP_IOM_FXNS.mdControlChan(
                                            chanp,
                                            PSP_CTRL_McBSP_SRGR_START,
                                            NULL
                                            );
    }

    /* Start the McBSP transmitter */
    status |= McBSP_IOM_FXNS.mdControlChan(
                                        chanp,
                                        PSP_CTRL_McBSP_START,
                                        NULL
                                        );

    if (PSP_AUDIO_AIC_SLAVE == audio_cfg->mode)
    {
        /* Start the Frame sync generator */
        status |= McBSP_IOM_FXNS.mdControlChan(
                                            chanp,
                                            PSP_CTRL_McBSP_FSGR_START,
                                            NULL
                                            );

        /* Need to wait 2 clock cycles here.The Worst case delay when sample  *
         * rate is 8000 Hz is 2*1/8000 = 0.25Msec,but bios provides a minumum *
         * delay of one msec only hence a delay of 1 msec is used             */
        PAL_osWaitMsecs(1);
    }

    return (status);
}

/*
 * ======== MCASP_Configuration ========
 * This function configures McBSP peripheral for
 *    1. Sample rate
 */
static Int MCASP_Configuration(Ptr chanp, Uint32 inputFreq, Uint32 samplingRate)
{
    PSP_McaspHwSetupData     mcaspConfig = {0};
    Int                      status = 0 ;
    Uint32                   changedSampleRate = 0;

    status |= McASP_IOM_FXNS.mdControlChan(
                                chanp,
                                PSP_MCASP_CNTRL_GET_FORMAT_CHAN,
                                &mcaspConfig
                                );
    changedSampleRate
        = (inputFreq / (samplingRate * DEFAULT_BITPERSAMPLE * NUM_OF_CHANNELS))
          -1;

    mcaspConfig.clk.clkSetupHiClk &= 0xFFFFF000;

    mcaspConfig.clk.clkSetupHiClk |= (changedSampleRate & 0x00000FFF) ;

    status |= McASP_IOM_FXNS.mdControlChan(
                                chanp,
                                PSP_MCASP_CNTRL_SET_FORMAT_CHAN,
                                &mcaspConfig
                                );
    return (status);
}

/*
 * ======== mcasp_pinmuxConfig ========
 * This function configures PinMux register for McASP
 */
static void mcasp_pinmuxConfig ()
{
    CSL_SysRegsOvly sysModuleRegs = (CSL_SysRegsOvly )CSL_SYS_0_REGS;

    /* Pinmux settings for McASP0
     *  PCIEN   =   0: PINMUX1 - bit - 0
     *  GIOBK   =   1: PINMUX1 - bit - 7
     *  UR0DBK  =   10:PINMUX1 - bit - 9:8
     *  UR0FCBK =   11:PINMUX1 - bit - 11:10
     *  PWM1BK  =   10:PINMUX1 - bit - 13:12
     *  TIM0BK  =  100:PINMUX1 - bit - 18:16
     */

    sysModuleRegs -> PINMUX1    &=  (0x02B7EFF0u);
    sysModuleRegs -> PINMUX1    |=  (0x02800000u);
    /* Power up setting
     *  UR0DAT  =   0: VDD3P3V_PWDN  -   bit-10
     *  UR0FC   =   0: VDD3P3V_PWDN  -   bit-11
     */
    sysModuleRegs->VDD3P3V_PWDN &= (~(0x00000C00u));

    /* Pinmux settings for McASP1
     *  CI10SEL  = 10   : PINMUX0 - bit - 31:30
     *  CI32SEL  = 10   : PINMUX0 - bit - 29:28
     *  CI54SEL  = 10   : PINMUX0 - bit - 27:26
     *  CCDCSEL  = 10   : PINMUX0 - bit - 21:20
     *  AEM      = 0    : PINMUX0 - bit - 0:2
     *
     *  PCIEN    = 0    : PINMUX1 - bit - 0
     */

    /*sysModuleRegs -> PINMUX0     |=  (0xA8100000u)*/
    /*sysModuleRegs -> PINMUX0     &=  (0xABF7FFFFu)*/
    /*sysModuleRegs -> PINMUX1     &=  (0xFFFFFFFEu)*/

    MCASP_IOM_init();
}

/*
 * ======== McASP_Master_Rcv_Config ========
 * This function configures McASP peripheral receive channel for
 *    1. Slave mode
 *    2. Samplerate
 */
static void mcasp_master_rcv_config()
{
    Uint32 rcvSampleRate = 0;

    rcvSampleRate = (audio_cfg->inputFreq
        / (audio_cfg->sampleFreq * DEFAULT_BITPERSAMPLE * NUM_OF_CHANNELS)) -1;

    rcvSampleRate &= HI_CLOCK_SAMPLERATE_MASK;

    /* Receive clock source generated internally */
    mcaspRcvSetup.clk.clkSetupClk   |=  CLOCK_ENABLE;

    /* Clear the hiclock divider bits */
    mcaspRcvSetup.clk.clkSetupHiClk &= (~(HI_CLOCK_SAMPLERATE_MASK));

    /* Receive frame sync is internally generated */
    mcaspRcvSetup.frSyncCtl |= FRAMESYNC_INTERNAL;

    /* Configure the clock divider with a new value */
    mcaspRcvSetup.clk.clkSetupHiClk
        |= (HI_CLOCK_ENABLE | rcvSampleRate);
                                              /* div = changedSampleRate,
                                                 Internal*/
    return;
}

/*
 * ======== McASP_Master_Xmt_Config ========
 * This function configures McASP peripheral transmit channel for
 *    1. Slave mode
 *    2. Samplerate
 */
static void mcasp_master_xmt_config()
{
    Uint32 xmitSampleRate = 0;

    xmitSampleRate = (audio_cfg->inputFreq
        / (audio_cfg->sampleFreq * DEFAULT_BITPERSAMPLE * NUM_OF_CHANNELS)) -1;

    xmitSampleRate &= HI_CLOCK_SAMPLERATE_MASK;

    /* Transmit clock source generated internally */
    mcaspXmtSetup.clk.clkSetupClk |= CLOCK_ENABLE;

    /* Clear the hiclock divider bits */
    mcaspXmtSetup.clk.clkSetupHiClk &= (~(HI_CLOCK_SAMPLERATE_MASK));

    /* Receive frame sync is internally generated */
    mcaspXmtSetup.frSyncCtl |= FRAMESYNC_INTERNAL;

    /* Configure the clock divider with a new value */
    mcaspXmtSetup.clk.clkSetupHiClk
        |= (HI_CLOCK_ENABLE | xmitSampleRate);
                                              /* div = changedSampleRate,
                                                 Internal*/
    return;
}


