/*******************************************************************************
**+--------------------------------------------------------------------------+**
**|                            ****                                          |**
**|                            ****                                          |**
**|                            ******o***                                    |**
**|                      ********_///_****                                   |**
**|                      ***** /_//_/ ****                                   |**
**|                       ** ** (__/ ****                                    |**
**|                           *********                                      |**
**|                            ****                                          |**
**|                            ***                                           |**
**|                                                                          |**
**|         Copyright (c) 1998-2006 Texas Instruments Incorporated           |**
**|                        ALL RIGHTS RESERVED                               |**
**|                                                                          |**
**| Permission is hereby granted to licensees of Texas Instruments           |**
**| Incorporated (TI) products to use this computer program for the sole     |**
**| purpose of implementing a licensee product based on TI products.         |**
**| No other rights to reproduce, use, or disseminate this computer          |**
**| program, whether in part or in whole, are granted.                       |**
**|                                                                          |**
**| TI makes no representation or warranties with respect to the             |**
**| performance of this computer program, and specifically disclaims         |**
**| any responsibility for any damages, special or consequential,            |**
**| connected with the use of this program.                                  |**
**|                                                                          |**
**+--------------------------------------------------------------------------+**
*******************************************************************************/

/** \file   psp_bios_main_sample.c
 *
 *  \brief  This file contains the test / demo code to demonstrate the
 *          I2C/EDMA/UART/NAND/VPSS driver implemented for DSP/BIOS
 *
 *  (C) Copyright 2006, Texas Instruments, Inc
 *
 *  \author     PSP Team
 *  \version    0.1
 */

#include <std.h>
#include <gio.h>
#include <stdio.h>
#include <log.h>
#include <ti/sdo/edma3/drv/src/edma3.h>
#include <ti/sdo/edma3/drv/edma3_drv.h>
#include <ti/sdo/edma3/rm/src/edma3ResMgr.h>
#include <ti/sdo/pspdrivers/drivers/uart/psp_uart.h>
#include <ti/sdo/pspdrivers/pal_os/pal_osWait.h>
#include <ti/sdo/pspdrivers/pal_os/bios/psputils.h>

#ifdef CHIP_DM6437
#include <ti/sdo/pspdrivers/pal_sys/dm6437/pal_sys.h>
#include <ti/sdo/pspdrivers/pal_sys/dm6437/pal_sys_soc.h>
#include <ti/sdo/pspdrivers/soc/dm6437/dsp/soc.h>
#include <ti/sdo/pspdrivers/soc/dm6437/dsp/cslr_sys.h>
#include <ti/sdo/pspdrivers/soc/dm6437/dsp/cslr_psc.h>
#endif

#ifdef CHIP_C6424
#include <ti/sdo/pspdrivers/pal_sys/c6424/pal_sys.h>
#include <ti/sdo/pspdrivers/pal_sys/c6424/pal_sys_soc.h>
#include <ti/sdo/pspdrivers/soc/c6424/dsp/soc.h>
#include <ti/sdo/pspdrivers/soc/c6424/dsp/cslr_sys.h>
#include <ti/sdo/pspdrivers/soc/c6424/dsp/cslr_psc.h>
#endif

#define PSP_DEBUG_PRINTF
/* Defines to enable and tests for various drivers*/

#define PSP_EDMA_TEST
/* #undef PSP_EDMA_TEST */

#define PSP_UART_TEST
/*#undef PSP_UART_TEST*/

#define PSP_I2C_TEST
/*#undef PSP_I2C_TEST*/

/* #define PSP_NAND_TEST */
#undef PSP_NAND_TEST

#ifdef CHIP_DM6437
#define PSP_VPSS_TEST
#else
#undef PSP_VPSS_TEST
#endif

/* #define PSP_VLYNQ_TEST */
#undef PSP_VLYNQ_TEST

#ifdef PSP_DEBUG_PRINTF
#define PSP_DEBUG_PRINT       kprintf
#endif /* PSP_DEBUG_PRINTF */

/* External Declaration */
extern EDMA3_DRV_Handle hEdma;
extern EDMA3_DRV_Result edma3init();
extern EDMA3_DRV_Result edma3MemToMemCpytest ();

#ifdef PSP_I2C_TEST
extern void start_i2c_sample();
#endif

#ifdef CHIP_DM6437
#ifdef PSP_VPSS_TEST
extern void start_vpss_test();
#endif
#endif

GIO_Handle hUart_OUT,hUart_IN;

static void tskHeartBit();

#ifdef PSP_VLYNQ_TEST
void start_vlynq_test();
#endif

static CSL_SysRegsOvly sysModuleRegs = (CSL_SysRegsOvly )CSL_SYS_0_REGS;

#ifdef PSP_UART_TEST
extern void start_uart_sample();
#endif /* PSP_UART_TEST */

void pspConsoleOut(Int32 data);

extern void initNand(Uint32 nandClkFreq);
#ifdef  PSP_NAND_TEST
extern void nandTestCode(void);
#define NANDCLKFREQUENCY        (27000000u)
#endif /* PSP_NAND_TEST */

void main()
{
    PSP_DEBUG("\nTII PSP Sample Main: Please check UART Terminal for Logs\n");
    return;
}




/* UART Echo Task */
void pspUartEchoTask(void)
{
    /* PSP Welcome Message */
    PSP_DEBUG_PRINT("***************************************************************\n\r");
    PSP_DEBUG_PRINT("*                                                             *\n\r");
    PSP_DEBUG_PRINT("*                            ****                             *\n\r");
    PSP_DEBUG_PRINT("*                            ****                             *\n\r");
    PSP_DEBUG_PRINT("*                            ******o***                       *\n\r");
    PSP_DEBUG_PRINT("*                      ********_///_****                      *\n\r");
    PSP_DEBUG_PRINT("*                      ***** /_//_/ ****                      *\n\r");
    PSP_DEBUG_PRINT("*                       ** ** (__/ ****                       *\n\r");
    PSP_DEBUG_PRINT("*                           *********                         *\n\r");
    PSP_DEBUG_PRINT("*                            ****                             *\n\r");
    PSP_DEBUG_PRINT("*                            ***                              *\n\r");
    PSP_DEBUG_PRINT("*                                                             *\n\r");
#ifdef CHIP_DM6437
	PSP_DEBUG_PRINT("*                     TI DM6437 EVM BIOS PSP                  *\n\r");
#endif
#ifdef CHIP_C6424
    PSP_DEBUG_PRINT("*                     TI C6424  EVM BIOS PSP                  *\n\r");
#endif
    PSP_DEBUG_PRINT("*                                                             *\n\r");
    PSP_DEBUG_PRINT("*                                                             *\n\r");
    PSP_DEBUG_PRINT("*       For issues on base port contact TII PSP Team          *\n\r");
    PSP_DEBUG_PRINT("*                                                             *\n\r");
    PSP_DEBUG_PRINT("*                                                             *\n\r");
    PSP_DEBUG_PRINT("*                                                             *\n\r");
    PSP_DEBUG_PRINT("***************************************************************\n\r");
    PSP_DEBUG_PRINT("\r\n\r\n");

}
void echo()
{
    GIO_Attrs gioAttrs = GIO_ATTRS;
    Int32 echoTskStatus= 0;
 	PSP_uartIoParams    chanParams;


	EDMA3_DRV_Result    edmaResult;

    if (NULL == hEdma)
    {
        edmaResult = edma3init();
        if (edmaResult != EDMA3_DRV_SOK)
        {
            /* Report EDMA Error */
            PSP_DEBUG("\r\nEDMA3 : edma3init() failed\r\n");
        }
        else
        {
            PSP_DEBUG("\r\nEDMA3 : edma3init() passed\r\n");
        }
    }


    /* Initialize UART
    * Currently is been used to display messages
    */
#ifdef INCLUDE_PSP_INIT_UART_DRV
    /* Power up settings for UART0
     * UR0DAT = 1: VDD3P3V_PWDN - bit 10
     */
    sysModuleRegs->VDD3P3V_PWDN &=  (~(0x400u));
    /*  Pinmux setting for UART0
     *  UR0DBK = 01 :   PINMUX1 - bit 9:8
     *  UR0FCBK = 01:   PINMUX1 - bit 11:10
     */
    sysModuleRegs->PINMUX1  &=   (0xFFFFF5FFu);
    sysModuleRegs->PINMUX1  |=   (0x00000500u);

	chanParams.hEdma = hEdma;

    /*  Pinmux setting for UART1
     *  TIM1BK = 10 :   PINMUX1 - bit 21:20
     */
    hUart_OUT = GIO_create("/UART0",IOM_OUTPUT,NULL,&chanParams,&gioAttrs);
    hUart_IN  = GIO_create("/UART0",IOM_INPUT,&echoTskStatus,&chanParams,&gioAttrs);
    if((NULL == hUart_IN)||(NULL == hUart_OUT))
    {
        PSP_DEBUG("ERROR: Initialization of UART failed\n");
        return;
    }

    /* Print the banner */
    pspUartEchoTask();

#endif /* INCLUDE_PSP_INIT_UART_DRV */


#ifdef PSP_UART_TEST
    if((NULL != hUart_IN)||(NULL != hUart_OUT))
    {
        /* Run UART sample application */
        start_uart_sample();

    }
#endif

#ifdef PSP_I2C_TEST
    /* Run UART sample application */
    start_i2c_sample();
#endif /*PSP_I2C_TEST*/

#ifdef PSP_NAND_TEST

    PSP_DEBUG_PRINT("\r\nNAND  :NAND testing started \n");

    /* Set PINMUX to use NAND */
    /*
     * AEM   =  001 : PINMUX0 - bit-  2:0
     * AEAW  =  010 : PINMUX0 - bit-  18:16
     * PCIEN =  0   : PINMUX1 - bit - 0
     */
    sysModuleRegs -> PINMUX0    &= (0xFFFAFFF9u);
    sysModuleRegs -> PINMUX0     |= (0x00020001u);
    sysModuleRegs -> PINMUX1     &= (0xFFFFFFFEu);
    /* Init Nand driver */
    initNand(NANDCLKFREQUENCY);
    /* Start nand test */
    nandTestCode();
    PSP_DEBUG_PRINT("\r\nNAND  :NAND testing completed \r\n\n");
#endif /*PSP_NAND_TEST*/

#ifdef CHIP_f
#ifdef PSP_VPSS_TEST
    /* VPSS PinMuxing */
    /* CI10SEL   - No CI[1:0]                       */
    /* CI32SEL   - No CI[3:2]                       */
    /* CI54SEL   - No CI[5:4]                       */
    /* CI76SEL   - No CI[7:6]                       */
    /* CFLDSEL   - No C_FIELD                       */
    /* CWENSEL   - No C_WEN                         */
    /* HDVSEL    - CCDC HD and VD enabled           */
    /* CCDCSEL   - CCDC PCLK, YI[7:0] enabled       */
    /* AEAW      - EMIFA full address mode          */
    /* VPBECKEN  - VPBECLK enabled                  */
    /* RGBSEL    - No digital outputs               */
    /* CS3SEL    - LCD_OE/EM_CS3 disabled           */
    /* CS4SEL    - CS4/VSYNC enabled                */
    /* CS5SEL    - CS5/HSYNC enabled                */
    /* VENCSEL   - VCLK,YOUT[7:0],COUT[7:0] enabled */
    /* AEM       - 8bEMIF + 8bCCDC + 8 to 16bVENC   */
    sysModuleRegs -> PINMUX0    &= (0x005482A3u);
    sysModuleRegs -> PINMUX0    |= (0x005482A3u);

    /* PCIEN    =   0: PINMUX1 - Bit 0 */
    sysModuleRegs -> PINMUX1 &= (0xFFFFFFFEu);

    sysModuleRegs -> VPSS_CLKCTL = (0x18u);

    /*Start of VPSS Test Application */
    start_vpss_test();
#endif /* PSP_VPSS_TEST */
#endif

#ifdef PSP_VLYNQ_TEST
    /* Pinmux settings for VLYNQ
     * PCIEN = 0: PINMUX1 - bit - 0
     * HOSTBK= 010: PINMUX1 bits - 6:4
     */
    sysModuleRegs -> PINMUX1    &=  (0xFFFFFFAEu);
    sysModuleRegs -> PINMUX1    |=  (0x00000020u);
    /*
     * Power up settings for VLYNQ
     * HOST = 0: VDD3P3V_PWDN- bit - 4
     */
    sysModuleRegs -> VDD3P3V_PWDN &= (~(0x00000010u));

    /*Run VLYNQ Test*/
    start_vlynq_test();
#endif /*PSP_VLYNQ_TEST*/

    /* Start the Heart Beat Print */
    tskHeartBit();

    return;
}

void tskHeartBit()
{
    static Uint32 counter = 0;

    while (counter < 0xFFFFFFFF)
    {
        PAL_osWaitMsecs(1000u);    /* Add large delay */
        PSP_DEBUG_PRINT("\r\n\r\n!!! PSP HrtBt %l", counter);
        counter++;
    }
}

/**
 * \brief   which prints on to the console
 */
void pspConsoleOut(Int32 data)
{
#if defined(INCLUDE_PSP_INIT_UART_DRV) && !defined(INCLUDE_PSP_INIT_UART_EDMA)
    char charData = (char) data;
    size_t len=1;
    PSP_uartDataParam buf;
    Int32   status;

    if(NULL != hUart_OUT){
        buf.addr = &charData;
        buf.timeout = SYS_FOREVER;
        len = 1;
        status = GIO_write(hUart_OUT, &buf, &len);
        if(! ((status != IOM_COMPLETED)||(status != IOM_PENDING)))
        {
#ifdef PSP_DEBUG_PRINTF
            PSP_DEBUG("\npspConsoleOut: Error writing data to UART");
#endif
        }
    }
#else /* INCLUDE_PSP_INIT_UART_DRV & !INCLUDE_PSP_INIT_UART_EDMA */
    PSP_DEBUG1("%c", data);
#endif /* INCLUDE_PSP_INIT_UART_DRV & !INCLUDE_PSP_INIT_UART_EDMA */
}
