/******************************************************************************
**+-------------------------------------------------------------------------+**
**|                            ****                                         |**
**|                            ****                                         |**
**|                            ******o***                                   |**
**|                      ********_///_****                                  |**
**|                      ***** /_//_/ ****                                  |**
**|                       ** ** (__/ ****                                   |**
**|                           *********                                     |**
**|                            ****                                         |**
**|                            ***                                          |**
**|                                                                         |**
**|         Copyright (c) 1998-2006 Texas Instruments Incorporated          |**
**|                        ALL RIGHTS RESERVED                              |**
**|                                                                         |**
**| Permission is hereby granted to licensees of Texas Instruments          |**
**| Incorporated (TI) products to use this computer program for the sole    |**
**| purpose of implementing a licensee product based on TI products.        |**
**| No other rights to reproduce, use, or disseminate this computer         |**
**| program, whether in part or in whole, are granted.                      |**
**|                                                                         |**
**| TI makes no representation or warranties with respect to the            |**
**| performance of this computer program, and specifically disclaims        |**
**| any responsibility for any damages, special or consequential,           |**
**| connected with the use of this program.                                 |**
**|                                                                         |**
**+-------------------------------------------------------------------------+**
******************************************************************************/


/** \file     psp_audio.h
 *
 *  \brief    Header file for audio APIs
 *
 *  The file contains defination of audion APIs
 *
 *  (C) Copyright 2006, Texas Instruments, Inc
 *
 *  \authors    PSP Team (please mail your comments/ queries to
 *              psparch-feedback@list.ti.com)
 *
 *  \note       Set tabstop to 4 (:se ts=4) while viewing this file in an
 *              editor
 *  \Revision
 *          0.1  Created  PSP Team
 */

#ifndef __PSP_AUDIO_H_
#define __PSP_AUDIO_H_

#ifdef CHIP_DM648
#include <ti/sdo/pspdrivers/soc/dm648/dsp/tistdtypes.h>
#include <ti/sdo/pspdrivers/pal_sys/dm648/pal_sys_soc.h>
#endif

#ifdef CHIP_C6452
#include <ti/sdo/pspdrivers/soc/c6452/dsp/tistdtypes.h>
#include <ti/sdo/pspdrivers/pal_sys/c6452/pal_sys_soc.h>
#endif

#ifdef __cplusplus
extern "C" {
#endif

#define CLOCK_FREQUENCY_DIVIDE_BY_SIX  (PAL_SYS_CPU_CLOCK_FREQUENCY/6)

typedef enum
{
    /* command to Stop current playback*/
    AUDIO_STOP = 0x100,
    /* Command to start Audio */
    AUDIO_START,
    /* command to Mute On*/
    AUDIO_MUTEON,
    /* command to MUTEOFF*/
    AUDIO_MUTEOFF,
    /* command to Pause*/
    AUDIO_PAUSE,
    /* command to Resume*/
    AUDIO_RESUME,

    /* Loop job enable*/
    AUDIO_MODIFY_LOOPJOB,

    /* command to configure sampling rate of input channel */
    AUDIO_INPUT_SAMPLERATE,
    /* command to configure sampling rate of output channel */
    AUDIO_OUTPUT_SAMPLERATE,

    /* command to select the output Audio mode Line-Out or Speaker-Out */
    AUDIO_OUT_SELECT,
    /* command to select the output Audio mode Line-In or Mic-In */
    AUDIO_IN_SELECT,

    /* Increase of Decrease the input volume */
    AUDIO_IN_GAIN_CONTROL,
    /* Increase of Decrease the output volume */
    AUDIO_OUT_GAIN_CONTROL,

    /* Device reset */
    AUDIO_DEVICE_RESET,
    /* Set the AIC slave address*/
    AUDIO_SET_CODEC

}ConfigCommand;

/**
  * \brief Audio AIC Mode enum
  */
typedef enum
{
    PSP_AUDIO_AIC_SLAVE = 0,
    PSP_AUDIO_AIC_MASTER
} PSP_audioAicMode;

/**
  * \brief Audio Input Mode enum
  */
typedef enum
{
    PSP_AUDIO_MIC_IN = 0,
    /**< MICIN bias powered down */

    PSP_AUDIO_LINE_IN,
    /**< LINE IN */

    PSP_AUDIO_MIC_IN_2_0_V,
    /**< MICIN bias powered to 2.0 V */

    PSP_AUDIO_MIC_IN_2_5_V,
    /**< MICIN bias powered to 2.5 V */

    PSP_AUDIO_MIC_IN_AVDD
    /**< MICIN bias is connected to AVDD */
} PSP_audioInputMode;

/**
  * \brief Audio Output Mode enum
  */
typedef enum
{
    PSP_AUDIO_SPK_OUT = 0,
    PSP_AUDIO_LINE_OUT
} PSP_audioOutputMode;


/**
  * \brief Audio Configuration Structure
  *
  *  This structure holds Configuration of Audio Driver.
  */
typedef struct PSP_audio_cfg_t
{
    PSP_audioAicMode        mode;
    /**< AIC Master or Slave Mode                   */
    Uint32                  inputFreq;
    /**< Input Frequency to McASP or McBSP Module   */
    Uint32                  sampleFreq;
    /**< Output Sampling Rate                       */
    Uint32                  inputGain;
    /**< Input Gain control                         */
    Uint32                  outputGain;
    /**< Output Gain control                        */
    PSP_audioInputMode      inputMode;
    /**< Input Select                               */
    PSP_audioOutputMode     outputMode;
    /**< Output Select                              */
} PSP_audio_cfg;

#ifdef __cplusplus
}
#endif

#endif  /*__PSP_AUDIO_H_*/
