/******************************************************************************
**+-------------------------------------------------------------------------+**
**|                            ****                                         |**
**|                            ****                                         |**
**|                            ******o***                                   |**
**|                      ********_///_****                                  |**
**|                      ***** /_//_/ ****                                  |**
**|                       ** ** (__/ ****                                   |**
**|                           *********                                     |**
**|                            ****                                         |**
**|                            ***                                          |**
**|                                                                         |**
**|         Copyright (c) 1998-2006 Texas Instruments Incorporated          |**
**|                        ALL RIGHTS RESERVED                              |**
**|                                                                         |**
**| Permission is hereby granted to licensees of Texas Instruments          |**
**| Incorporated (TI) products to use this computer program for the sole    |**
**| purpose of implementing a licensee product based on TI products.        |**
**| No other rights to reproduce, use, or disseminate this computer         |**
**| program, whether in part or in whole, are granted.                      |**
**|                                                                         |**
**| TI makes no representation or warranties with respect to the            |**
**| performance of this computer program, and specifically disclaims        |**
**| any responsibility for any damages, special or consequential,           |**
**| connected with the use of this program.                                 |**
**|                                                                         |**
**+-------------------------------------------------------------------------+**
******************************************************************************/

/*
 * \file   psp_audio.c
 *
 * \brief  Audio driver file.
 *
 * This file contains the API used as an interface to the underlying
 * McASP driver.
 *
 *  (C) Copyright 2006, Texas Instruments, Inc
 *
 *  \note       Set tabstop to 4 (:se ts=4) while viewing this file in an
 *              editor
 *
 *  \author
 *
 *  \version    0.1
 *
 */
#include <std.h>
#include <iom.h>
#include <bcache.h>

#include <ti/sdo/pspdrivers/pal_os/pal_osSem.h>
#include <ti/sdo/pspdrivers/common/psp_common.h>
#include <ti/sdo/pspdrivers/pal_os/bios/psputils.h>
#include <ti/sdo/edma3/drv/edma3_drv.h>
#include <ti/sdo/pspdrivers/drivers/mcasp/psp_mcasp.h>
#include <ti/sdo/pspdrivers/pal_os/pal_osWait.h>
#include <ti/sdo/pspdrivers/pal_os/pal_osProtect.h>
#include <ti/sdo/pspdrivers/pal_os/pal_osmem.h>

#ifdef CHIP_DM648
#include <ti/sdo/pspdrivers/system/dm648/bios/evmDM648/audio/psp_audio.h>
#include <ti/sdo/pspdrivers/system/dm648/bios/evmDM648/audio/src/psp_aic33Codec.h>
#include <ti/sdo/pspdrivers/soc/dm648/dsp/soc.h>
#endif

#ifdef CHIP_C6452
#include <ti/sdo/pspdrivers/system/c6452/bios/evm6452/audio/psp_audio.h>
#include <ti/sdo/pspdrivers/system/c6452/bios/evm6452/audio/src/psp_aic33Codec.h>
#include <ti/sdo/pspdrivers/soc/c6452/dsp/soc.h>
#endif


/* PINMUX address */
#define PRD_BUF_SIZE             (512u)
#define PINMUX0                  ((volatile Uint32*)0x02049000u)
#define CACHE_LENGTH             (128u)
#define DEFAULT_BITPERSAMPLE     (16u)
#define MCASPPORT                (0u)
#define NUM_TDM_CHANNELS         (1u)
#define NUM_OF_CHANNELS          (2u)
#define LOOP_JOB_BUF_LENGTH      (0u)
#define CLOCK_ENABLE             (0x00000020u)
#define HI_CLOCK_ENABLE          (0x00008000u)
#define HI_CLOCK_SAMPLERATE_MASK (0x00000FFFu)
#define FRAMESYNC_INTERNAL       (0x00000002u)

#ifdef  ONE_TO_ONE_TEST
#define NUM_OF_RXSERIALISER        (1u)
#define NUM_OF_TXSERIALISER        (1u)
#endif /* ONE_TO_ONE_TEST */

#ifdef  FOUR_TO_ONE_TEST
#define NUM_OF_RXSERIALISER        (4u)
#define NUM_OF_TXSERIALISER        (1u)
#endif /* FOUR_TO_ONE_TEST */

extern PSP_Handle    hEdma;
extern Uint16        aic33SlaveAddr;

static PSP_audio_cfg *audio_cfg1;







/*
 * Forward declaration of the IOM interface functions. They are only
 * exposed via the IOM function table to avoid namespace pollution.
 */
static Int audio_mdBindDev(Ptr *devp, Int devid, Ptr devParams);
static Int audio_mdControlChan(Ptr chanp, Uns cmd, Ptr arg);
static Int audio_mdCreateChan(Ptr *chanp, Ptr devp, String name, Int mode,
                         Ptr chanParams, IOM_TiomCallback cbFxn, Ptr cbArg);

static void mcasp_pinmuxConfig ();
static void mcasp_master_rcv_config();
static void mcasp_master_xmt_config();

extern far IOM_Fxns McASP_IOM_FXNS;
extern far IOM_Fxns I2CMD_FXNS;
extern void MCASP_IOM_init();

static volatile Ptr             mcAspChInHandle = NULL;
static volatile Ptr             mcAspChOutHandle = NULL;


static Int MCASP_Configuration(Ptr chanp, Uint32 inputFreq, Uint32 samplingRate);

/*
Init configuration for mcasp device - DMA mode
*/
static PSP_McaspHwSetup appMcaspHwSetup = {         \
    {
      /* .pfunc    = */ 0x00000000,                 /*mcasp or GPIO pin-will be set by driver from chanparams*/
      /* .pdir     = */ 0x00000001,                 /*Direction of pin -will be set by driver */
      /* .gblctl   = */ 0x00000000,                 /*control clk, hclk, statemachine - reset and release - driver ctrl*/
      /* .ditctl   = */ 0x00000000,                 /*DIT mode seting*/
      /* .dlbctl   = */ 0x00000000,                 /*loop back mode setting*/
      /* .amute    = */ 0x00000000,                 /*Amute setting*/
      /* .srctl0   = */ 0x00000000,                 /* init serialiser*/
      /* .srctl1   = */ 0x00000000                  /* init serialiser*/
     },
      {
          /* .rmask    = */ 0xFFFFFFFF,
          /* .rfmt     = */ 0x00000000,
          /* .afsrctl  = */ 0x00000000,
          /* .rtdm     = */ 0x00000001,
          /* .rintctl  = */ 0x00000000,
          /* .rstat    = */ 0x000001FF,                  /*reset any existing status bits*/
          /* .revtctl  = */ 0x00000000,
          {
             /* .aclkrctl  = */ 0x00000003,             /* \div = 1, clk = internal*/
             /* .ahclkrctl = */ 0x00008046,             /* div = 63, no inversion before divider ,Internal*/
             /* .rclkchk   = */ 0x00000000
          },
     },
     {
          /* .xmask    = */ 0xFFFFFFFF,
          /* .xfmt     = */ 0x00000000,
          /* .afsxctl  = */ 0x00000002,
          /* .xtdm     = */ 0x00000001,
          /* .xintctl  = */ 0x00000000,
          /* .xstat    = */ 0x000001FF,                 /*reset any existing status bits*/
          /* .xevtctl  = */ 0x00000000,
          {
             /* .aclkxctl  = */ 0x00000023,             /* \div = 1, clk = internal*/
             /* .ahclkxctl = */ 0x00008046,             /* div = 46, no inversion before divider ,Internal*/
             /* .xclkchk   = */ 0x00000000
          },
     },
           0x00000001              /*emu free*/
} ;


PSP_McaspHwSetupData mcaspXmtSetup = { \
        /* .xmask    = */ 0xFFFFFFFF,                   /*all the data bits are used*/
        /* .xfmt     = */ 0x000080F0,    /*no right rotation,
                                                         DMA access,
                                                         slot size = 32bits,
                                                         pad with 0th bit from data,(currently this option disabled by next field)
                                                         pad extra bits with 0,
                                                         LSB first,
                                                         0 bit delay from between fsync and data*/
        /* .afsxctl  = */ 0x00000000,    /*burst mode,
                                                        frame sync pulse width - 1 clk bit
                                                        clk is internal
                                                        Rising edge is validated*/

        /* .xtdm     = */ 0x00000003,                   /*n-th (2 here)TDM slot will be accounted - for burst mode no use*/
        /* .xintctl  = */ 0x00000000,                   /*reset any existing status bits*/
        /* .xstat    = */ 0x000001FF,                  /*reset any existing status bits*/
        /* .xevtctl  = */ 0x00000000,                   /*DMA or INT mode*/
        {
             /* .aclkxctl  = */ 0x00000000,            /* \div = 1, clk = External*/
             /* .ahclkxctl = */ 0x0000003F,             /* div = 63, no inversion before divider ,External*/
             /* .xclkchk   = */ 0x00000000
        },

};


PSP_McaspHwSetupData mcaspRcvSetup = { \
        /* .rmask    = */ 0xFFFFFFFF,                   /*all the data bits are used*/
        /* .rfmt     = */ 0x000080F0,    /*no right rotation,
                                                         DMA access,,
                                                         slot size = 16bits,
                                                         pad with 0th bit from data,(currently this option disabled by next field)
                                                         pad extra bits with 0,
                                                         LSB first,
                                                         0 bit delay from between fsync and data*/
        /* .afsrctl  = */ 0x00000000,    /*2slot tdm,
                                                        frame sync pulse width - 1 clk bit
                                                        clk is internal
                                                        Rising edge is validated*/
        /* .rtdm     = */ 0x00000003,                  /*n-th (2 here)TDM slot will be accounted*/
        /* .rintctl  = */ 0x00000000,                   /*This will be filled up by driver internally*/
        /* .rstat    = */ 0x000001FF,                   /*reset any existing status bits*/
        /* .revtctl  = */ 0x00000000,                   /*DMA or INT mode*/
        {
             /* .aclkrctl  = */ 0x00000000,             /* \div = 1, clk = External*/
             /* .ahclkrctl = */ 0x0000003F,             /* div = 63, no inversion before divider ,External*/
             /* .rclkchk   = */ 0x00000000
        }
} ;

/**
 * Device Parameters.
 * This will be passed down during mdBindDev.
 */
PSP_mcaspDevParams appDevParams = {             \
    /** Cache is enabled */
    TRUE,                                       \
    /** Packet Header information not available */
    FALSE,                                      \
   /** McASP HwSetup structure */               \
   &appMcaspHwSetup                             \
} ;

/*
 * The codec driver function table. Notice how we copy most functions
 * from the generic c6x1x edma mcasp driver.
 */
IOM_Fxns AUDIO_AIC33_FXNS = {
    &audio_mdBindDev,                   /* Bind device */
    NULL,                               /* UnBind device */
    &audio_mdControlChan,               /* Control Channel */
    &audio_mdCreateChan,                /* Create Channel */
    NULL,                               /* Delete Channel */
    NULL                                /* Submit Request */
};

/*
 * ======== mdBindDev ========
 * This function allocates and configures the pcm3002 codec.
 */
/* ARGSUSED */
static Int audio_mdBindDev(Ptr *devp, Int devid, Ptr devParams)
{
    Int                     status      = 0;
    PSP_mcaspDevParams     *mcaspParams = NULL;
    static volatile Ptr             mcAspPortHandle = NULL;




    if (NULL == devParams)
    {
        mcaspParams = (PSP_mcaspDevParams*)(&appDevParams);
    }
    else
    {
        mcaspParams = (PSP_mcaspDevParams*)devParams;
    }


    /* Call the generic mdBindDev to claim mcasp port MCASPPORT */
    status = McASP_IOM_FXNS.mdBindDev(devp, devid, mcaspParams);

    mcAspPortHandle = *devp;

    return status;
}

/*
 * ======== mdCreateChan ========
 * This function creates and configures a device channel.
 */
/* ARGSUSED */
static Int audio_mdCreateChan(Ptr *chanp, Ptr devp, String name, Int mode,
                        Ptr chanParams, IOM_TiomCallback cbFxn, Ptr cbArg)
{
    Int                     status = 0;
    PSP_mcaspChanParams     mcaspChanParams = {0};
    Uint32                  *prdBufPtr      = NULL;

    static Int              cfgCodec = 0;

    static PSP_audio_cfg audio_cfg_params =
    {
        PSP_AUDIO_AIC_MASTER,           /* AIC Mode */
        CLOCK_FREQUENCY_DIVIDE_BY_SIX,  /* Input Frequency to  McASP module */
        8000,                           /* Sampling Rate */
        50,                             /* Input Gain */
        99,                             /* Output Gain */
        PSP_AUDIO_LINE_IN,              /* Input select */
        PSP_AUDIO_LINE_OUT              /* Output Select */
    };


    if(NULL == chanParams)
    {
        audio_cfg1 = &audio_cfg_params;
    }
    else
    {
       	audio_cfg1 = (PSP_audio_cfg *)chanParams;
    }

    if ( PSP_AUDIO_AIC_MASTER != audio_cfg1->mode)
    {
        status = PSP_E_INVAL_PARAM;

        if(IOM_INPUT == mode)
		{
			mcAspChInHandle = NULL;
		}
		else
		{
			mcAspChOutHandle = NULL;
		}

    }

    if (NULL == hEdma)
    {
        status = PSP_E_RESOURCES;
    }
    else
    {
        if(0 == status)
        {
            if(0 == cfgCodec)
            {

                /* Configure AIC33 - 1 */
                audio_cfg1->mode = PSP_AUDIO_AIC_SLAVE;
                aic33SlaveAddr =  I2C_AIC33_U5_SLAVE_ADDR;
                status = aic33Codec_config(0, audio_cfg1);

                /* Configure AIC33 - 2 */
                aic33SlaveAddr =  I2C_AIC33_U4_SLAVE_ADDR;
			    status |= aic33Codec_config(0, audio_cfg1);

                /* Configure AIC33 - 4 */
                aic33SlaveAddr =  I2C_AIC33_U6_SLAVE_ADDR;
			    status |= aic33Codec_config(0, audio_cfg1);

                /* Configure AIC33 - 3 as Master*/
                audio_cfg1->mode = PSP_AUDIO_AIC_MASTER;
                aic33SlaveAddr = I2C_AIC33_U3_SLAVE_ADDR;

			    status |= aic33Codec_config(0, audio_cfg1);

		        if(status != 0)
		        {
		    	    cfgCodec = 0;
		        }
		        else
		        {
		    	    cfgCodec = 1;
		        }
            }

            if ((-1) != status)
            {

                prdBufPtr = NULL;

                if(IOM_INPUT == mode)
                {
                    /* configure for the interrupt for overrun */
                    mcaspRcvSetup.intCtl = 0x00000003;

                    if(PSP_AUDIO_AIC_SLAVE == audio_cfg1->mode)
                    {
                        mcasp_master_rcv_config();
                    }
                    mcaspChanParams.isDmaDriven                 = TRUE;
                    mcaspChanParams.mcaspSetup                  = &mcaspRcvSetup;
                    mcaspChanParams.channelMode                 = PSP_MCASP_TDM_MODE;
                    mcaspChanParams.noOfChannels                = NUM_TDM_CHANNELS;

                    mcaspChanParams.wordWidth                   = PSP_MCASP_WORDLEN_32;

                    mcaspChanParams.noOfSerRequested            = NUM_OF_RXSERIALISER;
                    mcaspChanParams.indexOfSersRequested[0]     = SERIALIZER_0;
#ifdef FOUR_TO_ONE_TEST
                    mcaspChanParams.indexOfSersRequested[1]     = SERIALIZER_1;
                    mcaspChanParams.indexOfSersRequested[2]     = SERIALIZER_4;
                    mcaspChanParams.indexOfSersRequested[3]     = SERIALIZER_5;
#endif /* FOUR_TO_ONE_TEST */
                    mcaspChanParams.userLoopJobBuffer           = prdBufPtr;
                    mcaspChanParams.userLoopJobLength           = 0;

                    mcaspChanParams.gblCbk                      = NULL;

                    mcaspChanParams.edmaHandle                  = hEdma;
                }
                else
                {
                    /* configure for the interrupt for underrun */
                    mcaspXmtSetup.intCtl = 0x00000003;

                    if(PSP_AUDIO_AIC_SLAVE == audio_cfg1->mode)
                    {
                        mcasp_master_xmt_config();
                    }
                    mcaspChanParams.isDmaDriven                 = TRUE;
                    mcaspChanParams.mcaspSetup                  = &mcaspXmtSetup;
                    mcaspChanParams.channelMode                 = PSP_MCASP_TDM_MODE;
                    mcaspChanParams.noOfChannels                = NUM_TDM_CHANNELS;

                    mcaspChanParams.wordWidth                   = PSP_MCASP_WORDLEN_32;

                    mcaspChanParams.noOfSerRequested            = NUM_OF_TXSERIALISER;

                    mcaspChanParams.indexOfSersRequested[0]     = SERIALIZER_2;
                    mcaspChanParams.userLoopJobBuffer           = prdBufPtr;
                    mcaspChanParams.userLoopJobLength           = 0;

                    mcaspChanParams.gblCbk                      = NULL;

                    mcaspChanParams.edmaHandle                  = hEdma;
                }

                status = (McASP_IOM_FXNS.mdCreateChan)(chanp,
                                                        devp,
                                                        name,
                                                        mode,
                                                        &mcaspChanParams,
                                                        cbFxn,
                                                        cbArg);

                if(IOM_INPUT == mode)
                {
                    mcAspChInHandle = *chanp;
                }
                else
                {
                    mcAspChOutHandle = *chanp;
                }
            } /* if ((-1) != status */
        }/*if (0 == status)*/
    }
    return (status);
}

static Int audio_mdControlChan(Ptr chanp, Uns cmd, Ptr arg)
{
    Int                     IOMStatus   = IOM_EBADARGS;

    if ((mcAspChInHandle == chanp) || (mcAspChOutHandle == chanp))
    {
        switch (cmd)
        {
            case AUDIO_STOP:
                    IOMStatus = McASP_IOM_FXNS.mdControlChan(
                                                    chanp,
                                                    PSP_MCASP_STOP_PORT,
                                                    NULL
                                                    );
                    break;

            case AUDIO_START:
                    IOMStatus = McASP_IOM_FXNS.mdControlChan(
                                                    chanp,
                                                    PSP_MCASP_START_PORT,
                                                    NULL
                                                    );
                    break;
            /* command to Mute On*/
            case AUDIO_MUTEON:
                    IOMStatus = McASP_IOM_FXNS.mdControlChan(
                                                    chanp,
                                                    PSP_CTRL_McASP_MUTE_ON,
                                                    NULL
                                                    );
                    break;
            /* command to MUTEOFF*/

            case AUDIO_MUTEOFF:
                    IOMStatus = McASP_IOM_FXNS.mdControlChan(
                                                    chanp,
                                                    PSP_CTRL_McASP_MUTE_OFF,
                                                    NULL
                                                    );
                    break;
            /* Loop job enable/disable*/
            case AUDIO_MODIFY_LOOPJOB:
                    IOMStatus = McASP_IOM_FXNS.mdControlChan(
                                            chanp,
                                            PSP_CTRL_McASP_MODIFY_LOOPJOB,
                                            arg
                                            );
                    break;

            case AUDIO_INPUT_SAMPLERATE:

                if (PSP_AUDIO_AIC_MASTER == audio_cfg1->mode)
                {
                    audio_cfg1->sampleFreq =  * (Uint32 *)(arg);
                        IOMStatus = aic33_sampleRateControl( audio_cfg1 );
                }
                else
                {

                    audio_cfg1->sampleFreq =  * (Uint32 *)(arg);
                        IOMStatus = aic33_sampleRateControl( audio_cfg1 );

                    if (IOM_COMPLETED == IOMStatus)
                    {
                        IOMStatus = MCASP_Configuration(
                                        chanp,
                                            audio_cfg1->inputFreq,
                                        ( * (Uint32 *) arg)
                                        );
                    }
                }
                break;

            case AUDIO_OUTPUT_SAMPLERATE:
                /* configure for changing sample rate */
                if (PSP_AUDIO_AIC_MASTER == audio_cfg1->mode)
                {
                    audio_cfg1->sampleFreq =  * (Uint32 *)(arg);
                        IOMStatus = aic33_sampleRateControl( audio_cfg1 );
                }
                else
                {
                    audio_cfg1->sampleFreq =  * (Uint32 *)(arg);
                        IOMStatus = aic33_sampleRateControl( audio_cfg1 );

                    if (IOM_COMPLETED == IOMStatus)
                    {
                        IOMStatus = MCASP_Configuration(
                                        chanp,
                                            audio_cfg1->inputFreq,
                                        ( * (Uint32 *) arg)
                                        );
                    }
                }
                break;

            case AUDIO_PAUSE:
                IOMStatus = McASP_IOM_FXNS.mdControlChan(
                                                chanp,
                                                PSP_MCASP_PAUSE,
                                                arg
                                                );
                break;

            case AUDIO_RESUME:
                IOMStatus = McASP_IOM_FXNS.mdControlChan(
                                                chanp,
                                                PSP_MCASP_RESUME,
                                                arg
                                                );
                break;

            case AUDIO_OUT_SELECT:
                IOMStatus = PSP_E_NOT_SUPPORTED;
                break;

            case AUDIO_IN_SELECT:
                    IOMStatus = aic33Codec_config(0, arg);

                break;

            case AUDIO_IN_GAIN_CONTROL:
                    IOMStatus = aic33_inGainControl(( * (Uint8 *) arg), audio_cfg1);
                break;

            case AUDIO_OUT_GAIN_CONTROL:
                    IOMStatus = aic33_outGainControl(( * (Uint8 *) arg), audio_cfg1);
                break;

            case AUDIO_DEVICE_RESET:
                IOMStatus = McASP_IOM_FXNS.mdControlChan(
                                            chanp,
                                            PSP_MCASP_DEVICE_RESET,
                                            NULL
                                            );
                break;
            case AUDIO_SET_CODEC:
                aic33SlaveAddr = (*(Uint16 *) arg);
                IOMStatus = IOM_COMPLETED;
                break;

            default:
                    IOMStatus = McASP_IOM_FXNS.mdControlChan(chanp, cmd, arg);
                    break;
        }
    }

    return IOMStatus;
}


/*
 * ======== AUDIO_AIC33_init ========
 * This function initializes the driver's structures.
 */
Void AUDIO_AIC33_init1()
{
    /* Pass some IOM fxns straight to the generic driver */
    AUDIO_AIC33_FXNS.mdDeleteChan =
        McASP_IOM_FXNS.mdDeleteChan;
    AUDIO_AIC33_FXNS.mdSubmitChan =
        McASP_IOM_FXNS.mdSubmitChan;
    AUDIO_AIC33_FXNS.mdUnBindDev =
        McASP_IOM_FXNS.mdUnBindDev;

    /* Enable pinmux for McASP instance 0 */
    mcasp_pinmuxConfig();
}


static Int MCASP_Configuration(Ptr chanp, Uint32 inputFreq, Uint32 samplingRate)
{
    PSP_McaspHwSetupData     mcaspConfig = {0};
    Int                      status = 0 ;
    Uint32                   changedSampleRate = 0;

    status  = McASP_IOM_FXNS.mdControlChan(
                                chanp,
                                PSP_MCASP_CNTRL_GET_FORMAT_CHAN,
                                &mcaspConfig
                                );
    changedSampleRate
        = (inputFreq / (samplingRate * DEFAULT_BITPERSAMPLE * NUM_OF_CHANNELS))
          -1;

    mcaspConfig.clk.clkSetupHiClk &= 0xFFFFF000;

    mcaspConfig.clk.clkSetupHiClk |= (changedSampleRate & 0x00000FFF) ;

    status = McASP_IOM_FXNS.mdControlChan(
                                chanp,
                                PSP_MCASP_CNTRL_SET_FORMAT_CHAN,
                                &mcaspConfig
                                );

    return (status);
}

/*
 * ======== mcasp_pinmuxConfig ========
 * This function configures PinMux register for McASP
 */
static void mcasp_pinmuxConfig ()
{
    /* Enable McASP instant */
    *PINMUX0 &= 0xFFFFFEFF;
    *PINMUX0 |= 0x00000200;

    MCASP_IOM_init();
}

/*
 * ======== mcasp_master_rcv_config ========
 * This function configures McASP peripheral receive channel for
 *    1. Slave mode
 *    2. Samplerate
 */
static void mcasp_master_rcv_config()
{
    Uint32 rcvSampleRate = 0;

    rcvSampleRate = (audio_cfg1->inputFreq
        / (audio_cfg1->sampleFreq * DEFAULT_BITPERSAMPLE * NUM_OF_CHANNELS)) -1;

    rcvSampleRate &= HI_CLOCK_SAMPLERATE_MASK;

    /* Receive clock source generated internally */
    mcaspRcvSetup.clk.clkSetupClk   |=  CLOCK_ENABLE;

    /* Clear the hiclock divider bits */
    mcaspRcvSetup.clk.clkSetupHiClk &= (~(HI_CLOCK_SAMPLERATE_MASK));

    /* Receive frame sync is internally generated */
    mcaspRcvSetup.frSyncCtl |= FRAMESYNC_INTERNAL;

    /* Configure the clock divider with a new value */
    mcaspRcvSetup.clk.clkSetupHiClk
        |= (HI_CLOCK_ENABLE | rcvSampleRate);
                                              /* div = changedSampleRate,
                                                 Internal*/
    return;
}

/*
 * ======== mcasp_master_xmt_config ========
 * This function configures McASP peripheral transmit channel for
 *    1. Slave mode
 *    2. Samplerate
 */
static void mcasp_master_xmt_config()
{
    Uint32 xmitSampleRate = 0;

    xmitSampleRate = (audio_cfg1->inputFreq
        / (audio_cfg1->sampleFreq * DEFAULT_BITPERSAMPLE * NUM_OF_CHANNELS)) -1;

    xmitSampleRate &= HI_CLOCK_SAMPLERATE_MASK;

    /* Transmit clock source generated internally */
    mcaspXmtSetup.clk.clkSetupClk |= CLOCK_ENABLE;

    /* Clear the hiclock divider bits */
    mcaspXmtSetup.clk.clkSetupHiClk &= (~(HI_CLOCK_SAMPLERATE_MASK));

    /* Receive frame sync is internally generated */
    mcaspXmtSetup.frSyncCtl |= FRAMESYNC_INTERNAL;

    /* Configure the clock divider with a new value */
    mcaspXmtSetup.clk.clkSetupHiClk
        |= (HI_CLOCK_ENABLE | xmitSampleRate);
                                              /* div = changedSampleRate,
                                                 Internal*/
    return;
}

