/*******************************************************************************
**+--------------------------------------------------------------------------+**
**|                            ****                                          |**
**|                            ****                                          |**
**|                            ******o***                                    |**
**|                      ********_///_****                                   |**
**|                      ***** /_//_/ ****                                   |**
**|                       ** ** (__/ ****                                    |**
**|                           *********                                      |**
**|                            ****                                          |**
**|                            ***                                           |**
**|                                                                          |**
**|         Copyright (c) 1998-2006 Texas Instruments Incorporated           |**
**|                        ALL RIGHTS RESERVED                               |**
**|                                                                          |**
**| Permission is hereby granted to licensees of Texas Instruments           |**
**| Incorporated (TI) products to use this computer program for the sole     |**
**| purpose of implementing a licensee product based on TI products.         |**
**| No other rights to reproduce, use, or disseminate this computer          |**
**| program, whether in part or in whole, are granted.                       |**
**|                                                                          |**
**| TI makes no representation or warranties with respect to the             |**
**| performance of this computer program, and specifically disclaims         |**
**| any responsibility for any damages, special or consequential,            |**
**| connected with the use of this program.                                  |**
**|                                                                          |**
**+--------------------------------------------------------------------------+**
*******************************************************************************/

/** \file   psp_bios_spi_st_sample_main.c
 *
 *  \brief  This file contains the init function for SPI driver implemented for
 *          DSP/BIOS
 *
 *  (C) Copyright 2006, Texas Instruments, Inc
 *
 *  \author     PSP Team
 *  \version    0.1
 */

#include <std.h>
#include <gio.h>
#include <log.h>
#include <tsk.h>
#include <stdio.h>

#ifdef CHIP_DM648
#include <ti/sdo/pspdrivers/pal_sys/dm648/pal_sys.h>
#include <ti/sdo/pspdrivers/pal_sys/dm648/pal_sys_soc.h>
#include <ti/sdo/pspdrivers/soc/dm648/dsp/soc.h>
#endif

#ifdef CHIP_C6452
#include <ti/sdo/pspdrivers/pal_sys/c6452/pal_sys.h>
#include <ti/sdo/pspdrivers/pal_sys/c6452/pal_sys_soc.h>
#include <ti/sdo/pspdrivers/soc/c6452/dsp/soc.h>
#endif


#define PSP_DEBUG_PRINT       printf

extern void start_spi_sample();

extern void spi_initDevParams(void);

static void tskHeartBit();

void pspConsoleOut(Int32 data);

void main()
{
    return;
}

/*
 * SPI init function called when creating the driver.
 */
void SPI_init()
{
    /* Power On SPI */
    if(PAL_sysModuleClkCtrl(PAL_SYS_CLK_MODULE_SPI,PAL_SYS_MODULE_CLK_ENABLE) != PAL_SOK)
    {
        return;
    }

    spi_initDevParams();

}

void echo()
{

    PAL_sysPinmuxEnable(PAL_SYS_PINMUX_SPI);
    /* Run SPI sample application */
    start_spi_sample();

    /* Start the Heart Beat Print */
    tskHeartBit();

    return;
}

void tskHeartBit()
{
    static Uint32 counter = 0;

    while (counter < 0xFFFFFFFF)
    {
        TSK_sleep(1000u);    /* Add large delay */
        PSP_DEBUG_PRINT("\r\n\r\n!!! PSP HrtBt %l", counter);
        counter++;
    }
}

