/*******************************************************************************
**+--------------------------------------------------------------------------+**
**|                            ****                                          |**
**|                            ****                                          |**
**|                            ******o***                                    |**
**|                      ********_///_****                                   |**
**|                      ***** /_//_/ ****                                   |**
**|                       ** ** (__/ ****                                    |**
**|                           *********                                      |**
**|                            ****                                          |**
**|                            ***                                           |**
**|                                                                          |**
**|         Copyright (c) 1998-2006 Texas Instruments Incorporated           |**
**|                        ALL RIGHTS RESERVED                               |**
**|                                                                          |**
**| Permission is hereby granted to licensees of Texas Instruments           |**
**| Incorporated (TI) products to use this computer program for the sole     |**
**| purpose of implementing a licensee product based on TI products.         |**
**| No other rights to reproduce, use, or disseminate this computer          |**
**| program, whether in part or in whole, are granted.                       |**
**|                                                                          |**
**| TI makes no representation or warranties with respect to the             |**
**| performance of this computer program, and specifically disclaims         |**
**| any responsibility for any damages, special or consequential,            |**
**| connected with the use of this program.                                  |**
**|                                                                          |**
**+--------------------------------------------------------------------------+**
*******************************************************************************/

/** \file   psp_drv_pinmux_combo2_bios_main_sample.c
 *
 *  \brief  This file contains the test / demo code to demonstrate the
 *          SPI/VLYNQ driver implemented for DSP/BIOS in C6452 platform
 *
 *  (C) Copyright 2006, Texas Instruments, Inc
 *
 *  \author     PSP Team
 *  \version    0.1
 */

#include <stdio.h>
#include <std.h>
#include <gio.h>
#include <log.h>
#include <tsk.h>
#include <ti/sdo/pspdrivers/pal_sys/c6452/pal_sys.h>
#include <ti/sdo/pspdrivers/pal_sys/c6452/pal_sys_soc.h>

#include <ti/sdo/edma3/drv/edma3_drv.h>


/* Defines to enable and tests for various drivers*/

#define PSP_EDMA_TEST
#define PSP_SPI_TEST
#define PSP_VLYNQ_TEST


#define PSP_DEBUG_PRINT       printf



/* PINMUX address */
#define PINMUX0         ((volatile Uint32*)0x02049000u)

/*
 * External references
 */
extern void start_spi_sample(void);
extern void spi_initDevParams(void);
extern EDMA3_DRV_Handle hEdma;
extern EDMA3_DRV_Result edma3init();
extern EDMA3_DRV_Result edma3MemToMemCpytest ();
extern void start_vlynq_test();

extern far LOG_Obj trace;

/*
 * Local references
 */
static void tskHeartBit(void);

/*
 * OS application entry point (main). This is called before OS task
 * switching enabled.
 */

void main()
{
   return;
}


/*
 * SPI init function called when creating the driver.
 */
void SPI_init()
{
   /* Power On TSIP module */
    if(PAL_sysModuleClkCtrl(PAL_SYS_CLK_MODULE_SPI,PAL_SYS_MODULE_CLK_ENABLE) != PAL_SOK)
    {
        return;
    }


   /* Initialize spi device hardware setup params structure */
    spi_initDevParams();
}



/*
 * Sample BIOS task
 */
void echo()
{
    EDMA3_DRV_Result    edmaResult;

#ifdef PSP_SPI_TEST
    PAL_sysPinmuxEnable(PAL_SYS_PINMUX_SPI); /* Enable SPI for C6452*/
    start_spi_sample();
#endif

#ifdef PSP_EDMA_TEST
    /* Initialize EDMA first */
    PSP_DEBUG_PRINT("\r\nInitialize EDMA first...\r\n");

    edmaResult = edma3init();
    if (EDMA3_DRV_SOK != edmaResult)
    {
        /* Report EDMA Error */
        PSP_DEBUG_PRINT("\r\nEDMA Initialization failed\r\n");
    }
    else
    {
        PSP_DEBUG_PRINT("\r\nEDMA Initialization passed\r\n");
    }
#endif


#ifdef PSP_VLYNQ_TEST
   /* Power On VLYNQ module */
    if(PAL_sysModuleClkCtrl(PAL_SYS_CLK_MODULE_VLYNQ,PAL_SYS_MODULE_CLK_ENABLE) != PAL_SOK)
    {
        return;
    }

    PAL_sysPinmuxEnable(PAL_SYS_PINMUX_VLYNQ); /* Enable VLYNQ for C6452 DVR mode*/
	start_vlynq_test();
#endif


    /* Start the Heart Beat Print */
    tskHeartBit();

    return;
}

void tskHeartBit()
{
    static Uint32 counter = 0;

    while (counter < 0xFFFFFFFF)
    {
        TSK_sleep(3000u);    /* Add large delay */
        PSP_DEBUG_PRINT("PSP Hearbeat[%d]\r\n",counter);
        counter++;
    }
}



