/*******************************************************************************
**+--------------------------------------------------------------------------+**
**|                            ****                                          |**
**|                            ****                                          |**
**|                            ******o***                                    |**
**|                      ********_///_****                                   |**
**|                      ***** /_//_/ ****                                   |**
**|                       ** ** (__/ ****                                    |**
**|                           *********                                      |**
**|                            ****                                          |**
**|                            ***                                           |**
**|                                                                          |**
**|         Copyright (c) 1998-2006 Texas Instruments Incorporated           |**
**|                        ALL RIGHTS RESERVED                               |**
**|                                                                          |**
**| Permission is hereby granted to licensees of Texas Instruments           |**
**| Incorporated (TI) products to use this computer program for the sole     |**
**| purpose of implementing a licensee product based on TI products.         |**
**| No other rights to reproduce, use, or disseminate this computer          |**
**| program, whether in part or in whole, are granted.                       |**
**|                                                                          |**
**| TI makes no representation or warranties with respect to the             |**
**| performance of this computer program, and specifically disclaims         |**
**| any responsibility for any damages, special or consequential,            |**
**| connected with the use of this program.                                  |**
**|                                                                          |**
**+--------------------------------------------------------------------------+**
*******************************************************************************/
/** \file   psp_bios_vlynq_master_sample.c
 *
 *   \brief  Sample application for Master mode VLYNQ
 *
 *  This is the sample application of vlynq which contains various
 *  test cases to test vlynq driver.
 *
 * (C) Copyright 2006, Texas Instruments, Inc
 *
 *  \author     Rinkal Shah
 *   \version    0.1
 */
/*
 * Include Files
 */
#include <std.h>
#include <c64.h>
#include <log.h>
#include <trc.h>

#include <ti/sdo/pspdrivers/pal_sys/vlynq/pal_sysvlynqDev.h>
#include <ti/sdo/pspdrivers/pal_os/bios/psputils.h>

#ifdef CHIP_DM648
#include <ti/sdo/pspdrivers/pal_sys/dm648/pal_sys.h>
#include <ti/sdo/pspdrivers/soc/dm648/dsp/soc.h>
#endif

#ifdef CHIP_C6452
#include <ti/sdo/pspdrivers/pal_sys/c6452/pal_sys.h>
#include <ti/sdo/pspdrivers/soc/c6452/dsp/soc.h>
#endif
/* externs */
extern LOG_Obj trace;

/*
 * Defines and Macros and globals
 */

/* Base address of VLYNQ Control Registers on soc */
#define VLYNQ_CONTROL_BASE   (CSL_VLYNQ_0_REGS)

/* Test Application States */
#define VLYNQ_APP_ERROR             -1u
#define VLYNQ_APP_SUCCESS            PAL_VLYNQ_OK
#define dataCount (39u)

/*
 * Typedefs and Stuctures
 */

/* memory mapping of LOCAL & PEER vlynq Regions  */
typedef struct
{
    Int32   id;
    Uint32  offset;
    Uint32  size;
    Uint8 remote;

} REGION_CONFIG_T;

/* LOCAL VLYNQ Configuration */

#define LOCAL_VLYNQ_TXADR_MAP          (0x38000100u) /* VLYNQ space */
#define LOCAL_VLYNQ_REMOTE_ADR         (0x84000000u) /* DDR */

#define LOCAL_ADDRESS_MAP_OFFSET_1     (LOCAL_VLYNQ_REMOTE_ADR + (0x0u)    )
#define LOCAL_ADDRESS_MAP_OFFSET_2     (LOCAL_VLYNQ_REMOTE_ADR + (0xFFCu)  )
#define LOCAL_ADDRESS_MAP_OFFSET_3     (LOCAL_VLYNQ_REMOTE_ADR + (0x131Cu) )
#define LOCAL_ADDRESS_MAP_OFFSET_4     (LOCAL_VLYNQ_REMOTE_ADR + (0x163Cu) )

#define LOCAL_VLYNQ_RXADRSIZE1         (0x00000FFCu)   /* Rx-1 Size = 4kb */
#define LOCAL_VLYNQ_RXADRSIZE2         (0x00000320u)   /* Rx-2 Size = 800b */
#define LOCAL_VLYNQ_RXADRSIZE3         (0x00000320u)   /* Rx-3 Size = 800b */
#define LOCAL_VLYNQ_RXADRSIZE4         (0x0000FFFFu)   /* Rx-4 Size = 64kb */



/* PEER VLYNQ Configuration */

#define REMOTE_VLYNQ_TXADR_MAP         (0x4C000000u) /* VLYNQ space */
#define PEER_VLYNQ_REMOTE_ADR          (0x84000000u) /* DDR*/

#define PEER_ADDRESS_MAP_OFFSET_1      (PEER_VLYNQ_REMOTE_ADR + (0x0u)    )
#define PEER_ADDRESS_MAP_OFFSET_2      (PEER_VLYNQ_REMOTE_ADR + (0xFFCu)  )
#define PEER_ADDRESS_MAP_OFFSET_3      (PEER_VLYNQ_REMOTE_ADR + (0x131Cu) )
#define PEER_ADDRESS_MAP_OFFSET_4      (PEER_VLYNQ_REMOTE_ADR + (0x163Cu) )

#define PEER_VLYNQ_RXADRSIZE1          (0x00000FFCu)  /* Rx-1 Size = 4kb */
#define PEER_VLYNQ_RXADRSIZE2          (0x00000320u)  /* Rx-2 Size = 800b */
#define PEER_VLYNQ_RXADRSIZE3          (0x00000320u)  /* Rx-3 Size = 800b */
#define PEER_VLYNQ_RXADRSIZE4          (0x0000FFFFu)  /* Rx-4 Size = 64kb */


/* Set these values to the RX registers to map regions */
static REGION_CONFIG_T region_config[] = {
{ 0, LOCAL_ADDRESS_MAP_OFFSET_1, LOCAL_VLYNQ_RXADRSIZE1, 0},
{ 1, LOCAL_ADDRESS_MAP_OFFSET_2, LOCAL_VLYNQ_RXADRSIZE2, 0},
{ 2, LOCAL_ADDRESS_MAP_OFFSET_3, LOCAL_VLYNQ_RXADRSIZE3, 0},
{ 3, LOCAL_ADDRESS_MAP_OFFSET_4, LOCAL_VLYNQ_RXADRSIZE4, 0},
{ 0, PEER_ADDRESS_MAP_OFFSET_1,  PEER_VLYNQ_RXADRSIZE1,  1},
{ 1, PEER_ADDRESS_MAP_OFFSET_2,  PEER_VLYNQ_RXADRSIZE2,  1},
{ 2, PEER_ADDRESS_MAP_OFFSET_3,  PEER_VLYNQ_RXADRSIZE3,  1},
{ 3, PEER_ADDRESS_MAP_OFFSET_4,  PEER_VLYNQ_RXADRSIZE4,  1},
{ -1, 0, 0, 0}
};


/* VLYNQ Configuration sturcture objects  */

PAL_VLYNQ_CONFIG_T          vlynq_config ;
static PAL_VLYNQ_DEV_HND   *ptr_vlynq_dev = NULL;
PAL_VLYNQ_HND              *ptr_vlynq     = NULL;
volatile int                delayCount    = 0;

/************************
 * Function declarations
 ************************/
extern void vlynq_delay_wait();
static PAL_Result EVM_vlynq_init(void);
PAL_Result vlynq_initialization();
PAL_Result vlynq_read_test();
PAL_Result vlynq_write_test();

/* Input and Output Buffers: for loop back */
Uint32 TxBuf[dataCount];
Uint32 RxBuf[dataCount];
Uint32 ReTxBuf[dataCount];

/*! \fn start_vlynq_test
 *  \brief Function will invoke all the VLYNQ read/write tests.
 *
 *  This function will be called by the main sample applicatoin to to start
 *  vlynq tests.
 *
 *  \param None
 */
void start_vlynq_test()
{

    Uint16   byteCount;
        Int32      error;

    /* Fill buffer to be transmitted with known values */
    for(byteCount=0; byteCount<dataCount; byteCount++)
    {
        TxBuf[byteCount] = (Uint32)(byteCount+(1u));
    }

    /* Fill buffer to be transmitted with known values */
    for(byteCount=0; byteCount<dataCount; byteCount++)
    {
        RxBuf[byteCount] = 0x12345678u;
    }

    /* Start VLYNQ intialization */
    error = vlynq_initialization();
    if (error != VLYNQ_APP_SUCCESS)
    {
        return;
    }

    /* checking status of LINK again before sending data */
    if(False == PAL_sysVlynqGetLinkStatus(ptr_vlynq))
    {
        LOG_printf(&trace, "VLYNQ MASTER:ERROR: Link is down between LOCAL & PEER.\n\r");
        return;
    }
    LOG_printf(&trace, "VLYNQ MASTER:SUCCESS: Link is established between LOCAL & PEER.\n\r");

    /* WRITE */
    LOG_printf(&trace, "VLYNQ MASTER : transmitting data\n\r");
    error = vlynq_write_test();
    if (VLYNQ_APP_SUCCESS != error)
    {
         LOG_printf(&trace, "VLYNQ MASTER :Error in trasmitting data.");
         return;
    }
    LOG_printf(&trace, "VLYNQ MASTER :Data transmit passed.\n\r");

    /* READ */
    LOG_printf(&trace, "VLYNQ MASTER : receiving data\n\r");
    error = vlynq_read_test();
    if (VLYNQ_APP_SUCCESS != error)
    {
         LOG_printf(&trace, "VLYNQ MASTER :Error in receiving data.");
         return;
    }
    LOG_printf(&trace, "VLYNQ MASTER :Data receive test passed.\n\r");
}



/*! \fn vlynq_initialization
 *  \brief Function does VLYNQ initialization.
 *
 *  This function will initialize VLYNQ for testing
 *
 *  \param None
 */
PAL_Result vlynq_initialization()
{
    Int32      error;

    /*Initialize the VLYNQ control module*/
    error = PAL_sysVlynqInit();
    if(VLYNQ_APP_SUCCESS == error)
    {
        LOG_printf(&trace, "VLYNQ MASTER:Success in Initializing vlynq configuration \n\r");
    }
    else
    {
       LOG_printf(&trace, "VLYNQ MASTER:Error  in Initializing vlynq configuration \n\r");
       return VLYNQ_APP_ERROR ;
    }

    /* Configure the LOCAL & PEER vlynq devices, maintain vlynq device chain And after
       setting up the memory map of regions create a link between them. so after
       successful execution of this function, a LINK established between LOCAL &
       PEER vlynq. */
    error = EVM_vlynq_init( );
    if(VLYNQ_APP_SUCCESS == error)
    {
        LOG_printf(&trace, "VLYNQ MASTER:Success in LOCAL & PEER vlynq Configuration.\n\r");
    }
    else
    {
       LOG_printf(&trace, "VLYNQ MASTER:Error in LOCAL & PEER vlynq Configuration.\n\r");
       return VLYNQ_APP_ERROR;
    }

    return VLYNQ_APP_SUCCESS;
}


/*! \fn EVM_vlynq_init
 *  \brief Function creates link between LOCAL and PEER VLYNQ.
 *
 *  This function will perform VLYNQ initialization and creates a link between
 *  LOCAL & PEER VLYNQ.
 *
 *  \return VLYNQ_APP_SUCCESS if success and VLYNQ_APP_ERROR if failure
 */
static PAL_Result EVM_vlynq_init(void)
{
    char dev_name[] = "DM648";
    Int32 instance    = 1;
    PAL_Result retCode = VLYNQ_APP_SUCCESS;
    REGION_CONFIG_T *init_p_region = &region_config[0];

    if(NULL == init_p_region)
    {
        retCode = VLYNQ_APP_ERROR;
    }


    if (VLYNQ_APP_SUCCESS == retCode)
    {
        /* Setup LOCAL & REMOTE vlynq configruation */
        LOG_printf(&trace, "VLYNQ MASTER:Setting up the VLYNQ configuration\n\r");

        vlynq_config.on_soc    = TRUE;
        vlynq_config.base_addr = VLYNQ_CONTROL_BASE;

        vlynq_config.local_clock_dir    = pal_vlynq_clk_out;
        vlynq_config.local_clock_div    = 0x7;

        vlynq_config.local_intr_local   = 0x1;
        vlynq_config.local_intr_vector  = 31;
        vlynq_config.local_intr_enable  = 0;
        vlynq_config.local_int2cfg      = 1;
        vlynq_config.local_intr_pointer = (0x14u); /* Ignored in case int2cfg is set */
#ifdef INCLUDE_ENDIAN_REGISTER
        vlynq_config.local_endianness   = pal_vlynq_little_en;
#endif
        vlynq_config.local_tx_addr      = (0x0u);
        vlynq_config.init_swap_flag     = 0;

        vlynq_config.peer_clock_div     = (0x7u);
        vlynq_config.peer_clock_dir     = pal_vlynq_clk_in;

        vlynq_config.peer_intr_local    = 0x0;
        vlynq_config.peer_intr_vector   = 30;
        vlynq_config.peer_intr_enable   = 0;
        vlynq_config.peer_int2cfg       = 0;
        vlynq_config.peer_intr_pointer  = (0x14u); /* Valid in case int2cfg is reset */
#ifdef INCLUDE_ENDIAN_REGISTER
        vlynq_config.peer_endianness    = pal_vlynq_little_en;
#endif
        vlynq_config.peer_tx_addr       = 0;

        vlynq_config.local_rtm_cfg_type = no_rtm_cfg;
        vlynq_config.peer_rtm_cfg_type = no_rtm_cfg;
        vlynq_config.local_tx_fast_path = FALSE;
        vlynq_config.peer_tx_fast_path = FALSE;

        /*  Initialize the VLYNQ control module */
        ptr_vlynq = PAL_sysVlynqInitSoc(&vlynq_config);

        if(NULL == ptr_vlynq)
        {
            LOG_printf(&trace, "VLYNQ MASTER:Failed to initialize the vlynq 0x%08x\n\r",
                         vlynq_config.base_addr);
            LOG_printf(&trace, "VLYNQ MASTER:The error msg: %s\n\r", vlynq_config.error_msg);
            goto av_vlynq_init_fail;
        }

        /* Create a VLYNQ device in the chain of VLYNQ devices */
        ptr_vlynq_dev = (PAL_VLYNQ_DEV_HND *)PAL_sysVlynqDevCreate(ptr_vlynq, dev_name, instance, 0, 0u);

        if(NULL == ptr_vlynq_dev)
        {
            LOG_printf(&trace, "VLYNQ MASTER:Failed to create the %s%d reference for vlynq\n\r",
                         dev_name, instance);
            goto av_vlynq_dev_fail;
        }

        /* Add This device in the chain of VLYNQ devices */
        if(VLYNQ_APP_SUCCESS != PAL_sysVlynqAddDevice(ptr_vlynq, ptr_vlynq_dev, 0u))
        {
            LOG_printf(&trace, "VLYNQ MASTER:Failed to add %s%d reference into vlynq\n\r",
                         dev_name, instance);
            goto av_vlynq_add_device_fail;
        }

        /*  Map the memory regions of the device for remote/local VLYNQ depending on the
            region ID to be mapped and the size and offset. */
        while(init_p_region->id > -1)
        {
            if(VLYNQ_APP_SUCCESS != PAL_sysVlynqMapRegion(ptr_vlynq, init_p_region->remote, init_p_region->id,
                                init_p_region->offset, init_p_region->size,
                                ptr_vlynq_dev))
            {
                init_p_region->id = -1;
                LOG_printf(&trace, "VLYNQ MASTER:Failed to map regions for %s%d in vlynq\n\r",
                             dev_name, instance);
                goto av_vlynq_map_region_fail;
            }

            init_p_region++;
        }


        return VLYNQ_APP_SUCCESS;

    av_vlynq_map_region_fail:

        LOG_printf(&trace, "VLYNQ MASTER:Un mapping the VLYNQ regions\n\r");

        /*  UnMap the memory regions of the device for remote/local VLYNQ depending on the
            region ID to be mapped and the size and offset. */

        init_p_region = &region_config[0];
        while(init_p_region->id > -1)
        {
            PAL_sysVlynqUnMapRegion(ptr_vlynq, init_p_region->remote, init_p_region->id,
                     ptr_vlynq_dev);

            init_p_region++;
        }

        /* Remove this VLYNQ device from the chain of VLYNQ devices */
        PAL_sysVlynqRemoveDevice(ptr_vlynq, ptr_vlynq_dev);
        return (VLYNQ_APP_ERROR);

    av_vlynq_add_device_fail:

        LOG_printf(&trace, "VLYNQ MASTER:Destroying the VLYNQ device\n\r");

        /* Destroy this VLYNQ device */
        PAL_sysVlynqDevDestroy(ptr_vlynq_dev);
        return(VLYNQ_APP_ERROR);

    av_vlynq_dev_fail:

        LOG_printf(&trace, "VLYNQ MASTER:Cleaning up\n\r");

        /* CleanUp this VLYNQ device configuration */
        if(VLYNQ_APP_SUCCESS != PAL_sysVlynqCleanUp(ptr_vlynq)){
            LOG_printf(&trace, "VLYNQ MASTER:It is not a Clean shut down\n\r");
            }
        return (VLYNQ_APP_ERROR);

    av_vlynq_init_fail:

        return (VLYNQ_APP_ERROR);
    }
    return retCode;
}



/*! \fn vlynq_write_test
 *  \brief Function performs write operation on VLYNQ.
 *
 *  Data transmission from LOCAL VLYNQ to PEER VLYNQ.
 *
 *  \return VLYNQ_APP_SUCCESS if success and VLYNQ_APP_ERROR if failure
 */
PAL_Result vlynq_write_test()
{

   Uint16   byteCount;
   volatile Uint32   *writePtr, *RPtr;

   writePtr = (Uint32*)LOCAL_VLYNQ_TXADR_MAP;

   /* writing data to VLYNQ Remote Memory Map on OMAP soc */
   for(byteCount=0; byteCount<dataCount; byteCount++)
   {
       writePtr[byteCount] = TxBuf[byteCount];
   }

   /* delay loop to wait untill transmission completes */
   for(delayCount=0; delayCount<500; delayCount++)
   {
   }

   /* verify the data written (read-back and compare)*/
   RPtr = (Uint32*)LOCAL_VLYNQ_TXADR_MAP;
   if(NULL != RPtr)
   {
        for(byteCount=0; byteCount<dataCount; byteCount++)
        {
                if(TxBuf[byteCount] != RPtr[byteCount])
                {
                    return VLYNQ_APP_ERROR;
                }
         }
   }

   return VLYNQ_APP_SUCCESS;
}



/*! \fn vlynq_read_test
 *  \brief Function performs read operation on VLYNQ.
 *
 *  VLYNQ Read operation.
 *
 *  \return VLYNQ_APP_SUCCESS if success and VLYNQ_APP_ERROR if failure
 */
PAL_Result vlynq_read_test()
{
    /* Reading data from VLYNQ Remote Memory Map on OMAP soc */
    volatile Uint32 *RxBufPtr;
    RxBufPtr = (Uint32*) LOCAL_VLYNQ_TXADR_MAP ;

    while(RxBufPtr[dataCount - 1] != dataCount)
    {
    }
    return VLYNQ_APP_SUCCESS;
}
