/*******************************************************************************
**+--------------------------------------------------------------------------+**
**|                            ****                                          |**
**|                            ****                                          |**
**|                            ******o***                                    |**
**|                      ********_///_****                                   |**
**|                      ***** /_//_/ ****                                   |**
**|                       ** ** (__/ ****                                    |**
**|                           *********                                      |**
**|                            ****                                          |**
**|                            ***                                           |**
**|                                                                          |**
**|         Copyright (c) 1998-2006 Texas Instruments Incorporated           |**
**|                        ALL RIGHTS RESERVED                               |**
**|                                                                          |**
**| Permission is hereby granted to licensees of Texas Instruments           |**
**| Incorporated (TI) products to use this computer program for the sole     |**
**| purpose of implementing a licensee product based on TI products.         |**
**| No other rights to reproduce, use, or disseminate this computer          |**
**| program, whether in part or in whole, are granted.                       |**
**|                                                                          |**
**| TI makes no representation or warranties with respect to the             |**
**| performance of this computer program, and specifically disclaims         |**
**| any responsibility for any damages, special or consequential,            |**
**| connected with the use of this program.                                  |**
**|                                                                          |**
**+--------------------------------------------------------------------------+**
*******************************************************************************/
/** \file   psp_bios_vlynq_master_sample_dlb.c
 *
 *   \brief  Sample application for Master mode VLYNQ for Loopback mode only
 *
 *  This is the sample application of vlynq which contains
 *  test case to test vlynq driver in loop back mode.
 *
 * (C) Copyright 2006, Texas Instruments, Inc
 *
 *  \author      Anuj Aggarwal
 *   \version    0.1
 */
/*
 * Include Files
 */
#include <std.h>
#include <hwi.h>
#include <c64.h>
#include <log.h>

#ifdef CHIP_DM648
#include <ti/sdo/pspdrivers/pal_sys/dm648/pal_sys.h>
#include <ti/sdo/pspdrivers/soc/dm648/dsp/soc.h>
#endif

#ifdef CHIP_C6452
#include <ti/sdo/pspdrivers/pal_sys/c6452/pal_sys.h>
#include <ti/sdo/pspdrivers/soc/c6452/dsp/soc.h>
#endif

#include <ti/sdo/pspdrivers/pal_sys/vlynq/pal_sysvlynqDev.h>
#include <ti/sdo/pspdrivers/pal_os/bios/psputils.h>

/*
 * Defines and Macros and globals
 */

/* VLYNQ Interrupt */
#define HWI_INT_NUM             8

#ifdef CHIP_DM648
#define VLYNQ_EVENT_ID          50
#endif


/* Base address of VLYNQ Control Registers on soc */
#define VLYNQ_CONTROL_BASE   (CSL_VLYNQ_0_REGS)


/* Test Application States */
#define VLYNQ_APP_ERROR             -1u
#define VLYNQ_APP_SUCCESS            PAL_VLYNQ_OK
#define dataCount (39u)

#ifdef CHIP_DM648
#define LOCAL_VLYNQ_TXADR_MAP          (0x38000100u) /* VLYNQ space */
#define REMOTE_VLYNQ_TXADR_MAP         (0x38000100u) /* VLYNQ space */
#endif


/* VLYNQ Configuration sturcture objects  */

PAL_VLYNQ_CONFIG_T          vlynq_config;
static PAL_VLYNQ_DEV_HND   *ptr_vlynq_dev = NULL;
PAL_VLYNQ_HND              *ptr_vlynq     = NULL;
volatile int                delayCount    = 0;

/************************
 * Function declarations
 ************************/
extern void vlynq_delay_wait();
static PAL_Result vlynqIntrInit(void);
static PAL_Result EVM_vlynq_init(void);
PAL_Result vlynq_initialization();
PAL_Result vlynq_write_test();

/* Input and Output Buffers: for loop back */
Uint32 TxBuf[dataCount];
Uint32 RxBuf[dataCount];



/*! \fn start_vlynq_test
 *  \brief Function will invoke all the VLYNQ read/write tests.
 *
 *  This function will be called by the main sample applicatoin to to start
 *  vlynq tests.
 *
 *  \param None
 */
void start_vlynq_test()
{
    Uint16   byteCount;
    Int32      error;

    /* Fill buffer to be transmitted with known values */
    for(byteCount=0; byteCount<dataCount; byteCount++)
    {
        TxBuf[byteCount] = (Uint32)(byteCount+(1u));
    }

    /* Fill buffer to be transmitted with known values */
    for(byteCount=0; byteCount<dataCount; byteCount++)
    {
        RxBuf[byteCount] = 0x12345678u;
    }

    /* Start VLYNQ intialization */
    error = vlynq_initialization();
    if (error != VLYNQ_APP_SUCCESS)
    {
        return;
    }

    /* checking status of LINK again before sending data */
    if(False == PAL_sysVlynqGetLinkStatus(ptr_vlynq))
    {
        LOG_printf(&trace, "VLYNQ  :ERROR: Link is down between LOCAL & PEER.\n\r");
        return;
    }
    LOG_printf(&trace, "VLYNQ  :SUCCESS: Link is established between LOCAL & PEER.\n\r");

    LOG_printf(&trace, "VLYNQ  :VLYNQ Master data receive passed\n\r");

    /* WRITE */
    LOG_printf(&trace, "VLYNQ  :Master is now transmitting data\n\r");

    error = vlynq_write_test();
    if (VLYNQ_APP_SUCCESS != error)
    {
        LOG_printf(&trace, "VLYNQ  :Error in trasmitting data in Master.");
        return;
    }

    LOG_printf(&trace, "VLYNQ  :Master Data transmit passed.\n\r");
}



/*! \fn vlynq_initialization
 *  \brief Function does VLYNQ initialization.
 *
 *  This function will initialize VLYNQ for testing
 *
 *  \param None
 */
PAL_Result vlynq_initialization()
{
    Int32      error;

    /* Assign ISR to vlynq HWI */
    error =     vlynqIntrInit();
    if(VLYNQ_APP_SUCCESS == error)
    {
        LOG_printf(&trace, "VLYNQ  :Success in assigning ISR to vlynq HWI \n\r");
    }
    else
    {
        LOG_printf(&trace, "VLYNQ  :Error in assigning ISR to vlynq HWI \n\r");
        return VLYNQ_APP_ERROR ;
    }

    /*Initialize the VLYNQ control module*/
    error = PAL_sysVlynqInit();
    if(VLYNQ_APP_SUCCESS == error)
    {
        LOG_printf(&trace, "VLYNQ  :Success in Initializing vlynq configuration \n\r");
    }
    else
    {
        LOG_printf(&trace, "VLYNQ  :Error  in Initializing vlynq configuration \n\r");
        return VLYNQ_APP_ERROR ;
    }

    /* Configure the LOCAL & PEER vlynq devices, maintain vlynq device chain And after
       setting up the memory map of regions create a link between them. so after
       successful execution of this function, a LINK established between LOCAL &
       PEER vlynq. */
    error = EVM_vlynq_init( );
    if(VLYNQ_APP_SUCCESS == error)
    {
        LOG_printf(&trace, "VLYNQ  :Success in LOCAL & PEER vlynq Configuration.\n\r");
    }
    else
    {
        LOG_printf(&trace, "VLYNQ  :Error in LOCAL & PEER vlynq Configuration.\n\r");
        return VLYNQ_APP_ERROR;
    }

    return VLYNQ_APP_SUCCESS;
}



/*! \fn vlynqIntrInit
 *  \brief Function does VLYNQ interrupt initialization.
 *
 *  This function will initialize VLYNQ interrupts for testing
 *
 *  \param None
 */
static PAL_Result vlynqIntrInit(void)
{
     PAL_Result status = 0;
     Int32 vecid3 = HWI_INT_NUM;
     Uint32 cookie = 0;
     HWI_Attrs vlynq_attr;
     vlynq_attr.intrMask = 1u;
     vlynq_attr.ccMask = 1u;
     vlynq_attr.arg = (Arg)ptr_vlynq;

    /* Disabling the interrupts */
    cookie = HWI_disable();

    /* Mapping the eventid to the HWI_ID of the DSP/BIOS*/
    HWI_eventMap(vecid3, VLYNQ_EVENT_ID);

    /* Assigning the function to the HWI_ID */
    /*Attach only the root VLYNQ module to the HWI*/
    HWI_dispatchPlug(vecid3,(Fxn)&PAL_sysVlynqRootIsr, -1, &vlynq_attr);

    /* Enabling the HWI_ID */
    C64_enableIER(1 << HWI_INT_NUM);

    /* Enabling the interrupts */
    HWI_restore(cookie);
    return status;
}



/*! \fn EVM_vlynq_init
 *  \brief Function creates link between LOCAL and PEER VLYNQ.
 *
 *  This function will perform VLYNQ initialization and creates a link between
 *  LOCAL & PEER VLYNQ.
 *
 *  \return VLYNQ_APP_SUCCESS if success and VLYNQ_APP_ERROR if failure
 */
static PAL_Result EVM_vlynq_init(void)
{
    char dev_name[] = "DM648";
    Int32 instance    = 1;
    PAL_Result initretval = VLYNQ_APP_SUCCESS;

    if (VLYNQ_APP_SUCCESS == initretval)
    {
        /* Setup LOCAL & REMOTE vlynq configruation */
        LOG_printf(&trace, "VLYNQ  :Setting up the VLYNQ configuration\n\r");

        vlynq_config.on_soc    = TRUE;
        vlynq_config.base_addr = VLYNQ_CONTROL_BASE;

        vlynq_config.local_clock_dir    = pal_vlynq_clk_out;
        vlynq_config.local_clock_div    = 0x3;

        vlynq_config.local_intr_local   = 0x1;
        vlynq_config.local_intr_vector  = 31;
        vlynq_config.local_intr_enable  = 0;
        vlynq_config.local_int2cfg      = 1;
        vlynq_config.local_intr_pointer = (0x14u); /* Ignored in case int2cfg is set */
#ifdef INCLUDE_ENDIAN_REGISTER
        vlynq_config.local_endianness   = pal_vlynq_little_en;
#endif
        vlynq_config.local_tx_addr      = (0x0u);
        vlynq_config.init_swap_flag     = 0;

        vlynq_config.peer_clock_div     = (0x3u);
        vlynq_config.peer_clock_dir     = pal_vlynq_clk_out;

        vlynq_config.peer_intr_local    = 0x0;
        vlynq_config.peer_intr_vector   = 30;
        vlynq_config.peer_intr_enable   = 0;
        vlynq_config.peer_int2cfg       = 0;
        vlynq_config.peer_intr_pointer  = (0x14u); /* Valid in case int2cfg is reset */
#ifdef INCLUDE_ENDIAN_REGISTER
        vlynq_config.peer_endianness    = pal_vlynq_little_en;
#endif
        vlynq_config.peer_tx_addr       = REMOTE_VLYNQ_TXADR_MAP;

        vlynq_config.local_rtm_cfg_type = no_rtm_cfg;
        vlynq_config.peer_rtm_cfg_type = no_rtm_cfg;
        vlynq_config.local_tx_fast_path = FALSE;
        vlynq_config.peer_tx_fast_path = FALSE;
        /*  Initialize the VLYNQ control module */
        ptr_vlynq = PAL_sysVlynqInitSoc(&vlynq_config);

        if(NULL == ptr_vlynq)
        {
            LOG_printf(&trace, "VLYNQ  :Failed to initialize the vlynq 0x%08x\n\r",
                         vlynq_config.base_addr);
            LOG_printf(&trace, "VLYNQ  :The error msg: %s\n\r", vlynq_config.error_msg);
            goto av_vlynq_init_fail;
        }

        /* Create a VLYNQ device in the chain of VLYNQ devices */
        ptr_vlynq_dev = (PAL_VLYNQ_DEV_HND *)PAL_sysVlynqDevCreate(ptr_vlynq, dev_name, instance, 0, 1u);

        if(NULL == ptr_vlynq_dev)
        {
            LOG_printf(&trace, "VLYNQ  :Failed to create the %s%d reference for vlynq\n\r",
                         dev_name, instance);
            goto av_vlynq_dev_fail;
        }

        /* Add This device in the chain of VLYNQ devices */
        if(VLYNQ_APP_SUCCESS != PAL_sysVlynqAddDevice(ptr_vlynq, ptr_vlynq_dev, 1u))
        {
            LOG_printf(&trace, "VLYNQ  :Failed to add %s%d reference into vlynq\n\r",
                         dev_name, instance);
            goto av_vlynq_add_device_fail;
        }

        if(VLYNQ_APP_SUCCESS != PAL_sysVlynqMapRegion(ptr_vlynq, 0, 0,
                            (unsigned int)(RxBuf), 0x100u,
                            ptr_vlynq_dev))
        {
            LOG_printf(&trace, "VLYNQ  :Failed to map regions for %s%d in vlynq\n\r",
                         dev_name, instance);
            goto av_vlynq_map_region_fail;
        }

        return VLYNQ_APP_SUCCESS;

    av_vlynq_map_region_fail:

        LOG_printf(&trace, "VLYNQ  :Un mapping the VLYNQ regions\n\r");

        PAL_sysVlynqUnMapRegion(ptr_vlynq, 0, 0, ptr_vlynq_dev);

        /* Remove this VLYNQ device from the chain of VLYNQ devices */
        PAL_sysVlynqRemoveDevice(ptr_vlynq, ptr_vlynq_dev);
        return (VLYNQ_APP_ERROR);

    av_vlynq_add_device_fail:

        LOG_printf(&trace, "VLYNQ  :Destroying the VLYNQ device\n\r");

        /* Destroy this VLYNQ device */
        PAL_sysVlynqDevDestroy(ptr_vlynq_dev);
        return(VLYNQ_APP_ERROR);

    av_vlynq_dev_fail:

        LOG_printf(&trace, "VLYNQ  :Cleaning up\n\r");

        /* CleanUp this VLYNQ device configuration */
        if(VLYNQ_APP_SUCCESS != PAL_sysVlynqCleanUp(ptr_vlynq)){
            LOG_printf(&trace, "VLYNQ  :It is not a Clean shut down\n\r");
            }
        return (VLYNQ_APP_ERROR);

    av_vlynq_init_fail:

        return (VLYNQ_APP_ERROR);
    }
    return initretval;
}



/*! \fn vlynq_write_test
 *  \brief Function performs write operation on VLYNQ.
 *
 *  Data transmission from LOCAL VLYNQ to PEER VLYNQ.
 *
 *  \return VLYNQ_APP_SUCCESS if success and VLYNQ_APP_ERROR if failure
 */
PAL_Result vlynq_write_test()
{

   Uint16   byteCount;
   volatile Uint32   *writePtr, *RPtr;

   writePtr = (Uint32*)LOCAL_VLYNQ_TXADR_MAP;

   /* writing data to VLYNQ Remote Memory Map */
   for(byteCount=0; byteCount<dataCount; byteCount++)
   {
       writePtr[byteCount] = TxBuf[byteCount];
   }

   /* delay loop to wait untill transmission completes */
   for(delayCount=0; delayCount<500; delayCount++)
   {
   }

   /* verify the data written (read-back and compare)*/
    RPtr = (Uint32*)RxBuf;

   if(NULL != RPtr)
   {
        for(byteCount=0; byteCount<dataCount; byteCount++)
        {
                if(TxBuf[byteCount] != RPtr[byteCount])
                {
                    return VLYNQ_APP_ERROR;
                }
         }
   }

   return VLYNQ_APP_SUCCESS;
}
