#include <std.h>
#include <log.h>
#include <sys.h>
#include <mem.h>
#include <sio.h>
#include <tsk.h>

#include <stdio.h>

#ifdef CHIP_DM6437
#include <ti/sdo/pspdrivers/system/dm6437/bios/evmDM6437/audio/psp_audio.h>
#endif

#ifdef CHIP_C6424
#include <ti/sdo/pspdrivers/system/c6424/bios/evm6424/audio/psp_audio.h>
#endif

extern far LOG_Obj trace;
extern Int edma3init();

/*
 * Buffers placed in external memory are aligned on a 128 bytes boundary.
 * In addition, the buffer should be of a size multiple of 128 bytes for
 * the cache work optimally on the C6x.
 */
#define BUFLEN                  1600         /* number of samples in the frame */
#define BUFALIGN                128          /* alignment of buffer to allow use of L2 cache */

#define BUFSIZE                 (BUFLEN * sizeof(MdUns))

#define NUM_BUFS                4            /*Number of Buffers to be issued and reclaimed*/
/* inStream and outStream are SIO handles created in main */
static SIO_Handle inStream, outStream;

/* Function prototype */
static Void createStreams();
static Void prime();


/*
 * ======== createStreams ========
 */
static Void createStreams()
{
    SIO_Attrs attrs;

    /* align the buffer to allow it to be used with L2 cache */
    attrs       = SIO_ATTRS;
    attrs.nbufs = NUM_BUFS;
    attrs.align = BUFALIGN;
    attrs.model = SIO_ISSUERECLAIM;

    /* open the I/O streams */
    outStream = SIO_create("/dioCodec", SIO_OUTPUT, BUFSIZE, &attrs);
    if (outStream == NULL) {
        SYS_abort("Create output stream FAILED.");
    }
    inStream = SIO_create("/dioCodec", SIO_INPUT, BUFSIZE, &attrs);
    if (inStream == NULL) {
        SYS_abort("Create input stream FAILED.");
    }
}

/*
 * ======== prime ========
 */
static Void prime()
{
    Ptr buf[NUM_BUFS * 2];
    int count = 0;

    /* Allocate buffers for the SIO buffer exchanges */
    for(count = 0; count < (NUM_BUFS * 2); count ++)
    {
        buf[count] = (Ptr)MEM_calloc(0, BUFSIZE, BUFALIGN);
        if(NULL == buf[count]) {
            SYS_abort("MEM_calloc failed.");
        }
    }

    for(count = 0; count < NUM_BUFS; count ++)
    {
        /* Issue the first & second empty buffers to the input stream */
        if (SIO_issue(inStream, buf[count], SIO_bufsize(inStream), NULL) != SYS_OK) {
            SYS_abort("Error issuing buffer to the input stream");
        }
    }

    for(count = NUM_BUFS; count < (NUM_BUFS * 2); count ++)
    {
        if (SIO_issue(outStream, buf[count], SIO_bufsize(outStream), NULL) != SYS_OK) {
            SYS_abort("Error issuing buffer to the output stream");
        }
    }
}

/*
 * ======== echo ========
 * This function copies from the input SIO to the output SIO. You could
 * easily replace the copy function with a signal processing algorithm.
 */
Void Audio_echo_Task()
{
    volatile int i;
    Int nmadus;         /* number of minimal addressable units */
    MdUns *rcv, *xmt;

    edma3init();

    /* Call createStream function to create I/O streams */
    createStreams();

    /* Call prime function to do priming */
    prime();

    /* Loop forever looping back buffers */
    for (;;) {

        /* Reclaim full buffer from the input stream */
        if ((nmadus = SIO_reclaim(inStream,(Ptr *)&rcv, NULL)) < 0) {
            SYS_abort("Error reclaiming full buffer from the input stream");
        }

        /* Reclaim empty buffer from the output stream to be reused */
        if (SIO_reclaim(outStream, (Ptr *)&xmt, NULL) < 0) {
            SYS_abort("Error reclaiming empty buffer from the output stream");
        }

        for (i = 0 ; i < (nmadus / sizeof(short)); i++)
        {
            xmt[i] = rcv[i];
        }

        /* Issue full buffer to the output stream */
        if (SIO_issue(outStream, xmt, nmadus, NULL) != SYS_OK) {
            SYS_abort("Error issuing full buffer to the output stream");
        }

        /* Issue an empty buffer to the input stream */
        if (SIO_issue(inStream, rcv, SIO_bufsize(inStream), NULL) != SYS_OK) {
            SYS_abort("Error issuing empty buffer to the input stream");
        }
    }
}


/*
 *  ======== prd10secs ========
 *  prd10secs is configured to be called every 10 seconds
 */
Void prd10secs()
{
    static Int seconds = 0;
    static Int minutes = 0;
    static Int hours = 0;

    seconds += 10;

    if (seconds == 60) {
        seconds = 0;
        minutes++;
        if (minutes == 60) {
            minutes = 0;
            hours++;
        }
        LOG_printf(&trace, "%d hours and %d minutes", hours, minutes);
    }
    else {
        LOG_printf(&trace, "%d seconds", seconds);
    }
}

