/******************************************************************************
**+-------------------------------------------------------------------------+**
**|                            ****                                         |**
**|                            ****                                         |**
**|                            ******o***                                   |**
**|                      ********_///_****                                  |**
**|                      ***** /_//_/ ****                                  |**
**|                       ** ** (__/ ****                                   |**
**|                           *********                                     |**
**|                            ****                                         |**
**|                            ***                                          |**
**|                                                                         |**
**|         Copyright (c) 1998-2006 Texas Instruments Incorporated          |**
**|                        ALL RIGHTS RESERVED                              |**
**|                                                                         |**
**| Permission is hereby granted to licensees of Texas Instruments          |**
**| Incorporated (TI) products to use this computer program for the sole    |**
**| purpose of implementing a licensee product based on TI products.        |**
**| No other rights to reproduce, use, or disseminate this computer         |**
**| program, whether in part or in whole, are granted.                      |**
**|                                                                         |**
**| TI makes no representation or warranties with respect to the            |**
**| performance of this computer program, and specifically disclaims        |**
**| any responsibility for any damages, special or consequential,           |**
**| connected with the use of this program.                                 |**
**|                                                                         |**
**+-------------------------------------------------------------------------+**
******************************************************************************/

/*
 * \file   psp_bios_mcbsp_sample
 *
 * \brief McBSP SPI sample application
 *
 * This file contains the API used as an interface to the underlying
 * McBSP driver.
 *
 *  (C) Copyright 2006, Texas Instruments, Inc
 *
 *  \author
 *
 *  \version    0.1
 *
 */
#include <stdio.h>
#include <std.h>
#include <gio.h>
#include <iom.h>
#include <tsk.h>
#include <ti/sdo/pspdrivers/drivers/mcbsp/psp_mcbsp.h>
#include <ti/sdo/pspdrivers/pal_os/pal_osmem.h>
#include <ti/sdo/pspdrivers/pal_os/bios/psputils.h>
#include <bcache.h>
#include <ti/sdo/pspdrivers/pal_os/pal_oswait.h>

#ifdef CHIP_DM6437
#include <ti/sdo/pspdrivers/system/dm6437/bios/evmDM6437/audio/src/psp_aic33Codec.h>
#include <ti/sdo/pspdrivers/soc/dm6437/dsp/soc.h>
#include <ti/sdo/pspdrivers/soc/dm6437/dsp/cslr_sys.h>
#endif


void start_mcbsp_sample();

#ifdef PSP_MCBSPINSPI_ASYNC_MODE_SUPPORT
    void McbspInSpiCallback();
	volatile Uint8 OperationCompletionFlag = 0 ;
#endif


extern PSP_Handle hEdma;
PSP_mcbspHwCfgRaw    mcbspRawHwCfg = {
                            /**< Serial Port Control Register */
                       0x00001000u,    /** enable clock stop without delay   */
                           /**< Receive Control Register */
                       0x00000000u,    /** Have a zero bit delay (SPI mode), */
                           /**< Transmit Control Register */
                       0x00000000u,    /** Have a zero bit delay (SPI mode), */
                           /**< Sample Rate Generator Register */
                       0x20080101u,    /** set clkdiv to 1,
                                                set internal clock,
                                                set 8 frame width            */
                           /**< Pin Control Register */
                       0x0000000Au     /** set transmit frame polarity     */
                            };

PSP_mcbspDevParams mcbsp_deviceparams = {
                          /**< Caching enabled                    */
                        TRUE,
                          /**< Internal clock is to be generated  */
                        TRUE,
                          /**< Framesync is to be generated       */
                        TRUE,
                         /**< Pointer to configuration parameters
                          **  to be used for the McBSP 			  */
/*                        PSP_McBSP_McBSP_SPISLAVE,				  */
                        PSP_McBSP_McBSP_SPIMASTER,                
                          /**< mork as SPI master mode */
/*                        PSP_OPMODE_DMAINTERRUPT, */
                       PSP_OPMODE_INTERRUPT,   				  
/*                        NULL,   */
						300000,
						/**< o/p Clk freq..Valid in Mcbsp SPI Master mode */
/*						NULL,*/
						99000000,
						/**< Module Clock Frequency..Valid in Mcbsp SPI Master mode   */        
                        &mcbspRawHwCfg,

                        };  /* Device parameters structure */

#define TEST_BUFFER_LENGTH      2000u
#define LOOP_LENGTH             100

#pragma DATA_ALIGN(rBuffer, 32);
Uint8               rBuffer[TEST_BUFFER_LENGTH]        = {0};
#pragma DATA_ALIGN(wBuffer, 32);
Uint8               wBuffer[TEST_BUFFER_LENGTH]        = {0};





Uint32 callbackCounter = 0;
void mcbspCallback();

void start_mcbsp_sample()
{

    Int                 devStatus;
    GIO_Attrs           gioAttrs            = GIO_ATTRS;
    PSP_mcbspChanParams     chanparams      = {0};
    GIO_Handle          mcbspHandle         = NULL;
    PSP_mcbspTransParam ioBuffer            = {0};
    size_t              bufLen              = TEST_BUFFER_LENGTH;
    Int                 i                   = 0;
    Int                 j                   = 0;
#ifdef PSP_MCBSPINSPI_ASYNC_MODE_SUPPORT
   GIO_AppCallback McBSPInSPICallBack;
#endif



    /* Create the channel */
    chanparams.userLoopJobBuffer    = NULL;
    chanparams.userLoopJobLength    = 0;
    chanparams.edmaHandle           = hEdma;
    chanparams.noOfTdmChans         = 1;
    chanparams.wordWidth            = PSP_MCBSP_WORDLEN_8;
    chanparams.intrNum              = 48u;



    /* create SPI channel for transmission */
    mcbspHandle =  GIO_create("/McBSP0",IOM_OUTPUT,NULL,&chanparams,&gioAttrs);

    if (NULL != mcbspHandle)
    {
        while (j < LOOP_LENGTH)
        {
            ioBuffer.transAddr      = (Uint8*)&wBuffer[0];
            ioBuffer.receiveAddr    = (Uint8*)&rBuffer[0];

            i = 0;
            while(i < TEST_BUFFER_LENGTH)
            {
                wBuffer[i] = i;
                rBuffer[i] = 0;
                i++;
            }


#ifdef PSP_MCBSPINSPI_ASYNC_MODE_SUPPORT

           /* Call the GIO_SUBMIT with the call back ..i.e async mode */

            McBSPInSPICallBack.fxn = McbspInSpiCallback;
            McBSPInSPICallBack.arg = NULL;
            devStatus = GIO_submit(mcbspHandle,IOM_WRITE,&ioBuffer,&bufLen,&McBSPInSPICallBack);
			while(OperationCompletionFlag == 0)
			    ;
			OperationCompletionFlag = 0;
#else

        /* Call the GIO_SUBMIT with NULL in the call back argument .
            .i.e sync mode */
            devStatus = GIO_submit(mcbspHandle,IOM_WRITE,&ioBuffer,&bufLen,NULL);
#endif

            if(devStatus < 0)
            {
                printf("\r\nBIOS McBSP0:Error in SPI sample Test \n");
            }

            for(i = 0; i < TEST_BUFFER_LENGTH; i++)
            {
                if (wBuffer[i] != rBuffer[i])
                {
                     break;
                }
            }
            if (i != TEST_BUFFER_LENGTH)
            {
                 printf("\r\n BIOS McBSP0:SPI data comparision failed");
                 break;
            }
            else
            {
                 printf("\r\nBIOS McBSP0:SPI data comparision Passed %d",(j));
            }

            j++;
        }

        if( j != LOOP_LENGTH )
            printf("\r\nBIOS McBSP0:SPI TRansceive operation Failed ...!!!\r\n ");
        else
            printf("\r\nBIOS McBSP0:SPI TRansceive operation finished %d times" 
                                                    "successfully\r\n ",(j));

    }
    else
    {
        printf("\r\n McBSP0 Driver Handle creation Failed ");
    }

    return;
}

#ifdef PSP_MCBSPINSPI_ASYNC_MODE_SUPPORT
/*! \fn McbspInSpiCallback
 *  \brief Call Back function Used in async mode.
 *
 *
 *  \param None
 */

void McbspInSpiCallback()
{


	OperationCompletionFlag = 1;
    return;

}
#endif

