/*******************************************************************************
**+--------------------------------------------------------------------------+**
**|                            ****                                          |**
**|                            ****                                          |**
**|                            ******o***                                    |**
**|                      ********_///_****                                   |**
**|                      ***** /_//_/ ****                                   |**
**|                       ** ** (__/ ****                                    |**
**|                           *********                                      |**
**|                            ****                                          |**
**|                            ***                                           |**
**|                                                                          |**
**|         Copyright (c) 1998-2006 Texas Instruments Incorporated           |**
**|                        ALL RIGHTS RESERVED                               |**
**|                                                                          |**
**| Permission is hereby granted to licensees of Texas Instruments           |**
**| Incorporated (TI) products to use this computer program for the sole     |**
**| purpose of implementing a licensee product based on TI products.         |**
**| No other rights to reproduce, use, or disseminate this computer          |**
**| program, whether in part or in whole, are granted.                       |**
**|                                                                          |**
**| TI makes no representation or warranties with respect to the             |**
**| performance of this computer program, and specifically disclaims         |**
**| any responsibility for any damages, special or consequential,            |**
**| connected with the use of this program.                                  |**
**|                                                                          |**
**+--------------------------------------------------------------------------+**
*******************************************************************************/

/** \file   psp_bios_nand_st_sample_main.c
 *
 *  \brief  This file contains the test / demo code to demonstrate the
 *          NAND driver implemented for DSP/BIOS
 *
 *  (C) Copyright 2006, Texas Instruments, Inc
 *
 *  \author     PSP Team
 *  \version    0.1
 */

#include <std.h>
#include <gio.h>

#include <ti/sdo/pspdrivers/pal_os/bios/psputils.h>
#include <ti/sdo/edma3/drv/edma3_drv.h>

#ifdef CHIP_DM6437
#include <ti/sdo/pspdrivers/soc/dm6437/dsp/soc.h>
#include <ti/sdo/pspdrivers/soc/dm6437/dsp/cslr_sys.h>
#endif

#ifdef CHIP_C6424
#include <ti/sdo/pspdrivers/soc/c6424/dsp/soc.h>
#include <ti/sdo/pspdrivers/soc/c6424/dsp/cslr_sys.h>
#endif

/* External Declaration */
extern EDMA3_DRV_Handle hEdma;
extern EDMA3_DRV_Result edma3init();
extern void nandTestCode(void);
extern void initNand(Uint32 nandClkFreq);

#define NANDCLKFREQUENCY        (27000000u)

static CSL_SysRegsOvly sysModuleRegs = (CSL_SysRegsOvly )CSL_SYS_0_REGS;

/* NAND Usage Instructions:
1. Place jumper of JP2 to NAND Chip Select
2. NAND driver has a dependency on EDMA3 driver & sample */

void main()
{
    PSP_DEBUG("\nTII PSP NAND Sample Main\n");
    return;
}

void echo()
{
    EDMA3_DRV_Result    edmaResult;

    /* Initialize EDMA
    */

    if (NULL == hEdma)
    {
        edmaResult = edma3init();
        if (edmaResult != EDMA3_DRV_SOK)
        {
            /* Report EDMA Error */
            PSP_DEBUG("\r\nEDMA3 : edma3init() failed\r\n");
        }
        else
        {
            PSP_DEBUG("\r\nEDMA3 : edma3init() passed\r\n");
        }
    }

    PSP_DEBUG("\r\nNAND  :NAND testing started \n");

    /* Set PINMUX to use NAND */
    /*
     * AEM   =  001 : PINMUX0 - bit-  2:0
     * AEAW  =  010 : PINMUX0 - bit-  18:16
     * PCIEN =  0   : PINMUX1 - bit - 0
     */
    sysModuleRegs -> PINMUX0    &= (0xFFFAFFF9u);
    sysModuleRegs -> PINMUX0     |= (0x00020001u);
    sysModuleRegs -> PINMUX1     &= (0xFFFFFFFEu);

    /* Init Nand driver */
    initNand(NANDCLKFREQUENCY);

    /* Start nand test */
    nandTestCode();

    PSP_DEBUG("\r\nNAND  :NAND testing completed \r\n\n");

    return;
}
