/*******************************************************************************
**+--------------------------------------------------------------------------+**
**|                            ****                                          |**
**|                            ****                                          |**
**|                            ******o***                                    |**
**|                      ********_///_****                                   |**
**|                      ***** /_//_/ ****                                   |**
**|                       ** ** (__/ ****                                    |**
**|                           *********                                      |**
**|                            ****                                          |**
**|                            ***                                           |**
**|                                                                          |**
**|         Copyright (c) 2006-2010 Texas Instruments Incorporated           |**
**|                        ALL RIGHTS RESERVED                               |**
**|                                                                          |**
**| Permission is hereby granted to licensees of Texas Instruments           |**
**| Incorporated (TI) products to use this computer program for the sole     |**
**| purpose of implementing a licensee product based on TI products.         |**
**| No other rights to reproduce, use, or disseminate this computer          |**
**| program, whether in part or in whole, are granted.                       |**
**|                                                                          |**
**| TI makes no representation or warranties with respect to the             |**
**| performance of this computer program, and specifically disclaims         |**
**| any responsibility for any damages, special or consequential,            |**
**| connected with the use of this program.                                  |**
**|                                                                          |**
**+--------------------------------------------------------------------------+**
*******************************************************************************/

/**
 *  \file   psp_bios_aew_st_sample.c
 *
 *  \brief  Sample application to test AEW functionality
 *
 *  This file contains the Implementation details of AEW test application
 *
 *  (C) Copyright 2010, Texas Instruments, Inc
 *
 *  \author     PSP Team
 *
 *  \version    0.1             Created
 *              1.0             First Release
 */

/*******************************************************************************
  Header File Inclusion
*******************************************************************************/
#include <std.h>
#include <stdio.h>
#include <gio.h>
#include <tsk.h>
#include <mem.h>
#include <string.h>
#include <clk.h>
#include <ti/sdo/pspdrivers/soc/dm6437/dsp/tistdtypes.h>
#include <ti/sdo/pspdrivers/pal_sys/dm6437/pal_sys.h>
#include <ti/sdo/pspdrivers/soc/dm6437/dsp/cslr_sys.h>
#include <ti/sdo/pspdrivers/soc/dm6437/dsp/soc.h>

#include <ti/sdo/pspdrivers/drivers/vpfe/psp_vpfe.h>
#include <ti/sdo/pspdrivers/soc/dm6437/dsp/csl_types.h>
#include <ti/sdo/pspdrivers/system/dm6437/bios/evmDM6437/video/fvid.h>
#include <ti/sdo/pspdrivers/system/dm6437/bios/evmDM6437/video/fvid_evmDM6437.h>
#include <ti/sdo/pspdrivers/common/psp_common.h>
#include <ti/sdo/pspdrivers/system/dm6437/bios/evmDM6437/video/src/MT9001_extImageSensor.h>
#include <ti/sdo/pspdrivers/drivers/h3a/psp_h3a.h>
#include <ti/sdo/pspdrivers/drivers/h3a/psp_aew.h>
#include <ti/sdo/pspdrivers/pal_os/bios/psputils.h>
#include <ti/sdo/pspdrivers/pal_os/pal_oscache.h>

#ifdef PSP_VIDEO_PATH_ENABLE
/*******************************************************************************
  Macros
*******************************************************************************/
#define X_RES_CCDC          (1920u)
#define Y_RES_CCDC          (1080u)
#define BPP_CCDC            (16u)
#define CCDC_FB_SIZE        (X_RES_CCDC * Y_RES_CCDC * (BPP_CCDC/8u))
#define DRIVERFILE          "/H3A0"
#define NO_OF_BUFFERS       (3u)
#define WIN_VT_COUNT        (8u)
#define WIN_HZ_COUNT        (8u)
#define H3A_AEW_BUFFER_SIZE (WIN_VT_COUNT * WIN_HZ_COUNT * PSP_AEW_WIN_SIZE)
#endif /* PSP_VIDEO_PATH_ENABLE */
#define AEW_APP_PRINT       PSP_DEBUG
#define AEW_APP_PRINT_VAL   PSP_DEBUG2

#ifdef PSP_VIDEO_PATH_ENABLE
/* array for H3A AEW buffer */
/* make arrayh3AAEW 128 bytes aligned */
#pragma DATA_ALIGN(arrayh3AAEW, 128);
#endif /* PSP_VIDEO_PATH_ENABLE */

/******************************************************************************
  Global variables
******************************************************************************/
#ifdef PSP_VIDEO_PATH_ENABLE
PSP_H3ABuffer enbuffer;
PSP_H3ABuffer debuffer;
PSP_H3AChannelType type = PSP_H3A_AEW;
Uint8 arrayh3AAEW[H3A_AEW_BUFFER_SIZE];

/* for proper cache operation, buffer size needs to be 128 bytes aligned */
Uint8 padAEWBytes[128 - ((H3A_AEW_BUFFER_SIZE & 0xEF) % 128)];
extern Int DDR2;
static FVID_Frame               *allocatedFrameBuffers[NO_OF_BUFFERS];
static GIO_Handle                    CcdcHandle;
static CSL_SysRegsOvly sysModuleRegs = (CSL_SysRegsOvly )CSL_SYS_0_REGS;
FVID_Frame                      *FBAddr          = NULL;

static PSP_VPFECcdcConfigParams ccdcParams =
{
    FVID_CCDC_RAW_FORMAT,               /* inpmod       */
    FVID_FIELD_MODE,                    /* ffMode       */
    Y_RES_CCDC + 1,                     /* height       */
    X_RES_CCDC,                         /* width        */
    (X_RES_CCDC *BPP_CCDC/(8u)),        /* pitch        */
    0,                                  /* horzStartPix */
    0,                                  /* vertStartPix */
    NULL,                               /* appCallback  */
    {
        MT9001_Open,                    /* extVD Fxn    */
        MT9001_Close,
        MT9001_Control,
    },
    0,                                  /* segId        */
    {
        PSP_VPFE_BITS10,                /* dataSize     */
        PSP_VPFE_PACK8_16BITS_PIXEL,    /* pack8        */
        PSP_VPFE_DataPol_Normal,        /* dataPol      */
        PSP_VPFE_SyncPol_Positive,      /* VDSyncPol    */
        PSP_VPFE_SyncPol_Positive,      /* HDSyncPol    */
        PSP_VPFE_SyncDir_Input,         /* HDVDMaster   */
        50,                             /* HDSyncWidth  */
        4,                              /* VDSyncWidth  */
        800,                            /* numPxlPerLine*/
        1000,                           /* numLinPerFld */
        PSP_VPFE_ALaw_Disable,          /* ALawEnable   */
        PSP_VPFE_ALaw_bits15_6,         /* ALaw_Width   */
    }
};

static PSP_AEWParams params =
{
    PSP_AEW_ALAW_DISABLE,   /* A Law Status     */
    120u,                   /* Saturation limit */
    {
        16u,                /* width    */
        16u,                /* height   */
        4u,                 /* horizontal start */
        4u,                 /* vertical start   */
        WIN_HZ_COUNT,       /* horizontal count */
        WIN_VT_COUNT,       /* vertical count   */
        4u,                 /* horizontal line increament   */
        4u,                 /* vertical line increament     */
    },
    {
        16u,                /* black window height          */
        4u,                 /* black window vertical start  */
    }
};

static MT9001_StandardFormat stdFormat;
#endif /* PSP_VIDEO_PATH_ENABLE */

/******************************************************************************
  Functions
******************************************************************************/
#ifdef PSP_VIDEO_PATH_ENABLE
/**
 * \brief   AEW_DumpToFile
 *          This function is used to dump statistics to
 *          the file
 *
 */
static void AEW_DumpToFile(void);
/**
 * \brief   I2C_INIT
 *          This function is used to Initialize the I2C Bus Driver
 *
 */
#endif /* PSP_VIDEO_PATH_ENABLE */
void I2C_INIT()
{
    /*Power On I2C*/
    if (PAL_SOK !=
        PAL_sysModuleClkCtrl(PAL_SYS_CLK_MODULE_I2C, PAL_SYS_MODULE_CLK_ENABLE))
    {
        return;
    }
}

#ifdef PSP_VIDEO_PATH_ENABLE
/**
  * \brief ccdcConfig
  * Configure CCDC and Create Device Entry for VPFE Driver
  */
static int ccdcConfig()
{
    Int resultCCDC = 0;
    GIO_Attrs gioAttrs                       = GIO_ATTRS;
    FVID_Frame *  ptrSP           = NULL;
    PSP_VPFEChannelParams                   feinitParams;
    Uint32 i = 0;
    Ptr                      ptrFB           = NULL;
    for(i = 0; i < NO_OF_BUFFERS; i++)
    {
        ptrSP = MEM_alloc(DDR2, sizeof(FVID_Frame) , 32u);
        if (NULL!=ptrSP)
        {
            ptrFB = MEM_alloc(DDR2, CCDC_FB_SIZE , 32u);
            if (NULL!=ptrFB)
            {
                ptrSP->pitch            =  (X_RES_CCDC *(BPP_CCDC/8u));
                ptrSP->lines            =  Y_RES_CCDC;
                ptrSP->bpp                  =  FVID_BPP_BITS16;
                ptrSP->frame.frameBufferPtr   =  ptrFB;
            }
        }
        allocatedFrameBuffers[i]    = ptrSP;
    }

    /* Create CCDC Channel */
    feinitParams.id         = PSP_VPFE_CCDC;
    feinitParams.params     = (PSP_VPFECcdcConfigParams*)&ccdcParams;
    CcdcHandle
        = FVID_create("/VPFE0", IOM_INOUT, NULL, &feinitParams, &gioAttrs);
    if (NULL == CcdcHandle)
    {
        AEW_APP_PRINT("VPSS  :CCDC Create.......FAILED \r\n");
        resultCCDC = -1;
    }
    else
    {
        stdFormat = MT9T001_MODE_1080p_18FPS;
        if (IOM_COMPLETED != FVID_control(CcdcHandle,
                VPFE_ExtVD_BASE+PSP_VPSS_EXT_VIDEO_DECODER_STD_FORMAT,
                &stdFormat))
        {
            AEW_APP_PRINT("VPSS  :MT9001.......FAILED \r\n");
            resultCCDC = -1;
        }
    }
    return resultCCDC;
}

/**
  * \brief startAEW
  * Main Function to run the sample application of AEW Driver
  * This Function enables the AF engine and collects Statistics generated
  * by AEW Engine
  */
static void startAEW(void)
{
    GIO_Handle aewHandle;
    GIO_Attrs gioAttrs = GIO_ATTRS;
    Int resultTestAEW, gioStatus;
    FVID_Frame *FBAddr = NULL;
    Uint32 bufferSize;

    /* open a logical channel */
    aewHandle = GIO_create(DRIVERFILE, IOM_INOUT, &gioStatus, &type, &gioAttrs);
    if ((NULL == aewHandle) || (IOM_COMPLETED != gioStatus))
    {
        AEW_APP_PRINT("\nAEW device open failed\n");
    }
    else
    {
        /* Call the IOCTL Set Parameters */
        resultTestAEW = GIO_control(aewHandle, PSP_H3A_IOCTL_SET_PARAM,
                                        &params);
        if (resultTestAEW < 0)
        {
            AEW_APP_PRINT("\nAEW IOCTL set params failed\n");
        }
        else
        {
            /* Enqueue the buffer, This will enable AEW engine */
            enbuffer.size = H3A_AEW_BUFFER_SIZE;
            enbuffer.ramIpAddr = (Ptr)(arrayh3AAEW);
            bufferSize = sizeof(PSP_H3ABuffer);
            if ( NULL != enbuffer.ramIpAddr )
            {
                resultTestAEW = GIO_submit(aewHandle, PSP_VPSS_QUEUE, &enbuffer,
                                            &bufferSize, NULL);
                if (resultTestAEW < 0)
                {
                    AEW_APP_PRINT("\nAEW enqueue failed\n");
                }
                else
                {
                    /* Enable ccdc engine */
                    if (NULL != CcdcHandle)
                    {
                        FBAddr   =  allocatedFrameBuffers[0];
                        if (NULL != FBAddr)
                        {
                            if (IOM_COMPLETED != FVID_queue(CcdcHandle, FBAddr))
                            {
                                AEW_APP_PRINT(
                                      "VPSS  :CCDC Queuing.......FAILED \r\n");
                            }
                        }
                    }

                    /* Dequeue the buffer */
                    resultTestAEW = GIO_submit(aewHandle, PSP_VPSS_DEQUEUE,
                                                &debuffer, &bufferSize, NULL);
                    if ( resultTestAEW < 0 )
                    {
                        AEW_APP_PRINT("\nAEW dequeue failed\n");
                    }
                    else
                    {
                        if (debuffer.buffStatus != PSP_H3A_BUFFER_DATA_VALID)
                        {
                            AEW_APP_PRINT(
                                  "\nData corrupted: Write Buffer Overflow\n");
                        }
                        /* Invalidate the cache */
                        PAL_osCacheInvalidate((PAL_osCacheMemAddrSpace)NULL,
                                    (Uint32)debuffer.ramIpAddr, debuffer.size);

                        AEW_APP_PRINT("\nAEW Sample Test successful\n");
                        AEW_APP_PRINT_VAL(
                               "\nBuffer Address: 0x%x, size: %d (in bytes)\n",
                                 debuffer.ramIpAddr, debuffer.size);
                        /* Write statistics to file */
                        AEW_DumpToFile();
                    }
                }
            }
        }
        /* close the logic channel */
        GIO_delete(aewHandle);
    }
    return;
}
#endif /* PSP_VIDEO_PATH_ENABLE */

/**
  * \brief main
  * Main function
  */
int main (void)
{
    return 0;
}

#ifdef PSP_VIDEO_PATH_ENABLE
/**
  * \brief PinMuxing
  * Pin Muxing
  */
void PinMuxing()
{
    /* VPSS PinMuxing                                   */
    /* CI10SEL   - No CI[1:0]                           */
    /* CI32SEL   - No CI[3:2]                           */
    /* CI54SEL   - No CI[5:4]                           */
    /* CI76SEL   - No CI[7:6]                           */
    /* CFLDSEL   - No C_FIELD                           */
    /* CWENSEL   - No C_WEN                             */
    /* HDVSEL    - CCDC HD and VD enabled               */
    /* CCDCSEL   - CCDC PCLK, YI[7:0] enabled           */
    /* AEAW      - EMIFA full address mode              */
    /* VPBECKEN  - VPBECLK enabled                      */
    /* RGBSEL    - No digital outputs                   */
    /* CS3SEL    - LCD_OE/EM_CS3 disabled               */
    /* CS4SEL    - CS4/VSYNC enabled                    */
    /* CS5SEL    - CS5/HSYNC enabled                    */
    /* VENCSEL   - VCLK, YOUT[7:0], COUT[7:0] enabled   */
    /* AEM       - 8bEMIF + 8bCCDC + 8 to 16bVENC       */
    sysModuleRegs -> PINMUX0    &= (0x005482A3u);
    sysModuleRegs -> PINMUX0    |= (0x005482A3u);

    /* PCIEN    =   0: PINMUX1 - Bit 0 */
    sysModuleRegs -> PINMUX1 &= (0xFFFFFFFEu);

    sysModuleRegs -> VPSS_CLKCTL = (0x18u);
    return;
}
#endif /* PSP_VIDEO_PATH_ENABLE */

/**
  * \brief sample_test_AEW
  * Function will be called by the task
  */
void sample_test_AEW()
{
#ifndef PSP_VIDEO_PATH_ENABLE
    AEW_APP_PRINT("\nError: Video port path is not enable in VPFE.\n");
#else
    int resultCCDConfig = 0;
    PinMuxing();
    resultCCDConfig = ccdcConfig();
    if (resultCCDConfig < 0)
    {
       AEW_APP_PRINT("\nUnable configure CCDC\n");
    }
    else
    {
        startAEW();
    }
    GIO_delete(CcdcHandle);
#endif /* PSP_VIDEO_PATH_ENABLE */
}
#ifdef PSP_VIDEO_PATH_ENABLE
/**
 * \brief   AEW_DumpToFile
 *          This function is used to dump statistics to
 *          the file
 *
 */
static void AEW_DumpToFile(void)
{
    Int indexDump;
    short int *temp;
    FILE *fp;
    /* Open Output file */
    fp = fopen("aew_st_sample.txt", "w" );
    temp = (short int *)debuffer.ramIpAddr;
    if ( (NULL != fp) && (NULL != temp))
    {
        /* Write Statistics to output File */
        for(indexDump = 0; indexDump < (enbuffer.size/(2u)); indexDump++)
        {
            fprintf(fp, "\n%d", *temp);
            temp++;
        }
        fclose(fp);
    }
    else
    {
        AEW_APP_PRINT("\nError in storing statistics in file\n");
    }
}
#endif /* PSP_VIDEO_PATH_ENABLE */

