/*******************************************************************************
**+--------------------------------------------------------------------------+**
**|                            ****                                          |**
**|                            ****                                          |**
**|                            ******o***                                    |**
**|                      ********_///_****                                   |**
**|                      ***** /_//_/ ****                                   |**
**|                       ** ** (__/ ****                                    |**
**|                           *********                                      |**
**|                            ****                                          |**
**|                            ***                                           |**
**|                                                                          |**
**|         Copyright (c) 2006-2010 Texas Instruments Incorporated           |**
**|                        ALL RIGHTS RESERVED                               |**
**|                                                                          |**
**| Permission is hereby granted to licensees of Texas Instruments           |**
**| Incorporated (TI) products to use this computer program for the sole     |**
**| purpose of implementing a licensee product based on TI products.         |**
**| No other rights to reproduce, use, or disseminate this computer          |**
**| program, whether in part or in whole, are granted.                       |**
**|                                                                          |**
**| TI makes no representation or warranties with respect to the             |**
**| performance of this computer program, and specifically disclaims         |**
**| any responsibility for any damages, special or consequential,            |**
**| connected with the use of this program.                                  |**
**|                                                                          |**
**+--------------------------------------------------------------------------+**
*******************************************************************************/

/**
 *  \file   psp_bios_af_st_sample.c
 *
 *  \brief  Sample application to test AF functionality
 *
 *  This file contains the Implementation details of AF test application
 *
 *  (C) Copyright 2010, Texas Instruments, Inc
 *
 *  \author     PSP Team
 *
 *  \version    0.1             Created
 *              1.0             First Release
 */

/*******************************************************************************
  Header File Inclusion
 ******************************************************************************/
#include <std.h>
#include <stdio.h>
#include <gio.h>
#include <tsk.h>
#include <mem.h>
#include <string.h>
#include <clk.h>
#include <ti/sdo/pspdrivers/soc/dm6437/dsp/tistdtypes.h>
#include <ti/sdo/pspdrivers/drivers/vpfe/psp_vpfe.h>
#include <ti/sdo/pspdrivers/soc/dm6437/dsp/csl_types.h>
#include <ti/sdo/pspdrivers/system/dm6437/bios/evmDM6437/video/fvid.h>
#include <ti/sdo/pspdrivers/system/dm6437/bios/evmDM6437/video/fvid_evmDM6437.h>
#include <ti/sdo/pspdrivers/common/psp_common.h>
#include <ti/sdo/pspdrivers/drivers/h3a/psp_h3a.h>
#include <ti/sdo/pspdrivers/pal_sys/dm6437/pal_sys.h>
#include <ti/sdo/pspdrivers/drivers/h3a/psp_af.h>
#include <ti/sdo/pspdrivers/pal_os/bios/psputils.h>
#include <ti/sdo/pspdrivers/pal_os/pal_oscache.h>
#include <ti/sdo/pspdrivers/system/dm6437/bios/evmDM6437/video/src/MT9001_extImageSensor.h>
#include <ti/sdo/pspdrivers/soc/dm6437/dsp/cslr_sys.h>
#include <ti/sdo/pspdrivers/soc/dm6437/dsp/soc.h>

/*******************************************************************************
  Macros
 ******************************************************************************/
#ifdef PSP_VIDEO_PATH_ENABLE
#define X_RES_CCDC          (1920u)
#define Y_RES_CCDC          (1080u)
#define BPP_CCDC            (16u)
#define CCDC_FB_SIZE        (X_RES_CCDC * Y_RES_CCDC * (BPP_CCDC/8u))
#define DRIVERFILE          "/H3A0"
#define NO_OF_BUFFERS       (3u)
#define PAXEL_VT_COUNT      (8u)
#define PAXEL_HZ_COUNT      (8u)
#define H3A_AF_BUFFER_SIZE (PAXEL_VT_COUNT * PAXEL_HZ_COUNT * PSP_AF_PAXEL_SIZE)
#endif /* PSP_VIDEO_PATH_ENABLE */
#define AF_APP_PRINT        PSP_DEBUG
#define AF_APP_PRINT_VAL    PSP_DEBUG2
#ifdef PSP_VIDEO_PATH_ENABLE
/* array for H3A AF buffer */
/* make arrayh3AAF 128 bytes aligned */
#pragma DATA_ALIGN(arrayh3AAF, 128);
#endif /* PSP_VIDEO_PATH_ENABLE */

/*******************************************************************************
  Global variables
 ******************************************************************************/
#ifdef PSP_VIDEO_PATH_ENABLE
PSP_H3ABuffer enbuffer;
PSP_H3ABuffer debuffer;

PSP_H3AChannelType type = PSP_H3A_AF;
Uint8 arrayh3AAF[H3A_AF_BUFFER_SIZE];
/* for proper cache operation, buffer size needs to be 128 bytes aligned */
Uint8 padAFBytes[128 - ((H3A_AF_BUFFER_SIZE & 0xEF)% 128)];
extern Int DDR2;
static FVID_Frame           *allocatedFrameBuffers[NO_OF_BUFFERS];
static GIO_Handle                    CcdcHandle;
static CSL_SysRegsOvly sysModuleRegs = (CSL_SysRegsOvly )CSL_SYS_0_REGS;
FVID_Frame                  *FBAddr        = NULL;
static PSP_VPFECcdcConfigParams ccdcParams =
{
    FVID_CCDC_RAW_FORMAT,               /* inpmod       */
    FVID_FIELD_MODE,                    /* ffMode       */
    Y_RES_CCDC + 1,                     /* height       */
    X_RES_CCDC,                         /* width        */
    (X_RES_CCDC *BPP_CCDC/(8u)),        /* pitch        */
    0,                                  /* horzStartPix */
    0,                                  /* vertStartPix */
    NULL,                               /* appCallback  */
    {
        MT9001_Open,                    /* extVD Fxn    */
        MT9001_Close,
        MT9001_Control,
    },
    0,                                  /* segId        */
    {
        PSP_VPFE_BITS10,                /* dataSize     */
        PSP_VPFE_PACK8_16BITS_PIXEL,    /* pack8        */
        PSP_VPFE_DataPol_Normal,        /* dataPol      */
        PSP_VPFE_SyncPol_Positive,      /* VDSyncPol    */
        PSP_VPFE_SyncPol_Positive,      /* HDSyncPol    */
        PSP_VPFE_SyncDir_Input,         /* HDVDMaster   */
        50,                             /* HDSyncWidth  */
        4,                              /* VDSyncWidth  */
        800,                            /* numPxlPerLine*/
        1000,                           /* numLinPerFld */
        PSP_VPFE_ALaw_Disable,          /* ALawEnable   */
        PSP_VPFE_ALaw_bits15_6,         /* ALaw_Width   */
    }
};

static PSP_AFParams params =
{
    PSP_AF_ALAW_DISABLE,                /* A Law Status */
    {
        PSP_AF_HMF_DISABLE,             /* HMF Status  */
        120u,                           /* Threshold value */
    },
    PSP_AF_GR_BG_BAYER,                 /* RGB position */
    /* IIR Filter Configuration */
    {
        2u,                             /* IIR Horizontal start */
        /*IIR Filter coefficients for set 0 */
        {
            64,
            0,
            0,
            21,
            22,
            21,
            0,
            0,
            -16,
            32,
            -16,
        },
        /*IIR Filter coefficients for set 1 */
        {
            64,
            0,
            0,
            21,
            22,
            21,
            0,
            -29,
            -16,
            32,
            -16,
        },
    },
    /* Paxel Configuration  */
    {
        8u,                     /* width */
        8u,                     /* height */
        8u,                     /* hzStart */
        8u,                     /* vtStart */
        PAXEL_HZ_COUNT,         /* hzCnt */
        PAXEL_VT_COUNT,         /* vtCnt */
        2u,                     /* lineIncr */
    },
    PSP_AF_ACCUMULATOR_SUMMED,  /* Accumulator Mode */
};

static MT9001_StandardFormat stdFormat;
#endif /* PSP_VIDEO_PATH_ENABLE */

/****************************************************************************
  Functions
 *****************************************************************************/
#ifdef PSP_VIDEO_PATH_ENABLE
/**
 * \brief   AF_DumpToFile
 *          This function is used to dump statistics to
 *          the file
 *
 */
static void AF_DumpToFile(void);
#endif /* PSP_VIDEO_PATH_ENABLE */
/**
 * \brief   I2C_INIT
 *          This function is used to Initialize the I2C Bus Driver
 *
 */
void I2C_INIT()
{
    /*Power On I2C*/
    if (PAL_SOK !=
        PAL_sysModuleClkCtrl(PAL_SYS_CLK_MODULE_I2C, PAL_SYS_MODULE_CLK_ENABLE))
    {
        return;
    }
}

#ifdef PSP_VIDEO_PATH_ENABLE
/**
 * \brief ccdcConfig
 * Configure CCDC and Create Device Entry for VPFE Driver
 */
static int ccdcConfig()
{
    Int resultCCDC = 0;
    GIO_Attrs gioAttrs                       = GIO_ATTRS;
    FVID_Frame *  ptrSP           = NULL;
    PSP_VPFEChannelParams                   feinitParams;
    Uint32 i = 0;
    Ptr                      ptrFB           = NULL;
    for(i = 0; i < NO_OF_BUFFERS; i++)
    {
        ptrSP = MEM_alloc(DDR2, sizeof(FVID_Frame) , 32u);
        if (NULL!=ptrSP)
        {
            ptrFB = MEM_alloc(DDR2, CCDC_FB_SIZE , 32u);
            if (NULL!=ptrFB)
            {
                ptrSP->pitch            =  (X_RES_CCDC *(BPP_CCDC/8u));
                ptrSP->lines            =  Y_RES_CCDC;
                ptrSP->bpp                  =  FVID_BPP_BITS16;
                ptrSP->frame.frameBufferPtr   =  ptrFB;
            }
        }
        allocatedFrameBuffers[i]    = ptrSP;
    }

    /* Create CCDC Channel */
    feinitParams.id         = PSP_VPFE_CCDC;
    feinitParams.params     = (PSP_VPFECcdcConfigParams*)&ccdcParams;
    CcdcHandle = FVID_create("/VPFE0", IOM_INOUT, NULL, &feinitParams,
        &gioAttrs);
    if (NULL == CcdcHandle)
    {
        AF_APP_PRINT("VPSS  :CCDC Create.......FAILED \r\n");
        resultCCDC = -1;
    }
    else
    {
        stdFormat = MT9T001_MODE_1080p_18FPS;
        if (IOM_COMPLETED != FVID_control(CcdcHandle,
                VPFE_ExtVD_BASE+PSP_VPSS_EXT_VIDEO_DECODER_STD_FORMAT,
                &stdFormat))
        {
            AF_APP_PRINT("VPSS  :MT9001.......FAILED \r\n");
            resultCCDC = -1;
        }
    }
    return resultCCDC;
}

/**
 * \brief startAF
 * Main Function to run the sample application of AF Driver
 * This Function enables the AF engine and collects Statistics generated
 * by AF Engine
 */
static void startAF(void)
{
    GIO_Handle afHandle;
    GIO_Attrs gioAttrs = GIO_ATTRS;
    Int resultTestAF, gioStatus;
    FVID_Frame *FBAddr = NULL;
    Uint32 bufferSize;

    /* open a logical channel */
    afHandle = GIO_create(DRIVERFILE, IOM_INOUT, &gioStatus, &type, &gioAttrs);
    if ((NULL == afHandle) || (IOM_COMPLETED != gioStatus))
    {
        AF_APP_PRINT("\nAF device open failed\n");
    }
    else
    {
        /* Call the IOCTL Set Parameters */
        resultTestAF = GIO_control(afHandle, PSP_H3A_IOCTL_SET_PARAM, &params);
        if (resultTestAF < 0)
        {
            AF_APP_PRINT("\nAF IOCTL set params failed\n");
        }
        else
        {
            /* Enqueue the buffer, This will enable AEW engine */
            enbuffer.size = H3A_AF_BUFFER_SIZE;
            enbuffer.ramIpAddr = (Ptr)(arrayh3AAF);
            bufferSize = sizeof(PSP_H3ABuffer);
            if ( NULL != enbuffer.ramIpAddr )
            {
                resultTestAF = GIO_submit(afHandle, PSP_VPSS_QUEUE, &enbuffer,
                    &bufferSize, NULL);
                if (resultTestAF < 0)
                {
                    AF_APP_PRINT("\nAF enqueue failed\n");
                }
                else
                {
                    /* Enable ccdc engine */
                    if (NULL != CcdcHandle)
                    {
                        FBAddr   =  allocatedFrameBuffers[0];
                        if (NULL != FBAddr)
                        {
                            if (IOM_COMPLETED != FVID_queue(CcdcHandle, FBAddr))
                            {
                                AF_APP_PRINT(
                                    "VPSS  :CCDC Queuing.......FAILED \r\n");
                            }
                        }
                    }

                    /* Dequeue the buffer */
                    resultTestAF = GIO_submit(afHandle, PSP_VPSS_DEQUEUE,
                        &debuffer, &bufferSize, NULL);
                    if ( resultTestAF < 0 )
                    {
                        AF_APP_PRINT("\nAF dequeue failed\n");
                    }
                    else
                    {
                        if (debuffer.buffStatus != PSP_H3A_BUFFER_DATA_VALID)
                        {
                            AF_APP_PRINT(
                                "\nData corrupted: Write Buffer Overflow\n");
                        }
                        /* Invalidate the cache */
                        PAL_osCacheInvalidate((PAL_osCacheMemAddrSpace)NULL,
                            (Uint32)debuffer.ramIpAddr, debuffer.size);
                        AF_APP_PRINT("\nAF Sample Test successful\n");
                        AF_APP_PRINT_VAL(
                            "\nBuffer Address: 0x%x, size: %d (in bytes)\n",
                            debuffer.ramIpAddr, debuffer.size);

                        /* Dump statistics to file */
                        AF_DumpToFile();
                    }
                }
            }
        }
        /* close the logic channel */
        GIO_delete(afHandle);
    }
    return;
}
#endif /* PSP_VIDEO_PATH_ENABLE */

/**
 * \brief main
 * Main function
 */
int main (void)
{
    return 0;
}

#ifdef PSP_VIDEO_PATH_ENABLE
/**
 * \brief PinMuxing
 * Pin Muxing
 */
void PinMuxing()
{
    /* VPSS PinMuxing                                   */
    /* CI10SEL   - No CI[1:0]                           */
    /* CI32SEL   - No CI[3:2]                           */
    /* CI54SEL   - No CI[5:4]                           */
    /* CI76SEL   - No CI[7:6]                           */
    /* CFLDSEL   - No C_FIELD                           */
    /* CWENSEL   - No C_WEN                             */
    /* HDVSEL    - CCDC HD and VD enabled               */
    /* CCDCSEL   - CCDC PCLK, YI[7:0] enabled           */
    /* AEAW      - EMIFA full address mode              */
    /* VPBECKEN  - VPBECLK enabled                      */
    /* RGBSEL    - No digital outputs                   */
    /* CS3SEL    - LCD_OE/EM_CS3 disabled               */
    /* CS4SEL    - CS4/VSYNC enabled                    */
    /* CS5SEL    - CS5/HSYNC enabled                    */
    /* VENCSEL   - VCLK, YOUT[7:0], COUT[7:0] enabled   */
    /* AEM       - 8bEMIF + 8bCCDC + 8 to 16bVENC       */
    sysModuleRegs -> PINMUX0    &= (0x005482A3u);
    sysModuleRegs -> PINMUX0    |= (0x005482A3u);

    /* PCIEN    =   0: PINMUX1 - Bit 0 */
    sysModuleRegs -> PINMUX1 &= (0xFFFFFFFEu);

    sysModuleRegs -> VPSS_CLKCTL = (0x18u);
    return;
}
#endif /* PSP_VIDEO_PATH_ENABLE */

/**
 * \brief sample_test_AF
 * Function will be called by the task
 */
void sample_test_AF()
{
#ifndef PSP_VIDEO_PATH_ENABLE
    AF_APP_PRINT("\nError: Video port path is not enable in VPFE.\n");
#else
    Int resultCCDConfig = 0;
    PinMuxing();
    resultCCDConfig = ccdcConfig();
    if (resultCCDConfig < 0)
    {
        AF_APP_PRINT("\nUnable to configure CCDC\n");
    }
    else
    {
        startAF();
    }
    GIO_delete(CcdcHandle);
#endif /* PSP_VIDEO_PATH_ENABLE */
}
#ifdef PSP_VIDEO_PATH_ENABLE
/**
 * \brief   AF_DumpToFile
 *          This function is used to dump statistics to
 *          the file
 *
 */
static void AF_DumpToFile(void)
{
    Int indexDump;
    Int *temp;
    FILE *fp;
    /* Open Output file */
    fp = fopen("af_st_sample.txt", "w" );
    temp = (int *)debuffer.ramIpAddr;
    if ( (NULL != fp) && (NULL != temp))
    {
        /* Write Statistics to output File */
        for(indexDump = 0; indexDump < (enbuffer.size/(4u)); indexDump++)
        {
            fprintf(fp, "\n%d", *temp);
            temp++;
        }
        fclose(fp);
    }
    else
    {
        AF_APP_PRINT("\nError in storing statistics in file\n");
    }
}
#endif /* PSP_VIDEO_PATH_ENABLE */

