/*******************************************************************************
**+--------------------------------------------------------------------------+**
**|                            ****                                          |**
**|                            ****                                          |**
**|                            ******o***                                    |**
**|                      ********_///_****                                   |**
**|                      ***** /_//_/ ****                                   |**
**|                       ** ** (__/ ****                                    |**
**|                           *********                                      |**
**|                            ****                                          |**
**|                            ***                                           |**
**|                                                                          |**
**|         Copyright (c) 2006-2010 Texas Instruments Incorporated           |**
**|                        ALL RIGHTS RESERVED                               |**
**|                                                                          |**
**| Permission is hereby granted to licensees of Texas Instruments           |**
**| Incorporated (TI) products to use this computer program for the sole     |**
**| purpose of implementing a licensee product based on TI products.         |**
**| No other rights to reproduce, use, or disseminate this computer          |**
**| program, whether in part or in whole, are granted.                       |**
**|                                                                          |**
**| TI makes no representation or warranties with respect to the             |**
**| performance of this computer program, and specifically disclaims         |**
**| any responsibility for any damages, special or consequential,            |**
**| connected with the use of this program.                                  |**
**|                                                                          |**
**+--------------------------------------------------------------------------+**
*******************************************************************************/
/**
 * \file   psp_bios_hist_sample.c
 *
 * \brief  Histogram sample application
 *
 * This file contains the sample application which is using serivces of the
 * Histogram device driver.
 *
 * (C) Copyright 2010, Texas Instruments, Inc
 *
 * \author     EI5
 *
 * \version    0.1       created
 *             1.0       First Release
 */

/******************************************************************************
  Header File Inclusion
 ******************************************************************************/
#include <stdio.h>
#include <std.h>
#include <gio.h>
#include <mem.h>
#include <string.h>
#include <ti/sdo/pspdrivers/pal_sys/dm6437/pal_sys.h>
#include <ti/sdo/pspdrivers/soc/dm6437/dsp/cslr_sys.h>
#include <ti/sdo/pspdrivers/soc/dm6437/dsp/soc.h>
#include <ti/sdo/edma3/drv/edma3_drv.h>
#include <ti/sdo/pspdrivers/drivers/vpfe/psp_vpfe.h>
#include <ti/sdo/pspdrivers/pal_os/pal_oscache.h>
#include <ti/sdo/pspdrivers/system/dm6437/bios/evmDM6437/video/fvid.h>
#include <ti/sdo/pspdrivers/system/dm6437/bios/evmDM6437/video/fvid_evmDM6437.h>
#include <ti/sdo/pspdrivers/drivers/histogram/psp_histogram.h>
#include <ti/sdo/pspdrivers/pal_os/bios/psputils.h>
#include <ti/sdo/pspdrivers/system/dm6437/bios/evmDM6437/video/src/MT9001_extImageSensor.h>

/******************************************************************************
  Macros
 ******************************************************************************/
#ifdef PSP_VIDEO_PATH_ENABLE
/* White balance gain for all colors. */
/* It is set within the range of x0~x7.96875(7+31/32).
   The decimal point is located between WG03[5] and WG03[4] */
#define WB_GAIN00       0x20  /* 1 */
#define WB_GAIN01       0x20  /* 1 */
#define WB_GAIN02       0x20  /* 1 */
#define WB_GAIN03       0x20  /* 1 */

/* If the "end" is programmed as the same value of "start", then the region size
   is treated as 0. In all cases, the total number of pixels processed is
   "End - Start + 1". Therefore, the minimum region dimension is at least 2. */
/* Region 0 boundary information */
#define REG0_HSTART     0u
#define REG0_HEND       639u
#define REG0_VSTART     0u
#define REG0_VEND       479u
/* Region 1 boundary information */
#define REG1_HSTART     0u
#define REG1_HEND       0u
#define REG1_VSTART     0u
#define REG1_VEND       0u
/* Region 2 boundary information */
#define REG2_HSTART     0u
#define REG2_HEND       0u
#define REG2_VSTART     0u
#define REG2_VEND       0u
/* Region 3 boundary information */
#define REG3_HSTART     0u
#define REG3_HEND       0u
#define REG3_VSTART     0u
#define REG3_VEND       0u

/* Buffer size in words(4 bytes). */
#define BUFFER_SIZE     1024u
/* Required buffer address allignment. It is required to cache invalidate the
   buffer. */
#define BUFFER_ALIGN    128u

/* Apllication error codes. */
#define HIST_APPLI_SOK      0
#define HIST_APPLI_ERROR    1

/* CCDC frame width */
#define X_RES_CCDC      720u
/* CCDC frame hight */
#define Y_RES_CCDC      481u
/* Bits per pixels for CCDC */
#define BPP_CCDC        16u
/* Buffer size for the captured frame from CCDC */
#define CCDC_FB_SIZE    (X_RES_CCDC * Y_RES_CCDC * (BPP_CCDC/8u))
#endif /* PSP_VIDEO_PATH_ENABLE */
#define HIST_APP_PRINT  PSP_DEBUG
/******************************************************************************
  External parameters
 ******************************************************************************/
#ifdef PSP_VIDEO_PATH_ENABLE
/* DDR2 Heap ID */
extern Int ddr2_segmentID;
/* Function to initialize the EDMA3 driver */
extern EDMA3_DRV_Result edma3init();
/* Function to uninitialize the EDMA3 driver */
extern EDMA3_DRV_Result edma3deinit();
/* Handle to EDMA3 device */
extern EDMA3_DRV_Handle hEdma;
#endif /* PSP_VIDEO_PATH_ENABLE */

/******************************************************************************
  Global parameters
 ******************************************************************************/
#ifdef PSP_VIDEO_PATH_ENABLE
/* Handle to CCDC device */
GIO_Handle CcdcHandle = NULL;
FVID_Frame *FBAddr = NULL;
FVID_Frame *allocatedFrameBuffers = NULL;

/* Histogram configuration parameters */
static PSP_HISTparam histConfigParams =
{
    PSP_HIST_CLEAR_AFTER_READ,      /* clearOpDataAfterRead */
    PSP_HIST_256BINS,               /* bins                 */
    PSP_HIST_DATA_RSHIFT_TWO,       /* shift                */
    {
        WB_GAIN00,                  /* wbGain[0]            */
        WB_GAIN01,                  /* wbGain[1]            */
        WB_GAIN02,                  /* wbGain[2]            */
        WB_GAIN03                   /* wbGain[3]            */
    },
    {
        {
            REG0_HSTART,            /* region[0].hStart     */
            REG0_HEND,              /* region[0].hEnd       */
            REG0_VSTART,            /* region[0].vStart     */
            REG0_VEND               /* region[0].vEnd       */
        },
        {
            REG1_HSTART,            /* region[1].hStart     */
            REG1_HEND,              /* region[1].hEnd       */
            REG1_VSTART,            /* region[1].vStart     */
            REG1_VEND               /* region[1].vEnd       */
        },
        {
            REG2_HSTART,            /* region[2].hStart     */
            REG2_HEND,              /* region[2].hEnd       */
            REG2_VSTART,            /* region[2].vStart     */
            REG2_VEND               /* region[2].vEnd       */
        },
        {
            REG3_HSTART,            /* region[3].hStart     */
            REG3_HEND,              /* region[3].hEnd       */
            REG3_VSTART,            /* region[3].vStart     */
            REG3_VEND               /* region[3].vEnd       */
        }
    }
};

/* CCDC configuration parameters */
static PSP_VPFECcdcConfigParams ccdcParams =
{
    FVID_CCDC_RAW_FORMAT,               /* inpmod       */
    FVID_FIELD_MODE,                    /* ffMode       */
    Y_RES_CCDC,                         /* height       */
    X_RES_CCDC,                         /* width        */
    (X_RES_CCDC *BPP_CCDC/(8u)),        /* pitch        */
    0,                                  /* horzStartPix */
    0,                                  /* vertStartPix */
    NULL,                               /* appCallback  */
    {
        MT9001_Open,                   /* extVD Fxn    */
        MT9001_Close,
        MT9001_Control,
    },
    0,                                  /*segId         */
    {
        PSP_VPFE_BITS10,                /* dataSize     */
        PSP_VPFE_PACK8_16BITS_PIXEL,    /* pack8        */
        PSP_VPFE_DataPol_Normal,        /* dataPol      */
        PSP_VPFE_SyncPol_Positive,      /* VDSyncPol    */
        PSP_VPFE_SyncPol_Positive,      /* HDSyncPol    */
        PSP_VPFE_SyncDir_Input,         /* HDVDMaster   */
        (50u),                          /* HDSyncWidth  */
        (4u),                           /* VDSyncWidth  */
        (800u),                         /* numPxlPerLine*/
        (1000u),                        /* numLinPerFld */
        PSP_VPFE_ALaw_Disable,          /* ALawEnable   */
        PSP_VPFE_ALaw_bits15_6,         /* ALaw_Width   */
    }
};

/* MT9001 configuration parameters */
static MT9001_StandardFormat stdFormat;

static CSL_SysRegsOvly sysModuleRegs = (CSL_SysRegsOvly )CSL_SYS_0_REGS;
#endif /* PSP_VIDEO_PATH_ENABLE */

/******************************************************************************
  Functions
 ******************************************************************************/
/**
 * \brief   I2C_INIT
 *          This function is used to Initialize the I2C Bus Driver
 *
 */
void I2C_INIT()
{
    /*Power On I2C*/
    if (PAL_SOK !=
        PAL_sysModuleClkCtrl(PAL_SYS_CLK_MODULE_I2C, PAL_SYS_MODULE_CLK_ENABLE))
    {
        return;
    }
}

#ifdef PSP_VIDEO_PATH_ENABLE
/**
 * \brief   ccdc_init
 *          Initiliaze the CCDC device.
 *
 */
static Int ccdc_init()
{
    GIO_Attrs             gioAttrs  = GIO_ATTRS;
    FVID_Frame *ptrSP    = NULL;
    PSP_VPFEChannelParams feinitParams;
    Ptr     ptrFB = NULL;
    Int returnCcdcInit = HIST_APPLI_SOK;

    /* VPSS PinMuxing                                   */
    /* CI10SEL   - No CI[1:0]                           */
    /* CI32SEL   - No CI[3:2]                           */
    /* CI54SEL   - No CI[5:4]                           */
    /* CI76SEL   - No CI[7:6]                           */
    /* CFLDSEL   - No C_FIELD                           */
    /* CWENSEL   - No C_WEN                             */
    /* HDVSEL    - CCDC HD and VD enabled               */
    /* CCDCSEL   - CCDC PCLK, YI[7:0] enabled           */
    /* AEAW      - EMIFA full address mode              */
    /* VPBECKEN  - VPBECLK enabled                      */
    /* RGBSEL    - No digital outputs                   */
    /* CS3SEL    - LCD_OE/EM_CS3 disabled               */
    /* CS4SEL    - CS4/VSYNC enabled                    */
    /* CS5SEL    - CS5/HSYNC enabled                    */
    /* VENCSEL   - VCLK, YOUT[7:0], COUT[7:0] enabled   */
    /* AEM       - 8bEMIF + 8bCCDC + 8 to 16bVENC       */
    sysModuleRegs->PINMUX0    &= (0x005482A3u);
    sysModuleRegs->PINMUX0    |= (0x005482A3u);

    /* PCIEN    =   0: PINMUX1 - Bit 0 */
    sysModuleRegs->PINMUX1 &= (0xFFFFFFFEu);

    sysModuleRegs->VPSS_CLKCTL = (0x18u);

    ptrSP = MEM_alloc(ddr2_segmentID, sizeof(FVID_Frame) , 32u);
    if (NULL != ptrSP)
    {
        ptrFB = MEM_alloc(ddr2_segmentID, CCDC_FB_SIZE , 32u);
        if (NULL != ptrFB)
        {
            ptrSP->pitch            =  (X_RES_CCDC *(BPP_CCDC / 8u));
            ptrSP->lines            =  Y_RES_CCDC;
            ptrSP->bpp                  =  FVID_BPP_BITS16;
            ptrSP->frame.frameBufferPtr   =  ptrFB;
        }
        else
        {
            returnCcdcInit = HIST_APPLI_ERROR;
        }
    }
    else
    {
        returnCcdcInit = HIST_APPLI_ERROR;
    }
    allocatedFrameBuffers = ptrSP;

    if (HIST_APPLI_SOK == returnCcdcInit)
    {
        /* Create CCDC Channel */
        feinitParams.id     = PSP_VPFE_CCDC;
        feinitParams.params = (PSP_VPFECcdcConfigParams*)&ccdcParams;
        CcdcHandle =
            FVID_create("/VPFE0", IOM_INOUT, NULL, &feinitParams, &gioAttrs);
        if (NULL == CcdcHandle)
        {
            HIST_APP_PRINT("VPSS  :CCDC Create.......FAILED \r\n");
            returnCcdcInit = HIST_APPLI_ERROR;
        }
    }

    if (HIST_APPLI_SOK == returnCcdcInit)
    {
        stdFormat = MT9T001_MODE_1080p_18FPS;
        if (IOM_COMPLETED != FVID_control(CcdcHandle,
                VPFE_ExtVD_BASE+PSP_VPSS_EXT_VIDEO_DECODER_STD_FORMAT,
                &stdFormat))
        {
            HIST_APP_PRINT("VPSS  :MT9001.......FAILED \r\n");
            returnCcdcInit = HIST_APPLI_ERROR;
        }
    }

    return returnCcdcInit;
}

/**
 * \brief   ccdc_enable
 *          Enable the CCDC engine.
 *
 */
static Int ccdc_enable()
{
    Int returnCcdcEnable = HIST_APPLI_ERROR;

    /* Enable ccdc engine */
    if (NULL != CcdcHandle)
    {
        /* Enables the ccdc Engine */
        FBAddr   =  allocatedFrameBuffers;

        if (NULL != FBAddr)
        {
            /* Enable CCDC engine */
            if (IOM_COMPLETED == FVID_queue(CcdcHandle, FBAddr))
            {
                returnCcdcEnable = HIST_APPLI_SOK;
            }
            else
            {
                HIST_APP_PRINT("\n VPSS  :CCDC Queuing.......FAILED ");
            }
        }
        else
        {
            HIST_APP_PRINT("\n CCDC input buffer is NULL ");
        }
    }
    else
    {
        HIST_APP_PRINT("\n CCDC device handle is NULL ");
    }

    return returnCcdcEnable;
}

/**
 * \brief   hist_sample_application
 *          Histogram sample test application.
 *
 * \returns Success or error code
 */
static Int hist_sample_application()
{
    GIO_Handle histGioChan  = NULL;
    GIO_Attrs  histGioAttrs = GIO_ATTRS;
    Int gioStatus;
    Int returnTask = HIST_APPLI_SOK;
    PSP_HISTbuffer inbuff[2];
    PSP_HISTbuffer *outbuff = NULL;
    Int sizeOfbuff;
    Uint32 i;
    FILE *fp = NULL;
    Char name[25];

    inbuff[0].ramIpAddr = NULL;
    inbuff[1].ramIpAddr = NULL;

    /* Create histogram channel */
    histGioChan = GIO_create("/histogram", IOM_INPUT, &gioStatus, hEdma,
        &histGioAttrs);
    if (NULL == histGioChan)
    {
        returnTask = HIST_APPLI_ERROR;
        HIST_APP_PRINT("\n Histogram channel open failed");
    }
    else
    {
        /* set the channel parameters */
        gioStatus = GIO_control(histGioChan, PSP_HIST_IOCTL_SET_PARAMS,
            &histConfigParams);
        if (IOM_COMPLETED != gioStatus)
        {
            returnTask = HIST_APPLI_ERROR;
            HIST_APP_PRINT("\n Histogram channel set parameter failed");
        }

        if (HIST_APPLI_SOK == returnTask)
        {
            sizeOfbuff = sizeof(PSP_HISTbuffer);

            /* Allocate memory for input buffers */
            for(i = 0; i < 2; i++)
            {
                inbuff[i].ramIpAddr = MEM_alloc(ddr2_segmentID,
                    BUFFER_SIZE * sizeof(Int),
                    BUFFER_ALIGN);
                if (NULL != inbuff[i].ramIpAddr)
                {
                    /* Initiliaze the input buffer */
                    memset(inbuff[i].ramIpAddr, 0u, (BUFFER_SIZE*sizeof(Int)));

                    /* size of buffer must be in terms of words (4 bytes) */
                    inbuff[i].bufferSize = BUFFER_SIZE;
                }
                else
                {
                    HIST_APP_PRINT("\n Memory allocation failed");
                    returnTask = HIST_APPLI_ERROR;
                    break;
                }
            }
        }

        if (HIST_APPLI_SOK == returnTask)
        {
            /* enqueue the first buffer to enable the histogram */
            gioStatus = GIO_submit(histGioChan, PSP_VPSS_QUEUE,
                (Ptr)(&inbuff[0]), (Ptr)(&sizeOfbuff), NULL);
            if (IOM_COMPLETED != gioStatus)
            {
                returnTask = HIST_APPLI_ERROR;
                HIST_APP_PRINT("\n Histogram enqueue buffer failed");
            }
        }

        if (HIST_APPLI_SOK == returnTask)
        {
            /* Enable the CCDC engine */
            returnTask = ccdc_enable();
        }

        if (HIST_APPLI_SOK == returnTask)
        {
            /* enqueue the second buffer to get the statistics */
            gioStatus = GIO_submit(histGioChan, PSP_VPSS_QUEUE,
                (Ptr)(&inbuff[1]), (Ptr)(&sizeOfbuff), NULL);
            if (IOM_COMPLETED != gioStatus)
            {
                returnTask = HIST_APPLI_ERROR;
                HIST_APP_PRINT("\n Histogram enqueue buffer failed");
            }
        }

        if (HIST_APPLI_SOK == returnTask)
        {
            /* dequeue the buffer */
            gioStatus = GIO_submit(histGioChan, PSP_VPSS_DEQUEUE,
                (Ptr)(&outbuff), (Ptr)(&sizeOfbuff), NULL);

            if (IOM_COMPLETED != gioStatus)
            {
                returnTask = HIST_APPLI_ERROR;
                HIST_APP_PRINT("\n Histogram dequeue failed");
            }
        }

        if (HIST_APPLI_SOK == returnTask)
        {
            if (NULL != outbuff)
            {
                /* Cache invalidate the buffer containing the statistics */
                PAL_osCacheInvalidate((PAL_osCacheMemAddrSpace)NULL,
                    (Uint32)(outbuff->ramIpAddr),
                    outbuff->bufferSize * sizeof(Int));
            }
        }

        if (HIST_APPLI_SOK == returnTask)
        {
            /* Delete histogram channel */
            gioStatus = GIO_delete(histGioChan);
            if (IOM_COMPLETED != gioStatus)
            {
                HIST_APP_PRINT("\n Histogram close failed");
                returnTask = HIST_APPLI_ERROR;
            }
        }
    }

    if (HIST_APPLI_SOK == returnTask)
    {
        /* dump the statistics in to the file */
        sprintf(name, "out_app_hist.csv");
        fp = fopen(name, "wb");
        if (NULL != fp)
        {
            fprintf(fp, "\n Time stamp %d ms", outbuff->timeStmp);
            for(i = 0u; i < BUFFER_SIZE; i++)
            {
                fprintf(fp, "\n %d", ((Int*)(outbuff->ramIpAddr))[i]);
            }
            fclose(fp);
        }
    }

    for(i = 0; i < 2; i++)
    {
        if (NULL != inbuff[i].ramIpAddr)
        {
            MEM_free(ddr2_segmentID, inbuff[i].ramIpAddr,
                BUFFER_SIZE * sizeof(Int));
        }
    }

    return (returnTask);
}
#endif /* PSP_VIDEO_PATH_ENABLE */

/**
 * \brief   main
 *          main function.
 *
 */
Int main()
{
    return 0;
}

/**
 * \brief   HISTTskFun
 *          Task function.
 *
 */
void HISTTskFun()
{
#ifndef PSP_VIDEO_PATH_ENABLE
    HIST_APP_PRINT("\nError: Video port path is not enable in VPFE.\n");
#else
    Int ret;

    /* Initiliaze the CCDC device */
    ret = ccdc_init();

    if (HIST_APPLI_SOK == ret)
    {
        /* Initialize the EDMA3 driver */
        ret = edma3init();

        if (EDMA3_DRV_SOK != ret)
        {
            HIST_APP_PRINT("\n EDMA initilizatioin failed \n ");
        }
        else
        {
            /* Histogram sample application */
            ret = hist_sample_application();
            if (HIST_APPLI_SOK == ret)
            {
                HIST_APP_PRINT("\n Sample test case passed\n ");
            }
            else
            {
                HIST_APP_PRINT("\n Sample test case failed\n ");
            }

            /* uninitialize the EDMA3 driver */
            edma3deinit();
            /* Delete the CCDC device instance */
            FVID_delete(CcdcHandle);
        }
    }
#endif /* PSP_VIDEO_PATH_ENABLE */
}

