/*******************************************************************************
**+--------------------------------------------------------------------------+**
**|                            ****                                          |**
**|                            ****                                          |**
**|                            ******o***                                    |**
**|                      ********_///_****                                   |**
**|                      ***** /_//_/ ****                                   |**
**|                       ** ** (__/ ****                                    |**
**|                           *********                                      |**
**|                            ****                                          |**
**|                            ***                                           |**
**|                                                                          |**
**|         Copyright (c) 2006-2010 Texas Instruments Incorporated           |**
**|                        ALL RIGHTS RESERVED                               |**
**|                                                                          |**
**| Permission is hereby granted to licensees of Texas Instruments           |**
**| Incorporated (TI) products to use this computer program for the sole     |**
**| purpose of implementing a licensee product based on TI products.         |**
**| No other rights to reproduce, use, or disseminate this computer          |**
**| program, whether in part or in whole, are granted.                       |**
**|                                                                          |**
**| TI makes no representation or warranties with respect to the             |**
**| performance of this computer program, and specifically disclaims         |**
**| any responsibility for any damages, special or consequential,            |**
**| connected with the use of this program.                                  |**
**|                                                                          |**
**+--------------------------------------------------------------------------+**
*******************************************************************************/
/**
 *  \file psp_bios_previewer_st_multipass_sample.c
 *
 *  \brief Multipass Previewer Application
 *
 *         This files includes Multipass Previewer Application that demonstrates
 *         multipass functionality to preview image of horizontal size greater
 *         than 1280 pixels. This application converts raw image in Bayer
 *         pattern to YUV4:2:2 image
 *
 *  (C) Copyright 2010, Texas Instruments, Inc
 *
 *  \author     PSP Team
 *
 *  \version    1.0     Created
 */


/******************************************************************************
  Header File Inclusion
 ******************************************************************************/
#include <stdio.h>
#include <string.h>
#include <std.h>
#include <gio.h>
#include <ti/sdo/pspdrivers/drivers/previewer/psp_previewer.h>
#include <ti/sdo/pspdrivers/pal_os/bios/psputils.h>
#include <ti/sdo/pspdrivers/pal_os/pal_oscache.h>
/******************************************************************************
  Macros
 ******************************************************************************/
/* height and width of input image */
#define PREV_IMAGE_HEIGHT 480u
#define PREV_IMAGE_WIDTH 1920u

/* number of pixels per word in output image */
#define PREV_OUT_PIXELS_PER_WORD 2u

/* max number of bytes required for output image - ingnoring crop size */
#define PREV_OUT_IMAGE_SIZE_IN_WORDS ((PREV_IMAGE_HEIGHT * PREV_IMAGE_WIDTH)\
    /(PREV_OUT_PIXELS_PER_WORD))

/* debug print macros */
#define PREV_APP_PRINT          PSP_DEBUG
#define PREV_APP_PRINT_VAL      PSP_DEBUG1

#define R_PHASE \
    0,   0,    0, 0, \
0,   64,   0, 0, \
0,   0,    0, 0, \
0,   0,    0, 0, \
\
0,   16,   0, 0, \
16,   0,   16, 0, \
\
16,   0,   16, 0, \
0,    0,   0, 0, \
16,   0,   16, 0, \
0,    0,   0, 0, \
\
0,    16,  0, 0, \
0,    0,   0, 0, \
\
0,   0,    0, 0, \
0,   64,   0, 0, \
0,   0,    0, 0, \
0,   0,    0, 0, \
\
0,   0,    0, 0, \
32,  0,   32, 0, \
\
16, -26,   16, 0, \
26, 0,    26, 0, \
16, -26,   16, 0, \
0,  0,    0,  0, \
\
0,  0,    0,  0, \
0,  0,    0,  0, \
\
0,  0,    0,  0, \
0, 64,    0,  0, \
0,  0,    0,  0, \
0,  0,    0,  0, \
\
0, 32,    0,  0, \
0,  0,    0,  0, \
\
16, 26,   16, 0, \
-26, 0,  -26, 0, \
16, 26,   16, 0, \
0,   0,    0, 0, \
\
0,  32,    0, 0, \
0,  0,     0, 0

#define GR_PHASE \
    -8,  0,   -8, 0, \
32, 32,   32, 0, \
-8,  0,   -8, 0, \
0,   0,    0, 0, \
\
0,   0,    0, 0, \
0,  64,    0, 0, \
\
-10, 32,  -10, 0, \
0,  40,    0, 0, \
-10, 32,  -10, 0, \
0,   0,    0, 0, \
\
0,   0,    0, 0, \
0,   0,    0, 0, \
\
0,   0,    0, 0, \
32,  0,   32, 0, \
0,   0,    0, 0, \
0,   0,    0, 0, \
\
0,   0,    0, 0, \
0,  64,    0, 0, \
\
-13, 32,  -13, 0, \
0,  52,    0, 0, \
-13, 32,  -13, 0, \
0,   0,    0, 0, \
\
0,   0,    0, 0, \
0,   0,    0, 0, \
\
-16, 0,  -16, 0, \
32, 64,  32, 0, \
-16, 0,  -16, 0, \
0,   0,    0, 0, \
\
0,   0,    0, 0, \
0,  64,    0, 0, \
\
0,  32,    0, 0, \
0,  0,     0, 0, \
0,  32,    0, 0, \
0,  0,     0, 0, \
\
0,  0,     0, 0, \
0,  0,     0, 0

#define GB_PHASE \
    -8, 32, -8, 0, \
0,  32,  0, 0, \
-8, 32, -8, 0, \
0,   0,  0, 0, \
\
0,   0,  0, 0, \
0,  64,  0, 0, \
\
-8,  0, -8, 0, \
32, 32, 32, 0, \
-8, 0,  -8, 0, \
0,  0,   0, 0, \
\
0,  0,   0, 0, \
0,  0,   0, 0, \
\
-16, 32,  -16, 0, \
0,  64,    0,  0, \
-16, 32, -16,  0, \
0,  0,   0,   0, \
\
0,  0,   0,   0, \
0, 64,   0,   0, \
\
0,  0,   0,   0, \
29, 6,  29,   0, \
0,  0,   0,   0, \
0,  0,   0,   0, \
\
0,  0,   0,   0, \
0,  0,   0,   0, \
\
0, 32,   0,   0, \
0,  0,   0,   0, \
0, 32,   0,   0, \
0,  0,   0,   0, \
\
0,  0,   0,   0, \
0, 64,   0,   0, \
\
-13, 0,  -13,  0, \
32, 52,   32,  0, \
-13, 0,  -13,  0, \
0,   0,   0,   0, \
\
0,   0,   0,   0, \
0,   0,   0,    0

#define B_PHASE  \
    16, -6,    16, 0, \
6,  0,     6, 0, \
16, -6,   16, 0, \
0,   0,    0, 0, \
\
0,   16,   0, 0, \
16,   0,  16, 0, \
\
0,    0,   0, 0, \
0,   64,   0, 0, \
0,    0,   0, 0, \
0,    0,   0, 0, \
\
0,   16,   0, 0, \
0,    0,   0, 0, \
\
16, -32,  16, 0, \
32,   0,  32, 0, \
16, -32,  16, 0, \
0,    0,   0, 0, \
\
0,    0,   0, 0, \
32,   0,  32, 0, \
\
0,    0,   0, 0, \
0,   64,   0, 0, \
0,    0,   0, 0, \
0,    0,   0, 0, \
\
0,    0,   0, 0, \
0,    0,   0, 0, \
\
16, 26,   16, 0, \
-26, 0,  -26, 0, \
16, 26,   16, 0, \
0,   0,    0, 0, \
\
0,  32,    0, 0, \
0,   0,    0, 0, \
\
0,   0,    0, 0, \
0,  64,    0, 0, \
0,   0,    0, 0, \
0,   0,    0, 0, \
\
0,  32,    0, 0, \
0, 0,  0, 0

/******************************************************************************
  Data-Structures
 ******************************************************************************/
/* input image, in bayer pattern format */
extern far Uint8 prevInImage[PREV_IMAGE_HEIGHT][PREV_IMAGE_WIDTH];

/* output image, will be in YUV format */
/* make out buffer 128 bytes aligned */
#pragma DATA_ALIGN(prevOutImage, 128);
Uint32 prevOutImage[PREV_OUT_IMAGE_SIZE_IN_WORDS];

/* outimage will be distrbuted in this Y, U, V bufffers */
/* make Y buffer 128 bytes aligned */
#pragma DATA_ALIGN(prevYBuf, 128);
Uint8 prevYBuf[PREV_IMAGE_HEIGHT * PREV_IMAGE_WIDTH];
/* make U buffer 128 bytes aligned */
#pragma DATA_ALIGN(prevUBuf, 128);
Uint8 prevUBuf[PREV_IMAGE_HEIGHT * PREV_IMAGE_WIDTH / 2];
/* make V buffer 128 bytes aligned */
#pragma DATA_ALIGN(prevVBuf, 128);
Uint8 prevVBuf[PREV_IMAGE_HEIGHT * PREV_IMAGE_WIDTH / 2];

const char cfa_coef[] =
{
    GR_PHASE,
    R_PHASE,
    B_PHASE,
    GB_PHASE
};

/* previewer channel handle */
GIO_Handle prevHandle = NULL;

/* previewer device name */
String prevDeviceName = "/previewer";

/* previewer parameters */
/* make prevParams 4 bytes aligned */
#pragma DATA_ALIGN(prevParams, 4);
PSP_previewerParams prevParams;
/******************************************************************************
  Functions
 ******************************************************************************/
/**
 * \brief   prevFillParamsFirstPass
 *          This function sets the paramters for the previewer channel
 *
 */
static void prevFillParamsFirstPass()
{
    Uint32 prevFillParamsFirstPassIndex1 = 0;
    /* down sample rate */
    prevParams.downSampleRate = PSP_PREVIEWER_DOWN_SAMPLE_RATE1;
    /* Set size and pitch parameters */
    /* start horizontal pixel */
    prevParams.sizeParam.sph = 0u;
    /* end horizontal pixel */
    prevParams.sizeParam.eph = (PREV_IMAGE_WIDTH/2u) + 4 - 1; /* 4 is the crop
                                                                 size value */
    /* start vertical pixel */
    prevParams.sizeParam.slv = 0u;
    /* end vertical pixel */
    prevParams.sizeParam.elv = PREV_IMAGE_HEIGHT - 1;
    /* pixel size */
    prevParams.sizeParam.pixelSize = PSP_PREVIEWER_INWIDTH_8BIT;
    /* offset distance between two raws in input image - should be 32 bytes
     * aligned */
    prevParams.sizeParam.inPitch = PREV_IMAGE_WIDTH;
    /* offset distance between two raws in output image - should be 32 bytes
     * aligned */
    prevParams.sizeParam.outPitch = (PREV_IMAGE_WIDTH * 2u);

    /* Set white balancing parameters */
    prevParams.whiteBalanceParam.wbDgain   = 0x100;
    prevParams.whiteBalanceParam.wbGain[0] = 0x40;
    prevParams.whiteBalanceParam.wbGain[1] = 0x40;
    prevParams.whiteBalanceParam.wbGain[2] = 0x40;
    prevParams.whiteBalanceParam.wbGain[3] = 0x40;

    prevParams.whiteBalanceParam.position[0][0] = 0;
    prevParams.whiteBalanceParam.position[0][1] = 1;
    prevParams.whiteBalanceParam.position[0][2] = 0;
    prevParams.whiteBalanceParam.position[0][3] = 1;

    prevParams.whiteBalanceParam.position[1][0] = 2;
    prevParams.whiteBalanceParam.position[1][1] = 3;
    prevParams.whiteBalanceParam.position[1][2] = 2;
    prevParams.whiteBalanceParam.position[1][3] = 3;

    prevParams.whiteBalanceParam.position[2][0] = 0;
    prevParams.whiteBalanceParam.position[2][1] = 1;
    prevParams.whiteBalanceParam.position[2][2] = 0;
    prevParams.whiteBalanceParam.position[2][3] = 1;

    prevParams.whiteBalanceParam.position[3][0] = 2;
    prevParams.whiteBalanceParam.position[3][1] = 3;
    prevParams.whiteBalanceParam.position[3][2] = 2;
    prevParams.whiteBalanceParam.position[3][3] = 3;

    /* Set RGB2RGB blending parameters */
    prevParams.rgbBlendingParam.blending[0][0] = 0x1a1;
    prevParams.rgbBlendingParam.blending[0][1] = 0xf8a;
    prevParams.rgbBlendingParam.blending[0][2] = 0xfd5;
    prevParams.rgbBlendingParam.blending[1][0] = 0xfa1;
    prevParams.rgbBlendingParam.blending[1][1] = 0x1c4;
    prevParams.rgbBlendingParam.blending[1][2] = 0xf9b;
    prevParams.rgbBlendingParam.blending[2][0] = 0xfbd;
    prevParams.rgbBlendingParam.blending[2][1] = 0xfb1;
    prevParams.rgbBlendingParam.blending[2][2] = 0x192;

    prevParams.rgbBlendingParam.offset[0] = 0u;
    prevParams.rgbBlendingParam.offset[1] = 0u;
    prevParams.rgbBlendingParam.offset[2] = 0u;

    /* Set RGB2YCBCR parameters */
    prevParams.rgb2ycbcrParam.coeff[0][0] = 0x4Cu;
    prevParams.rgb2ycbcrParam.coeff[0][1] = 0x96u;
    prevParams.rgb2ycbcrParam.coeff[0][2] = 0x1Du;
    prevParams.rgb2ycbcrParam.coeff[1][0] = 0x3d4u;
    prevParams.rgb2ycbcrParam.coeff[1][1] = 0x3acu;
    prevParams.rgb2ycbcrParam.coeff[1][2] = 0x80u;
    prevParams.rgb2ycbcrParam.coeff[2][0] = 0x80u;
    prevParams.rgb2ycbcrParam.coeff[2][1] = 0x395u;
    prevParams.rgb2ycbcrParam.coeff[2][2] = 0x3ebu;

    prevParams.rgb2ycbcrParam.yOffset = 0u;
    prevParams.rgb2ycbcrParam.cbOffset = 0u;
    prevParams.rgb2ycbcrParam.crOffset = 0u;

    /* Set Black adjustment parameters */
    prevParams.blackAdjParam.blueAdj = 0;
    prevParams.blackAdjParam.redAdj = 0;
    prevParams.blackAdjParam.greenAdj =  0;

    prevParams.brightness = 0x20;
    prevParams.contrast =  0x10;

    /*CFA*/
    prevParams.features = PSP_PREVIEWER_CFA;

    for(prevFillParamsFirstPassIndex1 = 0;
        prevFillParamsFirstPassIndex1 < PSP_PREVIEWER_CFA_COEFF_TABLE_SIZE;
        prevFillParamsFirstPassIndex1++)
    {
        prevParams.cfaCoeffsParam.coeffs[prevFillParamsFirstPassIndex1]
            = cfa_coef[prevFillParamsFirstPassIndex1];
    }

    prevParams.cfaCoeffsParam.vThreshold = 0x28;
    prevParams.cfaCoeffsParam.hThreshold = 0x28;

    /* output format */
    prevParams.outPixelOrderParam = PSP_PREVIEWER_PIXELORDER_YCBYCR;
}
/**
 * \brief   prevFillParamsSecondPass
 *          This function sets the paramters for the previewer
 *          channel for the second pass
 *
 */
static void prevFillParamsSecondPass()
{
    /* start horizontal pixel */
    prevParams.sizeParam.sph = (PREV_IMAGE_WIDTH/2u);
    /* end horizontal pixel */
    prevParams.sizeParam.eph = PREV_IMAGE_WIDTH - 1;
}
/**
 * \brief   prevFormatOutput
 *          This function formats the output generated by the previwer engine
 *
 */
static void prevFormatOutput(
    Uint32 inBuffer[],
    Uint8 YBuf[],
    Uint8 CbBuf[],
    Uint8 CrBuf[],
    PSP_previewerOutPixelOrder outOrder,
    Uint32 height,
    Uint32 width,
    Uint32 outPitch
    )
{
    Uint32* tempInBuffer;
    Uint32 heightIndex;
    Uint32 widthIndex;
    Uint8 firstByte;
    Uint8 secondByte;
    Uint8 thirdByte;
    Uint8 fourthByte;
    if (((NULL != inBuffer) && (NULL != YBuf))
        && ((NULL != CbBuf) && (NULL != CrBuf)))
    {
        tempInBuffer = inBuffer;
        if (NULL != tempInBuffer)
        {
            for (heightIndex = 0; heightIndex < height;heightIndex++)
            {
                for (widthIndex = 0; widthIndex < width; widthIndex += 2)
                {
                    firstByte = (*tempInBuffer);
                    secondByte = ((*tempInBuffer) >> 8) & 0xFF;
                    thirdByte = ((*tempInBuffer) >> 16) & 0xFF;
                    fourthByte = ((*tempInBuffer) >> 24) & 0xFF;
                    tempInBuffer++;

                    switch(outOrder)
                    {
                        case PSP_PREVIEWER_PIXELORDER_YCBYCR:
                            *YBuf = secondByte;
                            YBuf++;
                            *CbBuf = thirdByte;
                            CbBuf++;
                            *CrBuf = firstByte;
                            CrBuf++;
                            *YBuf = fourthByte;
                            YBuf++;
                            break;
                        case PSP_PREVIEWER_PIXELORDER_YCRYCB:
                            *YBuf = secondByte;
                            YBuf++;
                            *CbBuf = firstByte;
                            CbBuf++;
                            *CrBuf = thirdByte;
                            CrBuf++;
                            *YBuf = fourthByte;
                            YBuf++;
                            break;
                        case  PSP_PREVIEWER_PIXELORDER_CBYCRY:
                            *YBuf = firstByte;
                            YBuf++;
                            *CbBuf = fourthByte;
                            CbBuf++;
                            *CrBuf = secondByte;
                            CrBuf++;
                            *YBuf = thirdByte;
                            YBuf++;
                            break;
                        case PSP_PREVIEWER_PIXELORDER_CRYCBY:
                            *YBuf = firstByte;
                            YBuf++;
                            *CbBuf = secondByte;
                            CbBuf++;
                            *CrBuf = fourthByte;
                            CrBuf++;
                            *YBuf = thirdByte;
                            YBuf++;
                            break;
                        default:
                            break;
                    }
                }
                while(0 != ((Uint32)YBuf & (Uint32)0x3u))
                {
                    YBuf++;
                }
                while(0 != ((Uint32)CbBuf & (Uint32)0x3u))
                {
                    CbBuf++;
                }
                while(0 != ((Uint32)CrBuf & (Uint32)0x3u))
                {
                    CrBuf++;
                }
                tempInBuffer = inBuffer + (outPitch/4u);
                inBuffer = tempInBuffer;
            }
        }
    }
}
/**
 * \brief   main
 *          Main Function
 *
 */
int main()
{
    return 0;
}
/**
 * \brief   prevMultiPassSampleTest
 *          Previwer Multipass sample test function
 *
 */
static Int32 prevMultiPassSampleTest()
{
    Int32 taskReturnCode = -1;
    PSP_previewerChannelCreateMode taskPrevChannel;
    Int32 taskIOMReturnCode = IOM_EBADMODE;
    PSP_preview taskPreviewParams;
    PSP_previewerCropSize  taskCrop;

    taskPrevChannel.chanSource.source = PSP_PREVIEWER_CHANNEL_SDRAM;
    taskPrevChannel.segId = 0;

    /* parameter validation */
    if (NULL == prevDeviceName)
    {
        taskReturnCode = -1;
    }
    else
    {
        /* open channel handle */
        prevHandle = GIO_create(prevDeviceName, IOM_INOUT, NULL,
            &taskPrevChannel, NULL);
        /* check that channel is opened properly or not */
        if (NULL == prevHandle)
        {
            taskReturnCode = -1;
        }
        else
        {
            prevFillParamsFirstPass();
            /* call IOCTL to set parameters */
            taskIOMReturnCode = GIO_control(prevHandle,
                PSP_PREVIEWER_IOCTL_SET_PARAMS, &prevParams);

            /* check that parameters are configured properly or not */
            if (IOM_COMPLETED != taskIOMReturnCode)
            {
                GIO_delete(prevHandle);
                taskReturnCode = -1;
            }
            else
            {
                /* configure previewer parameters */
                taskPreviewParams.inBuf =  prevInImage;
                taskPreviewParams.outBuf = prevOutImage;
                taskPreviewParams.inBufSize = sizeof(prevInImage);
                taskPreviewParams.outBufSize = sizeof(prevOutImage);

                /* call IOCTL to previewing image */
                taskIOMReturnCode = GIO_control(prevHandle,
                    PSP_PREVIEWER_IOCTL_PREVIEW, &taskPreviewParams);

                /* check that previewer is triggerred properly or not */
                if (IOM_COMPLETED != taskIOMReturnCode)
                {
                    GIO_delete(prevHandle);
                    taskReturnCode = -1;
                }
                else
                {
                    prevFillParamsSecondPass();
                    /* call IOCTL to set parameters */
                    taskIOMReturnCode = GIO_control(prevHandle,
                        PSP_PREVIEWER_IOCTL_SET_PARAMS, &prevParams);
                    /* check that parameters are configured properly or not */
                    if (IOM_COMPLETED != taskIOMReturnCode)
                    {
                        GIO_delete(prevHandle);
                        taskReturnCode = -1;
                    }
                    else
                    {
                        /* configure previewer parameters */
                        taskPreviewParams.inBuf =  prevInImage;
                        taskPreviewParams.outBuf = (prevOutImage +
                            (PREV_IMAGE_WIDTH/4u)); /* 4 is used as outImage
                                                       array is of Uint32 type
                                                       */
                        taskPreviewParams.inBufSize = sizeof(prevInImage);
                        taskPreviewParams.outBufSize = sizeof(prevOutImage);

                        /* call IOCTL to previewing image */
                        taskIOMReturnCode = GIO_control(prevHandle,
                            PSP_PREVIEWER_IOCTL_PREVIEW, &taskPreviewParams);
                        /* check that previewer is triggerred properly or not */
                        if (IOM_COMPLETED != taskIOMReturnCode)
                        {
                            GIO_delete(prevHandle);
                            taskReturnCode = -1;
                        }
                        else
                        {
                            /* get crop size */
                            GIO_control(prevHandle,
                                PSP_PREVIEWER_IOCTL_GET_CROPSIZE,
                                &taskCrop);

                            /* call IOCTL to set parameters */
                            taskIOMReturnCode = GIO_delete(prevHandle);

                            /* check that channel is deleted properly or not */
                            if (IOM_COMPLETED != taskIOMReturnCode)
                            {
                                taskReturnCode = -1;
                            }
                            else
                            {
                                PAL_osCacheInvalidate(
                                    (PAL_osCacheMemAddrSpace)NULL,
                                    (Uint32)prevOutImage,
                                    sizeof(prevOutImage));
                                taskReturnCode = 0;
                                prevFormatOutput(prevOutImage,
                                    prevYBuf, prevUBuf, prevVBuf,
                                    prevParams.outPixelOrderParam,
                                    PREV_IMAGE_HEIGHT - taskCrop.vCrop,
                                    PREV_IMAGE_WIDTH - taskCrop.hCrop,
                                    prevParams.sizeParam.outPitch);
                                PAL_osCacheFlushAndInvalidate(
                                    (PAL_osCacheMemAddrSpace)NULL,
                                    (Uint32)prevYBuf,
                                    sizeof(prevYBuf));
                                PAL_osCacheFlushAndInvalidate(
                                    (PAL_osCacheMemAddrSpace)NULL,
                                    (Uint32)prevUBuf,
                                    sizeof(prevUBuf));
                                PAL_osCacheFlushAndInvalidate(
                                    (PAL_osCacheMemAddrSpace)NULL,
                                    (Uint32)prevVBuf,
                                    sizeof(prevVBuf));
                                PREV_APP_PRINT(
                                    "\nPreviewer: Multipass Test Pass\n");
                            }
                        }
                    }
                }
            }
        }
    }
    return taskReturnCode;
}
/**
 * \brief   prevMultiPassSample
 *          Previewer Multipass Task Function
 *
 */
void prevMultiPassSample()
{
    Int32 returnCode = 0;
    memset(prevOutImage, 0, sizeof(prevOutImage));
    memset(prevYBuf, 0, sizeof(prevYBuf));
    memset(prevUBuf, 0, sizeof(prevUBuf));
    memset(prevVBuf, 0, sizeof(prevVBuf));

    returnCode = prevMultiPassSampleTest();
    PREV_APP_PRINT_VAL("\nPreviewer : Return Code = %d\n", returnCode);
}

