/*******************************************************************************
**+--------------------------------------------------------------------------+**
**|                            ****                                          |**
**|                            ****                                          |**
**|                            ******o***                                    |**
**|                      ********_///_****                                   |**
**|                      ***** /_//_/ ****                                   |**
**|                       ** ** (__/ ****                                    |**
**|                           *********                                      |**
**|                            ****                                          |**
**|                            ***                                           |**
**|                                                                          |**
**|         Copyright (c) 2006-2010 Texas Instruments Incorporated           |**
**|                        ALL RIGHTS RESERVED                               |**
**|                                                                          |**
**| Permission is hereby granted to licensees of Texas Instruments           |**
**| Incorporated (TI) products to use this computer program for the sole     |**
**| purpose of implementing a licensee product based on TI products.         |**
**| No other rights to reproduce, use, or disseminate this computer          |**
**| program, whether in part or in whole, are granted.                       |**
**|                                                                          |**
**| TI makes no representation or warranties with respect to the             |**
**| performance of this computer program, and specifically disclaims         |**
**| any responsibility for any damages, special or consequential,            |**
**| connected with the use of this program.                                  |**
**|                                                                          |**
**+--------------------------------------------------------------------------+**
*******************************************************************************/

/**
 *  \file   psp_bios_resz_multipass_st_example.c
 *
 *  \brief  resizer application
 *
 *  This file contains the function which is used for Demonstating 10x
 *  downscaling of the color bar image with use of multi pass.
 *
 *  (C) Copyright 2010, Texas Instruments, Inc
 *
 *  \author     EI3
 *
 *  \version    0.1     Created
 *              1.0     First Release
 */


/******************************************************************************
  Header File Inclusion
 ******************************************************************************/
#include <std.h>
#include <tsk.h>
#include <gio.h>
#include <mem.h>
#include <log.h>
#include <string.h>
#include <stdio.h>
#include <iom.h>
#include <ti/sdo/pspdrivers/drivers/resizer/psp_resizer.h>
#include <ti/sdo/pspdrivers/pal_os/bios/psputils.h>
#include <ti/sdo/pspdrivers/pal_os/pal_oscache.h>
extern far char array[];
/******************************************************************************
  Macros
 ******************************************************************************/

#define gRDRV_reszFilter4TapHighQuality  0, 256, 0, 0, -6, 246, 16, 0, -7, \
    219, 44, 0, -5, 179, 83, -1, -3, 130, 132, -3, -1, 83, 179, -5, 0, \
44, 219, -7, 0, 16, 246, -6
#define gRDRV_reszFilter7TapHighQuality -1, 19, 108, 112, 19, -1, 0, 0, \
    0, 6, 88, 126, 37, -1, 0, 0, 0, 0, 61, 134, 61, 0, 0, 0, 0, -1, 37, \
126, 88, 6, 0, 0
/* Define to specify image height and width in relevant passes */
#define INHEIGHT    (640u)
#define INWIDTH     (1280u)
#define OUTHEIGHT   (64u)
#define OUTWIDTH    (128u)
#define INTERWIDTH  (320u)
#define INTERHEIGHT (160u)

/* debug print macros */
#define RSZ_APP_PRINT          PSP_DEBUG
#define RSZ_APP_PRINT_VAL      PSP_DEBUG1

/******************************************************************************
  Globals
 ******************************************************************************/
/* Input and output buffer pointers for 2 passes */
Char *ch1_inBuf=0;
Char *ch1_outBuf=0;

Char *ch2_inBuf=0;
Char *ch2_outBuf=0;

/* Image for viewing in CCS image viewer*/
Char ycharoutput[OUTHEIGHT *OUTWIDTH];
Char cbcharoutput[OUTHEIGHT *(OUTWIDTH/(2u))];
Char crcharoutput[OUTHEIGHT *(OUTWIDTH/(2u))];


/* make Y buffer 128 bytes aligned */
#pragma DATA_ALIGN(ycharoutput, 128);
/* make Y buffer 128 bytes aligned */
#pragma DATA_ALIGN(cbcharoutput, 128);
/* make Y buffer 128 bytes aligned */
#pragma DATA_ALIGN(crcharoutput, 128);

/* Params structure for configuration of parameters for channel 1 */
static PSP_RSZparams params =
{
    INWIDTH,                        /* Input image width */
    INHEIGHT,                       /* Input image height */
    INWIDTH*(2u),                   /* Input image pitch */
    PSP_RSZ_INTYPE_YCBCR422_16BIT,  /* Input image type */
    0,                              /* Vertical starting pixel */
    0,                              /* Horizontal starting pixel */
    0,                              /* Chroma position */
    PSP_RSZ_PIX_FMT_YUYV,           /* Image format */
    INTERWIDTH,                     /* Intermediate image width */
    INTERHEIGHT,                    /* Intermediate image height */
    INTERWIDTH*(2u),                /* Intermediate image pitch */
    0,                              /* Horizontal starting phase */
    0,                              /* Vertical starting phase */
    gRDRV_reszFilter7TapHighQuality, /* Horizontal filter coefficients */
    gRDRV_reszFilter7TapHighQuality, /* Vertical filter coefficients */
    PSP_RSZ_YENH_DISABLE             /* Luma enhancement options */
};
/* Params structure for configuration of parameters for channel 2 */
static PSP_RSZparams params1 =
{
    INTERWIDTH,                     /* Input image width */
    INTERHEIGHT,                    /* Input image height */
    INTERWIDTH*(2u),                /* Input image pitch */
    PSP_RSZ_INTYPE_YCBCR422_16BIT,  /* Input image type */
    0,                              /* Horizonatl starting pixel */
    0,                              /* Vertical starting pixel */
    0,                              /* Chroma position */
    PSP_RSZ_PIX_FMT_YUYV,           /* Image format */
    OUTWIDTH,                       /* Output image width */
    OUTHEIGHT,                      /* Output image height */
    OUTWIDTH*(2u),                  /* Output image pitch */
    0,                              /* Horizontal starting phase */
    0,                              /* Vertical starting phase */
    gRDRV_reszFilter7TapHighQuality, /* Horizontal filter coefficients */
    gRDRV_reszFilter7TapHighQuality, /* Vertical filter coefficients */
    PSP_RSZ_YENH_DISABLE             /* Luma enhancement options */
};

/******************************************************************************
  Functions definition
 ******************************************************************************/

static void TakeRszInputImage();
/*Function to see output image in CCS image viewer*/
static void TakeRszOutputImage();

/*Function to notify the completion of resiing*/
Void appResizeCallbackFxn(Ptr arg, Int status, Ptr bufp, size_t size);

PSP_RSZcallback appResizeCallback;
Uint32 appResizeCallbackArg = 0;

/******************************************************************************
  Program Main
 ******************************************************************************/
/**
 * \brief   main
 *          Main Function
 *
 */
Int main()
{

    return 0;
}
/******************************************************************************
  Resizer Task Function
 ******************************************************************************/
/**
 * \brief   RSZTskFun
 *          Resizer task function
 *
 */
Int RSZTskFun()
{
    Int resizeRet =0 ;
    GIO_Handle rszfd;
    GIO_Handle rszfd1;
    GIO_Attrs gioAttrs = GIO_ATTRS;

    Int memSegId =0;
    PSP_RSZresize ch1_resize;
    PSP_RSZresize ch2_resize;

    /* error checking for pointers */
    if ((NULL == ch1_inBuf) && (NULL == ch1_outBuf))
    {
        /* Memory allocation of input and output buffers of channel 1*/

        ch1_outBuf =(Char *)MEM_alloc(0, INTERHEIGHT*INTERWIDTH*(2u), (32u));
        if (NULL == ch1_outBuf)
        {
            resizeRet = -1;
        }

    }
    if ((NULL == ch2_inBuf) && (NULL == ch2_outBuf))
    {
        /* Memory allocation of input and output buffers of channel 2*/
        ch2_inBuf = (Char *)MEM_alloc(0, INTERHEIGHT*INTERWIDTH*(2u), (32u));
        if (NULL == ch2_inBuf)
        {
            resizeRet = -1;
        }
        ch2_outBuf =(Char *)MEM_alloc(0, OUTHEIGHT*OUTWIDTH*(2u), (128u));
        if ( NULL == ch2_outBuf)
        {
            resizeRet = -1;
        }

    }

    if (-1 != resizeRet)
    {
        /* Opening resizer device for channel 1 */
        rszfd = GIO_create("/resizer", IOM_INOUT, NULL, (void *)&memSegId,
            &gioAttrs);
        if (rszfd == NULL)
        {
            RSZ_APP_PRINT("\nError opening resizer device;");
            resizeRet = -1;
        }
        if (-1 !=    resizeRet)
        {
            /* Opening resizer device for channel 2 */
            rszfd1 = GIO_create("/resizer", IOM_INOUT, NULL, (void *)&memSegId,
                &gioAttrs);
            if ((NULL == rszfd1))
            {
                RSZ_APP_PRINT("\nError opening resizer device;");
                resizeRet = -1;
            }

        }
        
        /* Register resize callback with the driver */
        appResizeCallback.fxn = &appResizeCallbackFxn;
        appResizeCallback.arg = &appResizeCallbackArg;
        
        resizeRet = GIO_control(rszfd, 
                                PSP_RSZ_IOCTL_SET_RESIZE_CALLBACK,
                                &appResizeCallback);
      
        /* Setting parameters for channel 1*/
        resizeRet = GIO_control(rszfd, PSP_RSZ_IOCTL_SET_PARAMS, &params);
        if (0 > resizeRet)
        {
            RSZ_APP_PRINT(" IOCTL failed \n");
        }
        
        /* Setting parameters for channel 2*/
        resizeRet = GIO_control(rszfd1, PSP_RSZ_IOCTL_SET_PARAMS, &params1);
        if (0 > resizeRet)
        {
            RSZ_APP_PRINT(" IOCTL failed \n");
        }
        /* Taking input image */
        TakeRszInputImage();

        ch1_resize.inBuf = ch1_inBuf;
        ch1_resize.outBuf = ch1_outBuf;
        ch1_resize.inBufSize =INHEIGHT*INWIDTH*2;
        ch1_resize.outBufSize =INTERHEIGHT*INTERWIDTH*2;

        RSZ_APP_PRINT("mem copy finished \n");

        /* resizing for first channel input */
        resizeRet = GIO_control(rszfd, PSP_RSZ_IOCTL_RESIZE_ASYNC, &ch1_resize);

        if (0 > resizeRet)
        {
            RSZ_APP_PRINT(" IOCTL failed \n");
        }
        else
        {
            while(1u != appResizeCallbackArg)
            {
                RSZ_APP_PRINT("Waiting for resizer to complete\n");
                TSK_sleep(2000);
            }
        }
        
        appResizeCallbackArg = 0;

        /* Taking output of 1 resizing to input of second resizing*/
        memcpy(ch2_inBuf, ch1_outBuf, INTERHEIGHT*INTERWIDTH*2);


        ch2_resize.inBuf = ch2_inBuf;
        ch2_resize.outBuf = ch2_outBuf;
        ch2_resize.inBufSize =INTERHEIGHT*INTERWIDTH*2;
        ch2_resize.outBufSize =OUTHEIGHT*OUTWIDTH*2;
        
        resizeRet = GIO_control(rszfd1, PSP_RSZ_IOCTL_RESIZE_ASYNC, &ch2_resize);

        if (0 > resizeRet)
        {
            RSZ_APP_PRINT(" IOCTL failed \n");
        }
        else
        {
            while(1u != appResizeCallbackArg)
            {
                RSZ_APP_PRINT("Waiting for resizer to complete\n");
                TSK_sleep(2000);
            }
        }

        RSZ_APP_PRINT("Resizing finished \n");

        /* Taking output */
        TakeRszOutputImage();

        /* Closing logical channel 1 */
        resizeRet = GIO_delete(rszfd);
        /* Closing logical channel 2 */
        resizeRet = GIO_delete(rszfd1);


        MEM_free(0, ch1_outBuf, INTERHEIGHT*INTERWIDTH*(2u));
        MEM_free(0, ch2_inBuf, INTERHEIGHT*INTERWIDTH*(2u));
        MEM_free(0, ch2_outBuf, OUTHEIGHT*OUTWIDTH*(2u));


    }
    if (0 == resizeRet)
    {
        RSZ_APP_PRINT(" \n\n Test succesful \n\n");
    }
    else
    {
        RSZ_APP_PRINT(" \n\n Test failed \n\n");
    }

    return resizeRet;
}
/**
 * \brief   appResizeCallbackFxn
 *          This function is called when the resize is done with resizing
 *
 */
Void appResizeCallbackFxn(Ptr arg, Int status, Ptr bufp, size_t size)
{
    if((NULL != bufp) && (0 != size))
    {
        bufp= bufp;
        size = size;
    }
    
    if(arg != NULL)
    {
        if(IOM_COMPLETED == status)
        {
            *((Uint32*)arg) = 1;
        }
    }
}
/**
 * \brief   TakeRszInputImage
 *          This function takes the input image from file
 *
 */
static void TakeRszInputImage()
{

    ch1_inBuf = (char *)array;
}
/**
 * \brief   TakeRszOutputImage
 *          This function splits output image to see in CCS image viewer
 *
 */
static void TakeRszOutputImage()
{

    Int i;

    PAL_osCacheInvalidate((PAL_osCacheMemAddrSpace)NULL, (Uint32)ch2_outBuf,
        OUTHEIGHT*OUTWIDTH*(2u));
    /* taking the output image */
    for (i=0; i<(OUTHEIGHT*(OUTWIDTH/(2u))); i++)
    {

        crcharoutput[i] = *ch2_outBuf;
        ch2_outBuf++;
        ycharoutput[(i*2)] = *ch2_outBuf;
        ch2_outBuf++;
        cbcharoutput[i] = *ch2_outBuf;
        ch2_outBuf++;
        ycharoutput[(i*2)+1] = *ch2_outBuf;
        ch2_outBuf++;
    }

    PAL_osCacheFlushAndInvalidate((PAL_osCacheMemAddrSpace)NULL,
        (Uint32)ycharoutput, OUTHEIGHT*OUTWIDTH);
    PAL_osCacheFlushAndInvalidate((PAL_osCacheMemAddrSpace)NULL,
        (Uint32)cbcharoutput, (OUTHEIGHT *(OUTWIDTH/(2u))));
    PAL_osCacheFlushAndInvalidate((PAL_osCacheMemAddrSpace)NULL,
        (Uint32)crcharoutput, (OUTHEIGHT *(OUTWIDTH/(2u))));
}

