/*******************************************************************************
**+--------------------------------------------------------------------------+**
**|                            ****                                          |**
**|                            ****                                          |**
**|                            ******o***                                    |**
**|                      ********_///_****                                   |**
**|                      ***** /_//_/ ****                                   |**
**|                       ** ** (__/ ****                                    |**
**|                           *********                                      |**
**|                            ****                                          |**
**|                            ***                                           |**
**|                                                                          |**
**|         Copyright (c) 2006-2010 Texas Instruments Incorporated           |**
**|                        ALL RIGHTS RESERVED                               |**
**|                                                                          |**
**| Permission is hereby granted to licensees of Texas Instruments           |**
**| Incorporated (TI) products to use this computer program for the sole     |**
**| purpose of implementing a licensee product based on TI products.         |**
**| No other rights to reproduce, use, or disseminate this computer          |**
**| program, whether in part or in whole, are granted.                       |**
**|                                                                          |**
**| TI makes no representation or warranties with respect to the             |**
**| performance of this computer program, and specifically disclaims         |**
**| any responsibility for any damages, special or consequential,            |**
**| connected with the use of this program.                                  |**
**|                                                                          |**
**+--------------------------------------------------------------------------+**
*******************************************************************************/
/** \file   psp_bios_vpfe_st_on_the_fly_sample.c
 *
 *  \brief  This file contains the test / demo code to demonstrate the
 *          VPSS driver implemented using the GIO Framework Architecture
 *
 *          This test application does the loopback Application.Here CCDC and
 *          previewer is configured in on-the-fly mode. CCDC driver capture Raw
 *          image and give it to Previewer which converts the RAW image into
 *          YUV. Previewer gives output YUV image to Video Back End driver to
 *          display image on display Screen.
 *
 *  (C) Copyright 2010, Texas Instruments, Inc
 *
 *  \author     Maulik Desai
 *
 *  \version    0.1     Created
 */

/*******************************************************************************
  HEADER FILE INCLUSION
 ******************************************************************************/
#include <stdio.h>
#include <std.h>
#include <gio.h>
#include <ti/sdo/pspdrivers/pal_sys/dm6437/pal_sys.h>
#include <ti/sdo/pspdrivers/soc/dm6437/dsp/cslr_sys.h>
#include <ti/sdo/pspdrivers/soc/dm6437/dsp/soc.h>
#include <ti/sdo/pspdrivers/drivers/vpfe/psp_vpfe.h>
#include <ti/sdo/pspdrivers/drivers/previewer/psp_previewer.h>
#include <ti/sdo/pspdrivers/drivers/vpbe/psp_vpbe.h>
#include <ti/sdo/pspdrivers/pal_os/bios/psputils.h>
#include <ti/sdo/pspdrivers/system/dm6437/bios/evmDM6437/video/fvid.h>
#include <ti/sdo/pspdrivers/system/dm6437/bios/evmDM6437/video/fvid_evmDM6437.h>
#include <ti/sdo/pspdrivers/common/psp_common.h>
#include <ti/sdo/pspdrivers/system/dm6437/bios/evmDM6437/video/sample/psp_bios_vpfe_st_on_the_fly_sample.h>
#include <ti/sdo/pspdrivers/system/dm6437/bios/evmDM6437/video/src/MT9001_extImageSensor.h>

/*******************************************************************************
  EXTERN PARAMETERS
 ******************************************************************************/
extern Int      DDR2;

/*******************************************************************************
  MACROS DEFINED
 ******************************************************************************/
#define NO_OF_BUFFERS   (3u)
/* debug print macro */
#define PREV_APP_PRINT          PSP_DEBUG

/*******************************************************************************
  STATIC PARAMETERS
 ******************************************************************************/
static const char cfa_coef[] =
{
    GR_PHASE,
    R_PHASE,
    B_PHASE,
    GB_PHASE
};

#ifdef PSP_VIDEO_PATH_ENABLE

static FVID_Frame           *allocatedFrameBuffers[NO_OF_BUFFERS];
static PSP_previewerParams  PrevConfigParams;

static GIO_Handle           ccdcHandle = NULL;
static GIO_Handle           PrevHandle = NULL;
static GIO_Handle           vid0Handle = NULL;
static GIO_Handle           vencHandle = NULL;

static PSP_VPFECcdcConfigParams ccdcParams =
{
    FVID_CCDC_RAW_FORMAT,               /* dataFlow     */
    FVID_FIELD_MODE,                    /* ffMode       */
    FRAME_HEIGHT + 1,                   /* height       */
    FRAME_WIDTH,                        /* width        */
    (FRAME_WIDTH * 1),                  /* pitch        */
    0,                                  /* horzStartPix */
    0,                                  /* vertStartPix */
    NULL,                               /* appCallback  */
    {
        MT9001_Open,                    /* extVD Fxn    */
        MT9001_Close,
        MT9001_Control,
    },
    0,                                  /*segId         */
    {
        FVID_BPP_BITS8,                 /* dataSize     */
        PSP_VPFE_PACK8_8BITS_PIXEL,     /* pack8        */
        PSP_VPFE_DataPol_Normal,        /* dataPol      */
        PSP_VPFE_SyncPol_Positive,      /* VDSyncPol    */
        PSP_VPFE_SyncPol_Positive,      /* HDSyncPol    */
        PSP_VPFE_SyncDir_Input,         /* HDVDMaster   */
        50,                             /* HDSyncWidth  */
        4,                              /* VDSyncWidth  */
        800,                            /* numPxlPerLine*/
        1000,                           /* numLinPerFld */
        PSP_VPFE_ALaw_Disable,          /* ALawEnable   */
        PSP_VPFE_ALaw_bits15_6,         /* ALaw_Width   */
    }
};

static PSP_VPBEVencConfigParams vencParams =
{
    PSP_VPBE_DISPLAY_NTSC_INTERLACED_COMPOSITE /* Display Standard */
};

/* Vide0 0 Plane Configuration Parameter */
static PSP_VPBEOsdConfigParams  vid0Params =
{
    FVID_FRAME_MODE,                    /* ffmode       */
    FVID_BPP_BITS16,                    /* bitsPerPixel */
    FVID_YCbCr422_INTERLEAVED,          /* colorFormat  */
    (FRAME_WIDTH *  (16/8u)),           /* pitch        */
    0,                                  /* leftMargin   */
    0,                                  /* topMargin    */
    FRAME_WIDTH,                        /* width        */
    FRAME_HEIGHT,                       /* height       */
    0,                                  /* segId        */
    PSP_VPBE_ZOOM_IDENTITY,             /* hScaling     */
    PSP_VPBE_ZOOM_IDENTITY,             /* vScaling     */
    PSP_VPBE_EXP_IDENTITY,              /* hExpansion   */
    PSP_VPBE_EXP_IDENTITY,              /* vExpansion   */
    NULL                                /* appCallback  */

};

static MT9001_StandardFormat stdFormat;

#endif  /* #ifdef PSP_VIDEO_PATH_ENABLE */

static CSL_SysRegsOvly sysModuleRegs = (CSL_SysRegsOvly )CSL_SYS_0_REGS;

/*******************************************************************************
  FUNCTIONS
 ******************************************************************************/
/**
 * \brief   I2C_INIT
 *          This function is used to Initialize the I2C Bus Driver
 *
 */
void I2C_INIT()
{
    /*Power On I2C*/
    if (PAL_SOK !=
        PAL_sysModuleClkCtrl(PAL_SYS_CLK_MODULE_I2C, PAL_SYS_MODULE_CLK_ENABLE))
    {
        return;
    }
}

#ifdef PSP_VIDEO_PATH_ENABLE

static void closeHandle()
{
    if (NULL != ccdcHandle)
    {
        FVID_delete(ccdcHandle);
        ccdcHandle = NULL;
    }
    if (NULL != PrevHandle)
    {
        GIO_delete(PrevHandle);
        PrevHandle = NULL;
    }
    if (NULL != vid0Handle)
    {
        FVID_delete(vid0Handle);
        vid0Handle = NULL;
    }
    if (NULL != vencHandle)
    {
        FVID_delete(vencHandle);
        vencHandle = NULL;
    }
}

#endif  /* #ifdef PSP_VIDEO_PATH_ENABLE */

/**
 * \brief   GetPreviewerParams
 *          This function gets the previewer configuration parameters into it's
 *          parameter structure.
 *
 */
void GetPreviewerParams(PSP_previewerParams * PrevParams)
{
    Uint32 i = 0;

    PrevParams->downSampleRate =  PSP_PREVIEWER_DOWN_SAMPLE_RATE1;

    PrevParams->features       =  PSP_PREVIEWER_CFA;

    for(i = 0; i < PSP_PREVIEWER_CFA_COEFF_TABLE_SIZE; i++)
    {
        PrevParams->cfaCoeffsParam.coeffs[i] = cfa_coef[i];
    }

    PrevParams->cfaCoeffsParam.vThreshold = 0x28;
    PrevParams->cfaCoeffsParam.hThreshold = 0x28;

    PrevParams->sizeParam.sph   = 2;
    PrevParams->sizeParam.eph   = (FRAME_WIDTH - 2 - 1);
    PrevParams->sizeParam.slv   = 0;
    PrevParams->sizeParam.elv   = (FRAME_HEIGHT - 1);
    PrevParams->sizeParam.pixelSize = PSP_PREVIEWER_INWIDTH_8BIT;
    PrevParams->sizeParam.outPitch = (FRAME_WIDTH) * (16/8u);

    PrevParams->whiteBalanceParam.wbDgain   = 0x100;
    PrevParams->whiteBalanceParam.wbGain[0] = 0x40;
    PrevParams->whiteBalanceParam.wbGain[1] = 0x40;
    PrevParams->whiteBalanceParam.wbGain[2] = 0x40;
    PrevParams->whiteBalanceParam.wbGain[3] = 0x40;

    PrevParams->whiteBalanceParam.position[0][0] = 0;
    PrevParams->whiteBalanceParam.position[0][1] = 1;
    PrevParams->whiteBalanceParam.position[0][2] = 0;
    PrevParams->whiteBalanceParam.position[0][3] = 1;

    PrevParams->whiteBalanceParam.position[1][0] = 2;
    PrevParams->whiteBalanceParam.position[1][1] = 3;
    PrevParams->whiteBalanceParam.position[1][2] = 2;
    PrevParams->whiteBalanceParam.position[1][3] = 3;

    PrevParams->whiteBalanceParam.position[2][0] = 0;
    PrevParams->whiteBalanceParam.position[2][1] = 1;
    PrevParams->whiteBalanceParam.position[2][2] = 0;
    PrevParams->whiteBalanceParam.position[2][3] = 1;

    PrevParams->whiteBalanceParam.position[3][0] = 2;
    PrevParams->whiteBalanceParam.position[3][1] = 3;
    PrevParams->whiteBalanceParam.position[3][2] = 2;
    PrevParams->whiteBalanceParam.position[3][3] = 3;

    PrevParams->rgbBlendingParam.blending[0][0] = 0x1a1;
    PrevParams->rgbBlendingParam.blending[0][1] = 0xf8a;
    PrevParams->rgbBlendingParam.blending[0][2] = 0xfd5;
    PrevParams->rgbBlendingParam.blending[1][0] = 0xfa1;
    PrevParams->rgbBlendingParam.blending[1][1] = 0x1c4;
    PrevParams->rgbBlendingParam.blending[1][2] = 0xf9b;
    PrevParams->rgbBlendingParam.blending[2][0] = 0xfbd;
    PrevParams->rgbBlendingParam.blending[2][1] = 0xfb1;
    PrevParams->rgbBlendingParam.blending[2][2] = 0x192;

    PrevParams->rgbBlendingParam.offset[0] = 0;
    PrevParams->rgbBlendingParam.offset[1] = 0;
    PrevParams->rgbBlendingParam.offset[2] = 0;

    PrevParams->rgb2ycbcrParam.coeff[0][0] = 0x4C;
    PrevParams->rgb2ycbcrParam.coeff[0][1] = 0x96;
    PrevParams->rgb2ycbcrParam.coeff[0][2] = 0x1D;
    PrevParams->rgb2ycbcrParam.coeff[1][0] = 0x3d4;
    PrevParams->rgb2ycbcrParam.coeff[1][1] = 0x3ac;
    PrevParams->rgb2ycbcrParam.coeff[1][2] = 0x82;
    PrevParams->rgb2ycbcrParam.coeff[2][0] = 0x82;
    PrevParams->rgb2ycbcrParam.coeff[2][1] = 0x395;
    PrevParams->rgb2ycbcrParam.coeff[2][2] = 0x3eb;
    PrevParams->rgb2ycbcrParam.yOffset     = 0;
    PrevParams->rgb2ycbcrParam.cbOffset    = 0;
    PrevParams->rgb2ycbcrParam.crOffset    = 0;

    PrevParams->blackAdjParam.blueAdj      = 0;
    PrevParams->blackAdjParam.redAdj       = 0;
    PrevParams->blackAdjParam.greenAdj     = 0;

    PrevParams->brightness = 0x20u;
    PrevParams->contrast   = 0x10u;

    PrevParams->outPixelOrderParam = PSP_PREVIEWER_PIXELORDER_YCRYCB;
}

/**
 * \brief   vpss_main
 *
 */
static void vpss_main()
{
#ifndef PSP_VIDEO_PATH_ENABLE
    PREV_APP_PRINT("\nError: Video port path is not enable in VPFE.\n");
#else
    Uint32 i = 0, j = 0;
    Uint8 firstByte;
    Uint8 secondByte;
    Uint8 thirdByte;
    Uint8 fourthByte;
    GIO_Attrs gioAttrs              = GIO_ATTRS;
    FVID_Frame *ptrSP    = NULL;
    FVID_Frame *FBAddr   = NULL;
    Ptr                   ptrFB     = NULL;
    PSP_previewerChannelCreateMode  prevChannel;
    PSP_VPBEChannelParams           beinitParams;
    PSP_VPFEChannelParams           feinitParams;

    Uint32 NumOfIterations  = 1000;
    PREV_APP_PRINT("VPSS: Start of CCDC on-the-fly Application\r\n");

    /* Allocate Memory to Buffers */
    for(i = 0; i < NO_OF_BUFFERS; i++)
    {
        ptrSP = MEM_alloc(DDR2, sizeof(FVID_Frame) , 32u);
        if (NULL!=ptrSP)
        {
            ptrFB = MEM_alloc(DDR2,
                ((FRAME_WIDTH * FRAME_HEIGHT)* 2), 32u);
            if (NULL!=ptrFB)
            {
                ptrSP->pitch            =  (FRAME_WIDTH * 2);
                ptrSP->lines            =  FRAME_HEIGHT;
                ptrSP->bpp              =  FVID_BPP_BITS8;
                ptrSP->frame.frameBufferPtr   =  ptrFB;
            }
        }
        allocatedFrameBuffers[i]    = ptrSP;
    }

    /* Create Previewer Channel */
    prevChannel.chanSource.source = PSP_PREVIEWER_CHANNEL_CCDC;
    prevChannel.segId = 0;
    PrevHandle = GIO_create("/previewer", IOM_INOUT, NULL, &prevChannel,
        &gioAttrs);
    if (NULL == PrevHandle)
    {
        PREV_APP_PRINT("VPSS  :Previewer Create........Failed !\r\n");
        PREV_APP_PRINT("VPSS  :End of VPSS Loopback Application\r\n");
        closeHandle();
        return;
    }
    else
    {
        GetPreviewerParams(&PrevConfigParams);
        if (IOM_COMPLETED != GIO_control(
                PrevHandle, PSP_PREVIEWER_IOCTL_SET_PARAMS, &PrevConfigParams))
        {
            PREV_APP_PRINT("VPSS  :Error in Previewer SET PARAMS IOCTL  !\r\n");
        }
    }
    /* initialize all buffer to black color Y, U, V = 0x00, 0x80, 0x80 */
    switch(PrevConfigParams.outPixelOrderParam)
    {
        case PSP_PREVIEWER_PIXELORDER_YCBYCR:
            firstByte  = 0x80;  /* Cr Value */
            secondByte = 0x0;   /* Y value */
            thirdByte  = 0x80;  /* Cb Value */
            fourthByte = 0x0;   /* Y value */
            break;
        case PSP_PREVIEWER_PIXELORDER_YCRYCB:
            firstByte  = 0x80;  /* Cb Value */
            secondByte = 0x0;   /* Y value */
            thirdByte  = 0x80;  /* Cr Value */
            fourthByte = 0x0;   /* Y value */
            break;
        case  PSP_PREVIEWER_PIXELORDER_CBYCRY:
            firstByte  = 0x0;   /* Y Value */
            secondByte = 0x80;  /* Cr value */
            thirdByte  = 0x0;   /* Y Value */
            fourthByte = 0x80;  /* Cb value */
            break;
        case PSP_PREVIEWER_PIXELORDER_CRYCBY:
            firstByte  = 0x0;   /* Y Value */
            secondByte = 0x80;  /* Cb value */
            thirdByte  = 0x0;   /* Y Value */
            fourthByte = 0x80;  /* Cr value */
            break;
    }
    for(i = 0; i < NO_OF_BUFFERS; i++)
    {
        ptrFB = allocatedFrameBuffers[i]->frame.frameBufferPtr;
        for(j=0;j < (FRAME_WIDTH * FRAME_HEIGHT)* 2;)
        {
            *((Uint8*)ptrFB+j) = firstByte;
            j++;
            *((Uint8*)ptrFB+j) = secondByte;
            j++;
            *((Uint8*)ptrFB+j) = thirdByte;
            j++;
            *((Uint8*)ptrFB+j) = fourthByte;
            j++;
        }
    }

    /* Create CCDC Channel */
    feinitParams.id = PSP_VPFE_CCDC;
    feinitParams.params = (PSP_VPFECcdcConfigParams*)&ccdcParams;
    ccdcHandle =
        FVID_create("/VPFE0", IOM_INOUT, NULL, &feinitParams, &gioAttrs);
    if (NULL == ccdcHandle)
    {
        PREV_APP_PRINT("VPSS  :CCDC Create.......FAILED \r\n");
        PREV_APP_PRINT("VPSS  :End of VPSS Loopback Application\r\n");
        closeHandle();
        return;
    }

    stdFormat = MT9T001_MODE_VGA_30FPS;
    if (IOM_COMPLETED != FVID_control(ccdcHandle,
            VPFE_ExtVD_BASE+PSP_VPSS_EXT_VIDEO_DECODER_STD_FORMAT,
            &stdFormat))
    {
        PREV_APP_PRINT("VPSS  :MT9001.......FAILED \r\n");
        PREV_APP_PRINT("VPSS  :End of VPSS Loopback Application\r\n");
        closeHandle();
        return;
    }

    FBAddr = allocatedFrameBuffers[0];
    if (NULL!= FBAddr)
    {
        if (IOM_COMPLETED != FVID_queue(ccdcHandle, FBAddr))
        {
            PREV_APP_PRINT("VPSS  :CCDC Queuing.......FAILED \r\n");
        }
    }

    /* Create VIDEO Channel */
    beinitParams.id = PSP_VPBE_VIDEO_0;
    beinitParams.params = (Ptr)(&vid0Params);

    vid0Handle =
        FVID_create("/VPBE0", IOM_INOUT, NULL, &beinitParams, &gioAttrs);
    if (NULL == vid0Handle)
    {
        PREV_APP_PRINT("VPSS  :VIDE0 -0 Create.......FAILED \r\n");
        PREV_APP_PRINT("VPSS  :End of VPSS Loopback Application\r\n");
        closeHandle();
        return;
    }
    FBAddr = allocatedFrameBuffers[1];
    if (NULL!= FBAddr)
    {
        if (IOM_COMPLETED != FVID_queue(vid0Handle, FBAddr))
        {
            PREV_APP_PRINT("VPSS  :Video 0 Queuing.......FAILED \r\n");
        }
    }

    /* Create VENC Channel */
    beinitParams.id = PSP_VPBE_VENC;
    beinitParams.params = (PSP_VPBEVencConfigParams *)&vencParams;
    vencHandle =
        FVID_create("/VPBE0", IOM_INOUT, NULL, &beinitParams, &gioAttrs);
    if (NULL == vencHandle)
    {
        PREV_APP_PRINT("VPSS  :Venc Create ... FAILED!\r\n");
        PREV_APP_PRINT("VPSS  :End of VPSS Loopback Application\r\n");
        closeHandle();
        return;
    }

    PREV_APP_PRINT("VPSS  :VPSS Loopback Started \r\n");

    FBAddr = allocatedFrameBuffers[2];
    for(i = 0; i < NumOfIterations; i++)
    {
        if (IOM_COMPLETED != FVID_exchange(ccdcHandle, &FBAddr))
        {
            PREV_APP_PRINT("VPSS: Error in CCDC Exchange\r\n");
        }
        if (IOM_COMPLETED != FVID_exchange(vid0Handle, &FBAddr))
        {
            PREV_APP_PRINT("VPSS: Error in Video 0 Exchange\r\n");
        }
    }
    PREV_APP_PRINT("VPSS  :End of VPSS Loopback \r\n");

    /* End of loopback */
    closeHandle();

    for(i = 0; i < NO_OF_BUFFERS; i++)
    {
        MEM_free(
            DDR2, allocatedFrameBuffers[i]->frame.frameBufferPtr,
            ((FRAME_WIDTH * FRAME_HEIGHT)* 2));
        allocatedFrameBuffers[i]->frame.frameBufferPtr = NULL;
        MEM_free(DDR2, allocatedFrameBuffers[i], sizeof(FVID_Frame));
        allocatedFrameBuffers[i] = NULL;
    }
    PREV_APP_PRINT("VPSS: End of CCDC on-the-fly Application\r\n");
#endif /* PSP_VIDEO_PATH_ENABLE */
}

/**
 * \brief   Task Function will test On the Fly functionality
 *
 */
void start_vpss_test()
{
    /* VPSS PinMuxing */
    /* CI10SEL   - No CI[1:0]                       */
    /* CI32SEL   - No CI[3:2]                       */
    /* CI54SEL   - No CI[5:4]                       */
    /* CI76SEL   - No CI[7:6]                       */
    /* CFLDSEL   - No C_FIELD                       */
    /* CWENSEL   - No C_WEN                         */
    /* HDVSEL    - CCDC HD and VD enabled           */
    /* CCDCSEL   - CCDC PCLK, YI[7:0] enabled       */
    /* AEAW      - EMIFA full address mode          */
    /* VPBECKEN  - VPBECLK enabled                  */
    /* RGBSEL    - No digital outputs               */
    /* CS3SEL    - LCD_OE/EM_CS3 disabled           */
    /* CS4SEL    - CS4/VSYNC enabled                */
    /* CS5SEL    - CS5/HSYNC enabled                */
    /* VENCSEL   - VCLK, YOUT[7:0], COUT[7:0] enabled */
    /* AEM       - 8bEMIF + 8bCCDC + 8 to 16bVENC   */
    sysModuleRegs -> PINMUX0    &= (0x005482A3u);
    sysModuleRegs -> PINMUX0    |= (0x005482A3u);

    /* PCIEN    =   0: PINMUX1 - Bit 0 */
    sysModuleRegs -> PINMUX1 &= (0xFFFFFFFEu);

    sysModuleRegs -> VPSS_CLKCTL = (0x18u);

    /* Run the VPSS Loopback Application */
    vpss_main();
    return;
}

/**
 * \brief   main
 *
 */
Int main()
{
    return 0;
}

