/*******************************************************************************
**+--------------------------------------------------------------------------+**
**|                            ****                                          |**
**|                            ****                                          |**
**|                            ******o***                                    |**
**|                      ********_///_****                                   |**
**|                      ***** /_//_/ ****                                   |**
**|                       ** ** (__/ ****                                    |**
**|                           *********                                      |**
**|                            ****                                          |**
**|                            ***                                           |**
**|                                                                          |**
**|         Copyright (c) 2006-2010 Texas Instruments Incorporated           |**
**|                        ALL RIGHTS RESERVED                               |**
**|                                                                          |**
**| Permission is hereby granted to licensees of Texas Instruments           |**
**| Incorporated (TI) products to use this computer program for the sole     |**
**| purpose of implementing a licensee product based on TI products.         |**
**| No other rights to reproduce, use, or disseminate this computer          |**
**| program, whether in part or in whole, are granted.                       |**
**|                                                                          |**
**| TI makes no representation or warranties with respect to the             |**
**| performance of this computer program, and specifically disclaims         |**
**| any responsibility for any damages, special or consequential,            |**
**| connected with the use of this program.                                  |**
**|                                                                          |**
**+--------------------------------------------------------------------------+**
*******************************************************************************/
/** \file   psp_bios_vpss_rawloopback_sample.c
 *
 *  \brief  This file contains the test / demo code to demonstrate the
 *          VPSS driver implemented using the GIO Framework Architecture
 *
 *          This file test the VPSS Front End and Back End Driver.It performs
 *          loopback application.It captures Image from Image Sensor and gives
 *          to CCDC driver which gives it to Video Backend.Here Front End and
 *          Back End Driver work simulanteously.
 *
 *  (C) Copyright 2010, Texas Instruments, Inc
 *
 *  \author     Maulik Desai
 *
 *  \version    0.1     Created
 */
/****************************************************************************
                HEADER FILE INCLUSION
*****************************************************************************/
#include <std.h>
#include <tsk.h>
#include <gio.h>
#include <bcache.h>

#include <ti/sdo/pspdrivers/system/dm6437/bios/evmDM6437/video/fvid.h>
#include <ti/sdo/pspdrivers/system/dm6437/bios/evmDM6437/video/fvid_evmDM6437.h>
#include <ti/sdo/pspdrivers/drivers/vpfe/psp_vpfe.h>
#include <ti/sdo/pspdrivers/drivers/vpbe/psp_vpbe.h>
#include <ti/sdo/pspdrivers/pal_os/bios/psputils.h>

extern Int      DDR2;
/****************************************************************************
                MACROS DEFINED
*****************************************************************************/
#define VPSS_DBG            PSP_DEBUG
#define NO_OF_BUFFERS       (4u)

static FVID_Frame *CcdcallocFB[NO_OF_BUFFERS]={NULL,NULL};
static FVID_Frame *VidallocFB = NULL;
static FVID_Frame *OsdallocFB[NO_OF_BUFFERS] = {NULL,NULL};
GIO_Handle  Osd0Handle;
GIO_Handle  Vid0Handle;
GIO_Handle  CcdcHandle;
GIO_Handle  VencHandle;
Uint32      count = 0;
/*Field Mode -Progressive Mode */
static PSP_VPFECcdcConfigParams ccdcParams =
{
    FVID_CCDC_RAW_FORMAT,               /* dataFlow     */
    FVID_FIELD_MODE,                    /* ffMode       */
    480,                                /* height       */
    720,                                /* width        */
    (720 *2),                           /* pitch        */
    0,                                  /* horzStartPix */
    0,                                  /* vertStartPix */
    NULL,                               /* appCallback  */
    {
        NULL,                           /* extVD Fxn    */
        NULL,
        NULL,
    },
    0,                                  /*segId         */
    {
        PSP_VPFE_BITS16,                /* dataSize     */
        PSP_VPFE_PACK8_16BITS_PIXEL,    /* pack8        */
        PSP_VPFE_DataPol_Normal,        /* dataPol      */
        PSP_VPFE_SyncPol_Positive,      /* VDSyncPol    */
        PSP_VPFE_SyncPol_Positive,      /* HDSyncPol    */
        PSP_VPFE_SyncDir_Input,         /* HDVDMaster   */
        50,                             /* HDSyncWidth  */
        4,                              /* VDSyncWidth  */
        800,                            /* numPxlPerLine*/
        1000,                           /* numLinPerFld */
        PSP_VPFE_ALaw_Disable,          /* ALawEnable   */
        PSP_VPFE_ALaw_bits15_6,         /* ALaw_Width   */
    }
};

static PSP_VPFECCDC_BlackAdj blackadj =
{
    PSP_VPFE_BlkCompDisable,            /* clampEn      */
    PSP_VPFE_BlkComp1Pixel,             /* blackSampLen */
    PSP_VPFE_BlkComp1Pixel,             /* blackSampLine*/
    0,                                  /* blackPixStart*/
    0,                                  /* blackGain    */
    0,                                  /* dcSub        */
    0,                                  /* colPtn       */
    0,                                  /* blkCmpR      */
    0,                                  /* blkCmpGR     */
    0,                                  /* blkCmpGB     */
    0                                   /* blkCmpB      */
};

static PSP_VPBEOsdConfigParams  vid0Params =
{
    FVID_FRAME_MODE,                    /* ffmode       */
    FVID_BPP_BITS16,                    /* bitsPerPixel */
    FVID_YCbCr422_INTERLEAVED,          /* colorFormat  */
    (720 *  (16/8u)),                   /* pitch        */
    0,                                  /* leftMargin   */
    0,                                  /* topMargin    */
    720,                                /* width        */
    480,                                /* height       */
    0,                                  /* segId        */
    PSP_VPBE_ZOOM_IDENTITY,             /* hScaling     */
    PSP_VPBE_ZOOM_IDENTITY,             /* vScaling     */
    PSP_VPBE_EXP_IDENTITY,              /* hExpansion   */
    PSP_VPBE_EXP_IDENTITY,              /* vExpansion   */
    NULL                                /* appCallback  */

};

static PSP_VPBEVencConfigParams vencParams =
{
    PSP_VPBE_DISPLAY_NTSC_INTERLACED_COMPOSITE /* Display Standard */
};

static PSP_VPBEOsdConfigParams  osd0Params =
{
    FVID_FRAME_MODE,                    /* ffmode       */
    FVID_BPP_BITS16,                    /* bitsPerPixel */
    FVID_RGB565_INTERLEAVED,            /* colorFormat  */
    (720 *  (16/8u)),                   /* pitch        */
    0,                                  /* leftMargin   */
    0,                                  /* topMargin    */
    720,                                /* width        */
    480,                                /* height       */
    0,                                  /* segId        */
    PSP_VPBE_ZOOM_IDENTITY,             /* hScaling     */
    PSP_VPBE_ZOOM_IDENTITY,             /* vScaling     */
    PSP_VPBE_EXP_IDENTITY,              /* hExpansion   */
    PSP_VPBE_EXP_IDENTITY,              /* vExpansion   */
    NULL,                               /* appCallback  */
    PSP_VPBE_BLEND7                     /* blending     */
};

static void vpss_main()
{
    PSP_VPBEChannelParams   beinitParams;
    PSP_VPFEChannelParams   feinitParams;
    GIO_Attrs               gioAttrs = GIO_ATTRS;
    FVID_Frame * FBAddr   = NULL;
    Uint32 NumOfIterations  = 500;
    Uint16 *l_ptr_short   = NULL;
    Uint16  grayvalue     = 0;
    Uint32  i = 0;
    Uint32 j=0;

    VPSS_DBG("VPSS: Raw Capture Loopback Application Started \r\n");
    /**
     * Create Ccdc Channel
    **/
    feinitParams.id         = PSP_VPFE_CCDC;
    feinitParams.params     = (PSP_VPFECcdcConfigParams*)&ccdcParams;
    CcdcHandle              = FVID_create("/VPFE0",IOM_INOUT,NULL,&feinitParams,&gioAttrs);
    if(NULL == CcdcHandle)
    {
        VPSS_DBG("VPSS  :CCDC Create.......FAILED \r\n");
        VPSS_DBG("VPSS  :End of VPSS Loopback Application\r\n");
        return;
    }
    else
    {
        for(i=0;i<NO_OF_BUFFERS;i++)
        {
            if(IOM_COMPLETED == FVID_allocBuffer(CcdcHandle,&CcdcallocFB[i]))
            {
                if(IOM_COMPLETED != FVID_queue(CcdcHandle,CcdcallocFB[i]))
                {
                    VPSS_DBG("VPSS  :CCdC Queuing.......FAILED \r\n");
                }
            }
        }
    }
    if(IOM_COMPLETED !=FVID_control(CcdcHandle,PSP_VPFE_IOCTL_CCDC_BLACK_ADJUST,&blackadj))
    {
        VPSS_DBG("VPSS  :Error in IOCTL  !\r\n");
    }
    /**
     * Create Video Channel
    **/
    beinitParams.id         = PSP_VPBE_VIDEO_0;
    beinitParams.params     = (PSP_VPBEOsdConfigParams  *)&vid0Params;
    Vid0Handle              = FVID_create("/VPBE0",IOM_INOUT,NULL,&beinitParams,&gioAttrs);
    if(NULL == Vid0Handle)
    {
        VPSS_DBG("VPSS  :VIDE0 -0 Create.......FAILED \r\n");
        VPSS_DBG("VPSS  :End of VPSS Loopback Application\r\n");
        return;
    }

    else
    {
        if(IOM_COMPLETED == FVID_allocBuffer(Vid0Handle,&VidallocFB))
        {
            if(IOM_COMPLETED != FVID_queue(Vid0Handle,VidallocFB))
            {
                VPSS_DBG("VPSS  :Video 0 Queuing.......FAILED \r\n");
            }
        }

    }

    /**
     * Create OSD-0 Channel
    **/

    beinitParams.id         = PSP_VPBE_OSD_0;
    beinitParams.params     = (PSP_VPBEOsdConfigParams  *)&osd0Params;
    Osd0Handle              = FVID_create("/VPBE0",IOM_INOUT,NULL,&beinitParams,&gioAttrs);
    if(NULL == Osd0Handle)
    {
        VPSS_DBG("VPSS  :OSD -0 Create.......FAILED \r\n");
        VPSS_DBG("VPSS  :End of VPSS Loopback Application\r\n");
        return;
    }
    else
    {
        for(i=0;i<NO_OF_BUFFERS;i++)
        {
            if(IOM_COMPLETED == FVID_allocBuffer(Osd0Handle,&OsdallocFB[i]))
            {
                if(IOM_COMPLETED != FVID_queue(Osd0Handle,OsdallocFB[i]))
                {
                    VPSS_DBG("VPSS  :OSD 0 Queuing.......FAILED \r\n");
                }
            }
        }
    }

    /**
     * Create Venc Channel
    **/
    beinitParams.id         = PSP_VPBE_VENC;
    beinitParams.params     = (PSP_VPBEVencConfigParams *)&vencParams;
    VencHandle              = FVID_create("/VPBE0",IOM_INOUT,NULL,&beinitParams,&gioAttrs);
    if (NULL == VencHandle)
    {
        VPSS_DBG("VPSS  :Venc Create ... FAILED!\r\n");
        VPSS_DBG("VPSS  :End of VPSS Loopback Application\r\n");
        return;
    }

    FVID_allocBuffer(CcdcHandle, &FBAddr);

    /**
     * Loopback Test With Default Parameters
    **/
    for(count=0;count<NumOfIterations;count++)
    {

        if(IOM_COMPLETED == FVID_exchange(CcdcHandle,&FBAddr))
        {
            /* Black & White Conversion Logic */
            BCACHE_inv(FBAddr->frame.frameBufferPtr,(720*480*2),TRUE);
            for (i=0; i< 480; i++)
            {
               l_ptr_short = (Uint16 *)FBAddr->frame.frameBufferPtr + (720 * i);

               for(j=0;j<720;j++)
               {
                    grayvalue   = ((*l_ptr_short)) & 0x1f;
                    *l_ptr_short = (grayvalue << 11) | (grayvalue << 6) | grayvalue;
                    l_ptr_short++;
                }
                l_ptr_short = (Uint16 *)FBAddr->frame.frameBufferPtr + (720 * i);

            }
            BCACHE_wb(FBAddr->frame.frameBufferPtr,(720*480*2),TRUE);
        }
        if(IOM_COMPLETED != FVID_exchange(Osd0Handle,&FBAddr))
        {
            VPSS_DBG("VPSS  :OSD 0 Exchange.......FAILED \r\n");
        }
    }
    /**
     *  Free Memory Buffers
    **/
    for(i=0;i<NO_OF_BUFFERS;i++)
    {
        FVID_freeBuffer(CcdcHandle,CcdcallocFB[i]);
        FVID_freeBuffer(Osd0Handle,OsdallocFB[i]);
    }
    FVID_freeBuffer(Vid0Handle,VidallocFB);

    /**
     *  Delete Channels
    **/
    FVID_delete(CcdcHandle);
    FVID_delete(Vid0Handle);
    FVID_delete(VencHandle);

    VPSS_DBG("VPSS: Raw Capture Loopback Application Ended \r\n");
}

void start_vpss_test()
{
    vpss_main();
}
