/*******************************************************************************
**+--------------------------------------------------------------------------+**
**|                            ****                                          |**
**|                            ****                                          |**
**|                            ******o***                                    |**
**|                      ********_///_****                                   |**
**|                      ***** /_//_/ ****                                   |**
**|                       ** ** (__/ ****                                    |**
**|                           *********                                      |**
**|                            ****                                          |**
**|                            ***                                           |**
**|                                                                          |**
**|         Copyright (c) 2006-2010 Texas Instruments Incorporated           |**
**|                        ALL RIGHTS RESERVED                               |**
**|                                                                          |**
**| Permission is hereby granted to licensees of Texas Instruments           |**
**| Incorporated (TI) products to use this computer program for the sole     |**
**| purpose of implementing a licensee product based on TI products.         |**
**| No other rights to refproduce, use, or disseminate this computer         |**
**| program, whether in part or in whole, are granted.                       |**
**|                                                                          |**
**| TI makes no representation or warranties with respect to the             |**
**| performance of this computer program, and specifically disclaims         |**
**| any responsibility for any damages, special or consequential,            |**
**| connected with the use of this program.                                  |**
**|                                                                          |**
**+--------------------------------------------------------------------------+**
*******************************************************************************/
/** \file   psp_digital_vpbe_sample_application.c
 *
 *  \brief  This file contains the test / demo code to demonstrate the
 *          VPSS driver implemented using the GIO Framework Architecture
 *
 *          This file performs following Test for VPSS Back End Driver.
 *
 *  (C) Copyright 2010, Texas Instruments, Inc
 *
 *  \author     Maulik Desai
 *
 *  \version    0.1     Created
 */
/******************************************************************************
                            Header File Inclusion
******************************************************************************/
#include <std.h>
#include <gio.h>
#include <mem.h>
#include <string.h>
#include <bcache.h>

#include <ti/sdo/pspdrivers/system/dm6437/bios/evmDM6437/video/fvid.h>
#include <ti/sdo/pspdrivers/pal_os/bios/psputils.h>
#include <ti/sdo/pspdrivers/drivers/vpbe/psp_vpbe.h>
#include <ti/sdo/pspdrivers/system/dm6437/bios/evmDM6437/video/sample/yuv_imageCbCr.h>
#include <ti/sdo/pspdrivers/system/dm6437/bios/evmDM6437/video/src/THS8200_extVidEncoder.h>

extern Int      DDR2;
/****************************************************************************
                MACROS DEFINED
*****************************************************************************/
#define VPSS_DBG        PSP_DEBUG

/*
 * 480P 60Hz EDTV Display Configuration
 */
#define DIS_PARAMS_THS8200_480P_DEFAULT {                               \
    THS8200_MODE_480P_60HZ,             /* Mode             */          \
    THS8200_IFMT_YCBCR422_20_BIT,       /* InputFormat      */          \
    THS8200_AFMT_YPBPR_SYNC_ON_Y,       /* AnalogFormat     */          \
    TRUE,                               /* enableSlaveMode  */          \
    FALSE,                              /* enableBT656Sync  */          \
}


/*Global Variable Defined */
static GIO_Handle   Vid0Handle;
static GIO_Handle   VencHandle;
static Ptr          vidRefFrameBuffer    = NULL;
static FVID_Frame   *VidallocFB = NULL;

static PSP_VPBEOsdConfigParams  vid0Params =
{
    FVID_FIELD_MODE,                    /* ffmode       */
    FVID_BPP_BITS16,                    /* bitsPerPixel */
    FVID_YCbCr422_INTERLEAVED,          /* colorFormat  */
    (720 *  (16/8u)),                   /* pitch        */
    0,                                  /* leftMargin   */
    0,                                  /* topMargin    */
    720,                                /* width        */
    480,                                /* height       */
    0,                                  /* segId        */
    PSP_VPBE_ZOOM_IDENTITY,             /* hScaling     */
    PSP_VPBE_ZOOM_IDENTITY,             /* vScaling     */
    PSP_VPBE_EXP_IDENTITY,              /* hExpansion   */
    PSP_VPBE_EXP_IDENTITY,              /* vExpansion   */
    NULL                                /* appCallback  */

};

static PSP_VPBEVencConfigParams vencParams =
{
    PSP_VPBE_DISPLAY_YCC16_DIGITAL_480P, /* Display Standard     */
    {
        THS8200_open,                   /* Ext Video Encoder Fxn */
        THS8200_close,
        THS8200_ctrl,
    }
};
/* THS8200 EDC driver configuration */
static THS8200_ConfParams vDisParamsEncoder
    = DIS_PARAMS_THS8200_480P_DEFAULT;

/******************************************************************************
                            Prepare Video Frame
******************************************************************************/
static void prepareVidFrame(Ptr fbAddr)
{
    Uint8 * vidiPtr = NULL;
    static Uint vidlineNo = 0;

    vidlineNo = vidlineNo % (475);
    vidiPtr = (Uint8 *)fbAddr;
    if(NULL!=vidiPtr)
    {
        memcpy(vidiPtr,vidRefFrameBuffer,(720*480*2));
        vidiPtr = vidiPtr + (1440 * vidlineNo);
        memset(vidiPtr,0xFFFFFFFF,(5*1440));
        vidlineNo++;
    }
}
static void vpbe_main()
{
    PSP_VPBEChannelParams   beinitParams;
    GIO_Attrs               gioAttrs = GIO_ATTRS;
    Uint32 * iPtr                    = NULL;
    Uint32   NumOfIterations = 1000;
    Uint32   index          = 0;
    Uint32   i  =   0;
    VPSS_DBG("VPSS: VPBE Sample Application Started \r\n");

    vidRefFrameBuffer   = MEM_alloc(DDR2, (720*480*2) , 32u);
    iPtr                = (Uint32 *)vidRefFrameBuffer;
    if(NULL!=iPtr)
    {
        /*Store Image into Memory */
        for(index = 0;index<((720*480*2)/(sizeof(Uint32))); index++)
        {
            *(iPtr + index) = yuv_imageCbCr_720x480[index];
        }
    }
    /**
     * Create Video Channel
    **/
    beinitParams.id         =   PSP_VPBE_VIDEO_0;
    beinitParams.params     =   (PSP_VPBEOsdConfigParams    *)&vid0Params;
    Vid0Handle              =   FVID_create("/VPBE0",IOM_INOUT,NULL,&beinitParams,&gioAttrs);
    if(NULL == Vid0Handle)
    {
        VPSS_DBG("VPSS  :VIDE0 -0 Create.......FAILED \r\n");
        VPSS_DBG("VPSS  :End of VPSS Loopback Application\r\n");
        return;
    }
    else
    {
        if(IOM_COMPLETED == FVID_allocBuffer(Vid0Handle,&VidallocFB))
        {
            memcpy(VidallocFB->frame.frameBufferPtr,vidRefFrameBuffer,(720*480*2));
            if(IOM_COMPLETED != FVID_queue(Vid0Handle,VidallocFB))
            {
                VPSS_DBG("VPSS  :Video 0 Queuing.......FAILED \r\n");
            }
        }
    }
    /**
     * Create Venc Channel
    **/
    beinitParams.id         = PSP_VPBE_VENC;
    beinitParams.params     = (PSP_VPBEVencConfigParams *)&vencParams;
    VencHandle              = FVID_create("/VPBE0",IOM_INOUT,NULL,&beinitParams,&gioAttrs);
    if (NULL == VencHandle)
    {
        VPSS_DBG("VPSS  :Venc Create ... FAILED!\r\n");
        VPSS_DBG("VPSS  :End of VPSS Loopback Application\r\n");
        return;
    }
    /**
     * Configure the THS8200 Video Ecnoder
    **/
    if(IOM_COMPLETED != FVID_control(VencHandle,
                        VPBE_ExtVIDENC_BASE + PSP_VPSS_EXT_VIDEO_ENCODER_CONFIG,
                        &vDisParamsEncoder))
    {
        VPSS_DBG("VPSS  :Error in Configuring External Video Encoder  \r\n");
    }
    for(i = 0; i < NumOfIterations; i++)
    {
        prepareVidFrame(VidallocFB->frame.frameBufferPtr);
        if(IOM_COMPLETED == FVID_queue(Vid0Handle,VidallocFB))
        {
            if(IOM_COMPLETED != FVID_dequeue(Vid0Handle,&VidallocFB))
            {
                VPSS_DBG("VPSS  :Dequeue Call.......FAILED \r\n");
            }
        }
    }
    /**
     *  Delete Channels
    **/
    FVID_delete(VencHandle);
    FVID_delete(Vid0Handle);

    MEM_free(0,VidallocFB->frame.frameBufferPtr,(720*480*2));
    MEM_free(0,VidallocFB,sizeof(FVID_Frame));

    MEM_free(DDR2,vidRefFrameBuffer,(720*480*2));


    VPSS_DBG("VPSS: VPBE Sample Application Ended \r\n");
}

void start_vpss_test()
{
    vpbe_main();
    return;
}

