/*******************************************************************************
**+--------------------------------------------------------------------------+**
**|                            ****                                          |**
**|                            ****                                          |**
**|                            ******o***                                    |**
**|                      ********_///_****                                   |**
**|                      ***** /_//_/ ****                                   |**
**|                       ** ** (__/ ****                                    |**
**|                           *********                                      |**
**|                            ****                                          |**
**|                            ***                                           |**
**|                                                                          |**
**|         Copyright (c) 2006-2010 Texas Instruments Incorporated           |**
**|                        ALL RIGHTS RESERVED                               |**
**|                                                                          |**
**| Permission is hereby granted to licensees of Texas Instruments           |**
**| Incorporated (TI) products to use this computer program for the sole     |**
**| purpose of implementing a licensee product based on TI products.         |**
**| No other rights to reproduce, use, or disseminate this computer          |**
**| program, whether in part or in whole, are granted.                       |**
**|                                                                          |**
**| TI makes no representation or warranties with respect to the             |**
**| performance of this computer program, and specifically disclaims         |**
**| any responsibility for any damages, special or consequential,            |**
**| connected with the use of this program.                                  |**
**|                                                                          |**
**+--------------------------------------------------------------------------+**
*******************************************************************************/
/** \file   psp_h3a_application.c
 *
 *  \brief  VPSS integration Application H3A implementation file
 *
 *  (C) Copyright 2010, Texas Instruments, Inc
 *
 *  \author     EI
 *
 *  \version    1.0     Created
 */

/****************************************************************************
  HEADER FILE INCLUSION
 *****************************************************************************/
#include<stdio.h>
#include <std.h>
#include <gio.h>
#include <ti/sdo/pspdrivers/pal_os/pal_oscache.h>
#include <ti/sdo/pspdrivers/drivers/h3a/psp_h3a.h>
#include <ti/sdo/pspdrivers/drivers/h3a/psp_af.h>
#include <ti/sdo/pspdrivers/drivers/h3a/psp_aew.h>
#include <ti/sdo/pspdrivers/system/dm6437/bios/evmDM6437/video/sample/psp_h3a_application.h>
#include <ti/sdo/pspdrivers/system/dm6437/bios/evmDM6437/video/sample/psp_vpss_integrated.h>

/******************************************************************************
  Data-Structures
 ******************************************************************************/
/* H3A AF channel handle */
GIO_Handle h3aAFHandle = NULL;

/* H3A AEW channel handle */
GIO_Handle h3aAEWHandle = NULL;

/* previewer device name */
String h3aDeviceName = "/H3A0";

/* H3A AF parameters */
/* make h3aAFParams 4 bytes aligned */
#pragma DATA_ALIGN(h3aAFParams, 4);
PSP_AFParams h3aAFParams;

/* H3A AEW parameters */
/* make h3aAEWParams 4 bytes aligned */
#pragma DATA_ALIGN(h3aAEWParams, 4);
PSP_AEWParams h3aAEWParams;

/* array to use as buffers for AF and AEW. they will not be passed directly */

/* array for H3A AF buffer */
/* make arrayh3AAF 64 bytes aligned */
#pragma DATA_ALIGN(arrayh3AAF, 128);
Uint8 arrayh3AAF[H3A_AF_BUFFER_SIZE];
/* for proper cache operattion, buffer size needs to be 128 bytes aligned */
Uint8 padAFBytes[128 - ((H3A_AF_BUFFER_SIZE & 0xEF) % 128)];


/* array for H3A AEW buffer */
/* make arrayh3AAEW 64 bytes aligned */
#pragma DATA_ALIGN(arrayh3AAEW, 128);
Uint8 arrayh3AAEW[H3A_AEW_BUFFER_SIZE];
/* for proper cache operattion, buffer size needs to be 128 bytes aligned */
Uint8 padAEWBytes[128 - ((H3A_AEW_BUFFER_SIZE & 0xEF) % 128)];


/* H3A AF Enqueue buffer */
/* make h3aAFEnBuffer 4 bytes aligned */
#pragma DATA_ALIGN(h3aAFEnBuffer, 4);
PSP_H3ABuffer h3aAFEnBuffer;

/* H3A AEW Enqueue buffer */
/* make h3aAEWEnBuffer 4 bytes aligned */
#pragma DATA_ALIGN(h3aAEWEnBuffer, 4);
PSP_H3ABuffer h3aAEWEnBuffer;

/* H3A AF Dequeue buffer */
/* make h3aAFDeBuffer 4 bytes aligned */
#pragma DATA_ALIGN(h3aAFDeBuffer, 4);
PSP_H3ABuffer h3aAFDeBuffer;

/* H3A AEW Dequeue buffer */
/* make h3aAEWDeBuffer 4 bytes aligned */
#pragma DATA_ALIGN(h3aAEWDeBuffer, 4);
PSP_H3ABuffer h3aAEWDeBuffer;

Uint32 afFileNameCount = 1;
Uint32 aewFileNameCount = 1;
/******************************************************************************
  Functions
 ******************************************************************************/
/**
 * \brief   geth3aParams
 *          Gets AF and AEW configuration parameter's values into corresponding
 *          field of structure.
 *
 */
void geth3aParams(PSP_H3AChannelType *h3aType)
{
    /* parameter validation */
    if (NULL != h3aType)
    {
        if (PSP_H3A_AF == *h3aType)
        {
            /* Disable A law*/
            h3aAFParams.enable = PSP_AF_ALAW_DISABLE;
            h3aAFParams.hmfConfig.threshold = 120u;
            /* Disable HMF */
            h3aAFParams.hmfConfig.enable =PSP_AF_HMF_DISABLE ;
            h3aAFParams.iirConfig.coeffSet0[0] = 64;
            h3aAFParams.iirConfig.coeffSet0[1] = 0;
            h3aAFParams.iirConfig.coeffSet0[2] = 0;
            h3aAFParams.iirConfig.coeffSet0[3] = 21;
            h3aAFParams.iirConfig.coeffSet0[4] = 22;
            h3aAFParams.iirConfig.coeffSet0[5] = 21;
            h3aAFParams.iirConfig.coeffSet0[6] = 0;
            h3aAFParams.iirConfig.coeffSet0[7] = 0;
            h3aAFParams.iirConfig.coeffSet0[8] = -16;
            h3aAFParams.iirConfig.coeffSet0[9] = 32;
            h3aAFParams.iirConfig.coeffSet0[10] = -16;
            h3aAFParams.iirConfig.coeffSet1[0] = 64;
            h3aAFParams.iirConfig.coeffSet1[1] = 0;
            h3aAFParams.iirConfig.coeffSet1[2] = 0;
            h3aAFParams.iirConfig.coeffSet1[3] = 21;
            h3aAFParams.iirConfig.coeffSet1[4] = 22;
            h3aAFParams.iirConfig.coeffSet1[5] = 21;
            h3aAFParams.iirConfig.coeffSet1[6] = 0;
            h3aAFParams.iirConfig.coeffSet1[7] = -29;
            h3aAFParams.iirConfig.coeffSet1[8] = -16;
            h3aAFParams.iirConfig.coeffSet1[9] = 32;
            h3aAFParams.iirConfig.coeffSet1[10] = -16;
            h3aAFParams.iirConfig.hzStarPos = 2u;
            h3aAFParams.rgbPos = PSP_AF_GR_BG_BAYER;
            h3aAFParams.paxelConfig.height = 8u;
            h3aAFParams.paxelConfig.width = 8u;
            h3aAFParams.paxelConfig.hzCnt = H3A_AF_H_COUNT;
            h3aAFParams.paxelConfig.vtCnt = H3A_AF_V_COUNT;
            h3aAFParams.paxelConfig.hzStart = 8u;
            h3aAFParams.paxelConfig.vtStart= 8u;
            h3aAFParams.paxelConfig.lineIncr = 2u;
            h3aAFParams.mode = PSP_AF_ACCUMULATOR_SUMMED;
        }
        else if (PSP_H3A_AEW == *h3aType)
        {
            /* Disable A law*/
            h3aAEWParams.enable = PSP_AEW_ALAW_DISABLE;
            h3aAEWParams.satLimit = 120;
            h3aAEWParams.winConfig.height = 10u;
            h3aAEWParams.winConfig.width = 10u;
            h3aAEWParams.winConfig.hzCnt = H3A_AEW_H_COUNT;
            h3aAEWParams.winConfig.vtCnt = H3A_AEW_V_COUNT;
            h3aAEWParams.winConfig.hzStart = 4u;
            h3aAEWParams.winConfig.vtStart = 4u;
            h3aAEWParams.winConfig.hzLineIncr = 4u;
            h3aAEWParams.winConfig.vtLineIncr = 4u;
            h3aAEWParams.blkWinConfig.height = 10u;
            h3aAEWParams.blkWinConfig.vtStart = 4u;
        }
    }
    return;
}

/**
 * \brief   h3aOpen
 *          This function opens the AF and AEW channel
 *
 * \returns Success or error code
 */
Int32 h3aOpen(PSP_H3AChannelType *h3aType)
{
    Int32 h3aOpenReturnCode = -1;

    /* parameter validation */
    if ((NULL == h3aDeviceName) || (NULL == h3aType))
    {
        h3aOpenReturnCode = -1;
    }
    else
    {
        if (PSP_H3A_AF == *h3aType)
        {
            /* open channel handle */
            h3aAFHandle = GIO_create(h3aDeviceName, IOM_INOUT, NULL,
                h3aType, NULL);
            /* check that channel is open successfully or not */
            if (NULL == h3aAFHandle)
            {
                h3aOpenReturnCode = -1;
            }
            else
            {
                h3aOpenReturnCode = 0;
            }
            /* intialise buffer handle */
            h3aAFEnBuffer.size = H3A_AF_BUFFER_SIZE;
            h3aAFEnBuffer.ramIpAddr = (Ptr)(arrayh3AAF);
        }
        else if (PSP_H3A_AEW == *h3aType)
        {
            /* open channel handle */
            h3aAEWHandle = GIO_create(h3aDeviceName, IOM_INOUT, NULL,
                h3aType, NULL);
            /* check that channel is open successfully or not */
            if (NULL == h3aAEWHandle)
            {
                h3aOpenReturnCode = -1;
            }
            else
            {
                h3aOpenReturnCode = 0;
            }
            /* intialise buffer handle */
            h3aAEWEnBuffer.size = H3A_AEW_BUFFER_SIZE;
            h3aAEWEnBuffer.ramIpAddr = (Ptr)(arrayh3AAEW);
        }
        else
        {
            h3aOpenReturnCode = -1;
        }
    }
    return h3aOpenReturnCode;
}

/**
 * \brief   h3aConfig
 *          This function configures Auto Focus and AutoExposure/White Balance
 *            hardware
 *
 * \returns Success or error code
 */
Int32 h3aConfig(PSP_H3AChannelType *h3aType)
{
    Int32 h3aConfigReturnCode = -1;
    Int32 h3aConfigIOMReturnCode = IOM_EBADMODE;

    /* parameter validation */
    if (NULL == h3aType)
    {
        h3aConfigReturnCode = -1;
    }
    else
    {
        geth3aParams(h3aType);
        if (PSP_H3A_AF == *h3aType)
        {
            if (NULL == h3aAFHandle)
            {
                h3aConfigReturnCode = -1;
            }
            else
            {
                /* call IOCTL to set parameters */
                h3aConfigIOMReturnCode = GIO_control(h3aAFHandle,
                    PSP_H3A_IOCTL_SET_PARAM, &h3aAFParams);
            }
        }
        else if (PSP_H3A_AEW == *h3aType)
        {
            if (NULL == h3aAEWHandle)
            {
                h3aConfigReturnCode = -1;
            }
            else
            {
                /* call IOCTL to set parameters */
                h3aConfigIOMReturnCode = GIO_control(h3aAEWHandle,
                    PSP_H3A_IOCTL_SET_PARAM, &h3aAEWParams);
            }
        }
        else
        {
            h3aConfigReturnCode = -1;
        }
        /* check that parameters are configured properly or not */
        if (IOM_COMPLETED != h3aConfigIOMReturnCode)
        {
            h3aConfigReturnCode = -1;
        }
        else
        {
            h3aConfigReturnCode = 0;
        }
    }
    return h3aConfigReturnCode;
}

/**
 * \brief   h3aEnqueue
 *          This function performs enqueue operation for AF and AEW.
 *
 * \returns Success or error code
 */
Int32 h3aEnqueue(PSP_H3AChannelType *h3aType)
{
    Int32 h3aEnqueueReturnCode = -1;
    Int32 h3aEnqueueIOMReturnCode = IOM_EBADMODE;
    size_t  h3aEnqueueSize = sizeof(PSP_H3ABuffer);

    /* parameter validation */
    if (NULL == h3aType)
    {
        h3aEnqueueReturnCode = -1;
    }
    else
    {
        if (PSP_H3A_AF == *h3aType)
        {
            if (NULL == h3aAFHandle)
            {
                h3aEnqueueReturnCode = -1;
            }
            else
            {
                /* call IOCTL to enqueue channel */
                h3aEnqueueIOMReturnCode = GIO_submit(h3aAFHandle,
                    PSP_VPSS_QUEUE, &h3aAFEnBuffer,
                    &h3aEnqueueSize, NULL);
            }
        }
        else if (PSP_H3A_AEW == *h3aType)
        {
            if (NULL == h3aAEWHandle)
            {
                h3aEnqueueReturnCode = -1;
            }
            else
            {
                /* call IOCTL to enqueue channel */
                h3aEnqueueIOMReturnCode = GIO_submit(h3aAEWHandle,
                    PSP_VPSS_QUEUE, &h3aAEWEnBuffer,
                    &h3aEnqueueSize, NULL);
            }
        }
        else
        {
            h3aEnqueueReturnCode = -1;
        }
        /* check that enqueue properly or not */
        if (IOM_COMPLETED != h3aEnqueueIOMReturnCode)
        {
            h3aEnqueueReturnCode = -1;
        }
        else
        {
            h3aEnqueueReturnCode = 0;
        }
    }
    return h3aEnqueueReturnCode;
}

/**
 * \brief   h3aDequeue
 *          This function performs Dequeue operation for AF and AEW.
 *
 * \returns Success or error code
 */
Int32 h3aDequeue(PSP_H3AChannelType *h3aType)
{
    Int32 h3aDequeueReturnCode = -1;
    Int32 h3aDequeueIOMReturnCode = IOM_EBADMODE;
    size_t  h3aDequeueSize = sizeof(PSP_H3ABuffer);

    /* parameter validation */
    if (NULL == h3aType)
    {
        h3aDequeueReturnCode = -1;
    }
    else
    {
        if (PSP_H3A_AF == *h3aType)
        {
            if (NULL == h3aAFHandle)
            {
                h3aDequeueReturnCode = -1;
            }
            else
            {
                /* call IOCTL to dequeue channel */
                h3aDequeueIOMReturnCode = GIO_submit(h3aAFHandle,
                    PSP_VPSS_DEQUEUE, &h3aAFDeBuffer,
                    &h3aDequeueSize, NULL);
            }
        }
        else if (PSP_H3A_AEW == *h3aType)
        {
            if (NULL == h3aAEWHandle)
            {
                h3aDequeueReturnCode = -1;
            }
            else
            {
                /* call IOCTL to dequeue channel */
                h3aDequeueIOMReturnCode = GIO_submit(h3aAEWHandle,
                    PSP_VPSS_DEQUEUE, &h3aAEWDeBuffer,
                    &h3aDequeueSize, NULL);
            }
        }
        else
        {
            h3aDequeueReturnCode = -1;
        }
        /* check that enqueue properly or not */
        if (IOM_COMPLETED != h3aDequeueIOMReturnCode)
        {
            h3aDequeueReturnCode = -1;
        }
        else
        {
            if (PSP_H3A_AF == *h3aType)
            {
                PAL_osCacheInvalidate(
                    (PAL_osCacheMemAddrSpace)NULL,
                    (Uint32)(h3aAFDeBuffer.ramIpAddr),
                    h3aAFDeBuffer.size);

                if (PSP_H3A_BUFFER_DATA_CORRUPTED == h3aAFDeBuffer.buffStatus)
                {
                    INTEGRATION_APP_PRINT(
                        "\n Data is corrupted, Write buffer overflow \n");
                }
            }
            else if (PSP_H3A_AEW == *h3aType)
            {
                PAL_osCacheInvalidate(
                    (PAL_osCacheMemAddrSpace)NULL,
                    (Uint32)(h3aAEWDeBuffer.ramIpAddr),
                    h3aAEWDeBuffer.size);

                if (PSP_H3A_BUFFER_DATA_CORRUPTED == h3aAEWDeBuffer.buffStatus)
                {
                    INTEGRATION_APP_PRINT(
                        "\n Data is corrupted, Write buffer overflow \n");
                }
            }

            h3aDequeueReturnCode = 0;
        }
    }
    return h3aDequeueReturnCode;
}

/**
 * \brief   h3aClose
 *          This function closes the AF and AEW channel
 *
 * \returns Success or error code
 */
Int32 h3aClose(PSP_H3AChannelType *h3aType)
{
    Int32 h3aCloseReturnCode = -1;
    Int32 h3aCloseIOMReturnCode = IOM_EBADMODE;

    /* parameter validation */
    if (NULL == h3aType)
    {
        h3aCloseReturnCode = -1;
    }
    else
    {
        if (PSP_H3A_AF == *h3aType)
        {
            if (NULL == h3aAFHandle)
            {
                h3aCloseReturnCode = -1;
            }
            else
            {
                /* call IOCTL to delete channel */
                h3aCloseIOMReturnCode = GIO_delete(h3aAFHandle);
            }
        }
        else if (PSP_H3A_AEW == *h3aType)
        {
            if (NULL == h3aAEWHandle)
            {
                h3aCloseReturnCode = -1;
            }
            else
            {
                /* call IOCTL to delete channel */
                h3aCloseIOMReturnCode = GIO_delete(h3aAEWHandle);
            }
        }
        else
        {
            h3aCloseReturnCode = -1;
        }
        /* check that channel is deleted properly or not */
        if (IOM_COMPLETED != h3aCloseIOMReturnCode)
        {
            h3aCloseReturnCode = -1;
        }
        else
        {
            h3aCloseReturnCode = 0;
        }
    }
    return h3aCloseReturnCode;
}




/**
 * \brief   AEW_DumpToFile
 *          This function is used to dump statistics to
 *          the file
 *
 */
void AEW_DumpToFile(void)
{
    Int indexDump;
    short int *temp;
    FILE *fp;
    char tempName[80];
    /* Open Output file */
    sprintf(tempName, "AEW_%d.txt", aewFileNameCount);
    fp = fopen(tempName, "w" );
    temp = (short int *)h3aAEWDeBuffer.ramIpAddr;
    if ( (NULL != fp) && (NULL != temp))
    {
        /* Write Statistics to output File */
        for(indexDump = 0; indexDump < (h3aAEWEnBuffer.size/(2u)); indexDump++)
        {
            fprintf(fp, "\n%d", *temp);
            temp++;
        }
        fprintf(fp, "\n");
        aewFileNameCount++;
        fclose(fp);
    }
    else
    {
        INTEGRATION_APP_PRINT("\nError in storing statistics in file\n");
    }
}




/**
 * \brief   AF_DumpToFile
 *          This function is used to dump statistics to
 *          the file
 *
 */
void AF_DumpToFile(void)
{
    Int indexDump;
    Int *temp;
    FILE *fp;
    char tempName[80];
    /* Open Output file */
    sprintf(tempName, "AF_%d.txt", afFileNameCount);
    fp = fopen(tempName, "w" );
    temp = (int *)h3aAFDeBuffer.ramIpAddr;
    if ( (NULL != fp) && (NULL != temp))
    {
        /* Write Statistics to output File */
        for(indexDump = 0; indexDump < (h3aAFEnBuffer.size/(4u)); indexDump++)
        {
            fprintf(fp, "\n%d", *temp);
            temp++;
        }
        fprintf(fp, "\n", *temp);
        afFileNameCount++;
        fclose(fp);
    }
    else
    {
        INTEGRATION_APP_PRINT("\nError in storing statistics in file\n");
    }
}

