/*******************************************************************************
**+--------------------------------------------------------------------------+**
**|                            ****                                          |**
**|                            ****                                          |**
**|                            ******o***                                    |**
**|                      ********_///_****                                   |**
**|                      ***** /_//_/ ****                                   |**
**|                       ** ** (__/ ****                                    |**
**|                           *********                                      |**
**|                            ****                                          |**
**|                            ***                                           |**
**|                                                                          |**
**|         Copyright (c) 2006-2010 Texas Instruments Incorporated           |**
**|                        ALL RIGHTS RESERVED                               |**
**|                                                                          |**
**| Permission is hereby granted to licensees of Texas Instruments           |**
**| Incorporated (TI) products to use this computer program for the sole     |**
**| purpose of implementing a licensee product based on TI products.         |**
**| No other rights to reproduce, use, or disseminate this computer          |**
**| program, whether in part or in whole, are granted.                       |**
**|                                                                          |**
**| TI makes no representation or warranties with respect to the             |**
**| performance of this computer program, and specifically disclaims         |**
**| any responsibility for any damages, special or consequential,            |**
**| connected with the use of this program.                                  |**
**|                                                                          |**
**+--------------------------------------------------------------------------+**
*******************************************************************************/
/** \file   psp_histogram_application.c
 *
 *  \brief  VPSS integration Application Histogram implementation file
 *
 *  (C) Copyright 2010, Texas Instruments, Inc
 *
 *  \author     EI
 *
 *  \version    1.0     Created
 */

/****************************************************************************
  HEADER FILE INCLUSION
 *****************************************************************************/
#include <stdio.h>
#include <std.h>
#include <gio.h>
#include <ti/sdo/pspdrivers/pal_os/pal_oscache.h>
#include <ti/sdo/pspdrivers/drivers/histogram/psp_histogram.h>
#include <ti/sdo/pspdrivers/system/dm6437/bios/evmDM6437/video/sample/psp_histogram_application.h>
#include <ti/sdo/pspdrivers/system/dm6437/bios/evmDM6437/video/sample/psp_vpss_integrated.h>
#include <ti/sdo/edma3/drv/edma3_drv.h>

/******************************************************************************
  Data-Structures
 ******************************************************************************/
/* Histogram channel handle */
GIO_Handle histHandle = NULL;

/* Histogram device name */
String histDeviceName = "/histogram";

/* Histogram parameters */
/* make histParams 4 bytes aligned */
#pragma DATA_ALIGN(histParams, 4);
PSP_HISTparam histParams;

/* array to use as buffers for Histogram. they will not be passed directly */

/* array for Histogram buffer */
/* make arrayFirstHist 128 bytes aligned */
#pragma DATA_ALIGN(arrayFirstHist, 128);
Uint8 arrayFirstHist[HIST_BUFFER_SIZE];

/* make arraySecondHist 128 bytes aligned */
#pragma DATA_ALIGN(arraySecondHist, 128);
Uint8 arraySecondHist[HIST_BUFFER_SIZE];

/* Histogram Enqueue buffer */
PSP_HISTbuffer *histEnBuffer;

/* make histFirstEnBuffer 4 bytes aligned */
#pragma DATA_ALIGN(histFirstEnBuffer, 4);
PSP_HISTbuffer histFirstEnBuffer;

/* make histSecondEnBuffer 4 bytes aligned */
#pragma DATA_ALIGN(histSecondEnBuffer, 4);
PSP_HISTbuffer histSecondEnBuffer;

/* Histogram Dequeue buffer pointer */
PSP_HISTbuffer *histDeBuffer;

extern EDMA3_DRV_Handle hEdma;

Uint32 histFileNameCount = 1;

/******************************************************************************
  Functions
 ******************************************************************************/
/**
 * \brief   getHistParams
 *          Gets histogram configuration parameter's values into corresponding
 *          field of structure.
 *
 */
void getHistParams()
{
    histParams.clearOpDataAfterRead = PSP_HIST_CLEAR_AFTER_READ;
    histParams.bins = PSP_HIST_64BINS;
    histParams.shift = PSP_HIST_DATA_RSHIFT_FOUR;

    /* White balance gain for all colors */
    histParams.wbGain[0] = HIST_WB_GAIN00;
    histParams.wbGain[1] = HIST_WB_GAIN01;
    histParams.wbGain[2] = HIST_WB_GAIN02;
    histParams.wbGain[3] = HIST_WB_GAIN03;

    /* Image size : 640x480 */
    /* Region0 size */
    histParams.region[0].hStart = HIST_REG0_HSTART;
    histParams.region[0].hEnd   = HIST_REG0_HEND;
    histParams.region[0].vStart = HIST_REG0_VSTART;
    histParams.region[0].vEnd   = HIST_REG0_VEND;

    histParams.region[1].hStart = HIST_REG1_HSTART;
    histParams.region[1].hEnd   = HIST_REG1_HEND;
    histParams.region[1].vStart = HIST_REG1_VSTART;
    histParams.region[1].vEnd   = HIST_REG1_VEND;

    histParams.region[2].hStart = HIST_REG2_HSTART;
    histParams.region[2].hEnd   = HIST_REG2_HEND;
    histParams.region[2].vStart = HIST_REG2_VSTART;
    histParams.region[2].vEnd   = HIST_REG2_VEND;

    histParams.region[3].hStart = HIST_REG3_HSTART;
    histParams.region[3].hEnd   = HIST_REG3_HEND;
    histParams.region[3].vStart = HIST_REG3_VSTART;
    histParams.region[3].vEnd   = HIST_REG3_VEND;
    return;
}

/**
 * \brief   histOpen
 *          This function opens the histogram channel
 *
 * \returns Success or error code
 */
Int32 histOpen()
{
    Int32 histOpenReturnCode = -1;

    /* parameter validation */
    if (NULL == histDeviceName)
    {
        histOpenReturnCode = -1;
    }
    else
    {
        /* open channel handle */
        histHandle = GIO_create(histDeviceName, IOM_INPUT, NULL,
            hEdma, NULL);
        /* check that channel is open successfully or not */
        if (NULL == histHandle)
        {
            histOpenReturnCode = -1;
        }
        else
        {
            histOpenReturnCode = 0;
        }
    }

    return histOpenReturnCode;
}

/**
 * \brief   histConfig
 *          This function configures histogram hardware for histogram
 *
 * \returns Success or error code
 */
Int32 histConfig()
{
    Int32 histConfigReturnCode = -1;
    Int32 histConfigIOMReturnCode = IOM_EBADMODE;

    if (NULL == histHandle)
    {
        histConfigReturnCode = -1;
    }
    else
    {
        getHistParams();
        /* call IOCTL to set parameters */
        histConfigIOMReturnCode = GIO_control(histHandle,
            PSP_HIST_IOCTL_SET_PARAMS, &histParams);
    }

    /* check that parameters are configured properly or not */
    if (IOM_COMPLETED != histConfigIOMReturnCode)
    {
        histConfigReturnCode = -1;
    }
    else
    {
        histConfigReturnCode = 0;
    }
    /* intialise buffer handle */
    histFirstEnBuffer.bufferSize = HIST_BUFFER_SIZE/sizeof(int);
    histFirstEnBuffer.ramIpAddr = (Ptr)(arrayFirstHist);

    histSecondEnBuffer.bufferSize = HIST_BUFFER_SIZE/sizeof(int);
    histSecondEnBuffer.ramIpAddr = (Ptr)(arraySecondHist);

    return histConfigReturnCode;
}

/**
 * \brief   histFirstEnqueue
 *          This function performs first enqueue operation
 *
 * \returns Success or error code
 */
Int32 histFirstEnqueue()
{
    Int32 histFirstEnqueueReturnCode = -1;
    Int32 histFirstEnqueueIOMReturnCode = IOM_EBADMODE;

    size_t  histFirstEnqueueSize = sizeof(PSP_HISTbuffer);

    if (NULL == histHandle)
    {
        histFirstEnqueueReturnCode = -1;
    }
    else
    {
        /* call IOCTL to enqueue channel */
        /* intialise buffer handle */
        histEnBuffer = &histFirstEnBuffer;
        histFirstEnqueueIOMReturnCode = GIO_submit(histHandle,
            PSP_VPSS_QUEUE, histEnBuffer,
            &histFirstEnqueueSize, NULL);
    }

    /* check that enqueue properly or not */
    if (IOM_COMPLETED != histFirstEnqueueIOMReturnCode)
    {
        histFirstEnqueueReturnCode = -1;
    }
    else
    {
        histFirstEnqueueReturnCode = 0;
    }

    return histFirstEnqueueReturnCode;
}

/**
 * \brief   histEnqueue
 *          This function performs enqueue operation
 *
 * \returns Success or error code
 */
Int32 histEnqueue()
{
    Int32 histEnqueueReturnCode = -1;
    Int32 histEnqueueIOMReturnCode = IOM_EBADMODE;
    size_t  histEnqueueSize = sizeof(PSP_HISTbuffer);

    if (NULL == histHandle)
    {
        histEnqueueReturnCode = -1;
    }
    else
    {
        if (histEnBuffer == &histFirstEnBuffer)
        {
            histEnBuffer = &histSecondEnBuffer;
        }
        else
        {
            histEnBuffer = &histFirstEnBuffer;
        }
        /* call IOCTL to enqueue channel */
        histEnqueueIOMReturnCode = GIO_submit(histHandle,
            PSP_VPSS_QUEUE, histEnBuffer,
            &histEnqueueSize, NULL);

    }

    /* check that enqueue properly or not */
    if (IOM_COMPLETED != histEnqueueIOMReturnCode)
    {
        histEnqueueReturnCode = -1;
    }
    else
    {
        histEnqueueReturnCode = 0;
    }

    return histEnqueueReturnCode;
}

/**
 * \brief   histDequeue
 *          This function performs Dequeue operation for histogram
 *
 * \returns Success or error code
 */
Int32 histDequeue()
{
    Int32 histDequeueReturnCode = -1;
    Int32 histDequeueIOMReturnCode = IOM_EBADMODE;
    size_t  histDequeueSize = sizeof(PSP_HISTbuffer);

    if (NULL == histHandle)
    {
        histDequeueReturnCode = -1;
    }
    else
    {
        /* call IOCTL to dequeue channel */
        histDequeueIOMReturnCode = GIO_submit(histHandle,
            PSP_VPSS_DEQUEUE, &histDeBuffer,
            &histDequeueSize, NULL);
    }

    /* check that enqueue properly or not */
    if (IOM_COMPLETED != histDequeueIOMReturnCode)
    {
        histDequeueReturnCode = -1;
    }
    else
    {
        PAL_osCacheInvalidate(
            (PAL_osCacheMemAddrSpace)NULL,
            (Uint32)(histDeBuffer->ramIpAddr),
            (histDeBuffer->bufferSize)*sizeof(int));

        histDequeueReturnCode = 0;
    }

    return histDequeueReturnCode;
}

/**
 * \brief   histClose
 *          This function closes the histogram channel
 *
 * \returns Success or error code
 */
Int32 histClose()
{
    Int32 histCloseReturnCode = -1;
    Int32 histCloseIOMReturnCode = IOM_EBADMODE;

    if (NULL == histHandle)
    {
        histCloseReturnCode = -1;
    }
    else
    {
        /* call IOCTL to delete channel */
        histCloseIOMReturnCode = GIO_delete(histHandle);
    }

    /* check that channel is deleted properly or not */
    if (IOM_COMPLETED != histCloseIOMReturnCode)
    {
        histCloseReturnCode = -1;
    }
    else
    {
        histCloseReturnCode = 0;
    }

    return histCloseReturnCode;
}


/**
 * \brief   HIST_DumpToFile
 *          This function is used to dump statistics to
 *          the file
 *
 */
void HIST_DumpToFile(void)
{
    Int indexDump;
    Int32 *temp;
    FILE *fp;
    char tempName[80];
    /* Open Output file */
    sprintf(tempName, "HIST_%d.csv", histFileNameCount);
    fp = fopen(tempName, "w" );
    temp = (Int32*)histDeBuffer->ramIpAddr;
    if ( (NULL != fp) && (NULL != temp))
    {
        /* Write Statistics to output File */
        fprintf(fp, "\n Time stamp %d ms", histDeBuffer->timeStmp);
        for(indexDump = 0; indexDump < histDeBuffer->bufferSize; indexDump++)
        {
            fprintf(fp, "\n %d", *temp);
            temp++;
        }
        fprintf(fp, "\n");
        histFileNameCount++;
        fclose(fp);
    }
    else
    {
        INTEGRATION_APP_PRINT("\nError in storing statistics in file\n");
    }
}

