/*******************************************************************************
**+--------------------------------------------------------------------------+**
**|                            ****                                          |**
**|                            ****                                          |**
**|                            ******o***                                    |**
**|                      ********_///_****                                   |**
**|                      ***** /_//_/ ****                                   |**
**|                       ** ** (__/ ****                                    |**
**|                           *********                                      |**
**|                            ****                                          |**
**|                            ***                                           |**
**|                                                                          |**
**|         Copyright (c) 2006-2010 Texas Instruments Incorporated           |**
**|                        ALL RIGHTS RESERVED                               |**
**|                                                                          |**
**| Permission is hereby granted to licensees of Texas Instruments           |**
**| Incorporated (TI) products to use this computer program for the sole     |**
**| purpose of implementing a licensee product based on TI products.         |**
**| No other rights to reproduce, use, or disseminate this computer          |**
**| program, whether in part or in whole, are granted.                       |**
**|                                                                          |**
**| TI makes no representation or warranties with respect to the             |**
**| performance of this computer program, and specifically disclaims         |**
**| any responsibility for any damages, special or consequential,            |**
**| connected with the use of this program.                                  |**
**|                                                                          |**
**+--------------------------------------------------------------------------+**
*******************************************************************************/
/** \file   psp_previewer_application.c
 *
 *  \brief  VPSS integration Application Previewer implementation file
 *
 *  (C) Copyright 2010, Texas Instruments, Inc
 *
 *  \author     EI
 *
 *  \version    1.0     Created
 */

/****************************************************************************
  HEADER FILE INCLUSION
 *****************************************************************************/
#include<stdio.h>
#include <std.h>
#include <gio.h>
#include <ti/sdo/pspdrivers/drivers/previewer/psp_previewer.h>
#include <ti/sdo/pspdrivers/system/dm6437/bios/evmDM6437/video/sample/psp_previewer_application.h>
#include <ti/sdo/pspdrivers/system/dm6437/bios/evmDM6437/video/sample/psp_vpss_integrated.h>

/* previewer channel handle */
GIO_Handle prevHandle = NULL;

/* previewer device name */
String prevDeviceName = "/previewer";

/* previewer parameters */
/* make prevParams 4 bytes aligned */
#pragma DATA_ALIGN(prevParams, 4);
PSP_previewerParams prevParams;
/******************************************************************************
  Data-Structures
 ******************************************************************************/
const char cfa_coef[] =
{
    GR_PHASE,
    R_PHASE,
    B_PHASE,
    GB_PHASE
};
/******************************************************************************
  Functions
 ******************************************************************************/
/**
 * \brief   GetPreviewerParams
 *          Gets Previewer configuration parameter's values into corresponding
 *          field of structure.
 *
 */
void GetPreviewerParams()
{
    Uint32 i = 0;
    /* down sample rate */
    prevParams.downSampleRate =  PSP_PREVIEWER_DOWN_SAMPLE_RATE1;
    /* Set size and pitch parameters */
    /* start horizontal pixel */
    prevParams.sizeParam.sph   = 0;
    /* end horizontal pixel */
    prevParams.sizeParam.eph   = INPUT_IMAGE_WIDTH - 1;
    /* start vertical pixel */
    prevParams.sizeParam.slv   = 0;
    /* end vertical pixel */
    prevParams.sizeParam.elv   = INPUT_IMAGE_HEIGHT - 1;
    /* pixel size */
    prevParams.sizeParam.pixelSize = PSP_PREVIEWER_INWIDTH_10BIT;
    /* offset distance between two raws in input image - should be 32 bytes
     * aligned */
    prevParams.sizeParam.inPitch = (INPUT_IMAGE_WIDTH * 2u);
    /* offset distance between two raws in output image - should be 32 bytes
     * aligned */
    prevParams.sizeParam.outPitch = (INPUT_IMAGE_WIDTH * 2u);
    /* Set white balancing parameters */
    prevParams.whiteBalanceParam.wbDgain   = 0x100;
    prevParams.whiteBalanceParam.wbGain[0] = 0x40;
    prevParams.whiteBalanceParam.wbGain[1] = 0x40;
    prevParams.whiteBalanceParam.wbGain[2] = 0x40;
    prevParams.whiteBalanceParam.wbGain[3] = 0x40;

    prevParams.whiteBalanceParam.position[0][0] = 0;
    prevParams.whiteBalanceParam.position[0][1] = 1;
    prevParams.whiteBalanceParam.position[0][2] = 0;
    prevParams.whiteBalanceParam.position[0][3] = 1;

    prevParams.whiteBalanceParam.position[1][0] = 2;
    prevParams.whiteBalanceParam.position[1][1] = 3;
    prevParams.whiteBalanceParam.position[1][2] = 2;
    prevParams.whiteBalanceParam.position[1][3] = 3;

    prevParams.whiteBalanceParam.position[2][0] = 0;
    prevParams.whiteBalanceParam.position[2][1] = 1;
    prevParams.whiteBalanceParam.position[2][2] = 0;
    prevParams.whiteBalanceParam.position[2][3] = 1;

    prevParams.whiteBalanceParam.position[3][0] = 2;
    prevParams.whiteBalanceParam.position[3][1] = 3;
    prevParams.whiteBalanceParam.position[3][2] = 2;
    prevParams.whiteBalanceParam.position[3][3] = 3;

    /* Set RGB2RGB blending parameters */
    prevParams.rgbBlendingParam.blending[0][0] = 0x1a1;
    prevParams.rgbBlendingParam.blending[0][1] = 0xf8a;
    prevParams.rgbBlendingParam.blending[0][2] = 0xfd5;
    prevParams.rgbBlendingParam.blending[1][0] = 0xfa1;
    prevParams.rgbBlendingParam.blending[1][1] = 0x1c4;
    prevParams.rgbBlendingParam.blending[1][2] = 0xf9b;
    prevParams.rgbBlendingParam.blending[2][0] = 0xfbd;
    prevParams.rgbBlendingParam.blending[2][1] = 0xfb1;
    prevParams.rgbBlendingParam.blending[2][2] = 0x192;

    prevParams.rgbBlendingParam.offset[0] = 0;
    prevParams.rgbBlendingParam.offset[1] = 0;
    prevParams.rgbBlendingParam.offset[2] = 0;

    /* Set RGB2YCBCR parameters */
    prevParams.rgb2ycbcrParam.coeff[0][0] = 0x4D;
    prevParams.rgb2ycbcrParam.coeff[0][1] = 0x96;
    prevParams.rgb2ycbcrParam.coeff[0][2] = 0x1D;
    prevParams.rgb2ycbcrParam.coeff[1][0] = 0x3d4;
    prevParams.rgb2ycbcrParam.coeff[1][1] = 0x3ac;
    prevParams.rgb2ycbcrParam.coeff[1][2] = 0x82;
    prevParams.rgb2ycbcrParam.coeff[2][0] = 0x82;
    prevParams.rgb2ycbcrParam.coeff[2][1] = 0x395;
    prevParams.rgb2ycbcrParam.coeff[2][2] = 0x3eb;

    prevParams.rgb2ycbcrParam.yOffset     = 0;
    prevParams.rgb2ycbcrParam.cbOffset    = 0;
    prevParams.rgb2ycbcrParam.crOffset    = 0;

    /* Set Black adjustment parameters */
    prevParams.blackAdjParam.blueAdj      = 0;
    prevParams.blackAdjParam.redAdj       = 0;
    prevParams.blackAdjParam.greenAdj     = 0;

    /*brightness and Contrast*/
    prevParams.brightness = 0x20u;
    prevParams.contrast   = 0x10u;

    /*CFA*/
    prevParams.features       =  PSP_PREVIEWER_CFA;
    for (i=0; i< PSP_PREVIEWER_CFA_COEFF_TABLE_SIZE; i++)
    {
        prevParams.cfaCoeffsParam.coeffs[i] = cfa_coef[i];
    }
    prevParams.cfaCoeffsParam.vThreshold = 0x28;
    prevParams.cfaCoeffsParam.hThreshold = 0x28;

    /* output format */
    prevParams.outPixelOrderParam = PSP_PREVIEWER_PIXELORDER_YCBYCR;
}
/**
 * \brief   prevOpen
 *          This function opens the Previewer channel
 *
 * \returns Success or error code
 */
Int32 prevOpen()
{
    Int32 prevOpenReturnCode = -1;
    PSP_previewerChannelCreateMode prevOpenPrevChannel;

    prevOpenPrevChannel.chanSource.source = PSP_PREVIEWER_CHANNEL_SDRAM;
    prevOpenPrevChannel.segId = 0;

    /* parameter validation */
    if (NULL == prevDeviceName)
    {
        prevOpenReturnCode = -1;
    }
    else
    {
        /* open channel handle */
        prevHandle = GIO_create(prevDeviceName, IOM_INOUT, NULL,
            &prevOpenPrevChannel, NULL);
        /* check that channel is open successfully or not */
        if (NULL == prevHandle)
        {
            prevOpenReturnCode = -1;
        }
        else
        {
            prevOpenReturnCode = 0;
        }
    }
    return prevOpenReturnCode;
}
/**
 * \brief   prevConfig
 *          This function configures previewer hardware
 *
 * \returns Success or error code
 */
Int32 prevConfig()
{
    Int32 prevConfigReturnCode = -1;
    Int32 prevConfigIOMReturnCode = IOM_EBADMODE;

    /* parameter validation */
    if (NULL == prevHandle)
    {
        prevConfigReturnCode = -1;
    }
    else
    {
        GetPreviewerParams();

        /* call IOCTL to set parameters */
        prevConfigIOMReturnCode = GIO_control(prevHandle,
            PSP_PREVIEWER_IOCTL_SET_PARAMS, &prevParams);

        /* check that parameters are configured properly or not */
        if (IOM_COMPLETED != prevConfigIOMReturnCode)
        {
            prevConfigReturnCode = -1;
        }
        else
        {
            prevConfigReturnCode = 0;
        }
    }
    return prevConfigReturnCode;
}
/**
 * \brief   prevPreview
 *          This function triggers previewer
 *
 * \returns Success or error code
 */
Int32 prevPreview(PSP_preview *prevPreviewParams)
{
    Int32 prevPreviewReturnCode = -1;
    Int32 prevPreviewIOMReturnCode = IOM_EBADMODE;

    /* parameter validation */
    if (NULL == prevHandle)
    {
        prevPreviewReturnCode = -1;
    }
    else
    {
        /* call IOCTL to trigger previewer */
        prevPreviewIOMReturnCode = GIO_control(prevHandle,
            PSP_PREVIEWER_IOCTL_PREVIEW, prevPreviewParams);

        /* check that previewing operation is completed successfully */
        if (IOM_COMPLETED != prevPreviewIOMReturnCode)
        {
            prevPreviewReturnCode = -1;
        }
        else
        {
            prevPreviewReturnCode = 0;
        }
    }
    return prevPreviewReturnCode;
}
/**
 * \brief   prevClose
 *          This function closes the previewer channel
 *
 * \returns Success or error code
 */
Int32 prevClose()
{
    Int32 prevCloseReturnCode = -1;
    Int32 prevCloseIOMReturnCode = IOM_EBADMODE;

    /* parameter validation */
    if (NULL == prevHandle)
    {
        prevCloseReturnCode = -1;
    }
    else
    {
        /* call IOCTL to delete channel */
        prevCloseIOMReturnCode = GIO_delete(prevHandle);

        /* check that channel is deleted properly or not */
        if (IOM_COMPLETED != prevCloseIOMReturnCode)
        {
            prevCloseReturnCode = -1;
        }
        else
        {
            prevCloseReturnCode = 0;
        }
    }
    return prevCloseReturnCode;
}

