/*******************************************************************************
**+--------------------------------------------------------------------------+**
**|                            ****                                          |**
**|                            ****                                          |**
**|                            ******o***                                    |**
**|                      ********_///_****                                   |**
**|                      ***** /_//_/ ****                                   |**
**|                       ** ** (__/ ****                                    |**
**|                           *********                                      |**
**|                            ****                                          |**
**|                            ***                                           |**
**|                                                                          |**
**|         Copyright (c) 2006-2010 Texas Instruments Incorporated           |**
**|                        ALL RIGHTS RESERVED                               |**
**|                                                                          |**
**| Permission is hereby granted to licensees of Texas Instruments           |**
**| Incorporated (TI) products to use this computer program for the sole     |**
**| purpose of implementing a licensee product based on TI products.         |**
**| No other rights to reproduce, use, or disseminate this computer          |**
**| program, whether in part or in whole, are granted.                       |**
**|                                                                          |**
**| TI makes no representation or warranties with respect to the             |**
**| performance of this computer program, and specifically disclaims         |**
**| any responsibility for any damages, special or consequential,            |**
**| connected with the use of this program.                                  |**
**|                                                                          |**
**+--------------------------------------------------------------------------+**
*******************************************************************************/
/** \file   psp_resizer_application.c
 *
 *  \brief  VPSS integration Application Resizer implementation file
 *
 *  (C) Copyright 2010, Texas Instruments, Inc
 *
 *  \author     EI
 *
 *  \version    1.0     Created
 */

/****************************************************************************
  HEADER FILE INCLUSION
 *****************************************************************************/
#include<stdio.h>
#include <std.h>
#include <gio.h>
#include <ti/sdo/pspdrivers/drivers/resizer/psp_resizer.h>
#include <ti/sdo/pspdrivers/system/dm6437/bios/evmDM6437/video/sample/psp_resizer_application.h>
#include <ti/sdo/pspdrivers/system/dm6437/bios/evmDM6437/video/sample/psp_vpss_integrated.h>


/******************************************************************************
  Data-Structures
 ******************************************************************************/

/* resizer channel handle */
GIO_Handle rszHandle = NULL;

/* resizer device name */
String rszDeviceName = "/resizer";

/* resizer parameters */
/* make rszParams 4 bytes aligned */
#pragma DATA_ALIGN(rszParams, 4);
PSP_RSZparams rszParams;

Uint16 gRDRV_reszFilter4TapHighQuality[RDRV_RESZ_SPEC__MAX_FILTER_COEFF] =
{
    COEF((1u), (4u)), COEF((1u), (4u)), COEF((1u), (4u)), COEF((1u), (4u)),
    COEF((1u), (4u)), COEF((1u), (4u)), COEF((1u), (4u)), COEF((1u), (4u)),

    COEF((1u), (4u)), COEF((1u), (4u)), COEF((1u), (4u)), COEF((1u), (4u)),
    COEF((1u), (4u)), COEF((1u), (4u)), COEF((1u), (4u)), COEF((1u), (4u)),

    COEF((1u), (4u)), COEF((1u), (4u)), COEF((1u), (4u)), COEF((1u), (4u)),
    COEF((1u), (4u)), COEF((1u), (4u)), COEF((1u), (4u)), COEF((1u), (4u)),

    COEF((1u), (4u)), COEF((1u), (4u)), COEF((1u), (4u)), COEF((1u), (4u)),
    COEF((1u), (4u)), COEF((1u), (4u)), COEF((1u), (4u)), COEF((1u), (4u))
};

Uint16 gRDRV_reszFilter7TapHighQuality[RDRV_RESZ_SPEC__MAX_FILTER_COEFF] =
{
    COEF((1u), (7u)), COEF((1u), (7u)), COEF((1u), (7u)), COEF((1u), (7u)),
    COEF((1u), (7u)), COEF((1u), (7u)), COEF((1u), (7u)), 0,

    COEF((1u), (7u)), COEF((1u), (7u)), COEF((1u), (7u)), COEF((1u), (7u)),
    COEF((1u), (7u)), COEF((1u), (7u)), COEF((1u), (7u)), 0,

    COEF((1u), (7u)), COEF((1u), (7u)), COEF((1u), (7u)), COEF((1u), (7u)),
    COEF((1u), (7u)), COEF((1u), (7u)), COEF((1u), (7u)), 0,

    COEF((1u), (7u)), COEF((1u), (7u)), COEF((1u), (7u)), COEF((1u), (7u)),
    COEF((1u), (7u)), COEF((1u), (7u)), COEF((1u), (7u)), 0,
};

/******************************************************************************
  Functions
 ******************************************************************************/
/**
 * \brief   GetResizerParams
 *          Gets Resizer configuration parameter's values into corresponding
 *          field of structure.
 *
 */
void GetResizerParams()
{
    int i = 0;
    int vRatio = 0;
    int hRatio = 0;

    rszParams.inVsize = INPUT_IMAGE_HEIGHT; /* only 1 filed of NTSC image */
    rszParams.inHsize = INPUT_IMAGE_WIDTH;
    rszParams.inPitch = INPUT_IMAGE_WIDTH * 2;

    rszParams.cbilin = 0;      /* filter with luma for low pass */

    rszParams.pixfmt = PSP_RSZ_PIX_FMT_YUYV;

    rszParams.outVsize = OUTPUT_IMAGE_HEIGHT;
    rszParams.outHsize = OUTPUT_IMAGE_WIDTH;
    rszParams.outPitch = OUTPUT_IMAGE_WIDTH * 2;

    rszParams.vertStartingPixel =0;
    rszParams.horzStartingPixel =0;
    rszParams.inptyp = PSP_RSZ_INTYPE_YCBCR422_16BIT;
    rszParams.hstph = 0;
    rszParams.vstph = 0;
    rszParams.yenhParams.type = PSP_RSZ_YENH_DISABLE;

    vRatio = (rszParams.inVsize * 256) / rszParams.outVsize;

    hRatio = (rszParams.inHsize * 256) / rszParams.outHsize;

    /* If the resize ratio is less between 1/2x to 4x use
     * these coefficients else use  gRDRV_reszFilter7TapHighQuality */

    for (i=0; i < 32; i++)
    {
        if ((hRatio >= 64) && (hRatio <= 512))
        {

            rszParams.hfiltCoeffs[i]
                = (Int16)gRDRV_reszFilter4TapHighQuality[i];
        }
        else
        {
            rszParams.hfiltCoeffs[i]
                = (Int16)gRDRV_reszFilter7TapHighQuality[i];

        }
    }

    for (i=0; i < 32; i++)
    {
        if ((vRatio >= 64) && (vRatio <= 512))
        {

            rszParams.vfiltCoeffs[i]
                = (Int16)gRDRV_reszFilter4TapHighQuality[i];
        }
        else
        {
            rszParams.vfiltCoeffs[i]
                = (Int16)gRDRV_reszFilter7TapHighQuality[i];

        }
    }


    return;
}
/**
 * \brief   rszOpen
 *          This function opens the resizer channel
 *
 * \returns Success or error code
 */
Int32 rszOpen()
{
    Int32 rszOpenReturnCode = -1;
    Int32 segId = 0;

    /* parameter validation */
    if (NULL == rszDeviceName)
    {
        rszOpenReturnCode = -1;
    }
    else
    {
        /* open channel handle */
        rszHandle = GIO_create(rszDeviceName, IOM_INOUT, NULL,
            (Ptr)(&segId), NULL);

        /* check that channel is open successfully or not */
        if (NULL == rszHandle)
        {
            rszOpenReturnCode = -1;
        }
        else
        {
            rszOpenReturnCode = 0;
        }
    }
    return rszOpenReturnCode;
}
/**
 * \brief   rszConfig
 *          This function configures resizer hardware
 *
 * \returns Success or error code
 */
Int32 rszConfig()
{
    Int32 rszConfigReturnCode = -1;
    Int32 rszConfigIOMReturnCode = IOM_EBADMODE;

    /* parameter validation */
    if (NULL == rszHandle)
    {
        rszConfigReturnCode = -1;
    }
    else
    {
        GetResizerParams();

        /* call IOCTL to set parameters */
        rszConfigIOMReturnCode = GIO_control(rszHandle,
            PSP_RSZ_IOCTL_SET_PARAMS, &rszParams);

        /* check that parameters are configured properly or not */
        if (IOM_COMPLETED != rszConfigIOMReturnCode)
        {
            rszConfigReturnCode = -1;
        }
        else
        {
            rszConfigReturnCode = 0;
        }
    }
    return rszConfigReturnCode;

}
/**
 * \brief   rszResize
 *          This function triggers resizer
 *
 * \returns Success or error code
 */
Int32 rszResize(PSP_RSZresize *rszResizeParams)
{
    Int32 rszResizeReturnCode = -1;
    Int32 rszResizeIOMReturnCode = IOM_EBADMODE;


    /* parameter validation */
    if (NULL == rszHandle)
    {
        rszResizeReturnCode = -1;
    }
    else
    {
        /* call IOCTL to trigger rsziewer */
        rszResizeIOMReturnCode = GIO_control(rszHandle,
            PSP_RSZ_IOCTL_RESIZE, rszResizeParams);

        /* check that resizinging operation is completed successfully */
        if (IOM_COMPLETED != rszResizeIOMReturnCode)
        {
            rszResizeReturnCode = -1;
        }
        else
        {
            rszResizeReturnCode = 0;
        }
    }
    return rszResizeReturnCode;

}
/**
 * \brief   rszClose
 *          This function closes the resizer channel
 *
 * \returns Success or error code
 */
Int32 rszClose()
{
    Int32 rszCloseReturnCode = -1;
    Int32 rszCloseIOMReturnCode = IOM_EBADMODE;

    /* parameter validation */
    if (NULL == rszHandle)
    {
        rszCloseReturnCode = -1;
    }
    else
    {
        /* call IOCTL to delete channel */
        rszCloseIOMReturnCode = GIO_delete(rszHandle);

        /* check that channel is deleted properly or not */
        if (IOM_COMPLETED != rszCloseIOMReturnCode)
        {
            rszCloseReturnCode = -1;
        }
        else
        {
            rszCloseReturnCode = 0;
        }
    }
    return rszCloseReturnCode;

}

