/*******************************************************************************
**+--------------------------------------------------------------------------+**
**|                            ****                                          |**
**|                            ****                                          |**
**|                            ******o***                                    |**
**|                      ********_///_****                                   |**
**|                      ***** /_//_/ ****                                   |**
**|                       ** ** (__/ ****                                    |**
**|                           *********                                      |**
**|                            ****                                          |**
**|                            ***                                           |**
**|                                                                          |**
**|         Copyright (c) 2006-2010 Texas Instruments Incorporated           |**
**|                        ALL RIGHTS RESERVED                               |**
**|                                                                          |**
**| Permission is hereby granted to licensees of Texas Instruments           |**
**| Incorporated (TI) products to use this computer program for the sole     |**
**| purpose of implementing a licensee product based on TI products.         |**
**| No other rights to reproduce, use, or disseminate this computer          |**
**| program, whether in part or in whole, are granted.                       |**
**|                                                                          |**
**| TI makes no representation or warranties with respect to the             |**
**| performance of this computer program, and specifically disclaims         |**
**| any responsibility for any damages, special or consequential,            |**
**| connected with the use of this program.                                  |**
**|                                                                          |**
**+--------------------------------------------------------------------------+**
*******************************************************************************/
/** \file   psp_vpss_integrated.c
 *
 *  \brief  This file contains the test / demo code to demonstrate the
 *          VPSS driver implemented using the GIO Framework Architecture
 *
 *          This test application does the loopback Application.Here CCDC and
 *          previewer is configured in one shot mode.CCDC driver capture
 *          Raw image put it into memory, previewer will read that image and
 *          which converts the RAW image into YUV and put image into memory.
 *          Resizer will read this YUV image from memory and will do resizing
 *          operation.
 *          This image will be given to Video Back End driver to display
 *          image on display Screen.
 *
 *
 *  (C) Copyright 2010, Texas Instruments, Inc
 *
 *  \author     EI
 *
 *  \version    1.0     Created
 */

/****************************************************************************
  HEADER FILE INCLUSION
 *****************************************************************************/

#include <stdio.h>
#include <string.h>
#include <std.h>
#include <gio.h>
#include <ti/sdo/pspdrivers/pal_sys/dm6437/pal_sys.h>
#include <ti/sdo/pspdrivers/soc/dm6437/dsp/cslr_sys.h>
#include <ti/sdo/pspdrivers/soc/dm6437/dsp/soc.h>
#include <ti/sdo/edma3/drv/edma3_drv.h>
#include <ti/sdo/pspdrivers/pal_os/pal_oscache.h>
#include <ti/sdo/pspdrivers/system/dm6437/bios/evmDM6437/video/fvid.h>
#include <ti/sdo/pspdrivers/system/dm6437/bios/evmDM6437/video/fvid_evmDM6437.h>
#include <ti/sdo/pspdrivers/system/dm6437/bios/evmDM6437/video/src/MT9001_extImageSensor.h>
#include <ti/sdo/pspdrivers/drivers/vpfe/psp_vpfe.h>
#include <ti/sdo/pspdrivers/drivers/previewer/psp_previewer.h>
#include <ti/sdo/pspdrivers/drivers/vpbe/psp_vpbe.h>
#include <ti/sdo/pspdrivers/common/psp_common.h>
#include <ti/sdo/pspdrivers/system/dm6437/bios/evmDM6437/video/sample/psp_previewer_application.h>
#include <ti/sdo/pspdrivers/system/dm6437/bios/evmDM6437/video/sample/psp_resizer_application.h>
#include <ti/sdo/pspdrivers/system/dm6437/bios/evmDM6437/video/sample/psp_h3a_application.h>
#include <ti/sdo/pspdrivers/system/dm6437/bios/evmDM6437/video/sample/psp_histogram_application.h>
#include <ti/sdo/pspdrivers/system/dm6437/bios/evmDM6437/video/sample/psp_vpss_integrated.h>

/******************************************************************************
  Data-Structures
 ******************************************************************************/
static FVID_Frame  *allocatedCCDCFrameBuffers[
NO_OF_CCDC_OUTPUT_BUFFERS + 1];

#ifndef PSP_VIDEO_PATH_ENABLE
static FVID_Frame  *allocatedVideoFrameBuffers[
NO_OF_VIDEO_INPUT_BUFFERS];
#endif /* PSP_VIDEO_PATH_ENABLE */

/* this arrays will not be used directly, they will be used as buffer in
 * FVID_Frame instance */

/* make arrayPoolCCDC0 32 bytes aligned */
#pragma DATA_ALIGN(arrayPoolCCDC0, 32);
Uint8 arrayPoolCCDC0[sizeof(FVID_Frame)];

/* make arrayPoolCCDC1 32 bytes aligned */
#pragma DATA_ALIGN(arrayPoolCCDC1, 32);
Uint8 arrayPoolCCDC1[sizeof(FVID_Frame)];

#ifndef PSP_VIDEO_PATH_ENABLE
/* make arrayPoolCCDC2 32 bytes aligned */
#pragma DATA_ALIGN(arrayPoolCCDC2, 32);
Uint8 arrayPoolCCDC2[sizeof(FVID_Frame)];
#endif /* PSP_VIDEO_PATH_ENABLE */


#ifndef PSP_VIDEO_PATH_ENABLE
/* make arrayPoolVideo0 32 bytes aligned */
#pragma DATA_ALIGN(arrayPoolVideo0, 32);
Uint8 arrayPoolVideo0[sizeof(FVID_Frame)];

/* make arrayPoolVideo1 32 bytes aligned */
#pragma DATA_ALIGN(arrayPoolVideo1, 32);
Uint8 arrayPoolVideo1[sizeof(FVID_Frame)];
#endif /* PSP_VIDEO_PATH_ENABLE */


/* make arrayPoolBufferCCDC0 128 bytes aligned */
#pragma DATA_ALIGN(arrayPoolBufferCCDC0, 128);
Uint8 arrayPoolBufferCCDC0[((INPUT_IMAGE_HEIGHT + 1) * INPUT_IMAGE_WIDTH
    * (BPP_CCDC/8))];

/* make arrayPoolBufferCCDC1 128 bytes aligned */
#pragma DATA_ALIGN(arrayPoolBufferCCDC1, 128);
Uint8 arrayPoolBufferCCDC1[((INPUT_IMAGE_HEIGHT + 1) * INPUT_IMAGE_WIDTH
   * (BPP_CCDC/8))];

#ifndef PSP_VIDEO_PATH_ENABLE
/* make arrayPoolBufferCCDC2 128 bytes aligned */
#pragma DATA_ALIGN(arrayPoolBufferCCDC2, 128);
Uint8 arrayPoolBufferCCDC2[((INPUT_IMAGE_HEIGHT + 1) * INPUT_IMAGE_WIDTH
   * (BPP_CCDC/8))];
#endif /* PSP_VIDEO_PATH_ENABLE */

#ifndef PSP_VIDEO_PATH_ENABLE
/* make arrayPoolBufferVideo0 128 bytes aligned */
#pragma DATA_ALIGN(arrayPoolBufferVideo0, 128);
Uint8 arrayPoolBufferVideo0[(OUTPUT_IMAGE_HEIGHT * OUTPUT_IMAGE_WIDTH * 2)];

/* make arrayPoolBufferVideo1 128 bytes aligned */
#pragma DATA_ALIGN(arrayPoolBufferVideo1, 128);
Uint8 arrayPoolBufferVideo1[(OUTPUT_IMAGE_HEIGHT * OUTPUT_IMAGE_WIDTH * 2)];
#endif /* PSP_VIDEO_PATH_ENABLE */

#ifndef PSP_VIDEO_PATH_ENABLE
/* this buffer will be used for intermediate buffer between previewer and
 * resizer */
/* make intermediateBuffer 128 bytes aligned */
#pragma DATA_ALIGN(intermediateBuffer, 128);
Uint8 intermediateBuffer[INPUT_IMAGE_HEIGHT * INPUT_IMAGE_WIDTH * 2];
#endif /* PSP_VIDEO_PATH_ENABLE */

#define FRAME_COUNT       (1000)

/******************************************************************************
  Global Variables
 ******************************************************************************/

extern far SEM_Obj tskSyncSemEntry;
extern far SEM_Obj tskSyncSemExit;
GIO_Handle ccdcHandle = NULL;
PSP_VPFEChannelParams feinitParams;
Int32 frameCnt = 0;
Int32 slaveFrameCnt = 0;

GIO_Handle vid0Handle = NULL;
GIO_Handle vencHandle = NULL;
PSP_VPBEChannelParams beinitParams;

#ifndef PSP_VIDEO_PATH_ENABLE
PSP_preview prevPreviewParams;
PSP_RSZresize rszResizeParams;
#else
PSP_H3AChannelType h3aAFType = PSP_H3A_AF;
PSP_H3AChannelType h3aAEWType = PSP_H3A_AEW;
#endif /* PSP_VIDEO_PATH_ENABLE */

Int32 errorCode = -1;
Int32 slaveErrorCode = -2;

static PSP_VPFECcdcConfigParams ccdcParams =
{
    FVID_CCDC_RAW_FORMAT,               /* dataFlow     */
    FVID_FIELD_MODE,                    /* ffMode       */
    INPUT_IMAGE_HEIGHT + 1,             /* height       */
    INPUT_IMAGE_WIDTH,                  /* width        */
    (INPUT_IMAGE_WIDTH * BPP_CCDC)/(8u),/* pitch        */
    0,                                  /* horzStartPix */
    0,                                  /* vertStartPix */
    NULL,                               /* appCallback  */
    {
        MT9001_Open,                    /* extVD Fxn    */
        MT9001_Close,
        MT9001_Control,
    },
    0,                                  /*segId         */
    {
        PSP_VPFE_BITS10,                 /* dataSize     */
        PSP_VPFE_PACK8_16BITS_PIXEL,     /* pack8        */
        PSP_VPFE_DataPol_Normal,        /* dataPol      */
        PSP_VPFE_SyncPol_Positive,      /* VDSyncPol    */
        PSP_VPFE_SyncPol_Positive,      /* HDSyncPol    */
        PSP_VPFE_SyncDir_Input,         /* HDVDMaster   */
        50,                             /* HDSyncWidth  */
        4,                              /* VDSyncWidth  */
        800,                            /* numPxlPerLine*/
        1000,                           /* numLinPerFld */
        PSP_VPFE_ALaw_Disable,          /* ALawEnable   */
        PSP_VPFE_ALaw_bits15_6,         /* ALaw_Width   */
    }
};

#ifndef PSP_VIDEO_PATH_ENABLE
static PSP_VPBEVencConfigParams vencParams =
{
    PSP_VPBE_DISPLAY_NTSC_INTERLACED_COMPOSITE /* Display Standard */
};
#endif /* PSP_VIDEO_PATH_ENABLE */

static CSL_SysRegsOvly sysModuleRegs = (CSL_SysRegsOvly )CSL_SYS_0_REGS;

/*************************************************************************
  Vide0 0 Plane Configuration Parameter
 *************************************************************************/
#ifndef PSP_VIDEO_PATH_ENABLE
static PSP_VPBEOsdConfigParams  vid0Params;
#endif /* PSP_VIDEO_PATH_ENABLE */

static MT9001_StandardFormat stdFormat;

/******************************************************************************
  Functions
 ******************************************************************************/
/* Function to initialize the EDMA3 driver */
extern EDMA3_DRV_Result edma3init();
/* Function to uninitialize the EDMA3 driver */
extern EDMA3_DRV_Result edma3deinit();

/**
 * \brief   I2C_INIT
 *          This function is used to Initialize the I2C Bus Driver
 *
 */
void I2C_INIT()
{
    /*Power On I2C*/
    if (PAL_SOK !=
        PAL_sysModuleClkCtrl(PAL_SYS_CLK_MODULE_I2C, PAL_SYS_MODULE_CLK_ENABLE))
    {
        return;
    }
}

#ifndef PSP_VIDEO_PATH_ENABLE
/**
 * \brief   getVid0ConfigParams
 *          This function configures the parameters for VPBE
 *
 */
static Ptr getVid0ConfigParams(void)
{
    vid0Params.ffMode                       = FVID_FRAME_MODE;
    vid0Params.bitsPerPixel                 = FVID_BPP_BITS16;
    vid0Params.colorFormat                  = FVID_YCbCr422_INTERLEAVED;
    vid0Params.pitch                        = (OUTPUT_IMAGE_WIDTH * 2);
    vid0Params.width                        = OUTPUT_IMAGE_WIDTH;
    vid0Params.height                       = OUTPUT_IMAGE_HEIGHT;
    vid0Params.leftMargin                   = 0;
    vid0Params.topMargin                    = 0;
    vid0Params.blending                     = PSP_VPBE_BLEND1;
    vid0Params.hExpansion                   = PSP_VPBE_EXP_IDENTITY;
    vid0Params.vExpansion                   = PSP_VPBE_EXP_IDENTITY;
    vid0Params.hScaling                     = PSP_VPBE_ZOOM_IDENTITY;
    vid0Params.vScaling                     = PSP_VPBE_ZOOM_IDENTITY;
    vid0Params.appCallback                  = NULL;
    vid0Params.segId                        = 0;

    return ((Ptr)&vid0Params);
}
#endif /* PSP_VIDEO_PATH_ENABLE */
/**
 * \brief   closeAllHandle
 *          This function closes all the drivers
 *
 */
static void closeAllHandle()
{
#ifndef PSP_VIDEO_PATH_ENABLE
    prevClose();
    rszClose();
#else
    h3aClose(&h3aAFType);
    h3aClose(&h3aAEWType);
    histClose();
#endif /* PSP_VIDEO_PATH_ENABLE */
    if (NULL != ccdcHandle)
    {
        FVID_delete(ccdcHandle);
        ccdcHandle = NULL;
    }
    if (NULL != vid0Handle)
    {
        FVID_delete(vid0Handle);
        vid0Handle = NULL;
    }
    if (NULL != vencHandle)
    {
        FVID_delete(vencHandle);
        vencHandle = NULL;
    }
    return;
}

#ifndef PSP_VIDEO_PATH_ENABLE
/**
 * \brief   prevFormatVideoInput
 *          This function formats the input
 *
 */
static void prevFormatVideoInput(Uint32 inBuffer[],
    Uint32 size, PSP_previewerOutPixelOrder outOrder)
{
    Uint32 index;
    Uint32* tempInBuffer;
    Uint8 firstByte;
    Uint8 secondByte;
    Uint8 thirdByte;
    Uint8 fourthByte;
    Uint8* tempOutBuffer;

    if (NULL != inBuffer)
    {
        tempInBuffer = inBuffer;
        if (NULL != tempInBuffer)
        {
            for (index = 0; index < size; index += 4)
            {
                firstByte = (*tempInBuffer);
                secondByte = ((*tempInBuffer) >> 8) & 0xFF;
                thirdByte = ((*tempInBuffer) >> 16) & 0xFF;
                fourthByte = ((*tempInBuffer) >> 24) & 0xFF;
                tempOutBuffer = (Uint8*)tempInBuffer;
                tempInBuffer++;
                if (NULL != tempOutBuffer)
                {
                    switch(outOrder)
                    {
                        case PSP_PREVIEWER_PIXELORDER_YCBYCR:
                            *tempOutBuffer = thirdByte;
                            tempOutBuffer++;
                            *tempOutBuffer = secondByte;
                            tempOutBuffer++;
                            *tempOutBuffer = firstByte;
                            tempOutBuffer++;
                            *tempOutBuffer = fourthByte;
                            tempOutBuffer++;
                            break;
                        case PSP_PREVIEWER_PIXELORDER_YCRYCB:
                            *tempOutBuffer = firstByte;
                            tempOutBuffer++;
                            *tempOutBuffer = secondByte;
                            tempOutBuffer++;
                            *tempOutBuffer = thirdByte;
                            tempOutBuffer++;
                            *tempOutBuffer = fourthByte;
                            tempOutBuffer++;
                            break;
                        case PSP_PREVIEWER_PIXELORDER_CBYCRY:
                            *tempOutBuffer = fourthByte;
                            tempOutBuffer++;
                            *tempOutBuffer = firstByte;
                            tempOutBuffer++;
                            *tempOutBuffer = secondByte;
                            tempOutBuffer++;
                            *tempOutBuffer = thirdByte;
                            tempOutBuffer++;
                            break;
                        case PSP_PREVIEWER_PIXELORDER_CRYCBY:
                            *tempOutBuffer = secondByte;
                            tempOutBuffer++;
                            *tempOutBuffer = firstByte;
                            tempOutBuffer++;
                            *tempOutBuffer = fourthByte;
                            tempOutBuffer++;
                            *tempOutBuffer = thirdByte;
                            tempOutBuffer++;
                            break;
                        default:
                            break;
                    }
                }

            }
        }
    }
}
#endif /* PSP_VIDEO_PATH_ENABLE */
/**
 * \brief   vpss_main
 *          This function executes all the DM6437 drivers
 *
 */
static void vpss_main()
{
    GIO_Attrs gioAttrs = GIO_ATTRS;
    FVID_Frame *ptrSP = NULL;
    Ptr                      ptrFB = NULL;
    FVID_Frame *FBCCDCAddr = NULL;
#ifndef PSP_VIDEO_PATH_ENABLE
    Uint32 j = 0;
    Uint8 firstByte;
    Uint8 secondByte;
    Uint8 thirdByte;
    Uint8 fourthByte;
    FVID_Frame *FBVideoAddr = NULL;
#endif /* PSP_VIDEO_PATH_ENABLE */
    Int32 returnCode;
    Int32 loopFlag = TRUE;
    Int32 ret;

    ptrSP = (FVID_Frame*)arrayPoolCCDC0;
    ptrFB = arrayPoolBufferCCDC0;

    ptrSP->pitch            = INPUT_IMAGE_WIDTH * (BPP_CCDC/8);
    ptrSP->lines            = INPUT_IMAGE_HEIGHT;
    ptrSP->bpp              = FVID_BPP_BITS16;
    ptrSP->frame.frameBufferPtr   = ptrFB;
    allocatedCCDCFrameBuffers[0]    = ptrSP;

    ptrSP = (FVID_Frame*)arrayPoolCCDC1;
    ptrFB = arrayPoolBufferCCDC1;

    ptrSP->pitch            = INPUT_IMAGE_WIDTH * (BPP_CCDC/8);
    ptrSP->lines            = INPUT_IMAGE_HEIGHT;
    ptrSP->bpp              = FVID_BPP_BITS16;
    ptrSP->frame.frameBufferPtr   = ptrFB;
    allocatedCCDCFrameBuffers[1]    = ptrSP;

#ifndef PSP_VIDEO_PATH_ENABLE
    ptrSP = (FVID_Frame*)arrayPoolCCDC2;
    ptrFB = arrayPoolBufferCCDC2;

    ptrSP->pitch            = INPUT_IMAGE_WIDTH * (BPP_CCDC/8);
    ptrSP->lines            = INPUT_IMAGE_HEIGHT;
    ptrSP->bpp              = FVID_BPP_BITS16;
    ptrSP->frame.frameBufferPtr   = ptrFB;
    allocatedCCDCFrameBuffers[2]    = ptrSP;
#endif /* PSP_VIDEO_PATH_ENABLE */


#ifndef PSP_VIDEO_PATH_ENABLE
    /* Allocate Memory to Video Buffers */
    ptrSP = (FVID_Frame*)arrayPoolVideo0;
    ptrFB = arrayPoolBufferVideo0;

    ptrSP->pitch            = OUTPUT_IMAGE_WIDTH * 2;
    ptrSP->lines            = OUTPUT_IMAGE_HEIGHT;
    ptrSP->bpp              = FVID_BPP_BITS8;
    ptrSP->frame.frameBufferPtr   = ptrFB;
    allocatedVideoFrameBuffers[0]    = ptrSP;


    ptrSP = (FVID_Frame*)arrayPoolVideo1;
    ptrFB = arrayPoolBufferVideo1;

    ptrSP->pitch            = OUTPUT_IMAGE_WIDTH * 2;
    ptrSP->lines            = OUTPUT_IMAGE_HEIGHT;
    ptrSP->bpp              = FVID_BPP_BITS8;
    ptrSP->frame.frameBufferPtr   = ptrFB;
    allocatedVideoFrameBuffers[1]    = ptrSP;
#endif /* PSP_VIDEO_PATH_ENABLE */

    /* Initialize the EDMA3 driver */
    ret = edma3init();

    if (EDMA3_DRV_SOK != ret)
    {
        INTEGRATION_APP_PRINT("\n EDMA initilizatioin failed \n ");
        return;
    }


    while(loopFlag)
    {

#ifndef PSP_VIDEO_PATH_ENABLE
        /* -----------------------| Open PREVIEWER Channel |-----------   */
        returnCode = prevOpen();
        if (0 != returnCode)
        {
            errorCode = -1;
            closeAllHandle();
            break;
        }
        /* --------------------| configure PREVIEWER channel |------------- */
        returnCode = prevConfig();
        if (0 != returnCode)
        {
            errorCode = -1;
            closeAllHandle();
            break;
        }
        /* initialize all buffer to black color Y, U, V = 0x00, 0x80, 0x80 */
        switch(prevParams.outPixelOrderParam)
        {
            case PSP_PREVIEWER_PIXELORDER_YCBYCR:
                firstByte  = 0x80;  /* Cr Value */
                secondByte = 0x0;   /* Y value */
                thirdByte  = 0x80;  /* Cb Value */
                fourthByte = 0x0;   /* Y value */
                break;
            case PSP_PREVIEWER_PIXELORDER_YCRYCB:
                firstByte  = 0x80;  /* Cb Value */
                secondByte = 0x0;   /* Y value */
                thirdByte  = 0x80;  /* Cr Value */
                fourthByte = 0x0;   /* Y value */
                break;
            case  PSP_PREVIEWER_PIXELORDER_CBYCRY:
                firstByte  = 0x0;   /* Y Value */
                secondByte = 0x80;  /* Cr value */
                thirdByte  = 0x0;   /* Y Value */
                fourthByte = 0x80;  /* Cb value */
                break;
            case PSP_PREVIEWER_PIXELORDER_CRYCBY:
                firstByte  = 0x0;   /* Y Value */
                secondByte = 0x80;  /* Cb value */
                thirdByte  = 0x0;   /* Y Value */
                fourthByte = 0x80;  /* Cr value */
                break;
        }
        ptrFB = intermediateBuffer;
        for(j=0;j < sizeof(arrayPoolBufferCCDC0);)
        {
            *((Uint8*)ptrFB+j) = firstByte;
            j++;
            *((Uint8*)ptrFB+j) = secondByte;
            j++;
            *((Uint8*)ptrFB+j) = thirdByte;
            j++;
            *((Uint8*)ptrFB+j) = fourthByte;
            j++;
        }
        /* -----------------------| Open RESIZER Channel |-----------   */
        returnCode = rszOpen();
        if (0 != returnCode)
        {
            errorCode = -1;
            closeAllHandle();
            break;
        }
        /* --------------------| configure RESIZER channel |------------- */
        returnCode = rszConfig();
        if (0 != returnCode)
        {
            errorCode = -1;
            closeAllHandle();
            break;
        }
#else
        /* -----------------------| Open H3A AF Channel |-----------   */

        returnCode = h3aOpen(&h3aAFType);
        if (0 != returnCode)
        {
            errorCode = -1;
            closeAllHandle();
            break;
        }
        /* --------------------| configure H3A AF channel |------------- */
        returnCode = h3aConfig(&h3aAFType);
        if (0 != returnCode)
        {
            errorCode = -1;
            closeAllHandle();
            break;
        }
        /* -----------------------| Open H3A AEW Channel |-----------   */

        returnCode = h3aOpen(&h3aAEWType);
        if (0 != returnCode)
        {
            errorCode = -1;
            closeAllHandle();
            break;
        }
        /* --------------------| configure H3A AEW channel |------------- */
        returnCode = h3aConfig(&h3aAEWType);
        if (0 != returnCode)
        {
            errorCode = -1;
            closeAllHandle();
            break;
        }

        /* -----------------------| Open Histogram Channel |-----------   */
        returnCode = histOpen();
        if (0 != returnCode)
        {
            errorCode = -1;
            closeAllHandle();
            break;
        }
        /* --------------------| configure Histogram channel |------------- */
        returnCode = histConfig();
        if (0 != returnCode)
        {
            errorCode = -1;
            closeAllHandle();
            break;
        }
        /* -----------| Enqueue First buffer in Histogram channel |------ */
        returnCode = histFirstEnqueue();
        if (0 != returnCode)
        {
            errorCode = -1;
            closeAllHandle();
            break;
        }


#endif /* PSP_VIDEO_PATH_ENABLE */

        /* -----------------------| Create CCDC Channel |----------------- */
        feinitParams.id         = PSP_VPFE_CCDC;
        feinitParams.params     = (PSP_VPFECcdcConfigParams*)&ccdcParams;
        ccdcHandle              = FVID_create("/VPFE0", IOM_INOUT, NULL,
            &feinitParams, &gioAttrs);
        if (NULL == ccdcHandle)
        {
            INTEGRATION_APP_PRINT("VPSS  :CCDC Create.......FAILED \r\n");
            errorCode = -1;
            closeAllHandle();
            break;
        }
        stdFormat = MT9T001_MODE_480p_30FPS;
        if (IOM_COMPLETED != FVID_control(ccdcHandle,
                VPFE_ExtVD_BASE+PSP_VPSS_EXT_VIDEO_DECODER_STD_FORMAT,
                &stdFormat))
        {
            INTEGRATION_APP_PRINT("VPSS  :MT9001.......FAILED \r\n");
            INTEGRATION_APP_PRINT(
                "VPSS  :End of VPSS Loopback Application\r\n");
            return;
        }

        FBCCDCAddr = allocatedCCDCFrameBuffers[0];
        if (NULL != FBCCDCAddr)
        {
            if (IOM_COMPLETED != FVID_queue(ccdcHandle, FBCCDCAddr))
            {
                INTEGRATION_APP_PRINT("VPSS  :CCDC Queuing.......FAILED \r\n");
                errorCode = -1;
                closeAllHandle();
                break;
            }
        }
        FBCCDCAddr = allocatedCCDCFrameBuffers[1];
        if (NULL != FBCCDCAddr)
        {
            if (IOM_COMPLETED != FVID_queue(ccdcHandle, FBCCDCAddr))
            {
                INTEGRATION_APP_PRINT("VPSS  :CCDC Queuing.......FAILED \r\n");
                errorCode = -1;
                closeAllHandle();
                break;
            }
        }
#ifndef PSP_VIDEO_PATH_ENABLE
        /* ----------------| Create VIDEO Channel |---------------------- */
        beinitParams.id     =   PSP_VPBE_VIDEO_0;
        beinitParams.params =   getVid0ConfigParams();
        vid0Handle          =   FVID_create("/VPBE0", IOM_INOUT, NULL,
            &beinitParams, &gioAttrs);
        if (NULL == vid0Handle)
        {
            INTEGRATION_APP_PRINT("VPSS  :VIDE0 -0 Create.......FAILED \r\n");
            errorCode = -1;
            closeAllHandle();
            break;
        }
        FBVideoAddr  =  allocatedVideoFrameBuffers[0];
        if (NULL != FBVideoAddr)
        {
            if (IOM_COMPLETED != FVID_queue(vid0Handle, FBVideoAddr))
            {
                INTEGRATION_APP_PRINT(
                    "VPSS  :Video 0 Queuing.......FAILED \r\n");
                errorCode = -1;
                closeAllHandle();
                break;
            }
        }
        /* -----------------| Create VENC Channel |------------------------ */
        beinitParams.id         = PSP_VPBE_VENC;
        beinitParams.params     = (PSP_VPBEVencConfigParams *)&vencParams;
        vencHandle              = FVID_create("/VPBE0", IOM_INOUT, NULL,
            &beinitParams, &gioAttrs);
        if (NULL == vencHandle)
        {
            INTEGRATION_APP_PRINT("VPSS  :Venc Create ... FAILED!\r\n");
            errorCode = -1;
            closeAllHandle();
            break;
        }
#endif /* PSP_VIDEO_PATH_ENABLE */
        INTEGRATION_APP_PRINT("VPSS  :VPSS Loopback Started \r\n");


#ifndef PSP_VIDEO_PATH_ENABLE
        FBCCDCAddr = allocatedCCDCFrameBuffers[2];
        FBVideoAddr = allocatedVideoFrameBuffers[1];
#endif /* PSP_VIDEO_PATH_ENABLE */
        /* give signal to slave task */
        SEM_post(&tskSyncSemEntry);

#ifndef PSP_VIDEO_PATH_ENABLE
        errorCode = 0;
        while(frameCnt < FRAME_COUNT)
        {
            frameCnt++;
            if (IOM_COMPLETED != FVID_exchange(ccdcHandle, &FBCCDCAddr))
            {
                INTEGRATION_APP_PRINT("VPSS: Error in CCDC Exchange\r\n");
                loopFlag = FALSE;
                errorCode = -1;
                break;
            }
            prevPreviewParams.inBuf = FBCCDCAddr->frame.frameBufferPtr;
            prevPreviewParams.outBuf = intermediateBuffer;
            prevPreviewParams.inBufSize = (INPUT_IMAGE_HEIGHT *
                INPUT_IMAGE_WIDTH * 2);
            prevPreviewParams.outBufSize = (INPUT_IMAGE_HEIGHT *
                INPUT_IMAGE_WIDTH * 2);

            /* ---------------------| Trigger PREVIEWER Channel |----------- */
            returnCode = prevPreview(&prevPreviewParams);
            if (0 != returnCode)
            {
                INTEGRATION_APP_PRINT("VPSS: Error in Previewer trigger\n");
                errorCode = -1;
                loopFlag = FALSE;
                break;
            }
            rszResizeParams.inBuf = intermediateBuffer;
            rszResizeParams.outBuf = FBVideoAddr->frame.frameBufferPtr;
            rszResizeParams.inBufSize = (INPUT_IMAGE_HEIGHT *
                INPUT_IMAGE_WIDTH * 2);
            rszResizeParams.outBufSize = (OUTPUT_IMAGE_HEIGHT *
                OUTPUT_IMAGE_WIDTH * 2);

            /* ---------------------| Trigger RESIZER Channel |----------- */
            returnCode = rszResize(&rszResizeParams);
            if (0 != returnCode)
            {
                INTEGRATION_APP_PRINT("VPSS: Error in Resizer trigger\n");
                errorCode = -1;
                loopFlag = FALSE;
                break;
            }
            PAL_osCacheInvalidate(
                (PAL_osCacheMemAddrSpace)NULL,
                (Uint32)(FBVideoAddr->frame.frameBufferPtr),
                OUTPUT_IMAGE_HEIGHT * OUTPUT_IMAGE_WIDTH * 2);
            prevFormatVideoInput(FBVideoAddr->frame.frameBufferPtr,
                (OUTPUT_IMAGE_HEIGHT * OUTPUT_IMAGE_WIDTH * 2),
                prevParams.outPixelOrderParam);

            PAL_osCacheFlushAndInvalidate(
                (PAL_osCacheMemAddrSpace)NULL,
                (Uint32)(FBVideoAddr->frame.frameBufferPtr),
                OUTPUT_IMAGE_HEIGHT * OUTPUT_IMAGE_WIDTH * 2);

            if (IOM_COMPLETED != FVID_exchange(vid0Handle, &FBVideoAddr))
            {
                INTEGRATION_APP_PRINT("VPSS: Error in CCDC Exchange\r\n");
                errorCode = -1;
                loopFlag = FALSE;
                break;
            }
        }
#endif /* PSP_VIDEO_PATH_ENABLE */
        /* wait till slave task completes its task */
        SEM_pend(&tskSyncSemExit, SYS_FOREVER);
        loopFlag = FALSE;

    }
    closeAllHandle();
    /* uninitialize the EDMA3 driver */
    edma3deinit();
    INTEGRATION_APP_PRINT("VPSS  :End of VPSS Loopback \r\n");
}
/**
 * \brief   vpss_main
 *         This function executes the vpss integrated application
 *
 */
void start_vpss_test()
{
    /* VPSS PinMuxing */
    /* CI10SEL   - No CI[1:0]                       */
    /* CI32SEL   - No CI[3:2]                       */
    /* CI54SEL   - No CI[5:4]                       */
    /* CI76SEL   - No CI[7:6]                       */
    /* CFLDSEL   - No C_FIELD                       */
    /* CWENSEL   - No C_WEN                         */
    /* HDVSEL    - CCDC HD and VD enabled           */
    /* CCDCSEL   - CCDC PCLK, YI[7:0] enabled       */
    /* AEAW      - EMIFA full address mode          */
    /* VPBECKEN  - VPBECLK enabled                  */
    /* RGBSEL    - No digital outputs               */
    /* CS3SEL    - LCD_OE/EM_CS3 disabled           */
    /* CS4SEL    - CS4/VSYNC enabled                */
    /* CS5SEL    - CS5/HSYNC enabled                */
    /* VENCSEL   - VCLK, YOUT[7:0], COUT[7:0] enabled */
    /* AEM       - 8bEMIF + 8bCCDC + 8 to 16bVENC   */
    sysModuleRegs -> PINMUX0    &= (0x005482A3u);
    sysModuleRegs -> PINMUX0    |= (0x005482A3u);

    /* PCIEN    =   0: PINMUX1 - Bit 0 */
    sysModuleRegs -> PINMUX1 &= (0xFFFFFFFEu);

    sysModuleRegs -> VPSS_CLKCTL = (0x18u);

    /* Run the VPSS Loopback Application */
    vpss_main();
    return;
}

/* slave task */
void vpss_slave_fun()
{
#ifdef PSP_VIDEO_PATH_ENABLE
    Int32 returnCode;
#endif /* PSP_VIDEO_PATH_ENABLE */
    /* wait until got signal from main task */
    SEM_pend(&tskSyncSemEntry, SYS_FOREVER);
#ifdef PSP_VIDEO_PATH_ENABLE
    slaveErrorCode = 0;
    while(slaveFrameCnt < FRAME_COUNT)
    {
        slaveFrameCnt++;
        /* --------------------| Enqueue H3A AF channel |------------- */
        returnCode = h3aEnqueue(&h3aAFType);
        if (0 != returnCode)
        {
            slaveErrorCode = -1;
            break;
        }
        /* --------------------| Enqueue H3A AEW channel |------------- */
        returnCode = h3aEnqueue(&h3aAEWType);
        if (0 != returnCode)
        {
            slaveErrorCode = -1;
            break;
        }
        /* --------------------| Enqueue Histogram channel |------------- */
        returnCode = histEnqueue();
        if (0 != returnCode)
        {
            slaveErrorCode = -1;
            break;
        }

        /* --------------------| Dequeue H3A AF channel |------------- */
        returnCode = h3aDequeue(&h3aAFType);
        if (0 != returnCode)
        {
            slaveErrorCode = -1;
            break;
        }

        /* --------------------| Dequeue H3A AEW channel |------------- */
        returnCode = h3aDequeue(&h3aAEWType);
        if (0 != returnCode)
        {
            slaveErrorCode = -1;
            break;
        }

        /* --------------------| Dequeue Histogram channel |------------- */
        returnCode = histDequeue();
        if (0 != returnCode)
        {
            slaveErrorCode = -1;
            break;
        }

        /* write stastics to file */
        if (0 == (slaveFrameCnt % 100))
        {
            AEW_DumpToFile();
            AF_DumpToFile();
            HIST_DumpToFile();
        }
    }
#endif /* PSP_VIDEO_PATH_ENABLE */
    /* once finished send signal to main task */
    SEM_post(&tskSyncSemExit);
}



/**
 * \brief   main
 *
 */
Int main()
{
    return 0;
}

