/******************************************************************************
**+-------------------------------------------------------------------------+**
**|                            ****                                         |**
**|                            ****                                         |**
**|                            ******o***                                   |**
**|                      ********_///_****                                  |**
**|                      ***** /_//_/ ****                                  |**
**|                       ** ** (__/ ****                                   |**
**|                           *********                                     |**
**|                            ****                                         |**
**|                            ***                                          |**
**|                                                                         |**
**|         Copyright (c) 2006-2010 Texas Instruments Incorporated          |**
**|                        ALL RIGHTS RESERVED                              |**
**|                                                                         |**
**| Permission is hereby granted to licensees of Texas Instruments          |**
**| Incorporated (TI) products to use this computer program for the sole    |**
**| purpose of implementing a licensee product based on TI products.        |**
**| No other rights to reproduce, use, or disseminate this computer         |**
**| program, whether in part or in whole, are granted.                      |**
**|                                                                         |**
**| TI makes no representation or warranties with respect to the            |**
**| performance of this computer program, and specifically disclaims        |**
**| any responsibility for any damages, special or consequential,           |**
**| connected with the use of this program.                                 |**
**|                                                                         |**
**+-------------------------------------------------------------------------+**
******************************************************************************/
/**
 *  \file   MT9001_extImageSensor.c
 *
 *  \brief  MT9001_extImageSensor related parameters
 *
 *  This file contains the interfaces, data types and symbolic definitions
 *  that are required for the MT9001_extImageSenore driver.
 *
 *  (C) Copyright 2010, Texas Instruments, Inc
 *
 *  \author     Maulik Desai
 *
 *  \version    0.1     Created
 */
/*-----------------------------------------------------------------------------
                    Header File Inclusion
-----------------------------------------------------------------------------*/
#include <std.h>
#include <tsk.h>
#include <ti/sdo/pspdrivers/system/dm6437/bios/evmDM6437/video/src/psp_i2c_interface.h>
#include <ti/sdo/pspdrivers/system/dm6437/bios/evmDM6437/video/src/MT9001_extImageSensor.h>
#include <ti/sdo/pspdrivers/pal_os/pal_osWait.h>

/**< MT9001 device object */
static MT9001_Object    mt9001Object;
/*-----------------------------------------------------------------------------
                    Function Definitions
-----------------------------------------------------------------------------*/
static Bool ConfigPCA9543A();
static Bool setMT9001Format(MT9001_Object        *mt9001handle,
                            MT9001_FormatParams  *mt9001formatParams);
static Bool setMT9001Std(MT9001_Object           *mt9001handle,
                         MT9001_StandardFormat   stdFormat);
static Bool setMT9001DefaultParams( MT9001_Object           *mt9001handle,
                                    MT9001_StandardFormat   stdFormat);
static Bool setMT9001Control(MT9001_Object              *mt9001Handle,
                             MT9001_ControlGainParams   *cntrlParamSC);

/* Parameters for  various format supported  */
/*Format  is
{
    NUMBER OF PIXELS PER LINE, NUMBER OF LINES,
    HRIZONTAL BLANKING WIDTH, VERTICAL BLANKING WIDTH,
    SHUTTER WIDTH, ROW ADDRESS MODE, COL ADDRESS MODE,
    BLACK_LEVEL,PIXEL CLOCK CONTROL,
    ROW START, COL START
}
*/
const MT9001_FormatParams MT9T001_VGA_30FPS =
    { 1979, 1467, 21, 31, 810, 0x22, 0x22, 64, 0x8000, 0, 0 };
const MT9001_FormatParams MT9T001_VGA_60FPS =
    { 1979, 1467, 21, 31, 582, 0x12, 0x12, 64, 0x8000, 0, 0 };
const MT9001_FormatParams MT9T001_SVGA_30FPS =
    { 1639, 1239, 21, 31, 1042, 0x11, 0x11, 64, 0x8000, 0, 0 };
const MT9001_FormatParams MT9T001_SVGA_60FPS =
    { 1639, 1239, 21, 31, 661, 0x01, 0x01, 64, 0x8000, 0, 0 };
const MT9001_FormatParams MT9T001_XGA_30FPS =
    { 1039, 775, 100, 283, 783, 0x00, 0x00, 64, 0x8000, 0, 0 };
const MT9001_FormatParams MT9T001_480P_30FPS =
    { 1471, 975, 350, 350, 898, 0x11, 0x11, 64, 0x8000, 0, 0 };
const MT9001_FormatParams MT9T001_480P_60FPS =
    { 1471, 975, 52, 50, 480, 0x11, 0x11, 64, 0x8000, 0, 0 };
const MT9001_FormatParams MT9T001_576P_25FPS =
    { 1471, 1167, 424, 450, 500, 0x11, 0x11, 64, 0x8000, 0, 0 };
const MT9001_FormatParams MT9T001_576P_50FPS =
    { 1471, 1167, 84, 48, 480, 0x11, 0x11, 64, 0x8000, 0, 0 };
const MT9001_FormatParams MT9T001_720P_24FPS =
    { 1299, 729, 300, 282, 568, 0x00, 0x00, 64, 0x8000, 0, 0 };
const MT9001_FormatParams MT9T001_720P_30FPS =
    { 1299, 729, 22, 220, 568, 0x00, 0x00, 64, 0x8000, 0, 0 };
const MT9001_FormatParams MT9T001_1080P_18FPS =
    { 1919, 1079, 108, 31, 1095, 0x00, 0x00, 64, 0x8000, 0, 0 };

EVD_Handle MT9001_Open()
{
    EVD_Handle handle = NULL;
    MT9001_StandardFormat  stdFormat = MT9T001_MODE_VGA_30FPS;
    if(TRUE == i2c_init())
    {
        if(TRUE == ConfigPCA9543A())
        {
            if(TRUE == setMT9001DefaultParams(&mt9001Object, stdFormat))
            {
                handle = &mt9001Object;
            }
        }
    }
    return handle;
}
/**
 *  \brief MT9001 Close function
**/

Int MT9001_Close(EVD_Handle handle)
{
    Int result = EVD_FAIL;
    if(NULL == handle)
    {
        result = EVD_FAIL;
    }
    else
    {
        if(TRUE == i2c_deInit())
        {
            handle = NULL;
            result = EVD_SUCCESS;
        }
    }
    return result;
}
/**
 *  \brief MT9001 Control Function
**/
Int MT9001_Control(EVD_Handle handle,Uint32 Cmd,Ptr CmdArg)
{
    MT9001_Object               *extVDHandle         = NULL;
    MT9001_FormatParams         *extVDFormatParams   = NULL;
    MT9001_ControlGainParams    *extVDCtrlGainParams = NULL;
    MT9001_StandardFormat       *stdFormat = NULL;
    Int result  = EVD_FAIL;
    /* Validate the Input parameters */
    if((NULL == handle)||(NULL == CmdArg))
    {
        result = EVD_FAIL;
    }
    else
    {
        extVDHandle = (MT9001_Object *)handle;
        switch(Cmd)
        {
            case PSP_VPSS_EXT_VIDEO_DECODER_CONFIG:
            {
                extVDFormatParams  = (MT9001_FormatParams *)CmdArg;
                if(NULL != extVDFormatParams)
                {
                    if(TRUE == setMT9001Format(extVDHandle,extVDFormatParams))
                    {
                        result = EVD_SUCCESS;
                    }
                }
            }
            break;
            case PSP_VPSS_EXT_VIDEO_DECODER_STATUS:
            {
                /* NOT SUPPORTED */
            }
            break;
            case PSP_VPSS_EXT_VIDEO_DECODER_CONTROL:
            {
                extVDCtrlGainParams  = (MT9001_ControlGainParams *)CmdArg;
                if(NULL!= extVDCtrlGainParams)
                {
                    if(TRUE == setMT9001Control(extVDHandle,extVDCtrlGainParams))
                    {
                        result  = EVD_SUCCESS;
                    }
                }
            }
            break;
            case PSP_VPSS_EXT_VIDEO_DECODER_STD_FORMAT:
            {
                stdFormat = (MT9001_StandardFormat *)CmdArg;
                if(NULL != stdFormat)
                {
                    if(TRUE == setMT9001Std(extVDHandle,*stdFormat))
                    {
                        result = EVD_SUCCESS;
                    }
                }
            }
            break;
            default:
            {
                result  = EVD_FAIL;
            }
            break;
        }
    }
    return result;
}
/**
  * \brief To configure PCA9543 control register
 */
static Bool ConfigPCA9543A()
{
    Bool result = FALSE;
    Uint8 buffer = 3;
    if(TRUE ==i2c_writeReg(I2C_PCA9543A_SLAVE_ADDR,&buffer,1))
    {
        result = TRUE;
    }
    return result;
}
/**
  * \brief To configure MT9001 default parameter
 */

static Bool setMT9001DefaultParams( MT9001_Object           *mt9001handle,
                                    MT9001_StandardFormat   stdFormat)
{
    Bool    result  = TRUE;
    Uint8   buffer[3]= {0,0,0};
    if(NULL == mt9001handle)
    {
        result = FALSE;
    }
    else
    {
        /**
         *  Set the standard format parameter
         **/
        result = setMT9001Std( mt9001handle,  stdFormat);
        /**
         *  Sets other default parameters
         **/
        if (TRUE == result)
        {
            /**
             *  Write to Output Control Register
            **/
            buffer[0]  = OUTPUT_CONTROL_REG;
            buffer[1]  = (Uint8)(OUTPUT_CONTROL_DEFAULT >> 8);
            buffer[2]  = (Uint8)(OUTPUT_CONTROL_DEFAULT & 0x00FF);
            result     &= i2c_writeReg(I2C_MT9001_SLAVE_ADDR,buffer,3u);
            /**
             *  Write to Shutter Width Upper Register
            **/
            buffer[0]  = SHUTTER_WIDTH_UPPER_REG;
            buffer[1]  = (Uint8)(SHUTTER_WIDTH_UPPER_DEFAULT >> 8);
            buffer[2]  = (Uint8)(SHUTTER_WIDTH_UPPER_DEFAULT & 0x00FF);
            result     &= i2c_writeReg(I2C_MT9001_SLAVE_ADDR,buffer,3u);
            /**
             *  Write to Restart Register
            **/
            buffer[0]  = RESTART_REG;
            buffer[1]  = (Uint8)(RESTART_DEFAULT >> 8);
            buffer[2]  = (Uint8)(RESTART_DEFAULT & 0x00FF);
            result     &= i2c_writeReg(I2C_MT9001_SLAVE_ADDR,buffer,3u);
            /**
             *  Write to Shutter Delay Register
            **/
            buffer[0]  = SHUTTER_DELAY_REG;
            buffer[1]  = (Uint8)(SHUTTER_DELAY_DEFAULT >> 8);
            buffer[2]  = (Uint8)(SHUTTER_DELAY_DEFAULT & 0x00FF);
            result     &= i2c_writeReg(I2C_MT9001_SLAVE_ADDR,buffer,3u);
            /**
             *  Write to Reset Register
            **/
            buffer[0]  = RESET;
            buffer[1]  = (Uint8)(RESET_DEFAULT >> 8);
            buffer[2]  = (Uint8)(RESET_DEFAULT & 0x00FF);
            result     &= i2c_writeReg(I2C_MT9001_SLAVE_ADDR,buffer,3u);
            /**
             *  Write to Read Mode1 Register
            **/
            buffer[0]  = READ_MODE1_REG;
            buffer[1]  = (Uint8)(READ_MODE1_DEFAULT >> 8);
            buffer[2]  = (Uint8)(READ_MODE1_DEFAULT & 0x00FF);
            result     &= i2c_writeReg(I2C_MT9001_SLAVE_ADDR,buffer,3u);
            /**
             *  Write to Read Mode2 Register
            **/
            buffer[0]  = READ_MODE2_REG;
            buffer[1]  = (Uint8)(READ_MODE2_DEFAULT >> 8);
            buffer[2]  = (Uint8)(READ_MODE2_DEFAULT & 0x00FF);
            result     &= i2c_writeReg(I2C_MT9001_SLAVE_ADDR,buffer,3u);
            /**
             *  Write to Read Mode3 Register
            **/
            buffer[0]  = READ_MODE3_REG;
            buffer[1]  = (Uint8)(READ_MODE3_DEFAULT >> 8);
            buffer[2]  = (Uint8)(READ_MODE3_DEFAULT & 0x00FF);
            result     &= i2c_writeReg(I2C_MT9001_SLAVE_ADDR,buffer,3u);
            /**
             *  Write to Green1 Gain Register
            **/
            buffer[0]  = GREEN1_GAIN_REG;
            buffer[1]  = (Uint8)(GREEN1_GAIN_DEFAULT >> 8);
            buffer[2]  = (Uint8)(GREEN1_GAIN_DEFAULT & 0x00FF);
            result     &= i2c_writeReg(I2C_MT9001_SLAVE_ADDR,buffer,3u);
            /**
             *  Write to Blue Gain Register
            **/
            buffer[0]  = BLUE_GAIN_REG;
            buffer[1]  = (Uint8)(BLUE_GAIN_DEFAULT >> 8);
            buffer[2]  = (Uint8)(BLUE_GAIN_DEFAULT & 0x00FF);
            result     &= i2c_writeReg(I2C_MT9001_SLAVE_ADDR,buffer,3u);
            /**
             *  Write to Red Gain Register
            **/
            buffer[0]  = RED_GAIN_REG;
            buffer[1]  = (Uint8)(RED_GAIN_DEFAULT >> 8);
            buffer[2]  = (Uint8)(RED_GAIN_DEFAULT & 0x00FF);
            result     &= i2c_writeReg(I2C_MT9001_SLAVE_ADDR,buffer,3u);
            /**
             *  Write to Green2 Gain Register
            **/
            buffer[0]  = GREEN2_GAIN_REG;
            buffer[1]  = (Uint8)(GREEN2_GAIN_DEFAULT >> 8);
            buffer[2]  = (Uint8)(GREEN2_GAIN_DEFAULT & 0x00FF);
            result     &= i2c_writeReg(I2C_MT9001_SLAVE_ADDR,buffer,3u);

            /**
             *  Write to Global Gain Register
            **/
            buffer[0]  = GLOBAL_GAIN_REG;
            buffer[1]  = (Uint8)(GLOBAL_GAIN_DEFAULT >> 8);
            buffer[2]  = (Uint8)(GLOBAL_GAIN_DEFAULT & 0x00FF);
            result     &= i2c_writeReg(I2C_MT9001_SLAVE_ADDR,buffer,3u);
            /**
             *  Write to Coarse Threshold Register
            **/
            buffer[0]  = COARSE_THRESHOLDS_REG;
            buffer[1]  = (Uint8)(COARSE_THRESHOLDS_DEFAULT >> 8);
            buffer[2]  = (Uint8)(COARSE_THRESHOLDS_DEFAULT & 0x00FF);
            result     &= i2c_writeReg(I2C_MT9001_SLAVE_ADDR,buffer,3u);
            /**
             *  Write to Target Threshold Register
            **/
            buffer[0]  = TARGET_THRESHOLD_REG;
            buffer[1]  = (Uint8)(TARGET_THRESHOLD_DEFAULT >> 8);
            buffer[2]  = (Uint8)(TARGET_THRESHOLD_DEFAULT & 0x00FF);
            result     &= i2c_writeReg(I2C_MT9001_SLAVE_ADDR,buffer,3u);
            /**
             *  Write to Green1 Offset Register
            **/
            buffer[0]  = GREEN1_OFFSET_REG;
            buffer[1]  = (Uint8)(GREEN1_OFFSET_DEFAULT >> 8);
            buffer[2]  = (Uint8)(GREEN1_OFFSET_DEFAULT & 0x00FF);
            result     &= i2c_writeReg(I2C_MT9001_SLAVE_ADDR,buffer,3u);
            /**
             *  Write to Green2 Offset Register
            **/
            buffer[0]  = GREEN1_OFFSET_REG;
            buffer[1]  = (Uint8)(GREEN2_OFFSET_DEFAULT >> 8);
            buffer[2]  = (Uint8)(GREEN2_OFFSET_DEFAULT & 0x00FF);
            result     &= i2c_writeReg(I2C_MT9001_SLAVE_ADDR,buffer,3u);
            /**
             *  Write to Black Level Calibration Register
            **/
            buffer[0]  = BLK_LEVEL_CALIBRATION_REG;
            buffer[1]  = (Uint8)(BLK_LEVEL_CALIBRATION_DEFAULT >> 8);
            buffer[2]  = (Uint8)(BLK_LEVEL_CALIBRATION_DEFAULT & 0x00FF);
            result     &= i2c_writeReg(I2C_MT9001_SLAVE_ADDR,buffer,3u);
            /**
             *  Write to Blue Offset Register
            **/
            buffer[0]  = BLUE_OFFSET_REG;
            buffer[1]  = (Uint8)(BLUE_OFFSET_DEFAULT >> 8);
            buffer[2]  = (Uint8)(BLUE_OFFSET_DEFAULT & 0x00FF);
            result     &= i2c_writeReg(I2C_MT9001_SLAVE_ADDR,buffer,3u);
            /**
             *  Write to Red Offset Register
            **/
            buffer[0]  = RED_OFFSET_REG;
            buffer[1]  = (Uint8)(RED_OFFSET_DEFAULT >> 8);
            buffer[2]  = (Uint8)(RED_OFFSET_DEFAULT & 0x00FF);
            result     &= i2c_writeReg(I2C_MT9001_SLAVE_ADDR,buffer,3u);
            /**
             *  Write to Chip Enable Sync Register
            **/
            buffer[0]  = CHIP_ENABLE_SYNC;
            buffer[1]  = (Uint8)(CHIP_ENABLE_SYNC_DEFUALT >> 8);
            buffer[2]  = (Uint8)(CHIP_ENABLE_SYNC_DEFUALT & 0x00FF);
            result     &= i2c_writeReg(I2C_MT9001_SLAVE_ADDR,buffer,3u);

        }
    }
    return result;
}
/**
  * \brief To configure MT9001 Standard Format
 */
static Bool setMT9001Std(MT9001_Object          *mt9001handle,
                         MT9001_StandardFormat  stdFormat)
{
    Bool    result  = TRUE;
    MT9001_FormatParams  mt9001formatParams;
    if(NULL == mt9001handle)
    {
        result = FALSE;
    }
    else
    {
        /**
         *  Select configuration parameters as per video mode
        **/
        if (stdFormat == MT9T001_MODE_VGA_30FPS) {
            mt9001formatParams = MT9T001_VGA_30FPS;
        } else if (stdFormat == MT9T001_MODE_VGA_60FPS) {
            mt9001formatParams = MT9T001_VGA_60FPS;
        } else if (stdFormat == MT9T001_MODE_SVGA_30FPS) {
            mt9001formatParams = MT9T001_SVGA_30FPS;
        } else if (stdFormat == MT9T001_MODE_SVGA_60FPS) {
            mt9001formatParams = MT9T001_SVGA_60FPS;
        } else if (stdFormat == MT9T001_MODE_XGA_30FPS) {
            mt9001formatParams = MT9T001_XGA_30FPS;
        } else if (stdFormat == MT9T001_MODE_480p_30FPS) {
            mt9001formatParams = MT9T001_480P_30FPS;
        } else if (stdFormat == MT9T001_MODE_480p_60FPS) {
            mt9001formatParams = MT9T001_480P_60FPS;
        } else if (stdFormat == MT9T001_MODE_576p_25FPS) {
            mt9001formatParams = MT9T001_576P_25FPS;
        } else if (stdFormat == MT9T001_MODE_576p_50FPS) {
            mt9001formatParams = MT9T001_576P_50FPS;
        } else if (stdFormat == MT9T001_MODE_720p_24FPS) {
            mt9001formatParams = MT9T001_720P_24FPS;
        } else if (stdFormat == MT9T001_MODE_720p_30FPS) {
            mt9001formatParams = MT9T001_720P_30FPS;
        } else if (stdFormat == MT9T001_MODE_1080p_18FPS) {
            mt9001formatParams = MT9T001_1080P_18FPS;
        } else {
            result = FALSE;
        }
        if (TRUE == result)
        {
            result = setMT9001Format( mt9001handle, &mt9001formatParams );
        }
    }
    return result;

}
/**
  * \brief To configure MT9001 Format Parameters
 */
static Bool setMT9001Format(MT9001_Object        *mt9001handle,
                            MT9001_FormatParams  *mt9001formatParams)
{
    Bool    result  = TRUE;
    Uint8   buffer[3] = {0,0,0};

    if((NULL == mt9001handle )||(NULL == mt9001formatParams))
    {
        result = FALSE;
    }
    else
    {
        /**
         *  Write to Pixel Clock Control Register
        **/
        buffer[0]  = PIXEL_CLK_CONTROL_REG;
        buffer[1]  = (Uint8)(mt9001formatParams->pixel_clock_ctrl >> 8);
        buffer[2]  = (Uint8)(mt9001formatParams->pixel_clock_ctrl & 0x00FF);
        if(TRUE == i2c_writeReg(I2C_MT9001_SLAVE_ADDR,buffer,3u))
        {
            mt9001handle->format.pixel_clock_ctrl
                        = mt9001formatParams->pixel_clock_ctrl;
        }
        else
        {
            result  = FALSE;
        }
        /**
         *  Write to Row Size Register
        **/
        buffer[0]   = ROW_SIZE_REG;
        buffer[1]   = (Uint8)(mt9001formatParams->row_size>> 8);
        buffer[2]   = (Uint8)(mt9001formatParams->row_size & 0x00FF);
        if(TRUE == i2c_writeReg(I2C_MT9001_SLAVE_ADDR,buffer,3u))
        {
            mt9001handle->format.row_size   = mt9001formatParams->row_size;
        }
        else
        {
            result  = FALSE;
        }
        /**
         *  Write to Row Start Register
        **/
        buffer[0]   = ROW_START_REG;
        buffer[1]   = (Uint8)(mt9001formatParams->row_start >> 8);
        buffer[2]   = (Uint8)(mt9001formatParams->row_start & 0x00FF);
        if(TRUE == i2c_writeReg(I2C_MT9001_SLAVE_ADDR,buffer,3u))
        {
            mt9001handle->format.row_start  = mt9001formatParams->row_start;
        }
        else
        {
            result  = FALSE;
        }

        /**
         *  Write to Col Start Register
        **/
        buffer[0]   = COL_START_REG;
        buffer[1]   = (Uint8)(mt9001formatParams->col_start >> 8);
        buffer[2]   = (Uint8)(mt9001formatParams->col_start & 0x00FF);
        if(TRUE == i2c_writeReg(I2C_MT9001_SLAVE_ADDR,buffer,3u))
        {
            mt9001handle->format.col_start  = mt9001formatParams->col_start;
        }
        else
        {
            result  = FALSE;
        }
        /**
         *  Write to Col Size Register
        **/
        buffer[0]    = COL_SIZE_REG;
        buffer[1]    = (Uint8)(mt9001formatParams->column_size >> 8);
        buffer[2]    = (Uint8)(mt9001formatParams->column_size & 0x00FF);
        if(TRUE == i2c_writeReg(I2C_MT9001_SLAVE_ADDR,buffer,3u))
        {
            mt9001handle->format.column_size   = mt9001formatParams->column_size;
        }
        else
        {
            result  = FALSE;
        }

        /**
         *  Write to Horizontal Blanking Register
        **/
        buffer[0]   = HORZ_BLANKING_REG;
        buffer[1]   = (Uint8)(mt9001formatParams->h_blank >> 8);
        buffer[2]   = (Uint8)(mt9001formatParams->h_blank & 0x00FF);
        if(TRUE == i2c_writeReg(I2C_MT9001_SLAVE_ADDR,buffer,3u))
        {
            mt9001handle->format.h_blank = mt9001formatParams->h_blank;
        }
        else
        {
            result  = FALSE;
        }

        /**
         *  Write to Vertical Blanking Register
        **/
        buffer[0]   = VERT_BLANKING_REG;
        buffer[1]   = (Uint8)(mt9001formatParams->v_blank >> 8);
        buffer[2]   = (Uint8)(mt9001formatParams->v_blank & 0x00FF);
        if(TRUE == i2c_writeReg(I2C_MT9001_SLAVE_ADDR,buffer,3u))
        {
            mt9001handle->format.v_blank = mt9001formatParams->v_blank;
        }
        else
        {
            result  = FALSE;
        }

        /**
         *  Write to Shutter Width Register
        **/
        buffer[0]   = SHUTTER_WIDTH_REG;
        buffer[1]   = (Uint8)(mt9001formatParams->shutter_width >> 8);
        buffer[2]   = (Uint8)(mt9001formatParams->shutter_width & 0x00FF);
        if(TRUE == i2c_writeReg(I2C_MT9001_SLAVE_ADDR,buffer,3u))
        {
            mt9001handle->format.shutter_width  = mt9001formatParams->shutter_width;
        }
        else
        {
            result  = FALSE;
        }

        /**
         *  Write to Row Address Mode Register
        **/
        buffer[0]  = ROW_ADDR_MODE_REG;
        buffer[1]  = (Uint8)(mt9001formatParams->row_addr_mode >> 8);
        buffer[2]  = (Uint8)(mt9001formatParams->row_addr_mode & 0x00FF);
        if(TRUE == i2c_writeReg(I2C_MT9001_SLAVE_ADDR,buffer,3u))
        {
            mt9001handle->format.row_addr_mode  = mt9001formatParams->row_addr_mode;
        }
        else
        {
            result  = FALSE;
        }

        /**
         *  Write to Column Address Mode Register
        **/
        buffer[0] = COL_ADDR_MODE_REG;
        buffer[1] = (Uint8)(mt9001formatParams->col_addr_mode >> 8);
        buffer[2] = (Uint8)(mt9001formatParams->col_addr_mode & 0x00FF);
        if(TRUE == i2c_writeReg(I2C_MT9001_SLAVE_ADDR,buffer,3u))
        {
            mt9001handle->format.col_addr_mode  = mt9001formatParams->col_addr_mode;
        }
        else
        {
            result  = FALSE;
        }

        /**
         *  Write to Black Level Register
        **/
        buffer[0] = BLACK_LEVEL_REG;
        buffer[1] = (Uint8)(mt9001formatParams->black_level >> 8);
        buffer[2] = (Uint8)(mt9001formatParams->black_level & 0x00FF);
        if(TRUE == i2c_writeReg(I2C_MT9001_SLAVE_ADDR,buffer,3u))
        {
            mt9001handle->format.black_level    = mt9001formatParams->black_level;
        }
        else
        {
            result  = FALSE;
        }
    }
    return result;
}
/**
  * \brief To Control the Gain of RGB
 */
static Bool setMT9001Control(MT9001_Object            *mt9001Handle,
                             MT9001_ControlGainParams *cntrlParamSC)
{
    Bool    result = TRUE;
    Uint8   buffer[3] = {0,0,0};
    if((NULL == mt9001Handle)||(NULL == cntrlParamSC))
    {
        result = FALSE;
    }
    else
    {
        /**
         *  Write to Green1 Gain Register
        **/
        buffer[0]   = GREEN1_GAIN_REG;
        buffer[1]   = (Uint8)(cntrlParamSC->green1_digital_gain >> 8);
        buffer[2]   = (Uint8)(cntrlParamSC->green1_analog_gain & 0x007F);
        if(TRUE == i2c_writeReg(I2C_MT9001_SLAVE_ADDR,buffer,3u))
        {
            mt9001Handle->gain.green1_digital_gain = cntrlParamSC->green1_digital_gain;
            mt9001Handle->gain.green1_analog_gain  = cntrlParamSC->green1_analog_gain;
        }
        else
        {
            result  = FALSE;
        }
        /**
         *  Write to Blue Gain Register
        **/
        buffer[0]   = BLUE_GAIN_REG;
        buffer[1]   = (Uint8)(cntrlParamSC->blue_digital_gain >> 8);
        buffer[2]   = (Uint8)(cntrlParamSC->blue_analog_gain & 0x007F);
        if(TRUE == i2c_writeReg(I2C_MT9001_SLAVE_ADDR,buffer,3u))
        {
            mt9001Handle->gain.blue_digital_gain = cntrlParamSC->blue_digital_gain;
            mt9001Handle->gain.blue_analog_gain  = cntrlParamSC->blue_analog_gain;
        }
        else
        {
            result  = FALSE;
        }
        /**
         *  Write to Red Gain Register
        **/
        buffer[0]   = RED_GAIN_REG;
        buffer[1]   = (Uint8)(cntrlParamSC->red_digital_gain >> 8);
        buffer[2]   = (Uint8)(cntrlParamSC->red_analog_gain & 0x007F);
        if(TRUE == i2c_writeReg(I2C_MT9001_SLAVE_ADDR,buffer,3u))
        {
            mt9001Handle->gain.red_digital_gain = cntrlParamSC->red_digital_gain;
            mt9001Handle->gain.red_analog_gain   = cntrlParamSC->red_analog_gain;
        }
        else
        {
            result  = FALSE;
        }
        /**
         *  Write to Green2 Gain Register
        **/
        buffer[0]   = GREEN2_GAIN_REG;
        buffer[1]   = (Uint8)(cntrlParamSC->green2_digital_gain >> 8);
        buffer[2]   = (Uint8)(cntrlParamSC->green2_analog_gain & 0x007F);
        if(TRUE == i2c_writeReg(I2C_MT9001_SLAVE_ADDR,buffer,3u))
        {
            mt9001Handle->gain.green2_digital_gain = cntrlParamSC->green2_digital_gain;
            mt9001Handle->gain.green2_analog_gain  = cntrlParamSC->green2_analog_gain;
        }
        else
        {
            result  = FALSE;
        }
    }

    return result;
}
