/******************************************************************************
**+-------------------------------------------------------------------------+**
**|                            ****                                         |**
**|                            ****                                         |**
**|                            ******o***                                   |**
**|                      ********_///_****                                  |**
**|                      ***** /_//_/ ****                                  |**
**|                       ** ** (__/ ****                                   |**
**|                           *********                                     |**
**|                            ****                                         |**
**|                            ***                                          |**
**|                                                                         |**
**|         Copyright (c) 2006-2010 Texas Instruments Incorporated          |**
**|                        ALL RIGHTS RESERVED                              |**
**|                                                                         |**
**| Permission is hereby granted to licensees of Texas Instruments          |**
**| Incorporated (TI) products to use this computer program for the sole    |**
**| purpose of implementing a licensee product based on TI products.        |**
**| No other rights to reproduce, use, or disseminate this computer         |**
**| program, whether in part or in whole, are granted.                      |**
**|                                                                         |**
**| TI makes no representation or warranties with respect to the            |**
**| performance of this computer program, and specifically disclaims        |**
**| any responsibility for any damages, special or consequential,           |**
**| connected with the use of this program.                                 |**
**|                                                                         |**
**+-------------------------------------------------------------------------+**
******************************************************************************/
/**
 *  \file   MT9001_extImageSensor.h
 *
 *  \brief  MT9001 external Image Sensor related parameters.
 *
 *  This file contains the interfaces, data types and symbolic definitions
 *  that are required for the MT9001 external image sensor interface
 *
 *  (C) Copyright 2010, Texas Instruments, Inc
 *
 *  \author     Maulik Desai
 *
 *  \version    0.1     Created
 */
#ifndef _MT9001_EXT_IMAGE_SENSOR_H
#define _MT9001_EXT_IMAGE_SENSOR_H

#ifdef __cplusplus
extern "C" {
#endif

#include <ti/sdo/pspdrivers/system/dm6437/bios/evmDM6437/video/psp_vpss_extvidDecoder.h>

#define  I2C_MT9001_SLAVE_ADDR      (0x5D)

#define  I2C_PCA9543A_SLAVE_ADDR    (0x70)
/******************************************************************************
                            Register Overlay Macros
******************************************************************************/
#define CHIP_VERSION_REG            (0x00)
/**< Chip Version Register                      */
#define ROW_START_REG               (0x01)
/**< Row Start Register                         */
#define COL_START_REG               (0x02)
/**< Column Start Register                      */
#define ROW_SIZE_REG                (0x03)
/**< Row Size Register                          */
#define COL_SIZE_REG                (0x04)
/**< Column Size Register                       */
#define HORZ_BLANKING_REG           (0x05)
/**< Horizontal Blanking Register               */
#define VERT_BLANKING_REG           (0x06)
/**< Vertical Blanking Register                 */
#define OUTPUT_CONTROL_REG          (0x07)
/**< Output Control Register                    */
#define SHUTTER_WIDTH_UPPER_REG     (0x08)
/**< Shutter Width Upper Register               */
#define SHUTTER_WIDTH_REG           (0x09)
/**< Shutter Width Register                     */
#define PIXEL_CLK_CONTROL_REG       (0x0A)
/**< Pixel Clock Control Register               */
#define RESTART_REG                 (0x0B)
/**< Restart Register                           */
#define SHUTTER_DELAY_REG           (0x0C)
/**< Shutter Delay Register                     */
#define RESET                       (0x0D)
/**< Reset Register                             */
#define READ_MODE1_REG              (0x1E)
/**< Read Mode1 Register                        */
#define READ_MODE2_REG              (0x20)
/**< Read Mode2 Register                        */
#define READ_MODE3_REG              (0x21)
/**< Read Mode3 Register                        */
#define ROW_ADDR_MODE_REG           (0x22)
/**< Row Address Mode Register                  */
#define COL_ADDR_MODE_REG           (0x23)
/**< Column Address Mode Register               */
#define RESERVED_27_REG             (0x27)
/**< Reserver Register                          */
#define GREEN1_GAIN_REG             (0x2B)
/**< Green 1 Gain Register                      */
#define BLUE_GAIN_REG               (0x2C)
/**< Blue Gain Register                         */
#define RED_GAIN_REG                (0x2D)
/**< Red Gain Register                          */
#define GREEN2_GAIN_REG             (0x2E)
/**< Green2 Gain Register                       */
#define GLOBAL_GAIN_REG             (0x35)
/**< Global Gain Register                       */
#define BLACK_LEVEL_REG             (0x49)
/**< Black Level Register                       */
#define ROW_BLACK_DEF_OFFSET_REG    (0x4B)
/**< Row Black Default Offset Register          */
#define RESERVED_4E_REG             (0x4e)
/**< Reserved Register                          */
#define RESERVED_50_REG             (0x50)
/**< Reserved Register                          */
#define RESERVED_51_REG             (0x51)
/**< Reserved Register                          */
#define RESERVED_52_REG             (0x52)
/**< Reserved Register                          */
#define RESERVED_53_REG             (0x53)
/**< Reserved Register                          */
#define COARSE_THRESHOLDS_REG       (0x5D)
/**< Coarse Thresholds Register                 */
#define TARGET_THRESHOLD_REG        (0x5F)
/**< Target Thresholds Register                 */
#define GREEN1_OFFSET_REG           (0x60)
/**< Green1 Offset Register                     */
#define GREEN2_OFFSET_REG           (0x61)
/**< Green2 Offset Register                     */
#define BLK_LEVEL_CALIBRATION_REG   (0x62)
/**< Black Level Calibration  Register          */
#define RED_OFFSET_REG              (0x63)
/**< Red Offset Register                        */
#define BLUE_OFFSET_REG             (0x64)
/**< Blue Offset Register                       */
#define CHIP_ENABLE_SYNC            (0xF8)
/**< Chip Enable/Synchronize Register           */
#define CHIP_VERSION_END            (0xFF)
/**< Chip Version End Register                  */

/******************************************************************************
                            Register Default Values
******************************************************************************/
#define OUTPUT_CONTROL_DEFAULT        (0x0002u)
/**< Output control default setting               */
#define SHUTTER_WIDTH_UPPER_DEFAULT   (0x0000u)
/**< Shutter width default setting                */
#define RESTART_DEFAULT               (0x0000u)
/**< Restart default setting                      */
#define SHUTTER_DELAY_DEFAULT         (0x0000u)
/**< Shutter delay default setting                */
#define RESET_DEFAULT                 (0x0000u)
/**< Reset default setting                        */
#define READ_MODE1_DEFAULT            (0x8040u)
/**< Read mode1 default setting                   */
#define READ_MODE2_DEFAULT            (0x2000u)
/**< Read mode2 default setting                   */
#define READ_MODE3_DEFAULT            (0x0000u)
/**< Read mode3 default setting                   */
#define GREEN1_GAIN_DEFAULT           (0x0008u)
/**< Green1 gain default setting                  */
#define BLUE_GAIN_DEFAULT             (0x0008u)
/**< Blue gain default setting                    */
#define RED_GAIN_DEFAULT              (0x0008u)
/**< Res gain default setting                     */
#define GREEN2_GAIN_DEFAULT           (0x0008u)
/**< Green2 gain default setting                  */
#define GLOBAL_GAIN_DEFAULT           (0x0008u)
/**< Global gain default setting                  */
#define COARSE_THRESHOLDS_DEFAULT     (0x2D13u)
/**< Coarse Thresholds default setting            */
#define TARGET_THRESHOLD_DEFAULT      (0x231Du)
/**< Target Thresholds default setting            */
#define GREEN1_OFFSET_DEFAULT         (0x0020u)
/**< Green1 Offset default setting                */
#define GREEN2_OFFSET_DEFAULT         (0x0020u)
/**< Green2 Offset default setting                */
#define BLK_LEVEL_CALIBRATION_DEFAULT (0x0000u)
/**< Black Level Calibration  default setting     */
#define RED_OFFSET_DEFAULT            (0x0020u)
/**< Red Offset default setting                   */
#define BLUE_OFFSET_DEFAULT           (0x0020u)
/**< Blue Offset default setting                  */
#define CHIP_ENABLE_SYNC_DEFUALT      (0x0001u)
/**< Chip Enable/Synchronize default setting      */

typedef struct _MT9001_FormatParams
{
    Uint16 column_size;
    Uint16 row_size;
    Uint16 h_blank;
    Uint16 v_blank;
    Uint16 shutter_width;
    Uint16 row_addr_mode;
    Uint16 col_addr_mode;
    Uint16 black_level;
    Uint16  pixel_clock_ctrl;
    Uint16 row_start;
    Uint16 col_start;
}MT9001_FormatParams;

typedef struct _MT9001_ControlGainParams
{
    Uint8   green1_analog_gain;
    Uint8   blue_analog_gain;
    Uint8   red_analog_gain;
    Uint8   green2_analog_gain;
    Uint8   green1_digital_gain;
    Uint8   blue_digital_gain;
    Uint8   red_digital_gain;
    Uint8   green2_digital_gain;
}MT9001_ControlGainParams;

typedef struct _MT9001_BLKLVL_CALIBParams
{
    Bool    manual_override;
    Bool    disable_calibration;
    Bool    recalculate_black_level;
    Bool    lock_red_blue_calibration;
    Bool    lock_green_calibration;
    Uint8   low_coarse_threshold;
    Uint8   high_coarse_threshold;
    Uint8   low_target_threshold;
    Uint8   high_target_threshold;
    Uint8   green1_offset;
    Uint8   green2_offset;
    Uint8   red_offset;
    Uint8   blue_offset;

}MT9001_BLKLVL_CALIBParams;

/*-----------------------------------------------------------------------------
                     MT9001 Image Sensor Device Object
-----------------------------------------------------------------------------*/
typedef struct _MT9001_Object
{
    Int                                 ChipId;
    /**<  chip id  for Mt9001                       */
    MT9001_FormatParams                 format;
    /**<  MT9001 Config Parameters                  */
    MT9001_ControlGainParams            gain;
    /**<  MT9001 Gain Parameters                    */
    MT9001_BLKLVL_CALIBParams   black_calib;
    /**<  MT9001 Black Level Calibration Parameters */

}MT9001_Object;

/* define for various video format supported by MT9T001 driver 
*/

typedef enum _MT9001_STANDARD_FORMAT
{
    MT9T001_MODE_VGA_30FPS,
    MT9T001_MODE_VGA_60FPS,
    MT9T001_MODE_SVGA_30FPS,
    MT9T001_MODE_SVGA_60FPS,
    MT9T001_MODE_XGA_30FPS,
    MT9T001_MODE_480p_30FPS,
    MT9T001_MODE_480p_60FPS,
    MT9T001_MODE_576p_25FPS,
    MT9T001_MODE_576p_50FPS,
    MT9T001_MODE_720p_24FPS,
    MT9T001_MODE_720p_30FPS,
    MT9T001_MODE_1080p_18FPS
} MT9001_StandardFormat;

/*-----------------------------------------------------------------------------
                    Functions Defined
-----------------------------------------------------------------------------*/
/**
 *  \brief MT9001_Open
 *
 *  This Function is used to initialize the MT9001 external image sensor.
 *  It initialize the I2C Driver and MT9001 image sensor.It returns MT9001
 *  handle.
 *
 *  \return EVD_Handle
 */
EVD_Handle MT9001_Open();
/**
 *  \brief MT9001_Close
 *
 *  This Function is used to deinitialize the MT9001 external image sensor.
 *  It deinitialize the MT9001 sensor and i2c Driver..
 *
 *  \param handle           Handle of MT9001 driver
 */
Int MT9001_Close(EVD_Handle handle);
/**
 *  \brief MT9001_Control
 *
 *  This Function is to configure and change parameters of MT9001 image sensor
 *  runtime.
 *
 *  \param  handle          Handle of MT9001 image sensor
 *  \param  Cmd             Commands for MT9001 image sensor for runtime change
 *  \param  CmdArg          Argument to be passed for the runtime change
 */
Int MT9001_Control(EVD_Handle handle,Uint32 Cmd,Ptr CmdArg);

#ifdef __cplusplus
}
#endif /* extern "C" */

#endif /*_MT9001_EXT_IMAGE_SENSOR_H */

