/******************************************************************************
**+-------------------------------------------------------------------------+**
**|                            ****                                         |**
**|                            ****                                         |**
**|                            ******o***                                   |**
**|                      ********_///_****                                  |**
**|                      ***** /_//_/ ****                                  |**
**|                       ** ** (__/ ****                                   |**
**|                           *********                                     |**
**|                            ****                                         |**
**|                            ***                                          |**
**|                                                                         |**
**|         Copyright (c) 2006-2010 Texas Instruments Incorporated          |**
**|                        ALL RIGHTS RESERVED                              |**
**|                                                                         |**
**| Permission is hereby granted to licensees of Texas Instruments          |**
**| Incorporated (TI) products to use this computer program for the sole    |**
**| purpose of implementing a licensee product based on TI products.        |**
**| No other rights to reproduce, use, or disseminate this computer         |**
**| program, whether in part or in whole, are granted.                      |**
**|                                                                         |**
**| TI makes no representation or warranties with respect to the            |**
**| performance of this computer program, and specifically disclaims        |**
**| any responsibility for any damages, special or consequential,           |**
**| connected with the use of this program.                                 |**
**|                                                                         |**
**+-------------------------------------------------------------------------+**
******************************************************************************/

/**
 *  \file   THS8200_extVidEncoder.h
 *
 *  \brief  THS8200 Video Encoder related parameters
 *
 *  This file contains the interfaces, data types and symbolic definitions
 *  that are required for the THS8200 video encoder driver.
 *
 *  (C) Copyright 2010, Texas Instruments, Inc
 *
 *  \author     Maulik Desai
 *
 *  \version    0.1     Created
 */

#ifndef _THS8200_EXTVIDEO_ENCODER_H
#define _THS8200_EXTVIDEO_ENCODER_H

#ifdef __cplusplus
extern "C" {
#endif

#include <ti/sdo/pspdrivers/system/dm6437/bios/evmDM6437/video/psp_vpss_extvidEncoder.h>

/*
 * ========= DEFINES ==========
 */
//#define EDC_CONFIG                    (1)

/* Colour Space defines */
#define COLOUR_SPACE_RGB                (0)
#define COLOUR_SPACE_YCBCR              (1)

#define THS8200_I2CADDR                 (0x40 >> 1)

/* System Registers */
#define THS8200_VERSION_ADDR                        (0x02)
#define THS8200_CHIP_CTL_ADDR                       (0x03)

/* Color Space Conversion Registers */
#define THS8200_CSC_R11_ADDR                        (0x04)
#define THS8200_CSC_R12_ADDR                        (0x05)
#define THS8200_CSC_R21_ADDR                        (0x06)
#define THS8200_CSC_R22_ADDR                        (0x07)
#define THS8200_CSC_R31_ADDR                        (0x08)
#define THS8200_CSC_R32_ADDR                        (0x09)
#define THS8200_CSC_G11_ADDR                        (0x0A)
#define THS8200_CSC_G12_ADDR                        (0x0B)
#define THS8200_CSC_G21_ADDR                        (0x0C)
#define THS8200_CSC_G22_ADDR                        (0x0D)
#define THS8200_CSC_G31_ADDR                        (0x0E)
#define THS8200_CSC_G32_ADDR                        (0x0F)
#define THS8200_CSC_B11_ADDR                        (0x10)
#define THS8200_CSC_B12_ADDR                        (0x11)
#define THS8200_CSC_B21_ADDR                        (0x12)
#define THS8200_CSC_B22_ADDR                        (0x13)
#define THS8200_CSC_B31_ADDR                        (0x14)
#define THS8200_CSC_B32_ADDR                        (0x15)
#define THS8200_CSC_OFFS1_ADDR                      (0x16)
#define THS8200_CSC_OFFS12_ADDR                     (0x17)
#define THS8200_CSC_OFFS23_ADDR                     (0x18)
#define THS8200_CSC_OFFS3_ADDR                      (0x19)

/* Test Registers */
#define THS8200_TST_CNTL1_ADDR                      (0x1A)
#define THS8200_TST_CNTL2_ADDR                      (0x1B)

/* Data Path Registers */
#define THS8200_DATA_CNTL_ADDR                      (0x1C)

/* Display Timing Generation, Part 1 */
#define THS8200_DTG1_Y_SYNC1_LSB_ADDR               (0x1D)
#define THS8200_DTG1_Y_SYNC2_LSB_ADDR               (0x1E)
#define THS8200_DTG1_Y_SYNC3_LSB_ADDR               (0x1F)

#define THS8200_DTG1_CBCR_SYNC1_LSB_ADDR            (0x20)
#define THS8200_DTG1_CBCR_SYNC2_LSB_ADDR            (0x21)
#define THS8200_DTG1_CBCR_SYNC3_LSB_ADDR            (0x22)

#define THS8200_DTG1_Y_SYNC_MSB_ADDR                (0x23)
#define THS8200_DTG1_CBCR_SYNC_MSB_ADDR             (0x24)

#define THS8200_DTG1_SPEC_A_ADDR                    (0x25)
#define THS8200_DTG1_SPEC_B_ADDR                    (0x26)
#define THS8200_DTG1_SPEC_C_ADDR                    (0x27)
#define THS8200_DTG1_SPEC_D_LSB_ADDR                (0x28)
#define THS8200_DTG1_SPEC_D1_ADDR                   (0x29)
#define THS8200_DTG1_SPEC_E_LSB_ADDR                (0x2A)
#define THS8200_DTG1_SPEC_DEH_MSB_ADDR              (0x2B)
#define THS8200_DTG1_SPEC_H_LSB_ADDR                (0x2C)
#define THS8200_DTG1_SPEC_I_MSB_ADDR                (0x2D)
#define THS8200_DTG1_SPEC_I_LSB_ADDR                (0x2E)
#define THS8200_DTG1_SPEC_K_LSB_ADDR                (0x2F)
#define THS8200_DTG1_SPEC_K_MSB_ADDR                (0x30)
#define THS8200_DTG1_SPEC_K1_ADDR                   (0x31)
#define THS8200_DTG1_SPEC_G_LSB_ADDR                (0x32)
#define THS8200_DTG1_SPEC_G_MSB_ADDR                (0x33)

#define THS8200_DTG1_TOTAL_PIX_MSB_ADDR             (0x34)
#define THS8200_DTG1_TOTAL_PIX_LSB_ADDR             (0x35)
#define THS8200_DTG1_FLDFLIP_LINECNT_MSB_ADDR       (0x36)
#define THS8200_DTG1_LINECNT_LSB_ADDR               (0x37)

#define THS8200_DTG1_MODE_ADDR                      (0x38)

#define THS8200_DTG1_FRM_FLD_SIZE_MSB_ADDR          (0x39)
#define THS8200_DTG1_FRMSIZE_LSB_ADDR               (0x3A)
#define THS8200_DTG1_FIELD_SIZE_LSB_ADDR            (0x3B)
#define THS8200_DTG1_VESA_CBAR_SIZE_ADDR            (0x3C)

/* DAC Registers */
#define THS8200_DAC_CNTL_MSB_ADDR                   (0x3D)
#define THS8200_DAC1_CNTL_LSB_ADDR                  (0x3E)
#define THS8200_DAC2_CNTL_LSB_ADDR                  (0x3F)
#define THS8200_DAC3_CNTL_LSB_ADDR                  (0x40)

/* Clip/Shift/Multiplier Registers */
#define THS8200_CSM_CLIP_GY_LOW_ADDR                (0x41)
#define THS8200_CSM_CLIP_BCB_LOW_ADDR               (0x42)
#define THS8200_CSM_CLIP_RCR_LOW_ADDR               (0x43)

#define THS8200_CSM_CLIP_GY_HIGH_ADDR               (0x44)
#define THS8200_CSM_CLIP_BCB_HIGH_ADDR              (0x45)
#define THS8200_CSM_CLIP_RCR_HIGH_ADDR              (0x46)

#define THS8200_CSM_SHIFT_GY_ADDR                   (0x47)
#define THS8200_CSM_SHIFT_BCB_ADDR                  (0x48)
#define THS8200_CSM_SHIFT_RCR_ADDR                  (0x49)

#define THS8200_CSM_GY_CNTL_MULT_MSB_ADDR           (0x4A)
#define THS8200_CSM_MULT_BCB_RCR_MSB_ADDR           (0x4B)
#define THS8200_CSM_MULT_GY_LSB_ADDR                (0x4C)
#define THS8200_CSM_MULT_BCB_LSB_ADDR               (0x4D)
#define THS8200_CSM_MULT_RCR_LSB_ADDR               (0x4E)
#define THS8200_CSM_RCR_BCB_CNTL_ADDR               (0x4F)

/* Display Timing Generation, Part 2 */
#define THS8200_DTG2_BP1_2_MSB_ADDR                 (0x50)
#define THS8200_DTG2_BP3_4_MSB_ADDR                 (0x51)
#define THS8200_DTG2_BP5_6_MSB_ADDR                 (0x52)
#define THS8200_DTG2_BP7_8_MSB_ADDR                 (0x53)
#define THS8200_DTG2_BP9_10_MSB_ADDR                (0x54)
#define THS8200_DTG2_BP11_12_MSB_ADDR               (0x55)
#define THS8200_DTG2_BP13_14_MSB_ADDR               (0x56)
#define THS8200_DTG2_BP15_16_MSB_ADDR               (0x57)

#define THS8200_DTG2_BP1_LSB_ADDR                   (0x58)
#define THS8200_DTG2_BP2_LSB_ADDR                   (0x59)
#define THS8200_DTG2_BP3_LSB_ADDR                   (0x5A)
#define THS8200_DTG2_BP4_LSB_ADDR                   (0x5B)
#define THS8200_DTG2_BP5_LSB_ADDR                   (0x5C)
#define THS8200_DTG2_BP6_LSB_ADDR                   (0x5D)
#define THS8200_DTG2_BP7_LSB_ADDR                   (0x5E)
#define THS8200_DTG2_BP8_LSB_ADDR                   (0x5F)
#define THS8200_DTG2_BP9_LSB_ADDR                   (0x60)
#define THS8200_DTG2_BP10_LSB_ADDR                  (0x61)
#define THS8200_DTG2_BP11_LSB_ADDR                  (0x62)
#define THS8200_DTG2_BP12_LSB_ADDR                  (0x63)
#define THS8200_DTG2_BP13_LSB_ADDR                  (0x64)
#define THS8200_DTG2_BP14_LSB_ADDR                  (0x65)
#define THS8200_DTG2_BP15_LSB_ADDR                  (0x66)
#define THS8200_DTG2_BP16_LSB_ADDR                  (0x67)

#define THS8200_DTG2_LINETYPE1_ADDR                 (0x68)
#define THS8200_DTG2_LINETYPE2_ADDR                 (0x69)
#define THS8200_DTG2_LINETYPE3_ADDR                 (0x6A)
#define THS8200_DTG2_LINETYPE4_ADDR                 (0x6B)
#define THS8200_DTG2_LINETYPE5_ADDR                 (0x6C)
#define THS8200_DTG2_LINETYPE6_ADDR                 (0x6D)
#define THS8200_DTG2_LINETYPE7_ADDR                 (0x6E)
#define THS8200_DTG2_LINETYPE8_ADDR                 (0x6F)

#define THS8200_DTG2_HLENGTH_LSB_ADDR               (0x70)
#define THS8200_DTG2_HLENGTH_LSB_HDLY_MSB_ADDR      (0x71)
#define THS8200_DTG2_HDLY_LSB_ADDR                  (0x72)

#define THS8200_DTG2_VLENGTH1_LSB_ADDR              (0x73)
#define THS8200_DTG2_VLENGTH1_MSB_VDLY1_MSB_ADDR    (0x74)
#define THS8200_DTG2_VDLY1_LSB_ADDR                 (0x75)

#define THS8200_DTG2_VLENGTH2_LSB_ADDR              (0x76)
#define THS8200_DTG2_VLENGTH2_MSB_VDLY2_MSB_ADDR    (0x77)
#define THS8200_DTG2_VDLY2_LSB_ADDR                 (0x78)

#define THS8200_DTG2_HS_IN_DLY_MSB_ADDR             (0x79)
#define THS8200_DTG2_HS_IN_DLY_LSB_ADDR             (0x7A)

#define THS8200_DTG2_VS_IN_DLY_MSB_ADDR             (0x7B)
#define THS8200_DTG2_VS_IN_DLY_LSB_ADDR             (0x7C)

#define THS8200_DTG2_PIX_CNT_MSB_ADDR               (0x7D)
#define THS8200_DTG2_PIX_CNT_LSB_ADDR               (0x7E)

#define THS8200_DTG2_LINE_CNT_MSB_ADDR              (0x7F)
#define THS8200_DTG2_LINE_CNT_LSB_ADDR              (0x80)

#define THS8200_DTG2_CNTL_ADDR                      (0x82)

/* CGMS Control Registers */
#define THS8200_CGMS_CNTL_HEADER_ADDR               (0x83)
#define THS8200_CGMS_PAYLOAD_MSB_ADDR               (0x84)
#define THS8200_CGMS_PAYLOAD_LSB_ADDR               (0x85)

#define THS8200_MISC_PPL_LSB_ADDR                   (0x86)
#define THS8200_MISC_PPL_MSB_ADDR                   (0x87)
#define THS8200_MISC_LPF_LSB_ADDR                   (0x88)
#define THS8200_MISC_LPF_MSB_ADDR                   (0x89)


/* Defines for Configuration Values */
#define THS8200_DTG1_MODE_MASK                      (0x0F)
#define THS8200_DTG1_MODE_VESA_MASTER_VAL           (0x06)
#define THS8200_DTG1_MODE_VESA_SLAVE_VAL            (0x07)

#define THS8200_DTG2_EMBEDDED_SYNC_BIT              (0x20)
#define THS8200_DTG2_RGB_MODE_ON_BIT                (0x40)

#define THS8200_AFMT_LOWER_BYTE_MASK                (0xFF)
#define THS8200_AFMT_HIGHER_BYTE_READ_MASK          (0xF0)
#define THS8200_AFMT_HIGHER_BYTE_MASK               (0x300)
#define THS8200_AFMT_HIGH_VAL_SHIFT                 (8)
#define THS8200_AFMT_LOW_VAL_SHIFT                  (6)

#define THS8200_AFMT_RGB_MODE_VAL                   (0x40)

#define THS8200_NO_SYNC_VAL                         (0x00)
#define THS8200_SYNC_ON_Y_LOW                       (0x0049)
#define THS8200_SYNC_ON_Y_HIGH                      (0x03B6)
#define THS8200_SYNC_ON_CBCR_LOW                    (0x01FF)
#define THS8200_SYNC_ON_CBCR_HIGH                   (0x01FF)

#define THS8200_SYSCTRL_VESA_COLORBARS_BIT          (0x20)
#define THS8200_SYSCTRL_DAC_PWDN_BIT                (0x08)
#define THS8200_SYSCTRL_CHIP_PWDN_BIT               (0x04)
#define THS8200_SYSCTRL_CHIP_MS_BIT                 (0x02)
#define THS8200_SYSCTRL_ARST_FUNC_N_BIT             (0x01)

#define THS8200_DATA_FSADJ_BIT                      (0x40)
#define THS8200_DATA_IFIR12_BYPASS_BIT              (0x20)
#define THS8200_DATA_IFIR35_BYPASS_BIT              (0x10)
#define THS8200_DATA_TRISTATE656_BIT                (0x08)
#define THS8200_DATA_CLK656_ON_BIT                  (0x80)
#define THS8200_DATA_DMAN_CTL_MASK                  (0x07)
#define THS8200_DATA_DMAN_CTL_30BIT_VAL             (0x00)
#define THS8200_DATA_DMAN_CTL_16BIT_RGB_VAL         (0x01)
#define THS8200_DATA_DMAN_CTL_15BIT_RGB_VAL         (0x02)
#define THS8200_DATA_DMAN_CTL_20BIT_YCBCR_VAL       (0x03)
#define THS8200_DATA_DMAN_CTL_10BIT_YCBCR_VAL       (0x04)

#define THS8200_TST_CNTL1_ADDR_CNT                  (2)
#define THS8200_DTG1_Y_SYNC1_LSB_ADDR_CNT           (33)
#define THS8200_DTG2_HLENGTH_LSB_ADDR_CNT           (13)

#define THS8200_CSC_NUM_REGISTERS                   (22)

/** Enum **/
/**
 *  \brief THS8200 analog format Enum
 *   This enum gives available analog format selection with THS8200 encoder
 */
typedef enum THS8200_AnalogFormat_t
{
    THS8200_AFMT_RGB_NO_SYNC,
    /**< RGB out without sync signal - Used for VESA formats */
    THS8200_AFMT_RGB_SYNC_ON_GREEN,
    /**< RGB out with sync signal on Green  */
    THS8200_AFMT_RGB_SYNC_ON_ALL,
    /**< RGB out with sync signal on All    */
    THS8200_AFMT_YPBPR_SYNC_ON_Y,
    /**< YPbPr out with sync signal on Y - USED for EDTV and HDTV formats */
    THS8200_AFMT_YPBPR_SYNC_ON_ALL
    /**< YPbPr out with sync singnal on All */
} THS8200_AnalogFormat;

/**
 *  \brief THS8200 input format Enum
 *  This enum gives available input format for THS8200 encoder
 */
typedef enum THS8200_InputFormat_t
{
    THS8200_IFMT_YCBCR422_10_BIT,
    /**< Not supported    */
    THS8200_IFMT_YCBCR422_20_BIT,
    /**< 16/20 bit YUV422 */
    THS8200_IFMT_YCBCR444,
    /**< 24/30 bit YUV444 - Not supported on EVM */
    THS8200_IFMT_RGB444,
    /**< 24/30 bit RGB444 - Not supported on EVM */
    THS8200_IFMT_RGB565,
    /**< 16 bit RGB565    */
    THS8200_IFMT_RGB555
    /**< 15 bit RGB555    */
} THS8200_InputFormat;

/**
 *  \brief THS8200 operation mode Enum
 *  This enum gives available operation mode for THS8200 encoder
 */
typedef enum THS8200_Mode_t
{
    THS8200_MODE_480P_60HZ,
    /**< HD 480P 60Hz */
    THS8200_MODE_576P_50HZ
    /**< HD 576P 50Hz - Not supported */
} THS8200_Mode;

/**
  * \brief  THS8200 configuration parameters Structure
  *
  *  Structure to contain THS8200 register setting values
  */
typedef struct THS8200_ConfParams_t
{
    THS8200_Mode            mode;
    /**< Indicates resolution for THS8200 */

    THS8200_InputFormat     iFmt;
    /**< Selection for digital input format for THS8200 */

    THS8200_AnalogFormat    aFmt;
    /**< indicates analog output format for THS8200 */

    Bool                    enableSlaveMode;
    /**< Master or Slave mode
     * TRUE  = Slave mode(Timing signals are generated by Video Port)
     * FALSE = Master mode(Timing signals are generated THS8200) - Not supported
     */
    Bool                    enableBT656Sync;
    /**< Boolean to select embedded or external sync for digital input
     * TRUE  = embedded sync - Not Supported)
     * FALSE = external sync
     */
} THS8200_ConfParams;

/**
  * \brief  THS8200 register settings Structure
  *
  *  Structure to contain THS8200 register setting values
  */
typedef struct _THS8200_Regs_t
{
    Uint8 chip_cntl;
    /**< Chip control register 0x03                         */
    Uint8 tst_cntl1;
    /**< Color space conversion test control 1 reister 0x1A */
    Uint8 tst_cntl2;
    /**< Color space conversion test control 2 0x1B         */
    /* Display Timing Generator Control                     */
    Uint8 dtg_y_sync1;
    /**< display timing generator Y sync 1 0x1D             */
    Uint8 dtg_y_sync2 ;
    /**< display timing generator Y sync 2 0x1E             */
    Uint8 dtg_y_sync3;
    /**< display timing generator Ysync 3 0x1F              */
    Uint8 dtg_cbcr_sync1;
    /**< display timing generator CbCr sync 1 0x20          */
    Uint8 dtg_cbcr_sync2;
    /**< display timing generator CbCr sync 2 0x21          */
    Uint8 dtg_cbcr_sync3;
    /**< display timing generator CbCr sync 3 0x22          */
    Uint8 dtg_y_sync_upper;
    /**< display timing generator Y sync upper 0x23         */
    Uint8 dtg_cbcr_sync_upper;
    /**< display timing generator CbCr sync upper 0x24      */
    Uint8 dtg_spec_a;
    /**< Width of negative excursion of tri-level or bi-level sync 0x25 */
    Uint8 dtg_spec_b;
    /**< Distance from end of active video to start of negative sync
     * or to negative-to-positive transition of tri-level sync 0x26
     */
    Uint8 dtg_spec_c;
    /**< Width of positive excursion of tri-level (HDTV mode).
     * Width of equalization pulses (SDTV mode). 0x27
     */
    Uint8 dtg_spec_d;
    /**< Distance from leading edge of Hsync to start of active video
     * (SDTV mode) or from negative-to-positive transition of
     * tri-level sync to start of broad pulse (HDTV mode) 0x28
     */
    Uint8 dtg_spec_d1;
    /**< Distance from equalization pulse at center of line to active
     * video (SDTV mode) 0x29
     */
    Uint8 dtg_spec_e;
    /**< Distance from negative-to-positive transition of tri-level sync to
     * start of active video (HDTV mode). In case color bars are activated in
     * VESA mode, this parameter specifies the start of the color bar with
     * respect to the horizontal sync. 0x2A
     */
    Uint8 dtg_spec_h_msb;
    /**< Duration of broad pulse (SDTV mode) msb. 0x2B */
    Uint8 dtg_spec_h_lsb;
    /**< Duration of broad pulse (SDTV mode) lsb. 0x2C */
    Uint8 dtg_spec_i_msb;
    /**< Duration of full-line broad pulse (SDTV mode) msb 0x2D */
    Uint8 dtg_spec_i_lsb;
    /**< Duration of full-line broad pulse (SDTV mode) lsb 0x2E */
    Uint8 dtg_spec_k_lsb;
    /**< Distance from end of active video to leading edge of sync (SDTV) or
     * from end of broad pulse to negative-to-positive transition of
     * tri-level sync (HDTV) msb 0x2F
     */
    Uint8 dtg_spec_k_msb;
    /**< Distance from end of active video to leading edge of sync (SDTV) or
     * from end of broad pulse to negative-to-positive transition of
     * tri-level sync (HDTV) lsb 0x30 */
    Uint8 dtg_spec_k1;
    /**< Distance from end of active video in first half of line to center
     * equalization pulse for SDTV line type ACTIVE_NEQ 0x31 */
    Uint8 dtg_speg_g_lsb;
    /**< Half the line length. Only used in the calculations of SDTV line
     * types lsb 0x32
     */
    Uint8 dtg_speg_g_msb;
    /**< Half the line length. Only used in the calculations of SDTV line
     * types msb 0x33 */
    Uint8 dtg_total_pixel_msb;
    /**< Total number of pixels per line. Used in all DTG modes msb 0x34 */
    Uint8 dtg_total_pixel_lsb;
    /**< Total number of pixels per line. Used in all DTG modes lsb 0x35 */
    Uint8 dtg_linecnt_msb;
    /**< Sets the starting line number msb for the DTG 0x36 */
    Uint8 dtg_linecnt_lsb;
    /**< Sets the starting line number lsb for the DTG 0x37 */
    Uint8 dtg_mode;
    /**< display timing generator mode 0x38 */
    Uint8 dtg_frame_field_msb;
    /**< Determines number of lines per frame when in generic mode msb 0x39 */
    Uint8 dtg_frame_size_lsb;
    /**< Determines number of lines per frame when in generic mode lsb 0x3A */
    Uint8 dtg_field_size_lsb;
    /**< Determines number of lines in field1 when in generic mode msb 0x3B */
    Uint8 dtg1_vesa_cbar_size;
    /**< Sets the width of each color bar in the color bar test pattern. 0x3C */

    Uint8 dac_cntl_msb;
    /**< DA convert control msb 0x3D  */

    Uint8 csm_gy_cntl_mult_msb;
    /**< Clip/Scale/Multiplier G/Y control 0x4A */

    Uint8 csm_rcr_bcb_cntl;
    /**< Clip/Scale/Multiplier B/Cb control 0x4F */

    Uint8 dtg2_hlength_lsb;
    /**< Display Timing Generator Control, Part 2 horizontal length lsb 0x70 */
    Uint8 dtg2_hlength_lsb_hdly_msb;
    /**< Display Timing Generator Control, Part 2 horizontal delay msb 0x71 */
    Uint8 dtg2_hdly_lsb;
    /**< Display Timing Generator Control, Part 2 horizontal delay lsb 0x72 */
    Uint8 dtg2_vlength1_lsb;
    /**< Display Timing Generator Control, Part 2 vertical length1 lsb 0x73 */
    Uint8 dtg2_vlength1_msb_vdly1_msb;
    /**< Display Timing Generator Control, Part 2 vertical length1 msb 0x74 */
    Uint8 dtg2_vdly1_lsb;
    /**< Display Timing Generator Control, Part 2 vertical delay1 lsb 0x75 */
    Uint8 dtg2_vlength2_lsb;
    /**< Display Timing Generator Control, Part 2 vertical length2 lsb 0x76 */
    Uint8 dtg2_vlength2_msb_vdly2_msb;
    /**< Display Timing Generator Control, Part 2 vertical length1 msb 0x77 */
    Uint8 dtg2_vdly2_lsb;
    /**< Display Timing Generator Control, Part 2 vertical delay2 lsb 0x78 */
    Uint8 dtg2_hs_in_dly_msb;
    /**< Display Timing Generator Control, Part 2 hsync delay1 msb 0x79 */
    Uint8 dtg2_hs_in_dly_lsb;
    /**< Display Timing Generator Control, Part 2 hsync delay1 lsb 0x7A */
    Uint8 dtg2_vs_in_dly_msb;
    /**< Display Timing Generator Control, Part 2 vsync delay1 msb 0x7B */
    Uint8 dtg2_vs_in_dly_lsb;
    /**< Display Timing Generator Control, Part 2 vsync delay1 lsb 0x7C */

    Uint8 dtg2_cntl;
    /**< Display Timing Generator Control, Part 2 control 0x82 */
} _THS8200_Regs;

/* Color Space Conversion Control Registers */
typedef struct _THS8200_CSC_Regs_t
{
    Uint8 csc_r11;
    /**< Color space conversion red 1 1 reister 0x04 */
    Uint8 csc_r12;
    /**< Color space conversion red 1 2 reister 0x05 */
    Uint8 csc_r21;
    /**< Color space conversion red 2 1 reister 0x06 */
    Uint8 csc_r22;
    /**< Color space conversion red 2 2 reister 0x07 */
    Uint8 csc_r31;
    /**< Color space conversion red 3 1 reister 0x08 */
    Uint8 csc_r32;
    /**< Color space conversion red 3 2 reister 0x09 */
    Uint8 csc_g11;
    /**< Color space conversion green 1 1 reister 0x0A */
    Uint8 csc_g12;
    /**< Color space conversion green 1 2 reister 0x0B */
    Uint8 csc_g21;
    /**< Color space conversion green 2 1 reister 0x0C */
    Uint8 csc_g22;
    /**< Color space conversion green 2 2 reister 0x0D */
    Uint8 csc_g31;
    /**< Color space conversion green 3 1 reister 0x0E */
    Uint8 csc_g32;
    /**< Color space conversion green 3 2 reister 0x0F */
    Uint8 csc_b11;
    /**< Color space conversion blue 1 1 reister 0x10 */
    Uint8 csc_b12;
    /**< Color space conversion blue 1 2 reister 0x11 */
    Uint8 csc_b21;
    /**< Color space conversion blue 2 1 reister 0x12 */
    Uint8 csc_b22;
    /**< Color space conversion blue 2 2 reister 0x13 */
    Uint8 csc_b31;
    /**< Color space conversion blue 3 1 reister 0x14 */
    Uint8 csc_b32;
    /**< Color space conversion blue 3 2 reister 0x15 */
    Uint8 csc_offs1;
    /**< Color space conversion offset 1 reister 0x16 */
    Uint8 csc_offs12;
    /**< Color space conversion offset 12 reister 0x17 */
    Uint8 csc_offs23;
    /**< Color space conversion offset 23 reister 0x18 */
    Uint8 csc_offs3;
    /**< Color space conversion offset 3 reister 0x19 */
} _THS8200_CSC_Regs;

extern const _THS8200_Regs ths8200_480p_60Hz_Regs;
extern const _THS8200_Regs ths8200_576p_50Hz_Regs;

extern const _THS8200_CSC_Regs ths8200_CSC_Disable_Regs;
extern const _THS8200_CSC_Regs ths8200_CSC_YCbCr_To_RGB_Regs;
extern const _THS8200_CSC_Regs ths8200_CSC_RGB_To_YCbCr_Regs;


Int32          THS8200_ctrl(EVENC_Handle, Uint32, Ptr);
Int32          THS8200_close(EVENC_Handle);
EVENC_Handle   THS8200_open();

#ifdef __cplusplus
}
#endif /* extern "C" */

#endif /*_THS8200_EXTVIDEO_ENCODER_H */
