/*******************************************************************************
**+--------------------------------------------------------------------------+**
**|                            ****                                          |**
**|                            ****                                          |**
**|                            ******o***                                    |**
**|                      ********_///_****                                   |**
**|                      ***** /_//_/ ****                                   |**
**|                       ** ** (__/ ****                                    |**
**|                           *********                                      |**
**|                            ****                                          |**
**|                            ***                                           |**
**|                                                                          |**
**|         Copyright (c) 1998-2007 Texas Instruments Incorporated           |**
**|                        ALL RIGHTS RESERVED                               |**
**|                                                                          |**
**| Permission is hereby granted to licensees of Texas Instruments           |**
**| Incorporated (TI) products to use this computer program for the sole     |**
**| purpose of implementing a licensee product based on TI products.         |**
**| No other rights to reproduce, use, or disseminate this computer          |**
**| program, whether in part or in whole, are granted.                       |**
**|                                                                          |**
**| TI makes no representation or warranties with respect to the             |**
**| performance of this computer program, and specifically disclaims         |**
**| any responsibility for any damages, special or consequential,            |**
**| connected with the use of this program.                                  |**
**|                                                                          |**
**+--------------------------------------------------------------------------+**
*******************************************************************************/
/**
 *  \file   _ths8200.c
 *
 *  \brief  THS8200 Video Encoder related parameters
 *
 *  This file contains the interfaces, data types and symbolic definitions
 *  that are required for the THS8200 video encoder driver.
 *
 *  NOTE: Use file for configuring the external THS8200 video encoder.
 *
 *  (C) Copyright 2010, Texas Instruments, Inc
 *
 *  \author     Maulik Desai
 *
 *  \version    0.1     Created
 */

/*
 * ========== INCLUDE FILES ========
 */

#include <ti/sdo/pspdrivers/system/dm6437/bios/evmDM6437/video/src/THS8200_extVidEncoder.h>

/*
 * ========= STRUCTURES ===========
 */
const _THS8200_Regs ths8200_480p_60Hz_Regs =
{
    0x11,               /* 0x03 chip_cntl     */

    0x00,               /* 0x1A tst_cntl1     */
    0x00,               /* 0x1B tst_cntl2     */

    /* Display Timing Generator Control */
    0xFF,               /* 0x1D dtg_y_sync1           */
    0x49,               /* 0x1E dtg_y_sync2           */
    0xFF,               /* 0x1F dtg_y_sync3           */

    0xFF,               /* 0x20 dtg_cbcr_sync1        */
    0xFF,               /* 0x21 dtg_cbcr_sync2        */
    0xFF,               /* 0x22 dtg_cbcr_sync3        */

    0x11,               /* 0x23 dtg_y_sync_upper      */
    0x15,               /* 0x24 dtg_cbcr_sync_upper   */

    0x3D,               /* 0x25 dtg_spec_a            */
    0x10,               /* 0x26 dtg_spec_b            */
    0x20,               /* 0x27 dtg_spec_c            */

    0x7A,               /* 0x28 dtg_spec_d            */
    0x00,               /* 0x29 dtg_spec_d1           */
    0xC0,               /* 0x2A dtg_spec_e            */

    0x01,               /* 0x2B dtg_spec_h_msb        */
    0x90,               /* 0x2C dtg_spec_h_lsb        */
    0x03,               /* 0x2D dtg_spec_i_msb        */
    0x1B,               /* 0x2E dtg_spec_i_lsb        */

    0x10,               /* 0x2F dtg_spec_k_lsb        */
    0x00,               /* 0x30 dtg_spec_k_msb        */
    0x00,               /* 0x31 dtg_spec_k1           */

    0xAD,               /* 0x32 dtg_speg_g_lsb        */
    0x01,               /* 0x33 dtg_speg_g_msb        */

    0x03,               /* 0x34 dtg_total_pixel_msb   */
    0x5A,               /* 0x35 dtg_total_pixel_lsb   */
    0x00,               /* 0x36 dtg_linecnt_msb       */
    0x01,               /* 0x37 dtg_linecnt_lsb       */

    0x85,               /* 0x38 dtg_mode              */

    0x27,               /* 0x39 dtg_frame_field_msb   */
    0x0D,               /* 0x3A dtg_frame_size_lsb    */
    0xFF,               /* 0x3B dtg_field_size_lsb    */
    0x00,               /* 0x3C dtg1_vesa_cbar_size don't care  */

    0x00,               /* 0x3D dac_cntl_msb          */

    0x00,               /* 0x4A csm_gy_cntl_mult_msb  */
    0x00,               /* 0x4F csm_rcr_bcb_cntl  */

    0x00,               /* 0x70 dtg2_hlength_lsb              */
    0x00,               /* 0x71 dtg2_hlength_lsb_hdly_msb     */
    0x00,               /* 0x72 dtg2_hdly_lsb                 */

    0x00,               /* 0x73 dtg2_vlength1_lsb             */
    0x00,               /* 0x74 dtg2_vlength1_msb_vdly1_msb   */
    0x00,               /* 0x75 dtg2_vdly1_lsb                */

    0x00,               /* 0x76 dtg2_vlength2_lsb             */
    0x00,               /* 0x77 dtg2_vlength2_msb_vdly2_msb   */
    0x00,               /* 0x78 dtg2_vdly2_lsb                */

    0x00,               /* 0x79 dtg2_hs_in_dly_msb            */
    0x38,               /* 0x7A dtg2_hs_in_dly_lsb            */

    0x00,               /* 0x7B dtg2_vs_in_dly_msb            */
    0x04,               /* 0x7C dtg2_vs_in_dly_lsb            */

    0x3F                /* 0x82 dtg2_cntl                     */
};

const _THS8200_CSC_Regs ths8200_CSC_Disable_Regs =
{
    /* Color Space Conversion Control Registers */
    0x00,               /* 0x04 csc_r11       */
    0x00,               /* 0x05 csc_r12       */
    0x00,               /* 0x06 csc_r21       */
    0x00,               /* 0x07 csc_r22       */
    0x00,               /* 0x08 csc_r31       */
    0x00,               /* 0x09 csc_r32       */

    0x00,               /* 0x0A csc_g11       */
    0x00,               /* 0x0B csc_g12       */
    0x00,               /* 0x0C csc_g21       */
    0x00,               /* 0x0D csc_g22       */
    0x00,               /* 0x0E csc_g31       */
    0x00,               /* 0x0F csc_g32       */

    0x00,               /* 0x10 csc_b11       */
    0x00,               /* 0x11 csc_b12       */
    0x00,               /* 0x12 csc_b21       */
    0x00,               /* 0x13 csc_b22       */
    0x00,               /* 0x14 csc_b31       */
    0x00,               /* 0x15 csc_b32       */

    0x00,               /* 0x16 csc_offs1     */
    0x00,               /* 0x17 csc_offs12    */
    0x00,               /* 0x18 csc_offs23    */
    0x02                /* 0x19 csc_offs3     */
};

/*
 * YCbCr to RGB Conversion.
 *
 * Values based on the following conversion formulas
 *
 * G = Y - 0.4577*Cr - 0.1831*Cb + 328
 * B = Y             + 1.8142*Cb - 929
 * R = Y + 1.5396*Cr             - 788
 */
const _THS8200_CSC_Regs ths8200_CSC_YCbCr_To_RGB_Regs =
{
    /* Color Space Conversion Control Registers */
    0x81,               /* 0x04 csc_r11       */
    0xD5,               /* 0x05 csc_r12       */
    0x00,               /* 0x06 csc_r21       */
    0x00,               /* 0x07 csc_r22       */
    0x06,               /* 0x08 csc_r31       */
    0x29,               /* 0x09 csc_r32       */

    0x04,               /* 0x0A csc_g11       */
    0x00,               /* 0x0B csc_g12       */
    0x04,               /* 0x0C csc_g21       */
    0x80,               /* 0x0D csc_g22       */
    0x04,               /* 0x0E csc_g31       */
    0x00,               /* 0x0F csc_g32       */

    0x80,               /* 0x10 csc_b11       */
    0xBB,               /* 0x11 csc_b12       */
    0x07,               /* 0x12 csc_b21       */
    0x42,               /* 0x13 csc_b22       */
    0x00,               /* 0x14 csc_b31       */
    0x00,               /* 0x15 csc_b32       */

    0x14,               /* 0x16 csc_offs1     */
    0xAE,               /* 0x17 csc_offs12    */
    0x8B,               /* 0x18 csc_offs23    */
    0x15                /* 0x19 csc_offs3     */
};

/*
 * RGB to YCbCr Conversion.
 *
 * Values based on the following conversion formulas
 *
 * Y  =  0.2126*R + 0.7152*G + 0.0722*B
 * Cb = -0.1172*R - 0.3942*G + 0.5114*B + 512
 * Cr =  0.5114*R - 0.4646*G - 0.0468*B + 512
 */
const _THS8200_CSC_Regs ths8200_CSC_RGB_To_YCbCr_Regs =
{
    /* Color Space Conversion Control Registers */
    0x00,               /* 0x04 csc_r11       */
    0xDA,               /* 0x05 csc_r12       */
    0x80,               /* 0x06 csc_r21       */
    0x78,               /* 0x07 csc_r22       */
    0x02,               /* 0x08 csc_r31       */
    0x0C,               /* 0x09 csc_r32       */

    0x02,               /* 0x0A csc_g11       */
    0xDC,               /* 0x0B csc_g12       */
    0x81,               /* 0x0C csc_g21       */
    0x94,               /* 0x0D csc_g22       */
    0x81,               /* 0x0E csc_g31       */
    0xDC,               /* 0x0F csc_g32       */

    0x00,               /* 0x10 csc_b11       */
    0x4A,               /* 0x11 csc_b12       */
    0x02,               /* 0x12 csc_b21       */
    0x0C,               /* 0x13 csc_b22       */
    0x80,               /* 0x14 csc_b31       */
    0x30,               /* 0x15 csc_b32       */

    0x00,               /* 0x16 csc_offs1     */
    0x08,               /* 0x17 csc_offs12    */
    0x02,               /* 0x18 csc_offs23    */
    0x01                /* 0x19 csc_offs3     */
};

