/*******************************************************************************
**+--------------------------------------------------------------------------+**
**|                            ****                                          |**
**|                            ****                                          |**
**|                            ******o***                                    |**
**|                      ********_///_****                                   |**
**|                      ***** /_//_/ ****                                   |**
**|                       ** ** (__/ ****                                    |**
**|                           *********                                      |**
**|                            ****                                          |**
**|                            ***                                           |**
**|                                                                          |**
**|         Copyright (c) 2006-2010 Texas Instruments Incorporated           |**
**|                        ALL RIGHTS RESERVED                               |**
**|                                                                          |**
**| Permission is hereby granted to licensees of Texas Instruments           |**
**| Incorporated (TI) products to use this computer program for the sole     |**
**| purpose of implementing a licensee product based on TI products.         |**
**| No other rights to reproduce, use, or disseminate this computer          |**
**| program, whether in part or in whole, are granted.                       |**
**|                                                                          |**
**| TI makes no representation or warranties with respect to the             |**
**| performance of this computer program, and specifically disclaims         |**
**| any responsibility for any damages, special or consequential,            |**
**| connected with the use of this program.                                  |**
**|                                                                          |**
**+--------------------------------------------------------------------------+**
*******************************************************************************/

/** \file   psp_i2c_interface.c
 *
 *  \brief  This file contains the interface function for the various
 *          hardware devices which will be communicating through the
 *          I2C bus
 *
 *  This file performs a read/write tests for External Video Decoder Periheral
 *
 *
 *  (C) Copyright 2010, Texas Instruments, Inc
 *
 *  \author     Maulik Desai
 *  \version    0.1
 */
/******************************************************************************
                            Header File Inclusion
******************************************************************************/
#include <std.h>
#include <gio.h>

#include <ti/sdo/pspdrivers/common/psp_common.h>
#include <ti/sdo/pspdrivers/drivers/i2c/psp_i2c.h>
#include <ti/sdo/pspdrivers/drivers/i2c/src/psp_i2cApi.h>
#include <ti/sdo/pspdrivers/system/dm6437/bios/evmDM6437/video/src/psp_i2c_interface.h>
#include <ti/sdo/pspdrivers/pal_os/bios/pspUtils.h>

#include <ti/sdo/pspdrivers/pal_os/pal_osTask.h>
#include <ti/sdo/pspdrivers/pal_os/pal_osSem.h>

static PSP_Handle i2cHandle = NULL;

static Uint32 i2cInstanceId =   0x0;

static PAL_OsSemHandle    completionSem;

static Void I2cCallBack (Ptr semHandle,Ptr arg, Ptr ioRequest);

/******************************************************************************
                                    Functions
******************************************************************************/
Int i2c_init()
{
   Bool retVal = TRUE;
   PAL_OsSemAttrs        semAttrs        = PAL_OSSEM_ATTRS;

    if(TRUE == retVal)
    {
        /* Create Completion internal Semaphore */
        if (PAL_osSemCreate(
                            "I2C Completion Sem",
                            0,
                            &semAttrs,
                            &completionSem
                           ) != PAL_SOK)
        {
            retVal = FALSE;
        }
        /* open an instance */
        i2cHandle = PSP_i2cOpen(i2cInstanceId, &I2cCallBack, &completionSem);
        if (i2cHandle == NULL)
        {
            retVal = FALSE;
        }
    }

    return retVal;
}
/*-----------------------------------------------------------------------------
            I2C Write Function to write data to the Slave device
-----------------------------------------------------------------------------*/
Bool i2c_writeReg(Uint8 SlaveAddr,Uint8 *buffer, Uint32 length)
{

    Int     retCode = -1;
    Bool retVal= FALSE;
    PSP_i2cDataParam     buf;
    PSP_I2cRequest      IoRequest;

    buf.i2cTrans.buffer    = buffer;
    buf.i2cTrans.bufLen    = length;
    buf.i2cTrans.flags     = PSP_I2C_DEFAULT_WRITE | PSP_I2C_RESTART;
    buf.i2cTrans.param     = NULL;
    buf.i2cTrans.slaveAddr = SlaveAddr;
    buf.timeout     = -1;


     /* Update dataparams */
    IoRequest.dataparam  = &buf;
    IoRequest.actualSize = 0;
    IoRequest.appCbk     = NULL;
    IoRequest.status     = PSP_SOK;



    retCode = PSP_i2cTransferIOP( i2cHandle,&IoRequest,(Ptr)NULL);

    if (PSP_SINPROGRESS == retCode)
    {
        if( (PAL_SOK != PAL_osSemTake(completionSem, -1)) )
        {
            retVal = FALSE;
        }
        else
        {
            retVal = TRUE;
        }
    }

    if( (retCode < 0) )
    {
        retVal = FALSE;
    }
    else
    {
        retVal = TRUE;
    }

    return (retVal);



}
/*-----------------------------------------------------------------------------
        Function used to read the I2C data from the I2C device
-----------------------------------------------------------------------------*/
Bool i2c_readReg(Uint8 SlaveAddr,Uint8 *buffer, Uint32 length)
{

    Int     retCode = -1;
    Bool retVal= FALSE;
    PSP_i2cDataParam     buf;
    PSP_I2cRequest      IoRequest;

    if (NULL != buffer)
    {

        buf.i2cTrans.buffer    = &buffer[0];
        buf.i2cTrans.bufLen    = 1;
        buf.i2cTrans.flags     = PSP_I2C_DEFAULT_WRITE | PSP_I2C_RESTART;
        buf.i2cTrans.param     = NULL;
        buf.i2cTrans.slaveAddr = SlaveAddr;
        buf.timeout     = -1;


         /* Update dataparams */
        IoRequest.dataparam  = &buf;
        IoRequest.actualSize = 0;
        IoRequest.appCbk     = NULL;
        IoRequest.status     = PSP_SOK;

        retCode = PSP_i2cTransferIOP( i2cHandle,&IoRequest,(Ptr)NULL);

        if (PSP_SINPROGRESS == retCode)
        {
              if( (PAL_SOK != PAL_osSemTake(completionSem, -1)) )
              {
                retVal = FALSE;
              }
              retCode = 0;
        }
        if( (retCode < 0) )
        {
            retVal = FALSE;
        }
        else
        {
            retVal = TRUE;
        }
    }
    /**
     *  Read from Slave Device
    **/
    if(retCode == 0)
    {

        buf.i2cTrans.buffer    = &buffer[1];
        buf.i2cTrans.bufLen    = (length - 1u);
        buf.i2cTrans.flags     = PSP_I2C_DEFAULT_READ;
        buf.i2cTrans.param     = NULL;
        buf.i2cTrans.slaveAddr = SlaveAddr;
        buf.timeout     = -1;


         /* Update dataparams */
        IoRequest.dataparam  = &buf;
        IoRequest.actualSize = 0;
        IoRequest.appCbk     = NULL;
        IoRequest.status     = PSP_SOK;

        retCode = PSP_i2cTransferIOP( i2cHandle,&IoRequest,(Ptr)NULL);

        if (PSP_SINPROGRESS == retCode)
        {
            if( (PAL_SOK != PAL_osSemTake(completionSem, -1)) )
            {
                retVal = FALSE;
            }
            else
            {
                retVal = TRUE;
            }

            retCode = 0;
        }

        if( (retCode < 0) )
        {
                retVal = FALSE;
        }
    }
    return retVal;
}
/*-----------------------------------------------------------------------------
        Function used to Deinitialize I2C
-----------------------------------------------------------------------------*/
Bool i2c_deInit()
{
    Bool retVal = FALSE;

    /* Delete Completion Semaphore  */
    if (PAL_osSemDelete(completionSem) != PAL_SOK)
    {
        retVal = FALSE;
    }
    /* Close driver and delete it */
    if (PSP_SOK == PSP_i2cClose(i2cHandle))
    {
        retVal = TRUE;
    }
    return retVal;
}


/**
 *  \fn      static Void aic31CallBack ()
 *
 *  \brief   This function is the codec call back function invoked from the I2c
 *           driver on transfer completion.
 *
 *  \param   semHandle [IN] pointer to the Semaphore Handle
 *
 *  \return  none
 */
static Void I2cCallBack (Ptr Handle,Ptr arg, Ptr ioRequest)
{
    arg = arg;
    ioRequest = ioRequest;
    Handle = Handle;
    PAL_osSemGive(completionSem);
    return;
}

