/*******************************************************************************
**+--------------------------------------------------------------------------+**
**|                            ****                                          |**
**|                            ****                                          |**
**|                            ******o***                                    |**
**|                      ********_///_****                                   |**
**|                      ***** /_//_/ ****                                   |**
**|                       ** ** (__/ ****                                    |**
**|                           *********                                      |**
**|                            ****                                          |**
**|                            ***                                           |**
**|                                                                          |**
**|         Copyright (c) 1998-2007 Texas Instruments Incorporated           |**
**|                        ALL RIGHTS RESERVED                               |**
**|                                                                          |**
**| Permission is hereby granted to licensees of Texas Instruments           |**
**| Incorporated (TI) products to use this computer program for the sole     |**
**| purpose of implementing a licensee product based on TI products.         |**
**| No other rights to reproduce, use, or disseminate this computer          |**
**| program, whether in part or in whole, are granted.                       |**
**|                                                                          |**
**| TI makes no representation or warranties with respect to the             |**
**| performance of this computer program, and specifically disclaims         |**
**| any responsibility for any damages, special or consequential,            |**
**| connected with the use of this program.                                  |**
**|                                                                          |**
**+--------------------------------------------------------------------------+**
*******************************************************************************/

/** \file   psp_bios_spdifxmt_st_sample_main.c
 *
 *  \brief  This file contains the test / demo code to demonstrate the
 *          McASP driver in DIT mode implemented for DSP/BIOS in DM648/C6452 platform
 *
 *  (C) Copyright 2007, Texas Instruments, Inc
 *
 *  \author     PSP Team
 *  \version    0.1
 */

#include <stdio.h>
#include <std.h>
#include <gio.h>
#include <log.h>
#include <tsk.h>
#include <ti/sdo/pspdrivers/pal_os/bios/psputils.h>
#include <ti/sdo/pspdrivers/drivers/uart/psp_uart.h>
#include <ti/sdo/edma3/drv/edma3_drv.h>

#ifdef CHIP_DM648
#include <ti/sdo/pspdrivers/pal_sys/dm648/pal_sys.h>
#include <ti/sdo/pspdrivers/pal_sys/dm648/pal_sys_soc.h>
#endif

#ifdef CHIP_C6452
#include <ti/sdo/pspdrivers/pal_sys/c6452/pal_sys.h>
#include <ti/sdo/pspdrivers/pal_sys/c6452/pal_sys_soc.h>
#endif
/* Defines to enable and tests for various drivers*/
#define PSP_DEBUG_PRINTF

#ifdef PSP_DEBUG_PRINTF
#define PSP_DEBUG_PRINT       printf
#endif /* PSP_DEBUG_PRINTF */

/*
 * External references
 */
extern void start_i2c_sample(void);
extern EDMA3_DRV_Handle hEdma;
extern EDMA3_DRV_Result edma3init();
extern EDMA3_DRV_Result edma3MemToMemCpytest ();

extern PAL_Result mcasp_Init(PSP_Handle hEdma);
extern Void mcaspAudioPlaybackTask (void);

extern far LOG_Obj trace;

extern SEM_Handle audioSem;

/*
 * Local references
 */
static void tskHeartBit(void);



GIO_Handle  hUart_IN,hUart_OUT;
/*
 * OS application entry point (main). This is called before OS task
 * switching enabled.
 */
void main()
{
   return;
}


/*
 * Sample BIOS task
 */
void echo()
{
    EDMA3_DRV_Result    edmaResult;
    PAL_Result result;

    /* Initialize EDMA first */
    PSP_DEBUG_PRINT("\r\nInitialize EDMA first...\r\n");

    edmaResult = edma3init();
    if (EDMA3_DRV_SOK != edmaResult)
    {
        /* Report EDMA Error */
        PSP_DEBUG_PRINT("\r\nEDMA Initialization failed\r\n");
    }
    else
    {
        PSP_DEBUG_PRINT("\r\nEDMA Initialization passed\r\n");
    }

#ifdef PSP_EDMA_TEST
    /* Edma Test for memory to memory copy */
    PSP_DEBUG_PRINT("\r\nEDMA3: Starting EDMA3 Test memory to memory copy\r\n");

    edmaResult = edma3MemToMemCpytest();
    if (EDMA3_DRV_SOK != edmaResult)
    {
        /* Report EDMA Error */
        PSP_DEBUG_PRINT("\r\nEDMA3 : edma3MemToMemCpytest() failed\r\n");
    }
    else
    {
        PSP_DEBUG_PRINT("\r\nEDMA3 : edma3MemToMemCpytest() passed\r\n");
    }
    PSP_DEBUG_PRINT("\r\nEDMA3 : End EDMA3 Test memory to memory copy\r\n\n");
#endif

    printf("McASP: SPDIF Test started\n");
    result = mcasp_Init(hEdma);

    if (PSP_SOK == result)
    {
        mcaspAudioPlaybackTask();
    }
    else
    {
        printf("McASP: Error in creating a channel\n");
    }

    printf("McASP: SPDIF Test end\n");

    /* Start the Heart Beat Print */
    tskHeartBit();

    return;
}

void tskHeartBit()
{
    static Uint32 counter = 0;

    while (counter < 0xFFFFFFFF)
    {
        TSK_sleep(2000);    /* Add large delay */
        printf("PSP Hearbeat[%d]\n\r",counter);
        counter++;
    }
}



/**
 * \brief   which prints on to the console
 */
 /* ARGSUSED */
void pspConsoleOut(Int32 data)
{
#ifndef INCLUDE_PSP_INIT_UART_EDMA
#ifdef INCLUDE_PSP_INIT_UART_DRV
    char charData = (char) data;
    size_t len=1;
    PSP_uartDataParam buf;
    Int32   status;

    if(NULL != hUart_OUT){
        buf.addr = &charData;
        buf.timeout = SYS_FOREVER;
        len = 1;
        status = GIO_write(hUart_OUT, &buf, &len);
        if(! ((status != IOM_COMPLETED)||(status != IOM_PENDING)))
        {
#ifdef PSP_DEBUG_PRINTF
            printf("\npspConsoleOut: Error writing data to UART");
#endif
        }
    }
#endif
#endif /* INCLUDE_PSP_INIT_UART_EDMA */
#ifdef INCLUDE_PSP_INIT_UART_EDMA
    /*printf("%c",data);*/
#endif /* INCLUDE_PSP_INIT_UART_EDMA */
}

