/*******************************************************************************
**+--------------------------------------------------------------------------+**
**|                            ****                                          |**
**|                            ****                                          |**
**|                            ******o***                                    |**
**|                      ********_///_****                                   |**
**|                      ***** /_//_/ ****                                   |**
**|                       ** ** (__/ ****                                    |**
**|                           *********                                      |**
**|                            ****                                          |**
**|                            ***                                           |**
**|                                                                          |**
**|         Copyright (c) 1998-2007 Texas Instruments Incorporated           |**
**|                        ALL RIGHTS RESERVED                               |**
**|                                                                          |**
**| Permission is hereby granted to licensees of Texas Instruments           |**
**| Incorporated (TI) products to use this computer program for the sole     |**
**| purpose of implementing a licensee product based on TI products.         |**
**| No other rights to reproduce, use, or disseminate this computer          |**
**| program, whether in part or in whole, are granted.                       |**
**|                                                                          |**
**| TI makes no representation or warranties with respect to the             |**
**| performance of this computer program, and specifically disclaims         |**
**| any responsibility for any damages, special or consequential,            |**
**| connected with the use of this program.                                  |**
**|                                                                          |**
**+--------------------------------------------------------------------------+**
*******************************************************************************/

/** \file   spdifxmt_sample.c
 *
 *  \brief  This file contains the GIO based S/PDIF sample application in DIT
 *          mode.
 *
 *  (C) Copyright 2007, Texas Instruments, Inc
 *
 *  \author     PSG
 *  \version    0.1
 */
#ifdef DEBUG_PRINT
#include <stdio.h>
#endif

#include <std.h>
#include <iom.h>
#include <gio.h>
#include <ti/sdo/pspdrivers/pal_os/pal_osSem.h>
#include <ti/sdo/pspdrivers/pal_os/pal_osMem.h>
#include <ti/sdo/pspdrivers/pal_os/pal_osProtect.h>
#include <ti/sdo/pspdrivers/pal_os/bios/psputils.h>
#include <ti/sdo/pspdrivers/drivers/mcasp/psp_mcasp.h>
#include <tsk.h>

#ifdef CHIP_DM648
#include <ti/sdo/pspdrivers/soc/dm648/dsp/tistdtypes.h>
#endif

#ifdef CHIP_C6452
#include <ti/sdo/pspdrivers/soc/c6452/dsp/tistdtypes.h>
#endif

/* PINMUX address */
#define PINMUX0     ((volatile Uint32*)0x02049000u)

#define MCASP_QUE_DEPTH     20
#define NUM_OF_PACKETS      (5U)
#define MCASP_NUM_ELEMS     (4U * 1024U)
#define NO_OF_SERIALISERS   (1U)
#define PSP_E_IO_ABORTED                   (-52)


static void McASP_PinmuxConfig1 ();
PAL_Result mcasp_Init(PSP_Handle hEdma);
Void mcaspAudioPlaybackTask (void);

/*
  Init configuration for mcasp device - DMA mode
 */
static PSP_McaspHwSetup appSpdifMcaspHwSetup = {         \
    {
      /* .pfunc    = */ 0x08000000,                 /*mcasp or GPIO pin-will be set by driver from chanparams*/
      /* .pdir     = */ 0x00000001,                 /*Direction of pin -will be set by driver */
      /* .gblctl   = */ 0x00000000,                 /*control clk, hclk, statemachine - reset and release - driver ctrl*/
      /* .ditctl   = */ 0x00000000,                 /*DIT mode seting*/
      /* .dlbctl   = */ 0x00000000,                 /*loop back mode setting*/
      /* .amute    = */ 0x00000000,                 /*Amute setting*/
      /* .srctl0   = */ 0x00000000,                 /* init serialiser*/
      /* .srctl1   = */ 0x00000000                  /* init serialiser*/
     },
      {
          /* .rmask    = */ 0xFFFFFFFF,
          /* .rfmt     = */ 0x00000000,
          /* .afsrctl  = */ 0x00000000,
          /* .rtdm     = */ 0x00000001,
          /* .rintctl  = */ 0x00000000,
          /* .rstat    = */ 0x000001FF,                  /*reset any existing status bits*/
          /* .revtctl  = */ 0x00000000,
          {
             /* .aclkrctl  = */ 0x00000003,             /* \div = 1, clk = internal*/
             /* .ahclkrctl = */ 0x00008046,             /* div = 63, no inversion before divider ,Internal*/
             /* .rclkchk   = */ 0x00000000
          },
     },
     {
          /* .xmask    = */ 0xFFFFFFFF,
          /* .xfmt     = */ 0x00000000,
          /* .afsxctl  = */ 0x00000002,
          /* .xtdm     = */ 0x00000001,
          /* .xintctl  = */ 0x00000000,
          /* .xstat    = */ 0x000001FF,                 /*reset any existing status bits*/
          /* .xevtctl  = */ 0x00000000,
          {
             /* .aclkxctl  = */ 0x00000023,             /* \div = 1, clk = internal*/
             /* .ahclkxctl = */ 0x00008046,             /* div = 46, no inversion before divider ,Internal*/
             /* .xclkchk   = */ 0x00000000
          },
     },
           0x00000001              /*emu free*/
} ;

PSP_McaspHwSetupData mcaspSpdifXmtSetup = { \
        /* .xmask    = */ 0x00FFFFFF,                   /* Left Aligned, 24 Bit Data */
        /* .xfmt     = */ 0x000000F0,                   /* 8 Bits right rotation,
                                                           DMA access,
                                                           Slot size = 32bits,
                                                           Pad with 0th bit from data,
                                                           Pad extra bits with 0,
                                                           LSB first,
                                                           0 bit delay from between fsync and data */
        /* .afsxctl  = */ 0x0000C002,                   /* DIT mode,
                                                           Frame sync pulse width - 1 clk bit
                                                           Frame Sync is Internal
                                                           Rising edge is validated */

        /* .xtdm     = */ 0xFFFFFFFF,                   /* All slots counted - DIT mode */
        /* .xintctl  = */ 0x00000000,                   /* This will be filled up driver from ChanParams */
        /* .xstat    = */ 0x000001FF,                   /* Reset any existing status bits */
        /* .xevtctl  = */ 0x00000000,                   /* DMA  mode */
        {
             /* .aclkxctl  = */ 0x00000060,             /* div = 1, Clk = Internal, Falling Edge, Aysnchronous */
             /* .ahclkxctl = */ 0x00008018,             /* div = 90, No inversion before divider ,Internal */
             /* .xclkchk   = */ 0x00000000              /* Set to default values */
        },

};



/**
 * Device Parameters.
 * This will be passed down during mdBindDev.
 */
PSP_mcaspDevParams appSpdifDevParams = {             \
    /** Cache is disabled */
    TRUE,                                       \
    /** Packet Header information not available */
    TRUE,                                      \
   /** McASP HwSetup structure */               \
   &appSpdifMcaspHwSetup                             \
} ;

/**< Output channel handle of the specified McASP port instance */
static  GIO_Handle      opChanHandle;

static Int32            txSemId = 0;


Int16 _sineWavePattern[] = {
0     ,
0     ,
6401  ,
6401  ,
12555 ,
12555 ,
18226 ,
18226 ,
23195 ,
23195 ,
27269 ,
27269 ,
30293 ,
30293 ,
32150 ,
32150 ,
32767 ,
32767 ,
32122 ,
32122 ,
30240 ,
30240 ,
27191 ,
27191 ,
23096 ,
23096 ,
18110 ,
18110 ,
12426 ,
12426 ,
6263  ,
6263  ,
-140  ,
-140  ,
-6538 ,
-6538 ,
-12685,
-12685,
-18342,
-18342,
-23293,
-23293,
-27347,
-27347,
-30346,
-30346,
-32177,
-32177,
-32767,
-32767,
-32094,
-32094,
-30185,
-30185,
-27113,
-27113,
-22996,
-22996,
-17993,
-17993,
-12296,
-12296,
-6126 ,
-6126
};
/* ======== McASP_PinmuxConfig ========
 * This function configures PinMux register for McASP
 */
static void McASP_PinmuxConfig1 ()
{
    /* Enable McASP instant */
    *PINMUX0 &= 0xFFFFFEFF;
    *PINMUX0 |= 0x00000200;
}

/*
 *  Initialize McASP2 with following parameters
 *  isDMADriven   = True
 *  ChannelMode   = DIT
 *  WordLen       = 16
 *  Serial Sel    = 3
 *  edmaHandle    = hEdma
 */
PAL_Result mcasp_Init(PSP_Handle hEdma)
{

    Int                     stat = IOM_COMPLETED;
    PAL_Result              ret = PAL_SOK;
    GIO_Attrs               xmtgioAttrs;
    PSP_mcaspChanParams     xmtchanParams = {0};

    McASP_PinmuxConfig1();

    if(NULL == hEdma)
    {
        ret = IOM_EBADARGS;
    }
    else
    {
#ifdef DEBUG_PRINT
            printf("\r\nMcASP  : Starting Mcasp test");
#endif
            /* Creates an asynchronous transmit channel which operates in DMA mode */
            mcaspSpdifXmtSetup.intCtl                    = 0x00000001u;

            /* Initialize channel attributes.*/
            xmtgioAttrs.nPackets                    = MCASP_QUE_DEPTH;
            xmtgioAttrs.timeout                     = SYS_FOREVER;

            /* Initialize parameters for transmit channel*/
            xmtchanParams.isDmaDriven               = TRUE;
            xmtchanParams.mcaspSetup                = &mcaspSpdifXmtSetup;
            xmtchanParams.channelMode               = PSP_MCASP_DIT_MODE;

			/*
			in DIT mode the wordlen should be 32. As the mcasp takes 24bits of data from the 
			buffer to fill up spdif data field and as slot size is(must be) set to 32bits
			this(SPDIF) is mode, it is mandatory that for each subframe of
			spdif (left channel or right channel) application has to provide 32bits of data.
			That means 
			1)Buffer to the driver in this mode should be of Uint32type and each doulble word
			would cater to one subframe. Hence users should send different channels(left/right)
			of data in different double words.

			2)Set the wordwidth parameter of chanparams to PSP_MCASP_WORDLEN_32.
			*/
            xmtchanParams.wordWidth                 = PSP_MCASP_WORDLEN_32;
            xmtchanParams.noOfChannels              = 1;
            xmtchanParams.noOfSerRequested          = 1U;
            xmtchanParams.indexOfSersRequested[0]   = SERIALIZER_7;
            xmtchanParams.userLoopJobBuffer         = NULL;
            xmtchanParams.userLoopJobLength         = 0;
            xmtchanParams.edmaHandle                = hEdma;
            xmtchanParams.gblCbk                    = NULL;

            opChanHandle = GIO_create("/MCASP0",IOM_OUTPUT,&stat,&xmtchanParams,&xmtgioAttrs);

            if (NULL == opChanHandle)
            {
#ifdef DEBUG_PRINT
                printf("\r\nMcASP  : ERROR: Could not create transmit channel");
#endif
                ret = IOM_EABORT;
            }
            else 
            {
#ifdef DEBUG_PRINT
                printf("\r\nMcASP  : Created  transmit channel");
#endif
            }
    }

    return (ret);
}


/**
 * \brief xmtCallback
 *     Keeps track of number of transmit packets submitted.
 */
/* ARGSUSED */
static Void xmtCallback(Ptr arg, Int status, Ptr addr, Uns size)
{
    static Int32 txcount = 0;

    txcount++;


    if (status == PSP_E_IO_ABORTED)
    {
#ifdef DEBUG_PRINT
        printf("\r\nMcASP  :Request is aborted");
#endif
    }
    /* Release the pending submit request call */
    PAL_osSemGive((PAL_OsSemHandle)txSemId );
}

/**
 * McASP Audio Playback task.
 *
 * This function is for seperate play task, having same priority as of record task
 *
 */
Void mcaspAudioPlaybackTask (void)
{
    Int32               stat = 0;
    Uint32              bufLen  = MCASP_NUM_ELEMS * NO_OF_SERIALISERS;
    volatile Uint32     indx    = 0;
    PAL_OsSemAttrs      attrs;
    Uint32  *           alignedBuffer;
    Uint32              i, j ;
    /**< Pool of buffer used to send Audio Data */
    static PSP_Mcasp_PktAddrPayload audioPackets[MCASP_QUE_DEPTH];
    /* Buffer for Audio Data  */
    static Uint32   rxBuf[(NUM_OF_PACKETS *  MCASP_NUM_ELEMS * NO_OF_SERIALISERS)+64U];
    static  Uint32          pktNum;
    static GIO_AppCallback  xmtAppCallback;
    static Int32    genSineWavePattern[(MCASP_NUM_ELEMS * NO_OF_SERIALISERS)];


    alignedBuffer   = (Uint32 *)(((Uint32)rxBuf + 0x3FU) & ~0x3F);

    /* Fill up 4k buffer with the know sine tone.*/
    for (i=0; i<64; i++){
        for (j=0; j<64; j++){
            genSineWavePattern[(i*64) + j] = _sineWavePattern[j];
        }
    }

    PAL_osMemSet( (Ptr)alignedBuffer, 0, (NUM_OF_PACKETS *  MCASP_NUM_ELEMS * NO_OF_SERIALISERS));

    for (j = 0; j < NUM_OF_PACKETS; j++)
    {
        Uint32 *tempPtr;
        Uint32 *temp2Ptr;
        tempPtr = &alignedBuffer[(j * bufLen)];
        temp2Ptr = (Uint32 *)genSineWavePattern;

        /*
        in case of transfers with SPDIF meta data - user data, channel status for SPDIF frame,
        it is suggested to have each IOP to cater one spdif block and send each IOP (submit) one by one.
        Sending submits one by one is mandatory as otherwise there is a possiblity of user data and 
        channel status getting messed up between IO requests. However for the transfer that does not 
        involve the user data, channel status we could have any transfer size per IO request and 
        IO request can be queued to the driver
        */
        
        for(i = 0; i < bufLen; i++)  /* as the gensinewavepattern can take its size/2 of 32 bit data*/
        {
            tempPtr[i] =  *temp2Ptr;
            temp2Ptr++;
        }
        audioPackets[j].addr           = &(alignedBuffer[j * bufLen]);
        audioPackets[j].chStat         = NULL;
        audioPackets[j].userData       = NULL;
        audioPackets[j].writeDitParams = FALSE;

    }

    /*
     * Fill each of the buffer with SINE wave pattern
     * Note that the data / pattern has to be continous Otherwise we could end up
     * sourcing NOISE in the pattern
     */


    if ( PAL_SOK != PAL_osSemCreate(NULL,1U,&attrs,(PAL_OsSemHandle)&txSemId))
    {
#ifdef DEBUG_PRINT
        printf("\r\nMcASP  : Failed to create semaphore");
#endif
        return ;
    }
    pktNum = 0;
	bufLen= bufLen*4;  /* Converting to bytes - GIO takes size in bytes*/

    PAL_osSemTake((PAL_OsSemHandle)txSemId,PAL_OSSEM_NO_TIMEOUT);

    xmtAppCallback.fxn = (GIO_TappCallback)&xmtCallback;
    xmtAppCallback.arg = NULL;
    stat = GIO_submit(opChanHandle, IOM_WRITE, &audioPackets[0], &bufLen, &xmtAppCallback);
    stat = GIO_submit(opChanHandle, IOM_WRITE, &audioPackets[1], &bufLen, &xmtAppCallback);
    stat = GIO_submit(opChanHandle, IOM_WRITE, &audioPackets[2], &bufLen, &xmtAppCallback);
    stat = GIO_submit(opChanHandle, IOM_WRITE, &audioPackets[3], &bufLen, &xmtAppCallback);
    pktNum = 4;

    for(;;)
    {
        PAL_osSemTake((PAL_OsSemHandle)txSemId,PAL_OSSEM_NO_TIMEOUT);
        stat = GIO_submit(opChanHandle, IOM_WRITE, &audioPackets[pktNum], &bufLen, &xmtAppCallback);
        pktNum++;
        if(pktNum > (NUM_OF_PACKETS - 1)){
            pktNum = 0;
        }
        if  (PSP_SINPROGRESS != stat )
        {
#ifdef DEBUG_PRINT
            printf("\r\nMcASP  Error Submitting Tx packets Exitting....");
#endif
            break;
        }
    }

}
