/******************************************************************************
**+-------------------------------------------------------------------------+**
**|                            ****                                         |**
**|                            ****                                         |**
**|                            ******o***                                   |**
**|                      ********_///_****                                  |**
**|                      ***** /_//_/ ****                                  |**
**|                       ** ** (__/ ****                                   |**
**|                           *********                                     |**
**|                            ****                                         |**
**|                            ***                                          |**
**|                                                                         |**
**|         Copyright (c) 1998-2006 Texas Instruments Incorporated          |**
**|                        ALL RIGHTS RESERVED                              |**
**|                                                                         |**
**| Permission is hereby granted to licensees of Texas Instruments          |**
**| Incorporated (TI) products to use this computer program for the sole    |**
**| purpose of implementing a licensee product based on TI products.        |**
**| No other rights to reproduce, use, or disseminate this computer         |**
**| program, whether in part or in whole, are granted.                      |**
**|                                                                         |**
**| TI makes no representation or warranties with respect to the            |**
**| performance of this computer program, and specifically disclaims        |**
**| any responsibility for any damages, special or consequential,           |**
**| connected with the use of this program.                                 |**
**|                                                                         |**
**+-------------------------------------------------------------------------+**
******************************************************************************/

/*
 * \file   aic33Codec.h
 *
 * \brief  Header for AIC33 audio codec configuration file
 *
 * This file contains the macros, forward declartions used in AIC33 codec configuration
 *
 *  (C) Copyright 2006, Texas Instruments, Inc
 *
 *  \note       Set tabstop to 4 (:se ts=4) while viewing this file in an
 *              editor
 *
 *  \author     Girish Mistral
 *
 *  \version    0.1
 *
 */

#ifndef _AIC33_CODEC_H_
#define _AIC33_CODEC_H_

#include <ti/sdo/pspdrivers/pal_os/pal_osSem.h>

#ifdef CHIP_DM648
#include <ti/sdo/pspdrivers/soc/dm648/dsp/tistdtypes.h>
#include <ti/sdo/pspdrivers/system/dm648/bios/evmDM648/audio/psp_audio.h>
#endif

#ifdef CHIP_C6452
#include <ti/sdo/pspdrivers/soc/c6452/dsp/tistdtypes.h>
#include <ti/sdo/pspdrivers/system/c6452/bios/evm6452/audio/psp_audio.h>
#endif

#ifdef __cplusplus
extern "C" {
#endif

#define LIG_MAX                 0x0077
#define LIG_MIN                 0x0000

#define LOG_MAX                 0x007f
#define LOG_MIN                 0x0000

#define PAGING_LESS_MASK        0x007F
#define PAGING_BIT              0x0080

/** Slave address of AIC33 codec */
#define I2C_AIC33_U3_SLAVE_ADDR        0x18
#define I2C_AIC33_U4_SLAVE_ADDR        0x19
#define I2C_AIC33_U5_SLAVE_ADDR        0x1A
#define I2C_AIC33_U6_SLAVE_ADDR        0x1B
#define I2C_AIC33_SLAVE_ADDR           0x1B

/** Codec module definitions */
#define AIC33_NUMREGS           102
#define AIC33_PAGESELECT        0
#define AIC33_RESET             1


#define MCBSP_BCLKRATE_44100HZ      44100

/** AIC registers */
#define AIC33_PAGE_SELECT_ADDR                      0x0000
#define AIC33_RESET_ADDR                            0x0001
#define AIC33_CODEC_SAMPLE_RATE_ADDR                0x0002
#define AIC33_PLLA_PROG_ADDR                        0x0003
#define AIC33_PLLB_PROG_ADDR                        0x0004
#define AIC33_PLLC_PROG_ADDR                        0x0005
#define AIC33_PLLD_PROG_ADDR                        0x0006
#define AIC33_CODEC_DATAPATH_SETUP_ADDR             0x0007
#define AIC33_SERIAL_INTERFACEA_ADDR                0x0008
#define AIC33_SERIAL_INTERFACEB_ADDR                0x0009
#define AIC33_SERIAL_INTERFACEC_ADDR                0x000A
#define AIC33_CODEC_OVERFLOW_FLAG_ADDR              0x000B
#define AIC33_CODEC_DIGIFILTER_CTRL_ADDR            0x000C
#define AIC33_CODEC_HEADSET_DETA_ADDR               0x000D
#define AIC33_CODEC_HEADSET_DETB_ADDR               0x000E
#define AIC33_LEFT_ADCPGA_GAIN_CTRL_ADDR            0x000F
#define AIC33_RIGHT_ADCPGA_GAIN_CTRL_ADDR           0x0010

/** Connects MIC3 Left or Right to the left ADC PGA */
#define AIC33_MIC3LR_TO_LEFTADC_CTRL_ADDR           0x0011

/** Connects MIC3 Left or Right to the right ADC PGA */
#define AIC33_MIC3LR_TO_RIGHTADC_CTRL_ADDR          0x0012

/** Connects LINE1L to the Left ADC PGA */
#define AIC33_LINE1L_TO_LEFT_ADC_CTRL_ADDR          0x0013

/** Connects LINE2L to the Right ADC PGA */
#define AIC33_LINE2L_TO_LEFT_ADC_CTRL_ADDR          0x0014

/** Connects LINE1R to the Left ADC PGA */
#define AIC33_LINE1R_TO_LEFT_ADC_CTRL_ADDR          0x0015

/** Connects LINE1R to the Right ADC PGA */
#define AIC33_LINE1R_TO_RIGHT_ADC_CTL_ADDR          0x0016

/** Connects LINE2R to the Right ADC PGA */
#define AIC33_LINE2R_TO_RIGTH_ADC_CTRL_ADDR         0x0017

/** Connects LINE1R to the Right ADC PGA */
#define AIC33_LINE1L_TO_RIGTH_ADC_CTRL_ADDR         0x0018

/** MICBIAS Control register */
#define AIC33_MICBIAS_CTRL_ADDR                     0x0019

#define AIC33_LEFT_AGC_CTRLA_ADDR                   0x001A
#define AIC33_LEFT_AGC_CTRLB_ADDR                   0x001B
#define AIC33_LEFT_AGC_CTRLC_ADDR                   0x001C

#define AIC33_RIGHT_AGC_CTRLA_ADDR                  0x001D
#define AIC33_RIGHT_AGC_CTRLB_ADDR                  0x001E
#define AIC33_RIGHT_AGC_CTRLC_ADDR                  0x001F

#define AIC33_LEFT_AGC_GAIN_ADDR                    0x0020
#define AIC33_RIGHT_AGC_GAIN_ADDR                   0x0021
#define AIC33_LEFT_AGC_NOISE_GATE_DEBOUNCE_ADDR     0x0022
#define AIC33_RIGHT_AGC_NOISE_GATE_DEBOUNCE_ADDR    0x0023
#define AIC33_ADC_FLAG_ADDR                         0x0024
#define AIC33_DAC_POWER_OUTPUT_DRIVER_CTRL_ADDR     0x0025
#define AIC33_HP_OUTPUT_DRIVER_CTRL_ADDR            0x0026
#define AIC33_RESERVE                               0x0027
#define AIC33_HP_OUTPUT_STAGE_CTRL_ADDR             0x0028
#define AIC33_DAC_OUTPUT_SWITCH_CTRL_ADDR           0x0029
#define AIC33_OUTPUT_DRV_POP_REDUCTION_ADDR         0x002A
#define AIC33_LEFT_DAC_VOL_CTRL_ADDR                0x002B
#define AIC33_RIGHT_DAC_VOL_CTRL_ADDR               0x002C


#define AIC33_LINE2L_TO_HPLOUT_VOL_CTRL_ADDR        0x002D
#define AIC33_PGA_L_TO_HPLOUT_VOL_CTRL_ADDR         0x002E
#define AIC33_DAC_L1_TO_HPLOUT_VOL_CTRL_ADDR        0x002F
#define AIC33_LINE2R_TO_HPLOUT_VOL_CTRL_ADDR        0x0030
#define AIC33_PGA_R_TO_HPLOUT_VOL_CTRL_ADDR         0x0031
#define AIC33_DAC_R1_TO_HPLOUT_VOL_CTRL_ADDR        0x0032
#define AIC33_HPLOUT_OUTPUT_LEVEL_CTRL_ADDR         0x0033

#define AIC33_LIN2L_TO_HPLCOM_VOL_CTRL_ADDR         0x0034
#define AIC33_PGA_L_TO_HPLCOM_VOL_CTRL_ADDR         0x0035
#define AIC33_DAC_L1_TO_HPLCOM_VOL_CTRL_ADDR        0x0036
#define AIC33_LINE2R_TO_HPLCOM_VOL_CTRL_ADDR        0x0037
#define AIC33_PGA_R_TO_HPLCOM_VOL_CTRL_ADDR         0x0038
#define AIC33_DAC_R1_TO_HPLCOM_VOL_CTRL_ADDR        0x0039
#define AIC33_HPLCOM_OUTPUT_LEVEL_CTRL_ADDR         0x003A


#define AIC33_LINE2L_TO_HPROUT_VOL_CTRL_ADDR        0x003B
#define AIC33_PGA_L_TO_HPROUT_VOL_CTRL_ADDR         0x003C
#define AIC33_DAC_L1_TO_HPROUT_VOL_CTRL_ADDR        0x003D
#define AIC33_LINE2R_TO_HPROUT_VOL_CTRL_ADDR        0x003E
#define AIC33_PGA_R_TO_HPROUT_VOL_CTRL_ADDR         0x003F
#define AIC33_DAC_R1_TO_HPROUT_VOL_CTRL_ADDR        0x0040
#define AIC33_HPROUT_OUTPUT_LEVEL_CTRL_ADDR         0x0041

#define AIC33_LIN2L_TO_HPRCOM_VOL_CTRL_ADDR         0x0042
#define AIC33_PGA_L_TO_HPRCOM_VOL_CTRL_ADDR         0x0043
#define AIC33_DAC_L1_TO_HPRCOM_VOL_CTRL_ADDR        0x0044
#define AIC33_LINE2R_TO_HPRCOM_VOL_CTRL_ADDR        0x0045
#define AIC33_PGA_R_TO_HPRCOM_VOL_CTRL_ADDR         0x0046
#define AIC33_DAC_R1_TO_HPRCOM_VOL_CTRL_ADDR        0x0047
#define AIC33_HPRCOM_OUTPUT_LEVEL_CTRL_ADDR         0x0048

#define AIC33_LIN2L_TO_MONO_LOPM_VOL_CTRL_ADDR      0x0049
#define AIC33_PGA_L_TO_MONO_LOPM_VOL_CTRL_ADDR      0x004A
#define AIC33_DAC_L1_TO_MONO_LOPM_VOL_CTRL_ADDR     0x004B
#define AIC33_LINE2R_TO_MONO_LOPM_VOL_CTRL_ADDR     0x004C
#define AIC33_PGA_R_TO_MONO_LOPM_VOL_CTRL_ADDR      0x004D
#define AIC33_DAC_R1_TO_MONO_LOPM_VOL_CTRL_ADDR     0x004E
#define AIC33_MONO_LOPM_OUTPUT_LEVEL_CTRL_ADDR      0x004F

#define AIC33_LIN2L_TO_LEFT_LOPM_VOL_CTRL_ADDR      0x0050
#define AIC33_PGA_L_TO_LEFT_LOPM_VOL_CTRL_ADDR      0x0051
#define AIC33_DAC_L1_TO_LEFT_LOPM_VOL_CTRL_ADDR     0x0052
#define AIC33_LINE2R_TO_LEFT_LOPM_VOL_CTRL_ADDR     0x0053
#define AIC33_PGA_R_TO_LEFT_LOPM_VOL_CTRL_ADDR      0x0054
#define AIC33_DAC_R1_TO_LEFT_LOPM_VOL_CTRL_ADDR     0x0055
#define AIC33_LEFT_LOPM_OUTPUT_LEVEL_CTRL_ADDR      0x0056

#define AIC33_LIN2L_TO_RIGHT_LOPM_VOL_CTRL_ADDR     0x0057
#define AIC33_PGA_L_TO_RIGHT_LOPM_VOL_CTRL_ADDR     0x0058
#define AIC33_DAC_L1_TO_RIGHT_LOPM_VOL_CTRL_ADDR    0x0059
#define AIC33_LINE2R_TO_RIGHT_LOPM_VOL_CTRL_ADDR    0x005A
#define AIC33_PGA_R_TO_RIGHT_LOPM_VOL_CTRL_ADDR     0x005B
#define AIC33_DAC_R1_TO_RIGHT_LOPM_VOL_CTRL_ADDR    0x005C
#define AIC33_RIGHT_LOPM_OUTPUT_LEVEL_CTRL_ADDR     0x005D

#define AIC33_MODULE_POWER_STAT_ADDR                0x005E
#define AIC33_OUTPUT_DRV_SHORTCKT_DET_STAT_ADDR     0x005F
#define AIC33_STICKY_INTR_FLAGS_ADDR                0x0060
#define AIC33_REALTIME_INTR_FLAGS_ADDR              0x0061
#define AIC33_GPIO1_CTRL_ADDR                       0x0062
#define AIC33_GPIO2_CTRL_ADDR                       0x0063
#define AIC33_ADDITIONAL_GPIOCTRLA_ADDR             0x0064
#define AIC33_ADDITIONAL_GPIOCTRLB_ADDR             0x0065
#define AIC33_CLKGEN_CTRL_ADDR                      0x0066


#define FSREF_48000                                 0x0000
#define FSREF_44100                                 0x1<<7
#define ADC_DUALRATE_ENABLE                         ((0x1u)<<6)
#define ADC_DUALRATE_DISABLE                        (0x0000u)
#define DAC_DUALRATE_ENABLE                         ((0x1u)<<5)
#define DAC_DUALRATE_DISABLE                        (0x0000u)
#define AIC33_BCLK_CTRL_CONTINUOS                   0x0000
#define AIC33_BCLK_CTRL_256MODE                     0x0008
#define AIC33_BCLK_SLAVE                            0x0000
#define AIC33_BCLK_MASTER                           0x0080
#define AIC33_WCLK_SLAVE                            0x0000
#define AIC33_WCLK_MASTER                           0x0040

#define I2C_ICSTR_ICRRDY         0x0008
#define I2C_ICMDR_FREE           0x4000
#define I2C_ICMDR_STT            0x2000
#define I2C_ICMDR_IDLEEN         0x1000
#define I2C_ICMDR_STP            0x0800
#define I2C_ICMDR_MST            0x0400
#define I2C_ICMDR_TRX            0x0200
#define I2C_ICMDR_XA             0x0100
#define I2C_ICMDR_RM             0x0080
#define I2C_ICMDR_DLB            0x0040
#define I2C_ICMDR_IRS            0x0020
#define I2C_ICMDR_STB            0x0010
#define I2C_ICMDR_FDF            0x0008
#define I2C_ICMDR_BC_MASK        0x0007


/** Left DAC control path */
typedef enum {
    LEFT_DAC_PATH_MUTE = 0x0,
    LEFT_DAC_PATH_PLAYS_LEFTDATA = 0x1,
    LEFT_DAC_PATH_PLAYS_RIGHTDATA = 0x2,
    LEFT_DAC_PATH_PLAYS_MONO_LEFTRIGTH =0x3
}aic33_left_dacpath;

/** Right DAC control path */
typedef enum {
    RIGHT_DAC_PATH_MUTE = 0x0,
    RIGHT_DAC_PATH_PLAYS_RIGHTDATA = 0x1,
    RIGHT_DAC_PATH_PLAYS_LEFTDATA = 0x2,
    RIGHT_DAC_PATH_PLAYS_MONO_LEFTRIGTH = 0x3
}aic33_right_dacpath;

/** MOde of the audio serial interface */
typedef enum {
    AIC33_I2S           = 0x0,
    AIC33_DSP           = 0x1,
    AIC33_RIGHT_JUSTIFY = 0x2,
    AIC33_LEFT_JUSTIFY  = 0x3
}aic33_serial_interface_mode;

/** Word length of the audio serial data */
typedef enum {
    AIC33_WORDLEN_16 = 0x0,
    AIC33_WORDLEN_20 = 0x1,
    AIC33_WORDLEN_24 = 0x2,
    AIC33_WORDLEN_32 = 0x3
}aic33_serial_data_wordlen;

/**  Codec Handle */
typedef  struct aic33_codec {
    PAL_OsSemHandle    completionSem;               
 }aic33_CodecHandle;


/**  AIC33 Codec Structure */
typedef struct
{
    Uint16 regs[AIC33_NUMREGS];
} aic33_Config;


/**
 *  aic33Codec_config( Uint32 id, PSP_audio_cfg *audioCfg )
 *     Configure the codec
 **/
Int aic33Codec_config( Uint32 id, PSP_audio_cfg *audioCfg );

/*
 *  aic33_closeCodec( )
 *     Close the codec
 *
 */
void aic33_closeCodec( aic33_CodecHandle aic33handle );

/*
 *  aic33_inGainControl(Uint8 newGain, PSP_audio_cfg *audioCfg)
 *     Change the gain setting of input channel with a passed value
 *
 */
Int aic33_inGainControl(Uint8 newGain, PSP_audio_cfg *audioCfg);

/*
 *  aic33_outGainControl(Uint8 newGain, PSP_audio_cfg *audioCfg)
 *     Change the gain setting of output channel with a passed value
 *
 */
Int aic33_outGainControl(Uint8 newGain, PSP_audio_cfg *audioCfg);

/**
 *  aic33_sampleRateControl( PSP_audio_cfg *audioCfg )
 *  Configure the sampling rate of the Audio Codec
 **/
Int aic33_sampleRateControl (PSP_audio_cfg *audioCfg);

#ifdef __cplusplus
}
#endif

#endif /* _AIC33_CODEC_H_ */
