/*******************************************************************************
**+--------------------------------------------------------------------------+**
**|                            ****                                          |**
**|                            ****                                          |**
**|                            ******o***                                    |**
**|                      ********_///_****                                   |**
**|                      ***** /_//_/ ****                                   |**
**|                       ** ** (__/ ****                                    |**
**|                           *********                                      |**
**|                            ****                                          |**
**|                            ***                                           |**
**|                                                                          |**
**|         Copyright (c) 1998-2006 Texas Instruments Incorporated           |**
**|                        ALL RIGHTS RESERVED                               |**
**|                                                                          |**
**| Permission is hereby granted to licensees of Texas Instruments           |**
**| Incorporated (TI) products to use this computer program for the sole     |**
**| purpose of implementing a licensee product based on TI products.         |**
**| No other rights to reproduce, use, or disseminate this computer          |**
**| program, whether in part or in whole, are granted.                       |**
**|                                                                          |**
**| TI makes no representation or warranties with respect to the             |**
**| performance of this computer program, and specifically disclaims         |**
**| any responsibility for any damages, special or consequential,            |**
**| connected with the use of this program.                                  |**
**|                                                                          |**
**+--------------------------------------------------------------------------+**
*******************************************************************************/

/** \file   psp_dvr_pinmux_combo1_bios_main_sample.c
 *
 *  \brief  This file contains the test / demo code to demonstrate the
 *          I2C/UART/McASP driver implemented for DSP/BIOS in DM648 platform
 *
 *  (C) Copyright 2006, Texas Instruments, Inc
 *
 *  \author     PSP Team
 *  \version    0.1
 */

#include <stdio.h>
#include <std.h>
#include <gio.h>
#include <log.h>
#include <tsk.h>
#include <ti/sdo/pspdrivers/pal_sys/dm648/pal_sys.h>
#include <ti/sdo/pspdrivers/pal_os/bios/psputils.h>
#include <ti/sdo/pspdrivers/pal_sys/dm648/pal_sys_soc.h>
#include <ti/sdo/pspdrivers/drivers/uart/psp_uart.h>

#include <ti/sdo/edma3/drv/edma3_drv.h>


/* Defines to enable and tests for various drivers*/
#define PSP_EDMA_TEST
#define PSP_DEBUG_PRINTF

#ifdef PSP_DEBUG_PRINTF
#define PSP_DEBUG_PRINT       printf
#endif /* PSP_DEBUG_PRINTF */

/* PINMUX address */
#define PINMUX0         ((volatile Uint32*)0x02049000u)

/*
 * External references
 */
extern void start_i2c_sample(void);
extern void start_uart_sample(void);
extern EDMA3_DRV_Handle hEdma;
extern EDMA3_DRV_Result edma3init();
extern EDMA3_DRV_Result edma3MemToMemCpytest ();

extern far LOG_Obj trace;

/*
 * Global References
 */
GIO_Handle  hUart_IN,hUart_OUT;


/*
 * Local references
 */
static void tskHeartBit(void);


/*
 * OS application entry point (main). This is called before OS task
 * switching enabled.
 */
void main()
{
   return;
}


/*
 * ======== VPORT0_init ========
 * VPORT0 init function to enable Video Port 0 module.
 * Note: This function is register as a Init function in BIOS TCF file.
 */
void VPORT0_init(void)
{
    /* Power on VPORT0 */
    PAL_sysModuleClkCtrl(PAL_SYS_CLK_MODULE_VP0, PAL_SYS_MODULE_CLK_ENABLE);

    /* Enable pin mux */
    PAL_sysPinmuxEnable(PAL_SYS_PINMUX_VP0);
}



/*
 * ======== VPORT1_init ========
 * VPORT1 init function to enable Video Port 1 module.
 * Note: This function is register as a Init function in BIOS TCF file.
 */
void VPORT1_init(void)
{
    /* Power on VPORT1 */
    PAL_sysModuleClkCtrl(PAL_SYS_CLK_MODULE_VP1, PAL_SYS_MODULE_CLK_ENABLE);

    /* Enable pin mux */
    PAL_sysPinmuxEnable(PAL_SYS_PINMUX_VP1);
}



/*
 * ======== VPORT2_init ========
 * VPORT2 init function to enable Video Port 2 module.
 * Note: This function is register as a Init function in BIOS TCF file.
 */
void VPORT2_init(void)
{
    /* Power on VPORT2 */
    PAL_sysModuleClkCtrl(PAL_SYS_CLK_MODULE_VP2, PAL_SYS_MODULE_CLK_ENABLE);

    /* Enable pin mux */
    PAL_sysPinmuxEnable(PAL_SYS_PINMUX_VP2);
}



/*
 * ======== VPORT3_init ========
 * VPORT3 init function to enable Video Port 3 module.
 * Note: This function is register as a Init function in BIOS TCF file.
 */
void VPORT3_init(void)
{
    /* Power on VPORT3 */
    PAL_sysModuleClkCtrl(PAL_SYS_CLK_MODULE_VP3, PAL_SYS_MODULE_CLK_ENABLE);

    /* Enable pin mux */
    PAL_sysPinmuxEnable(PAL_SYS_PINMUX_VP3_VP4);
}



/*
 * ======== VPORT4_init ========
 * VPORT4 init function to enable Video Port 4 module.
 * Note: This function is register as a Init function in BIOS TCF file.
 */
void VPORT4_init(void)
{
    /* Power on VPORT4 */
    PAL_sysModuleClkCtrl(PAL_SYS_CLK_MODULE_VP4, PAL_SYS_MODULE_CLK_ENABLE);

    /* Enable pin mux */
    PAL_sysPinmuxEnable(PAL_SYS_PINMUX_VP3_VP4);
}


/*
 * I2C init function called when creating the driver.
 */
void I2C_init()
{
    /*Power On I2C*/
    if(PAL_sysModuleClkCtrl(PAL_SYS_CLK_MODULE_I2C,PAL_SYS_MODULE_CLK_ENABLE) != PAL_SOK)
    {
        return;
    }
}


/*
 * Sample BIOS task
 */
void echo()
{
    PSP_uartIoParams chanParams;
    GIO_Attrs gioAttrs = GIO_ATTRS;
    Int32 echoTskStatus= 0;


    chanParams.hEdma = NULL;

    /* Initialize UART
    * Currently is been used to display messages
    */
    PAL_sysPinmuxEnable(PAL_SYS_PINMUX_UART);
    hUart_OUT = GIO_create("/UART0",IOM_OUTPUT,NULL,&chanParams,&gioAttrs);
    hUart_IN  = GIO_create("/UART0",IOM_INPUT,&echoTskStatus,&chanParams,&gioAttrs);
    if((NULL == hUart_IN)||(NULL == hUart_OUT))
    {
        PSP_DEBUG("ERROR: Initialization of UART failed\n");
        return;
    }


    /* No pinmuxing for I2C on DM648 */
    start_i2c_sample();

    start_uart_sample();

    /* Start the Heart Beat Print */
    tskHeartBit();

    return;
}

void tskHeartBit()
{
    static Uint32 counter = 0;

    while (counter < 0xFFFFFFFF)
    {
        TSK_sleep(2000);    /* Add large delay */
        printf("PSP Hearbeat[%d]\n\r",counter);
        counter++;
    }
}


/**
 * \brief   which prints on to the console
 */
 /* ARGSUSED */
void pspConsoleOut(Int32 data)
{
#ifndef INCLUDE_PSP_INIT_UART_EDMA
#ifdef INCLUDE_PSP_INIT_UART_DRV
    char charData = (char) data;
    size_t len=1;
    PSP_uartDataParam buf;
    Int32   status;

    if(NULL != hUart_OUT){
        buf.addr = &charData;
        buf.timeout = SYS_FOREVER;
        len = 1;
        status = GIO_write(hUart_OUT, &buf, &len);
        if(! ((status != IOM_COMPLETED)||(status != IOM_PENDING)))
        {
#ifdef PSP_DEBUG_PRINTF
            printf("\npspConsoleOut: Error writing data to UART");
#endif
        }
    }
#endif
#endif /* INCLUDE_PSP_INIT_UART_EDMA */
#ifdef INCLUDE_PSP_INIT_UART_EDMA
    /*printf("%c",data);*/
#endif /* INCLUDE_PSP_INIT_UART_EDMA */
}

