/*******************************************************************************
**+--------------------------------------------------------------------------+**
**|                            ****                                          |**
**|                            ****                                          |**
**|                            ******o***                                    |**
**|                      ********_///_****                                   |**
**|                      ***** /_//_/ ****                                   |**
**|                       ** ** (__/ ****                                    |**
**|                           *********                                      |**
**|                            ****                                          |**
**|                            ***                                           |**
**|                                                                          |**
**|         Copyright (c) 1998-2006 Texas Instruments Incorporated           |**
**|                        ALL RIGHTS RESERVED                               |**
**|                                                                          |**
**| Permission is hereby granted to licensees of Texas Instruments           |**
**| Incorporated (TI) products to use this computer program for the sole     |**
**| purpose of implementing a licensee product based on TI products.         |**
**| No other rights to reproduce, use, or disseminate this computer          |**
**| program, whether in part or in whole, are granted.                       |**
**|                                                                          |**
**| TI makes no representation or warranties with respect to the             |**
**| performance of this computer program, and specifically disclaims         |**
**| any responsibility for any damages, special or consequential,            |**
**| connected with the use of this program.                                  |**
**|                                                                          |**
**+--------------------------------------------------------------------------+**
*******************************************************************************/

/** \file   psp_bios_uart_main.c
 *
 *  \brief  This file contains the test / demo code to demonstrate the
 *          UART driver implemented for DSP/BIOS
 *
 *  (C) Copyright 2006, Texas Instruments, Inc
 *
 *  \author     PSP Team
 *  \version    0.1
 */

#include <std.h>
#include <gio.h>
#include <log.h>
#include <tsk.h>
#include <stdio.h>

#ifdef CHIP_DM648
#include <ti/sdo/pspdrivers/pal_sys/dm648/pal_sys.h>
#include <ti/sdo/pspdrivers/pal_sys/dm648/pal_sys_soc.h>
#endif

#ifdef CHIP_C6452
#include <ti/sdo/pspdrivers/pal_sys/c6452/pal_sys.h>
#include <ti/sdo/pspdrivers/pal_sys/c6452/pal_sys_soc.h>
#endif

#include <ti/sdo/pspdrivers/drivers/uart/psp_uart.h>

#ifdef PSP_UART_EDMA_SUPPORT
#include <ti/sdo/edma3/drv/edma3_drv.h>
#endif


#define PSP_DEBUG_PRINT       printf

/*
 * External references
 */

extern void start_uart_sample();

#ifdef PSP_UART_EDMA_SUPPORT
/*
 * EDMA handle (Required in EDMA mode)
 */
extern EDMA3_DRV_Handle hEdma;
#endif
/*
 * Global references
 */

/* UART handle for input channel */
GIO_Handle hUart_IN;

/* UART handle for output channel */
GIO_Handle hUart_OUT;


/*
 * Local References
 */
static void tskHeartBit(void);


void main()
{
    return;
}


/* UART Echo Task */
void pspUartEchoTask(void)
{
    /* PSP Welcome Message */
    PSP_DEBUG_PRINT("***************************************************************\n\r");
    PSP_DEBUG_PRINT("*                                                             *\n\r");
    PSP_DEBUG_PRINT("*                            ****                             *\n\r");
    PSP_DEBUG_PRINT("*                            ****                             *\n\r");
    PSP_DEBUG_PRINT("*                            ******o***                       *\n\r");
    PSP_DEBUG_PRINT("*                      ********_///_****                      *\n\r");
    PSP_DEBUG_PRINT("*                      ***** /_//_/ ****                      *\n\r");
    PSP_DEBUG_PRINT("*                       ** ** (__/ ****                       *\n\r");
    PSP_DEBUG_PRINT("*                           *********                         *\n\r");
    PSP_DEBUG_PRINT("*                            ****                             *\n\r");
    PSP_DEBUG_PRINT("*                            ***                              *\n\r");
    PSP_DEBUG_PRINT("*                                                             *\n\r");
#ifdef CHIP_DM648
    PSP_DEBUG_PRINT("*                  TI DM648  EVM BIOS PSP UART SAMPLE         *\n\r");
#endif
#ifdef CHIP_C6452
    PSP_DEBUG_PRINT("*                  TI C6452  EVM BIOS PSP UART SAMPLE         *\n\r");
#endif
    PSP_DEBUG_PRINT("*                                                             *\n\r");
    PSP_DEBUG_PRINT("*                                                             *\n\r");
    PSP_DEBUG_PRINT("*       For issues on base port contact TII PSP Team          *\n\r");
    PSP_DEBUG_PRINT("*                                                             *\n\r");
    PSP_DEBUG_PRINT("*                                                             *\n\r");
    PSP_DEBUG_PRINT("*                                                             *\n\r");
    PSP_DEBUG_PRINT("***************************************************************\n\r");
    PSP_DEBUG_PRINT("\r\n\r\n");

}

void echo()
{
    GIO_Attrs gioAttrs;
    Int32 echoTskStatus= 0;
    PSP_uartIoParams chanParams;

    /*
     * Initialize channel attributes.
     */
    gioAttrs.nPackets = PSP_UART_NUM_IOP;


    chanParams.hEdma = NULL;

#ifdef PSP_UART_EDMA_SUPPORT
    chanParams.hEdma = hEdma;
#endif

   /* Initialize UART
    * Currently is been used to display messages
    */
    PAL_sysPinmuxEnable(PAL_SYS_PINMUX_UART);
    hUart_OUT = GIO_create("/UART0",IOM_OUTPUT,NULL,&chanParams,&gioAttrs);
    hUart_IN  = GIO_create("/UART0",IOM_INPUT,&echoTskStatus,&chanParams,&gioAttrs);
    if((NULL == hUart_IN)||(NULL == hUart_OUT))
    {
        PSP_DEBUG_PRINT("ERROR: Initialization of UART failed\n");
        return;
    }

    if((NULL != hUart_IN)||(NULL != hUart_OUT))
    {
        /* Print the banner */
        pspUartEchoTask();

        /* Run UART sample application */
        start_uart_sample();

        /* Start the Heart Beat Print */
        tskHeartBit();

    }

    return;
}

void tskHeartBit()
{
    static Uint32 counter = 0;

    while (counter < 0xFFFFFFFF)
    {
        TSK_sleep(1000u);    /* Add large delay */
        PSP_DEBUG_PRINT("\r\n\r\n!!! PSP HrtBt %l", counter);
        counter++;
    }
}

