/*******************************************************************************
**+--------------------------------------------------------------------------+**
**|                            ****                                          |**
**|                            ****                                          |**
**|                            ******o***                                    |**
**|                      ********_///_****                                   |**
**|                      ***** /_//_/ ****                                   |**
**|                       ** ** (__/ ****                                    |**
**|                           *********                                      |**
**|                            ****                                          |**
**|                            ***                                           |**
**|                                                                          |**
**|         Copyright (c) 1998-2007 Texas Instruments Incorporated           |**
**|                        ALL RIGHTS RESERVED                               |**
**|                                                                          |**
**| Permission is hereby granted to licensees of Texas Instruments           |**
**| Incorporated (TI) products to use this computer program for the sole     |**
**| purpose of implementing a licensee product based on TI products.         |**
**| No other rights to reproduce, use, or disseminate this computer          |**
**| program, whether in part or in whole, are granted.                       |**
**|                                                                          |**
**| TI makes no representation or warranties with respect to the             |**
**| performance of this computer program, and specifically disclaims         |**
**| any responsibility for any damages, special or consequential,            |**
**| connected with the use of this program.                                  |**
**|                                                                          |**
**+--------------------------------------------------------------------------+**
*******************************************************************************/

/**
 *  \file    psp_bios_vport_capParams.h
 *
 * This file contains the capture configuration parameters for different modes
 */

#ifndef _PSP_BIOS_VPORT_CAPPARAMS_H
#define _PSP_BIOS_VPORT_CAPPARAMS_H


/*
 * ========== INCLUDE FILES ==============
 */
#include <ti/sdo/pspdrivers/drivers/vport/vport.h>
#include <ti/sdo/pspdrivers/drivers/vport/vportcap.h>

#include <ti/sdo/pspdrivers/system/dm648/bios/evmDM648/video/tvp5154.h>
#include <ti/sdo/pspdrivers/system/dm648/bios/evmDM648/video/tvp7000.h>

#ifdef __cplusplus
extern "C" {
#endif

/*
 * ======== DEFINES =========
 */

#define CAP_PARAMS_PORT_DEFAULT(enableDualChan) {                       \
    enableDualChan,             /* enableDualChan                  */   \
    VPORT_POLARITY_ACTIVE_HIGH, /* vport control pin 1 polarity    */   \
    VPORT_POLARITY_ACTIVE_HIGH, /* vport control pin 2 polarity    */   \
    VPORT_POLARITY_ACTIVE_HIGH, /* vport control pin 3 polarity    */   \
    &TVP5154_Fxns,                                                      \
    &TVP5154_Fxns,                                                      \
}

#define CAP_PARAMS_PORT_HDTV_DEFAULT {                                  \
    FALSE,                      /* enableDualChan                  */   \
    VPORT_POLARITY_ACTIVE_HIGH, /* vport control pin 1 polarity    */   \
    VPORT_POLARITY_ACTIVE_HIGH, /* vport control pin 2 polarity    */   \
    VPORT_POLARITY_ACTIVE_HIGH, /* vport control pin 3 polarity    */   \
    &TVP7000_Fxns,                                                      \
    INV,                                                                \
}

#define CAP_PARAMS_PORT_RAW_DEFAULT(enableDualChan) {                   \
    enableDualChan,             /* enableDualChan                  */   \
    VPORT_POLARITY_ACTIVE_HIGH, /* vport control pin 1 polarity    */   \
    VPORT_POLARITY_ACTIVE_HIGH, /* vport control pin 2 polarity    */   \
    VPORT_POLARITY_ACTIVE_HIGH, /* vport control pin 3 polarity    */   \
    INV,                                                                \
    INV,                                                                \
}


/*
 * NTSC/PAL Capture Configuration
 */
#define CAP_PARAMS_TVP5154_EMBEDDED_DEFAULT(mode, afmt) {               \
    TVP5154_MODE_##mode##,              /* Mode            */           \
    TVP5154_AFMT_##afmt##,              /* Analog format   */           \
    TRUE                                /* enableBT656Sync */           \
}

#define CAP_NTSC_LINE_SZ                (720)
#define CAP_NTSC_NUM_LINES              (480)
#define CAP_NTSC_NUM_LINES_PER_FLD      (CAP_NTSC_NUM_LINES >> 1)

#define CAP_PAL_LINE_SZ                 (720)
#define CAP_PAL_NUM_LINES               (576)
#define CAP_PAL_NUM_LINES_PER_FLD       (CAP_PAL_NUM_LINES >> 1)

#define CAP_PARAMS_CHAN_BT656_DEFAULT(MOD) {                            \
    VPORT_MODE_BT656_8BIT,              /* cmode:3      */              \
    VPORT_FLDOP_FRAME,                  /* fldOp:3      */              \
                                                                        \
    VPORT_SCALING_DISABLE,              /* scale:1      */              \
    VPORT_RESMPL_DISABLE,               /* resmpl:1     */              \
    VPORTCAP_BPK_10BIT_ZERO_EXTENDED,   /* bpk10Bit:2   */              \
                                                                        \
    VPORTCAP_HRST_SAV,                  /* hCtRst:1     */              \
    VPORTCAP_VRST_EAV_V0,               /* vCtRst:1     */              \
                                                                        \
    VPORTCAP_FLDD_DISABLE,              /* fldDect:1    */              \
    VPORTCAP_EXC_DISABLE,               /* fldInv:1     */              \
    VPORTCAP_FINV_DISABLE,              /* fldInv:1     */              \
                                                                        \
    0,                                  /* fldXStrt1    */              \
    3,                                  /* fldYStrt1    */              \
    0,                                  /* fldXStrt2    */              \
    3,                                  /* fldYStrt2    */              \
                                                                        \
    CAP_##MOD##_LINE_SZ - 1,            /* fldXStop1    */              \
    CAP_##MOD##_NUM_LINES_PER_FLD + 2,  /* fldYStop1    */              \
    CAP_##MOD##_LINE_SZ - 1,            /* fldXStop2    */              \
    CAP_##MOD##_NUM_LINES_PER_FLD + 2,  /* fldYStop2    */              \
                                                                        \
    (CAP_##MOD##_LINE_SZ >> 3),         /* thrld        */              \
                                                                        \
    3,                                  /* numFrmBufs   */              \
    128,                                /* alignment    */              \
    VPORT_FLDS_MERGED,                  /* mergeFlds    */              \
                                                                        \
    NULL,                               /* segId        */              \
    TRUE,                               /* autoSyncEnable */            \
    NULL                                /* hEdma        */              \
}


/*
 * 720P 60Hz HDTV Capture Configuration
 */
#define CAP_PARAMS_TVP7000_720P_60HZ_DEFAULT {                          \
    TVP7000_MODE_720P_60HZ,             /* Analog Input Mode     */     \
    TVP7000_OFMT_16BIT_YCBCR_422        /* Digital Output Format */     \
}

#define CAP_720P_LINE_SZ                (1280)
#define CAP_720P_NUM_LINES              (720)

#define CAP_PARAMS_CHAN_720P_60HZ_DEFAULT {                             \
    VPORT_MODE_YCBCR_8BIT,              /* cmode:3      */              \
    VPORT_FLDOP_PROGRESSIVE,            /* fldOp:3      */              \
                                                                        \
    VPORT_SCALING_DISABLE,              /* scale:1      */              \
    VPORT_RESMPL_DISABLE,               /* resmpl:1     */              \
    VPORTCAP_BPK_10BIT_ZERO_EXTENDED,   /* bpk10Bit:2   */              \
                                                                        \
    VPORTCAP_HRST_START_HSYNC,          /* hCtRst:1     */              \
    VPORTCAP_VRST_START_VSYNC,          /* vCtRst:1     */              \
                                                                        \
    VPORTCAP_FLDD_ENABLE,               /* fldDect:1    */              \
    VPORTCAP_EXC_ENABLE,                /* fldInv:1     */              \
    VPORTCAP_FINV_DISABLE,              /* fldInv:1     */              \
                                                                        \
    260,                                /* fldXStrt1    */              \
    30,                                 /* fldYStrt1    */              \
    0,                                  /* fldXStrt2    */              \
    0,                                  /* fldYStrt2    */              \
                                                                        \
    (CAP_720P_LINE_SZ - 1 + 260),       /* fldXStop1    */              \
    (CAP_720P_NUM_LINES - 1 + 30),      /* fldYStop1    */              \
    0,                                  /* fldXStop2    */              \
    0,                                  /* fldYStop2    */              \
                                                                        \
    (CAP_720P_LINE_SZ >> 3),            /* thrld        */              \
                                                                        \
    3,                                  /* numFrmBufs   */              \
    128,                                /* alignment    */              \
    VPORT_FLDS_MERGED,                  /* mergeFlds    */              \
                                                                        \
    NULL,                               /* segId        */              \
    TRUE,                               /* autoSyncEnable */            \
    NULL                                /* hEdma        */              \
}

#define CAP_720P_LINE_SZ_FIX            (1280)
#define CAP_720P_NUM_LINES_FIX          (1440)
#define CAP_720P_NUM_LINES_PER_FLD_FIX  (CAP_720P_NUM_LINES_FIX >> 1)

#define CAP_PARAMS_CHAN_720P_60HZ_DEFAULT_FIX {                         \
    VPORT_MODE_YCBCR_8BIT,              /* cmode:3      */              \
    VPORT_FLDOP_FRAME,                  /* fldOp:3      */              \
                                                                        \
    VPORT_SCALING_DISABLE,              /* scale:1      */              \
    VPORT_RESMPL_DISABLE,               /* resmpl:1     */              \
    VPORTCAP_BPK_10BIT_ZERO_EXTENDED,   /* bpk10Bit:2   */              \
                                                                        \
    VPORTCAP_HRST_START_HSYNC,          /* hCtRst:1     */              \
    VPORTCAP_VRST_START_VSYNC,          /* vCtRst:1     */              \
                                                                        \
    VPORTCAP_FLDD_ENABLE,               /* fldDect:1    */              \
    VPORTCAP_EXC_ENABLE,                /* fldInv:1     */              \
    VPORTCAP_FINV_DISABLE,              /* fldInv:1     */              \
                                                                        \
    270,                                /* fldXStrt1    */              \
    25,                                 /* fldYStrt1    */              \
    270,                                /* fldXStrt2    */              \
    25,                                 /* fldYStrt2    */              \
                                                                        \
    (CAP_720P_LINE_SZ_FIX - 1 + 270),           /* fldXStop1    */      \
    (CAP_720P_NUM_LINES_PER_FLD_FIX - 1 + 25),  /* fldYStop1    */      \
    (CAP_720P_LINE_SZ_FIX - 1 + 270),           /* fldXStop2    */      \
    (CAP_720P_NUM_LINES_PER_FLD_FIX - 1 + 25),  /* fldYStop2    */      \
                                                                        \
    (CAP_720P_LINE_SZ_FIX >> 3),        /* thrld        */              \
                                                                        \
    3,                                  /* numFrmBufs   */              \
    128,                                /* alignment    */              \
    VPORT_FLDS_SEPARATED,               /* mergeFlds    */              \
                                                                        \
    NULL,                               /* segId        */              \
    TRUE,                               /* autoSyncEnable */            \
    NULL                                /* hEdma        */              \
}


/*
 * 1080I 60Hz HDTV Capture Configuration
 */
#define CAP_PARAMS_TVP7000_1080I_60HZ_DEFAULT {                         \
    TVP7000_MODE_1080I_60HZ,            /* Analog Input Mode     */     \
    TVP7000_OFMT_16BIT_YCBCR_422        /* Digital Output Format */     \
}

#define CAP_1080I_LINE_SZ               (1920)
#define CAP_1080I_NUM_LINES             (1080)
#define CAP_1080I_NUM_LINES_PER_FLD     (CAP_1080I_NUM_LINES >> 1)

#define CAP_PARAMS_CHAN_1080I_60HZ_DEFAULT {                            \
    VPORT_MODE_YCBCR_8BIT,              /* cmode:3      */              \
    VPORT_FLDOP_FRAME,                  /* fldOp:3      */              \
                                                                        \
    VPORT_SCALING_DISABLE,              /* scale:1      */              \
    VPORT_RESMPL_DISABLE,               /* resmpl:1     */              \
    VPORTCAP_BPK_10BIT_ZERO_EXTENDED,   /* bpk10Bit:2   */              \
                                                                        \
    VPORTCAP_HRST_START_HSYNC,          /* hCtRst:1     */              \
    VPORTCAP_VRST_START_VSYNC,          /* vCtRst:1     */              \
                                                                        \
    VPORTCAP_FLDD_ENABLE,               /* fldDect:1    */              \
    VPORTCAP_EXC_ENABLE,                /* fldInv:1     */              \
    VPORTCAP_FINV_DISABLE,              /* fldInv:1     */              \
                                                                        \
    192,                                /* fldXStrt1    */              \
    20,                                 /* fldYStrt1    */              \
    192,                                /* fldXStrt2    */              \
    20,                                 /* fldYStrt2    */              \
                                                                        \
    (CAP_1080I_LINE_SZ - 1 + 192),          /* fldXStop1    */          \
    (CAP_1080I_NUM_LINES_PER_FLD - 1 + 20), /* fldYStop1    */          \
    (CAP_1080I_LINE_SZ - 1 + 192),          /* fldXStop2    */          \
    (CAP_1080I_NUM_LINES_PER_FLD - 1 + 20), /* fldYStop2    */          \
                                                                        \
    (CAP_1080I_LINE_SZ >> 4),           /* thrld        */              \
                                                                        \
    3,                                  /* numFrmBufs   */              \
    128,                                /* alignment    */              \
    VPORT_FLDS_MERGED,                  /* mergeFlds    */              \
                                                                        \
    NULL,                               /* segId        */              \
    TRUE,                               /* autoSyncEnable */            \
    NULL                                /* hEdma        */              \
}

#define CAP_PARAMS_CHAN_1080I_60HZ_DEFAULT_FIX {                        \
    VPORT_MODE_YCBCR_8BIT,              /* cmode:3      */              \
    VPORT_FLDOP_FRAME,                  /* fldOp:3      */              \
                                                                        \
    VPORT_SCALING_DISABLE,              /* scale:1      */              \
    VPORT_RESMPL_DISABLE,               /* resmpl:1     */              \
    VPORTCAP_BPK_10BIT_ZERO_EXTENDED,   /* bpk10Bit:2   */              \
                                                                        \
    VPORTCAP_HRST_START_HSYNC,          /* hCtRst:1     */              \
    VPORTCAP_VRST_START_VSYNC,          /* vCtRst:1     */              \
                                                                        \
    VPORTCAP_FLDD_ENABLE,               /* fldDect:1    */              \
    VPORTCAP_EXC_ENABLE,                /* fldInv:1     */              \
    VPORTCAP_FINV_DISABLE,              /* fldInv:1     */              \
                                                                        \
    162,                                /* fldXStrt1    */              \
    20,                                 /* fldYStrt1    */              \
    162,                                /* fldXStrt2    */              \
    20,                                 /* fldYStrt2    */              \
                                                                        \
    (CAP_1080I_LINE_SZ - 1 + 162),          /* fldXStop1    */          \
    (CAP_1080I_NUM_LINES_PER_FLD - 1 + 20), /* fldYStop1    */          \
    (CAP_1080I_LINE_SZ - 1 + 162),          /* fldXStop2    */          \
    (CAP_1080I_NUM_LINES_PER_FLD - 1 + 20), /* fldYStop2    */          \
                                                                        \
    (CAP_1080I_LINE_SZ >> 4),           /* thrld        */              \
                                                                        \
    3,                                  /* numFrmBufs   */              \
    128,                                /* alignment    */              \
    VPORT_FLDS_MERGED,                  /* mergeFlds    */              \
                                                                        \
    NULL,                               /* segId        */              \
    TRUE,                               /* autoSyncEnable */            \
    NULL                                /* hEdma        */              \
}


/*
 * 1080I 50Hz HDTV Capture Configuration
 */
#define CAP_PARAMS_TVP7000_1080I_50HZ_DEFAULT {                         \
    TVP7000_MODE_1080I_50HZ,            /* Analog Input Mode     */     \
    TVP7000_OFMT_16BIT_YCBCR_422        /* Digital Output Format */     \
}

#define CAP_PARAMS_CHAN_1080I_50HZ_DEFAULT {                            \
    VPORT_MODE_YCBCR_8BIT,              /* cmode:3      */              \
    VPORT_FLDOP_FRAME,                  /* fldOp:3      */              \
                                                                        \
    VPORT_SCALING_DISABLE,              /* scale:1      */              \
    VPORT_RESMPL_DISABLE,               /* resmpl:1     */              \
    VPORTCAP_BPK_10BIT_ZERO_EXTENDED,   /* bpk10Bit:2   */              \
                                                                        \
    VPORTCAP_HRST_START_HSYNC,          /* hCtRst:1     */              \
    VPORTCAP_VRST_START_VSYNC,          /* vCtRst:1     */              \
                                                                        \
    VPORTCAP_FLDD_ENABLE,               /* fldDect:1    */              \
    VPORTCAP_EXC_ENABLE,                /* fldInv:1     */              \
    VPORTCAP_FINV_DISABLE,              /* fldInv:1     */              \
                                                                        \
    192,                                /* fldXStrt1    */              \
    23,                                 /* fldYStrt1    */              \
    192,                                /* fldXStrt2    */              \
    23,                                 /* fldYStrt2    */              \
                                                                        \
    (CAP_1080I_LINE_SZ - 1 + 192),          /* fldXStop1    */          \
    (CAP_1080I_NUM_LINES_PER_FLD - 1 + 23), /* fldYStop1    */          \
    (CAP_1080I_LINE_SZ - 1 + 192),          /* fldXStop2    */          \
    (CAP_1080I_NUM_LINES_PER_FLD - 1 + 23), /* fldYStop2    */          \
                                                                        \
    (CAP_1080I_LINE_SZ >> 4),           /* thrld        */              \
                                                                        \
    3,                                  /* numFrmBufs   */              \
    128,                                /* alignment    */              \
    VPORT_FLDS_MERGED,                  /* mergeFlds    */              \
                                                                        \
    NULL,                               /* segId        */              \
    TRUE,                               /* autoSyncEnable */            \
    NULL                                /* hEdma        */              \
}

#define CAP_PARAMS_CHAN_1080I_50HZ_DEFAULT_FIX {                        \
    VPORT_MODE_YCBCR_8BIT,              /* cmode:3      */              \
    VPORT_FLDOP_FRAME,                  /* fldOp:3      */              \
                                                                        \
    VPORT_SCALING_DISABLE,              /* scale:1      */              \
    VPORT_RESMPL_DISABLE,               /* resmpl:1     */              \
    VPORTCAP_BPK_10BIT_ZERO_EXTENDED,   /* bpk10Bit:2   */              \
                                                                        \
    VPORTCAP_HRST_START_HSYNC,          /* hCtRst:1     */              \
    VPORTCAP_VRST_START_VSYNC,          /* vCtRst:1     */              \
                                                                        \
    VPORTCAP_FLDD_ENABLE,               /* fldDect:1    */              \
    VPORTCAP_EXC_ENABLE,                /* fldInv:1     */              \
    VPORTCAP_FINV_DISABLE,              /* fldInv:1     */              \
                                                                        \
    192,                                /* fldXStrt1    */              \
    23,                                 /* fldYStrt1    */              \
    192,                                /* fldXStrt2    */              \
    23,                                 /* fldYStrt2    */              \
                                                                        \
    (CAP_1080I_LINE_SZ - 1 + 192),          /* fldXStop1    */          \
    (CAP_1080I_NUM_LINES_PER_FLD - 1 + 23), /* fldYStop1    */          \
    (CAP_1080I_LINE_SZ - 1 + 192),          /* fldXStop2    */          \
    (CAP_1080I_NUM_LINES_PER_FLD - 1 + 23), /* fldYStop2    */          \
                                                                        \
    (CAP_1080I_LINE_SZ >> 4),           /* thrld        */              \
                                                                        \
    3,                                  /* numFrmBufs   */              \
    128,                                /* alignment    */              \
    VPORT_FLDS_MERGED,                  /* mergeFlds    */              \
                                                                        \
    NULL,                               /* segId        */              \
    TRUE,                               /* autoSyncEnable */            \
    NULL                                /* hEdma        */              \
}


/*
 * NTSC 8-bit RAW Capture Configuration
 */
#define CAP_NTSC_RAW_8BIT_LINE_SZ       (720 << 1)
#define CAP_NTSC_RAW_8BIT_NUM_LINES     (480)

#define CAP_PARAMS_CHAN_NTSC_RAW_8BIT {                                 \
    VPORT_MODE_RAW_8BIT,                /* cmode:3      */              \
    VPORTCAP_BPK_10BIT_ZERO_EXTENDED,   /* bpk10Bit     */              \
                                                                        \
    TRUE,                               /* SSE          */              \
    CAP_NTSC_RAW_8BIT_LINE_SZ,          /* blankperiod  */              \
                                                                        \
    CAP_NTSC_RAW_8BIT_LINE_SZ,          /* lineSz       */              \
    CAP_NTSC_RAW_8BIT_NUM_LINES,        /* numLines     */              \
                                                                        \
    (CAP_NTSC_RAW_8BIT_LINE_SZ >> 4),   /* thrld        */              \
                                                                        \
    3,                                  /* numFrmBufs   */              \
    128,                                /* alignment    */              \
                                                                        \
    NULL,                               /* segId        */              \
    NULL                                /* hEdma        */              \
}


/*
 * PAL 8-bit RAW Capture Configuration
 */
#define CAP_PAL_RAW_8BIT_LINE_SZ        (720 << 1)
#define CAP_PAL_RAW_8BIT_NUM_LINES      (576)

#define CAP_PARAMS_CHAN_PAL_RAW_8BIT {                                  \
    VPORT_MODE_RAW_8BIT,                /* cmode:3      */              \
    VPORTCAP_BPK_10BIT_ZERO_EXTENDED,   /* bpk10Bit     */              \
                                                                        \
    TRUE,                               /* SSE          */              \
    CAP_PAL_RAW_8BIT_LINE_SZ,           /* blankperiod  */              \
                                                                        \
    CAP_PAL_RAW_8BIT_LINE_SZ,           /* lineSz       */              \
    CAP_PAL_RAW_8BIT_NUM_LINES,         /* numLines     */              \
                                                                        \
    (CAP_PAL_RAW_8BIT_LINE_SZ >> 4),    /* thrld        */              \
                                                                        \
    3,                                  /* numFrmBufs   */              \
    128,                                /* alignment    */              \
                                                                        \
    NULL,                               /* segId        */              \
    NULL                                /* hEdma        */              \
}


/*
 * NTSC 16-bit RAW Capture Configuration
 */
#define CAP_NTSC_RAW_16BIT_LINE_SZ      (720)
#define CAP_NTSC_RAW_16BIT_NUM_LINES    (480)

#define CAP_PARAMS_CHAN_NTSC_RAW_16BIT {                                \
    VPORT_MODE_RAW_16BIT,               /* cmode:3      */              \
    VPORTCAP_BPK_10BIT_ZERO_EXTENDED,   /* bpk10Bit     */              \
                                                                        \
    TRUE,                               /* SSE          */              \
    CAP_NTSC_RAW_16BIT_LINE_SZ,         /* blankperiod  */              \
                                                                        \
    CAP_NTSC_RAW_16BIT_LINE_SZ,         /* lineSz       */              \
    CAP_NTSC_RAW_16BIT_NUM_LINES,       /* numLines     */              \
                                                                        \
    (CAP_NTSC_RAW_16BIT_LINE_SZ >> 3),  /* thrld        */              \
                                                                        \
    3,                                  /* numFrmBufs   */              \
    128,                                /* alignment    */              \
                                                                        \
    NULL,                               /* segId        */              \
    NULL                                /* hEdma        */              \
}


/*
 * PAL 16-bit RAW Capture Configuration
 */
#define CAP_PAL_RAW_16BIT_LINE_SZ       (720)
#define CAP_PAL_RAW_16BIT_NUM_LINES     (576)

#define CAP_PARAMS_CHAN_PAL_RAW_16BIT {                                 \
    VPORT_MODE_RAW_16BIT,               /* cmode:3      */              \
    VPORTCAP_BPK_10BIT_ZERO_EXTENDED,   /* bpk10Bit     */              \
                                                                        \
    TRUE,                               /* SSE          */              \
    CAP_PAL_RAW_16BIT_LINE_SZ,          /* blankperiod  */              \
                                                                        \
    CAP_PAL_RAW_16BIT_LINE_SZ,          /* lineSz       */              \
    CAP_PAL_RAW_16BIT_NUM_LINES,        /* numLines     */              \
                                                                        \
    (CAP_PAL_RAW_16BIT_LINE_SZ >> 3),   /* thrld        */              \
                                                                        \
    3,                                  /* numFrmBufs   */              \
    128,                                /* alignment    */              \
                                                                        \
    NULL,                               /* segId        */              \
    NULL                                /* hEdma        */              \
}


#ifdef __cplusplus
}
#endif /* extern "C" */

#endif  /* #ifdef _PSP_BIOS_VPORT_CAPPARAMS_H */

/******************************************************************************/
/* End of file                                                                */
/******************************************************************************/
