/*******************************************************************************
**+--------------------------------------------------------------------------+**
**|                            ****                                          |**
**|                            ****                                          |**
**|                            ******o***                                    |**
**|                      ********_///_****                                   |**
**|                      ***** /_//_/ ****                                   |**
**|                       ** ** (__/ ****                                    |**
**|                           *********                                      |**
**|                            ****                                          |**
**|                            ***                                           |**
**|                                                                          |**
**|         Copyright (c) 1998-2007 Texas Instruments Incorporated           |**
**|                        ALL RIGHTS RESERVED                               |**
**|                                                                          |**
**| Permission is hereby granted to licensees of Texas Instruments           |**
**| Incorporated (TI) products to use this computer program for the sole     |**
**| purpose of implementing a licensee product based on TI products.         |**
**| No other rights to reproduce, use, or disseminate this computer          |**
**| program, whether in part or in whole, are granted.                       |**
**|                                                                          |**
**| TI makes no representation or warranties with respect to the             |**
**| performance of this computer program, and specifically disclaims         |**
**| any responsibility for any damages, special or consequential,            |**
**| connected with the use of this program.                                  |**
**|                                                                          |**
**+--------------------------------------------------------------------------+**
*******************************************************************************/

/**
 *  \file    psp_bios_vport_disParams.h
 *
 * This file contains the display configuration parameters for different modes
 */

#ifndef _PSP_BIOS_VPORT_DISPARAMS_H
#define _PSP_BIOS_VPORT_DISPARAMS_H


/*
 * ========== INCLUDE FILES ==============
 */
#include <ti/sdo/pspdrivers/drivers/vport/vport.h>
#include <ti/sdo/pspdrivers/drivers/vport/vportdis.h>

#include <ti/sdo/pspdrivers/system/dm648/bios/evmDM648/video/saa7105.h>
#include <ti/sdo/pspdrivers/system/dm648/bios/evmDM648/video/ths8200.h>
#include <ti/sdo/pspdrivers/system/dm648/bios/evmDM648/video/edcEncoder.h>

#ifdef __cplusplus
extern "C" {
#endif

/*
 * ======== DEFINES =========
 */

#define DIS_PARAMS_PORT_DEFAULT {                                       \
    FALSE,                      /* enableDualChan                   */  \
    VPORT_POLARITY_ACTIVE_HIGH, /* vport control pin 1 polarity     */  \
    VPORT_POLARITY_ACTIVE_HIGH, /* vport control pin 2 polarity     */  \
    VPORT_POLARITY_ACTIVE_HIGH, /* vport control pin 3 polarity     */  \
    &edcEncoder_Fxns,                                                   \
    INV,                                                                \
}

#define DIS_PARAMS_PORT_RAW_DEFAULT {                                   \
    FALSE,                      /* enableDualChan                   */  \
    VPORT_POLARITY_ACTIVE_HIGH, /* vport control pin 1 polarity     */  \
    VPORT_POLARITY_ACTIVE_HIGH, /* vport control pin 2 polarity     */  \
    VPORT_POLARITY_ACTIVE_HIGH, /* vport control pin 3 polarity     */  \
    INV,                                                                \
    INV,                                                                \
}

#define DIS_PARAMS_SAA7105_SDTV_DEFAULT(Mode, aFmt) {                   \
    SAA7105_AFMT_##aFmt##,              /* AnalogFormat     */          \
    SAA7105_MODE_##Mode##,              /* Mode             */          \
    SAA7105_IFMT_YCBCR422_INTERLACED,   /* InputFormat      */          \
    TRUE,                               /* enableSlaveMode  */          \
    FALSE                               /* enableBT656Sync  */          \
}

#define DIS_PARAMS_SAA7105_SDTV_EMBEDDED_DEFAULT(Mode, aFmt) {          \
    SAA7105_AFMT_##aFmt##,              /* AnalogFormat     */          \
    SAA7105_MODE_##Mode##,              /* Mode             */          \
    SAA7105_IFMT_YCBCR422_INTERLACED,   /* InputFormat      */          \
    TRUE,                               /* enableSlaveMode  */          \
    TRUE                                /* enableBT656Sync  */          \
}


/*
 * NTSC Display Configuration
 */
#define DIS_NTSC_LINE_SZ                (720)
#define DIS_NTSC_NUM_LINES              (480)
#define DIS_NTSC_NUM_LINES_PER_FLD      (DIS_NTSC_NUM_LINES >> 1)

#define _DIS_PARAMS_CHAN_NTSC_DEFAULT {                                 \
    VPORT_MODE_BT656_8BIT,              /* dmode:3          */          \
    VPORT_FLDOP_FRAME,                  /* fldOp:3          */          \
                                                                        \
    VPORT_SCALING_DISABLE,              /* scale:1          */          \
    VPORT_RESMPL_DISABLE,               /* resmpl:1         */          \
    VPORTDIS_DEFVAL_ENABLE,             /* defValEn:1       */          \
    VPORTDIS_BPK_10BIT_NORMAL,          /* bpk10Bit:1       */          \
                                                                        \
    VPORTDIS_VCTL1_HSYNC,               /* vctl1Config:2    */          \
    VPORTDIS_VCTL2_VSYNC,               /* vctl2Config:2    */          \
    VPORTDIS_VCTL3_FLD,                 /* vctl3Config:1    */          \
    VPORTDIS_EXC_DISABLE,               /* extCtl:3         */          \
                                                                        \
    858,                                /* frmHSize         */          \
    525,                                /* frmVSize         */          \
                                                                        \
    0,                                  /* imgHOffsetFld1   */          \
    0,                                  /* imgVOffsetFld1   */          \
    DIS_NTSC_LINE_SZ,                   /* imgHSizeFld1     */          \
    DIS_NTSC_NUM_LINES_PER_FLD,         /* imgVSizeFld1     */          \
                                                                        \
    0,                                  /* imgHOffsetFld2   */          \
    0,                                  /* imgVOffsetFld2   */          \
    DIS_NTSC_LINE_SZ,                   /* imgHSizeFld2     */          \
    DIS_NTSC_NUM_LINES_PER_FLD,         /* imgVSizeFld2     */          \
                                                                        \
    720,                                /* hBlnkStart       */          \
    856,                                /* hBlnkStop        */          \
                                                                        \
    720,                                /* vBlnkXStartFld1  */          \
    1,                                  /* vBlnkYStartFld1  */          \
    720,                                /* vBlnkXStopFld1   */          \
    21,                                 /* vBlnkYStopFld1   */          \
                                                                        \
    360,                                /* vBlnkXStartFld2  */          \
    263,                                /* vBlnkYStartFld2  */          \
    360,                                /* vBlnkXStopFld2   */          \
    284,                                /* vBlnkYStopFld2   */          \
                                                                        \
    720,                                /* xStartFld1       */          \
    1,                                  /* yStartFld1       */          \
                                                                        \
    360,                                /* xStartFld2       */          \
    263,                                /* yStartFld2       */          \
                                                                        \
    736,                                /* hSyncStart       */          \
    800,                                /* hSyncStop        */          \
                                                                        \
    736,                                /* vSyncXStartFld1  */          \
    4,                                  /* vSyncYStartFld1  */          \
    736,                                /* vSyncXStopFld1   */          \
    7,                                  /* vSyncYStopFld1   */          \
                                                                        \
    307,                                /* vSyncXStartFld2  */          \
    266,                                /* vSyncYStartFld2  */          \
    307,                                /* vSyncXStopFld2   */          \
    269,                                /* vSyncYStopFld2   */          \
                                                                        \
    16,                                 /* yClipLow         */          \
    235,                                /* yClipHigh        */          \
    16,                                 /* cClipLow         */          \
    240,                                /* cClipHigh        */          \
                                                                        \
    0x10,                               /* Default Y value  */          \
    0x80,                               /* Default Cb value */          \
    0x80,                               /* Default Cr value */          \
                                                                        \
    VPORTDIS_RGBX_DISABLE,              /* RGB extract disable */       \
    0,                                  /* incPix, for raw mode only */ \
                                                                        \
    (DIS_NTSC_LINE_SZ >> 3),            /* thrld            */          \
                                                                        \
    3,                                  /* numFrmBufs       */          \
    128,                                /* alignment        */          \
    VPORT_FLDS_MERGED,                  /* mergeFlds        */          \
                                                                        \
    NULL,                               /* segId            */          \
    NULL                                /* hEdma            */          \
}


/*
 * PAL Display Configuration
 */
#define DIS_PAL_LINE_SZ                 (720)
#define DIS_PAL_NUM_LINES               (576)
#define DIS_PAL_NUM_LINES_PER_FLD       (DIS_PAL_NUM_LINES >> 1)

#define _DIS_PARAMS_CHAN_PAL_DEFAULT {                                  \
    VPORT_MODE_BT656_8BIT,              /* dmode:3          */          \
    VPORT_FLDOP_FRAME,                  /* fldOp:3          */          \
                                                                        \
    VPORT_SCALING_DISABLE,              /* scale:1          */          \
    VPORT_RESMPL_DISABLE,               /* resmpl:1         */          \
    VPORTDIS_DEFVAL_ENABLE,             /* defValEn:1       */          \
    VPORTDIS_BPK_10BIT_NORMAL,          /* bpk10Bit:1       */          \
                                                                        \
    VPORTDIS_VCTL1_HSYNC,               /* vctl1Config:2    */          \
    VPORTDIS_VCTL2_VSYNC,               /* vctl2Config:2    */          \
    VPORTDIS_VCTL3_FLD,                 /* vctl3Config:1    */          \
    VPORTDIS_EXC_DISABLE,               /* extCtl:3         */          \
                                                                        \
    864,                                /* frmHSize         */          \
    625,                                /* frmVSize         */          \
                                                                        \
    0,                                  /* imgHOffsetFld1   */          \
    0,                                  /* imgVOffsetFld1   */          \
    DIS_PAL_LINE_SZ,                    /* imgHSizeFld1     */          \
    DIS_PAL_NUM_LINES_PER_FLD,          /* imgVSizeFld1     */          \
                                                                        \
    0,                                  /* imgHOffsetFld2   */          \
    0,                                  /* imgVOffsetFld2   */          \
    DIS_PAL_LINE_SZ,                    /* imgHSizeFld2     */          \
    DIS_PAL_NUM_LINES_PER_FLD,          /* imgVSizeFld2     */          \
                                                                        \
    720,                                /* hBlnkStart       */          \
    862,                                /* hBlnkStop        */          \
                                                                        \
    720,                                /* vBlnkXStartFld1  */          \
    624,                                /* vBlnkYStartFld1  */          \
    720,                                /* vBlnkXStopFld1   */          \
    23,                                 /* vBlnkYStopFld1   */          \
                                                                        \
    360,                                /* vBlnkXStartFld2  */          \
    311,                                /* vBlnkYStartFld2  */          \
    360,                                /* vBlnkXStopFld2   */          \
    336,                                /* vBlnkYStopFld2   */          \
                                                                        \
    720,                                /* xStartFld1       */          \
    1,                                  /* yStartFld1       */          \
                                                                        \
    360,                                /* xStartFld2       */          \
    313,                                /* yStartFld2       */          \
                                                                        \
    732,                                /* hSyncStart       */          \
    782,                                /* hSyncStop        */          \
                                                                        \
    720,                                /* vSyncXStartFld1  */          \
    1,                                  /* vSyncYStartFld1  */          \
    732,                                /* vSyncXStopFld1   */          \
    3,                                  /* vSyncYStopFld1   */          \
                                                                        \
    360,                                /* vSyncXStartFld2  */          \
    313,                                /* vSyncYStartFld2  */          \
    720,                                /* vSyncXStopFld2   */          \
    316,                                /* vSyncYStopFld2   */          \
                                                                        \
    16,                                 /* yClipLow         */          \
    235,                                /* yClipHigh        */          \
    16,                                 /* cClipLow         */          \
    240,                                /* cClipHigh        */          \
                                                                        \
    0x10,                               /* Default Y value  */          \
    0x80,                               /* Default Cb value */          \
    0x80,                               /* Default Cr value */          \
                                                                        \
    VPORTDIS_RGBX_DISABLE,              /* RGB extract disable */       \
    0,                                  /* incPix, for raw mode only */ \
                                                                        \
    (DIS_PAL_LINE_SZ >> 3),             /* thrld            */          \
                                                                        \
    3,                                  /* numFrmBufs       */          \
    128,                                /* alignment        */          \
    VPORT_FLDS_MERGED,                  /* mergeFlds        */          \
                                                                        \
    NULL,                               /* segId            */          \
    NULL                                /* hEdma            */          \
}

#define DIS_PARAMS_CHAN_BT656_DEFAULT(Mode)  _DIS_PARAMS_CHAN_##Mode##_DEFAULT


/*
 * 720P 60Hz HD Display Configuration
 */
#define DIS_PARAMS_THS8200_720P_60HZ_DEFAULT {                          \
    THS8200_MODE_720P_60HZ,             /* Mode             */          \
    THS8200_IFMT_YCBCR422_20_BIT,       /* InputFormat      */          \
    THS8200_AFMT_YPBPR_SYNC_ON_ALL,     /* AnalogFormat     */          \
    TRUE,                               /* enableSlaveMode  */          \
    TRUE                                /* enableBT656Sync  */          \
}

#define DIS_720P_LINE_SZ                (1280)
#define DIS_720P_NUM_LINES              (720)

#define DIS_PARAMS_CHAN_720P_60HZ_DEFAULT {                             \
    VPORT_MODE_YCBCR_8BIT,              /* dmode:3          */          \
    VPORT_FLDOP_PROGRESSIVE,            /* fldOp:3          */          \
                                                                        \
    VPORT_SCALING_DISABLE,              /* scale:1          */          \
    VPORT_RESMPL_DISABLE,               /* resmpl:1         */          \
    VPORTDIS_DEFVAL_ENABLE,             /* defValEn:1       */          \
    VPORTDIS_BPK_10BIT_NORMAL,          /* bpk10Bit:1       */          \
                                                                        \
    VPORTDIS_VCTL1_HSYNC,               /* vctl1Config:2    */          \
    VPORTDIS_VCTL2_VSYNC,               /* vctl2Config:2    */          \
    VPORTDIS_VCTL3_FLD,                 /* vctl3Config:1    */          \
    VPORTDIS_EXC_DISABLE,               /* extCtl:3         */          \
                                                                        \
    1650,                               /* frmHSize         */          \
    750,                                /* frmVSize         */          \
                                                                        \
    0,                                  /* imgHOffsetFld1   */          \
    0,                                  /* imgVOffsetFld1   */          \
    DIS_720P_LINE_SZ,                   /* imgHSizeFld1     */          \
    DIS_720P_NUM_LINES,                 /* imgVSizeFld1     */          \
                                                                        \
    0,                                  /* imgHOffsetFld2   */          \
    0,                                  /* imgVOffsetFld2   */          \
    0,                                  /* imgHSizeFld2     */          \
    0,                                  /* imgVSizeFld2     */          \
                                                                        \
    1280,                               /* hBlnkStart       */          \
    1646,                               /* hBlnkStop        */          \
                                                                        \
    0,                                  /* vBlnkXStartFld1  */          \
    1,                                  /* vBlnkYStartFld1  */          \
    0,                                  /* vBlnkXStopFld1   */          \
    31,                                 /* vBlnkYStopFld1   */          \
                                                                        \
    0,                                  /* vBlnkXStartFld2  */          \
    0,                                  /* vBlnkYStartFld2  */          \
    0,                                  /* vBlnkXStopFld2   */          \
    0,                                  /* vBlnkYStopFld2   */          \
                                                                        \
    0,                                  /* xStartFld1       */          \
    1,                                  /* yStartFld1       */          \
                                                                        \
    0,                                  /* xStartFld2       */          \
    0,                                  /* yStartFld2       */          \
                                                                        \
    1390,                               /* hSyncStart       */          \
    1430,                               /* hSyncStop        */          \
                                                                        \
    1390,                               /* vSyncXStartFld1  */          \
    5,                                  /* vSyncYStartFld1  */          \
    1390,                               /* vSyncXStopFld1   */          \
    10,                                 /* vSyncYStopFld1   */          \
                                                                        \
    0,                                  /* vSyncXStartFld2  */          \
    0,                                  /* vSyncYStartFld2  */          \
    0,                                  /* vSyncXStopFld2   */          \
    0,                                  /* vSyncYStopFld2   */          \
                                                                        \
    16,                                 /* yClipLow         */          \
    235,                                /* yClipHigh        */          \
    16,                                 /* cClipLow         */          \
    240,                                /* cClipHigh        */          \
                                                                        \
    0x10,                               /* Default Y value  */          \
    0x80,                               /* Default Cb value */          \
    0x80,                               /* Default Cr value */          \
                                                                        \
    VPORTDIS_RGBX_DISABLE,              /* RGB extract disable */       \
    0,                                  /* incPix, for raw mode only */ \
                                                                        \
    (DIS_720P_LINE_SZ >> 3),            /* thrld            */          \
                                                                        \
    3,                                  /* numFrmBufs       */          \
    128,                                /* alignment        */          \
    VPORT_FLDS_MERGED,                  /* mergeFlds        */          \
                                                                        \
    NULL,                               /* segId            */          \
    NULL                                /* hEdma            */          \
}


/*
 * 1080I 60Hz HD Display Configuration
 */
#define DIS_PARAMS_THS8200_1080I_60HZ_DEFAULT {                         \
    THS8200_MODE_1080I_60HZ,            /* Mode             */          \
    THS8200_IFMT_YCBCR422_20_BIT,       /* InputFormat      */          \
    THS8200_AFMT_YPBPR_SYNC_ON_ALL,     /* AnalogFormat     */          \
    TRUE,                               /* enableSlaveMode  */          \
    TRUE                                /* enableBT656Sync  */          \
}

#define DIS_1080I_LINE_SZ               (1920)
#define DIS_1080I_NUM_LINES             (1080)
#define DIS_1080I_NUM_LINES_PER_FLD     (DIS_1080I_NUM_LINES >> 1)

#define DIS_PARAMS_CHAN_1080I_60HZ_DEFAULT {                            \
    VPORT_MODE_YCBCR_8BIT,              /* dmode:3          */          \
    VPORT_FLDOP_FRAME,                  /* fldOp:3          */          \
                                                                        \
    VPORT_SCALING_DISABLE,              /* scale:1          */          \
    VPORT_RESMPL_DISABLE,               /* resmpl:1         */          \
    VPORTDIS_DEFVAL_ENABLE,             /* defValEn:1       */          \
    VPORTDIS_BPK_10BIT_NORMAL,          /* bpk10Bit:1       */          \
                                                                        \
    VPORTDIS_VCTL1_HSYNC,               /* vctl1Config:2    */          \
    VPORTDIS_VCTL2_VSYNC,               /* vctl2Config:2    */          \
    VPORTDIS_VCTL3_FLD,                 /* vctl3Config:1    */          \
    VPORTDIS_EXC_DISABLE,               /* extCtl:3         */          \
                                                                        \
    2200,                               /* frmHSize         */          \
    1125,                               /* frmVSize         */          \
                                                                        \
    0,                                  /* imgHOffsetFld1   */          \
    0,                                  /* imgVOffsetFld1   */          \
    DIS_1080I_LINE_SZ,                  /* imgHSizeFld1     */          \
    DIS_1080I_NUM_LINES_PER_FLD,        /* imgVSizeFld1     */          \
                                                                        \
    0,                                  /* imgHOffsetFld2   */          \
    0,                                  /* imgVOffsetFld2   */          \
    DIS_1080I_LINE_SZ,                  /* imgHSizeFld2     */          \
    DIS_1080I_NUM_LINES_PER_FLD,        /* imgVSizeFld2     */          \
                                                                        \
    1920,                               /* hBlnkStart       */          \
    2196,                               /* hBlnkStop        */          \
                                                                        \
    0,                                  /* vBlnkXStartFld1  */          \
    1,                                  /* vBlnkYStartFld1  */          \
    0,                                  /* vBlnkXStopFld1   */          \
    23,                                 /* vBlnkYStopFld1   */          \
                                                                        \
    0,                                  /* vBlnkXStartFld2  */          \
    563,                                /* vBlnkYStartFld2  */          \
    0,                                  /* vBlnkXStopFld2   */          \
    586,                                /* vBlnkYStopFld2   */          \
                                                                        \
    0,                                  /* xStartFld1       */          \
    1,                                  /* yStartFld1       */          \
                                                                        \
    0,                                  /* xStartFld2       */          \
    563,                                /* yStartFld2       */          \
                                                                        \
    2008,                               /* hSyncStart       */          \
    2052,                               /* hSyncStop        */          \
                                                                        \
    2008,                               /* vSyncXStartFld1  */          \
    2,                                  /* vSyncYStartFld1  */          \
    2008,                               /* vSyncXStopFld1   */          \
    7,                                  /* vSyncYStopFld1   */          \
                                                                        \
    908,                                /* vSyncXStartFld2  */          \
    505,                                /* vSyncYStartFld2  */          \
    908,                                /* vSyncXStopFld2   */          \
    505,                                /* vSyncYStopFld2   */          \
                                                                        \
    16,                                 /* yClipLow         */          \
    235,                                /* yClipHigh        */          \
    16,                                 /* cClipLow         */          \
    240,                                /* cClipHigh        */          \
                                                                        \
    0x10,                               /* Default Y value  */          \
    0x80,                               /* Default Cb value */          \
    0x80,                               /* Default Cr value */          \
                                                                        \
    VPORTDIS_RGBX_DISABLE,              /* RGB extract disable */       \
    0,                                  /* incPix, for raw mode only */ \
                                                                        \
    (DIS_1080I_LINE_SZ >> 4),           /* thrld            */          \
                                                                        \
    3,                                  /* numFrmBufs       */          \
    128,                                /* alignment        */          \
    VPORT_FLDS_MERGED,                  /* mergeFlds        */          \
                                                                        \
    NULL,                               /* segId            */          \
    NULL                                /* hEdma            */          \
}


/*
 * 1080I 50Hz HD Display Configuration
 */
#define DIS_PARAMS_THS8200_1080I_50HZ_DEFAULT {                         \
    THS8200_MODE_1080I_50HZ,            /* Mode             */          \
    THS8200_IFMT_YCBCR422_20_BIT,       /* InputFormat      */          \
    THS8200_AFMT_YPBPR_SYNC_ON_ALL,     /* AnalogFormat     */          \
    TRUE,                               /* enableSlaveMode  */          \
    TRUE                                /* enableBT656Sync  */          \
}

#define DIS_PARAMS_CHAN_1080I_50HZ_DEFAULT {                            \
    VPORT_MODE_YCBCR_8BIT,              /* dmode:3          */          \
    VPORT_FLDOP_FRAME,                  /* fldOp:3          */          \
                                                                        \
    VPORT_SCALING_DISABLE,              /* scale:1          */          \
    VPORT_RESMPL_DISABLE,               /* resmpl:1         */          \
    VPORTDIS_DEFVAL_ENABLE,             /* defValEn:1       */          \
    VPORTDIS_BPK_10BIT_NORMAL,          /* bpk10Bit:1       */          \
                                                                        \
    VPORTDIS_VCTL1_HSYNC,               /* vctl1Config:2    */          \
    VPORTDIS_VCTL2_VSYNC,               /* vctl2Config:2    */          \
    VPORTDIS_VCTL3_FLD,                 /* vctl3Config:1    */          \
    VPORTDIS_EXC_DISABLE,               /* extCtl:3         */          \
                                                                        \
    2640,                               /* frmHSize         */          \
    1125,                               /* frmVSize         */          \
                                                                        \
    0,                                  /* imgHOffsetFld1   */          \
    0,                                  /* imgVOffsetFld1   */          \
    DIS_1080I_LINE_SZ,                  /* imgHSizeFld1     */          \
    DIS_1080I_NUM_LINES_PER_FLD,        /* imgVSizeFld1     */          \
                                                                        \
    0,                                  /* imgHOffsetFld2   */          \
    0,                                  /* imgVOffsetFld2   */          \
    DIS_1080I_LINE_SZ,                  /* imgHSizeFld2     */          \
    DIS_1080I_NUM_LINES_PER_FLD,        /* imgVSizeFld2     */          \
                                                                        \
    1920,                               /* hBlnkStart       */          \
    2636,                               /* hBlnkStop        */          \
                                                                        \
    0,                                  /* vBlnkXStartFld1  */          \
    1,                                  /* vBlnkYStartFld1  */          \
    0,                                  /* vBlnkXStopFld1   */          \
    23,                                 /* vBlnkYStopFld1   */          \
                                                                        \
    0,                                  /* vBlnkXStartFld2  */          \
    563,                                /* vBlnkYStartFld2  */          \
    0,                                  /* vBlnkXStopFld2   */          \
    586,                                /* vBlnkYStopFld2   */          \
                                                                        \
    0,                                  /* xStartFld1       */          \
    1,                                  /* yStartFld1       */          \
                                                                        \
    0,                                  /* xStartFld2       */          \
    563,                                /* yStartFld2       */          \
                                                                        \
    2448,                               /* hSyncStart       */          \
    2485,                               /* hSyncStop        */          \
                                                                        \
    2448,                               /* vSyncXStartFld1  */          \
    2,                                  /* vSyncYStartFld1  */          \
    2448,                               /* vSyncXStopFld1   */          \
    7,                                  /* vSyncYStopFld1   */          \
                                                                        \
    908,                                /* vSyncXStartFld2  */          \
    505,                                /* vSyncYStartFld2  */          \
    908,                                /* vSyncXStopFld2   */          \
    505,                                /* vSyncYStopFld2   */          \
                                                                        \
    16,                                 /* yClipLow         */          \
    235,                                /* yClipHigh        */          \
    16,                                 /* cClipLow         */          \
    240,                                /* cClipHigh        */          \
                                                                        \
    0x10,                               /* Default Y value  */          \
    0x80,                               /* Default Cb value */          \
    0x80,                               /* Default Cr value */          \
                                                                        \
    VPORTDIS_RGBX_DISABLE,              /* RGB extract disable */       \
    0,                                  /* incPix, for raw mode only */ \
                                                                        \
    (DIS_1080I_LINE_SZ >> 4),           /* thrld            */          \
                                                                        \
    3,                                  /* numFrmBufs       */          \
    128,                                /* alignment        */          \
    VPORT_FLDS_MERGED,                  /* mergeFlds        */          \
                                                                        \
    NULL,                               /* segId            */          \
    NULL                                /* hEdma            */          \
}


/*
 * VGA 60Hz VESA Display Configuration
 */
#define DIS_PARAMS_THS8200_VGA_60HZ_DEFAULT {                           \
    THS8200_MODE_VGA_60HZ,              /* Mode             */          \
    THS8200_IFMT_RGB565,                /* InputFormat      */          \
    THS8200_AFMT_RGB_NO_SYNC,           /* AnalogFormat     */          \
    TRUE,                               /* enableSlaveMode  */          \
    FALSE                               /* enableBT656Sync  */          \
}

#define DIS_VGA_LINE_SZ                 (640)
#define DIS_VGA_NUM_LINES               (480)

#define DIS_PARAMS_CHAN_VGA_60HZ_DEFAULT {                              \
    VPORT_MODE_RAW_16BIT,               /* dmode:3          */          \
    VPORT_FLDOP_PROGRESSIVE,            /* fldOp:3          */          \
                                                                        \
    VPORT_SCALING_DISABLE,              /* scale:1          */          \
    VPORT_RESMPL_DISABLE,               /* resmpl:1         */          \
    VPORTDIS_DEFVAL_ENABLE,             /* defValEn:1       */          \
    VPORTDIS_BPK_10BIT_NORMAL,          /* bpk10Bit:1       */          \
                                                                        \
    VPORTDIS_VCTL1_HSYNC,               /* vctl1Config:2    */          \
    VPORTDIS_VCTL2_VSYNC,               /* vctl2Config:2    */          \
    VPORTDIS_VCTL3_FLD,                 /* vctl3Config:1    */          \
    VPORTDIS_EXC_DISABLE,               /* extCtl:3         */          \
                                                                        \
    800,                                /* frmHSize         */          \
    525,                                /* frmVSize         */          \
                                                                        \
    0,                                  /* imgHOffsetFld1   */          \
    0,                                  /* imgVOffsetFld1   */          \
    DIS_VGA_LINE_SZ,                    /* imgHSizeFld1     */          \
    DIS_VGA_NUM_LINES,                  /* imgVSizeFld1     */          \
                                                                        \
    0,                                  /* imgHOffsetFld2   */          \
    0,                                  /* imgVOffsetFld2   */          \
    0,                                  /* imgHSizeFld2     */          \
    0,                                  /* imgVSizeFld2     */          \
                                                                        \
    640,                                /* hBlnkStart       */          \
    0,                                  /* hBlnkStop        */          \
                                                                        \
    0,                                  /* vBlnkXStartFld1  */          \
    1,                                  /* vBlnkYStartFld1  */          \
    0,                                  /* vBlnkXStopFld1   */          \
    46,                                 /* vBlnkYStopFld1   */          \
                                                                        \
    0,                                  /* vBlnkXStartFld2  */          \
    0,                                  /* vBlnkYStartFld2  */          \
    0,                                  /* vBlnkXStopFld2   */          \
    0,                                  /* vBlnkYStopFld2   */          \
                                                                        \
    0,                                  /* xStartFld1       */          \
    1,                                  /* yStartFld1       */          \
                                                                        \
    0,                                  /* xStartFld2       */          \
    0,                                  /* yStartFld2       */          \
                                                                        \
    (656 - 3),                          /* hSyncStart       */          \
    (752 - 3),                          /* hSyncStop        */          \
                                                                        \
    (656 - 3),                          /* vSyncXStartFld1  */          \
    11,                                 /* vSyncYStartFld1  */          \
    (656 - 3),                          /* vSyncXStopFld1   */          \
    13,                                 /* vSyncYStopFld1   */          \
                                                                        \
    0,                                  /* vSyncXStartFld2  */          \
    0,                                  /* vSyncYStartFld2  */          \
    0,                                  /* vSyncXStopFld2   */          \
    0,                                  /* vSyncYStopFld2   */          \
                                                                        \
    16,                                 /* yClipLow         */          \
    240,                                /* yClipHigh        */          \
    16,                                 /* cClipLow         */          \
    240,                                /* cClipHigh        */          \
                                                                        \
    0x00,                               /* Default Y value  */          \
    0x00,                               /* Default Cb value */          \
    0x00,                               /* Default Cr value */          \
                                                                        \
    VPORTDIS_RGBX_DISABLE,              /* RGB extract disable */       \
    1,                                  /* incPix, for raw mode only */ \
                                                                        \
    (DIS_VGA_LINE_SZ >> 3),             /* thrld            */          \
                                                                        \
    3,                                  /* numFrmBufs       */          \
    128,                                /* alignment        */          \
    VPORT_FLDS_MERGED,                  /* mergeFlds        */          \
                                                                        \
    NULL,                               /* segId            */          \
    NULL                                /* hEdma            */          \
}


/*
 * VGA 72Hz VESA Display Configuration
 */
#define DIS_PARAMS_THS8200_VGA_72HZ_DEFAULT {                           \
    THS8200_MODE_VGA_72HZ,              /* Mode             */          \
    THS8200_IFMT_RGB565,                /* InputFormat      */          \
    THS8200_AFMT_RGB_NO_SYNC,           /* AnalogFormat     */          \
    TRUE,                               /* enableSlaveMode  */          \
    FALSE                               /* enableBT656Sync  */          \
}

#define DIS_PARAMS_CHAN_VGA_72HZ_DEFAULT {                              \
    VPORT_MODE_RAW_16BIT,               /* dmode:3          */          \
    VPORT_FLDOP_PROGRESSIVE,            /* fldOp:3          */          \
                                                                        \
    VPORT_SCALING_DISABLE,              /* scale:1          */          \
    VPORT_RESMPL_DISABLE,               /* resmpl:1         */          \
    VPORTDIS_DEFVAL_ENABLE,             /* defValEn:1       */          \
    VPORTDIS_BPK_10BIT_NORMAL,          /* bpk10Bit:1       */          \
                                                                        \
    VPORTDIS_VCTL1_HSYNC,               /* vctl1Config:2    */          \
    VPORTDIS_VCTL2_VSYNC,               /* vctl2Config:2    */          \
    VPORTDIS_VCTL3_FLD,                 /* vctl3Config:1    */          \
    VPORTDIS_EXC_DISABLE,               /* extCtl:3         */          \
                                                                        \
    832,                                /* frmHSize         */          \
    520,                                /* frmVSize         */          \
                                                                        \
    0,                                  /* imgHOffsetFld1   */          \
    0,                                  /* imgVOffsetFld1   */          \
    DIS_VGA_LINE_SZ,                    /* imgHSizeFld1     */          \
    DIS_VGA_NUM_LINES,                  /* imgVSizeFld1     */          \
                                                                        \
    0,                                  /* imgHOffsetFld2   */          \
    0,                                  /* imgVOffsetFld2   */          \
    0,                                  /* imgHSizeFld2     */          \
    0,                                  /* imgVSizeFld2     */          \
                                                                        \
    640,                                /* hBlnkStart       */          \
    0,                                  /* hBlnkStop        */          \
                                                                        \
    0,                                  /* vBlnkXStartFld1  */          \
    1,                                  /* vBlnkYStartFld1  */          \
    0,                                  /* vBlnkXStopFld1   */          \
    41,                                 /* vBlnkYStopFld1   */          \
                                                                        \
    0,                                  /* vBlnkXStartFld2  */          \
    0,                                  /* vBlnkYStartFld2  */          \
    0,                                  /* vBlnkXStopFld2   */          \
    0,                                  /* vBlnkYStopFld2   */          \
                                                                        \
    0,                                  /* xStartFld1       */          \
    1,                                  /* yStartFld1       */          \
                                                                        \
    0,                                  /* xStartFld2       */          \
    0,                                  /* yStartFld2       */          \
                                                                        \
    (656 - 3),                          /* hSyncStart       */          \
    (696 - 3),                          /* hSyncStop        */          \
                                                                        \
    (656 - 3),                          /* vSyncXStartFld1  */          \
    11,                                 /* vSyncYStartFld1  */          \
    (656 - 3),                          /* vSyncXStopFld1   */          \
    14,                                 /* vSyncYStopFld1   */          \
                                                                        \
    0,                                  /* vSyncXStartFld2  */          \
    0,                                  /* vSyncYStartFld2  */          \
    0,                                  /* vSyncXStopFld2   */          \
    0,                                  /* vSyncYStopFld2   */          \
                                                                        \
    16,                                 /* yClipLow         */          \
    240,                                /* yClipHigh        */          \
    16,                                 /* cClipLow         */          \
    240,                                /* cClipHigh        */          \
                                                                        \
    0x00,                               /* Default Y value  */          \
    0x00,                               /* Default Cb value */          \
    0x00,                               /* Default Cr value */          \
                                                                        \
    VPORTDIS_RGBX_DISABLE,              /* RGB extract disable */       \
    1,                                  /* incPix, for raw mode only */ \
                                                                        \
    (DIS_VGA_LINE_SZ >> 3),             /* thrld            */          \
                                                                        \
    3,                                  /* numFrmBufs       */          \
    128,                                /* alignment        */          \
    VPORT_FLDS_MERGED,                  /* mergeFlds        */          \
                                                                        \
    NULL,                               /* segId            */          \
    NULL                                /* hEdma            */          \
}


/*
 * VGA 75Hz VESA Display Configuration
 */
#define DIS_PARAMS_THS8200_VGA_75HZ_DEFAULT {                           \
    THS8200_MODE_VGA_75HZ,              /* Mode             */          \
    THS8200_IFMT_RGB565,                /* InputFormat      */          \
    THS8200_AFMT_RGB_NO_SYNC,           /* AnalogFormat     */          \
    TRUE,                               /* enableSlaveMode  */          \
    FALSE                               /* enableBT656Sync  */          \
}

#define DIS_PARAMS_CHAN_VGA_75HZ_DEFAULT {                              \
    VPORT_MODE_RAW_16BIT,               /* dmode:3          */          \
    VPORT_FLDOP_PROGRESSIVE,            /* fldOp:3          */          \
                                                                        \
    VPORT_SCALING_DISABLE,              /* scale:1          */          \
    VPORT_RESMPL_DISABLE,               /* resmpl:1         */          \
    VPORTDIS_DEFVAL_ENABLE,             /* defValEn:1       */          \
    VPORTDIS_BPK_10BIT_NORMAL,          /* bpk10Bit:1       */          \
                                                                        \
    VPORTDIS_VCTL1_HSYNC,               /* vctl1Config:2    */          \
    VPORTDIS_VCTL2_VSYNC,               /* vctl2Config:2    */          \
    VPORTDIS_VCTL3_FLD,                 /* vctl3Config:1    */          \
    VPORTDIS_EXC_DISABLE,               /* extCtl:3         */          \
                                                                        \
    840,                                /* frmHSize         */          \
    500,                                /* frmVSize         */          \
                                                                        \
    0,                                  /* imgHOffsetFld1   */          \
    0,                                  /* imgVOffsetFld1   */          \
    DIS_VGA_LINE_SZ,                    /* imgHSizeFld1     */          \
    DIS_VGA_NUM_LINES,                  /* imgVSizeFld1     */          \
                                                                        \
    0,                                  /* imgHOffsetFld2   */          \
    0,                                  /* imgVOffsetFld2   */          \
    0,                                  /* imgHSizeFld2     */          \
    0,                                  /* imgVSizeFld2     */          \
                                                                        \
    640,                                /* hBlnkStart       */          \
    0,                                  /* hBlnkStop        */          \
                                                                        \
    0,                                  /* vBlnkXStartFld1  */          \
    1,                                  /* vBlnkYStartFld1  */          \
    0,                                  /* vBlnkXStopFld1   */          \
    21,                                 /* vBlnkYStopFld1   */          \
                                                                        \
    0,                                  /* vBlnkXStartFld2  */          \
    0,                                  /* vBlnkYStartFld2  */          \
    0,                                  /* vBlnkXStopFld2   */          \
    0,                                  /* vBlnkYStopFld2   */          \
                                                                        \
    0,                                  /* xStartFld1       */          \
    1,                                  /* yStartFld1       */          \
                                                                        \
    0,                                  /* xStartFld2       */          \
    0,                                  /* yStartFld2       */          \
                                                                        \
    (656 - 3),                          /* hSyncStart       */          \
    (720 - 3),                          /* hSyncStop        */          \
                                                                        \
    (656 - 3),                          /* vSyncXStartFld1  */          \
    11,                                 /* vSyncYStartFld1  */          \
    (656 - 3),                          /* vSyncXStopFld1   */          \
    14,                                 /* vSyncYStopFld1   */          \
                                                                        \
    0,                                  /* vSyncXStartFld2  */          \
    0,                                  /* vSyncYStartFld2  */          \
    0,                                  /* vSyncXStopFld2   */          \
    0,                                  /* vSyncYStopFld2   */          \
                                                                        \
    16,                                 /* yClipLow         */          \
    240,                                /* yClipHigh        */          \
    16,                                 /* cClipLow         */          \
    240,                                /* cClipHigh        */          \
                                                                        \
    0x00,                               /* Default Y value  */          \
    0x00,                               /* Default Cb value */          \
    0x00,                               /* Default Cr value */          \
                                                                        \
    VPORTDIS_RGBX_DISABLE,              /* RGB extract disable */       \
    1,                                  /* incPix, for raw mode only */ \
                                                                        \
    (DIS_VGA_LINE_SZ >> 3),             /* thrld            */          \
                                                                        \
    3,                                  /* numFrmBufs       */          \
    128,                                /* alignment        */          \
    VPORT_FLDS_MERGED,                  /* mergeFlds        */          \
                                                                        \
    NULL,                               /* segId            */          \
    NULL                                /* hEdma            */          \
}


/*
 * VGA 85Hz VESA Display Configuration
 */
#define DIS_PARAMS_THS8200_VGA_85HZ_DEFAULT {                           \
    THS8200_MODE_VGA_85HZ,              /* Mode             */          \
    THS8200_IFMT_RGB565,                /* InputFormat      */          \
    THS8200_AFMT_RGB_NO_SYNC,           /* AnalogFormat     */          \
    TRUE,                               /* enableSlaveMode  */          \
    FALSE                               /* enableBT656Sync  */          \
}

#define DIS_PARAMS_CHAN_VGA_85HZ_DEFAULT {                              \
    VPORT_MODE_RAW_16BIT,               /* dmode:3          */          \
    VPORT_FLDOP_PROGRESSIVE,            /* fldOp:3          */          \
                                                                        \
    VPORT_SCALING_DISABLE,              /* scale:1          */          \
    VPORT_RESMPL_DISABLE,               /* resmpl:1         */          \
    VPORTDIS_DEFVAL_ENABLE,             /* defValEn:1       */          \
    VPORTDIS_BPK_10BIT_NORMAL,          /* bpk10Bit:1       */          \
                                                                        \
    VPORTDIS_VCTL1_HSYNC,               /* vctl1Config:2    */          \
    VPORTDIS_VCTL2_VSYNC,               /* vctl2Config:2    */          \
    VPORTDIS_VCTL3_FLD,                 /* vctl3Config:1    */          \
    VPORTDIS_EXC_DISABLE,               /* extCtl:3         */          \
                                                                        \
    840,                                /* frmHSize         */          \
    509,                                /* frmVSize         */          \
                                                                        \
    0,                                  /* imgHOffsetFld1   */          \
    0,                                  /* imgVOffsetFld1   */          \
    DIS_VGA_LINE_SZ,                    /* imgHSizeFld1     */          \
    DIS_VGA_NUM_LINES,                  /* imgVSizeFld1     */          \
                                                                        \
    0,                                  /* imgHOffsetFld2   */          \
    0,                                  /* imgVOffsetFld2   */          \
    0,                                  /* imgHSizeFld2     */          \
    0,                                  /* imgVSizeFld2     */          \
                                                                        \
    640,                                /* hBlnkStart       */          \
    0,                                  /* hBlnkStop        */          \
                                                                        \
    0,                                  /* vBlnkXStartFld1  */          \
    1,                                  /* vBlnkYStartFld1  */          \
    0,                                  /* vBlnkXStopFld1   */          \
    30,                                 /* vBlnkYStopFld1   */          \
                                                                        \
    0,                                  /* vBlnkXStartFld2  */          \
    0,                                  /* vBlnkYStartFld2  */          \
    0,                                  /* vBlnkXStopFld2   */          \
    0,                                  /* vBlnkYStopFld2   */          \
                                                                        \
    0,                                  /* xStartFld1       */          \
    1,                                  /* yStartFld1       */          \
                                                                        \
    0,                                  /* xStartFld2       */          \
    0,                                  /* yStartFld2       */          \
                                                                        \
    (656 - 3),                          /* hSyncStart       */          \
    (720 - 3),                          /* hSyncStop        */          \
                                                                        \
    (656 - 3),                          /* vSyncXStartFld1  */          \
    11,                                 /* vSyncYStartFld1  */          \
    (656 - 3),                          /* vSyncXStopFld1   */          \
    14,                                 /* vSyncYStopFld1   */          \
                                                                        \
    0,                                  /* vSyncXStartFld2  */          \
    0,                                  /* vSyncYStartFld2  */          \
    0,                                  /* vSyncXStopFld2   */          \
    0,                                  /* vSyncYStopFld2   */          \
                                                                        \
    16,                                 /* yClipLow         */          \
    240,                                /* yClipHigh        */          \
    16,                                 /* cClipLow         */          \
    240,                                /* cClipHigh        */          \
                                                                        \
    0x00,                               /* Default Y value  */          \
    0x00,                               /* Default Cb value */          \
    0x00,                               /* Default Cr value */          \
                                                                        \
    VPORTDIS_RGBX_DISABLE,              /* RGB extract disable */       \
    1,                                  /* incPix, for raw mode only */ \
                                                                        \
    (DIS_VGA_LINE_SZ >> 3),             /* thrld            */          \
                                                                        \
    3,                                  /* numFrmBufs       */          \
    128,                                /* alignment        */          \
    VPORT_FLDS_MERGED,                  /* mergeFlds        */          \
                                                                        \
    NULL,                               /* segId            */          \
    NULL                                /* hEdma            */          \
}


/*
 * SVGA 60Hz VESA Display Configuration
 */
#define DIS_PARAMS_THS8200_SVGA_60HZ_DEFAULT {                          \
    THS8200_MODE_SVGA_60HZ,             /* Mode             */          \
    THS8200_IFMT_RGB565,                /* InputFormat      */          \
    THS8200_AFMT_RGB_NO_SYNC,           /* AnalogFormat     */          \
    TRUE,                               /* enableSlaveMode  */          \
    FALSE                               /* enableBT656Sync  */          \
}

#define DIS_SVGA_LINE_SZ                (800)
#define DIS_SVGA_NUM_LINES              (600)

#define DIS_PARAMS_CHAN_SVGA_60HZ_DEFAULT {                             \
    VPORT_MODE_RAW_16BIT,               /* dmode:3          */          \
    VPORT_FLDOP_PROGRESSIVE,            /* fldOp:3          */          \
                                                                        \
    VPORT_SCALING_DISABLE,              /* scale:1          */          \
    VPORT_RESMPL_DISABLE,               /* resmpl:1         */          \
    VPORTDIS_DEFVAL_ENABLE,             /* defValEn:1       */          \
    VPORTDIS_BPK_10BIT_NORMAL,          /* bpk10Bit:1       */          \
                                                                        \
    VPORTDIS_VCTL1_HSYNC,               /* vctl1Config:2    */          \
    VPORTDIS_VCTL2_VSYNC,               /* vctl2Config:2    */          \
    VPORTDIS_VCTL3_FLD,                 /* vctl3Config:1    */          \
    VPORTDIS_EXC_DISABLE,               /* extCtl:3         */          \
                                                                        \
    1056,                               /* frmHSize         */          \
    628,                                /* frmVSize         */          \
                                                                        \
    0,                                  /* imgHOffsetFld1   */          \
    0,                                  /* imgVOffsetFld1   */          \
    DIS_SVGA_LINE_SZ,                   /* imgHSizeFld1     */          \
    DIS_SVGA_NUM_LINES,                 /* imgVSizeFld1     */          \
                                                                        \
    0,                                  /* imgHOffsetFld2   */          \
    0,                                  /* imgVOffsetFld2   */          \
    0,                                  /* imgHSizeFld2     */          \
    0,                                  /* imgVSizeFld2     */          \
                                                                        \
    800,                                /* hBlnkStart       */          \
    0,                                  /* hBlnkStop        */          \
                                                                        \
    0,                                  /* vBlnkXStartFld1  */          \
    1,                                  /* vBlnkYStartFld1  */          \
    0,                                  /* vBlnkXStopFld1   */          \
    29,                                 /* vBlnkYStopFld1   */          \
                                                                        \
    0,                                  /* vBlnkXStartFld2  */          \
    0,                                  /* vBlnkYStartFld2  */          \
    0,                                  /* vBlnkXStopFld2   */          \
    0,                                  /* vBlnkYStopFld2   */          \
                                                                        \
    0,                                  /* xStartFld1       */          \
    1,                                  /* yStartFld1       */          \
                                                                        \
    0,                                  /* xStartFld2       */          \
    0,                                  /* yStartFld2       */          \
                                                                        \
    (840 - 3),                          /* hSyncStart       */          \
    (968 - 3),                          /* hSyncStop        */          \
                                                                        \
    (840 - 3),                          /* vSyncXStartFld1  */          \
    2,                                  /* vSyncYStartFld1  */          \
    (840 - 3),                          /* vSyncXStopFld1   */          \
    6,                                  /* vSyncYStopFld1   */          \
                                                                        \
    0,                                  /* vSyncXStartFld2  */          \
    0,                                  /* vSyncYStartFld2  */          \
    0,                                  /* vSyncXStopFld2   */          \
    0,                                  /* vSyncYStopFld2   */          \
                                                                        \
    16,                                 /* yClipLow         */          \
    240,                                /* yClipHigh        */          \
    16,                                 /* cClipLow         */          \
    240,                                /* cClipHigh        */          \
                                                                        \
    0x00,                               /* Default Y value  */          \
    0x00,                               /* Default Cb value */          \
    0x00,                               /* Default Cr value */          \
                                                                        \
    VPORTDIS_RGBX_DISABLE,              /* RGB extract disable */       \
    1,                                  /* incPix, for raw mode only */ \
                                                                        \
    (DIS_SVGA_LINE_SZ >> 3),            /* thrld            */          \
                                                                        \
    3,                                  /* numFrmBufs       */          \
    128,                                /* alignment        */          \
    VPORT_FLDS_MERGED,                  /* mergeFlds        */          \
                                                                        \
    NULL,                               /* segId            */          \
    NULL                                /* hEdma            */          \
}


/*
 * SVGA 72Hz VESA Display Configuration
 */
#define DIS_PARAMS_THS8200_SVGA_72HZ_DEFAULT {                          \
    THS8200_MODE_SVGA_72HZ,             /* Mode             */          \
    THS8200_IFMT_RGB565,                /* InputFormat      */          \
    THS8200_AFMT_RGB_NO_SYNC,           /* AnalogFormat     */          \
    TRUE,                               /* enableSlaveMode  */          \
    FALSE                               /* enableBT656Sync  */          \
}

#define DIS_PARAMS_CHAN_SVGA_72HZ_DEFAULT {                             \
    VPORT_MODE_RAW_16BIT,               /* dmode:3          */          \
    VPORT_FLDOP_PROGRESSIVE,            /* fldOp:3          */          \
                                                                        \
    VPORT_SCALING_DISABLE,              /* scale:1          */          \
    VPORT_RESMPL_DISABLE,               /* resmpl:1         */          \
    VPORTDIS_DEFVAL_ENABLE,             /* defValEn:1       */          \
    VPORTDIS_BPK_10BIT_NORMAL,          /* bpk10Bit:1       */          \
                                                                        \
    VPORTDIS_VCTL1_HSYNC,               /* vctl1Config:2    */          \
    VPORTDIS_VCTL2_VSYNC,               /* vctl2Config:2    */          \
    VPORTDIS_VCTL3_FLD,                 /* vctl3Config:1    */          \
    VPORTDIS_EXC_DISABLE,               /* extCtl:3         */          \
                                                                        \
    1040,                               /* frmHSize         */          \
    666,                                /* frmVSize         */          \
                                                                        \
    0,                                  /* imgHOffsetFld1   */          \
    0,                                  /* imgVOffsetFld1   */          \
    DIS_SVGA_LINE_SZ,                   /* imgHSizeFld1     */          \
    DIS_SVGA_NUM_LINES,                 /* imgVSizeFld1     */          \
                                                                        \
    0,                                  /* imgHOffsetFld2   */          \
    0,                                  /* imgVOffsetFld2   */          \
    0,                                  /* imgHSizeFld2     */          \
    0,                                  /* imgVSizeFld2     */          \
                                                                        \
    800,                                /* hBlnkStart       */          \
    0,                                  /* hBlnkStop        */          \
                                                                        \
    0,                                  /* vBlnkXStartFld1  */          \
    1,                                  /* vBlnkYStartFld1  */          \
    0,                                  /* vBlnkXStopFld1   */          \
    67,                                 /* vBlnkYStopFld1   */          \
                                                                        \
    0,                                  /* vBlnkXStartFld2  */          \
    0,                                  /* vBlnkYStartFld2  */          \
    0,                                  /* vBlnkXStopFld2   */          \
    0,                                  /* vBlnkYStopFld2   */          \
                                                                        \
    0,                                  /* xStartFld1       */          \
    1,                                  /* yStartFld1       */          \
                                                                        \
    0,                                  /* xStartFld2       */          \
    0,                                  /* yStartFld2       */          \
                                                                        \
    (840 - 3),                          /* hSyncStart       */          \
    (960 - 3),                          /* hSyncStop        */          \
                                                                        \
    (840 - 3),                          /* vSyncXStartFld1  */          \
    2,                                  /* vSyncYStartFld1  */          \
    (840 - 3),                          /* vSyncXStopFld1   */          \
    8,                                  /* vSyncYStopFld1   */          \
                                                                        \
    0,                                  /* vSyncXStartFld2  */          \
    0,                                  /* vSyncYStartFld2  */          \
    0,                                  /* vSyncXStopFld2   */          \
    0,                                  /* vSyncYStopFld2   */          \
                                                                        \
    16,                                 /* yClipLow         */          \
    240,                                /* yClipHigh        */          \
    16,                                 /* cClipLow         */          \
    240,                                /* cClipHigh        */          \
                                                                        \
    0x00,                               /* Default Y value  */          \
    0x00,                               /* Default Cb value */          \
    0x00,                               /* Default Cr value */          \
                                                                        \
    VPORTDIS_RGBX_DISABLE,              /* RGB extract disable */       \
    1,                                  /* incPix, for raw mode only */ \
                                                                        \
    (DIS_SVGA_LINE_SZ >> 3),            /* thrld            */          \
                                                                        \
    3,                                  /* numFrmBufs       */          \
    128,                                /* alignment        */          \
    VPORT_FLDS_MERGED,                  /* mergeFlds        */          \
                                                                        \
    NULL,                               /* segId            */          \
    NULL                                /* hEdma            */          \
}


/*
 * SVGA 75Hz VESA Display Configuration
 */
#define DIS_PARAMS_THS8200_SVGA_75HZ_DEFAULT {                          \
    THS8200_MODE_SVGA_75HZ,             /* Mode             */          \
    THS8200_IFMT_RGB565,                /* InputFormat      */          \
    THS8200_AFMT_RGB_NO_SYNC,           /* AnalogFormat     */          \
    TRUE,                               /* enableSlaveMode  */          \
    FALSE                               /* enableBT656Sync  */          \
}

#define DIS_PARAMS_CHAN_SVGA_75HZ_DEFAULT {                             \
    VPORT_MODE_RAW_16BIT,               /* dmode:3          */          \
    VPORT_FLDOP_PROGRESSIVE,            /* fldOp:3          */          \
                                                                        \
    VPORT_SCALING_DISABLE,              /* scale:1          */          \
    VPORT_RESMPL_DISABLE,               /* resmpl:1         */          \
    VPORTDIS_DEFVAL_ENABLE,             /* defValEn:1       */          \
    VPORTDIS_BPK_10BIT_NORMAL,          /* bpk10Bit:1       */          \
                                                                        \
    VPORTDIS_VCTL1_HSYNC,               /* vctl1Config:2    */          \
    VPORTDIS_VCTL2_VSYNC,               /* vctl2Config:2    */          \
    VPORTDIS_VCTL3_FLD,                 /* vctl3Config:1    */          \
    VPORTDIS_EXC_DISABLE,               /* extCtl:3         */          \
                                                                        \
    1056,                               /* frmHSize         */          \
    625,                                /* frmVSize         */          \
                                                                        \
    0,                                  /* imgHOffsetFld1   */          \
    0,                                  /* imgVOffsetFld1   */          \
    DIS_SVGA_LINE_SZ,                   /* imgHSizeFld1     */          \
    DIS_SVGA_NUM_LINES,                 /* imgVSizeFld1     */          \
                                                                        \
    0,                                  /* imgHOffsetFld2   */          \
    0,                                  /* imgVOffsetFld2   */          \
    0,                                  /* imgHSizeFld2     */          \
    0,                                  /* imgVSizeFld2     */          \
                                                                        \
    800,                                /* hBlnkStart       */          \
    0,                                  /* hBlnkStop        */          \
                                                                        \
    0,                                  /* vBlnkXStartFld1  */          \
    1,                                  /* vBlnkYStartFld1  */          \
    0,                                  /* vBlnkXStopFld1   */          \
    26,                                 /* vBlnkYStopFld1   */          \
                                                                        \
    0,                                  /* vBlnkXStartFld2  */          \
    0,                                  /* vBlnkYStartFld2  */          \
    0,                                  /* vBlnkXStopFld2   */          \
    0,                                  /* vBlnkYStopFld2   */          \
                                                                        \
    0,                                  /* xStartFld1       */          \
    1,                                  /* yStartFld1       */          \
                                                                        \
    0,                                  /* xStartFld2       */          \
    0,                                  /* yStartFld2       */          \
                                                                        \
    (840 - 3),                          /* hSyncStart       */          \
    (920 - 3),                          /* hSyncStop        */          \
                                                                        \
    (840 - 3),                          /* vSyncXStartFld1  */          \
    2,                                  /* vSyncYStartFld1  */          \
    (840 - 3),                          /* vSyncXStopFld1   */          \
    5,                                  /* vSyncYStopFld1   */          \
                                                                        \
    0,                                  /* vSyncXStartFld2  */          \
    0,                                  /* vSyncYStartFld2  */          \
    0,                                  /* vSyncXStopFld2   */          \
    0,                                  /* vSyncYStopFld2   */          \
                                                                        \
    16,                                 /* yClipLow         */          \
    240,                                /* yClipHigh        */          \
    16,                                 /* cClipLow         */          \
    240,                                /* cClipHigh        */          \
                                                                        \
    0x00,                               /* Default Y value  */          \
    0x00,                               /* Default Cb value */          \
    0x00,                               /* Default Cr value */          \
                                                                        \
    VPORTDIS_RGBX_DISABLE,              /* RGB extract disable */       \
    1,                                  /* incPix, for raw mode only */ \
                                                                        \
    (DIS_SVGA_LINE_SZ >> 3),            /* thrld            */          \
                                                                        \
    3,                                  /* numFrmBufs       */          \
    128,                                /* alignment        */          \
    VPORT_FLDS_MERGED,                  /* mergeFlds        */          \
                                                                        \
    NULL,                               /* segId            */          \
    NULL                                /* hEdma            */          \
}


/*
 * SVGA 75Hz VESA Display Configuration
 */
#define DIS_PARAMS_THS8200_SVGA_85HZ_DEFAULT {                          \
    THS8200_MODE_SVGA_85HZ,             /* Mode             */          \
    THS8200_IFMT_RGB565,                /* InputFormat      */          \
    THS8200_AFMT_RGB_NO_SYNC,           /* AnalogFormat     */          \
    TRUE,                               /* enableSlaveMode  */          \
    FALSE                               /* enableBT656Sync  */          \
}

#define DIS_PARAMS_CHAN_SVGA_85HZ_DEFAULT {                             \
    VPORT_MODE_RAW_16BIT,               /* dmode:3          */          \
    VPORT_FLDOP_PROGRESSIVE,            /* fldOp:3          */          \
                                                                        \
    VPORT_SCALING_DISABLE,              /* scale:1          */          \
    VPORT_RESMPL_DISABLE,               /* resmpl:1         */          \
    VPORTDIS_DEFVAL_ENABLE,             /* defValEn:1       */          \
    VPORTDIS_BPK_10BIT_NORMAL,          /* bpk10Bit:1       */          \
                                                                        \
    VPORTDIS_VCTL1_HSYNC,               /* vctl1Config:2    */          \
    VPORTDIS_VCTL2_VSYNC,               /* vctl2Config:2    */          \
    VPORTDIS_VCTL3_FLD,                 /* vctl3Config:1    */          \
    VPORTDIS_EXC_DISABLE,               /* extCtl:3         */          \
                                                                        \
    1048,                               /* frmHSize         */          \
    631,                                /* frmVSize         */          \
                                                                        \
    0,                                  /* imgHOffsetFld1   */          \
    0,                                  /* imgVOffsetFld1   */          \
    DIS_SVGA_LINE_SZ,                   /* imgHSizeFld1     */          \
    DIS_SVGA_NUM_LINES,                 /* imgVSizeFld1     */          \
                                                                        \
    0,                                  /* imgHOffsetFld2   */          \
    0,                                  /* imgVOffsetFld2   */          \
    0,                                  /* imgHSizeFld2     */          \
    0,                                  /* imgVSizeFld2     */          \
                                                                        \
    800,                                /* hBlnkStart       */          \
    0,                                  /* hBlnkStop        */          \
                                                                        \
    0,                                  /* vBlnkXStartFld1  */          \
    1,                                  /* vBlnkYStartFld1  */          \
    0,                                  /* vBlnkXStopFld1   */          \
    32,                                 /* vBlnkYStopFld1   */          \
                                                                        \
    0,                                  /* vBlnkXStartFld2  */          \
    0,                                  /* vBlnkYStartFld2  */          \
    0,                                  /* vBlnkXStopFld2   */          \
    0,                                  /* vBlnkYStopFld2   */          \
                                                                        \
    0,                                  /* xStartFld1       */          \
    1,                                  /* yStartFld1       */          \
                                                                        \
    0,                                  /* xStartFld2       */          \
    0,                                  /* yStartFld2       */          \
                                                                        \
    (840 - 3),                          /* hSyncStart       */          \
    (904 - 3),                          /* hSyncStop        */          \
                                                                        \
    (840 - 3),                          /* vSyncXStartFld1  */          \
    2,                                  /* vSyncYStartFld1  */          \
    (840 - 3),                          /* vSyncXStopFld1   */          \
    5,                                  /* vSyncYStopFld1   */          \
                                                                        \
    0,                                  /* vSyncXStartFld2  */          \
    0,                                  /* vSyncYStartFld2  */          \
    0,                                  /* vSyncXStopFld2   */          \
    0,                                  /* vSyncYStopFld2   */          \
                                                                        \
    16,                                 /* yClipLow         */          \
    240,                                /* yClipHigh        */          \
    16,                                 /* cClipLow         */          \
    240,                                /* cClipHigh        */          \
                                                                        \
    0x00,                               /* Default Y value  */          \
    0x00,                               /* Default Cb value */          \
    0x00,                               /* Default Cr value */          \
                                                                        \
    VPORTDIS_RGBX_DISABLE,              /* RGB extract disable */       \
    1,                                  /* incPix, for raw mode only */ \
                                                                        \
    (DIS_SVGA_LINE_SZ >> 3),            /* thrld            */          \
                                                                        \
    3,                                  /* numFrmBufs       */          \
    128,                                /* alignment        */          \
    VPORT_FLDS_MERGED,                  /* mergeFlds        */          \
                                                                        \
    NULL,                               /* segId            */          \
    NULL                                /* hEdma            */          \
}


/*
 * XGA 60Hz VESA Display Configuration
 */
#define DIS_PARAMS_THS8200_XGA_60HZ_DEFAULT {                           \
    THS8200_MODE_XGA_60HZ,              /* Mode             */          \
    THS8200_IFMT_RGB565,                /* InputFormat      */          \
    THS8200_AFMT_RGB_NO_SYNC,           /* AnalogFormat     */          \
    TRUE,                               /* enableSlaveMode  */          \
    FALSE                               /* enableBT656Sync  */          \
}

#define DIS_XGA_LINE_SZ                 (1024)
#define DIS_XGA_NUM_LINES               (768)

#define DIS_PARAMS_CHAN_XGA_60HZ_DEFAULT {                              \
    VPORT_MODE_RAW_16BIT,               /* dmode:3          */          \
    VPORT_FLDOP_PROGRESSIVE,            /* fldOp:3          */          \
                                                                        \
    VPORT_SCALING_DISABLE,              /* scale:1          */          \
    VPORT_RESMPL_DISABLE,               /* resmpl:1         */          \
    VPORTDIS_DEFVAL_ENABLE,             /* defValEn:1       */          \
    VPORTDIS_BPK_10BIT_NORMAL,          /* bpk10Bit:1       */          \
                                                                        \
    VPORTDIS_VCTL1_HSYNC,               /* vctl1Config:2    */          \
    VPORTDIS_VCTL2_VSYNC,               /* vctl2Config:2    */          \
    VPORTDIS_VCTL3_FLD,                 /* vctl3Config:1    */          \
    VPORTDIS_EXC_DISABLE,               /* extCtl:3         */          \
                                                                        \
    1344,                               /* frmHSize         */          \
    806,                                /* frmVSize         */          \
                                                                        \
    0,                                  /* imgHOffsetFld1   */          \
    0,                                  /* imgVOffsetFld1   */          \
    DIS_XGA_LINE_SZ,                    /* imgHSizeFld1     */          \
    DIS_XGA_NUM_LINES,                  /* imgVSizeFld1     */          \
                                                                        \
    0,                                  /* imgHOffsetFld2   */          \
    0,                                  /* imgVOffsetFld2   */          \
    0,                                  /* imgHSizeFld2     */          \
    0,                                  /* imgVSizeFld2     */          \
                                                                        \
    1024,                               /* hBlnkStart       */          \
    0,                                  /* hBlnkStop        */          \
                                                                        \
    0,                                  /* vBlnkXStartFld1  */          \
    1,                                  /* vBlnkYStartFld1  */          \
    0,                                  /* vBlnkXStopFld1   */          \
    39,                                 /* vBlnkYStopFld1   */          \
                                                                        \
    0,                                  /* vBlnkXStartFld2  */          \
    0,                                  /* vBlnkYStartFld2  */          \
    0,                                  /* vBlnkXStopFld2   */          \
    0,                                  /* vBlnkYStopFld2   */          \
                                                                        \
    0,                                  /* xStartFld1       */          \
    1,                                  /* yStartFld1       */          \
                                                                        \
    0,                                  /* xStartFld2       */          \
    0,                                  /* yStartFld2       */          \
                                                                        \
    (1048 - 3),                         /* hSyncStart       */          \
    (1184 - 3),                         /* hSyncStop        */          \
                                                                        \
    (1048 - 3),                         /* vSyncXStartFld1  */          \
    4,                                  /* vSyncYStartFld1  */          \
    (1048 - 3),                         /* vSyncXStopFld1   */          \
    10,                                 /* vSyncYStopFld1   */          \
                                                                        \
    0,                                  /* vSyncXStartFld2  */          \
    0,                                  /* vSyncYStartFld2  */          \
    0,                                  /* vSyncXStopFld2   */          \
    0,                                  /* vSyncYStopFld2   */          \
                                                                        \
    16,                                 /* yClipLow         */          \
    240,                                /* yClipHigh        */          \
    16,                                 /* cClipLow         */          \
    240,                                /* cClipHigh        */          \
                                                                        \
    0x00,                               /* Default Y value  */          \
    0x00,                               /* Default Cb value */          \
    0x00,                               /* Default Cr value */          \
                                                                        \
    VPORTDIS_RGBX_DISABLE,              /* RGB extract disable */       \
    1,                                  /* incPix, for raw mode only */ \
                                                                        \
    (DIS_XGA_LINE_SZ >> 4),             /* thrld            */          \
                                                                        \
    3,                                  /* numFrmBufs       */          \
    128,                                /* alignment        */          \
    VPORT_FLDS_MERGED,                  /* mergeFlds        */          \
                                                                        \
    NULL,                               /* segId            */          \
    NULL                                /* hEdma            */          \
}


/*
 * XGA 70Hz VESA Display Configuration
 */
#define DIS_PARAMS_THS8200_XGA_70HZ_DEFAULT {                           \
    THS8200_MODE_XGA_70HZ,              /* Mode             */          \
    THS8200_IFMT_RGB565,                /* InputFormat      */          \
    THS8200_AFMT_RGB_NO_SYNC,           /* AnalogFormat     */          \
    TRUE,                               /* enableSlaveMode  */          \
    FALSE                               /* enableBT656Sync  */          \
}

#define DIS_PARAMS_CHAN_XGA_70HZ_DEFAULT {                              \
    VPORT_MODE_RAW_16BIT,               /* dmode:3          */          \
    VPORT_FLDOP_PROGRESSIVE,            /* fldOp:3          */          \
                                                                        \
    VPORT_SCALING_DISABLE,              /* scale:1          */          \
    VPORT_RESMPL_DISABLE,               /* resmpl:1         */          \
    VPORTDIS_DEFVAL_ENABLE,             /* defValEn:1       */          \
    VPORTDIS_BPK_10BIT_NORMAL,          /* bpk10Bit:1       */          \
                                                                        \
    VPORTDIS_VCTL1_HSYNC,               /* vctl1Config:2    */          \
    VPORTDIS_VCTL2_VSYNC,               /* vctl2Config:2    */          \
    VPORTDIS_VCTL3_FLD,                 /* vctl3Config:1    */          \
    VPORTDIS_EXC_DISABLE,               /* extCtl:3         */          \
                                                                        \
    1328,                               /* frmHSize         */          \
    806,                                /* frmVSize         */          \
                                                                        \
    0,                                  /* imgHOffsetFld1   */          \
    0,                                  /* imgVOffsetFld1   */          \
    DIS_XGA_LINE_SZ,                    /* imgHSizeFld1     */          \
    DIS_XGA_NUM_LINES,                  /* imgVSizeFld1     */          \
                                                                        \
    0,                                  /* imgHOffsetFld2   */          \
    0,                                  /* imgVOffsetFld2   */          \
    0,                                  /* imgHSizeFld2     */          \
    0,                                  /* imgVSizeFld2     */          \
                                                                        \
    1024,                               /* hBlnkStart       */          \
    0,                                  /* hBlnkStop        */          \
                                                                        \
    0,                                  /* vBlnkXStartFld1  */          \
    1,                                  /* vBlnkYStartFld1  */          \
    0,                                  /* vBlnkXStopFld1   */          \
    39,                                 /* vBlnkYStopFld1   */          \
                                                                        \
    0,                                  /* vBlnkXStartFld2  */          \
    0,                                  /* vBlnkYStartFld2  */          \
    0,                                  /* vBlnkXStopFld2   */          \
    0,                                  /* vBlnkYStopFld2   */          \
                                                                        \
    0,                                  /* xStartFld1       */          \
    1,                                  /* yStartFld1       */          \
                                                                        \
    0,                                  /* xStartFld2       */          \
    0,                                  /* yStartFld2       */          \
                                                                        \
    (1048 - 3),                         /* hSyncStart       */          \
    (1184 - 3),                         /* hSyncStop        */          \
                                                                        \
    (1048 - 3),                         /* vSyncXStartFld1  */          \
    4,                                  /* vSyncYStartFld1  */          \
    (1048 - 3),                         /* vSyncXStopFld1   */          \
    10,                                 /* vSyncYStopFld1   */          \
                                                                        \
    0,                                  /* vSyncXStartFld2  */          \
    0,                                  /* vSyncYStartFld2  */          \
    0,                                  /* vSyncXStopFld2   */          \
    0,                                  /* vSyncYStopFld2   */          \
                                                                        \
    16,                                 /* yClipLow         */          \
    240,                                /* yClipHigh        */          \
    16,                                 /* cClipLow         */          \
    240,                                /* cClipHigh        */          \
                                                                        \
    0x00,                               /* Default Y value  */          \
    0x00,                               /* Default Cb value */          \
    0x00,                               /* Default Cr value */          \
                                                                        \
    VPORTDIS_RGBX_DISABLE,              /* RGB extract disable */       \
    1,                                  /* incPix, for raw mode only */ \
                                                                        \
    (DIS_XGA_LINE_SZ >> 4),             /* thrld            */          \
                                                                        \
    3,                                  /* numFrmBufs       */          \
    128,                                /* alignment        */          \
    VPORT_FLDS_MERGED,                  /* mergeFlds        */          \
                                                                        \
    NULL,                               /* segId            */          \
    NULL                                /* hEdma            */          \
}


/*
 * SXGA 60Hz VESA Display Configuration
 */
#define DIS_PARAMS_THS8200_SXGA_60HZ_DEFAULT {                          \
    THS8200_MODE_SXGA_60HZ,             /* Mode             */          \
    THS8200_IFMT_RGB565,                /* InputFormat      */          \
    THS8200_AFMT_RGB_NO_SYNC,           /* AnalogFormat     */          \
    TRUE,                               /* enableSlaveMode  */          \
    FALSE                               /* enableBT656Sync  */          \
}

#define DIS_SXGA_LINE_SZ                (1280)
#define DIS_SXGA_NUM_LINES              (1024)

#define DIS_PARAMS_CHAN_SXGA_60HZ_DEFAULT {                             \
    VPORT_MODE_RAW_16BIT,               /* dmode:3          */          \
    VPORT_FLDOP_PROGRESSIVE,            /* fldOp:3          */          \
                                                                        \
    VPORT_SCALING_DISABLE,              /* scale:1          */          \
    VPORT_RESMPL_DISABLE,               /* resmpl:1         */          \
    VPORTDIS_DEFVAL_ENABLE,             /* defValEn:1       */          \
    VPORTDIS_BPK_10BIT_NORMAL,          /* bpk10Bit:1       */          \
                                                                        \
    VPORTDIS_VCTL1_HSYNC,               /* vctl1Config:2    */          \
    VPORTDIS_VCTL2_VSYNC,               /* vctl2Config:2    */          \
    VPORTDIS_VCTL3_FLD,                 /* vctl3Config:1    */          \
    VPORTDIS_EXC_DISABLE,               /* extCtl:3         */          \
                                                                        \
    1688,                               /* frmHSize         */          \
    1066,                               /* frmVSize         */          \
                                                                        \
    0,                                  /* imgHOffsetFld1   */          \
    0,                                  /* imgVOffsetFld1   */          \
    DIS_SXGA_LINE_SZ,                   /* imgHSizeFld1     */          \
    DIS_SXGA_NUM_LINES,                 /* imgVSizeFld1     */          \
                                                                        \
    0,                                  /* imgHOffsetFld2   */          \
    0,                                  /* imgVOffsetFld2   */          \
    0,                                  /* imgHSizeFld2     */          \
    0,                                  /* imgVSizeFld2     */          \
                                                                        \
    1280,                               /* hBlnkStart       */          \
    0,                                  /* hBlnkStop        */          \
                                                                        \
    0,                                  /* vBlnkXStartFld1  */          \
    1,                                  /* vBlnkYStartFld1  */          \
    0,                                  /* vBlnkXStopFld1   */          \
    43,                                 /* vBlnkYStopFld1   */          \
                                                                        \
    0,                                  /* vBlnkXStartFld2  */          \
    0,                                  /* vBlnkYStartFld2  */          \
    0,                                  /* vBlnkXStopFld2   */          \
    0,                                  /* vBlnkYStopFld2   */          \
                                                                        \
    0,                                  /* xStartFld1       */          \
    1,                                  /* yStartFld1       */          \
                                                                        \
    0,                                  /* xStartFld2       */          \
    0,                                  /* yStartFld2       */          \
                                                                        \
    (1304 - 3),                         /* hSyncStart       */          \
    (1416 - 3),                         /* hSyncStop        */          \
                                                                        \
    (1304 - 3),                         /* vSyncXStartFld1  */          \
    4,                                  /* vSyncYStartFld1  */          \
    (1304 - 3),                         /* vSyncXStopFld1   */          \
    7,                                  /* vSyncYStopFld1   */          \
                                                                        \
    0,                                  /* vSyncXStartFld2  */          \
    0,                                  /* vSyncYStartFld2  */          \
    0,                                  /* vSyncXStopFld2   */          \
    0,                                  /* vSyncYStopFld2   */          \
                                                                        \
    16,                                 /* yClipLow         */          \
    240,                                /* yClipHigh        */          \
    16,                                 /* cClipLow         */          \
    240,                                /* cClipHigh        */          \
                                                                        \
    0x00,                               /* Default Y value  */          \
    0x00,                               /* Default Cb value */          \
    0x00,                               /* Default Cr value */          \
                                                                        \
    VPORTDIS_RGBX_DISABLE,              /* RGB extract disable */       \
    1,                                  /* incPix, for raw mode only */ \
                                                                        \
    (DIS_SXGA_LINE_SZ >> 4),            /* thrld            */          \
                                                                        \
    3,                                  /* numFrmBufs       */          \
    128,                                /* alignment        */          \
    VPORT_FLDS_MERGED,                  /* mergeFlds        */          \
                                                                        \
    NULL,                               /* segId            */          \
    NULL                                /* hEdma            */          \
}


/*
 * NTSC 8-bit RAW Display Configuration
 */
#define DIS_NTSC_RAW_8BIT_LINE_SZ       (720 << 1)
#define DIS_NTSC_RAW_8BIT_NUM_LINES     (480)

#define DIS_PARAMS_CHAN_NTSC_RAW_8BIT {                                 \
    VPORT_MODE_RAW_8BIT,                /* dmode:3          */          \
    VPORT_FLDOP_PROGRESSIVE,            /* fldOp:3          */          \
                                                                        \
    VPORT_SCALING_DISABLE,              /* scale:1          */          \
    VPORT_RESMPL_DISABLE,               /* resmpl:1         */          \
    VPORTDIS_DEFVAL_ENABLE,             /* defValEn:1       */          \
    VPORTDIS_BPK_10BIT_NORMAL,          /* bpk10Bit:1       */          \
                                                                        \
    VPORTDIS_VCTL1_AVID,                /* vctl1Config:2    */          \
    VPORTDIS_VCTL2_VBLNK,               /* vctl2Config:2    */          \
    VPORTDIS_VCTL3_CBLNK,               /* vctl3Config:1    */          \
    VPORTDIS_EXC_DISABLE,               /* extCtl:3         */          \
                                                                        \
    (858 << 1),                         /* frmHSize         */          \
    525,                                /* frmVSize         */          \
                                                                        \
    0,                                  /* imgHOffsetFld1   */          \
    0,                                  /* imgVOffsetFld1   */          \
    DIS_NTSC_RAW_8BIT_LINE_SZ,          /* imgHSizeFld1     */          \
    DIS_NTSC_RAW_8BIT_NUM_LINES,        /* imgVSizeFld1     */          \
                                                                        \
    0,                                  /* imgHOffsetFld2   */          \
    0,                                  /* imgVOffsetFld2   */          \
    0,                                  /* imgHSizeFld2     */          \
    0,                                  /* imgVSizeFld2     */          \
                                                                        \
    (720 << 1),                         /* hBlnkStart       */          \
    0,                                  /* hBlnkStop        */          \
                                                                        \
    0,                                  /* vBlnkXStartFld1  */          \
    1,                                  /* vBlnkYStartFld1  */          \
    0,                                  /* vBlnkXStopFld1   */          \
    46,                                 /* vBlnkYStopFld1   */          \
                                                                        \
    0,                                  /* vBlnkXStartFld2  */          \
    0,                                  /* vBlnkYStartFld2  */          \
    0,                                  /* vBlnkXStopFld2   */          \
    0,                                  /* vBlnkYStopFld2   */          \
                                                                        \
    0,                                  /* xStartFld1       */          \
    1,                                  /* yStartFld1       */          \
                                                                        \
    0,                                  /* xStartFld2       */          \
    0,                                  /* yStartFld2       */          \
                                                                        \
    (736 << 1),                         /* hSyncStart       */          \
    (800 << 1),                         /* hSyncStop        */          \
                                                                        \
    (736 << 1),                         /* vSyncXStartFld1  */          \
    4,                                  /* vSyncYStartFld1  */          \
    (736 << 1),                         /* vSyncXStopFld1   */          \
    7,                                  /* vSyncYStopFld1   */          \
                                                                        \
    0,                                  /* vSyncXStartFld2  */          \
    0,                                  /* vSyncYStartFld2  */          \
    0,                                  /* vSyncXStopFld2   */          \
    0,                                  /* vSyncYStopFld2   */          \
                                                                        \
    16,                                 /* yClipLow         */          \
    240,                                /* yClipHigh        */          \
    16,                                 /* cClipLow         */          \
    240,                                /* cClipHigh        */          \
                                                                        \
    0x00,                               /* Default Y value  */          \
    0x00,                               /* Default Cb value */          \
    0x00,                               /* Default Cr value */          \
                                                                        \
    VPORTDIS_RGBX_DISABLE,              /* RGB extract disable */       \
    1,                                  /* incPix, for raw mode only */ \
                                                                        \
    (DIS_NTSC_RAW_8BIT_LINE_SZ >> 4),   /* thrld            */          \
                                                                        \
    3,                                  /* numFrmBufs       */          \
    128,                                /* alignment        */          \
    VPORT_FLDS_MERGED,                  /* mergeFlds        */          \
                                                                        \
    NULL,                               /* segId            */          \
    NULL                                /* hEdma            */          \
}


/*
 * PAL 8-bit RAW Display Configuration
 */
#define DIS_PAL_RAW_8BIT_LINE_SZ        (720 << 1)
#define DIS_PAL_RAW_8BIT_NUM_LINES      (576)

#define DIS_PARAMS_CHAN_PAL_RAW_8BIT {                                  \
    VPORT_MODE_RAW_8BIT,                /* dmode:3          */          \
    VPORT_FLDOP_PROGRESSIVE,            /* fldOp:3          */          \
                                                                        \
    VPORT_SCALING_DISABLE,              /* scale:1          */          \
    VPORT_RESMPL_DISABLE,               /* resmpl:1         */          \
    VPORTDIS_DEFVAL_ENABLE,             /* defValEn:1       */          \
    VPORTDIS_BPK_10BIT_NORMAL,          /* bpk10Bit:1       */          \
                                                                        \
    VPORTDIS_VCTL1_AVID,                /* vctl1Config:2    */          \
    VPORTDIS_VCTL2_VBLNK,               /* vctl2Config:2    */          \
    VPORTDIS_VCTL3_CBLNK,               /* vctl3Config:1    */          \
    VPORTDIS_EXC_DISABLE,               /* extCtl:3         */          \
                                                                        \
    (864 << 1),                         /* frmHSize         */          \
    625,                                /* frmVSize         */          \
                                                                        \
    0,                                  /* imgHOffsetFld1   */          \
    0,                                  /* imgVOffsetFld1   */          \
    DIS_PAL_RAW_8BIT_LINE_SZ,           /* imgHSizeFld1     */          \
    DIS_PAL_RAW_8BIT_NUM_LINES,         /* imgVSizeFld1     */          \
                                                                        \
    0,                                  /* imgHOffsetFld2   */          \
    0,                                  /* imgVOffsetFld2   */          \
    0,                                  /* imgHSizeFld2     */          \
    0,                                  /* imgVSizeFld2     */          \
                                                                        \
    (720 << 1),                         /* hBlnkStart       */          \
    0,                                  /* hBlnkStop        */          \
                                                                        \
    0,                                  /* vBlnkXStartFld1  */          \
    1,                                  /* vBlnkYStartFld1  */          \
    0,                                  /* vBlnkXStopFld1   */          \
    50,                                 /* vBlnkYStopFld1   */          \
                                                                        \
    0,                                  /* vBlnkXStartFld2  */          \
    0,                                  /* vBlnkYStartFld2  */          \
    0,                                  /* vBlnkXStopFld2   */          \
    0,                                  /* vBlnkYStopFld2   */          \
                                                                        \
    0,                                  /* xStartFld1       */          \
    1,                                  /* yStartFld1       */          \
                                                                        \
    0,                                  /* xStartFld2       */          \
    0,                                  /* yStartFld2       */          \
                                                                        \
    (732 << 1),                         /* hSyncStart       */          \
    (782 << 1),                         /* hSyncStop        */          \
                                                                        \
    (720 << 1),                         /* vSyncXStartFld1  */          \
    1,                                  /* vSyncYStartFld1  */          \
    (732 << 1),                         /* vSyncXStopFld1   */          \
    3,                                  /* vSyncYStopFld1   */          \
                                                                        \
    0,                                  /* vSyncXStartFld2  */          \
    0,                                  /* vSyncYStartFld2  */          \
    0,                                  /* vSyncXStopFld2   */          \
    0,                                  /* vSyncYStopFld2   */          \
                                                                        \
    16,                                 /* yClipLow         */          \
    240,                                /* yClipHigh        */          \
    16,                                 /* cClipLow         */          \
    240,                                /* cClipHigh        */          \
                                                                        \
    0x00,                               /* Default Y value  */          \
    0x00,                               /* Default Cb value */          \
    0x00,                               /* Default Cr value */          \
                                                                        \
    VPORTDIS_RGBX_DISABLE,              /* RGB extract disable */       \
    1,                                  /* incPix, for raw mode only */ \
                                                                        \
    (DIS_PAL_RAW_8BIT_LINE_SZ >> 4),    /* thrld            */          \
                                                                        \
    3,                                  /* numFrmBufs       */          \
    128,                                /* alignment        */          \
    VPORT_FLDS_MERGED,                  /* mergeFlds        */          \
                                                                        \
    NULL,                               /* segId            */          \
    NULL                                /* hEdma            */          \
}


/*
 * NTSC 16-bit RAW Display Configuration
 */
#define DIS_NTSC_RAW_16BIT_LINE_SZ      (720)
#define DIS_NTSC_RAW_16BIT_NUM_LINES    (480)

#define DIS_PARAMS_CHAN_NTSC_RAW_16BIT {                                \
    VPORT_MODE_RAW_16BIT,               /* dmode:3          */          \
    VPORT_FLDOP_PROGRESSIVE,            /* fldOp:3          */          \
                                                                        \
    VPORT_SCALING_DISABLE,              /* scale:1          */          \
    VPORT_RESMPL_DISABLE,               /* resmpl:1         */          \
    VPORTDIS_DEFVAL_ENABLE,             /* defValEn:1       */          \
    VPORTDIS_BPK_10BIT_NORMAL,          /* bpk10Bit:1       */          \
                                                                        \
    VPORTDIS_VCTL1_AVID,                /* vctl1Config:2    */          \
    VPORTDIS_VCTL2_VBLNK,               /* vctl2Config:2    */          \
    VPORTDIS_VCTL3_CBLNK,               /* vctl3Config:1    */          \
    VPORTDIS_EXC_DISABLE,               /* extCtl:3         */          \
                                                                        \
    858,                                /* frmHSize         */          \
    525,                                /* frmVSize         */          \
                                                                        \
    0,                                  /* imgHOffsetFld1   */          \
    0,                                  /* imgVOffsetFld1   */          \
    DIS_NTSC_RAW_16BIT_LINE_SZ,         /* imgHSizeFld1     */          \
    DIS_NTSC_RAW_16BIT_NUM_LINES,       /* imgVSizeFld1     */          \
                                                                        \
    0,                                  /* imgHOffsetFld2   */          \
    0,                                  /* imgVOffsetFld2   */          \
    0,                                  /* imgHSizeFld2     */          \
    0,                                  /* imgVSizeFld2     */          \
                                                                        \
    720,                                /* hBlnkStart       */          \
    0,                                  /* hBlnkStop        */          \
                                                                        \
    0,                                  /* vBlnkXStartFld1  */          \
    1,                                  /* vBlnkYStartFld1  */          \
    0,                                  /* vBlnkXStopFld1   */          \
    46,                                 /* vBlnkYStopFld1   */          \
                                                                        \
    0,                                  /* vBlnkXStartFld2  */          \
    0,                                  /* vBlnkYStartFld2  */          \
    0,                                  /* vBlnkXStopFld2   */          \
    0,                                  /* vBlnkYStopFld2   */          \
                                                                        \
    0,                                  /* xStartFld1       */          \
    1,                                  /* yStartFld1       */          \
                                                                        \
    0,                                  /* xStartFld2       */          \
    0,                                  /* yStartFld2       */          \
                                                                        \
    736,                                /* hSyncStart       */          \
    800,                                /* hSyncStop        */          \
                                                                        \
    736,                                /* vSyncXStartFld1  */          \
    4,                                  /* vSyncYStartFld1  */          \
    736,                                /* vSyncXStopFld1   */          \
    7,                                  /* vSyncYStopFld1   */          \
                                                                        \
    0,                                  /* vSyncXStartFld2  */          \
    0,                                  /* vSyncYStartFld2  */          \
    0,                                  /* vSyncXStopFld2   */          \
    0,                                  /* vSyncYStopFld2   */          \
                                                                        \
    16,                                 /* yClipLow         */          \
    240,                                /* yClipHigh        */          \
    16,                                 /* cClipLow         */          \
    240,                                /* cClipHigh        */          \
                                                                        \
    0x00,                               /* Default Y value  */          \
    0x00,                               /* Default Cb value */          \
    0x00,                               /* Default Cr value */          \
                                                                        \
    VPORTDIS_RGBX_DISABLE,              /* RGB extract disable */       \
    1,                                  /* incPix, for raw mode only */ \
                                                                        \
    (DIS_NTSC_RAW_16BIT_LINE_SZ >> 3),  /* thrld            */          \
                                                                        \
    3,                                  /* numFrmBufs       */          \
    128,                                /* alignment        */          \
    VPORT_FLDS_MERGED,                  /* mergeFlds        */          \
                                                                        \
    NULL,                               /* segId            */          \
    NULL                                /* hEdma            */          \
}


/*
 * PAL 16-bit RAW Display Configuration
 */
#define DIS_PAL_RAW_16BIT_LINE_SZ       (720)
#define DIS_PAL_RAW_16BIT_NUM_LINES     (576)

#define DIS_PARAMS_CHAN_PAL_RAW_16BIT {                                 \
    VPORT_MODE_RAW_16BIT,               /* dmode:3          */          \
    VPORT_FLDOP_PROGRESSIVE,            /* fldOp:3          */          \
                                                                        \
    VPORT_SCALING_DISABLE,              /* scale:1          */          \
    VPORT_RESMPL_DISABLE,               /* resmpl:1         */          \
    VPORTDIS_DEFVAL_ENABLE,             /* defValEn:1       */          \
    VPORTDIS_BPK_10BIT_NORMAL,          /* bpk10Bit:1       */          \
                                                                        \
    VPORTDIS_VCTL1_AVID,                /* vctl1Config:2    */          \
    VPORTDIS_VCTL2_VBLNK,               /* vctl2Config:2    */          \
    VPORTDIS_VCTL3_CBLNK,               /* vctl3Config:1    */          \
    VPORTDIS_EXC_DISABLE,               /* extCtl:3         */          \
                                                                        \
    864,                                /* frmHSize         */          \
    625,                                /* frmVSize         */          \
                                                                        \
    0,                                  /* imgHOffsetFld1   */          \
    0,                                  /* imgVOffsetFld1   */          \
    DIS_PAL_RAW_16BIT_LINE_SZ,          /* imgHSizeFld1     */          \
    DIS_PAL_RAW_16BIT_NUM_LINES,        /* imgVSizeFld1     */          \
                                                                        \
    0,                                  /* imgHOffsetFld2   */          \
    0,                                  /* imgVOffsetFld2   */          \
    0,                                  /* imgHSizeFld2     */          \
    0,                                  /* imgVSizeFld2     */          \
                                                                        \
    720,                                /* hBlnkStart       */          \
    0,                                  /* hBlnkStop        */          \
                                                                        \
    0,                                  /* vBlnkXStartFld1  */          \
    1,                                  /* vBlnkYStartFld1  */          \
    0,                                  /* vBlnkXStopFld1   */          \
    50,                                 /* vBlnkYStopFld1   */          \
                                                                        \
    0,                                  /* vBlnkXStartFld2  */          \
    0,                                  /* vBlnkYStartFld2  */          \
    0,                                  /* vBlnkXStopFld2   */          \
    0,                                  /* vBlnkYStopFld2   */          \
                                                                        \
    0,                                  /* xStartFld1       */          \
    1,                                  /* yStartFld1       */          \
                                                                        \
    0,                                  /* xStartFld2       */          \
    0,                                  /* yStartFld2       */          \
                                                                        \
    732,                                /* hSyncStart       */          \
    782,                                /* hSyncStop        */          \
                                                                        \
    720,                                /* vSyncXStartFld1  */          \
    1,                                  /* vSyncYStartFld1  */          \
    732,                                /* vSyncXStopFld1   */          \
    3,                                  /* vSyncYStopFld1   */          \
                                                                        \
    0,                                  /* vSyncXStartFld2  */          \
    0,                                  /* vSyncYStartFld2  */          \
    0,                                  /* vSyncXStopFld2   */          \
    0,                                  /* vSyncYStopFld2   */          \
                                                                        \
    16,                                 /* yClipLow         */          \
    240,                                /* yClipHigh        */          \
    16,                                 /* cClipLow         */          \
    240,                                /* cClipHigh        */          \
                                                                        \
    0x00,                               /* Default Y value  */          \
    0x00,                               /* Default Cb value */          \
    0x00,                               /* Default Cr value */          \
                                                                        \
    VPORTDIS_RGBX_DISABLE,              /* RGB extract disable */       \
    1,                                  /* incPix, for raw mode only */ \
                                                                        \
    (DIS_PAL_RAW_16BIT_LINE_SZ >> 3),   /* thrld            */          \
                                                                        \
    3,                                  /* numFrmBufs       */          \
    128,                                /* alignment        */          \
    VPORT_FLDS_MERGED,                  /* mergeFlds        */          \
                                                                        \
    NULL,                               /* segId            */          \
    NULL                                /* hEdma            */          \
}


#ifdef __cplusplus
}
#endif /* extern "C" */

#endif  /* #ifndef _PSP_BIOS_VPORT_DISPARAMS_H */

/******************************************************************************/
/* End of file                                                                */
/******************************************************************************/
