/*******************************************************************************
**+--------------------------------------------------------------------------+**
**|                            ****                                          |**
**|                            ****                                          |**
**|                            ******o***                                    |**
**|                      ********_///_****                                   |**
**|                      ***** /_//_/ ****                                   |**
**|                       ** ** (__/ ****                                    |**
**|                           *********                                      |**
**|                            ****                                          |**
**|                            ***                                           |**
**|                                                                          |**
**|         Copyright (c) 1998-2007 Texas Instruments Incorporated           |**
**|                        ALL RIGHTS RESERVED                               |**
**|                                                                          |**
**| Permission is hereby granted to licensees of Texas Instruments           |**
**| Incorporated (TI) products to use this computer program for the sole     |**
**| purpose of implementing a licensee product based on TI products.         |**
**| No other rights to reproduce, use, or disseminate this computer          |**
**| program, whether in part or in whole, are granted.                       |**
**|                                                                          |**
**| TI makes no representation or warranties with respect to the             |**
**| performance of this computer program, and specifically disclaims         |**
**| any responsibility for any damages, special or consequential,            |**
**| connected with the use of this program.                                  |**
**|                                                                          |**
**+--------------------------------------------------------------------------+**
*******************************************************************************/

/** \file   psp_bios_vport_st_sample_main.c
 *
 *  \brief  This file contains the test/demo code to demonstrate the
 *          VPORT driver implemented for DSP/BIOS on EVMDM648 platform
 *
 */

/*
 * ========== INCLUDE FILES ===========
 */

#include <std.h>

#include <ti/sdo/pspdrivers/pal_sys/dm648/pal_sys.h>
#include <ti/sdo/pspdrivers/pal_sys/dm648/pal_sys_soc.h>
#include <ti/sdo/pspdrivers/drivers/i2c/psp_i2c.h>


/*
 * ======== DEFINES =========
 */

/* I2C Initialization Parameters */
#define I2C_OWN_ADDR                        (0x10u)
#define I2C_BUS_FREQ                        (200000u)
#define I2C_INPUT_BUS_FREQ                  (PAL_SYS_CPU_CLOCK_FREQUENCY / 6)
#define I2C_NUM_BITS                        (8u)


/*
 * ======== GLOBALS =========
 */

/* I2C Default Initial Parameters */
PSP_I2cConfig I2C_devParams =
{
    /** Driver operation mode                       */
    PSP_OPMODE_INTERRUPT,
    /**< Own address (7 or 10 bit)                  */
    I2C_OWN_ADDR,
    /**< Number of bits/byte to be sent/received    */
    I2C_NUM_BITS,
    /**< I2C Bus Frequency                          */
    I2C_BUS_FREQ,
    /**< Module input clock freq                    */
    I2C_INPUT_BUS_FREQ,
    /**< 7bit/10bit Addressing mode                 */
    FALSE,
    /**< Digital Loob Back (DLB) mode enabled       */
    FALSE
};


/*
 * ============= FUNC DECLARATIONS ==============
 */



/*
 * ============= EXTERNS ==============
 */



/*
 * ============= DEFINITIONS ==============
 */

/*
 * ======== main ========
 */
Int main(void)
{
    return 0;
}



/*
 * ======== VPORT0_init ========
 * VPORT0 init function to enable Video Port 0 module.
 * Note: This function is register as a Init function in BIOS TCF file.
 */
void VPORT0_init(void)
{
    /* Power on VPORT0 */
    PAL_sysModuleClkCtrl(PAL_SYS_CLK_MODULE_VP0, PAL_SYS_MODULE_CLK_ENABLE);

    /* Enable pin mux */
    PAL_sysPinmuxEnable(PAL_SYS_PINMUX_VP0);
}



/*
 * ======== VPORT1_init ========
 * VPORT1 init function to enable Video Port 1 module.
 * Note: This function is register as a Init function in BIOS TCF file.
 */
void VPORT1_init(void)
{
    /* Power on VPORT1 */
    PAL_sysModuleClkCtrl(PAL_SYS_CLK_MODULE_VP1, PAL_SYS_MODULE_CLK_ENABLE);

    /* Enable pin mux */
    PAL_sysPinmuxEnable(PAL_SYS_PINMUX_VP1);
}



/*
 * ======== VPORT2_init ========
 * VPORT2 init function to enable Video Port 2 module.
 * Note: This function is register as a Init function in BIOS TCF file.
 */
void VPORT2_init(void)
{
    /* Power on VPORT2 */
    PAL_sysModuleClkCtrl(PAL_SYS_CLK_MODULE_VP2, PAL_SYS_MODULE_CLK_ENABLE);

    /* Enable pin mux */
    PAL_sysPinmuxEnable(PAL_SYS_PINMUX_VP2);
}



/*
 * ======== VPORT3_init ========
 * VPORT3 init function to enable Video Port 3 module.
 * Note: This function is register as a Init function in BIOS TCF file.
 */
void VPORT3_init(void)
{
    /* Power on VPORT3 */
    PAL_sysModuleClkCtrl(PAL_SYS_CLK_MODULE_VP3, PAL_SYS_MODULE_CLK_ENABLE);

    /* Enable pin mux */
    PAL_sysPinmuxEnable(PAL_SYS_PINMUX_VP3_VP4);
}



/*
 * ======== VPORT4_init ========
 * VPORT4 init function to enable Video Port 4 module.
 * Note: This function is register as a Init function in BIOS TCF file.
 */
void VPORT4_init(void)
{
    /* Power on VPORT4 */
    PAL_sysModuleClkCtrl(PAL_SYS_CLK_MODULE_VP4, PAL_SYS_MODULE_CLK_ENABLE);

    /* Enable pin mux */
    PAL_sysPinmuxEnable(PAL_SYS_PINMUX_VP3_VP4);
}



/*
 * ======== I2C_init ========
 * I2C init function to enable I2C module.
 */
void I2C_INIT(void)
{
    /*Power On I2C*/
    PAL_sysModuleClkCtrl(PAL_SYS_CLK_MODULE_I2C, PAL_SYS_MODULE_CLK_ENABLE);
}


/******************************************************************************/
/* End of file                                                                */
/******************************************************************************/
