/*******************************************************************************
**+--------------------------------------------------------------------------+**
**|                            ****                                          |**
**|                            ****                                          |**
**|                            ******o***                                    |**
**|                      ********_///_****                                   |**
**|                      ***** /_//_/ ****                                   |**
**|                       ** ** (__/ ****                                    |**
**|                           *********                                      |**
**|                            ****                                          |**
**|                            ***                                           |**
**|                                                                          |**
**|         Copyright (c) 1998-2007 Texas Instruments Incorporated           |**
**|                        ALL RIGHTS RESERVED                               |**
**|                                                                          |**
**| Permission is hereby granted to licensees of Texas Instruments           |**
**| Incorporated (TI) products to use this computer program for the sole     |**
**| purpose of implementing a licensee product based on TI products.         |**
**| No other rights to reproduce, use, or disseminate this computer          |**
**| program, whether in part or in whole, are granted.                       |**
**|                                                                          |**
**| TI makes no representation or warranties with respect to the             |**
**| performance of this computer program, and specifically disclaims         |**
**| any responsibility for any damages, special or consequential,            |**
**| connected with the use of this program.                                  |**
**|                                                                          |**
**+--------------------------------------------------------------------------+**
*******************************************************************************/

/**
 *  \file    _saa7105.h file
 *
 *  This file contains internal structures and defines for SAA7105 encoder
 */

#ifndef __SAA7105_H
#define __SAA7105_H

#ifdef __cplusplus
extern "C" {
#endif

/*
 * =========== INCLUDE FILES ==========
 */
#include <ti/sdo/pspdrivers/system/dm648/bios/evmDM648/video/saa7105.h>

/*
 * =========== DEFINES ==========
 */
/** SAA7105 8 bit I2C address */
#define _SAA7105_IICADDR                (0x88>>1)

#ifndef INV
    #define INV                         ((void*)(-1))
    /**< Define for invalid pointer */
#endif /* INV */

/* SAA7105 register address defines */
#define SAA7105_STATUS_BYTE_ADDR                             (0x00)
/**< SAA7105 Status Byte Register Offset */
#define SAA7105_COMMON_DAC_ADJUST_FINE_ADDR                  (0x16)
/**< SAA7105 Common Dac Adjust Fine Register Offset */
#define SAA7105_R_DAC_ADJUST_COARSE_ADDR                     (0x17)
/**< SAA7105 R Dac Adjust Coarse Register Offset */
#define SAA7105_G_DAC_ADJUST_COARSE_ADDR                     (0x18)
/**< SAA7105 G Dac Adjust Coarse Register Offset */
#define SAA7105_B_DAC_ADJUST_COARSE_ADDR                     (0x19)
/**< SAA7105 B Dac Adjust Coarse Register Offset */
#define SAA7105_MSM_THRESHOLD_ADDR                           (0x1A)
/**< SAA7105 MSM Threshold Register Offset */
#define SAA7105_MONITOR_SENSE_MODE_ADDR                      (0x1B)
/**< SAA7105 Monitor Sense Mode Register Offset */
#define SAA7105_CHIP_ID_ADDR                                 (0x1C)
/**< SAA7105 Chip ID Register Offset */
#define SAA7105_WSS_ADDR1                                    (0x26)
/**< SAA7105 WSS Register 1 Offset */
#define SAA7105_WSS_ADDR2                                    (0x27)
/**< SAA7105 WSS Register 2 Offset */
#define SAA7105_REAL_TIME_CTRL_BURST_START_ADDR              (0x28)
/**< SAA7105 Real Time Control Burst Start Register Offset */
#define SAA7105_SYNC_RST_ENABLE_BURST_END_ADDR               (0x29)
/**< SAA7105 Sync Rst Enable Burst End Register Offset */
#define SAA7105_CG_0_ADDR                                    (0x2A)
/**< SAA7105 CG 0 Register Offset */
#define SAA7105_CG_1_ADDR                                    (0x2B)
/**< SAA7105 CG 1 Register Offset */
#define SAA7105_CG_ENABLE_2_ADDR                             (0x2C)
/**< SAA7105 CG Enable 2 Register Offset */
#define SAA7105_OUTPUT_PORT_CTRL_ADDR                        (0x2D)
/**< SAA7105 Output Port Control Register Offset */
#define SAA7105_INPUT_PATH_CTRL_ADDR1                        (0x37)
/**< SAA7105 Input Path Control Register Offset */
#define SAA7105_GAIN_LUMA_FOR_RGB_ADDR                       (0x38)
/**< SAA7105 Gain Luma for RGB Register Offset */
#define SAA7105_GAIN_COLOR_DIFF_RGB_ADDR                     (0x39)
/**< SAA7105 Gain Color Diff RGB Register Offset */
#define SAA7105_INPUT_PORT_CTRL_1_ADDR                       (0x3A)
/**< SAA7105 Input Port Control 1 Register Offset */
#define SAA7105_VPS_ENABLE_IN_CTRL_2_ADDR                    (0x54)
/**< SAA7105 VPS Enable in Control 2 Register Offset */
#define SAA7105_VPS_BYTE_5_ADDR                              (0x55)
/**< SAA7105 VPS Byte 5 Register Offset */
#define SAA7105_VPS_BYTE_11_ADDR                             (0x56)
/**< SAA7105 VPS Byte 11 Register Offset */
#define SAA7105_VPS_BYTE_12_ADDR                             (0x57)
/**< SAA7105 VPS Byte 12 Register Offset */
#define SAA7105_VPS_BYTE_13_ADDR                             (0x58)
/**< SAA7105 VPS Byte 13 Register Offset */
#define SAA7105_VPS_BYTE_14_ADDR                             (0x59)
/**< SAA7105 VPS Byte 14 Register Offset */
#define SAA7105_CHROMA_PHASE_ADDR                            (0x5A)
/**< SAA7105 Chroma Phase Register Offset */
#define SAA7105_GAIN_U_ADDR                                  (0x5B)
/**< SAA7105 Gain U Register Offset */
#define SAA7105_GAIN_V_ADDR                                  (0x5C)
/**< SAA7105 Gain V Register Offset */
#define SAA7105_GAIN_U_MSB_BLACK_LEVEL_ADDR                  (0x5D)
/**< SAA7105 Gain U MSB Black Level Register Offset */
#define SAA7105_GAIN_V_MSB_BLANKING_LEVEL_ADDR               (0x5E)
/**< SAA7105 Gain V MSB Blanking Level Register Offset */
#define SAA7105_CCR_BLANKING_LEVEL_VBI_ADDR                  (0x5F)
/**< SAA7105 CCR Blanking Level VBI Register Offset */
#define SAA7105_STANDARD_CTRL_ADDR                           (0x61)
/**< SAA7105 Standard Control Register Offset */
#define SAA7105_BURST_AMPLITUDE_ADDR                         (0x62)
/**< SAA7105 Burst Amplitude Register Offset */
#define SAA7105_SUBCARRIER_0_ADDR                            (0x63)
/**< SAA7105 Subcarrier 0 Register Offset */
#define SAA7105_SUBCARRIER_1_ADDR                            (0x64)
/**< SAA7105 Subcarrier 1 Register Offset */
#define SAA7105_SUBCARRIER_2_ADDR                            (0x65)
/**< SAA7105 Subcarrier 2 Register Offset */
#define SAA7105_SUBCARRIER_3_ADDR                            (0x66)
/**< SAA7105 Subcarrier 3 Register Offset */
#define SAA7105_LINE_21_ODD_0_ADDR                           (0x67)
/**< SAA7105 Line 21 Odd 0 Register Offset */
#define SAA7105_LINE_21_ODD_1_ADDR                           (0x68)
/**< SAA7105 Line 21 Odd 1 Register Offset */
#define SAA7105_LINE_21_EVEN_0_ADDR                          (0x69)
/**< SAA7105 Line 21 Even 0 Register Offset */
#define SAA7105_LINE_21_EVEN_1_ADDR                          (0x6A)
/**< SAA7105 Line 21 Even 1 Register Offset */
#define SAA7105_TRIGGER_CTRL_ADDR1                           (0x6C)
/**< SAA7105 Trigger Control Register 1 Offset */
#define SAA7105_TRIGGER_CTRL_ADDR2                           (0x6D)
/**< SAA7105 Trigger Control Register 2 Offset */
#define SAA7105_MULTI_CTRL_ADDR                              (0x6E)
/**< SAA7105 Multi Control Register Offset */
#define SAA7105_CC_TELETEXT_ENABLE_ADDR                      (0x6F)
/**< SAA7105 CC Teletext Enable Register Offset */
#define SAA7105_ACTIVE_DISP_HORIZ_START_ADDR                 (0x70)
/**< SAA7105 Active Disp Horizontal Start Register Offset */
#define SAA7105_ACTIVE_DISP_HORIZ_END_ADDR                   (0x71)
/**< SAA7105 Active Disp Horizontal End Register Offset */
#define SAA7105_MSBS_ADWH_ADDR                               (0x72)
/**< SAA7105 MSBS ADWH Register Offset */
#define SAA7105_TTX_REQST_HORIZ_START_ADDR                   (0x73)
/**< SAA7105 TTX Reqst Horizontal Start Register Offset */
#define SAA7105_TTX_REQST_HORIZ_DELAY_ADDR                   (0x74)
/**< SAA7105 TTX Reqst Horizontal Delay Register Offset */
#define SAA7105_CSYNC_ADVANCE_ADDR                           (0x75)
/**< SAA7105 Csync Advance Register Offset */
#define SAA7105_TTX_ODD_REQST_VERT_START_ADDR                (0x76)
/**< SAA7105 TTX Odd Reqst Vertical Start Register Offset */
#define SAA7105_TTX_ODD_REQST_VERT_END_ADDR                  (0x77)
/**< SAA7105 TTX Odd Reqst Vertical End Register Offset */
#define SAA7105_TTX_EVEN_REQST_VERT_START_ADDR               (0x78)
/**< SAA7105 TTX Even Reqst Vertical Start Register Offset */
#define SAA7105_TTX_EVEN_REQST_VERT_END_ADDR                 (0x79)
/**< SAA7105 TTX Even Reqst Vertical End Register Offset */
#define SAA7105_FIRST_ACTIVE_LINE_ADDR                       (0x7A)
/**< SAA7105 First Active Line Register Offset */
#define SAA7105_LAST_ACTIVE_LINE_ADDR                        (0x7B)
/**< SAA7105 Last Active Line Register Offset */
#define SAA7105_TTX_MODE_MSB_VERT_ADDR                       (0x7C)
/**< SAA7105 TTX Mode MSB Vertical Register Offset */
#define SAA7105_DISABLE_TTX_LINE_ADDR1                       (0x7E)
/**< SAA7105 Disable TTX Line Register Offset */
#define SAA7105_DISABLE_TTX_LINE_ADDR2                       (0x7F)
/**< SAA7105 Disable TTX Line Register Offset */
#define SAA7105_FIFO_STATUS_ADDR                             (0x80)
/**< SAA7105 FIFO Status Register Offset */
#define SAA7105_PIXEL_CLK_0_ADDR                             (0x81)
/**< SAA7105 Pixel Clk 0 Register Offset */
#define SAA7105_PIXEL_CLK_1_ADDR                             (0x82)
/**< SAA7105 Pixel Clk 1 Register Offset */
#define SAA7105_PIXEL_CLK_2_ADDR                             (0x83)
/**< SAA7105 Pixel Clk 2 Register Offset */
#define SAA7105_PIXEL_CLK_CTRL_ADDR                          (0x84)
/**< SAA7105 Pixel Clk Control Register Offset */
#define SAA7105_FIFO_CTRL_ADDR                               (0x85)
/**< SAA7105 FIFO Control Register Offset */
#define SAA7105_HORIZ_OFFSET_ADDR                            (0x90)
/**< SAA7105 Horizontal Offset Register Offset */
#define SAA7105_PIXEL_NUM_ADDR                               (0x91)
/**< SAA7105 Pixel Num Register Offset */
#define SAA7105_VERT_OFFSET_ODD_ADDR                         (0x92)
/**< SAA7105 Vertical Offset Odd Register Offset */
#define SAA7105_VERT_OFFSET_EVEN_ADDR                        (0x93)
/**< SAA7105 Vertical Offset Even Register Offset */
#define SAA7105_MSBS_ADDR                                    (0x94)
/**< SAA7105 MSBS Register Offset */
#define SAA7105_LINE_NUM_ADDR                                (0x95)
/**< SAA7105 Line Num Register Offset */
#define SAA7105_SCALER_CTRL_MCB_YPIX_ADDR                    (0x96)
/**< SAA7105 Scaler Control MCB YPIX Register Offset */
#define SAA7105_SYNC_CTRL_ADDR                               (0x97)
/**< SAA7105 Sync Control Register Offset */
#define SAA7105_LINE_LENGTH_ADDR                             (0x98)
/**< SAA7105 Line Length Register Offset */
#define SAA7105_IP_DELAY_MSB_LINE_LENGTH_ADDR                (0x99)
/**< SAA7105 IP Delay MSB Line Length Register Offset */
#define SAA7105_HORIZ_INCR_ADDR                              (0x9A)
/**< SAA7105 Horizontal Incr Register Offset */
#define SAA7105_VERT_INCR_ADDR                               (0x9B)
/**< SAA7105 Vertical Incr Register Offset */
#define SAA7105_MSBS_VERT_AND_HORIZ_INCR_ADDR                (0x9C)
/**< SAA7105 MSBS Vertical and Horizontal Incr Register Offset */
#define SAA7105_WEIGHTING_FACTOR_ODD_ADDR                    (0x9D)
/**< SAA7105 Weighting Factor Odd Register Offset */
#define SAA7105_WEIGHTING_FACTOR_EVEN_ADDR                   (0x9E)
/**< SAA7105 Weighting Factor Even Register Offset */
#define SAA7105_WEIGHTING_FACTOR_MSB_ADDR                    (0x9F)
/**< SAA7105 Weighting Factor MSB Register Offset */
#define SAA7105_VERT_LINE_SKIP_ADDR                          (0xA0)
/**< SAA7105 Vertical Line Skip Register Offset */
#define SAA7105_VERT_LINE_SKIP_MSB_ADDR                      (0xA1)
/**< SAA7105 Vertical Line Skip MSB Register Offset */
#define SAA7105_BORDER_COLOR_Y_ADDR                          (0xA2)
/**< SAA7105 Border Color Y Register Offset */
#define SAA7105_BORDER_COLOR_U_ADDR                          (0xA3)
/**< SAA7105 Border Color U Register Offset */
#define SAA7105_BORDER_COLOR_V_ADDR                          (0xA4)
/**< SAA7105 Border Color V Register Offset */
#define SAA7105_HD_SYNC_LINE_COUNT_ARRAY_ADDR                (0xD0)
/**< SAA7105 HD Sync Line Count Array Register Offset */
#define SAA7105_HD_SYNC_LINE_TYPE_ARRAY_ADDR                 (0xD1)
/**< SAA7105 HD Sync Line Type Array Register Offset */
#define SAA7105_HD_SYNC_LINE_PATTERN_ARRAY_ADDR              (0xD2)
/**< SAA7105 HD Sync Line Pattern Array Register Offset */
#define SAA7105_HD_SYNC_VALUE_ARRAY_ADDR                     (0xD3)
/**< SAA7105 HD Sync Value Array Register Offset */
#define SAA7105_HD_SYNC_TRIG_STATE_1_ADDR                    (0xD4)
/**< SAA7105 HD Sync Trig State 1 Register Offset */
#define SAA7105_HD_SYNC_TRIG_STATE_2_ADDR                    (0xD5)
/**< SAA7105 HD Sync Trig State 2 Register Offset */
#define SAA7105_HD_SYNC_TRIG_STATE_3_ADDR                    (0xD6)
/**< SAA7105 HD Sync Trig State 3 Register Offset */
#define SAA7105_HD_SYNC_TRIG_STATE_4_ADDR                    (0xD7)
/**< SAA7105 HD Sync Trig State 4 Register Offset */
#define SAA7105_HD_SYNC_TRIG_PHASE_X_LOW_ADDR                (0xD8)
/**< SAA7105 HD Sync Trig Phase X Low Register Offset */
#define SAA7105_HD_SYNC_TRIG_PHASE_X_HIGH_ADDR               (0xD9)
/**< SAA7105 HD Sync Trig Phase X High Register Offset */
#define SAA7105_HD_SYNC_TRIG_PHASE_Y_LOW_ADDR                (0xDA)
/**< SAA7105 HD Sync Trig Phase Y Low Register Offset */
#define SAA7105_HD_SYNC_TRIG_PHASE_Y_HIGH_ADDR               (0xDB)
/**< SAA7105 HD Sync Trig Phase Y High Register Offset */
#define SAA7105_HD_OUTPUT_CTRL_ADDR                          (0xDC)
/**< SAA7105 HD Output Control Register Offset */
#define SAA7105_CURSOR_COLOR_1_R_ADDR                        (0xF0)
/**< SAA7105 Cursor Color 1 R Register Offset */
#define SAA7105_CURSOR_COLOR_1_G_ADDR                        (0xF1)
/**< SAA7105 Cursor Color 1 G Register Offset */
#define SAA7105_CURSOR_COLOR_1_B_ADDR                        (0xF2)
/**< SAA7105 Cursor Color 1 B Register Offset */
#define SAA7105_CURSOR_COLOR_2_R_ADDR                        (0xF3)
/**< SAA7105 Cursor Color 2 R Register Offset */
#define SAA7105_CURSOR_COLOR_2_G_ADDR                        (0xF4)
/**< SAA7105 Cursor Color 2 G Register Offset */
#define SAA7105_CURSOR_COLOR_2_B_ADDR                        (0xF5)
/**< SAA7105 Cursor Color 2 B Register Offset */
#define SAA7105_AUX_CURSOR_COLOUR_R_ADDR                     (0xF6)
/**< SAA7105 Aux Cursor Colour R Register Offset */
#define SAA7105_AUX_CURSOR_COLOUR_G_ADDR                     (0xF7)
/**< SAA7105 Aux Cursor Colour G Register Offset */
#define SAA7105_AUX_CURSOR_COLOUR_B_ADDR                     (0xF8)
/**< SAA7105 Aux Cursor Colour B Register Offset */
#define SAA7105_HORIZ_CURSOR_POSITION_ADDR                   (0xF9)
/**< SAA7105 Horizontal Cursor Position Register Offset */
#define SAA7105_HORIZ_HOT_SPOT_MSB_XCP_ADDR                  (0xFA)
/**< SAA7105 Horizontal Hot Spot MSB_XCP Register Offset */
#define SAA7105_VERT_CURSOR_POSITION_ADDR                    (0xFB)
/**< SAA7105 Vertical Cursor Position Register Offset */
#define SAA7105_VERT_HOT_SPOT_MSB_YCP_ADDR                   (0xFC)
/**< SAA7105 Vertical Hot Spot MSB YCP Register Offset */
#define SAA7105_INPUT_PATH_CTRL_ADDR2                        (0xFD)
/**< SAA7105 Input Path Control Register Offset */
#define SAA7105_CURSOR_BIT_MAP_ADDR                          (0xFE)
/**< SAA7105 Cursor Bit Map Register Offset */
#define SAA7105_COLOR_LOOK_UP_TABLE_ADDR                     (0xFF)
/**< SAA7105 Color Look Up Table Register Offset */

/* defines for configuration values */
#define SAA7105_CURSOR_NUMBYTES                              (256)
/**< Number of bytes for Cursor */
#define SAA7105_CURSOR_RAM_ADDR                              (0x00)
/**< Cursor RAM Address */
#define SAA7105_CURSOR_TRANS_VAL                             (0xAA)
/**< Transparent Cursor Value */

/*
 * ========= STRUCTURES ==============
 */
/**
 *  \brief  SAA7105 Registers Structure
 *  This structure contains register values for SAA7105.
 */
typedef struct _SAA7105_Regs
{
    Uint8 status;
    /**< status of SAA7105 */
    Uint8 nullArray1[0x15];
    /**< null array */

    Uns dacAdjust : 4;                  /**< dacAdjust bit field */
    Uns unusedDACAdjust : 4;            /**< unusedDACAdjust bit field */
    /**< Common DAC Adjust (0x16) */

    Uns redDACAdjust : 5;               /**< redDACAdjust bit field */
    Uns unusedRDACAdjust : 3;           /**< unusedRDACAdjust bit field */
    /**< RedDAC Adjust (0x17) */

    Uns greenDACAdjust : 5;             /**< greenDACAdjust bit field */
    Uns unusedGDACAdjust : 3;           /**< unusedGDACAdjust bit field */
    /**< Green DAC Adjust (0x18) */

    Uns blueDACAdjust : 5;              /**< blueDACAdjust bit field */
    Uns unusedBDACAdjust : 3;           /**< unusedBDACAdjust bit field */
    /**< Blue DAC Adjust (0x19) */

    Uint8 thrldMSM;
    /**< MSM Threshold (0x1A) */

    Uns blueComp : 1;                   /**< blueComp bit field */
    Uns greenComp : 1;                  /**< greenComp bit field */
    Uns redComp : 1;                    /**< redComp bit field */
    Uns reg1BUnused : 2;                /**< reg1BUnused bit field */
    Uns outputEnableMSM : 1;            /**< outputEnableMSM bit field */
    Uns autoEnableMSM : 1;              /**< autoEnableMSM bit field */
    Uns enableMSM : 1;                  /**< enableMSM bit field */
    /**< Monitor sense mode (0x1B) */

    Uint8 chipID;
    /**< Chip identification (0x1C) */

    Uint8 nullArray2[9];
    /**< Null Array (0x1D) - (0x25) */

    Uint8 wideScreenLSBits;             /**< wideScreenLSBits Register */
    Uns wideScreenMSBits : 6;           /**< wideScreenMSBits bit field */
    Uns wideScreenunused : 1;           /**< wideScreenunused bit field */
    Uns wideScreenEnable : 1;           /**< wideScreenEnable bit field */
    /**< Wide screen signal (0x26) - (0x27) */

    Uns burstStart : 6;                 /**< burstStart bit field */
    Uns burstUnused : 2;                /**< burstUnused bit field */
    /**< Burst start (0x28) */

    Uns burstEnd : 6;                   /**< burstEnd bit field */
    Uns reg29Unused : 1;                /**< reg29Unused bit field */
    Uns syncResetEnable : 1;            /**< syncResetEnable bit field */
    /**< Burst start (0x29) */

    Uint8 copyGen0;                     /**< copyGen0 Register */
    Uint8 copyGen1;                     /**< copyGen1 Register */
    Uns copyGenMSBits : 4;              /**< copyGenMSBits bit field */
    Uns reg2CUnused : 3;                /**< reg2CUnused bit field */
    Uns copyGenEnable : 1;              /**< copyGenEnable bit field */
    /**< Copy generation (0x2A) - (0x2C) */

    Uns reg2DUnused : 1;                /**< reg2DUnused bit field */
    Uns cvbsEn2 : 1;                    /**< cvbsEn2 bit field */
    Uns clk2En : 1;                     /**< clk2En bit field */
    Uns encOff : 1;                     /**< encOff bit field */
    Uns cEn : 1;                        /**< cEn bit field */
    Uns cvbsEn0 : 1;                    /**< cvbsEn0 bit field */
    Uns cvbsEn1 : 1;                    /**< cvbsEn1 bit field */
    Uns vbsEn : 1;                      /**< vbsEn bit field */
    /**< Output Port Control (0x2D) */

    Uint8 nullArray3[9];
    /**< Null Array (0x2E) - (0x36) */

    Uns xFilterActive : 1;              /**< xFilterActive bit field */
    Uns inputLevel : 1;                 /**< inputLevel bit field */
    Uns cursorZoom : 1;                 /**< cursorZoom bit field */
    Uns reg37AUnused : 1;               /**< reg37AUnused bit field */
    Uns yUpscaleFilter : 2;             /**< yUpscaleFilter bit field */
    Uns yUpscaleActive : 1;             /**< yUpscaleActive bit field */
    Uns reg37BUnused : 1;               /**< reg37BUnused bit field */
    /**< Input Path Control (0x37) */

    Uns rgbGainLuminance : 5;           /**< rgbGainLuminance bit field */
    Uns reg38Unused : 3;                /**< reg38Unused bit field */
    /**< Gain luminance for RGB (0x38) */

    Uns rgbGainChrominance : 5;         /**< rgbGainChrominance bit field */
    Uns reg39Unused : 3;                /**< reg39Unused bit field */
    /**< Gain chrominance for RGB (0x39) */

    Uns chromaBinary : 1;               /**< chromaBinary bit field */
    Uns lumaBinary : 1;                 /**< lumaBinary bit field */
    Uns compSyncEnable : 1;             /**< compSyncEnable bit field */
    Uns yuvToRGBBypass : 1;             /**< yuvToRGBBypass bit field */
    Uns syncVia656 : 1;                 /**< syncVia656 bit field */
    Uns svynt : 1;                      /**< svynt bit field */
    Uns reg3AUnused : 1;                /**< reg3AUnused bit field */
    Uns colorBarsEnable : 1;            /**< colorBarsEnable bit field */
    /**< Input Port Control (0x3A) */

    Uint8 nullArray4[0x19];
    /**< Null Array (0x3B) - (0x53) */

    Uns slot : 1;                       /**< slot bit field */
    Uns edge : 1;                       /**< edge bit field */
    Uns reg54AUnused : 2;               /**< reg54AUnused bit field */
    Uns gpEnable : 1;                   /**< gpEnable bit field */
    Uns gpData : 1;                     /**< gpData bit field */
    Uns reg54BUnused : 1;               /**< reg54BUnused bit field */
    Uns vpsEnable : 1;                  /**< vpsEnable bit field */
    /**< VPS Enable (0x54) */

    Uint8 vpsByte5;                     /**< VPS Byte5 Register */
    Uint8 vpsByte11;                    /**< VPS Byte11 Register */
    Uint8 vpsByte12;                    /**< VPS Byte12 Register */
    Uint8 vpsByte13;                    /**< VPS Byte13 Register */
    Uint8 vpsByte15;                    /**< VPS Byte15 Register */
    /**< VPS Byte5 to Byte14 (0x55) - (0x59) */

    Uint8 chromaPhase;
    /**< VPS Enable (0x5A) */

    Uint8 cbGain;
    /**< Gain Cb (0x5B) */

    Uint8 crGain;
    /**< Gain Cr (0x5C) */

    Uns blackLevel : 6;                 /**< blackLevel bit field */
    Uns reg5DUnused : 1;                /**< reg5DUnused bit field */
    Uns uGainMSB : 1;                   /**< uGainMSB bit field */
    /**< Black Level (0x5D) */

    Uns blankLevel : 6;                 /**< blankLevel bit field */
    Uns reg5EUnused : 1;                /**< reg5EUnused bit field */
    Uns vGainMSB : 1;                   /**< vGainMSB bit field */
    /**< Blank Level (0x5E) */

    Uns vBIBlankLevel : 6;              /**< vBIBlankLevel bit field */
    Uns ccrFilter : 2;                  /**< ccrFilter bit field */
    /**< Black Level (0x5F) */

    Uint8 nullByte60;
    /**< Null Byte (0x60) */

    Uns fise : 1;                       /**< fise bit field */
    Uns palEnable : 1;                  /**< palEnable bit field */
    Uns chromaBW : 1;                   /**< chromaBW bit field */
    Uns reg61Unused : 1;                /**< reg61Unused bit field */
    Uns whiteLevel : 1;                 /**< whiteLevel bit field */
    Uns palSwitch : 1;                  /**< palSwitch bit field */
    Uns downA : 1;                      /**< downA bit field */
    Uns downD : 1;                      /**< downD bit field */
    /**< Standard Control (0x61) */

    Uns burstAmplitude : 7;             /**< burstAmplitude bit field */
    Uns rtCEEnable : 1;                 /**< rtCEEnable bit field */
    /**< Burst Amplitude (0x62) */

    Uint8 subCarrier0;                  /**< Sub Carrier 0 Register */
    Uint8 subCarrier1;                  /**< Sub Carrier 1 Register */
    Uint8 subCarrier2;                  /**< Sub Carrier 2 Register */
    Uint8 subCarrier3;                  /**< Sub Carrier 3 Register */
    /**< Sub Carrier 0-3 (0x63) - (0x66) */
/*  Uns int SubCarrier; */

    Uint8 line21OddF0;                  /**< Line 21 Odd F0 Register */
    Uint8 line21OddF1;                  /**< Line 21 Odd F1 Register */
    Uint8 line21EvenF0;                 /**< Line 21 Even F0 Register */
    Uint8 line21EvenF1;                 /**< Line 21 Even F1 Register */
    /**< Closed Captioning (0x67) - (0x6A) */

    Uint8 nullByte6B;
    /**< Null Byte (0x6B) */

    Uint8 hTrigger;
    /**< Horizontal Trigger (0x6C) */

    Uns vTrigger : 5;                   /**< vTrigger bit field */
    Uns hTriggerMSBs : 3;               /**< hTriggerMSBs bit field */
    /**< H & V Trigger (0x6D) */

    Uns fieldControl : 2;               /**< fieldControl bit field */
    Uns lumaDelay : 2;                  /**< lumaDelay bit field */
    Uns phaseResetMode : 2;             /**< phaseResetMode bit field */
    Uns blankLevelOut : 1;              /**< blankLevelOut bit field */
    Uns vTrigNegative : 1;              /**< vTrigNegative bit field */
    /**< Multi Control (0x6E) */

    Uns cCLine : 5;                     /**< cCLine bit field */
    Uns teletextEnable : 1;             /**< teletextEnable bit field */
    Uns cCEnable : 2;                   /**< cCEnable bit field */
    /**< Closed Caption/Teletext Enable (0x6F) */

    Uint8 hStart;
    /**< Active Display Window Horizontal Start (0x70) */

    Uint8 hEnd;
    /**< Active Display Window Horizontal End (0x71) */

    Uns hStartMSB : 3;                  /**< hStartMSB bit field */
    Uns reg72BUnused : 1;               /**< reg72BUnused bit field */
    Uns hEndMSB : 3;                    /**< hEndMSB bit field */
    Uns reg72AUnused : 1;               /**< reg72AUnused bit field */
    /**< Active Display Window MSBs (0x72) */

    Uint8 teletextHStart;
    /**< Teletext Horizontal Start (0x73) */

    Uns teletextHDelay : 4;             /**< teletextHDelay bit field */
    Uns reg74Unused : 4;                /**< reg74Unused bit field */
    /**< Teletext Horizontal Start (0x74) */

    Uns reg75Unused : 3;                /**< reg75Unused bit field */
    Uns cSyncAdvance : 5;               /**< cSyncAdvance bit field */
    /**< CSYNC Advance (0x75) */

    Uint8 teletextOddVStart;
    /**< Teletext Odd Vertical Start (0x76) */

    Uint8 teletextOddVEnd;
    /**< Teletext Odd Vertical Start (0x77) */

    Uint8 teletextEvenVStart;
    /**< Teletext Odd Vertical Start (0x78) */

    Uint8 teletextEvenVEnd;
    /**< Teletext Odd Vertical Start (0x79) */

    Uint8 fal;
    /**< First Active Line (0x7A) */

    Uint8 lal;
    /**< Last Active Line (0x7B) */

    Uns ttxOVSMsb : 1;                  /**< ttxOVSMsb bit field */
    /**< TTX mode */
    Uns ttxOVEMsb : 1;                  /**< ttxOVEMsb bit field */
    Uns ttxEVSMsb : 1;                  /**< ttxEVSMsb bit field */
    Uns ttxEVEMsb : 1;                  /**< ttxEVEMsb bit field */
    Uns falMsb : 1;                     /**< falMsb bit field */
    Uns OldTTXProtocol : 1;             /**< OldTTXProtocol bit field */
    Uns lalMsb : 1;                     /**< lalMsb bit field */
    Uns teletext60HzEnable : 1;         /**< teletext60HzEnable bit field */
    /**< MSB vertical (0x7C) */

    Uint8 nullByte7D;
    /**< Null Byte (0x7D) */

    Uint8 ttxLineLsbOff;
    /**< Disable Teletext Line (0x7E) */
    Uint8 ttxLineMsbOff;
    /**< Disable Teletext Line (0x7f) */

    Uns fifoUnderflow : 1;              /**< fifoUnderflow bit field */
    Uns fifoOverflow : 1;               /**< fifoOverflow bit field */
    Uns bufferFIFOOverflow : 1;         /**< bufferFIFOOverflow bit field */
    Uns inputFifoError : 1;             /**< inputFifoError bit field */
    Uns reg80Unused : 4;                /**< reg80Unused bit field */
    /**< FIFO Status (0x80) */

    Uint8 pixClock0;
    /**< Disable Teletext Line (0x81) */
    Uint8 pixClock1;
    /**< Disable Teletext Line (0x82) */
    Uint8 pixClock2;
    /**< Disable Teletext Line (0x83) */

    Uns pclkInDiv : 2;                  /**< pclkInDiv bit field */
    Uns pclkOutDiv : 2;                 /**< pclkOutDiv bit field */
    Uns bypassInputFIFO : 1;            /**< bypassInputFIFO bit field */
    Uns fifoResetOnField : 1;           /**< fifoResetOnField bit field */
    Uns pclkSyncVSYNC : 1;              /**< pclkSyncVSYNC bit field */
    Uns pclkSingleEnded : 1;            /**< pclkSingleEnded bit field */
    /**< Pixel Clock Control (0x84) */

    Uns fifoThreshold : 4;              /**< fifoThreshold bit field */
    Uns reg85Unused : 3;                /**< reg85Unused bit field */
    Uns nonDVOCompliant : 1;            /**< nonDVOCompliant bit field */
    /**< FIFO Control (0x85) */

    Uint8 bullArray5[10];
    /**< Null Array (0x86) - (0x8F) */

    Uint8 xOfs;
    /**< Horizontal Offset (0x90) */

    Uint8 xPix;
    /**< Horizontal Offset (0x91) */

    Uint8 yOfsOdd;
    /**< Vertical Odd Offset (0x92) */

    Uint8 yOfsEven;
    /**< Vertical Even Field Offset (0x93) */

    Uns xOfsMsb : 2;                    /**< xOfsMsb bit field */
    Uns xPixMsb : 2;                    /**< xPixMsb bit field */
    Uns yOfsOddMsb : 2;                 /**< yOfsOddMsb bit field */
    Uns yOfsEvenMsb : 2;                /**< yOfsEvenMsb bit field */
    /**< MSBs (0x94) */

    Uint8 yPix;
    /**< Line Number (0x95) */

    Uns yPixMsb : 2;                    /**< yPixMsb bit field */
    Uns reg96Unused : 1;                /**< reg96Unused bit field */
    Uns lumaBooster : 1;                /**< lumaBooster bit field */
    Uns interlacedCursor : 1;           /**< interlacedCursor bit field */
    Uns masterSlaveMode : 1;            /**< masterSlaveMode bit field */
    Uns cboPolarity : 1;                /**< cboPolarity bit field */
    Uns frameSyncEnable : 1;            /**< frameSyncEnable bit field */
    /**< Scaler Control (0x96) */

    Uns hSyncPolarity : 1;              /**< hSyncPolarity bit field */
    Uns hSyncOutput : 1;                /**< hSyncOutput bit field */
    Uns vSyncPolarity : 1;              /**< vSyncPolarity bit field */
    Uns vSyncOutput : 1;                /**< vSyncOutput bit field */
    Uns frameSyncPolarity : 1;          /**< frameSyncPolarity bit field */
    Uns fieldOutput : 1;                /**< fieldOutput bit field */
    Uns vSyncMode : 1;                  /**< vSyncMode bit field */
    Uns hSyncMode : 1;                  /**< hSyncMode bit field */
    /**< Sync Control (0x97) */

    Uint8 hLen;
    /**< Line Length (0x98) */

    Uns hLenMsb : 4;                    /**< hLenMsb bit field */
    Uns idel : 4;                       /**< idel bit field */
    /**< Input Delay (0x99) */

    Uint8 xInc;
    /**< Horizontal Increment (0x9A) */

    Uint8 yInc;
    /**< Vertical Increment (0x9B) */

    Uns xIncMsb : 4;                    /**< xIncMsb bit field */
    Uns yIncMsb : 4;                    /**< yIncMsb bit field */
    /**< MSBs Hor/Vertical Increment (0x9C) */

    Uint8 yIWGTO;
    /**< Weighting Factor Odd (0x9D) */

    Uint8 yIWGTE;
    /**< Weighting Factor Even (0x9E) */

    Uns yIWGTOMsb : 4;                  /**< yIWGTOMsb bit field */
    Uns yIWGTEMsb : 4;                  /**< yIWGTEMsb bit field */
    /**< MSBs Weighting Factor (0x9F) */

    Uint8 ySkip;
    /**< Vertical Line Skip (0xA0) */

    Uns ySkipMsb : 4;                   /**< ySkipMsb bit field */
    Uns regA0Unused : 3;                /**< regA0Unused bit field */
    Uns enableBlank : 1;                /**< enableBlank bit field */
    /**< MSBs Weighting Factor (0xA1) */

    Uint8 yBorderColor;
    /**< Y Border Color (0xA2) */

    Uint8 uBorderColor;
    /**< U Border Color (0xA3) */

    Uint8 vBorderColor;
    /**< V Border Color (0xA4) */

    Uint8 nullArray6[0x2B];
    /**< Null Array (0xA5) - (0xCF) */

    Uint8 ramAAddress;
    /**< HD Sync Line Count Array (0xD0) */

    Uint8 ramBAddress;
    /**< HD Sync Line Type Array (0xD1) */

    Uint8 ramCAddress;
    /**< HD Sync Line Pattern Array (0xD2) */

    Uint8 ramDAddress;
    /**< HD Sync Value Array (0xD3) */

    Uns hdLineCounter : 10;             /**< hdLineCounter bit field */
    Uns hdLineTypePtr : 2;              /**< hdLineTypePtr bit field */
    Uns hdLinePatternPtr : 4;           /**< hdLinePatternPtr bit field */
    /**< HD Sync Trigger (State 1-4) (0xD4 - 0xD5) */

    Uns hdDurationCtr : 10;             /**< hdDurationCtr bit field */
    Uns regD6AUnused : 2;               /**< regD6AUnused bit field */
    Uns hdEventTypePtr : 3;             /**< hdEventTypePtr bit field */
    Uns regD6BUnused : 1;               /**< regD6BUnused bit field */
    /**< HD Sync Trigger (State 1-4) (0xD6 - 0xD7) */

    Uns hdTriggerPhaseX : 12;           /**< hdTriggerPhaseX bit field */
    Uns regD9Unused : 4;                /**< regD9Unused bit field */
    /**< HD Sync Trigger Phase X (0xD8 - 0xD9) */

    Uns hdTriggerPhaseY : 10;           /**< hdTriggerPhaseY bit field */
    Uns regDBUnused : 6;                /**< regDBUnused bit field */
    /**< HD Sync Trigger Phase Y (0xDA - 0xDB) */

    Uns hdColorInterpolator : 1;        /**< hdColorInterpolator bit field */
    Uns hdFullGain : 1;                 /**< hdFullGain bit field */
    Uns hdRGB_YCbCr : 1;                /**< hdRGB_YCbCr bit field */
    Uns hdActive : 1;                   /**< hdActive bit field */
    Uns regDCUnused : 4;                /**< regDCUnused bit field */
    /**< HD Output Control (0xDC) */

    Uint8 nullArray7[0x13];
    /**< Null Array (0xDD) - (0xEF) */

    Uint8 redCursorColor1;
    /**< R Cursor Color1 (0xF0) */

    Uint8 greenCursorColor1;
    /**< G Cursor Color1 (0xF1) */

    Uint8 blueCursorColor1;
    /**< B Cursor Color1 (0xF2) */

    Uint8 redCursorColor2;
    /**< R Cursor Color2 (0xF3) */

    Uint8 greenCursorColor2;
    /**< G Cursor Color2 (0xF4) */

    Uint8 blueCursorColor2;
    /**< B Cursor Color2 (0xF5) */

    Uint8 auxRCursorColor;
    /**< Aux R Cursor Color (0xF6) */

    Uint8 auxGCursorColor;
    /**< Aux G Cursor Color (0xF7) */

    Uint8 auxBCursorColor;
    /**< Aux B Cursor Color (0xF8) */

    Uint8 hCursorPos;
    /**< Horizontal Cursor Position (0xF9) */

    Uns hCursPosMSBs : 3;               /**< hCursPosMSBs bit field */
    Uns horHotSpot : 5;                 /**< horHotSpot bit field */
    /**< Horizontal Hot Spot / MSBs H Cursor Position (0xFA) */

    Uint8 vCursorPos;
    /**< Vertical Cursor Position (0xFB) */

    Uns vCursPosMSBs : 2;               /**< vCursPosMSBs bit field */
    Uns regFCUnused : 1;                /**< regFCUnused bit field */
    Uns vertHotSpot : 5;                /**< vertHotSpot bit field */
    /**< Horizontal Hot Spot / MSBs H Cursor Position (0xFC) */

    Uns downFormatDisable : 1;          /**< downFormatDisable bit field */
    Uns rgbToYUVDisable : 1;            /**< rgbToYUVDisable bit field */
    Uns inputFormat : 3;                /**< inputFormat bit field */
    Uns lutLoadMode : 1;                /**< lutLoadMode bit field */
    Uns cursorMode : 1;                 /**< cursorMode bit field */
    Uns lutDisable : 1;                 /**< lutDisable bit field */
    /**< Input Path Control (0xFD) */

    Uint8 cursorAddress;
    /**< Cursor Bit Map Address (0xFE) */

    Uint8 lutAddress;
    /**< Color LUT Map Address (0xFF) */

}_SAA7105_Regs; /**< Typedef for struct _SAA7105_Regs */

/**
 *  \brief SAA7105 cursor structure
 *  This structure contains cursor values for SAA7105 Encoder
 */
typedef struct SAA7105_Cursor_t
{
    Uint8 address;
    /**< cursor address */
    Uint8 cursorBlock[256];
    /**< cursor value block */
} SAA7105_Cursor;   /**< Typedef for struct SAA7105_Cursor_t */

/*
 * ======== EXTERNS =========
 */
extern _SAA7105_Regs _SAA7105_settingsDef;
extern EDC_Fxns SAA7105_Fxns;

#ifdef __cplusplus
}
#endif

#endif /*#ifndef __SAA7105_H*/

/******************************************************************************/
/* end of file                                                                */
/******************************************************************************/
