/*******************************************************************************
**+--------------------------------------------------------------------------+**
**|                            ****                                          |**
**|                            ****                                          |**
**|                            ******o***                                    |**
**|                      ********_///_****                                   |**
**|                      ***** /_//_/ ****                                   |**
**|                       ** ** (__/ ****                                    |**
**|                           *********                                      |**
**|                            ****                                          |**
**|                            ***                                           |**
**|                                                                          |**
**|         Copyright (c) 1998-2007 Texas Instruments Incorporated           |**
**|                        ALL RIGHTS RESERVED                               |**
**|                                                                          |**
**| Permission is hereby granted to licensees of Texas Instruments           |**
**| Incorporated (TI) products to use this computer program for the sole     |**
**| purpose of implementing a licensee product based on TI products.         |**
**| No other rights to reproduce, use, or disseminate this computer          |**
**| program, whether in part or in whole, are granted.                       |**
**|                                                                          |**
**| TI makes no representation or warranties with respect to the             |**
**| performance of this computer program, and specifically disclaims         |**
**| any responsibility for any damages, special or consequential,            |**
**| connected with the use of this program.                                  |**
**|                                                                          |**
**+--------------------------------------------------------------------------+**
*******************************************************************************/

/**
 *  \file _ths8200.c
 *
 *  This file contains structure variables for ths8200 encoder
 */

/*
 * ========== INCLUDE FILES ========
 */
#include <ti/sdo/pspdrivers/system/dm648/bios/evmDM648/video/src/_ths8200.h>

/*
 * ========= STRUCTURES ===========
 */
/** THS8200 Register settings for 480P 60Hz EDTV display */
const _THS8200_Regs ths8200_480p_60Hz_Regs =
{
    0x11,               /* 0x03 chip_cntl     */

    0x00,               /* 0x1A tst_cntl1     */
    0x00,               /* 0x1B tst_cntl2     */

    /* Display Timing Generator Control */
    0xFF,               /* 0x1D dtg_y_sync1           */
    0x49,               /* 0x1E dtg_y_sync2           */
    0xFF,               /* 0x1F dtg_y_sync3           */

    0xFF,               /* 0x20 dtg_cbcr_sync1        */
    0xFF,               /* 0x21 dtg_cbcr_sync2        */
    0xFF,               /* 0x22 dtg_cbcr_sync3        */

    0x11,               /* 0x23 dtg_y_sync_upper      */
    0x15,               /* 0x24 dtg_cbcr_sync_upper   */

    0x3D,               /* 0x25 dtg_spec_a            */
    0x10,               /* 0x26 dtg_spec_b            */
    0x20,               /* 0x27 dtg_spec_c            */

    0x7A,               /* 0x28 dtg_spec_d            */
    0x00,               /* 0x29 dtg_spec_d1           */
    0xC0,               /* 0x2A dtg_spec_e            */

    0x01,               /* 0x2B dtg_spec_h_msb        */
    0x90,               /* 0x2C dtg_spec_h_lsb        */
    0x03,               /* 0x2D dtg_spec_i_msb        */
    0x1B,               /* 0x2E dtg_spec_i_lsb        */

    0x10,               /* 0x2F dtg_spec_k_lsb        */
    0x00,               /* 0x30 dtg_spec_k_msb        */
    0x00,               /* 0x31 dtg_spec_k1           */

    0xAD,               /* 0x32 dtg_speg_g_lsb        */
    0x01,               /* 0x33 dtg_speg_g_msb        */

    0x03,               /* 0x34 dtg_total_pixel_msb   */
    0x5A,               /* 0x35 dtg_total_pixel_lsb   */
    0x00,               /* 0x36 dtg_linecnt_msb       */
    0x01,               /* 0x37 dtg_linecnt_lsb       */

    0x85,               /* 0x38 dtg_mode              */

    0x27,               /* 0x39 dtg_frame_field_msb   */
    0x0D,               /* 0x3A dtg_frame_size_lsb    */
    0xFF,               /* 0x3B dtg_field_size_lsb    */
    0x00,               /* 0x3C dtg1_vesa_cbar_size don't care  */

    0x00,               /* 0x3D dac_cntl_msb          */

    0x00,               /* 0x4A csm_gy_cntl_mult_msb  */
    0x00,               /* 0x4F csm_rcr_bcb_cntl  */

    0x00,               /* 0x70 dtg2_hlength_lsb              */
    0x00,               /* 0x71 dtg2_hlength_lsb_hdly_msb     */
    0x00,               /* 0x72 dtg2_hdly_lsb                 */

    0x00,               /* 0x73 dtg2_vlength1_lsb             */
    0x00,               /* 0x74 dtg2_vlength1_msb_vdly1_msb   */
    0x00,               /* 0x75 dtg2_vdly1_lsb                */

    0x00,               /* 0x76 dtg2_vlength2_lsb             */
    0x00,               /* 0x77 dtg2_vlength2_msb_vdly2_msb   */
    0x00,               /* 0x78 dtg2_vdly2_lsb                */

    0x00,               /* 0x79 dtg2_hs_in_dly_msb            */
    0x38,               /* 0x7A dtg2_hs_in_dly_lsb            */

    0x00,               /* 0x7B dtg2_vs_in_dly_msb            */
    0x04,               /* 0x7C dtg2_vs_in_dly_lsb            */

    0x3F                /* 0x82 dtg2_cntl                     */
};

/** THS8200 Register settings for 720P 60Hz HDTV display */
const _THS8200_Regs ths8200_720p_60Hz_Regs =
{
    0x01,               /* 0x03 chip_cntl     */

    0x00,               /* 0x1A tst_cntl1     */
    0x00,               /* 0x1B tst_cntl2     */

    /* Display Timing Generator Control */
    0xFF,               /* 0x1D dtg_y_sync1           */
    0x49,               /* 0x1E dtg_y_sync2           */
    0xB6,               /* 0x1F dtg_y_sync3           */

    0xFF,               /* 0x20 dtg_cbcr_sync1        */
    0xFF,               /* 0x21 dtg_cbcr_sync2        */
    0xFF,               /* 0x22 dtg_cbcr_sync3        */

    0x13,               /* 0x23 dtg_y_sync_upper      */
    0x15,               /* 0x24 dtg_cbcr_sync_upper   */

    0x28,               /* 0x25 dtg_spec_a            */
    0x6E,               /* 0x26 dtg_spec_b            */
    0x28,               /* 0x27 dtg_spec_c            */

    0x04,               /* 0x28 dtg_spec_d            */
    0x00,               /* 0x29 dtg_spec_d1           */
    0x04,               /* 0x2A dtg_spec_e            */

    0xC0,               /* 0x2B dtg_spec_h_msb        */
    0x00,               /* 0x2C dtg_spec_h_lsb        */
    0x00,               /* 0x2D dtg_spec_i_msb        */
    0x00,               /* 0x2E dtg_spec_i_lsb        */

    0x6E,               /* 0x2F dtg_spec_k_lsb        */
    0x00,               /* 0x30 dtg_spec_k_msb        */
    0x00,               /* 0x31 dtg_spec_k1           */

    0x00,               /* 0x32 dtg_speg_g_lsb        */
    0x00,               /* 0x33 dtg_speg_g_msb        */

    0x06,               /* 0x34 dtg_total_pixel_msb   */
    0x72,               /* 0x35 dtg_total_pixel_lsb   */
    0x00,               /* 0x36 dtg_linecnt_msb       */
    0x01,               /* 0x37 dtg_linecnt_lsb       */

    0x82,               /* 0x38 dtg_mode              */

    0x27,               /* 0x39 dtg_frame_field_msb   */
    0xEE,               /* 0x3A dtg_frame_size_lsb    */
    0xFF,               /* 0x3B dtg_field_size_lsb    */
    0x80,               /* 0x3C dtg1_vesa_cbar_size don't care  */

    0x00,               /* 0x3D dac_cntl_msb          */

    0x00,               /* 0x4A csm_gy_cntl_mult_msb  */
    0x00,               /* 0x4F csm_rcr_bcb_cntl  */

    0x28,               /* 0x70 dtg2_hlength_lsb              */
    0x06,               /* 0x71 dtg2_hlength_lsb_hdly_msb     */
    0x71,               /* 0x72 dtg2_hdly_lsb                 */

    0x06,               /* 0x73 dtg2_vlength1_lsb             */
    0x00,               /* 0x74 dtg2_vlength1_msb_vdly1_msb   */
    0x01,               /* 0x75 dtg2_vdly1_lsb                */

    0x00,               /* 0x76 dtg2_vlength2_lsb             */
    0x07,               /* 0x77 dtg2_vlength2_msb_vdly2_msb   */
    0xFF,               /* 0x78 dtg2_vdly2_lsb                */

    0x00,               /* 0x79 dtg2_hs_in_dly_msb            */
    0xA2,               /* 0x7A dtg2_hs_in_dly_lsb            */

    0x00,               /* 0x7B dtg2_vs_in_dly_msb            */
    0x05,               /* 0x7C dtg2_vs_in_dly_lsb            */

    0x1B                /* 0x82 dtg2_cntl                     */
};

/** THS8200 Register settings for 720P 50Hz HDTV display */
const _THS8200_Regs ths8200_720p_50Hz_Regs =
{
    0x01,               /* 0x03 chip_cntl     */

    0x00,               /* 0x1A tst_cntl1     */
    0x00,               /* 0x1B tst_cntl2     */

    /* Display Timing Generator Control */
    0xFF,               /* 0x1D dtg_y_sync1           */
    0x49,               /* 0x1E dtg_y_sync2           */
    0xB6,               /* 0x1F dtg_y_sync3           */

    0xFF,               /* 0x20 dtg_cbcr_sync1        */
    0xFF,               /* 0x21 dtg_cbcr_sync2        */
    0xFF,               /* 0x22 dtg_cbcr_sync3        */

    0x13,               /* 0x23 dtg_y_sync_upper      */
    0x15,               /* 0x24 dtg_cbcr_sync_upper   */

    0x28,               /* 0x25 dtg_spec_a            */
    0xFF,               /* 0x26 dtg_spec_b            */
    0x28,               /* 0x27 dtg_spec_c            */

    0x04,               /* 0x28 dtg_spec_d            */
    0x00,               /* 0x29 dtg_spec_d1           */
    0x04,               /* 0x2A dtg_spec_e            */

    0xC0,               /* 0x2B dtg_spec_h_msb        */
    0x00,               /* 0x2C dtg_spec_h_lsb        */
    0x00,               /* 0x2D dtg_spec_i_msb        */
    0x00,               /* 0x2E dtg_spec_i_lsb        */

    0xB8,               /* 0x2F dtg_spec_k_lsb        */
    0x01,               /* 0x30 dtg_spec_k_msb        */
    0x00,               /* 0x31 dtg_spec_k1           */

    0x00,               /* 0x32 dtg_speg_g_lsb        */
    0x00,               /* 0x33 dtg_speg_g_msb        */

    0x07,               /* 0x34 dtg_total_pixel_msb   */
    0xBC,               /* 0x35 dtg_total_pixel_lsb   */
    0x80,               /* 0x36 dtg_linecnt_msb       */
    0x01,               /* 0x37 dtg_linecnt_lsb       */

    0x82,               /* 0x38 dtg_mode              */

    0x27,               /* 0x39 dtg_frame_field_msb   */
    0xEE,               /* 0x3A dtg_frame_size_lsb    */
    0xFF,               /* 0x3B dtg_field_size_lsb    */
    0x80,               /* 0x3C dtg1_vesa_cbar_size don't care  */

    0x00,               /* 0x3D dac_cntl_msb          */

    0x00,               /* 0x4A csm_gy_cntl_mult_msb */
    0x00,               /* 0x4F csm_rcr_bcb_cntl  */

    0x28,               /* 0x70 dtg2_hlength_lsb              */
    0x40,               /* 0x71 dtg2_hlength_lsb_hdly_msb     */
    0xFD,               /* 0x72 dtg2_hdly_lsb                 */

    0x1A,               /* 0x73 dtg2_vlength1_lsb             */
    0x02,               /* 0x74 dtg2_vlength1_msb_vdly1_msb   */
    0xEF,               /* 0x75 dtg2_vdly1_lsb                */

    0x00,               /* 0x76 dtg2_vlength2_lsb             */
    0x07,               /* 0x77 dtg2_vlength2_msb_vdly2_msb   */
    0xFF,               /* 0x78 dtg2_vdly2_lsb                */

    0x01,               /* 0x79 dtg2_hs_in_dly_msb            */
    0xD0,               /* 0x7A dtg2_hs_in_dly_lsb            */

    0x00,               /* 0x7B dtg2_vs_in_dly_msb            */
    0x20,               /* 0x7C dtg2_vs_in_dly_lsb            */

    0x1B                /* 0x82 dtg2_cntl                     */
};

/** THS8200 Register settings for 1080i 60Hz HDTV display */
const _THS8200_Regs ths8200_1080i_60Hz_Regs =
{
    0x01,               /* 0x03 chip_cntl     */

    0x00,               /* 0x1A tst_cntl1     */
    0x00,               /* 0x1B tst_cntl2     */

    /* Display Timing Generator Control */
    0xFF,               /* 0x1D dtg_y_sync1           */
    0x49,               /* 0x1E dtg_y_sync2           */
    0xB6,               /* 0x1F dtg_y_sync3           */

    0xFF,               /* 0x20 dtg_cbcr_sync1        */
    0xFF,               /* 0x21 dtg_cbcr_sync2        */
    0xFF,               /* 0x22 dtg_cbcr_sync3        */

    0x13,               /* 0x23 dtg_y_sync_upper      */
    0x15,               /* 0x24 dtg_cbcr_sync_upper   */

    0x2C,               /* 0x25 dtg_spec_a            */
    0x58,               /* 0x26 dtg_spec_b            */
    0x2C,               /* 0x27 dtg_spec_c            */

    0x84,               /* 0x28 dtg_spec_d            */
    0x00,               /* 0x29 dtg_spec_d1           */
    0xC0,               /* 0x2A dtg_spec_e            */

    0x00,               /* 0x2B dtg_spec_h_msb        */
    0x00,               /* 0x2C dtg_spec_h_lsb        */
    0x00,               /* 0x2D dtg_spec_i_msb        */
    0x00,               /* 0x2E dtg_spec_i_lsb        */

    0x58,               /* 0x2F dtg_spec_k_lsb        */
    0x00,               /* 0x30 dtg_spec_k_msb        */
    0x00,               /* 0x31 dtg_spec_k1           */

    0x58,               /* 0x32 dtg_speg_g_lsb        */
    0x00,               /* 0x33 dtg_speg_g_msb        */

    0x08,               /* 0x34 dtg_total_pixel_msb   */
    0x98,               /* 0x35 dtg_total_pixel_lsb   */
    0x00,               /* 0x36 dtg_linecnt_msb       */
    0x01,               /* 0x37 dtg_linecnt_lsb       */

    0x81,               /* 0x38 dtg_mode              */

    0x42,               /* 0x39 dtg_frame_field_msb   */
    0x65,               /* 0x3A dtg_frame_size_lsb    */
    0x33,               /* 0x3B dtg_field_size_lsb    */
    0x80,               /* 0x3C dtg1_vesa_cbar_size  don't care */

    0x00,               /* 0x3D dac_cntl_msb          */

    0x00,               /* 0x4A csm_gy_cntl_mult_msb  */
    0x00,               /* 0x4F csm_rcr_bcb_cntl  */

    0x18,               /* 0x70 dtg2_hlength_lsb              */
    0x48,               /* 0x71 dtg2_hlength_lsb_hdly_msb     */
    0x44,               /* 0x72 dtg2_hdly_lsb                 */

    0x17,               /* 0x73 dtg2_vlength1_lsb             */
    0x04,               /* 0x74 dtg2_vlength1_msb_vdly1_msb   */
    0x65,               /* 0x75 dtg2_vdly1_lsb                */

    0x18,               /* 0x76 dtg2_vlength2_lsb             */
    0x02,               /* 0x77 dtg2_vlength2_msb_vdly2_msb   */
    0x32,               /* 0x78 dtg2_vdly2_lsb                */

    0x00,               /* 0x79 dtg2_hs_in_dly_msb            */
    0x8A,               /* 0x7A dtg2_hs_in_dly_lsb            */

    0x00,               /* 0x7B dtg2_vs_in_dly_msb            */
    0x02,               /* 0x7C dtg2_vs_in_dly_lsb            */

    0x1F                /* 0x82 dtg2_cntl                     */
};

/** THS8200 Register settings for 1080i 50Hz HDTV display */
const _THS8200_Regs ths8200_1080i_50Hz_Regs =
{
    0x01,               /* 0x03 chip_cntl     */

    0x00,               /* 0x1A tst_cntl1     */
    0x00,               /* 0x1B tst_cntl2     */

    /* Display Timing Generator Control */
    0xFF,               /* 0x1D dtg_y_sync1           */
    0x49,               /* 0x1E dtg_y_sync2           */
    0xB6,               /* 0x1F dtg_y_sync3           */

    0xFF,               /* 0x20 dtg_cbcr_sync1        */
    0xFF,               /* 0x21 dtg_cbcr_sync2        */
    0xFF,               /* 0x22 dtg_cbcr_sync3        */

    0x13,               /* 0x23 dtg_y_sync_upper      */
    0x15,               /* 0x24 dtg_cbcr_sync_upper   */

    0x2C,               /* 0x25 dtg_spec_a            */
    0xFF,               /* 0x26 dtg_spec_b            */
    0x2C,               /* 0x27 dtg_spec_c            */

    0x84,               /* 0x28 dtg_spec_d            */
    0x00,               /* 0x29 dtg_spec_d1           */
    0xC0,               /* 0x2A dtg_spec_e            */

    0x00,               /* 0x2B dtg_spec_h_msb        */
    0x00,               /* 0x2C dtg_spec_h_lsb        */
    0x00,               /* 0x2D dtg_spec_i_msb        */
    0x00,               /* 0x2E dtg_spec_i_lsb        */

    0x34,               /* 0x2F dtg_spec_k_lsb        */
    0x01,               /* 0x30 dtg_spec_k_msb        */
    0x00,               /* 0x31 dtg_spec_k1           */

    0x58,               /* 0x32 dtg_speg_g_lsb        */
    0x00,               /* 0x33 dtg_speg_g_msb        */

    0x0A,               /* 0x34 dtg_total_pixel_msb   */
    0x50,               /* 0x35 dtg_total_pixel_lsb   */
    0x00,               /* 0x36 dtg_linecnt_msb       */
    0x01,               /* 0x37 dtg_linecnt_lsb       */

    0x81,               /* 0x38 dtg_mode              */

    0x42,               /* 0x39 dtg_frame_field_msb   */
    0x65,               /* 0x3A dtg_frame_size_lsb    */
    0x33,               /* 0x3B dtg_field_size_lsb    */
    0x80,               /* 0x3C dtg1_vesa_cbar_size don't care  */

    0x00,               /* 0x3D dac_cntl_msb          */

    0x00,               /* 0x4A csm_gy_cntl_mult_msb */
    0x00,               /* 0x4F csm_rcr_bcb_cntl  */

    0x18,               /* 0x70 dtg2_hlength_lsb              */
    0x48,               /* 0x71 dtg2_hlength_lsb_hdly_msb     */
    0x44,               /* 0x72 dtg2_hdly_lsb                 */

    0x17,               /* 0x73 dtg2_vlength1_lsb             */
    0x04,               /* 0x74 dtg2_vlength1_msb_vdly1_msb   */
    0x65,               /* 0x75 dtg2_vdly1_lsb                */

    0x18,               /* 0x76 dtg2_vlength2_lsb             */
    0x02,               /* 0x77 dtg2_vlength2_msb_vdly2_msb   */
    0x32,               /* 0x78 dtg2_vdly2_lsb                */

    0x02,               /* 0x79 dtg2_hs_in_dly_msb            */
    0x42,               /* 0x7A dtg2_hs_in_dly_lsb            */

    0x00,               /* 0x7B dtg2_vs_in_dly_msb            */
    0x01,               /* 0x7C dtg2_vs_in_dly_lsb            */

    0x1F                /* 0x82 dtg2_cntl                     */
};

/** THS8200 Register settings for VGA 60Hz VESA display */
const _THS8200_Regs ths8200_VGA_60Hz_Regs =
{
    0x11,               /* 0x03 chip_cntl     */

    0x00,               /* 0x1A tst_cntl1     */
    0x00,               /* 0x1B tst_cntl2     */

    /* Display Timing Generator Control */
    0x00,               /* 0x1D dtg_y_sync1      don't care   */
    0x00,               /* 0x1E dtg_y_sync2      don't care   */
    0x00,               /* 0x1F dtg_y_sync3      don't care   */

    0x00,               /* 0x20 dtg_cbcr_sync1   don't care   */
    0x00,               /* 0x21 dtg_cbcr_sync2   don't care   */
    0x00,               /* 0x22 dtg_cbcr_sync3   don't care   */

    0x23,               /* 0x23 dtg_y_sync_upper don't care   */
    0x23,               /* 0x24 dtg_cbcr_sync_upper don't care  */

    0x2C,               /* 0x25 dtg_spec_a       don't care   */
    0x58,               /* 0x26 dtg_spec_b       don't care   */
    0x2C,               /* 0x27 dtg_spec_c       don't care   */

    0x84,               /* 0x28 dtg_spec_d       don't care   */
    0x00,               /* 0x29 dtg_spec_d1      don't care   */
    0xC0,               /* 0x2A dtg_spec_e       don't care   */

    0x00,               /* 0x2B dtg_spec_h_msb   don't care   */
    0x00,               /* 0x2C dtg_spec_h_lsb   don't care   */
    0x00,               /* 0x2D dtg_spec_i_msb   don't care   */
    0x00,               /* 0x2E dtg_spec_i_lsb   don't care   */

    0x58,               /* 0x2F dtg_spec_k_lsb   don't care   */
    0x00,               /* 0x30 dtg_spec_k_msb   don't care   */
    0x00,               /* 0x31 dtg_spec_k1      don't care   */

    0x58,               /* 0x32 dtg_speg_g_lsb   don't care   */
    0x00,               /* 0x33 dtg_speg_g_msb   don't care   */

    0x03,               /* 0x34 dtg_total_pixel_msb   */
    0x20,               /* 0x35 dtg_total_pixel_lsb   */
    0x80,               /* 0x36 dtg_linecnt_msb       */
    0x02,               /* 0x37 dtg_linecnt_lsb       */

    0x87,               /* 0x38 dtg_mode              */

    0x22,               /* 0x39 dtg_frame_field_msb   */
    0x0D,               /* 0x3A dtg_frame_size_lsb    */
    0x0D,               /* 0x3B dtg_field_size_lsb    */
    0x80,               /* 0x3C dtg1_vesa_cbar_size   */

    0x00,               /* 0x3D dac_cntl_msb          */

    0x00,               /* 0x4A csm_gy_cntl_mult_msb */
    0x00,               /* 0x4F csm_rcr_bcb_cntl  */

    0x60,               /* 0x70 dtg2_hlength_lsb              */
    0x02,               /* 0x71 dtg2_hlength_lsb_hdly_msb     */
    0xF7,               /* 0x72 dtg2_hdly_lsb                 */

    0x03,               /* 0x73 dtg2_vlength1_lsb             */
    0x00,               /* 0x74 dtg2_vlength1_msb_vdly1_msb   */
    0x01,               /* 0x75 dtg2_vdly1_lsb                */

    0x00,               /* 0x76 dtg2_vlength2_lsb             */
    0x07,               /* 0x77 dtg2_vlength2_msb_vdly2_msb   */
    0xFF,               /* 0x78 dtg2_vdly2_lsb                */

    0x00,               /* 0x79 dtg2_hs_in_dly_msb            */
    0x3B,               /* 0x7A dtg2_hs_in_dly_lsb            */

    0x00,               /* 0x7B dtg2_vs_in_dly_msb            */
    0x00,               /* 0x7C dtg2_vs_in_dly_lsb            */

    0x43                /* 0x82 dtg2_cntl                     */
};

/** THS8200 Register settings for VGA 72Hz VESA display */
const _THS8200_Regs ths8200_VGA_72Hz_Regs =
{
    0x11,               /* 0x03 chip_cntl     */

    0x00,               /* 0x1A tst_cntl1     */
    0x00,               /* 0x1B tst_cntl2     */

    /* Display Timing Generator Control */
    0x00,               /* 0x1D dtg_y_sync1      don't care   */
    0x00,               /* 0x1E dtg_y_sync2      don't care   */
    0x00,               /* 0x1F dtg_y_sync3      don't care   */

    0x00,               /* 0x20 dtg_cbcr_sync1   don't care   */
    0x00,               /* 0x21 dtg_cbcr_sync2   don't care   */
    0x00,               /* 0x22 dtg_cbcr_sync3   don't care   */

    0x23,               /* 0x23 dtg_y_sync_upper don't care   */
    0x23,               /* 0x24 dtg_cbcr_sync_upper don't care  */

    0x2C,               /* 0x25 dtg_spec_a       don't care   */
    0x58,               /* 0x26 dtg_spec_b       don't care   */
    0x2C,               /* 0x27 dtg_spec_c       don't care   */

    0x84,               /* 0x28 dtg_spec_d       don't care   */
    0x00,               /* 0x29 dtg_spec_d1      don't care   */
    0xC0,               /* 0x2A dtg_spec_e       don't care   */

    0x00,               /* 0x2B dtg_spec_h_msb   don't care   */
    0x00,               /* 0x2C dtg_spec_h_lsb   don't care   */
    0x00,               /* 0x2D dtg_spec_i_msb   don't care   */
    0x00,               /* 0x2E dtg_spec_i_lsb   don't care   */

    0x58,               /* 0x2F dtg_spec_k_lsb   don't care   */
    0x00,               /* 0x30 dtg_spec_k_msb   don't care   */
    0x00,               /* 0x31 dtg_spec_k1      don't care   */

    0x58,               /* 0x32 dtg_speg_g_lsb   don't care   */
    0x00,               /* 0x33 dtg_speg_g_msb   don't care   */

    0x03,               /* 0x34 dtg_total_pixel_msb   */
    0x40,               /* 0x35 dtg_total_pixel_lsb   */
    0x80,               /* 0x36 dtg_linecnt_msb       */
    0x02,               /* 0x37 dtg_linecnt_lsb       */

    0x87,               /* 0x38 dtg_mode              */

    0x22,               /* 0x39 dtg_frame_field_msb   */
    0x08,               /* 0x3A dtg_frame_size_lsb    */
    0x08,               /* 0x3B dtg_field_size_lsb    */
    0x80,               /* 0x3C dtg1_vesa_cbar_size   */

    0x00,               /* 0x3D dac_cntl_msb          */

    0x00,               /* 0x4A csm_gy_cntl_mult_msb */
    0x00,               /* 0x4F csm_rcr_bcb_cntl  */

    0x28,               /* 0x70 dtg2_hlength_lsb              */
    0x03,               /* 0x71 dtg2_hlength_lsb_hdly_msb     */
    0x17,               /* 0x72 dtg2_hdly_lsb                 */

    0x04,               /* 0x73 dtg2_vlength1_lsb             */
    0x00,               /* 0x74 dtg2_vlength1_msb_vdly1_msb   */
    0x01,               /* 0x75 dtg2_vdly1_lsb                */

    0x00,               /* 0x76 dtg2_vlength2_lsb             */
    0x07,               /* 0x77 dtg2_vlength2_msb_vdly2_msb   */
    0xFF,               /* 0x78 dtg2_vdly2_lsb                */

    0x00,               /* 0x79 dtg2_hs_in_dly_msb            */
    0x43,               /* 0x7A dtg2_hs_in_dly_lsb            */

    0x00,               /* 0x7B dtg2_vs_in_dly_msb            */
    0x00,               /* 0x7C dtg2_vs_in_dly_lsb            */

    0x43                /* 0x82 dtg2_cntl                     */
};

/** THS8200 Register settings for VGA 75Hz VESA display */
const _THS8200_Regs ths8200_VGA_75Hz_Regs =
{
    0x11,               /* 0x03 chip_cntl     */

    0x00,               /* 0x1A tst_cntl1     */
    0x00,               /* 0x1B tst_cntl2     */

    /* Display Timing Generator Control */
    0x00,               /* 0x1D dtg_y_sync1      don't care   */
    0x00,               /* 0x1E dtg_y_sync2      don't care   */
    0x00,               /* 0x1F dtg_y_sync3      don't care   */

    0x00,               /* 0x20 dtg_cbcr_sync1   don't care   */
    0x00,               /* 0x21 dtg_cbcr_sync2   don't care   */
    0x00,               /* 0x22 dtg_cbcr_sync3   don't care   */

    0x23,               /* 0x23 dtg_y_sync_upper don't care   */
    0x23,               /* 0x24 dtg_cbcr_sync_upper don't care  */

    0x2C,               /* 0x25 dtg_spec_a       don't care   */
    0x58,               /* 0x26 dtg_spec_b       don't care   */
    0x2C,               /* 0x27 dtg_spec_c       don't care   */

    0x84,               /* 0x28 dtg_spec_d       don't care   */
    0x00,               /* 0x29 dtg_spec_d1      don't care   */
    0xC0,               /* 0x2A dtg_spec_e       don't care   */

    0x00,               /* 0x2B dtg_spec_h_msb   don't care   */
    0x00,               /* 0x2C dtg_spec_h_lsb   don't care   */
    0x00,               /* 0x2D dtg_spec_i_msb   don't care   */
    0x00,               /* 0x2E dtg_spec_i_lsb   don't care   */

    0x58,               /* 0x2F dtg_spec_k_lsb   don't care   */
    0x00,               /* 0x30 dtg_spec_k_msb   don't care   */
    0x00,               /* 0x31 dtg_spec_k1      don't care   */

    0x58,               /* 0x32 dtg_speg_g_lsb   don't care   */
    0x00,               /* 0x33 dtg_speg_g_msb   don't care   */

    0x03,               /* 0x34 dtg_total_pixel_msb   */
    0x48,               /* 0x35 dtg_total_pixel_lsb   */
    0x80,               /* 0x36 dtg_linecnt_msb       */
    0x02,               /* 0x37 dtg_linecnt_lsb       */

    0x87,               /* 0x38 dtg_mode              */

    0x11,               /* 0x39 dtg_frame_field_msb   */
    0xF4,               /* 0x3A dtg_frame_size_lsb    */
    0xF4,               /* 0x3B dtg_field_size_lsb    */
    0x80,               /* 0x3C dtg1_vesa_cbar_size   */

    0x00,               /* 0x3D dac_cntl_msb          */

    0x00,               /* 0x4A csm_gy_cntl_mult_msb */
    0x00,               /* 0x4F csm_rcr_bcb_cntl  */

    0x40,               /* 0x70 dtg2_hlength_lsb              */
    0x03,               /* 0x71 dtg2_hlength_lsb_hdly_msb     */
    0x31,               /* 0x72 dtg2_hdly_lsb                 */

    0x04,               /* 0x73 dtg2_vlength1_lsb             */
    0x01,               /* 0x74 dtg2_vlength1_msb_vdly1_msb   */
    0xEC,               /* 0x75 dtg2_vdly1_lsb                */

    0x00,               /* 0x76 dtg2_vlength2_lsb             */
    0x07,               /* 0x77 dtg2_vlength2_msb_vdly2_msb   */
    0xFF,               /* 0x78 dtg2_vdly2_lsb                */

    0x00,               /* 0x79 dtg2_hs_in_dly_msb            */
    0x29,               /* 0x7A dtg2_hs_in_dly_lsb            */

    0x00,               /* 0x7B dtg2_vs_in_dly_msb            */
    0x00,               /* 0x7C dtg2_vs_in_dly_lsb            */

    0x43                /* 0x82 dtg2_cntl                     */
};

/** THS8200 Register settings for VGA 85Hz VESA display */
const _THS8200_Regs ths8200_VGA_85Hz_Regs =
{
    0x11,               /* 0x03 chip_cntl     */

    0x00,               /* 0x1A tst_cntl1     */
    0x00,               /* 0x1B tst_cntl2     */

    /* Display Timing Generator Control */
    0x00,               /* 0x1D dtg_y_sync1      don't care   */
    0x00,               /* 0x1E dtg_y_sync2      don't care   */
    0x00,               /* 0x1F dtg_y_sync3      don't care   */

    0x00,               /* 0x20 dtg_cbcr_sync1   don't care   */
    0x00,               /* 0x21 dtg_cbcr_sync2   don't care   */
    0x00,               /* 0x22 dtg_cbcr_sync3   don't care   */

    0x23,               /* 0x23 dtg_y_sync_upper don't care   */
    0x23,               /* 0x24 dtg_cbcr_sync_upper don't care  */

    0x2C,               /* 0x25 dtg_spec_a       don't care   */
    0x58,               /* 0x26 dtg_spec_b       don't care   */
    0x2C,               /* 0x27 dtg_spec_c       don't care   */

    0x84,               /* 0x28 dtg_spec_d       don't care   */
    0x00,               /* 0x29 dtg_spec_d1      don't care   */
    0xC0,               /* 0x2A dtg_spec_e       don't care   */

    0x00,               /* 0x2B dtg_spec_h_msb   don't care   */
    0x00,               /* 0x2C dtg_spec_h_lsb   don't care   */
    0x00,               /* 0x2D dtg_spec_i_msb   don't care   */
    0x00,               /* 0x2E dtg_spec_i_lsb   don't care   */

    0x58,               /* 0x2F dtg_spec_k_lsb   don't care   */
    0x00,               /* 0x30 dtg_spec_k_msb   don't care   */
    0x00,               /* 0x31 dtg_spec_k1      don't care   */

    0x58,               /* 0x32 dtg_speg_g_lsb   don't care   */
    0x00,               /* 0x33 dtg_speg_g_msb   don't care   */

    0x03,               /* 0x34 dtg_total_pixel_msb   */
    0x48,               /* 0x35 dtg_total_pixel_lsb   */
    0x80,               /* 0x36 dtg_linecnt_msb       */
    0x02,               /* 0x37 dtg_linecnt_lsb       */

    0x87,               /* 0x38 dtg_mode              */

    0x11,               /* 0x39 dtg_frame_field_msb   */
    0xFD,               /* 0x3A dtg_frame_size_lsb    */
    0xFD,               /* 0x3B dtg_field_size_lsb    */
    0x80,               /* 0x3C dtg1_vesa_cbar_size   */

    0x00,               /* 0x3D dac_cntl_msb          */

    0x00,               /* 0x4A csm_gy_cntl_mult_msb */
    0x00,               /* 0x4F csm_rcr_bcb_cntl  */

    0x40,               /* 0x70 dtg2_hlength_lsb              */
    0x03,               /* 0x71 dtg2_hlength_lsb_hdly_msb     */
    0x45,               /* 0x72 dtg2_hdly_lsb                 */

    0x04,               /* 0x73 dtg2_vlength1_lsb             */
    0x01,               /* 0x74 dtg2_vlength1_msb_vdly1_msb   */
    0xF5,               /* 0x75 dtg2_vdly1_lsb                */

    0x00,               /* 0x76 dtg2_vlength2_lsb             */
    0x07,               /* 0x77 dtg2_vlength2_msb_vdly2_msb   */
    0xFF,               /* 0x78 dtg2_vdly2_lsb                */

    0x00,               /* 0x79 dtg2_hs_in_dly_msb            */
    0x44,               /* 0x7A dtg2_hs_in_dly_lsb            */

    0x00,               /* 0x7B dtg2_vs_in_dly_msb            */
    0x00,               /* 0x7C dtg2_vs_in_dly_lsb            */

    0x43                /* 0x82 dtg2_cntl                     */
};

/** THS8200 Register settings for SVGA 60Hz VESA display */
const _THS8200_Regs ths8200_SVGA_60Hz_Regs =
{
    0x11,               /* 0x03 chip_cntl     */

    0x00,               /* 0x1A tst_cntl1     */
    0x00,               /* 0x1B tst_cntl2     */

    /* Display Timing Generator Control */
    0x00,               /* 0x1D dtg_y_sync1      don't care   */
    0x00,               /* 0x1E dtg_y_sync2      don't care   */
    0x00,               /* 0x1F dtg_y_sync3      don't care   */

    0x00,               /* 0x20 dtg_cbcr_sync1   don't care   */
    0x00,               /* 0x21 dtg_cbcr_sync2   don't care   */
    0x00,               /* 0x22 dtg_cbcr_sync3   don't care   */

    0x23,               /* 0x23 dtg_y_sync_upper don't care   */
    0x23,               /* 0x24 dtg_cbcr_sync_upper don't care  */

    0x2C,               /* 0x25 dtg_spec_a       don't care   */
    0x58,               /* 0x26 dtg_spec_b       don't care   */
    0x2C,               /* 0x27 dtg_spec_c       don't care   */

    0x84,               /* 0x28 dtg_spec_d       don't care   */
    0x00,               /* 0x29 dtg_spec_d1      don't care   */
    0xC0,               /* 0x2A dtg_spec_e       don't care   */

    0x00,               /* 0x2B dtg_spec_h_msb   don't care   */
    0x00,               /* 0x2C dtg_spec_h_lsb   don't care   */
    0x00,               /* 0x2D dtg_spec_i_msb   don't care   */
    0x00,               /* 0x2E dtg_spec_i_lsb   don't care   */

    0x58,               /* 0x2F dtg_spec_k_lsb   don't care   */
    0x00,               /* 0x30 dtg_spec_k_msb   don't care   */
    0x00,               /* 0x31 dtg_spec_k1      don't care   */

    0x58,               /* 0x32 dtg_speg_g_lsb   don't care   */
    0x00,               /* 0x33 dtg_speg_g_msb   don't care   */

    0x04,               /* 0x34 dtg_total_pixel_msb   */
    0x20,               /* 0x35 dtg_total_pixel_lsb   */
    0x80,               /* 0x36 dtg_linecnt_msb       */
    0x02,               /* 0x37 dtg_linecnt_lsb       */

    0x87,               /* 0x38 dtg_mode              */

    0x22,               /* 0x39 dtg_frame_field_msb   */
    0x74,               /* 0x3A dtg_frame_size_lsb    */
    0x74,               /* 0x3B dtg_field_size_lsb    */
    0x80,               /* 0x3C dtg1_vesa_cbar_size   */

    0x00,               /* 0x3D dac_cntl_msb          */

    0x00,               /* 0x4A csm_gy_cntl_mult_msb  */
    0x00,               /* 0x4F csm_rcr_bcb_cntl  */

    0x80,               /* 0x70 dtg2_hlength_lsb              */
    0x03,               /* 0x71 dtg2_hlength_lsb_hdly_msb     */
    0xF7,               /* 0x72 dtg2_hdly_lsb                 */

    0x05,               /* 0x73 dtg2_vlength1_lsb             */
    0x00,               /* 0x74 dtg2_vlength1_msb_vdly1_msb   */
    0x01,               /* 0x75 dtg2_vdly1_lsb                */

    0x00,               /* 0x76 dtg2_vlength2_lsb             */
    0x07,               /* 0x77 dtg2_vlength2_msb_vdly2_msb   */
    0xFF,               /* 0x78 dtg2_vdly2_lsb                */

    0x00,               /* 0x79 dtg2_hs_in_dly_msb            */
    0x3B,               /* 0x7A dtg2_hs_in_dly_lsb            */

    0x00,               /* 0x7B dtg2_vs_in_dly_msb            */
    0x00,               /* 0x7C dtg2_vs_in_dly_lsb            */

    0x5B                /* 0x82 dtg2_cntl                     */
};

/** THS8200 Register settings for SVGA 72Hz VESA display */
const _THS8200_Regs ths8200_SVGA_72Hz_Regs =
{
    0x11,               /* 0x03 chip_cntl     */

    0x00,               /* 0x1A tst_cntl1     */
    0x00,               /* 0x1B tst_cntl2     */

    /* Display Timing Generator Control */
    0x00,               /* 0x1D dtg_y_sync1      don't care   */
    0x00,               /* 0x1E dtg_y_sync2      don't care   */
    0x00,               /* 0x1F dtg_y_sync3      don't care   */

    0x00,               /* 0x20 dtg_cbcr_sync1   don't care   */
    0x00,               /* 0x21 dtg_cbcr_sync2   don't care   */
    0x00,               /* 0x22 dtg_cbcr_sync3   don't care   */

    0x23,               /* 0x23 dtg_y_sync_upper don't care   */
    0x23,               /* 0x24 dtg_cbcr_sync_upper don't care  */

    0x2C,               /* 0x25 dtg_spec_a       don't care   */
    0x58,               /* 0x26 dtg_spec_b       don't care   */
    0x2C,               /* 0x27 dtg_spec_c       don't care   */

    0x84,               /* 0x28 dtg_spec_d       don't care   */
    0x00,               /* 0x29 dtg_spec_d1      don't care   */
    0xC0,               /* 0x2A dtg_spec_e       don't care   */

    0x00,               /* 0x2B dtg_spec_h_msb   don't care   */
    0x00,               /* 0x2C dtg_spec_h_lsb   don't care   */
    0x00,               /* 0x2D dtg_spec_i_msb   don't care   */
    0x00,               /* 0x2E dtg_spec_i_lsb   don't care   */

    0x58,               /* 0x2F dtg_spec_k_lsb   don't care   */
    0x00,               /* 0x30 dtg_spec_k_msb   don't care   */
    0x00,               /* 0x31 dtg_spec_k1      don't care   */

    0x58,               /* 0x32 dtg_speg_g_lsb   don't care   */
    0x00,               /* 0x33 dtg_speg_g_msb   don't care   */

    0x04,               /* 0x34 dtg_total_pixel_msb   */
    0x10,               /* 0x35 dtg_total_pixel_lsb   */
    0x80,               /* 0x36 dtg_linecnt_msb       */
    0x02,               /* 0x37 dtg_linecnt_lsb       */

    0x87,               /* 0x38 dtg_mode              */

    0x22,               /* 0x39 dtg_frame_field_msb   */
    0x9A,               /* 0x3A dtg_frame_size_lsb    */
    0x9A,               /* 0x3B dtg_field_size_lsb    */
    0x80,               /* 0x3C dtg1_vesa_cbar_size   */

    0x00,               /* 0x3D dac_cntl_msb          */

    0x00,               /* 0x4A csm_gy_cntl_mult_msb  */
    0x00,               /* 0x4F csm_rcr_bcb_cntl  */

    0x78,               /* 0x70 dtg2_hlength_lsb              */
    0x04,               /* 0x71 dtg2_hlength_lsb_hdly_msb     */
    0x09,               /* 0x72 dtg2_hdly_lsb                 */

    0x07,               /* 0x73 dtg2_vlength1_lsb             */
    0x00,               /* 0x74 dtg2_vlength1_msb_vdly1_msb   */
    0x26,               /* 0x75 dtg2_vdly1_lsb                */

    0x00,               /* 0x76 dtg2_vlength2_lsb             */
    0x07,               /* 0x77 dtg2_vlength2_msb_vdly2_msb   */
    0xFF,               /* 0x78 dtg2_vdly2_lsb                */

    0x00,               /* 0x79 dtg2_hs_in_dly_msb            */
    0x29,               /* 0x7A dtg2_hs_in_dly_lsb            */

    0x00,               /* 0x7B dtg2_vs_in_dly_msb            */
    0x00,               /* 0x7C dtg2_vs_in_dly_lsb            */

    0x5B                /* 0x82 dtg2_cntl                     */
};

/** THS8200 Register settings for SVGA 75Hz VESA display */
const _THS8200_Regs ths8200_SVGA_75Hz_Regs =
{
    0x01,               /* 0x03 chip_cntl     */

    0x00,               /* 0x1A tst_cntl1     */
    0x00,               /* 0x1B tst_cntl2     */

    /* Display Timing Generator Control */
    0x00,               /* 0x1D dtg_y_sync1      don't care   */
    0x00,               /* 0x1E dtg_y_sync2      don't care   */
    0x00,               /* 0x1F dtg_y_sync3      don't care   */

    0x00,               /* 0x20 dtg_cbcr_sync1   don't care   */
    0x00,               /* 0x21 dtg_cbcr_sync2   don't care   */
    0x00,               /* 0x22 dtg_cbcr_sync3   don't care   */

    0x23,               /* 0x23 dtg_y_sync_upper don't care   */
    0x23,               /* 0x24 dtg_cbcr_sync_upper don't care  */

    0x2C,               /* 0x25 dtg_spec_a       don't care   */
    0x58,               /* 0x26 dtg_spec_b       don't care   */
    0x2C,               /* 0x27 dtg_spec_c       don't care   */

    0x84,               /* 0x28 dtg_spec_d       don't care   */
    0x00,               /* 0x29 dtg_spec_d1      don't care   */
    0xC0,               /* 0x2A dtg_spec_e       don't care   */

    0x00,               /* 0x2B dtg_spec_h_msb   don't care   */
    0x00,               /* 0x2C dtg_spec_h_lsb   don't care   */
    0x00,               /* 0x2D dtg_spec_i_msb   don't care   */
    0x00,               /* 0x2E dtg_spec_i_lsb   don't care   */

    0x58,               /* 0x2F dtg_spec_k_lsb   don't care   */
    0x00,               /* 0x30 dtg_spec_k_msb   don't care   */
    0x00,               /* 0x31 dtg_spec_k1      don't care   */

    0x58,               /* 0x32 dtg_speg_g_lsb   don't care   */
    0x00,               /* 0x33 dtg_speg_g_msb   don't care   */

    0x04,               /* 0x34 dtg_total_pixel_msb   */
    0x20,               /* 0x35 dtg_total_pixel_lsb   */
    0x80,               /* 0x36 dtg_linecnt_msb       */
    0x02,               /* 0x37 dtg_linecnt_lsb       */

    0x87,               /* 0x38 dtg_mode              */

    0x22,               /* 0x39 dtg_frame_field_msb   */
    0x71,               /* 0x3A dtg_frame_size_lsb    */
    0x71,               /* 0x3B dtg_field_size_lsb    */
    0x80,               /* 0x3C dtg1_vesa_cbar_size   */

    0x00,               /* 0x3D dac_cntl_msb          */

    0x00,               /* 0x4A csm_gy_cntl_mult_msb  */
    0x00,               /* 0x4F csm_rcr_bcb_cntl  */

    0x50,               /* 0x70 dtg2_hlength_lsb              */
    0x03,               /* 0x71 dtg2_hlength_lsb_hdly_msb     */
    0xF7,               /* 0x72 dtg2_hdly_lsb                 */

    0x04,               /* 0x73 dtg2_vlength1_lsb             */
    0x00,               /* 0x74 dtg2_vlength1_msb_vdly1_msb   */
    0x01,               /* 0x75 dtg2_vdly1_lsb                */

    0x00,               /* 0x76 dtg2_vlength2_lsb             */
    0x07,               /* 0x77 dtg2_vlength2_msb_vdly2_msb   */
    0xFF,               /* 0x78 dtg2_vdly2_lsb                */

    0x00,               /* 0x79 dtg2_hs_in_dly_msb            */
    0x23,               /* 0x7A dtg2_hs_in_dly_lsb            */

    0x00,               /* 0x7B dtg2_vs_in_dly_msb            */
    0x00,               /* 0x7C dtg2_vs_in_dly_lsb            */

    0x5B                /* 0x82 dtg2_cntl                     */
};

/** THS8200 Register settings for SVGA 85Hz VESA display */
const _THS8200_Regs ths8200_SVGA_85Hz_Regs =
{
    0x11,               /* 0x03 chip_cntl     */

    0x00,               /* 0x1A tst_cntl1     */
    0x00,               /* 0x1B tst_cntl2     */

    /* Display Timing Generator Control */
    0x00,               /* 0x1D dtg_y_sync1      don't care   */
    0x00,               /* 0x1E dtg_y_sync2      don't care   */
    0x00,               /* 0x1F dtg_y_sync3      don't care   */

    0x00,               /* 0x20 dtg_cbcr_sync1   don't care   */
    0x00,               /* 0x21 dtg_cbcr_sync2   don't care   */
    0x00,               /* 0x22 dtg_cbcr_sync3   don't care   */

    0x23,               /* 0x23 dtg_y_sync_upper don't care   */
    0x23,               /* 0x24 dtg_cbcr_sync_upper don't care  */

    0x2C,               /* 0x25 dtg_spec_a       don't care   */
    0x58,               /* 0x26 dtg_spec_b       don't care   */
    0x2C,               /* 0x27 dtg_spec_c       don't care   */

    0x84,               /* 0x28 dtg_spec_d       don't care   */
    0x00,               /* 0x29 dtg_spec_d1      don't care   */
    0xC0,               /* 0x2A dtg_spec_e       don't care   */

    0x00,               /* 0x2B dtg_spec_h_msb   don't care   */
    0x00,               /* 0x2C dtg_spec_h_lsb   don't care   */
    0x00,               /* 0x2D dtg_spec_i_msb   don't care   */
    0x00,               /* 0x2E dtg_spec_i_lsb   don't care   */

    0x58,               /* 0x2F dtg_spec_k_lsb   don't care   */
    0x00,               /* 0x30 dtg_spec_k_msb   don't care   */
    0x00,               /* 0x31 dtg_spec_k1      don't care   */

    0x58,               /* 0x32 dtg_speg_g_lsb   don't care   */
    0x00,               /* 0x33 dtg_speg_g_msb   don't care   */

    0x04,               /* 0x34 dtg_total_pixel_msb   */
    0x18,               /* 0x35 dtg_total_pixel_lsb   */
    0x80,               /* 0x36 dtg_linecnt_msb       */
    0x02,               /* 0x37 dtg_linecnt_lsb       */

    0x87,               /* 0x38 dtg_mode              */

    0x22,               /* 0x39 dtg_frame_field_msb   */
    0x77,               /* 0x3A dtg_frame_size_lsb    */
    0x77,               /* 0x3B dtg_field_size_lsb    */
    0x80,               /* 0x3C dtg1_vesa_cbar_size   */

    0x00,               /* 0x3D dac_cntl_msb          */

    0x00,               /* 0x4A csm_gy_cntl_mult_msb  */
    0x00,               /* 0x4F csm_rcr_bcb_cntl  */

    0x40,               /* 0x70 dtg2_hlength_lsb              */
    0x03,               /* 0x71 dtg2_hlength_lsb_hdly_msb     */
    0xEF,               /* 0x72 dtg2_hdly_lsb                 */

    0x04,               /* 0x73 dtg2_vlength1_lsb             */
    0x00,               /* 0x74 dtg2_vlength1_msb_vdly1_msb   */
    0x01,               /* 0x75 dtg2_vdly1_lsb                */

    0x00,               /* 0x76 dtg2_vlength2_lsb             */
    0x07,               /* 0x77 dtg2_vlength2_msb_vdly2_msb   */
    0xFF,               /* 0x78 dtg2_vdly2_lsb                */

    0x00,               /* 0x79 dtg2_hs_in_dly_msb            */
    0x33,               /* 0x7A dtg2_hs_in_dly_lsb            */

    0x00,               /* 0x7B dtg2_vs_in_dly_msb            */
    0x00,               /* 0x7C dtg2_vs_in_dly_lsb            */

    0x5B                /* 0x82 dtg2_cntl                     */
};

/** THS8200 Register settings for XGA 60Hz VESA display */
const _THS8200_Regs ths8200_XGA_60Hz_Regs =
{
    0x01,               /* 0x03 chip_cntl     */

    0x00,               /* 0x1A tst_cntl1     */
    0x00,               /* 0x1B tst_cntl2     */

    /* Display Timing Generator Control */
    0x00,               /* 0x1D dtg_y_sync1      don't care   */
    0x00,               /* 0x1E dtg_y_sync2      don't care   */
    0x00,               /* 0x1F dtg_y_sync3      don't care   */

    0x00,               /* 0x20 dtg_cbcr_sync1   don't care   */
    0x00,               /* 0x21 dtg_cbcr_sync2   don't care   */
    0x00,               /* 0x22 dtg_cbcr_sync3   don't care   */

    0x23,               /* 0x23 dtg_y_sync_upper don't care   */
    0x23,               /* 0x24 dtg_cbcr_sync_upper don't care  */

    0x2C,               /* 0x25 dtg_spec_a       don't care   */
    0x58,               /* 0x26 dtg_spec_b       don't care   */
    0x2C,               /* 0x27 dtg_spec_c       don't care   */

    0x84,               /* 0x28 dtg_spec_d       don't care   */
    0x00,               /* 0x29 dtg_spec_d1      don't care   */
    0xC0,               /* 0x2A dtg_spec_e       don't care   */

    0x00,               /* 0x2B dtg_spec_h_msb   don't care   */
    0x00,               /* 0x2C dtg_spec_h_lsb   don't care   */
    0x00,               /* 0x2D dtg_spec_i_msb   don't care   */
    0x00,               /* 0x2E dtg_spec_i_lsb   don't care   */

    0x58,               /* 0x2F dtg_spec_k_lsb   don't care   */
    0x00,               /* 0x30 dtg_spec_k_msb   don't care   */
    0x00,               /* 0x31 dtg_spec_k1      don't care   */

    0x58,               /* 0x32 dtg_speg_g_lsb   don't care   */
    0x00,               /* 0x33 dtg_speg_g_msb   don't care   */

    0x05,               /* 0x34 dtg_total_pixel_msb   */
    0x40,               /* 0x35 dtg_total_pixel_lsb   */
    0x80,               /* 0x36 dtg_linecnt_msb       */
    0x02,               /* 0x37 dtg_linecnt_lsb       */

    0x87,               /* 0x38 dtg_mode              */

    0x33,               /* 0x39 dtg_frame_field_msb   */
    0x26,               /* 0x3A dtg_frame_size_lsb    */
    0x26,               /* 0x3B dtg_field_size_lsb    */
    0x80,               /* 0x3C dtg1_vesa_cbar_size   */

    0x00,               /* 0x3D dac_cntl_msb          */

    0x00,               /* 0x4A csm_gy_cntl_mult_msb */
    0x00,               /* 0x4F csm_rcr_bcb_cntl  */

    0x88,               /* 0x70 dtg2_hlength_lsb              */
    0x04,               /* 0x71 dtg2_hlength_lsb_hdly_msb     */
    0xA2,               /* 0x72 dtg2_hdly_lsb                 */

    0x07,               /* 0x73 dtg2_vlength1_lsb             */
    0x03,               /* 0x74 dtg2_vlength1_msb_vdly1_msb   */
    0x22,               /* 0x75 dtg2_vdly1_lsb                */

    0x00,               /* 0x76 dtg2_vlength2_lsb             */
    0x07,               /* 0x77 dtg2_vlength2_msb_vdly2_msb   */
    0xFF,               /* 0x78 dtg2_vdly2_lsb                */

    0x00,               /* 0x79 dtg2_hs_in_dly_msb            */
    0x29,               /* 0x7A dtg2_hs_in_dly_lsb            */

    0x00,               /* 0x7B dtg2_vs_in_dly_msb            */
    0x00,               /* 0x7C dtg2_vs_in_dly_lsb            */

    0x40                /* 0x82 dtg2_cntl                     */
};

/** THS8200 Register settings for XGA 70Hz VESA display */
const _THS8200_Regs ths8200_XGA_70Hz_Regs =
{
    0x01,               /* 0x03 chip_cntl     */

    0x00,               /* 0x1A tst_cntl1     */
    0x00,               /* 0x1B tst_cntl2     */

    /* Display Timing Generator Control */
    0x00,               /* 0x1D dtg_y_sync1      don't care   */
    0x00,               /* 0x1E dtg_y_sync2      don't care   */
    0x00,               /* 0x1F dtg_y_sync3      don't care   */

    0x00,               /* 0x20 dtg_cbcr_sync1   don't care   */
    0x00,               /* 0x21 dtg_cbcr_sync2   don't care   */
    0x00,               /* 0x22 dtg_cbcr_sync3   don't care   */

    0x23,               /* 0x23 dtg_y_sync_upper don't care   */
    0x23,               /* 0x24 dtg_cbcr_sync_upper don't care  */

    0x2C,               /* 0x25 dtg_spec_a       don't care   */
    0x58,               /* 0x26 dtg_spec_b       don't care   */
    0x2C,               /* 0x27 dtg_spec_c       don't care   */

    0x84,               /* 0x28 dtg_spec_d       don't care   */
    0x00,               /* 0x29 dtg_spec_d1      don't care   */
    0xC0,               /* 0x2A dtg_spec_e       don't care   */

    0x00,               /* 0x2B dtg_spec_h_msb   don't care   */
    0x00,               /* 0x2C dtg_spec_h_lsb   don't care   */
    0x00,               /* 0x2D dtg_spec_i_msb   don't care   */
    0x00,               /* 0x2E dtg_spec_i_lsb   don't care   */

    0x58,               /* 0x2F dtg_spec_k_lsb   don't care   */
    0x00,               /* 0x30 dtg_spec_k_msb   don't care   */
    0x00,               /* 0x31 dtg_spec_k1      don't care   */

    0x58,               /* 0x32 dtg_speg_g_lsb   don't care   */
    0x00,               /* 0x33 dtg_speg_g_msb   don't care   */

    0x05,               /* 0x34 dtg_total_pixel_msb   */
    0x30,               /* 0x35 dtg_total_pixel_lsb   */
    0x80,               /* 0x36 dtg_linecnt_msb       */
    0x02,               /* 0x37 dtg_linecnt_lsb       */

    0x87,               /* 0x38 dtg_mode              */

    0x33,               /* 0x39 dtg_frame_field_msb   */
    0x26,               /* 0x3A dtg_frame_size_lsb    */
    0x26,               /* 0x3B dtg_field_size_lsb    */
    0x80,               /* 0x3C dtg1_vesa_cbar_size   */

    0x00,               /* 0x3D dac_cntl_msb          */

    0x00,               /* 0x4A csm_gy_cntl_mult_msb */
    0x00,               /* 0x4F csm_rcr_bcb_cntl  */

    0x88,               /* 0x70 dtg2_hlength_lsb              */
    0x04,               /* 0x71 dtg2_hlength_lsb_hdly_msb     */
    0x91,               /* 0x72 dtg2_hdly_lsb                 */

    0x07,               /* 0x73 dtg2_vlength1_lsb             */
    0x03,               /* 0x74 dtg2_vlength1_msb_vdly1_msb   */
    0x21,               /* 0x75 dtg2_vdly1_lsb                */

    0x00,               /* 0x76 dtg2_vlength2_lsb             */
    0x07,               /* 0x77 dtg2_vlength2_msb_vdly2_msb   */
    0xFF,               /* 0x78 dtg2_vdly2_lsb                */

    0x00,               /* 0x79 dtg2_hs_in_dly_msb            */
    0x29,               /* 0x7A dtg2_hs_in_dly_lsb            */

    0x00,               /* 0x7B dtg2_vs_in_dly_msb            */
    0x00,               /* 0x7C dtg2_vs_in_dly_lsb            */

    0x40                /* 0x82 dtg2_cntl                     */
};

/** THS8200 Register settings for SXGA 60Hz VESA display */
const _THS8200_Regs ths8200_SXGA_60Hz_Regs =
{
    0x81,               /* 0x03 chip_cntl     */

    0x00,               /* 0x1A tst_cntl1     */
    0x00,               /* 0x1B tst_cntl2     */

    /* Display Timing Generator Control */
    0x00,               /* 0x1D dtg_y_sync1      don't care   */
    0x00,               /* 0x1E dtg_y_sync2      don't care   */
    0x00,               /* 0x1F dtg_y_sync3      don't care   */

    0x00,               /* 0x20 dtg_cbcr_sync1   don't care   */
    0x00,               /* 0x21 dtg_cbcr_sync2   don't care   */
    0x00,               /* 0x22 dtg_cbcr_sync3   don't care   */

    0x23,               /* 0x23 dtg_y_sync_upper don't care   */
    0x23,               /* 0x24 dtg_cbcr_sync_upper don't care  */

    0x2C,               /* 0x25 dtg_spec_a       don't care   */
    0x58,               /* 0x26 dtg_spec_b       don't care   */
    0x2C,               /* 0x27 dtg_spec_c       don't care   */

    0x84,               /* 0x28 dtg_spec_d       don't care   */
    0x00,               /* 0x29 dtg_spec_d1      don't care   */
    0xC0,               /* 0x2A dtg_spec_e       don't care   */

    0x00,               /* 0x2B dtg_spec_h_msb   don't care   */
    0x00,               /* 0x2C dtg_spec_h_lsb   don't care   */
    0x00,               /* 0x2D dtg_spec_i_msb   don't care   */
    0x00,               /* 0x2E dtg_spec_i_lsb   don't care   */

    0x58,               /* 0x2F dtg_spec_k_lsb   don't care   */
    0x00,               /* 0x30 dtg_spec_k_msb   don't care   */
    0x00,               /* 0x31 dtg_spec_k1      don't care   */

    0x58,               /* 0x32 dtg_speg_g_lsb   don't care   */
    0x00,               /* 0x33 dtg_speg_g_msb   don't care   */

    0x06,               /* 0x34 dtg_total_pixel_msb   */
    0x98,               /* 0x35 dtg_total_pixel_lsb   */
    0x80,               /* 0x36 dtg_linecnt_msb       */
    0x02,               /* 0x37 dtg_linecnt_lsb       */

    0x87,               /* 0x38 dtg_mode              */

    0x44,               /* 0x39 dtg_frame_field_msb   */
    0x2A,               /* 0x3A dtg_frame_size_lsb    */
    0x2A,               /* 0x3B dtg_field_size_lsb    */
    0x80,               /* 0x3C dtg1_vesa_cbar_size   */

    0x00,               /* 0x3D dac_cntl_msb          */

    0x00,               /* 0x4A csm_gy_cntl_mult_msb */
    0x00,               /* 0x4F csm_rcr_bcb_cntl  */

    0x70,               /* 0x70 dtg2_hlength_lsb              */
    0x06,               /* 0x71 dtg2_hlength_lsb_hdly_msb     */
    0x98,               /* 0x72 dtg2_hdly_lsb                 */

    0x04,               /* 0x73 dtg2_vlength1_lsb             */
    0x00,               /* 0x74 dtg2_vlength1_msb_vdly1_msb   */
    0x01,               /* 0x75 dtg2_vdly1_lsb                */

    0x00,               /* 0x76 dtg2_vlength2_lsb             */
    0x07,               /* 0x77 dtg2_vlength2_msb_vdly2_msb   */
    0xFF,               /* 0x78 dtg2_vdly2_lsb                */

    0x00,               /* 0x79 dtg2_hs_in_dly_msb            */
    0x2D,               /* 0x7A dtg2_hs_in_dly_lsb            */

    0x00,               /* 0x7B dtg2_vs_in_dly_msb            */
    0x00,               /* 0x7C dtg2_vs_in_dly_lsb            */

    0x5B                /* 0x82 dtg2_cntl                     */
};

/** THS8200 CSC Register settings to disable CSC */
const _THS8200_CSC_Regs ths8200_CSC_Disable_Regs =
{
    /* Color Space Conversion Control Registers */
    0x00,               /* 0x04 csc_r11       */
    0x00,               /* 0x05 csc_r12       */
    0x00,               /* 0x06 csc_r21       */
    0x00,               /* 0x07 csc_r22       */
    0x00,               /* 0x08 csc_r31       */
    0x00,               /* 0x09 csc_r32       */

    0x00,               /* 0x0A csc_g11       */
    0x00,               /* 0x0B csc_g12       */
    0x00,               /* 0x0C csc_g21       */
    0x00,               /* 0x0D csc_g22       */
    0x00,               /* 0x0E csc_g31       */
    0x00,               /* 0x0F csc_g32       */

    0x00,               /* 0x10 csc_b11       */
    0x00,               /* 0x11 csc_b12       */
    0x00,               /* 0x12 csc_b21       */
    0x00,               /* 0x13 csc_b22       */
    0x00,               /* 0x14 csc_b31       */
    0x00,               /* 0x15 csc_b32       */

    0x00,               /* 0x16 csc_offs1     */
    0x00,               /* 0x17 csc_offs12    */
    0x00,               /* 0x18 csc_offs23    */
    0x02                /* 0x19 csc_offs3     */
};

/**
 * THS8200 CSC Register settings for YCbCr to RGB Conversion
 *
 * Values based on the following conversion formulas
 *
 * G = Y - 0.4577*Cr - 0.1831*Cb + 328
 * B = Y             + 1.8142*Cb - 929
 * R = Y + 1.5396*Cr             - 788
 */
const _THS8200_CSC_Regs ths8200_CSC_YCbCr_To_RGB_Regs =
{
    /* Color Space Conversion Control Registers */
    0x81,               /* 0x04 csc_r11       */
    0xD5,               /* 0x05 csc_r12       */
    0x00,               /* 0x06 csc_r21       */
    0x00,               /* 0x07 csc_r22       */
    0x06,               /* 0x08 csc_r31       */
    0x29,               /* 0x09 csc_r32       */

    0x04,               /* 0x0A csc_g11       */
    0x00,               /* 0x0B csc_g12       */
    0x04,               /* 0x0C csc_g21       */
    0x80,               /* 0x0D csc_g22       */
    0x04,               /* 0x0E csc_g31       */
    0x00,               /* 0x0F csc_g32       */

    0x80,               /* 0x10 csc_b11       */
    0xBB,               /* 0x11 csc_b12       */
    0x07,               /* 0x12 csc_b21       */
    0x42,               /* 0x13 csc_b22       */
    0x00,               /* 0x14 csc_b31       */
    0x00,               /* 0x15 csc_b32       */

    0x14,               /* 0x16 csc_offs1     */
    0xAE,               /* 0x17 csc_offs12    */
    0x8B,               /* 0x18 csc_offs23    */
    0x15                /* 0x19 csc_offs3     */
};

/**
 * THS8200 CSC Register settings for RGB to YCbCr Conversion
 *
 * Values based on the following conversion formulas
 *
 * Y  =  0.2126*R + 0.7152*G + 0.0722*B
 * Cb = -0.1172*R - 0.3942*G + 0.5114*B + 512
 * Cr =  0.5114*R - 0.4646*G - 0.0468*B + 512
 */
const _THS8200_CSC_Regs ths8200_CSC_RGB_To_YCbCr_Regs =
{
    /* Color Space Conversion Control Registers */
    0x00,               /* 0x04 csc_r11       */
    0xDA,               /* 0x05 csc_r12       */
    0x80,               /* 0x06 csc_r21       */
    0x78,               /* 0x07 csc_r22       */
    0x02,               /* 0x08 csc_r31       */
    0x0C,               /* 0x09 csc_r32       */

    0x02,               /* 0x0A csc_g11       */
    0xDC,               /* 0x0B csc_g12       */
    0x81,               /* 0x0C csc_g21       */
    0x94,               /* 0x0D csc_g22       */
    0x81,               /* 0x0E csc_g31       */
    0xDC,               /* 0x0F csc_g32       */

    0x00,               /* 0x10 csc_b11       */
    0x4A,               /* 0x11 csc_b12       */
    0x02,               /* 0x12 csc_b21       */
    0x0C,               /* 0x13 csc_b22       */
    0x80,               /* 0x14 csc_b31       */
    0x30,               /* 0x15 csc_b32       */

    0x00,               /* 0x16 csc_offs1     */
    0x08,               /* 0x17 csc_offs12    */
    0x02,               /* 0x18 csc_offs23    */
    0x01                /* 0x19 csc_offs3     */
};


/******************************************************************************/
/* End of file                                                                */
/******************************************************************************/
