/*******************************************************************************
**+--------------------------------------------------------------------------+**
**|                            ****                                          |**
**|                            ****                                          |**
**|                            ******o***                                    |**
**|                      ********_///_****                                   |**
**|                      ***** /_//_/ ****                                   |**
**|                       ** ** (__/ ****                                    |**
**|                           *********                                      |**
**|                            ****                                          |**
**|                            ***                                           |**
**|                                                                          |**
**|         Copyright (c) 1998-2007 Texas Instruments Incorporated           |**
**|                        ALL RIGHTS RESERVED                               |**
**|                                                                          |**
**| Permission is hereby granted to licensees of Texas Instruments           |**
**| Incorporated (TI) products to use this computer program for the sole     |**
**| purpose of implementing a licensee product based on TI products.         |**
**| No other rights to reproduce, use, or disseminate this computer          |**
**| program, whether in part or in whole, are granted.                       |**
**|                                                                          |**
**| TI makes no representation or warranties with respect to the             |**
**| performance of this computer program, and specifically disclaims         |**
**| any responsibility for any damages, special or consequential,            |**
**| connected with the use of this program.                                  |**
**|                                                                          |**
**+--------------------------------------------------------------------------+**
*******************************************************************************/

/**
 *  \file    _ths8200.h
 *
 *  This file contains internal structures and defines for THS8200 encoder
 */

#ifndef __THS8200_H
#define __THS8200_H

#include <ti/sdo/pspdrivers/drivers/vport/edc.h>
#include <ti/sdo/pspdrivers/system/dm648/bios/evmDM648/video/ths8200.h>

#ifdef __cplusplus
extern "C" {
#endif

/*
 * ======== EXTERNS ===========
 */
/** THS8200 EDC function table */
extern EDC_Fxns THS8200_Fxns;

/*
 * ========= DEFINES ==========
 */
/* Colour Space defines */
#define COLOUR_SPACE_RGB                (0)
/**< Macro for RGB color space */
#define COLOUR_SPACE_YCBCR              (1)
/**< Macro for YCbCr color space */

/** THS8200 I2C address. In EVM, address selecting pin I2CA = 0 so WRITE address
 *  is 0x40 and read address 0x41.
 */
#define THS8200_I2CADDR                 (0x40 >> 1)

/* System Registers */
#define THS8200_VERSION_ADDR                        (0x02)
/**< THS8200 Version Register Offset */
#define THS8200_CHIP_CTL_ADDR                       (0x03)
/**< THS8200 Chip Control Register Offset */

/* Color Space Conversion Registers */
#define THS8200_CSC_R11_ADDR                        (0x04)
/**< THS8200 CSC R11 Register Offset */
#define THS8200_CSC_R12_ADDR                        (0x05)
/**< THS8200 CSC R12 Register Offset */
#define THS8200_CSC_R21_ADDR                        (0x06)
/**< THS8200 CSC R21 Register Offset */
#define THS8200_CSC_R22_ADDR                        (0x07)
/**< THS8200 CSC R22 Register Offset */
#define THS8200_CSC_R31_ADDR                        (0x08)
/**< THS8200 CSC R31 Register Offset */
#define THS8200_CSC_R32_ADDR                        (0x09)
/**< THS8200 CSC R32 Register Offset */
#define THS8200_CSC_G11_ADDR                        (0x0A)
/**< THS8200 CSC G11 Register Offset */
#define THS8200_CSC_G12_ADDR                        (0x0B)
/**< THS8200 CSC G12 Register Offset */
#define THS8200_CSC_G21_ADDR                        (0x0C)
/**< THS8200 CSC G21 Register Offset */
#define THS8200_CSC_G22_ADDR                        (0x0D)
/**< THS8200 CSC G22 Register Offset */
#define THS8200_CSC_G31_ADDR                        (0x0E)
/**< THS8200 CSC G31 Register Offset */
#define THS8200_CSC_G32_ADDR                        (0x0F)
/**< THS8200 CSC G32 Register Offset */
#define THS8200_CSC_B11_ADDR                        (0x10)
/**< THS8200 CSC B11 Register Offset */
#define THS8200_CSC_B12_ADDR                        (0x11)
/**< THS8200 CSC B12 Register Offset */
#define THS8200_CSC_B21_ADDR                        (0x12)
/**< THS8200 CSC B21 Register Offset */
#define THS8200_CSC_B22_ADDR                        (0x13)
/**< THS8200 CSC B22 Register Offset */
#define THS8200_CSC_B31_ADDR                        (0x14)
/**< THS8200 CSC B31 Register Offset */
#define THS8200_CSC_B32_ADDR                        (0x15)
/**< THS8200 CSC B32 Register Offset */
#define THS8200_CSC_OFFS1_ADDR                      (0x16)
/**< THS8200 CSC Offset 1 Register Offset */
#define THS8200_CSC_OFFS12_ADDR                     (0x17)
/**< THS8200 CSC Offset 12 Register Offset */
#define THS8200_CSC_OFFS23_ADDR                     (0x18)
/**< THS8200 CSC Offset 23 Register Offset */
#define THS8200_CSC_OFFS3_ADDR                      (0x19)
/**< THS8200 CSC Offset 3 Register Offset */

/* Test Registers */
#define THS8200_TST_CNTL1_ADDR                      (0x1A)
/**< THS8200 Test Control 1 Register Offset */
#define THS8200_TST_CNTL2_ADDR                      (0x1B)
/**< THS8200 Test Control 2 Register Offset */

/* Data Path Registers */
#define THS8200_DATA_CNTL_ADDR                      (0x1C)
/**< THS8200 Data Control Register Offset */

/* Display Timing Generation, Part 1 */
#define THS8200_DTG1_Y_SYNC1_LSB_ADDR               (0x1D)
/**< THS8200 DTG1 Y Sync1 LSB Register Offset */
#define THS8200_DTG1_Y_SYNC2_LSB_ADDR               (0x1E)
/**< THS8200 DTG1 Y Sync2 LSB Register Offset */
#define THS8200_DTG1_Y_SYNC3_LSB_ADDR               (0x1F)
/**< THS8200 DTG1 Y Sync3 LSB Register Offset */

#define THS8200_DTG1_CBCR_SYNC1_LSB_ADDR            (0x20)
/**< THS8200 DTG1 CbCr Sync1 LSB Register Offset */
#define THS8200_DTG1_CBCR_SYNC2_LSB_ADDR            (0x21)
/**< THS8200 DTG1 CbCr Sync2 LSB Register Offset */
#define THS8200_DTG1_CBCR_SYNC3_LSB_ADDR            (0x22)
/**< THS8200 DTG1 CbCr Sync3 LSB Register Offset */

#define THS8200_DTG1_Y_SYNC_MSB_ADDR                (0x23)
/**< THS8200 DTG1 Y Sync MSB Register Offset */
#define THS8200_DTG1_CBCR_SYNC_MSB_ADDR             (0x24)
/**< THS8200 DTG1 CbCr Sync MSB Register Offset */

#define THS8200_DTG1_SPEC_A_ADDR                    (0x25)
/**< THS8200 DTG1 Spec A Register Offset */
#define THS8200_DTG1_SPEC_B_ADDR                    (0x26)
/**< THS8200 DTG1 Spec B Register Offset */
#define THS8200_DTG1_SPEC_C_ADDR                    (0x27)
/**< THS8200 DTG1 Spec C Register Offset */
#define THS8200_DTG1_SPEC_D_LSB_ADDR                (0x28)
/**< THS8200 DTG1 Spec D LSB Register Offset */
#define THS8200_DTG1_SPEC_D1_ADDR                   (0x29)
/**< THS8200 DTG1 Spec D1 Register Offset */
#define THS8200_DTG1_SPEC_E_LSB_ADDR                (0x2A)
/**< THS8200 DTG1 Spec E LSB Register Offset */
#define THS8200_DTG1_SPEC_DEH_MSB_ADDR              (0x2B)
/**< THS8200 DTG1 Spec DEH MSB Register Offset */
#define THS8200_DTG1_SPEC_H_LSB_ADDR                (0x2C)
/**< THS8200 DTG1 Spec H LSB Register Offset */
#define THS8200_DTG1_SPEC_I_MSB_ADDR                (0x2D)
/**< THS8200 DTG1 Spec I MSB Register Offset */
#define THS8200_DTG1_SPEC_I_LSB_ADDR                (0x2E)
/**< THS8200 DTG1 Spec I LSB Register Offset */
#define THS8200_DTG1_SPEC_K_LSB_ADDR                (0x2F)
/**< THS8200 DTG1 Spec K LSB Register Offset */
#define THS8200_DTG1_SPEC_K_MSB_ADDR                (0x30)
/**< THS8200 DTG1 Spec K MSB Register Offset */
#define THS8200_DTG1_SPEC_K1_ADDR                   (0x31)
/**< THS8200 DTG1 Spec K1 Register Offset */
#define THS8200_DTG1_SPEC_G_LSB_ADDR                (0x32)
/**< THS8200 DTG1 Spec G LSB Register Offset */
#define THS8200_DTG1_SPEC_G_MSB_ADDR                (0x33)
/**< THS8200 DTG1 Spec G MSB Register Offset */

#define THS8200_DTG1_TOTAL_PIX_MSB_ADDR             (0x34)
/**< THS8200 DTG1 Total Pixel MSB Register Offset */
#define THS8200_DTG1_TOTAL_PIX_LSB_ADDR             (0x35)
/**< THS8200 DTG1 Total Pixel LSB Register Offset */
#define THS8200_DTG1_FLDFLIP_LINECNT_MSB_ADDR       (0x36)
/**< THS8200 DTG1 Field Flip Line Count MSB Register Offset */
#define THS8200_DTG1_LINECNT_LSB_ADDR               (0x37)
/**< THS8200 DTG1 Line Count LSB Register Offset */

#define THS8200_DTG1_MODE_ADDR                      (0x38)
/**< THS8200 DTG1 Mode Register Offset */

#define THS8200_DTG1_FRM_FLD_SIZE_MSB_ADDR          (0x39)
/**< THS8200 DTG1 Frame Field Size MSB Register Offset */
#define THS8200_DTG1_FRMSIZE_LSB_ADDR               (0x3A)
/**< THS8200 DTG1 Frame Size LSB Register Offset */
#define THS8200_DTG1_FIELD_SIZE_LSB_ADDR            (0x3B)
/**< THS8200 DTG1 Field_Size LSB Register Offset */
#define THS8200_DTG1_VESA_CBAR_SIZE_ADDR            (0x3C)
/**< THS8200 DTG1 VESA Colorbar Size Register Offset */

/* DAC Registers */
#define THS8200_DAC_CNTL_MSB_ADDR                   (0x3D)
/**< THS8200 Dac Control MSB Register Offset */
#define THS8200_DAC1_CNTL_LSB_ADDR                  (0x3E)
/**< THS8200 Dac1 Control LSB Register Offset */
#define THS8200_DAC2_CNTL_LSB_ADDR                  (0x3F)
/**< THS8200 Dac2 Control LSB Register Offset */
#define THS8200_DAC3_CNTL_LSB_ADDR                  (0x40)
/**< THS8200 Dac3 Control LSB Register Offset */

/* Clip/Shift/Multiplier Registers */
#define THS8200_CSM_CLIP_GY_LOW_ADDR                (0x41)
/**< THS8200 CSM Clip Gy Low Register Offset */
#define THS8200_CSM_CLIP_BCB_LOW_ADDR               (0x42)
/**< THS8200 CSM Clip Bcb Low Register Offset */
#define THS8200_CSM_CLIP_RCR_LOW_ADDR               (0x43)
/**< THS8200 CSM Clip Rcr Low Register Offset */

#define THS8200_CSM_CLIP_GY_HIGH_ADDR               (0x44)
/**< THS8200 CSM Clip Gy High Register Offset */
#define THS8200_CSM_CLIP_BCB_HIGH_ADDR              (0x45)
/**< THS8200 CSM Clip Bcb High Register Offset */
#define THS8200_CSM_CLIP_RCR_HIGH_ADDR              (0x46)
/**< THS8200 CSM Clip Rcr High Register Offset */

#define THS8200_CSM_SHIFT_GY_ADDR                   (0x47)
/**< THS8200 CSM Shift Gy Register Offset */
#define THS8200_CSM_SHIFT_BCB_ADDR                  (0x48)
/**< THS8200 CSM Shift Bcb Register Offset */
#define THS8200_CSM_SHIFT_RCR_ADDR                  (0x49)
/**< THS8200 CSM Shift Rcr Register Offset */

#define THS8200_CSM_GY_CNTL_MULT_MSB_ADDR           (0x4A)
/**< THS8200 CSM Gy Control Mult MSB Register Offset */
#define THS8200_CSM_MULT_BCB_RCR_MSB_ADDR           (0x4B)
/**< THS8200 CSM Mult Bcb Rcr MSB Register Offset */
#define THS8200_CSM_MULT_GY_LSB_ADDR                (0x4C)
/**< THS8200 CSM Mult Gy LSB Register Offset */
#define THS8200_CSM_MULT_BCB_LSB_ADDR               (0x4D)
/**< THS8200 CSM Mult Bcb LSB Register Offset */
#define THS8200_CSM_MULT_RCR_LSB_ADDR               (0x4E)
/**< THS8200 CSM Mult Rcr LSB Register Offset */
#define THS8200_CSM_RCR_BCB_CNTL_ADDR               (0x4F)
/**< THS8200 CSM Rcr Bcb Control Register Offset */

/* Display Timing Generation, Part 2 */
#define THS8200_DTG2_BP1_2_MSB_ADDR                 (0x50)
/**< THS8200 DTG2 BP1 2 MSB Register Offset */
#define THS8200_DTG2_BP3_4_MSB_ADDR                 (0x51)
/**< THS8200 DTG2 BP3 4 MSB Register Offset */
#define THS8200_DTG2_BP5_6_MSB_ADDR                 (0x52)
/**< THS8200 DTG2 BP5 6 MSB Register Offset */
#define THS8200_DTG2_BP7_8_MSB_ADDR                 (0x53)
/**< THS8200 DTG2 BP7 8 MSB Register Offset */
#define THS8200_DTG2_BP9_10_MSB_ADDR                (0x54)
/**< THS8200 DTG2 BP9 10 MSB Register Offset */
#define THS8200_DTG2_BP11_12_MSB_ADDR               (0x55)
/**< THS8200 DTG2 BP11 12 MSB Register Offset */
#define THS8200_DTG2_BP13_14_MSB_ADDR               (0x56)
/**< THS8200 DTG2 BP13 14 MSB Register Offset */
#define THS8200_DTG2_BP15_16_MSB_ADDR               (0x57)
/**< THS8200 DTG2 BP15 16 MSB Register Offset */

#define THS8200_DTG2_BP1_LSB_ADDR                   (0x58)
/**< THS8200 DTG2 BP1 LSB Register Offset */
#define THS8200_DTG2_BP2_LSB_ADDR                   (0x59)
/**< THS8200 DTG2 BP2 LSB Register Offset */
#define THS8200_DTG2_BP3_LSB_ADDR                   (0x5A)
/**< THS8200 DTG2 BP3 LSB Register Offset */
#define THS8200_DTG2_BP4_LSB_ADDR                   (0x5B)
/**< THS8200 DTG2 BP4 LSB Register Offset */
#define THS8200_DTG2_BP5_LSB_ADDR                   (0x5C)
/**< THS8200 DTG2 BP5 LSB Register Offset */
#define THS8200_DTG2_BP6_LSB_ADDR                   (0x5D)
/**< THS8200 DTG2 BP6 LSB Register Offset */
#define THS8200_DTG2_BP7_LSB_ADDR                   (0x5E)
/**< THS8200 DTG2 BP7 LSB Register Offset */
#define THS8200_DTG2_BP8_LSB_ADDR                   (0x5F)
/**< THS8200 DTG2 BP8 LSB Register Offset */
#define THS8200_DTG2_BP9_LSB_ADDR                   (0x60)
/**< THS8200 DTG2 BP9 LSB Register Offset */
#define THS8200_DTG2_BP10_LSB_ADDR                  (0x61)
/**< THS8200 DTG2 BP10 LSB Register Offset */
#define THS8200_DTG2_BP11_LSB_ADDR                  (0x62)
/**< THS8200 DTG2 BP11 LSB Register Offset */
#define THS8200_DTG2_BP12_LSB_ADDR                  (0x63)
/**< THS8200 DTG2 BP12 LSB Register Offset */
#define THS8200_DTG2_BP13_LSB_ADDR                  (0x64)
/**< THS8200 DTG2 BP13 LSB Register Offset */
#define THS8200_DTG2_BP14_LSB_ADDR                  (0x65)
/**< THS8200 DTG2 BP14 LSB Register Offset */
#define THS8200_DTG2_BP15_LSB_ADDR                  (0x66)
/**< THS8200 DTG2 BP15 LSB Register Offset */
#define THS8200_DTG2_BP16_LSB_ADDR                  (0x67)
/**< THS8200 DTG2 BP16 LSB Register Offset */

#define THS8200_DTG2_LINETYPE1_ADDR                 (0x68)
/**< THS8200 DTG2 Linetype1 Register Offset */
#define THS8200_DTG2_LINETYPE2_ADDR                 (0x69)
/**< THS8200 DTG2 Linetype2 Register Offset */
#define THS8200_DTG2_LINETYPE3_ADDR                 (0x6A)
/**< THS8200 DTG2 Linetype3 Register Offset */
#define THS8200_DTG2_LINETYPE4_ADDR                 (0x6B)
/**< THS8200 DTG2 Linetype4 Register Offset */
#define THS8200_DTG2_LINETYPE5_ADDR                 (0x6C)
/**< THS8200 DTG2 Linetype5 Register Offset */
#define THS8200_DTG2_LINETYPE6_ADDR                 (0x6D)
/**< THS8200 DTG2 Linetype6 Register Offset */
#define THS8200_DTG2_LINETYPE7_ADDR                 (0x6E)
/**< THS8200 DTG2 Linetype7 Register Offset */
#define THS8200_DTG2_LINETYPE8_ADDR                 (0x6F)
/**< THS8200 DTG2 Linetype8 Register Offset */

#define THS8200_DTG2_HLENGTH_LSB_ADDR               (0x70)
/**< THS8200 DTG2 Hlength LSB Register Offset */
#define THS8200_DTG2_HLENGTH_LSB_HDLY_MSB_ADDR      (0x71)
/**< THS8200 DTG2 Hlength LSB Hdly MSB Register Offset */
#define THS8200_DTG2_HDLY_LSB_ADDR                  (0x72)
/**< THS8200 DTG2 Hdly LSB Register Offset */

#define THS8200_DTG2_VLENGTH1_LSB_ADDR              (0x73)
/**< THS8200 DTG2 Vlength1 LSB Register Offset */
#define THS8200_DTG2_VLENGTH1_MSB_VDLY1_MSB_ADDR    (0x74)
/**< THS8200 DTG2 Vlength1 MSB Vdly1 MSB Register Offset */
#define THS8200_DTG2_VDLY1_LSB_ADDR                 (0x75)
/**< THS8200 DTG2 Vdly1 LSB Register Offset */

#define THS8200_DTG2_VLENGTH2_LSB_ADDR              (0x76)
/**< THS8200 DTG2 Vlength2 LSB Register Offset */
#define THS8200_DTG2_VLENGTH2_MSB_VDLY2_MSB_ADDR    (0x77)
/**< THS8200 DTG2 Vlength2 MSB Vdly2 MSB Register Offset */
#define THS8200_DTG2_VDLY2_LSB_ADDR                 (0x78)
/**< THS8200 DTG2 Vdly2 LSB Register Offset */

#define THS8200_DTG2_HS_IN_DLY_MSB_ADDR             (0x79)
/**< THS8200 DTG2 Hs In Dly MSB Register Offset */
#define THS8200_DTG2_HS_IN_DLY_LSB_ADDR             (0x7A)
/**< THS8200 DTG2 Hs In Dly LSB Register Offset */

#define THS8200_DTG2_VS_IN_DLY_MSB_ADDR             (0x7B)
/**< THS8200 DTG2 Vs In Dly MSB Register Offset */
#define THS8200_DTG2_VS_IN_DLY_LSB_ADDR             (0x7C)
/**< THS8200 DTG2 Vs In Dly LSB Register Offset */

#define THS8200_DTG2_PIX_CNT_MSB_ADDR               (0x7D)
/**< THS8200 DTG2 Pixel Count MSB Register Offset */
#define THS8200_DTG2_PIX_CNT_LSB_ADDR               (0x7E)
/**< THS8200 DTG2 Pixel Count LSB Register Offset */

#define THS8200_DTG2_LINE_CNT_MSB_ADDR              (0x7F)
/**< THS8200 DTG2 Line Count MSB Register Offset */
#define THS8200_DTG2_LINE_CNT_LSB_ADDR              (0x80)
/**< THS8200 DTG2 Line Count LSB Register Offset */

#define THS8200_DTG2_CNTL_ADDR                      (0x82)
/**< THS8200 Dtg2 Control Register Offset */

/* CGMS Control Registers */
#define THS8200_CGMS_CNTL_HEADER_ADDR               (0x83)
/**< THS8200 CGMS Control Header Register Offset */
#define THS8200_CGMS_PAYLOAD_MSB_ADDR               (0x84)
/**< THS8200 CGMS Payload MSB Register Offset */
#define THS8200_CGMS_PAYLOAD_LSB_ADDR               (0x85)
/**< THS8200 CGMS Payload LSB Register Offset */

#define THS8200_MISC_PPL_LSB_ADDR                   (0x86)
/**< THS8200 Misc PPL LSB Register Offset */
#define THS8200_MISC_PPL_MSB_ADDR                   (0x87)
/**< THS8200 Misc PPL MSB Register Offset */
#define THS8200_MISC_LPF_LSB_ADDR                   (0x88)
/**< THS8200 Misc LPF LSB Register Offset */
#define THS8200_MISC_LPF_MSB_ADDR                   (0x89)
/**< THS8200 Misc LPF MSB Register Offset */


/* Defines for Configuration Values */
#define THS8200_DTG1_MODE_MASK                      (0x0F)
/**< Mask for DTG1 Mode Field */
#define THS8200_DTG1_MODE_VESA_MASTER_VAL           (0x06)
/**< Master value for DTG1 Mode */
#define THS8200_DTG1_MODE_VESA_SLAVE_VAL            (0x07)
/**< Slave value for DTG1 Mode */

#define THS8200_DTG2_EMBEDDED_SYNC_BIT              (0x20)
/**< Bit position for DTG2 Embedded Field */
#define THS8200_DTG2_RGB_MODE_ON_BIT                (0x40)
/**< Bit position for DTG2 RGB Mode On Field */

#define THS8200_AFMT_LOWER_BYTE_MASK                (0xFF)
/**< Mask for AFMT Lower Byte Field */
#define THS8200_AFMT_HIGHER_BYTE_READ_MASK          (0xF0)
/**< Mask for AFMT Higher Byte & Read Field */
#define THS8200_AFMT_HIGHER_BYTE_MASK               (0x300)
/**< Mask for AFMT Higher Byte Field */
#define THS8200_AFMT_HIGH_VAL_SHIFT                 (8)
/**< Shift for AFMT High Field */
#define THS8200_AFMT_LOW_VAL_SHIFT                  (6)
/**< Shift for AFMT Low Field */

#define THS8200_AFMT_RGB_MODE_VAL                   (0x40)
/**< AFMT RGB Mode value */

#define THS8200_NO_SYNC_VAL                         (0x00)
/**< Value for generating no sync signal */
#define THS8200_SYNC_ON_Y_LOW                       (0x0049)
/**< Low value for Y sync signal */
#define THS8200_SYNC_ON_Y_HIGH                      (0x03B6)
/**< High value for Y sync signal */
#define THS8200_SYNC_ON_CBCR_LOW                    (0x01FF)
/**< Low value for Cb & Cr sync signal */
#define THS8200_SYNC_ON_CBCR_HIGH                   (0x01FF)
/**< High value for Cb & Cr sync signal */

#define THS8200_SYSCTRL_VESA_COLORBARS_BIT          (0x20)
/**< Bit position for SYSCTRL VESA colorbars Field */
#define THS8200_SYSCTRL_DAC_PWDN_BIT                (0x08)
/**< Bit position for SYSCTRL DAC powerdown Field */
#define THS8200_SYSCTRL_CHIP_PWDN_BIT               (0x04)
/**< Bit position for SYSCTRL chip powerdown Field */
#define THS8200_SYSCTRL_CHIP_MS_BIT                 (0x02)
/**< Bit position for SYSCTRL chip master/slave Field */
#define THS8200_SYSCTRL_ARST_FUNC_N_BIT             (0x01)
/**< Bit position for SYSCTRL reset function Field */

#define THS8200_DATA_FSADJ_BIT                      (0x40)
/**< Bit position for DATA FSADJ Field */
#define THS8200_DATA_IFIR12_BYPASS_BIT              (0x20)
/**< Bit position for DATA IFIR12 bypass Field */
#define THS8200_DATA_IFIR35_BYPASS_BIT              (0x10)
/**< Bit position for DATA IFIR35 bypass Field */
#define THS8200_DATA_TRISTATE656_BIT                (0x08)
/**< Bit position for DATA BT656 tristate Field */
#define THS8200_DATA_CLK656_ON_BIT                  (0x80)
/**< Bit position for DATA BT656 clock on Field */
#define THS8200_DATA_DMAN_CTL_MASK                  (0x07)
/**< Mask for DATA DMAN control Field */
#define THS8200_DATA_DMAN_CTL_30BIT_VAL             (0x00)
/**< 30-bit value for DATA DMAN control Field */
#define THS8200_DATA_DMAN_CTL_16BIT_RGB_VAL         (0x01)
/**< 16-bit RGB value for DATA DMAN control Field */
#define THS8200_DATA_DMAN_CTL_15BIT_RGB_VAL         (0x02)
/**< 15-bit RGB value for DATA DMAN control Field */
#define THS8200_DATA_DMAN_CTL_20BIT_YCBCR_VAL       (0x03)
/**< 20-bit YCbCr value for DATA DMAN control Field */
#define THS8200_DATA_DMAN_CTL_10BIT_YCBCR_VAL       (0x04)
/**< 10-bit YCbCr value for DATA DMAN control Field */

#define THS8200_TST_CNTL1_ADDR_CNT                  (2)
/**< Number of registers to write after TST_CNTL1 register */
#define THS8200_DTG1_Y_SYNC1_LSB_ADDR_CNT           (33)
/**< Number of registers to write after DTG1_Y_SYNC1_LSB register */
#define THS8200_DTG2_HLENGTH_LSB_ADDR_CNT           (13)
/**< Number of registers to write after DTG2_HLENGTH_LSB register */

#define THS8200_CSC_NUM_REGISTERS                   (22)
/**< Number of registers to write in CSC register */

/**
  * \brief  THS8200 register settings Structure
  *  Structure to contain THS8200 register setting values
  */
typedef struct _THS8200_Regs_t
{
    Uint8 chip_cntl;
    /**< Chip control register 0x03 */

    Uint8 tst_cntl1;
    /**< Color space conversion test control 1 register 0x1A */
    Uint8 tst_cntl2;
    /**< Color space conversion test control 2 0x1B */

    /* Display Timing Generator Control */
    Uint8 dtg_y_sync1;
    /**< display timing generator Y sync 1 0x1D */
    Uint8 dtg_y_sync2 ;
    /**< display timing generator Y sync 2 0x1E */
    Uint8 dtg_y_sync3;
    /**< display timing generator Ysync 3 0x1F */
    Uint8 dtg_cbcr_sync1;
    /**< display timing generator CbCr sync 1 0x20 */
    Uint8 dtg_cbcr_sync2;
    /**< display timing generator CbCr sync 2 0x21 */
    Uint8 dtg_cbcr_sync3;
    /**< display timing generator CbCr sync 3 0x22 */
    Uint8 dtg_y_sync_upper;
    /**< display timing generator Y sync upper 0x23 */
    Uint8 dtg_cbcr_sync_upper;
    /**< display timing generator CbCr sync upper 0x24 */
    Uint8 dtg_spec_a;
    /**< Width of negative excursion of tri-level or bi-level sync 0x25 */
    Uint8 dtg_spec_b;
    /**< Distance from end of active video to start of negative sync
     * or to negative-to-positive transition of tri-level sync 0x26
     */
    Uint8 dtg_spec_c;
    /**< Width of positive excursion of tri-level (HDTV mode).
     * Width of equalization pulses (SDTV mode). 0x27
     */
    Uint8 dtg_spec_d;
    /**< Distance from leading edge of Hsync to start of active video
     * (SDTV mode) or from negative-to-positive transition of
     * tri-level sync to start of broad pulse (HDTV mode) 0x28
     */
    Uint8 dtg_spec_d1;
    /**< Distance from equalization pulse at center of line to active
     * video (SDTV mode) 0x29
     */
    Uint8 dtg_spec_e;
    /**< Distance from negative-to-positive transition of tri-level sync to
     * start of active video (HDTV mode). In case color bars are activated in
     * VESA mode, this parameter specifies the start of the color bar with
     * respect to the horizontal sync. 0x2A
     */
    Uint8 dtg_spec_h_msb;
    /**< Duration of broad pulse (SDTV mode) msb. 0x2B */
    Uint8 dtg_spec_h_lsb;
    /**< Duration of broad pulse (SDTV mode) lsb. 0x2C */
    Uint8 dtg_spec_i_msb;
    /**< Duration of full-line broad pulse (SDTV mode) msb 0x2D */
    Uint8 dtg_spec_i_lsb;
    /**< Duration of full-line broad pulse (SDTV mode) lsb 0x2E */
    Uint8 dtg_spec_k_lsb;
    /**< Distance from end of active video to leading edge of sync (SDTV) or
     * from end of broad pulse to negative-to-positive transition of
     * tri-level sync (HDTV) msb 0x2F
     */
    Uint8 dtg_spec_k_msb;
    /**< Distance from end of active video to leading edge of sync (SDTV) or
     * from end of broad pulse to negative-to-positive transition of
     * tri-level sync (HDTV) lsb 0x30 */
    Uint8 dtg_spec_k1;
    /**< Distance from end of active video in first half of line to center
     * equalization pulse for SDTV line type ACTIVE_NEQ 0x31 */
    Uint8 dtg_speg_g_lsb;
    /**< Half the line length. Only used in the calculations of SDTV line
     * types lsb 0x32
     */
    Uint8 dtg_speg_g_msb;
    /**< Half the line length. Only used in the calculations of SDTV line
     * types msb 0x33 */
    Uint8 dtg_total_pixel_msb;
    /**< Total number of pixels per line. Used in all DTG modes msb 0x34 */
    Uint8 dtg_total_pixel_lsb;
    /**< Total number of pixels per line. Used in all DTG modes lsb 0x35 */
    Uint8 dtg_linecnt_msb;
    /**< Sets the starting line number msb for the DTG 0x36 */
    Uint8 dtg_linecnt_lsb;
    /**< Sets the starting line number lsb for the DTG 0x37 */
    Uint8 dtg_mode;
    /**< display timing generator mode 0x38 */
    Uint8 dtg_frame_field_msb;
    /**< Determines number of lines per frame when in generic mode msb 0x39 */
    Uint8 dtg_frame_size_lsb;
    /**< Determines number of lines per frame when in generic mode lsb 0x3A */
    Uint8 dtg_field_size_lsb;
    /**< Determines number of lines in field1 when in generic mode msb 0x3B */
    Uint8 dtg1_vesa_cbar_size;
    /**< Sets the width of each color bar in the color bar test pattern. 0x3C */

    Uint8 dac_cntl_msb;
    /**< DA convert control msb 0x3D  */

    Uint8 csm_gy_cntl_mult_msb;
    /**< Clip/Scale/Multiplier G/Y control 0x4A */

    Uint8 csm_rcr_bcb_cntl;
    /**< Clip/Scale/Multiplier B/Cb control 0x4F */

    Uint8 dtg2_hlength_lsb;
    /**< Display Timing Generator Control, Part 2 horizontal length lsb 0x70 */
    Uint8 dtg2_hlength_lsb_hdly_msb;
    /**< Display Timing Generator Control, Part 2 horizontal delay msb 0x71 */
    Uint8 dtg2_hdly_lsb;
    /**< Display Timing Generator Control, Part 2 horizontal delay lsb 0x72 */
    Uint8 dtg2_vlength1_lsb;
    /**< Display Timing Generator Control, Part 2 vertical length1 lsb 0x73 */
    Uint8 dtg2_vlength1_msb_vdly1_msb;
    /**< Display Timing Generator Control, Part 2 vertical length1 msb 0x74 */
    Uint8 dtg2_vdly1_lsb;
    /**< Display Timing Generator Control, Part 2 vertical delay1 lsb 0x75 */
    Uint8 dtg2_vlength2_lsb;
    /**< Display Timing Generator Control, Part 2 vertical length2 lsb 0x76 */
    Uint8 dtg2_vlength2_msb_vdly2_msb;
    /**< Display Timing Generator Control, Part 2 vertical length1 msb 0x77 */
    Uint8 dtg2_vdly2_lsb;
    /**< Display Timing Generator Control, Part 2 vertical delay2 lsb 0x78 */
    Uint8 dtg2_hs_in_dly_msb;
    /**< Display Timing Generator Control, Part 2 hsync delay1 msb 0x79 */
    Uint8 dtg2_hs_in_dly_lsb;
    /**< Display Timing Generator Control, Part 2 hsync delay1 lsb 0x7A */
    Uint8 dtg2_vs_in_dly_msb;
    /**< Display Timing Generator Control, Part 2 vsync delay1 msb 0x7B */
    Uint8 dtg2_vs_in_dly_lsb;
    /**< Display Timing Generator Control, Part 2 vsync delay1 lsb 0x7C */

    Uint8 dtg2_cntl;
    /**< Display Timing Generator Control, Part 2 control 0x82 */
} _THS8200_Regs;    /**< Typedef for struct _THS8200_Regs_t */

/**
  * \brief  THS8200 Color Space Conversion Control Registers settings structure
  */
typedef struct _THS8200_CSC_Regs_t
{
    Uint8 csc_r11;
    /**< Color space conversion red 1 1 register 0x04 */
    Uint8 csc_r12;
    /**< Color space conversion red 1 2 register 0x05 */
    Uint8 csc_r21;
    /**< Color space conversion red 2 1 register 0x06 */
    Uint8 csc_r22;
    /**< Color space conversion red 2 2 register 0x07 */
    Uint8 csc_r31;
    /**< Color space conversion red 3 1 register 0x08 */
    Uint8 csc_r32;
    /**< Color space conversion red 3 2 register 0x09 */
    Uint8 csc_g11;
    /**< Color space conversion green 1 1 register 0x0A */
    Uint8 csc_g12;
    /**< Color space conversion green 1 2 register 0x0B */
    Uint8 csc_g21;
    /**< Color space conversion green 2 1 register 0x0C */
    Uint8 csc_g22;
    /**< Color space conversion green 2 2 register 0x0D */
    Uint8 csc_g31;
    /**< Color space conversion green 3 1 register 0x0E */
    Uint8 csc_g32;
    /**< Color space conversion green 3 2 register 0x0F */
    Uint8 csc_b11;
    /**< Color space conversion blue 1 1 register 0x10 */
    Uint8 csc_b12;
    /**< Color space conversion blue 1 2 register 0x11 */
    Uint8 csc_b21;
    /**< Color space conversion blue 2 1 register 0x12 */
    Uint8 csc_b22;
    /**< Color space conversion blue 2 2 register 0x13 */
    Uint8 csc_b31;
    /**< Color space conversion blue 3 1 register 0x14 */
    Uint8 csc_b32;
    /**< Color space conversion blue 3 2 register 0x15 */
    Uint8 csc_offs1;
    /**< Color space conversion offset 1 register 0x16 */
    Uint8 csc_offs12;
    /**< Color space conversion offset 12 register 0x17 */
    Uint8 csc_offs23;
    /**< Color space conversion offset 23 register 0x18 */
    Uint8 csc_offs3;
    /**< Color space conversion offset 3 register 0x19 */
} _THS8200_CSC_Regs;    /**< Typedef for struct _THS8200_CSC_Regs_t */


/*
 * ========== EXTERNS ===========
 */
extern const _THS8200_Regs ths8200_480p_60Hz_Regs;
extern const _THS8200_Regs ths8200_720p_60Hz_Regs;
extern const _THS8200_Regs ths8200_720p_50Hz_Regs;
extern const _THS8200_Regs ths8200_1080i_60Hz_Regs;
extern const _THS8200_Regs ths8200_1080i_50Hz_Regs;
extern const _THS8200_Regs ths8200_VGA_60Hz_Regs;
extern const _THS8200_Regs ths8200_VGA_72Hz_Regs;
extern const _THS8200_Regs ths8200_VGA_75Hz_Regs;
extern const _THS8200_Regs ths8200_VGA_85Hz_Regs;
extern const _THS8200_Regs ths8200_SVGA_60Hz_Regs;
extern const _THS8200_Regs ths8200_SVGA_72Hz_Regs;
extern const _THS8200_Regs ths8200_SVGA_75Hz_Regs;
extern const _THS8200_Regs ths8200_SVGA_85Hz_Regs;
extern const _THS8200_Regs ths8200_XGA_60Hz_Regs;
extern const _THS8200_Regs ths8200_XGA_70Hz_Regs;
extern const _THS8200_Regs ths8200_SXGA_60Hz_Regs;

extern const _THS8200_CSC_Regs ths8200_CSC_Disable_Regs;
extern const _THS8200_CSC_Regs ths8200_CSC_YCbCr_To_RGB_Regs;
extern const _THS8200_CSC_Regs ths8200_CSC_RGB_To_YCbCr_Regs;

#ifdef __cplusplus
}
#endif

#endif /* #ifndef __THS8200_H */

/******************************************************************************/
/* End of file                                                                */
/******************************************************************************/
