/*******************************************************************************
**+--------------------------------------------------------------------------+**
**|                            ****                                          |**
**|                            ****                                          |**
**|                            ******o***                                    |**
**|                      ********_///_****                                   |**
**|                      ***** /_//_/ ****                                   |**
**|                       ** ** (__/ ****                                    |**
**|                           *********                                      |**
**|                            ****                                          |**
**|                            ***                                           |**
**|                                                                          |**
**|         Copyright (c) 1998-2007 Texas Instruments Incorporated           |**
**|                        ALL RIGHTS RESERVED                               |**
**|                                                                          |**
**| Permission is hereby granted to licensees of Texas Instruments           |**
**| Incorporated (TI) products to use this computer program for the sole     |**
**| purpose of implementing a licensee product based on TI products.         |**
**| No other rights to reproduce, use, or disseminate this computer          |**
**| program, whether in part or in whole, are granted.                       |**
**|                                                                          |**
**| TI makes no representation or warranties with respect to the             |**
**| performance of this computer program, and specifically disclaims         |**
**| any responsibility for any damages, special or consequential,            |**
**| connected with the use of this program.                                  |**
**|                                                                          |**
**+--------------------------------------------------------------------------+**
*******************************************************************************/

/**
 *  \file    _tvp5154.h file
 *
 *  This file contains internal structures and defines for TVP5154 decoder
 */

#ifndef __TVP5154_H
#define __TVP5154_H

/*
 * =========== INCLUDE FILES ==========
 */
#include <ti/sdo/pspdrivers/pal_os/pal_osSem.h>

#ifdef __cplusplus
extern "C" {
#endif

/*
 * =========== DEFINES ==========
 */
/** Indicates two TVP5154 decoders */
#define NUM_DECODERS                    (2)
/** Number of channels supported by one decoder */
#define NUM_CHANNELS                    (4)

#define _TVP5154_1_IIC_ADDR             (0x5E)    /**< TVP5154 #1 I2C address */
#define _TVP5154_2_IIC_ADDR             (0x5F)    /**< TVP5154 #2 I2C address */

/* TVP5154 register address defines */
#define TVP5154_INPUT_SRC_SEL_1_ADDR            (0x00)
/**< TVP5154 Input Source Sel 1 Register Offset */
#define TVP5154_ANALOG_CHAN_CTRL_ADDR           (0x01)
/**< TVP5154 Analog Chan Control Register Offset */
#define TVP5154_OPERATION_MODE_CTRL_ADDR        (0x02)
/**< TVP5154 Operation Mode Control Register Offset */
#define TVP5154_MISC_CTRL_ADDR                  (0x03)
/**< TVP5154 Misc Control Register Offset */
#define TVP5154_AUTOSWITCH_MASK_ADDR            (0x04)
/**< TVP5154 Autoswitch Mask Register Offset */
#define TVP5154_CLK_CTRL_ADDR                   (0x05)
/**< TVP5154 Clock Control Register Offset */
#define TVP5154_COL_KILLER_THRLD_CTRL_ADDR      (0x06)
/**< TVP5154 Color Killer Thrld Control Register Offset */
#define TVP5154_LUMA_PROC_CTRL_1_ADDR           (0x07)
/**< TVP5154 Luma Proc Control 1 Register Offset */
#define TVP5154_LUMA_PROC_CTRL_2_ADDR           (0x08)
/**< TVP5154 Luma Proc Control 2 Register Offset */
#define TVP5154_BRIGHT_CTRL_ADDR                (0x09)
/**< TVP5154 Bright Control Register Offset */
#define TVP5154_COLOR_SATURATION_CTRL_ADDR      (0x0A)
/**< TVP5154 Color Saturation Control Register Offset */
#define TVP5154_HUE_CTRL_ADDR                   (0x0B)
/**< TVP5154 Hue Control Register Offset */
#define TVP5154_CONTRAST_CTRL_ADDR              (0x0C)
/**< TVP5154 Contrast Control Register Offset */
#define TVP5154_OUTPUTS_DATA_RATES_SEL_ADDR     (0x0D)
/**< TVP5154 Outputs Data Rates Select Register Offset */
#define TVP5154_LUMA_PROC_CTRL_3_ADDR           (0x0E)
/**< TVP5154 Luma Proc Control 3 Register Offset */
#define TVP5154_CONF_SHARED_PINS_ADDR           (0x0F)
/**< TVP5154 Conf Shared Pins Register Offset */

#define TVP5154_CROP_START_MSB_UNSCALED_ADDR    (0x11)
/**< TVP5154 Crop Start MSB_Unscaled Register Offset */
#define TVP5154_CROP_START_LSB_UNSCALED_ADDR    (0x12)
/**< TVP5154 Crop Start LSB Unscaled Register Offset */
#define TVP5154_CROP_STOP_MSB_UNSCALED_ADDR     (0x13)
/**< TVP5154 Crop Stop MSB Unscaled Register Offset */
#define TVP5154_CROP_STOP_LSB_UNSCALED_ADDR     (0x14)
/**< TVP5154 Crop Stop LSB Unscaled Register Offset */
#define TVP5154_GENLOCK_RTC_ADDR                (0x15)
/**< TVP5154 Genlock RTC Register Offset */
#define TVP5154_HORIZ_SYNC_START_ADDR           (0x16)
/**< TVP5154 Horizontal Sync Start Register Offset */
#define TVP5154_ANCILLARY_SAV_EAV_CTRL_ADDR     (0x17)
/**< TVP5154 Ancillary_SAV EAV Control Register Offset */
#define TVP5154_VERT_BLANK_START_ADDR           (0x18)
/**< TVP5154 Vertical Blank Start Register Offset */
#define TVP5154_VERT_BLANK_STOP_ADDR            (0x19)
/**< TVP5154 Vertical Blank Stop Register Offset */
#define TVP5154_CHROMA_PROCESS_CTRL_1_ADDR      (0x1A)
/**< TVP5154 Chroma_Process Control 1 Register Offset */
#define TVP5154_CHROMA_PROCESS_CTRL_2_ADDR      (0x1B)
/**< TVP5154 Chroma Process Control 2 Register Offset */
#define TVP5154_INT_RESET_REG_B_ADDR            (0x1C)
/**< TVP5154 Interrupt  Reset Reg B Register Offset */
#define TVP5154_INT_ENABLE_REG_B_ADDR           (0x1D)
/**< TVP5154 Interrupt  Enable Reg B Register Offset */
#define TVP5154_INT_CONF_REG_B_ADDR             (0x1E)
/**< TVP5154 Interrupt  Conf Reg B Register Offset */
#define TVP5154_OUTPUT_CTRL_ADDR                (0x1F)
/**< TVP5154 Output Control Register Offset */

#define TVP5154_I2C_INDIRECT_REG1_ADDR          (0x21)
/**< TVP5154 I2C Indirect Reg1 Register Offset */
#define TVP5154_I2C_INDIRECT_REG2_ADDR          (0x22)
/**< TVP5154 I2C Indirect Reg2 Register Offset */
#define TVP5154_I2C_INDIRECT_REG3_ADDR          (0x23)
/**< TVP5154 I2C Indirect Reg3 Register Offset */
#define TVP5154_I2C_INDIRECT_REG4_ADDR          (0x24)
/**< TVP5154 I2C Indirect Reg4 Register Offset */
#define TVP5154_AVID_PIXEL_MSB_ADDR             (0x25)
/**< TVP5154 Avid Pixel MSB Register Offset */
#define TVP5154_AVID_PIXEL_ACTIVE_LSB_ADDR      (0x26)
/**< TVP5154 Avid Pixel Active LSB Register Offset */

#define TVP5154_VIDEO_STANDARD_ADDR             (0x28)
/**< TVP5154 Video Standard Register Offset */
#define TVP5154_AVID_STOP_PIXEL_MSB_ADDR        (0x29)
/**< TVP5154 Avid Stop Pixel MSB Register Offset */
#define TVP5154_AVID_STOP_PIXEL_LSB_ADDR        (0x2A)
/**< TVP5154 Avid Stop Pixel LSB Register Offset */

#define TVP5154_CB_GAIN_FACTOR_ADDR             (0x2C)
/**< TVP5154 Cb Gain Factor Register Offset */
#define TVP5154_CR_GAIN_FACTOR_ADDR             (0x2D)
/**< TVP5154 Cr Gain Factor Register Offset */

#define TVP5154_656_REVISION_SEL_ADDR           (0x30)
/**< TVP5154 656 Revision Select Register Offset */

#define TVP5154_POWERUP_REG_ADDR                (0x7F)
/**< TVP5154 Powerup Register Offset */

#define TVP5154_MSB_OF_DEVICE_ID_ADDR           (0x80)
/**< TVP5154 MSB Of Device ID Register Offset */
#define TVP5154_LSB_OF_DEVICE_ID_ADDR           (0x81)
/**< TVP5154 LSB Of Device ID Register Offset */
#define TVP5154_ROM_MAJOR_VERSION_ADDR          (0x82)
/**< TVP5154 ROM Major Version Register Offset */
#define TVP5154_ROM_MINOR_VERSION_ADDR          (0x83)
/**< TVP5154 ROM Minor Version Register Offset */
#define TVP5154_VERT_LINE_COUNT_MSB_ADDR        (0x84)
/**< TVP5154 Vertical Line Count MSB Register Offset */
#define TVP5154_VERT_LINE_COUNT_LSB_ADDR        (0x85)
/**< TVP5154 Vertical Line Count LSB Register Offset */
#define TVP5154_INT_STATUS_REG_B_ADDR           (0x86)
/**< TVP5154 Interrupt Status Reg_B Register Offset */
#define TVP5154_INT_ACTIVE_REG_B_ADDR           (0x87)
/**< TVP5154 Interrupt Active_Reg_B Register Offset */
#define TVP5154_STATUS_REG_1_ADDR               (0x88)
/**< TVP5154 Status Reg 1 Register Offset */
#define TVP5154_STATUS_REG_2_ADDR               (0x89)
/**< TVP5154 Status Reg 2 Register Offset */
#define TVP5154_STATUS_REG_3_ADDR               (0x8A)
/**< TVP5154 Status Reg 3 Register Offset */
#define TVP5154_STATUS_REG_4_ADDR               (0x8B)
/**< TVP5154 Status Reg 4 Register Offset */
#define TVP5154_STATUS_REG_5_ADDR               (0x8C)
/**< TVP5154 Status Reg 5 Register Offset */

#define TVP5154_CC_FIELD_1_BYTE_1_ADDR          (0x90)
/**< TVP5154 CC_Field 1 Byte 1 Register Offset */
#define TVP5154_CC_FIELD_1_BYTE_2_ADDR          (0x91)
/**< TVP5154 CC Field 1 Byte 2 Register Offset */
#define TVP5154_CC_FIELD_2_BYTE_1_ADDR          (0x92)
/**< TVP5154 CC Field 2 Byte 1 Register Offset */
#define TVP5154_CC_FIELD_2_BYTE_2_ADDR          (0x93)
/**< TVP5154 CC Field 2 Byte 2 Register Offset */
#define TVP5154_WSS_FIELD_1_BYTE_1_ADDR         (0x94)
/**< TVP5154 WSS Field 1 Byte 1 Register Offset */
#define TVP5154_WSS_FIELD_1_BYTE_2_ADDR         (0x95)
/**< TVP5154 WSS Field 1 Byte 2 Register Offset */
#define TVP5154_WSS_FIELD_1_BYTE_3_ADDR         (0x96)
/**< TVP5154 WSS Field 1 Byte 3 Register Offset */
#define TVP5154_WSS_FIELD_2_BYTE_1_ADDR         (0x97)
/**< TVP5154 WSS Field 2 Byte 1 Register Offset */
#define TVP5154_WSS_FIELD_2_BYTE_2_ADDR         (0x98)
/**< TVP5154 WSS Field 2 Byte 2 Register Offset */
#define TVP5154_WSS_FIELD_2_BYTE_3_ADDR         (0x99)
/**< TVP5154 WSS Field 2 Byte 3 Register Offset */
#define TVP5154_VPS_BYTE_1_ADDR                 (0x9A)
/**< TVP5154 VPS Byte 1 Register Offset */
#define TVP5154_VPS_BYTE_2_ADDR                 (0x9B)
/**< TVP5154 VPS Byte 2 Register Offset */
#define TVP5154_VPS_BYTE_3_ADDR                 (0x9C)
/**< TVP5154 VPS Byte 3 Register Offset */
#define TVP5154_VPS_BYTE_4_ADDR                 (0x9D)
/**< TVP5154 VPS Byte 4 Register Offset */
#define TVP5154_VPS_BYTE_5_ADDR                 (0x9E)
/**< TVP5154 VPS Byte 5 Register Offset */
#define TVP5154_VPS_BYTE_6_ADDR                 (0x9F)
/**< TVP5154 VPS Byte 6 Register Offset */
#define TVP5154_VPS_BYTE_7_ADDR                 (0xA0)
/**< TVP5154 VPS Byte 7 Register Offset */
#define TVP5154_VPS_BYTE_8_ADDR                 (0xA1)
/**< TVP5154 VPS Byte 8 Register Offset */
#define TVP5154_VPS_BYTE_9_ADDR                 (0xA2)
/**< TVP5154 VPS Byte 9 Register Offset */
#define TVP5154_VPS_BYTE_10_ADDR                (0xA3)
/**< TVP5154 VPS Byte 10 Register Offset */
#define TVP5154_VPS_BYTE_11_ADDR                (0xA4)
/**< TVP5154 VPS Byte 11 Register Offset */
#define TVP5154_VPS_BYTE_12_ADDR                (0xA5)
/**< TVP5154 VPS Byte 12 Register Offset */
#define TVP5154_VPS_BYTE_13_ADDR                (0xA6)
/**< TVP5154 VPS Byte 13 Register Offset */
#define TVP5154_VITC_FRAME_BYTE_1_ADDR          (0xA7)
/**< TVP5154 VITC Frame Byte 1 Register Offset */
#define TVP5154_VITC_FRAME_BYTE_2_ADDR          (0xA8)
/**< TVP5154 VITC Frame Byte 2 Register Offset */
#define TVP5154_VITC_SECONDS_BYTE_1_ADDR        (0xA9)
/**< TVP5154 VITC Seconds Byte 1 Register Offset */
#define TVP5154_VITC_SECONDS_BYTE_2_ADDR        (0xAA)
/**< TVP5154 VITC Seconds Byte 2 Register Offset */
#define TVP5154_VITC_MINUTES_BYTE_1_ADDR        (0xAB)
/**< TVP5154 VITC Minutes Byte 1 Register Offset */
#define TVP5154_VITC_MINUTES_BYTE_2_ADDR        (0xAC)
/**< TVP5154 VITC Minutes Byte 2 Register Offset */
#define TVP5154_VITC_HOUR_BYTE_1_ADDR           (0xAD)
/**< TVP5154 VITC Hour Byte 1 Register Offset */
#define TVP5154_VITC_HOUR_BYTE_2_ADDR           (0xAE)
/**< TVP5154 VITC Hour Byte 2 Register Offset */
#define TVP5154_VITC_CRC_ADDR                   (0xAF)
/**< TVP5154 VITC CRC Register Offset */
#define TVP5154_VBI_FIFO_READ_DATA_ADDR         (0xB0)
/**< TVP5154 VBI FIFO Read Data Register Offset */
#define TVP5154_FILTER_1_MASK_1_ADDR            (0xB1)
/**< TVP5154 Filter 1 Mask 1 Register Offset */
#define TVP5154_FILTER_1_MASK_2_ADDR            (0xB2)
/**< TVP5154 Filter 1 Mask 2 Register Offset */
#define TVP5154_FILTER_1_MASK_3_ADDR            (0xB3)
/**< TVP5154 Filter 1 Mask 3 Register Offset */
#define TVP5154_FILTER_1_MASK_4_ADDR            (0xB4)
/**< TVP5154 Filter 1 Mask 4 Register Offset */
#define TVP5154_FILTER_1_MASK_5_ADDR            (0xB5)
/**< TVP5154 Filter 1 Mask 5 Register Offset */
#define TVP5154_FILTER_2_MASK_1_ADDR            (0xB6)
/**< TVP5154 Filter 2 Mask 1 Register Offset */
#define TVP5154_FILTER_2_MASK_2_ADDR            (0xB7)
/**< TVP5154 Filter 2 Mask 2 Register Offset */
#define TVP5154_FILTER_2_MASK_3_ADDR            (0xB8)
/**< TVP5154 Filter 2 Mask 3 Register Offset */
#define TVP5154_FILTER_2_MASK_4_ADDR            (0xB9)
/**< TVP5154 Filter 2 Mask 4 Register Offset */
#define TVP5154_FILTER_2_MASK_5_ADDR            (0xBA)
/**< TVP5154 Filter 2 Mask 5 Register Offset */
#define TVP5154_TELETEXT_FILTER_ENABLE_ADDR     (0xBB)
/**< TVP5154 Teletext Filter Enable Register Offset */

#define TVP5154_INT_STATUS_REG_A_ADDR           (0xC0)
/**< TVP5154 Interrupt Status Reg A Register Offset */
#define TVP5154_INT_ENABLE_REG_A_ADDR           (0xC1)
/**< TVP5154 Interrupt Enable Reg A Register Offset */
#define TVP5154_INT_CONF_ADDR                   (0xC2)
/**< TVP5154 Interrupt Conf Register Offset */
#define TVP5154_VDP_CONF_RAM_DATA_ADDR          (0xC3)
/**< TVP5154 VDP_Conf_RAM Data Register Offset */
#define TVP5154_CONF_RAM_ADDR_LOW_BYTE_ADDR     (0xC4)
/**< TVP5154 Conf RAM LSB Register Offset */
#define TVP5154_CONF_RAM_ADDR_HIGH_BYTE_ADDR    (0xC5)
/**< TVP5154 Conf RAM MSB Register Offset */
#define TVP5154_VDP_STATUS_REG_ADDR             (0xC6)
/**< TVP5154 VDP Status Reg Register Offset */
#define TVP5154_FIFO_WORD_COUNT_ADDR            (0xC7)
/**< TVP5154 FIFO Word Count Register Offset */
#define TVP5154_FIFO_INT_THRESHOLD_ADDR         (0xC8)
/**< TVP5154 FIFO Interrupt Threshold Register Offset */
#define TVP5154_FIFO_RESET_ADDR                 (0xC9)
/**< TVP5154 FIFO Reset Register Offset */
#define TVP5154_LINE_NUM_INT_ADDR               (0xCA)
/**< TVP5154 Line Num Int Register Offset */
#define TVP5154_PIX_ALIGN_REG_LOW_BYTE_ADDR     (0xCB)
/**< TVP5154 Pix Align Reg Low Byte Register Offset */
#define TVP5154_PIX_ALIGN_REG_HIGH_BYTE_ADDR    (0xCC)
/**< TVP5154 Pix Align Reg High Byte Register Offset */
#define TVP5154_FIFO_OUTPUT_CTRL_ADDR           (0xCD)
/**< TVP5154 FIFO Output Control Register Offset */

#define TVP5154_FULL_FIELD_ENABLE_ADDR          (0xCF)
/**< TVP5154 Full Field Enable Register Offset */
#define TVP5154_LINE_MODE_REG_ADDR              (0xD0)
/**< TVP5154 Line Mode Reg Register Offset */

#define TVP5154_FULL_FIELD_MODE_REG_ADDR        (0xFC)
/**< TVP5154 Full Field Mode Reg Register Offset */

#define TVP5154_DECODER_WRITE_ENABLES_ADDR      (0xFE)
/**< TVP5154 Decoder Write Enables Register Offset */
#define TVP5154_DECODER_READ_ENABLES_ADDR       (0xFF)
/**< TVP5154 Decoder Read Enables Register Offset */

/* defines for configuration values */
#define TVP5154_EMBEDDED_SYNC                   (0x07)
/**< Embedded Sync value */
#define TVP5154_HSYNC_START_PAL                 (0x7B)
/**< HSync Start value for PAL */
#define TVP5154_HSYNC_START_NTSC                (0x7C)
/**< HSync Start value for NTSC */
#define TVP5154_MODE_VAL_AUTOSWITCH             (0x00)
/**< Mode value for autoswitch */
#define TVP5154_MODE_VAL_NTSC                   (0x02)
/**< Mode value for NTSC */
#define TVP5154_MODE_VAL_PAL                    (0x04)
/**< Mode value for PAL */
#define TVP5154_EN_YCBCR_CLK                    (0x09)
/**< Value to enable YCbCr sequence and Clock */
#define TVP5154_EXTERNAL_SYNC                   (0x00)
/**< External Sync value */
#define TVP5154_AFMT_VAL_SVIDEO                 (0x01)
/**< Analog format value for Svideo */
#define TVP5154_AFMT_VAL_COMPOSITE_B            (0x02)
/**< Analog format value for Composite channel B */
#define TVP5154_AFMT_VAL_COMPOSITE_A            (0x00)
/**< Analog format value for Composite channel A */
#define TVP5154_MODE_MASK                       (0x0F)
/**< Mask for Mode Field */
#define TVP5154_OP_MODE_POWER_OFF_VAL           (0x01)
/**< Mode value to Power off */
#define TVP5154_OP_MODE_POWER_ON_VAL            (0x00)
/**< Mode value to Power on */
#define TVP5154_RESERVED_POWER_ON_VAL           (0x00)
/**< Reserved power on value */
#define TVP5154_READ_VALUE                      (0x54)
/**< Signature after proper power on */
#define TVP5154_MODE_MASK_NTSC                  (0x01)
/**< Mask for NTSC Mode Field */
#define TVP5154_MODE_MASK_PAL                   (0x03)
/**< Mask for PAL Mode Field */
#define TVP5154_7_5_IRE_PEDESTAL_MASK           (0x20)
/**< Mask for 7.5 IRE pedestal Field */

/**
 *  \brief  TVP5154 channel object Structure
 *  Channel object structure for TVP5154 channels
 */
typedef struct _TVP5154_chanObj_t
{
    Uint8     decNum;
    /**< Decoder number to which channel belongs to */

    Uint8     chanMask;
    /**< Mask for decoder channel number */

#ifdef ENABLE_EDC_DEBUG
    Uint8     regSpace[256];
    /**< To store enhance debugging register values*/
#endif /* ENABLE_EDC_DEBUG */
}_TVP5154_chanObj;  /**< Typedef for struct _TVP5154_chanObj_t */

/**
 *  \brief  TVP5154 decoder object Structure
 *  Decoder object structure for TVP5154 decoder
 */
typedef struct _TVP5154_decObj_t
{
    Uint8                addrI2C;
    /**< i2c address of the decoder */

    PAL_OsSemHandle      decChanSem;
    /**< decoder semaphore handle */

    Uint8                chanOpenCnt;
    /**< count for opened channel */

    _TVP5154_chanObj     chanObj[NUM_CHANNELS];
    /**< decoder channel objects */
}_TVP5154_decObj;   /**< Typedef for struct _TVP5154_decObj_t */

#ifdef __cplusplus
}
#endif

#endif /* __TVP5154_H */

/******************************************************************************/
/* End of file                                                                */
/******************************************************************************/
