/*******************************************************************************
**+--------------------------------------------------------------------------+**
**|                            ****                                          |**
**|                            ****                                          |**
**|                            ******o***                                    |**
**|                      ********_///_****                                   |**
**|                      ***** /_//_/ ****                                   |**
**|                       ** ** (__/ ****                                    |**
**|                           *********                                      |**
**|                            ****                                          |**
**|                            ***                                           |**
**|                                                                          |**
**|         Copyright (c) 1998-2007 Texas Instruments Incorporated           |**
**|                        ALL RIGHTS RESERVED                               |**
**|                                                                          |**
**| Permission is hereby granted to licensees of Texas Instruments           |**
**| Incorporated (TI) products to use this computer program for the sole     |**
**| purpose of implementing a licensee product based on TI products.         |**
**| No other rights to reproduce, use, or disseminate this computer          |**
**| program, whether in part or in whole, are granted.                       |**
**|                                                                          |**
**| TI makes no representation or warranties with respect to the             |**
**| performance of this computer program, and specifically disclaims         |**
**| any responsibility for any damages, special or consequential,            |**
**| connected with the use of this program.                                  |**
**|                                                                          |**
**+--------------------------------------------------------------------------+**
*******************************************************************************/

/**
 *  \file _tvp7000.c
 *
 *  This file contains structure variables for TVP7000 decoder register settings
 */

/*
 * ========= Include Files ==========
 */
#include <ti/sdo/pspdrivers/system/dm648/bios/evmDM648/video/src/_tvp7000.h>


/*
 * ========= USER CONFIGURABLE MACROS ==========
 */

/**
 * Define this macro to 1 to enable software workaround for 1080i and 720p
 * capture in production EVM.
 * For proper 1080i capture, TVP7000 HSYNC polarity is inverted (active low) and
 * hence a horizontal shift is required in the field1 and field2 HSTART.
 * For proper 720p capture, TVP7000 HSYNC output start value is changed. Still
 * DM648 VPORT detects the progressive input from TVP7000 as interlaced video.
 * Hence VPORT driver should be configured to capture both fields
 * so that two 720p frames are captured per FVID call.
 */
#define CFG_ENABLE_HDCAPTURE_WORKAROUND     (1)


/*
 * ========= CONSTANTS ===========
 */

/** TVP7000 default register settings */
const Uint8 tvp7000_default[] =
{
    0x80,       /* 0x08 Blue Fine Gain */
    0x80,       /* 0x09 Green Fine Gain */
    0x80,       /* 0x0A Red Fine Gain */
    0x80,       /* 0x0B Blue Fine Offset */
    0x80,       /* 0x0C Green Fine Offset */
    0x80,       /* 0x0D Red Fine Offset */
    0x20,       /* 0x0E Sync Control */
    0x2E,       /* 0x0F PLL and Clamp Control */
    0x85,       /* 0x10 Sync On Green Threshold */
    0x47,       /* 0x11 Sync Separator Threshold */

    0x02,       /* 0x15 Output Formatter */
    0x2D,       /* 0x16 Test Register */

    0x00,       /* 0x19 Input Mux Select 1 */
    0x80,       /* 0x1A Input Mux Select 2 */
    0x55,       /* 0x1B Blue and Green Coarse Gain */
    0x05,       /* 0x1C Red Coarse Gain */
    0x00,       /* 0x1D Fine Offset LSB */
    0x1F,       /* 0x1E Blue Coarse Offset */
    0x1F,       /* 0x1F Green Coarse Offset */
    0x1F,       /* 0x20 Red Coarse Offset */
    0x08,       /* 0x21 HSync Output Start */
    0x00,       /* 0x22 Misc Control */

    0x80,       /* 0x26 Automatic Level Control Enable */

    0x03,       /* 0x28 Automatic Level Control Filter */

    0x07,       /* 0x2A Fine Clamp Control */
    0x00,       /* 0x2B Power Control */
    0x50,       /* 0x2C ADC Setup */
    0x00,       /* 0x2D Coarse Clamp Control */
    0x80,       /* 0x2E SOG Clamp */
};

/** TVP7000 Register settings for 480P 60Hz EDTV capture */
const _TVP7000_Regs tvp7000_480p_60Hz_Regs =
{
    0x6B,       /* 0x01 PLL divide MSB */
    0x40,       /* 0x02 PLL divide LSB */
    0x68,       /* 0x03 PLL control */
    0xB1,       /* 0x04 Phase Select */
    0x06,       /* 0x05 Clamp start */
    0x10,       /* 0x06 Clamp Width */
    0x40,       /* 0x07 HSYNC Output Width */
    0x20,       /* 0x0E Sync Control */
    0x85,       /* 0x10 Sync On Green Threshold */
    0x03,       /* 0x12 Pre-Coast */
    0x0C,       /* 0x13 Post-Coast */
    0x0A,       /* 0x21 HSOUT output start */
    0x18        /* 0x31 ALC Placement */
};

/** TVP7000 Register settings for 576P 50Hz EDTV capture */
const _TVP7000_Regs tvp7000_576p_50Hz_Regs =
{
    0x6C,       /* 0x01 PLL divide MSB */
    0x00,       /* 0x02 PLL divide LSB */
    0x68,       /* 0x03 PLL control */
    0xB1,       /* 0x04 Phase Select */
    0x06,       /* 0x05 Clamp start */
    0x10,       /* 0x06 Clamp Width */
    0x32,       /* 0x07 HSYNC Output Width */
    0x20,       /* 0x0E Sync Control */
    0x85,       /* 0x10 Sync On Green Threshold */
    0x03,       /* 0x12 Pre-Coast */
    0x0C,       /* 0x13 Post-Coast */
    0x08,       /* 0x21 HSOUT output start */
    0x18        /* 0x31 ALC Placement */
};

/** TVP7000 Register settings for 720P 60Hz HDTV capture */
const _TVP7000_Regs tvp7000_720p_60Hz_Regs =
{
    0x67,       /* 0x01 PLL divide MSB */
    0x20,       /* 0x02 PLL divide LSB */
    0xA8,       /* 0x03 PLL control */
    0xB0,       /* 0x04 Phase Select */
    0x32,       /* 0x05 Clamp start */
    0x20,       /* 0x06 Clamp Width */
    0x28,       /* 0x07 HSYNC Output Width */

#if (CFG_ENABLE_HDCAPTURE_WORKAROUND == 1)

    0x20,       /* 0x0E Sync Control */
    0x55,       /* 0x10 Sync On Green Threshold */

#else

    0x20,       /* 0x0E Sync Control */
    0x85,       /* 0x10 Sync On Green Threshold */

#endif  /* #if (CFG_ENABLE_HDCAPTURE_WORKAROUND == 1) */

    0x00,       /* 0x12 Pre-Coast */
    0x00,       /* 0x13 Post-Coast */

#if (CFG_ENABLE_HDCAPTURE_WORKAROUND == 1)

    0x26,       /* 0x21 HSOUT output start */

#else

    0x30,       /* 0x21 HSOUT output start */

#endif  /* #if (CFG_ENABLE_HDCAPTURE_WORKAROUND == 1) */

    0x5A        /* 0x31 ALC Placement */
};

/** TVP7000 Register settings for 720P 50Hz HDTV capture */
const _TVP7000_Regs tvp7000_720p_50Hz_Regs =
{
    0x7B,       /* 0x01 PLL divide MSB */
    0xC0,       /* 0x02 PLL divide LSB */
    0xA8,       /* 0x03 PLL control */
    0xB0,       /* 0x04 Phase Select */
    0x32,       /* 0x05 Clamp start */
    0x20,       /* 0x06 Clamp Width */
    0x22,       /* 0x07 HSYNC Output Width */
    0x20,       /* 0x0E Sync Control */
    0x85,       /* 0x10 Sync On Green Threshold */
    0x00,       /* 0x12 Pre-Coast */
    0x00,       /* 0x13 Post-Coast */
    0x08,       /* 0x21 HSOUT output start */
    0x5A        /* 0x31 ALC Placement */
};

/** TVP7000 Register settings for 1080i 60Hz HDTV capture */
const _TVP7000_Regs tvp7000_1080i_60Hz_Regs =
{
    0x89,       /* 0x01 PLL divide MSB */
    0x80,       /* 0x02 PLL divide LSB */
    0xA8,       /* 0x03 PLL control */
    0xA0,       /* 0x04 Phase Select */
    0x32,       /* 0x05 Clamp start */
    0x20,       /* 0x06 Clamp Width */
    0x2C,       /* 0x07 HSYNC Output Width */

#if (CFG_ENABLE_HDCAPTURE_WORKAROUND == 1)

    0x00,       /* 0x0E Sync Control */
    0x6D,       /* 0x10 Sync On Green Threshold */

#else

    0x20,       /* 0x0E Sync Control */
    0x85,       /* 0x10 Sync On Green Threshold */

#endif  /* #if (CFG_ENABLE_HDCAPTURE_WORKAROUND == 1) */

    0x03,       /* 0x12 Pre-Coast */
    0x00,       /* 0x13 Post-Coast */

#if (CFG_ENABLE_HDCAPTURE_WORKAROUND == 1)

    0x26,       /* 0x21 HSOUT output start */

#else

    0x34,       /* 0x21 HSOUT output start */

#endif  /* #if (CFG_ENABLE_HDCAPTURE_WORKAROUND == 1) */

    0x5A        /* 0x31 ALC Placement */
};

/** TVP7000 Register settings for 1080i 50Hz HDTV capture */
const _TVP7000_Regs tvp7000_1080i_50Hz_Regs =
{
    0xA5,       /* 0x01 PLL divide MSB */
    0x00,       /* 0x02 PLL divide LSB */
    0xA8,       /* 0x03 PLL control */
    0xA0,       /* 0x04 Phase Select */
    0x32,       /* 0x05 Clamp start */
    0x20,       /* 0x06 Clamp Width */
    0x25,       /* 0x07 HSYNC Output Width */

#if (CFG_ENABLE_HDCAPTURE_WORKAROUND == 1)

    0x20,       /* 0x0E Sync Control */
    0x85,       /* 0x10 Sync On Green Threshold */

#else

    0x20,       /* 0x0E Sync Control */
    0x85,       /* 0x10 Sync On Green Threshold */

#endif  /* #if (CFG_ENABLE_HDCAPTURE_WORKAROUND == 1) */

    0x03,       /* 0x12 Pre-Coast */
    0x00,       /* 0x13 Post-Coast */

#if (CFG_ENABLE_HDCAPTURE_WORKAROUND == 1)

    0x34,       /* 0x21 HSOUT output start */

#else

    0x34,       /* 0x21 HSOUT output start */

#endif  /* #if (CFG_ENABLE_HDCAPTURE_WORKAROUND == 1) */

    0x5A        /* 0x31 ALC Placement */
};


/******************************************************************************/
/* End of file                                                                */
/******************************************************************************/
