/*******************************************************************************
**+--------------------------------------------------------------------------+**
**|                            ****                                          |**
**|                            ****                                          |**
**|                            ******o***                                    |**
**|                      ********_///_****                                   |**
**|                      ***** /_//_/ ****                                   |**
**|                       ** ** (__/ ****                                    |**
**|                           *********                                      |**
**|                            ****                                          |**
**|                            ***                                           |**
**|                                                                          |**
**|         Copyright (c) 1998-2007 Texas Instruments Incorporated           |**
**|                        ALL RIGHTS RESERVED                               |**
**|                                                                          |**
**| Permission is hereby granted to licensees of Texas Instruments           |**
**| Incorporated (TI) products to use this computer program for the sole     |**
**| purpose of implementing a licensee product based on TI products.         |**
**| No other rights to reproduce, use, or disseminate this computer          |**
**| program, whether in part or in whole, are granted.                       |**
**|                                                                          |**
**| TI makes no representation or warranties with respect to the             |**
**| performance of this computer program, and specifically disclaims         |**
**| any responsibility for any damages, special or consequential,            |**
**| connected with the use of this program.                                  |**
**|                                                                          |**
**+--------------------------------------------------------------------------+**
*******************************************************************************/

/**
 *  \file    _tvp7000.h
 *
 *  This file contains internal structures and defines for TVP7000 decoder
 */

#ifndef __TVP7000_H
#define __TVP7000_H

/*
 * =========== INCLUDE FILES ==========
 */
#include <ti/sdo/pspdrivers/system/dm648/bios/evmDM648/video/tvp7000.h>

#ifdef __cplusplus
extern "C" {
#endif

/*
 * =========== DEFINES ==========
 */
#define _TVP7000_IIC_ADDR               (0xB8 >> 1)
/**< TVP7000 I2C address */
#define _THS7353_IIC_ADDR               (0x58 >> 1)
/**< THS7353 I2C address */

/* TVP7000 register address defines */
#define TVP7000_CHIP_REVISION_ADDR          (0x00)
/**< TVP7000 Chip_Revision Regsiter Offset */

#define TVP7000_PLL_DIVIDE_MSB_ADDR         (0x01)
/**< TVP7000 PLL Divide MSB Regsiter Offset */
#define TVP7000_PLL_DIVIDE_LSB_ADDR         (0x02)
/**< TVP7000 PLL Divide LSB Regsiter Offset */
#define TVP7000_PLL_CTRL_ADDR               (0x03)
/**< TVP7000 PLL Control Regsiter Offset */
#define TVP7000_PHASE_SEL_ADDR              (0x04)
/**< TVP7000 Phase Select Regsiter Offset */

#define TVP7000_CLAMP_START_ADDR            (0x05)
/**< TVP7000 Clamp Start Regsiter Offset */
#define TVP7000_CLAMP_WIDTH_ADDR            (0x06)
/**< TVP7000 Clamp Width Regsiter Offset */

#define TVP7000_HSYNC_OUTPUT_WIDTH_ADDR     (0x07)
/**< TVP7000 Hsync Output Width Regsiter Offset */

#define TVP7000_B_FINE_GAIN_ADDR            (0x08)
/**< TVP7000 Blue Fine Gain Regsiter Offset */
#define TVP7000_G_FINE_GAIN_ADDR            (0x09)
/**< TVP7000 Green Fine Gain Regsiter Offset */
#define TVP7000_R_FINE_GAIN_ADDR            (0x0A)
/**< TVP7000 Red Fine Gain Regsiter Offset */

#define TVP7000_B_FINE_OFFSET_ADDR          (0x0B)
/**< TVP7000 Blue Fine Offset Regsiter Offset */
#define TVP7000_G_FINE_OFFSET_ADDR          (0x0C)
/**< TVP7000 Green Fine Offset Regsiter Offset */
#define TVP7000_R_FINE_OFFSET_ADDR          (0x0D)
/**< TVP7000 Red Fine Offset Regsiter Offset */

#define TVP7000_SYNC_CTRL_1_ADDR            (0x0E)
/**< TVP7000 Sync Control 1 Regsiter Offset */
#define TVP7000_PLL_AND_CLAMP_CTRL_ADDR     (0x0F)
/**< TVP7000 PLL and Clamp Control Regsiter Offset */

#define TVP7000_SYNC_ON_G_THRLD_ADDR        (0x10)
/**< TVP7000 Sync On Green Threshold Regsiter Offset */
#define TVP7000_SYNC_SEPARATOR_THRLD_ADDR   (0x11)
/**< TVP7000 Sync Separator Threshold Regsiter Offset */

#define TVP7000_PRE_COAST_ADDR              (0x12)
/**< TVP7000 Pre Coast Regsiter Offset */
#define TVP7000_POST_COAST_ADDR             (0x13)
/**< TVP7000 Post Coast Regsiter Offset */
#define TVP7000_SYNC_DETECT_STATUS_ADDR     (0x14)
/**< TVP7000 Sync Detect Status Regsiter Offset */

#define TVP7000_OUTPUT_FORMATER_ADDR        (0x15)
/**< TVP7000 Output Formater Regsiter Offset */
#define TVP7000_TEST_REG_ADDR               (0x16)
/**< TVP7000 Test Regsiter Offset */

#define TVP7000_INPUT_MUX_SEL_1_ADDR        (0x19)
/**< TVP7000 Input Mux Select 1 Regsiter Offset */
#define TVP7000_INPUT_MUX_SEL_2_ADDR        (0x1A)
/**< TVP7000 Input Mux Select 2 Regsiter Offset */

#define TVP7000_B_GREEN_COARSE_GAIN_ADDR    (0x1B)
/**< TVP7000 Blue and Green Coarse Gain Regsiter Offset */
#define TVP7000_R_COARSE_GAIN_ADDR          (0x1C)
/**< TVP7000 Red Coarse Gain Regsiter Offset */

#define TVP7000_FINE_OFFSET_LSB_ADDR        (0x1D)
/**< TVP7000 Fine Offset LSB Regsiter Offset */
#define TVP7000_B_COARSE_OFFSET_ADDR        (0x1E)
/**< TVP7000 Blue Coarse Offset Regsiter Offset */
#define TVP7000_G_COARSE_OFFSET_ADDR        (0x1F)
/**< TVP7000 Green Coarse Offset Regsiter Offset */
#define TVP7000_R_COARSE_OFFSET_ADDR        (0x20)
/**< TVP7000 Red Coarse Offset Regsiter Offset */

#define TVP7000_HSOUT_OUTPUT_START_ADDR     (0x21)
/**< TVP7000 HSout Output Start Regsiter Offset */
#define TVP7000_MISC_CTRL_ADDR              (0x22)
/**< TVP7000 Misc Control Regsiter Offset */

#define TVP7000_AUTO_LVL_CNT_ENABLE_ADDR    (0x26)
/**< TVP7000 Auto Level Count Enable Regsiter Offset */
#define TVP7000_AUTO_LVL_CNT_FILTER_ADDR    (0x28)
/**< TVP7000 Auto Level Count Filter Regsiter Offset */

#define TVP7000_FINE_CLAMP_CTRL_ADDR        (0x2A)
/**< TVP7000 Fine Clamp Control Regsiter Offset */
#define TVP7000_POWER_CTRL_ADDR             (0x2B)
/**< TVP7000 Power Control Regsiter Offset */
#define TVP7000_ADC_SETUP_ADDR              (0x2C)
/**< TVP7000 ADC Setup Regsiter Offset */

#define TVP7000_COARSE_CLAMP_CTRL_ADDR      (0x2D)
/**< TVP7000 Coarse Clamp Control Regsiter Offset */
#define TVP7000_SOG_CLAMP_ADDR              (0x2E)
/**< TVP7000 SOG Clamp Regsiter Offset */
#define TVP7000_ALC_PLACEMENT_ADDR          (0x31)
/**< TVP7000 ALC Placement Regsiter Offset */

/* THS7353 register address defines */
#define THS7353_CHANNEL1_ADDR               (0x01)
/**< THS7353 Channel1 Regsiter Offset */
#define THS7353_CHANNEL2_ADDR               (0x02)
/**< THS7353 Channel2 Regsiter Offset */
#define THS7353_CHANNEL3_ADDR               (0x03)
/**< THS7353 Channel3 Regsiter Offset */

/* EDTV Default Value for THS7353 Filter */
#define THS7353_EDTV_Y_CHANNEL_DEF          (0x4D)
/**< EDTV default value for Y channel */
#define THS7353_EDTV_PB_CHANNEL_DEF         (0x4C)
/**< EDTV default value for Pb channel */
#define THS7353_EDTV_PR_CHANNEL_DEF         (0x4C)
/**< EDTV default value for Pr channel */

/* HDTV Default Value for THS7353 Filter */
#define THS7353_HDTV_Y_CHANNEL_DEF          (0xD5)
/**< HDTV default value for Y channel */
#define THS7353_HDTV_PB_CHANNEL_DEF         (0xD5)
/**< HDTV default value for Pb channel */
#define THS7353_HDTV_PR_CHANNEL_DEF         (0xD5)
/**< HDTV default value for Pr channel */

/* define number of bytes to read/write for each register set */
#define PLL_REG_CNT                         (7)
/**< Number of bytes to read/write after PLL register */
#define COAST_REG_CNT                       (2)
/**< Number of bytes to read/write after Coast register */

/* defines for configuration values */
#define TVP7000_IN_MUX_SEL2_DEF             (0x80)
/**< Default value for In Mux Select 2 Register */

#define TVP7000_IN_MUX_SEL1_MASK            (0x03)
/**< Mask for In Mux Select 1 Field */
#define TVP7000_IN_MUX_SEL1_BLUE_SHIFT      (0x00)
/**< Shift for In Mux Select 1 Blue Field */
#define TVP7000_IN_MUX_SEL1_GREEN_SHIFT     (0x02)
/**< Shift for In Mux Select 1 Green Field */
#define TVP7000_IN_MUX_SEL1_RED_SHIFT       (0x04)
/**< Shift for In Mux Select 1 Red Field */
#define TVP7000_IN_MUX_SEL1_SOG_SHIFT       (0x06)
/**< Shift for In Mux Select 1 SOG Field */

#define TVP7000_IN_MUX_SEL2_MASK            (0x01)
/**< Mask for In Mux Select 2 Field */
#define TVP7000_IN_MUX_SEL2_HSYNC_SHIFT     (0x00)
/**< Shift for In Mux Select 2 HSync Field */
#define TVP7000_IN_MUX_SEL2_VSYNC_SHIFT     (0x02)
/**< Shift for In Mux Select 2 Vsync Field */

#define TVP7000_CHIP_POWER_DOWN_BIT         (0x02)
/**< Bit position for Chip Power Down Field */

#define TVP7000_OUT_FORMATER_444_422_BIT    (0x02)
/**< Bit position for Output Formatter Field */


/**
  * \brief  TVP7000 register settings Structure
  *  Structure to contain TVP7000 register setting values
  */
typedef struct _TVP7000_Regs_t
{
    Uint8 pll_divide_msb;
    /**< PLL Divide register MSB 0x01 */
    Uint8 pll_divide_lsb;
    /**< PLL Divide register LSB 0x02 */
    Uint8 pll_control;
    /**< PLL Control register 0x03 */
    Uint8 phase_select;
    /**< Phase Select register 0x04 */

    Uint8 clamp_start;
    /**< Clamp Start register 0x05 */
    Uint8 clamp_width;
    /**< Clamp Width register 0x06 */

    Uint8 hsync_out_width;
    /**< HSYNC Output Width register 0x07 */

    Uint8 sync_ctrl_1;
    /**< Sync Control 1 register 0x0E */

    Uint8 sync_on_g_thrld;
    /**< Sync On-Green Threshold register 0x10 */

    Uint8 pre_coast;
    /**< Pre-Coast register 0x12 */
    Uint8 post_coast;
    /**< Post-Coast register 0x13 */

    Uint8 hsout_start;
    /**< HSOUT Output Start register 0x21 */

    Uint8 alc_placement;
    /**< ALC Placement register 0x31 */
} _TVP7000_Regs;    /**< Typedef for structure _TVP7000_Regs_t */


/*
 * ======== EXTERNS =========
 */
extern const Uint8          tvp7000_default[];
extern const _TVP7000_Regs  tvp7000_480p_60Hz_Regs;
extern const _TVP7000_Regs  tvp7000_576p_50Hz_Regs;
extern const _TVP7000_Regs  tvp7000_720p_60Hz_Regs;
extern const _TVP7000_Regs  tvp7000_720p_50Hz_Regs;
extern const _TVP7000_Regs  tvp7000_1080i_60Hz_Regs;
extern const _TVP7000_Regs  tvp7000_1080i_50Hz_Regs;

#ifdef __cplusplus
}
#endif

#endif /* __TVP7000_H */

/******************************************************************************/
/* End of file                                                                */
/******************************************************************************/
