/*******************************************************************************
**+--------------------------------------------------------------------------+**
**|                            ****                                          |**
**|                            ****                                          |**
**|                            ******o***                                    |**
**|                      ********_///_****                                   |**
**|                      ***** /_//_/ ****                                   |**
**|                       ** ** (__/ ****                                    |**
**|                           *********                                      |**
**|                            ****                                          |**
**|                            ***                                           |**
**|                                                                          |**
**|         Copyright (c) 1998-2007 Texas Instruments Incorporated           |**
**|                        ALL RIGHTS RESERVED                               |**
**|                                                                          |**
**| Permission is hereby granted to licensees of Texas Instruments           |**
**| Incorporated (TI) products to use this computer program for the sole     |**
**| purpose of implementing a licensee product based on TI products.         |**
**| No other rights to reproduce, use, or disseminate this computer          |**
**| program, whether in part or in whole, are granted.                       |**
**|                                                                          |**
**| TI makes no representation or warranties with respect to the             |**
**| performance of this computer program, and specifically disclaims         |**
**| any responsibility for any damages, special or consequential,            |**
**| connected with the use of this program.                                  |**
**|                                                                          |**
**+--------------------------------------------------------------------------+**
*******************************************************************************/

/**
 *  \file    psp_i2c_interface.h
 *
 *  This file contains I2C interface function declaration for external devices
 */

#ifndef _PSP_I2C_INTERFACE_H
#define _PSP_I2C_INTERFACE_H


/*
 * ========== INCLUDE FILES ==============
 */
#include <std.h>

#ifdef __cplusplus
extern "C" {
#endif

/*
 * ========== FUNCTION DECLARATIONS =========
 */

/**
 *  \brief I2C Init
 *
 *  This function must be called before starting any i2c operations
 *
 *  \return  EDC_SUCCESS if successful else EDC_FAILED error code.
 */
Int32 i2c_init(void);

/**
 *  \brief I2C Deinit
 *
 *  This function should be called to deinitialize i2c module
 *
 *  \return  EDC_SUCCESS if successful else EDC_FAILED error code.
 */
Int32 i2c_deInit(void);

/**
 *  \brief I2C write register
 *
 *  This function is called to write on register via i2c
 *
 *  \param   slaveAddr [IN] slave address
 *  \param   subAddr   [IN] sub address at which write operation to be performed
 *  \param   buffer    [IN] buffer address from which values to be read
 *  \param   length    [IN] length of i2c transfer
 *
 *  \return  EDC_SUCCESS if successful else EDC_FAILED error code.
 */
Int32 i2c_writeReg(Uint8 slaveAddr, Uint8 subAddr, const Uint8 *buffer,
                   Uint32 length);

/**
 *  \brief I2C read register
 *
 *  This function is called to write on register via i2c
 *
 *  \param   slaveAddr [IN] slave address
 *  \param   subAddr   [IN] sub address at which write operation to be performed
 *  \param   buffer    [OUT] buffer address at which read values to be stored
 *  \param   length    [IN] length of i2c transfer
 *
 *  \return  EDC_SUCCESS if successful else EDC_FAILED error code.
 */
Int32 i2c_readReg(Uint8 slaveAddr, Uint8 subAddr, Uint8 *buffer, Uint32 length);

#ifdef __cplusplus
}
#endif

#endif  /* _PSP_I2C_INTERFACE_H */

/******************************************************************************/
/* End of file                                                                */
/******************************************************************************/

