/*******************************************************************************
**+--------------------------------------------------------------------------+**
**|                            ****                                          |**
**|                            ****                                          |**
**|                            ******o***                                    |**
**|                      ********_///_****                                   |**
**|                      ***** /_//_/ ****                                   |**
**|                       ** ** (__/ ****                                    |**
**|                           *********                                      |**
**|                            ****                                          |**
**|                            ***                                           |**
**|                                                                          |**
**|         Copyright (c) 1998-2007 Texas Instruments Incorporated           |**
**|                        ALL RIGHTS RESERVED                               |**
**|                                                                          |**
**| Permission is hereby granted to licensees of Texas Instruments           |**
**| Incorporated (TI) products to use this computer program for the sole     |**
**| purpose of implementing a licensee product based on TI products.         |**
**| No other rights to reproduce, use, or disseminate this computer          |**
**| program, whether in part or in whole, are granted.                       |**
**|                                                                          |**
**| TI makes no representation or warranties with respect to the             |**
**| performance of this computer program, and specifically disclaims         |**
**| any responsibility for any damages, special or consequential,            |**
**| connected with the use of this program.                                  |**
**|                                                                          |**
**+--------------------------------------------------------------------------+**
*******************************************************************************/

/**
 *  \file    tvp5154.h
 *
 *  This file contains configuration structure and enums for tvp5154 decoder
 */

#ifndef _TVP5154_H
#define _TVP5154_H


/*
 * ========= INCLUDE FILES ==========
 */
#include <std.h>
#include <ti/sdo/pspdrivers/drivers/vport/edc.h>

#ifdef __cplusplus
extern "C" {
#endif

/*
 * ========== Defines ==============
 */

/*
 * IOCTLS Supported
 */
/**
 *  \brief TVP5154 powerdown command
 *  This doesn't take any argument
 */
#define TVP5154_POWERDOWN               (EDC_USER + 1)

/**
 *  \brief TVP5154 powerup command
 *  This doesn't take any argument
 */
#define TVP5154_POWERUP                 (EDC_USER + 2)

/**
 *  \brief TVP5154 analog channel selection command
 *  The argument for this IOCTL is TVP5154_AnalogChan enum
 */
#define TVP5154_SET_ANALOG_CHAN         (EDC_USER + 3)

/**
 * Apart from above IOCTLS the following generic EDC IOCTLS are supported
 *
 * EDC_CONFIG   - Argument is a pointer to TVP5154_ConfParams structure
 * EDC_RESET    - Doesn't take any argument
 *
 * The following generic EDC IOCTLS are NOT supported
 *
 * EDC_START
 * EDC_STOP
 * EDC_GET_CONFIG
 * EDC_GET_STATUS
 */

/** \brief type define TVP5154 IOCTL command type */
typedef unsigned int TVP5154_Cmd;


/**
 *  \brief TVP5154 analog format Enum
 *  This enum gives available analog format selection with TVP5154 decoder
 */
typedef enum TVP5154_AnalogFormat_t
{
    TVP5154_AFMT_COMPOSITE_A,
    /**< decoder channel A selection for composite video input */
    TVP5154_AFMT_COMPOSITE_B,
    /**< decoder channel B selection for composite video
     * input (Not supported on EVM)
     */
    TVP5154_AFMT_SVIDEO
    /**< Analog for SVIDEO input */
} TVP5154_AnalogFormat;     /**< Typedef for enum TVP5154_AnalogFormat_t */

/**
 *  \brief TVP5154 analog channel selection Enum
 *  This enum gives available analog channel selection with TVP5154 decoder
 */
typedef enum TVP5154_AnalogChan_t
{
    TVP5154_AFMT_CHANNEL_A,
    /**< decoder channel A selection for composite video input,  */
    TVP5154_AFMT_CHANNEL_B
    /**< decoder channel B selection for composite video
     * input (Not supported on EVM) */
} TVP5154_AnalogChan;       /**< Typedef for enum TVP5154_AnalogChan_t */

/**
 *  \brief TVP5154 operation mode selection Enum
 *  This enum gives available mode selection with TVP5154 decoder
 */
typedef enum TVP5154_Mode_t
{
    TVP5154_MODE_NTSC,
    /**< NTSC mode */
    TVP5154_MODE_PAL,
    /**< PAL mode */
    TVP5154_MODE_SECAM
    /**< SECAM mode for future use, code not available for this mode */
} TVP5154_Mode;             /**< Typedef for enum TVP5154_Mode_t */

/**
 *  \brief TVP5154 configuration structure
 *  This structure contains configuration parameters for TVP5154 decoder
 */
typedef struct TVP5154_ConfParams_t
{
    TVP5154_Mode            mode;
    /**< indicates output format for TVP5154 */

    TVP5154_AnalogFormat    aFmt;
    /**< indicates analog input format for TVP5154 */

    Bool                    enableBT656Sync;
    /**< Boolean to select embedded or external sync for digital output
     * TRUE  = embedded sync
     * FALSE = external sync (Not supported on EVM)
     */
} TVP5154_ConfParams;       /**< Typedef for structure TVP5154_ConfParams_t */


/*
 * ========== EXTERNS ===========
 */
/* TVP5154 driver function table */
extern EDC_Fxns TVP5154_Fxns;

#ifdef __cplusplus
}
#endif

#endif  /* #ifndef _TVP5154_H */

/******************************************************************************/
/* End of file                                                                */
/******************************************************************************/
