/*******************************************************************************
**+--------------------------------------------------------------------------+**
**|                            ****                                          |**
**|                            ****                                          |**
**|                            ******o***                                    |**
**|                      ********_///_****                                   |**
**|                      ***** /_//_/ ****                                   |**
**|                       ** ** (__/ ****                                    |**
**|                           *********                                      |**
**|                            ****                                          |**
**|                            ***                                           |**
**|                                                                          |**
**|         Copyright (c) 1998-2006 Texas Instruments Incorporated           |**
**|                        ALL RIGHTS RESERVED                               |**
**|                                                                          |**
**| Permission is hereby granted to licensees of Texas Instruments           |**
**| Incorporated (TI) products to use this computer program for the sole     |**
**| purpose of implementing a licensee product based on TI products.         |**
**| No other rights to reproduce, use, or disseminate this computer          |**
**| program, whether in part or in whole, are granted.                       |**
**|                                                                          |**
**| TI makes no representation or warranties with respect to the             |**
**| performance of this computer program, and specifically disclaims         |**
**| any responsibility for any damages, special or consequential,            |**
**| connected with the use of this program.                                  |**
**|                                                                          |**
**+--------------------------------------------------------------------------+**
*******************************************************************************/

/** \file   psp_bios_i2c_main_sample.c
 *
 *  \brief  This file contains the test / demo code to demonstrate the
 *          I2C/EDMA/UART/NAND/VPSS driver implemented for DSP/BIOS
 *
 *  (C) Copyright 2006, Texas Instruments, Inc
 *
 *  \author     PSP Team
 *  \version    0.1
 */

#include <std.h>
#include <gio.h>
#include <log.h>
#include <tsk.h>

#include <ti/sdo/pspdrivers/pal_os/bios/psputils.h>
#include <ti/sdo/pspdrivers/drivers/uart/psp_uart.h>

#ifdef CHIP_DM648
#include <ti/sdo/pspdrivers/pal_sys/dm648/pal_sys.h>
#include <ti/sdo/pspdrivers/pal_sys/dm648/pal_sys_soc.h>
#include <ti/sdo/pspdrivers/soc/dm648/dsp/soc.h>
#include <ti/sdo/pspdrivers/soc/dm648/dsp/cslr_sys.h>
#include <ti/sdo/pspdrivers/soc/dm648/dsp/cslr_psc.h>
#endif

#ifdef CHIP_C6452
#include <ti/sdo/pspdrivers/pal_sys/c6452/pal_sys.h>
#include <ti/sdo/pspdrivers/pal_sys/c6452/pal_sys_soc.h>
#include <ti/sdo/pspdrivers/soc/c6452/dsp/soc.h>
#include <ti/sdo/pspdrivers/soc/c6452/dsp/cslr_sys.h>
#include <ti/sdo/pspdrivers/soc/c6452/dsp/cslr_psc.h>
#endif

#define PSP_DEBUG_PRINT       kprintf


/*
 * EDMA handle
 */
GIO_Handle hEdma;
/*
 * UART handle for input channel
 */
GIO_Handle hUart_IN;
/*
 * UART handle for output channel
 */
GIO_Handle hUart_OUT;

/* SYSTEM REGISTERS */
static CSL_SysRegsOvly sysModuleRegs = (CSL_SysRegsOvly )CSL_SYS_0_REGS;

extern void start_vlynq_test();

static void tskHeartBit();

void pspConsoleOut(Int32 data);

void main()
{
    return;
}

/**
 *  ======== UART_INIT ========
 *  This function is used to Initialize the UART Bus Driver
 *
 */
void UART_init()
{
}

/* UART Echo Task */
void pspUartEchoTask(void)
{
    /* PSP Welcome Message */
    PSP_DEBUG_PRINT("***************************************************************\n\r");
    PSP_DEBUG_PRINT("*                                                             *\n\r");
    PSP_DEBUG_PRINT("*                            ****                             *\n\r");
    PSP_DEBUG_PRINT("*                            ****                             *\n\r");
    PSP_DEBUG_PRINT("*                            ******o***                       *\n\r");
    PSP_DEBUG_PRINT("*                      ********_///_****                      *\n\r");
    PSP_DEBUG_PRINT("*                      ***** /_//_/ ****                      *\n\r");
    PSP_DEBUG_PRINT("*                       ** ** (__/ ****                       *\n\r");
    PSP_DEBUG_PRINT("*                           *********                         *\n\r");
    PSP_DEBUG_PRINT("*                            ****                             *\n\r");
    PSP_DEBUG_PRINT("*                            ***                              *\n\r");
    PSP_DEBUG_PRINT("*                                                             *\n\r");
#ifdef CHIP_DM648
    PSP_DEBUG_PRINT("*                     TI DM648  EVM BIOS PSP vlynq sample     *\n\r");
#endif
#ifdef CHIP_C6452
    PSP_DEBUG_PRINT("*                     TI C6452  EVM BIOS PSP vlynq sample     *\n\r");
#endif
    PSP_DEBUG_PRINT("*                                                             *\n\r");
    PSP_DEBUG_PRINT("*                                                             *\n\r");
    PSP_DEBUG_PRINT("*       For issues on base port contact TII PSP Team          *\n\r");
    PSP_DEBUG_PRINT("*                                                             *\n\r");
    PSP_DEBUG_PRINT("*                                                             *\n\r");
    PSP_DEBUG_PRINT("*                                                             *\n\r");
    PSP_DEBUG_PRINT("***************************************************************\n\r");
    PSP_DEBUG_PRINT("\r\n\r\n");

}

void echo()
{
    GIO_Attrs gioAttrs = GIO_ATTRS;
    Int32 echoTskStatus= 0;

#if 0
    /* Pinmux settings for VLYNQ
     * PCIEN = 0: PINMUX1 - bit - 0
     * HOSTBK= 010: PINMUX1 bits - 6:4
     */
    sysModuleRegs -> PINMUX1    &=  (0xFFFFFFAEu);
    sysModuleRegs -> PINMUX1    |=  (0x00000020u);
    /*
     * Power up settings for VLYNQ
     * HOST = 0: VDD3P3V_PWDN- bit - 4
     */
    sysModuleRegs -> VDD3P3V_PWDN &= (~(0x00000010u));
   /* Initialize UART
    * Currently is been used to display messages
    */
    /* Power up settings for UART0
     * UR0DAT = 1: VDD3P3V_PWDN - bit 10
     */
    sysModuleRegs->VDD3P3V_PWDN &=  (~(0x400u));
    /*  Pinmux setting for UART0
     *  UR0DBK = 01 :   PINMUX1 - bit 9:8
     *  UR0FCBK = 01:   PINMUX1 - bit 11:10
     */
    sysModuleRegs->PINMUX1  &=   (0xFFFFF5FFu);
    sysModuleRegs->PINMUX1  |=   (0x00000500u);

    /*  Pinmux setting for UART1
     *  TIM1BK = 10 :   PINMUX1 - bit 21:20
     */
#endif
    hUart_OUT = GIO_create("/UART0",IOM_OUTPUT,NULL,NULL,&gioAttrs);
    hUart_IN  = GIO_create("/UART0",IOM_INPUT,&echoTskStatus,NULL,&gioAttrs);
    if((NULL == hUart_IN)||(NULL == hUart_OUT))
    {
        PSP_DEBUG("ERROR: Initialization of UART failed\n");
        return;
    }

    if((NULL != hUart_IN)||(NULL != hUart_OUT))
    {
        /* Print the banner */
        pspUartEchoTask();

        /* Run VLYNQ sample application */
        start_vlynq_test(0);

        /* Start the Heart Beat Print */
        tskHeartBit();

    }

    return;
}

void tskHeartBit()
{
    static Uint32 counter = 0;

    while (counter < 0xFFFFFFFF)
    {
        TSK_sleep(1000u);    /* Add large delay */
        PSP_DEBUG_PRINT("\r\n\r\n!!! PSP HrtBt %l", counter);
        counter++;
    }
}

/**
 * \brief   which prints on to the console
 */
void pspConsoleOut(Int32 data)
{
    char charData = (char) data;
    size_t len=1;
    PSP_uartDataParam buf;
    Int32   status;

    if(NULL != hUart_OUT){
        buf.addr = &charData;
        buf.timeout = SYS_FOREVER;
        len = 1;
        status = GIO_write(hUart_OUT, &buf, &len);
        if(! ((status != IOM_COMPLETED)||(status != IOM_PENDING)))
        {
            PSP_DEBUG_PRINT("\npspConsoleOut: Error writing data to UART");
        }
    }
}
