/*
 *  Copyright 2006 by Texas Instruments Incorporated.
 *  All rights reserved. Property of Texas Instruments Incorporated.
 *  Restricted rights to use, duplicate or disclose this code are
 *  granted through contract.
 *
 *  @(#) TCP/IP_Network_Developers_Kit 1.92.00.13 11-17-2006 (ndk-b13)
 */
/*
 *  ======== evmdm648_init.c ========
 *  Do all necessary Board level initialization here.
 */

#include <stdio.h>
#include <netmain.h>
#include <log.h>
#include "llpacket.h"
#include "cpsw3g_ioctl.h"

extern far LOG_Obj logTrace;

#define ENABLE_SAMPLE_APP	

/* This string array corresponds to link state */
static Int8 *LinkStr[] = { "No Link",
							"None",
                           "10Mb/s Half Duplex",
                           "10Mb/s Full Duplex",
                           "100Mb/s Half Duplex",
                           "100Mb/s Full Duplex",
						   "1000Mb/s Half Duplex", /*not suported*/
                           "1000Mb/s Full Duplex"};

static Uint8 bMacAddr[] = {0x00,0x0e,0x99,0x02,0xaa,0x23};

/** We need to program/read the following system module registers
 * Verify Offsets : as they dont match in internal docs */
#define SYS_CFGPLL_REG   (*(volatile Uint32*)0x020490A8u)
#define SYS_CFGRX0_REG   (*(volatile Uint32*)0x020490B0u)
#define SYS_CFGTX0_REG   (*(volatile Uint32*)0x020490B8u)
#define SYS_CFGRX1_REG   (*(volatile Uint32*)0x020490B4u)
#define SYS_CFGTX1_REG   (*(volatile Uint32*)0x020490Bcu)

#define SYS_MACADDR_R0_REG  (*(volatile Uint32*)0x020490C4u)
#define SYS_MACADDR_R1_REG  (*(volatile Uint32*)0x020490C8u)



/*
 * Main Thread
 *
 * We changed our TCF file to point call this private init
 * function. Here we initialize our board and read in our
 * MAC address.
 */
void evmdm648_init()
{
	Uint32 use_SMA_on_port0, use_SMA_on_port1;
    /* Initialize our board ,clock DDR MUX etc */
    /* At the minimum, system clocks LPSC must be programmed  here */

    /* Read the MAC Address from System Module Register space
     * If not populated uses default. If two devices use the same
     * default MAC address, it will cause issues on the network*/

    
    /* read mac addr from SYS_MACADDR_R regs here */
    /* configure CFG output for SERDES configuration here */
	/** PLL must be 0x13 for input frequency of 62.5Mhz and
		0x0B for input frequency of 125Mhz*/
	#ifdef INPUT_CLOCK_FREQUENCY_125MHZ
	SYS_CFGPLL_REG = 0x0Bu;
	#elif defined(INPUT_CLOCK_FREQUENCY_62_5MHZ)
	SYS_CFGPLL_REG = 0x13u;
	#else
	#error "Define input clock frequency (125/62.5Mhz)\
    		Project file must define INPUT_CLOCK_FREQUENCY_125MHZ\
    		or INPUT_CLOCK_FREQUENCY_62_5MHZ"	
	#endif

	SYS_CFGTX0_REG =0x921u;
    SYS_CFGTX1_REG = 0x921u;
    SYS_CFGRX0_REG = 0x89121u;/*0x00081013;*/    
    SYS_CFGRX1_REG = 0x89121u;/*0x00081013*/

    
	if(( 0u != SYS_MACADDR_R1_REG) || (0u != SYS_MACADDR_R0_REG))
	{	/* Use the MAC addr from sys.regs if not non-zero*/
		/* get the MAC Address from System module register space */
		bMacAddr[0] = (Uint8)((SYS_MACADDR_R1_REG & ((Uint32)0xFF00u)) >> 8u);
    	bMacAddr[1] = (Uint8)(SYS_MACADDR_R1_REG & 0xFFu);
		bMacAddr[2] = (Uint8)((SYS_MACADDR_R0_REG & 0xFF000000u) >> 24u);
		bMacAddr[3] = (Uint8)((SYS_MACADDR_R0_REG & 0x00FF0000u) >> 16u);
		bMacAddr[4] = (Uint8)((SYS_MACADDR_R0_REG & 0x0000FF00u) >> 8u);
		bMacAddr[5] = (Uint8)((SYS_MACADDR_R0_REG & 0x000000FFu) );
	}

	/* If you want to use SMA connector instead of the ethernet PHY
	 * invoke the driver provided callback to indicate this
	 * If not set through this callback the driver assumes that the
	 * GMAC ports are connected to the PHY and not the SMA conector*/
	 use_SMA_on_port0 = FALSE;
	 use_SMA_on_port1 = FALSE;
	 CPSW3G_set_connector(use_SMA_on_port0,use_SMA_on_port1);	
	
}

/*
 * CPSW3G_getConfig()
 *
 * This is a callback from the Ethernet driver. This function
 * is used by the driver to get its 6 byte MAC address, and
 * to determine which DSP interrupt the EMAC should be mapped to.
 */
void CPSW3G_getConfig( Uint8 *pMacAddr, Uint32 *pIntVector)
{
    printf("Using MAC Address: %02x-%02x-%02x-%02x-%02x-%02x\n",
            bMacAddr[0], bMacAddr[1], bMacAddr[2],
            bMacAddr[3], bMacAddr[4], bMacAddr[5]);

    if( ((Uint8*)0 != pMacAddr) && ((Uint32*)0 != pIntVector)) 
	{
    	/* We fill in the pointers here.*/
    	mmCopy( pMacAddr, bMacAddr, 6u );
    	*pIntVector = 5u;		
	}
}

#ifdef ENABLE_SAMPLE_APP	
static volatile Int32 sampleAppStarted = 0;
extern void switchApp();
#endif

/*
 * CPSW3G_linkStatus()
 *
 * This is a callback from the Ethernet driver. This function
 * is called whenever there is a change in link state. The
 * current PHY and current link state are passed as parameters.
 */
void CPSW3G_linkStatus( Uint32 phy, Uint32 linkStatus )
{
    printf("Link Status: %s on PHY %d\n",LinkStr[linkStatus],phy);

#ifdef ENABLE_SAMPLE_APP	
	if( (0u == sampleAppStarted) && (linkStatus > 1u) )
	{

		TaskCreate( &switchApp, "SwitchApplication", 9, 0x1400u, 0, 0, 0 );
        sampleAppStarted = 1;
	}
#endif

}




