/*******************************************************************************
**+--------------------------------------------------------------------------+**
**|                            ****                                          |**
**|                            ****                                          |**
**|                            ******o***                                    |**
**|                      ********_///_****                                   |**
**|                      ***** /_//_/ ****                                   |**
**|                       ** ** (__/ ****                                    |**
**|                           *********                                      |**
**|                            ****                                          |**
**|                            ***                                           |**
**|                                                                          |**
**|         Copyright (c) 1998-2007 Texas Instruments Incorporated           |**
**|                        ALL RIGHTS RESERVED                               |**
**|                                                                          |**
**+--------------------------------------------------------------------------+**
*******************************************************************************/

/** \file   cpsw3g_switchApp.c
    \brief  CPSW3G Sample switch configuration application

	This sample application illustrates the usage switch configuration
	IOCTLs. It adds a multicast address to the ALE, waits for 20secs 
	and then deletes the entry from the ALE. If a ping is initiated to the
	multicast address it would initially fail until the entry is added
	and succeeds for the duration that the entry exists in ALE
    
 */

#include <std.h>
#include <sys.h>
#include <c64.h>
#include <stkmain.h>
#include "llpacket.h"
#include "cpsw3g_ioctl.h"


/* all global , that  can be set runtime thru CCS */
Uint32 stopSwitchApp = 0;
Uint32 dumpAle = 0;

void switchApp()
{
    SwitchConsCmd switchConsCommand;
	ALE_VLANCMD *lpVlanCmd = &switchConsCommand.CmdType.AleVlanCmd;


	/* mac multicast address corresponding to IP 224.1.2.18 */
	Uint8 mcastAddr[6] = {0x01,0x00,0x5e,0x1,0x2,0x12};
	Uint32 i;

	TSK_sleep(20000u);

	for(i = 0u; i < 6u;i++)
	{
		lpVlanCmd->add[i] = mcastAddr[i];
	}
	
	/* add multicast entry to ALE */
	lpVlanCmd->vid = 1u; /* default port VLAN ID */
	lpVlanCmd->mem_port = 0x7u ; /*port mask of 0x7 */
	lpVlanCmd->flag = 0u; /* set super to 0 */
	lpVlanCmd->untag_port = 3u ; /*set fwd_state to 3 */
	
	switchConsCommand.opcode = CPSW3G_IOCTL_ALE_ADDMLT;
	llPacketIoctl(1u,CPSW3G_IOCTL_SWITCH_CMD,(void*)&switchConsCommand);

	/* ensure address got added */
	switchConsCommand.opcode = CPSW3G_IOCTL_ALE_FINDADDR;
	/* reuse addr,vid populated earlier */
	llPacketIoctl(1u,CPSW3G_IOCTL_SWITCH_CMD,(void*)&switchConsCommand);


	/* Add a VLAN entry with VID=2, for illustration : IF a Packet
	 * with VID=2 is received its restricted to only ports
	 * 0 & 2 and will not be forwarded over port 1*/
	switchConsCommand.opcode = CPSW3G_IOCTL_ALE_ADDVLAN;

	lpVlanCmd->vid = 0x2u; /*VID */
	lpVlanCmd->untag_port = 0x5u; /*untagged egress port */
	lpVlanCmd->regag_port = 0x5u;/*Reg Multicast flood mask */
	lpVlanCmd->unreg_port = 0x5u;/*unknown multicast flood*/
	lpVlanCmd->mem_port = 0x5u;	;/*Vlan member port mask */
	llPacketIoctl(1u,CPSW3G_IOCTL_SWITCH_CMD,(void*)&switchConsCommand);

	TSK_sleep(40000u);

	/* delete multicast address */
	switchConsCommand.opcode = CPSW3G_IOCTL_ALE_DELADDR;
	/* reuse addr,vid populated earlier */
	llPacketIoctl(1u,CPSW3G_IOCTL_SWITCH_CMD,(void*)&switchConsCommand);

	/* ensure address got deleted */
	switchConsCommand.opcode = CPSW3G_IOCTL_ALE_FINDADDR;
	/* reuse addr,vid populated earlier */
	llPacketIoctl(1u,CPSW3G_IOCTL_SWITCH_CMD,(void*)&switchConsCommand);

  
	TSK_sleep(10000u);
		
}

