/*
 *  Copyright 2007 by Texas Instruments Incorporated.
 *  All rights reserved. Property of Texas Instruments Incorporated.
 *  Restricted rights to use, duplicate or disclose this code are
 *  granted through contract.
 *
 *  @(#) TCP/IP_Network_Developers_Kit 1.92.00.13 11-17-2006 (ndk-b13)
 */
/*--------------------------------------------------------------------------
 * IP Stack Console Demonstration Program
 *--------------------------------------------------------------------------
   ConSwitchCtl.c

  Basic Console Functions
  ConCmdRoute   - Switch Control/Configuration Command

  Author: A.G.Sriramakrishnan
  Copyright 2007 by Texas Instruments Inc.
 -------------------------------------------------------------------------*/
#include <netmain.h>
#include <_stack.h>
#include "console.h"
#include "llpacket.h"
#include "cpsw3g_ioctl.h"

/**prototypes */
static unsigned char str_to_hexnum(unsigned char c);
static void str_to_ethaddr(unsigned char *ea,  char *str);

void ConCmdSwitchCtl(int numtok,char **tokarr)
{
	SwitchConsCmd switchConsCommand;
	StatsCmd statsCmd;
	ALE_VLANCMD *lpVlanCmd = &switchConsCommand.CmdType.AleVlanCmd;
	PORT_CMD *lpPortCmd = &switchConsCommand.CmdType.PortCmd;

	switchConsCommand.consolePrint = &ConPrintf ;
	switchConsCommand.usePrintFn = 1;

	if( numtok == 1 )
    {
        ConPrintf("\n[switchCtl Command]\n");
        ConPrintf("\nCalled to print, add, or delete entries to ALE.\n");
        ConPrintf("switchCtl addmulti  - Add Multicast address to ALE\n");
        ConPrintf("switchCtl adduni  - Add Unicast address to ALE\n");
        ConPrintf("switchCtl addoui  - Add OUI address to ALE\n");;
        ConPrintf("switchCtl addvlan  - Add VLAN entry to ALE\n");
        ConPrintf("switchCtl findvlan - Search for VLAN entry in ALE\n");
        ConPrintf("switchCtl findaddr - Search for Address in ALE\n");
        ConPrintf("switchCtl delvlan - Delete VLAN entry from ALE\n");
        ConPrintf("switchCtl deladdr - Delete Address from ALE\n");
        ConPrintf("switchCtl setportvlancfg - set port vlan config\n");
        ConPrintf("switchCtl aletimeout - Set ALE aging timeout interval\n");
        ConPrintf("switchCtl aledump - Dump Contents of ALE\n");
		ConPrintf("switchCtl ingress - Enable/Disable Port Ingress checking\n");
		ConPrintf("switchCtl rateLimit - Enable/Disable Rate Limiting on a port\n");
		ConPrintf("switchCtl portstats - Enable/Disable Port Statistics \n");
		ConPrintf("switchCtl setunknowninfo - Configure unknown vlan information\n");
		ConPrintf("switchCtl setportstate - Set the Port state\n");
		ConPrintf("switchCtl clearstats - Clear software/hardware statistics \n");


       
    }
	else if( !stricmp( tokarr[1], "addmulti" ) )
	{
		if(numtok != 7)
		{
			ConPrintf("Usage : switchCtl addmulti <address> <VID 0-4094 0=novlan >"
						"<portmask0-7><super0-1><fwdState0-3>\n");
		}
		else
		{
			switchConsCommand.opcode = CPSW3G_IOCTL_ALE_ADDMLT;
			
			str_to_ethaddr(lpVlanCmd->add,tokarr[2]);
			lpVlanCmd->vid = atoi(tokarr[3]); /*VID */
			lpVlanCmd->mem_port = atoi(tokarr[4]) ; /*Port-mask*/
			lpVlanCmd->flag = atoi(tokarr[5]) ;/*super flag*/
			lpVlanCmd->untag_port = atoi(tokarr[6]); /*fwd_state */
		
			llPacketIoctl(1,CPSW3G_IOCTL_SWITCH_CMD,&switchConsCommand);
		}
	}
	else if( !stricmp( tokarr[1], "adduni" ) )
	{
		if(numtok != 8)
		{
			ConPrintf("Usage : switchCtl adduni <address> <port0-2>"
					  "<VID 0-4094 0=novlan><blocked(0/1)><secure(0/1)><ageable(0/1)>\n");
		}
		else
		{
			switchConsCommand.opcode = CPSW3G_IOCTL_ALE_ADDUNI;
			
			str_to_ethaddr(lpVlanCmd->add,tokarr[2]);
			lpVlanCmd->mem_port = atoi(tokarr[3]) ; /*PortNumber*/
			lpVlanCmd->vid = atoi(tokarr[4]); /*VID */
			lpVlanCmd->blocked = atoi(tokarr[5]); /*block flag */
			lpVlanCmd->secure = atoi(tokarr[6]); /* secure flag */
			lpVlanCmd->ageable = atoi(tokarr[7]); /* age flag */
				
			llPacketIoctl(1,CPSW3G_IOCTL_SWITCH_CMD,&switchConsCommand);
		}
	}
	else if( !stricmp( tokarr[1], "addoui" ) )
	{
		if(numtok != 3)
		{
			ConPrintf("Usage : switchCtl addoui <address> \n");
		}
		else
		{
			switchConsCommand.opcode = CPSW3G_IOCTL_ALE_ADDOUI;

			str_to_ethaddr(lpVlanCmd->add,tokarr[2]);
			llPacketIoctl(1,CPSW3G_IOCTL_SWITCH_CMD,&switchConsCommand);
		}
	}
	else if( !stricmp( tokarr[1], "addvlan" ) )
	{
		if(numtok != 7)
		{
			ConPrintf("Usage : switchCtl addvlan <VID 1-4094>"
					"<UTagged 0-7><Mult 0-7><UMult 0-7><Member 0-7>\n");
		}
		else
		{
			switchConsCommand.opcode = CPSW3G_IOCTL_ALE_ADDVLAN;

			lpVlanCmd->vid = atoi(tokarr[2]); /*VID */
			lpVlanCmd->untag_port = atoi(tokarr[3]); /*untagged egress port */
			lpVlanCmd->regag_port = atoi(tokarr[4]);/*Reg Multicast flood mask */
			lpVlanCmd->unreg_port = atoi(tokarr[5]);/*unknown multicast flood*/
			lpVlanCmd->mem_port = atoi(tokarr[6]);/*Vlan member port mask */
			llPacketIoctl(1,CPSW3G_IOCTL_SWITCH_CMD,&switchConsCommand);
		}
	}
	else if( !stricmp( tokarr[1], "findvlan" ) )
	{
		if(numtok != 3)
		{
			ConPrintf("Usage : switchCtl findvlan <VID 1-4094>\n");
		}
		else
		{
			switchConsCommand.opcode = CPSW3G_IOCTL_ALE_FINDVLAN;

			lpVlanCmd->vid = atoi(tokarr[2]); /*VID */
			llPacketIoctl(1,CPSW3G_IOCTL_SWITCH_CMD,&switchConsCommand);
		}
	}
	else if( !stricmp( tokarr[1], "findaddr" ) )
	{
		if(numtok != 4)
		{
			ConPrintf("Usage : switchCtl findaddr addr <VID 1-4094>\n");

		}
		else
		{
			switchConsCommand.opcode = CPSW3G_IOCTL_ALE_FINDADDR;

			str_to_ethaddr(lpVlanCmd->add,tokarr[2]);
			lpVlanCmd->vid = atoi(tokarr[3]); /*VID */
			llPacketIoctl(1,CPSW3G_IOCTL_SWITCH_CMD,&switchConsCommand);
		}
	}
	else if( !stricmp( tokarr[1], "delvlan" ) )
	{
		if(numtok != 3)
		{
			ConPrintf("Usage : switchCtl delvlan <VID 1-4094>\n");
		}
		else
		{
			switchConsCommand.opcode = CPSW3G_IOCTL_ALE_DELVLAN;

			lpVlanCmd->vid = atoi(tokarr[2]); /*VID */
			llPacketIoctl(1,CPSW3G_IOCTL_SWITCH_CMD,&switchConsCommand);
		}
	}
	else if( !stricmp( tokarr[1], "deladdr" ) )
	{
		if(numtok != 4)
		{
			ConPrintf("Usage : switchCtl deladdr addr <VID 1-4094>\n");
		}
		else
		{
			switchConsCommand.opcode = CPSW3G_IOCTL_ALE_DELADDR;

			str_to_ethaddr(lpVlanCmd->add,tokarr[2]);
			lpVlanCmd->vid = atoi(tokarr[3]); /*VID */
			llPacketIoctl(1,CPSW3G_IOCTL_SWITCH_CMD,&switchConsCommand);
		}
	}
	else if( !stricmp( tokarr[1], "setportvlancfg" ) )
	{
		if(numtok != 6)
		{
			ConPrintf("Usage : switchCtl setportvlancfg <port 0-2>"
					"<priority 0-7><port_cfi 0-1><VID 1-4094>\n");
		}
		else
		{
			switchConsCommand.opcode = CPSW3G_IOCTL_SET_PORT_VLAN_CONFIG;

			lpVlanCmd->mem_port = atoi(tokarr[2]);/*Port Number */
			lpVlanCmd->prio_port = atoi(tokarr[3]);/*VLAN priority*/
			lpVlanCmd->CFI_port = atoi(tokarr[4]);/*VLAN CFI */
			lpVlanCmd->vid = atoi(tokarr[5]);/*VLAN ID */
			llPacketIoctl(1,CPSW3G_IOCTL_SWITCH_CMD,&switchConsCommand);
		}
	}
	else if( !stricmp( tokarr[1], "aletimeout" ) )
	{
		if(numtok != 3)
		{
			ConPrintf("Usage : switchCtl aletimeout <Value(msec)>\n");
		}
		else
		{
			switchConsCommand.opcode = CPSW3G_IOCTL_ALE_TIMEOUT;
			lpVlanCmd->aleTimeout = atoi(tokarr[2]);
			llPacketIoctl(1,CPSW3G_IOCTL_SWITCH_CMD,&switchConsCommand);
		}
	}
	else if( !stricmp( tokarr[1], "aleDump" ) )
	{
		if(numtok != 2)
		{
			ConPrintf("Usage : switchCtl aledump \n");
		}
		else
		{
			switchConsCommand.opcode = CPSW3G_IOCTL_ALE_DUMP;
			llPacketIoctl(1,CPSW3G_IOCTL_SWITCH_CMD,&switchConsCommand);
		}
	}
	else if( !stricmp( tokarr[1], "ingress" ) )
	{
		if(numtok != 5)
		{
			ConPrintf("Usage : switchCtl ingress <Port 0-2>"
			"<VID Ingress Check Enable-1 /Disable-0>"
			"<drop untag enable-1/disable-0>\n");
		}
		else
		{
			switchConsCommand.opcode = CPSW3G_IOCTL_VIDINGRESSCHECK;
			lpPortCmd->port = atoi(tokarr[2]);/*Port Number */
			lpPortCmd->ml = atoi(tokarr[3]);/* Ingress check */
			lpPortCmd->bl = atoi(tokarr[4]);/* drop untag */
			llPacketIoctl(1,CPSW3G_IOCTL_SWITCH_CMD,&switchConsCommand);
		}
	}
	else if( !stricmp( tokarr[1], "ratelimit" ) )
	{
		if(numtok != 7)
		{
			ConPrintf("Usage : switchCtl ratelimit <enable-1 /disable-0>"
			"<Tx-1/Rx-0><Port 0-2><Broadcast-0/Multicast-1>"
			"<Num of Pkts 0-256> \n");
		}
		else
		{
			switchConsCommand.opcode = CPSW3G_IOCTL_RATELIMIT;
			lpPortCmd->EnDis = atoi(tokarr[2]);/* enable/disable */
			lpPortCmd->value = atoi(tokarr[3]);/* Tx/Rx bit*/
			lpPortCmd->port = atoi(tokarr[4]);/* Port Number */
			lpPortCmd->ml = atoi(tokarr[5]);/* Broadcast-multicast*/
			lpPortCmd->bl = atoi(tokarr[6]);/* Number of pkts */

			llPacketIoctl(1,CPSW3G_IOCTL_SWITCH_CMD,&switchConsCommand);
		}
	}
	else if( !stricmp( tokarr[1], "portstats" ) )
	{
		if(numtok != 5)
		{
			ConPrintf("Usage : switchCtl portstats <port0(0/1)>"
			"<port1(0/1)><port2(0/1)>");
		}
		else
		{
			switchConsCommand.opcode = CPSW3G_IOCTL_PORT_STATISTICS_ENABLE;
			lpPortCmd->value = atoi(tokarr[2]);/* Port 0 enable/Disable*/
			lpPortCmd->ml = atoi(tokarr[3]);/* Port 1 enable/Disable*/
			lpPortCmd->bl = atoi(tokarr[4]);/* Port 2 enable/Disable*/

			llPacketIoctl(1,CPSW3G_IOCTL_SWITCH_CMD,&switchConsCommand);
		}
	}
	else if( !stricmp( tokarr[1], "setunknowninfo" ) )
	{
		if(numtok != 6)
		{
			ConPrintf("Usage : switchCtl setunknowninfo <unknownuntagEgress 0-7>"
			"<RegMcastFloodMask 0-7><McastFloodMask 0-7>"
			"<UnknownVlanMember 0-7> \n");
		}
		else
		{
			switchConsCommand.opcode = CPSW3G_IOCTL_ADD_UNKNOWN_VLAN_INFO;
			lpPortCmd->value = atoi(tokarr[2]);/*Untagged Egress Port Mask*/
			lpPortCmd->port = atoi(tokarr[3]);/*Registered Multicast mask */
			lpPortCmd->bl = atoi(tokarr[4]);/* Unknown Multicast flood mask*/
			lpPortCmd->ml = atoi(tokarr[5]);/* Vlan membr port mask*/


			llPacketIoctl(1,CPSW3G_IOCTL_SWITCH_CMD,&switchConsCommand);
		}
	}

	else if( !stricmp( tokarr[1], "setportstate" ) )
	{
		if(numtok != 4)
		{
			ConPrintf("Usage : switchCtl setportstate <port 0-2>"
			"<portstate - 0(Disabled)/1(Blocked)/2(Learn)/3(Forward)> \n");
		}
		else
		{
			switchConsCommand.opcode = CPSW3G_IOCTL_STP_CONFIG;
			lpPortCmd->port = atoi(tokarr[2]);/*Port Number */
			lpPortCmd->value = atoi(tokarr[3]);/* Port State */
			llPacketIoctl(1,CPSW3G_IOCTL_SWITCH_CMD,&switchConsCommand);
		}
	}
	else if( !stricmp( tokarr[1], "clearstats" ) )
	{
		if(numtok != 2)
		{
			ConPrintf("Usage : switchCtl clearstats \n");
		}
		else
		{
			statsCmd.opcode = CPSW3G_IOCTL_STAT_CLEAR;
			llPacketIoctl(1,CPSW3G_IOCTL_STAT_CMD,&statsCmd);
		}
	}
}



/* string to hex conversion */
static unsigned char str_to_hexnum(unsigned char c)
{
        if (c >= '0' && c <= '9')
                return c - '0';
        if (c >= 'a' && c <= 'f')
                return c - 'a' + 10;
        if (c >= 'A' && c <= 'F')
                return c - 'A' + 10;
        return 0;
}

/* string to ethernet address conversion */
static void str_to_ethaddr( unsigned char *ea, char *str)
{
        int i;
        unsigned char num;

        for (i = 0; i < 6; i++) {
                if ((*str == '.') || (*str == ':')) {
                        str++;
                }
                num = str_to_hexnum(*str) << 4;
                ++str;
                num |= (str_to_hexnum(*str));
                ++str;
                ea[i] = num;
        }
}

