/*
 *  Copyright 2006 by Texas Instruments Incorporated.
 *  All rights reserved. Property of Texas Instruments Incorporated.
 *  Restricted rights to use, duplicate or disclose this code are
 *  granted through contract.
 *
 *  @(#) TCP/IP_Network_Developers_Kit 1.92.00.13 11-17-2006 (ndk-b13)
 */
/**
 *
 * llpacket.h
 *
 * Useful equates for a packet driver
 *
 */

#ifndef _LLPACKET_H_
#define _LLPACKET_H_

#ifdef __cplusplus
extern "C" {
#endif

/**
 *
 * Pre-Pad Packet Data Offset
 *
 * The TCP/IP stack library requires that every packet device
 * include enough L2 header room for all supported headers. In
 * order to support PPPoE, this requires a 22 byte L2 header.
 * Thus, since standard Ethernet is only 14 bytes, we must add
 * on an additional 8 byte offset, or PPPoE can not function
 * with our driver.
 *
 */
#define PKT_PREPAD          (8u)

/**
 * Multicast Address List Size
 */
#define PKT_MAX_MCAST       (16u)

/**
 * Packet Queues
 */
extern PBMQ    PBMQ_rx;         /* Rx queue (one for all PKT devices) */

/**
 *
 * Packet device information
 *
 */
typedef struct _pdinfo {
    Uint32            PhysIdx;    /* Physical index of this device (0 to n-1) */
    HANDLE            hEther;     /* Handle to logical driver */
    STKEVENT_Handle   hEvent;
    Uint8             bMacAddr[6];/* MAC Address */
    Uint32            Filter;     /* Current RX filter */
    Uint32            MCastCnt;   /* Current MCast Address Countr */
    Uint8             bMCast[6*PKT_MAX_MCAST];
    Uint32            TxFree;     /* Transmitter "free" flag */
    PBMQ              PBMQ_tx;    /* Tx queue (one for each PKT device) */
} PDINFO;


/**
 *  
 *  Ideally, if statistics have to be exported to the application, this structure must 
 *  be included in the stack interface header file.Unless there is a specific requirement,
 *  Keep the stats structure an exact overlay of H/w Stats Registers
 *
 */
typedef struct _etherstats{
    Uint32 RXGOODFRAMES;
    Uint32 RXBCASTFRAMES;
    Uint32 RXMCASTFRAMES;
    Uint32 RXPAUSEFRAMES;
    Uint32 RXCRCERRORS;
    Uint32 RXALIGNCODEERRORS;
    Uint32 RXOVERSIZED;
    Uint32 RXJABBER;
    Uint32 RXUNDERSIZED;
    Uint32 RXFRAGMENTS;
    Uint32 RXFILTERED;
    Uint32 RXQOSFILTERED;
    Uint32 RXOCTETS;
    Uint32 TXGOODFRAMES;
    Uint32 TXBCASTFRAMES;
    Uint32 TXMCASTFRAMES;
    Uint32 TXPAUSEFRAMES;
    Uint32 TXDEFERRED;
    Uint32 TXCOLLISION;
    Uint32 TXSINGLECOLL;
    Uint32 TXMULTICOLL;
    Uint32 TXEXCESSIVECOLL;
    Uint32 TXLATECOLL;
    Uint32 TXUNDERRUN;
    Uint32 TXCARRIERSENSE;
    Uint32 TXOCTETS;
    Uint32 FRAME64;
    Uint32 FRAME65T127;
    Uint32 FRAME128T255;
    Uint32 FRAME256T511;
    Uint32 FRAME512T1023;
    Uint32 FRAME1024TUP;
    Uint32 NETOCTETS;
    Uint32 RXSOFOVERRUNS;
    Uint32 RXMOFOVERRUNS;
    Uint32 RXDMAOVERRUNS;
}ETHERSTATS;

/**
 *
 * Functions Provided by Hw specific code
 *
 */
extern uint HwPktInit();
extern void HwPktShutdown();
extern uint HwPktOpen( PDINFO *pi );
extern void HwPktClose( PDINFO *pi );
extern void HwPktSetRx( PDINFO *pi );
extern void HwPktTxNext( PDINFO *pi );
extern void _HwPktPoll( PDINFO *pi, uint fTimerTick );




/**
 * If statistics abstraction is added to the core stack,stats should be exported thru HwPktStats kind of API
 * 
 * extern void HwPktGetStats(PDINFO *pi, PDSTATS *stats);
 * 
 * extern void HxPktClearStats(PDINFO * pi);
 *
 * For now, provide direct interface, assuming only one MAC instance
 */
extern void getEtherStats(ETHERSTATS * stats);
extern void clearEtherStats(void);

#ifdef __cplusplus
}
#endif

#endif
