/*
 *  Copyright 2007 by Texas Instruments Incorporated.
 *  All rights reserved. Property of Texas Instruments Incorporated.
 *  Restricted rights to use, duplicate or disclose this code are
 *  granted through contract.
 *
 *  @(#) TCP/IP_Network_Developers_Kit 1.92.00.13 
 */
#ifndef _CPSW3G_COMMON_H_
#define _CPSW3G_COMMON_H_

#include "cslr.h"
#include "cslr_ectl.h"
#include "cslr_sgmii.h"
#include "cslr_cpsw3g.h"

#ifdef __cplusplus
extern "C" {
#endif

/*
 * Peripheral register structures
 */


#define CPSW3G_BASEADDR     			(0x02D03000U)
#define MDIO_BASEADDR				(0x02D04000U)
#define CPSW_3GSS_S_BASEADDR			(0x02D02000U)
#define CPSW3G_SGMII0_BASEADDR			(0x02D04800U)
#define CPSW3G_SGMII1_BASEADDR			(0x02D04C00U)


/* Interrupt number to the CPU */
#define RX_PULSE_INTNUM			32
#define RX_THRESH_PULSE_INTNUM		33
#define TX_PULSE_INTNUM			34
#define MISC_PULSE_INTNUM		35

/*
 *  DMA Descriptor section
 */

#define _CPPI_DSC_BASE_ADDR         	0x02D00000  /*0X02C82000U;0x01c82000u*/
#define _CPPI_DSC_RAM_SIZE              8192
#define _CPPI_DSC_ENTRY_SIZE        	16
#define _CPPI_DSC_ENTRY_COUNT       	(_CPPI_DSC_RAM_SIZE/_CPPI_DSC_ENTRY_SIZE)

/*
 * DESCRIPTOR ACCESS MACROS
 */

/*  Packet Flags for TX and RX */
#define CPPI_DESC_FLAG_SOP                       0x80000000u
#define CPPI_DESC_FLAG_EOP                       0x40000000u
#define CPPI_DESC_FLAG_OWNER                     0x20000000u
#define CPPI_DESC_FLAG_EOQ                       0x10000000u
#define CPPI_DESC_FLAG_TDOWNCMPLT                0x08000000u
#define CPPI_DESC_FLAG_PASSCRC                   0x04000000u

/* The following flags are RX only */
#define CPPI_DESC_FLAG_JABBER                    0x02000000u
#define CPPI_DESC_FLAG_OVERSIZE                  0x01000000u
#define CPPI_DESC_FLAG_FRAGMENT                  0x00800000u
#define CPPI_DESC_FLAG_UNDERSIZED                0x00400000u
#define CPPI_DESC_FLAG_CONTROL                   0x00200000u
#define CPPI_DESC_FLAG_OVERRUN                   0x00100000u
#define CPPI_DESC_FLAG_CODEERROR                 0x00080000u
#define CPPI_DESC_FLAG_ALIGNERROR                0x00040000u
#define CPPI_DESC_FLAG_CRCERROR                  0x00020000u
#define CPPI_DESC_FLAG_NOMATCH                   0x00010000u

/*MAC Invector definitions */
#define CSL_CPSW_MACINVECTOR_STATPEND_MASK 		(0x20000000u)
#define CSL_CPSW_MACINVECTOR_STATPEND_SHIFT 		(0x0000001Du)
#define CSL_CPSW_MACINVECTOR_STATPEND_RESETVAL 		(0x00000000u)

#define CSL_CPSW_MACINVECTOR_HOSTPEND_MASK 		(0x10000000u)
#define CSL_CPSW_MACINVECTOR_HOSTPEND_SHIFT 		(0x0000001Cu)
#define CSL_CPSW_MACINVECTOR_HOSTPEND_RESETVAL		(0x00000000u)

#define CSL_CPSW_MACINVECTOR_LINKINT_MASK 		(0x0C000000u)
#define CSL_CPSW_MACINVECTOR_LINKINT_SHIFT 		(0x0000001Au)
#define CSL_CPSW_MACINVECTOR_LINKINT_RESETVAL 		(0x00000000u)

#define CSL_CPSW_MACINVECTOR_USERINT_MASK 		(0x03000000u)
#define CSL_CPSW_MACINVECTOR_USERINT_SHIFT 		(0x00000018u)
#define CSL_CPSW_MACINVECTOR_USERINT_RESETVAL 		(0x00000000u)

#define CSL_CPSW_MACINVECTOR_TXPEND_MASK 		(0x00FF0000u)
#define CSL_CPSW_MACINVECTOR_TXPEND_SHIFT 		(0x00000010u)
#define CSL_CPSW_MACINVECTOR_TXPEND_RESETVAL 		(0x00000000u)

#define CSL_CPSW_MACINVECTOR_RXTHRE_MASK 		(0x0000FF00u)
#define CSL_CPSW_MACINVECTOR_RXTHRE_SHIFT 		(0x00000008u)
#define CSL_CPSW_MACINVECTOR_RXTHRE_RESETVAL 		(0x00000000u)

#define CSL_CPSW_MACINVECTOR_RXPEND_MASK 		(0x000000FFu)
#define CSL_CPSW_MACINVECTOR_RXPEND_SHIFT 		(0x00000000u)
#define CSL_CPSW_MACINVECTOR_RXPEND_RESETVAL 		(0x00000000u)

#define CSL_CPSW_MACINVECTOR_RESETVAL 			(0x00000000u)

/* EOI vector definitions */
#define CSL_CPSW_MACEOIVECTOR_DMA_EOI_VECTOR_MASK 	(0x0000001Fu)
#define CSL_CPSW_MACEOIVECTOR_DMA_EOI_VECTOR_SHIFT 	(0x00000000u)
#define CSL_CPSW_MACEOIVECTOR_DMA_EOI_VECTOR_RESETVAL 	(0x00000000u)

#define CSL_CPSW_MACEOIVECTOR_RESETVAL 			(0x00000000u)

#define EOI_RXTHRESH_PULSE 	(0x0u)
#define EOI_RX_PULSE		(0x1u)
#define EOI_TX_PULSE		(0x2u)
#define EOI_MISC_PULSE		(0x3u)

/* Miscellaneous register related defines */
#define CPSW3G_ALE_TABLE_WRITE                      (0x1u << 31)
#define CPSW3G_SOFT_RESET_BIT                       (0x1u << 0)
#define CPSW3G_SOFT_RESET_COMPLETE                  (0x0u << 0)
#define CPSW3G_TX_CONTROL_TX_ENABLE_VAL             (0x1u << 0)
#define CPSW3G_RX_CONTROL_RX_ENABLE_VAL             (0x1u << 0)
#define CPSW3G_HOST_ERR_INTMASK_VAL                 (0x1u << 1)
#define CPSW3G_STAT_PEND_INTMASK_VAL		(0x1u << 0)


/*
 * \brief CPSW3G register overlay pointer
 *
 * Can be used  directly for performance considerations.
 */
typedef volatile CSL_Cpsw3gRegs *CSL_Cpsw3g_RegsOvly;

/*
 * CPPI DMA  Descriptor
 *
 * The following is the format of a single buffer descriptor
 */
typedef struct _CPPI_Desc {
  struct _CPPI_Desc *pNext;     /* Pointer to next descriptor in chain */
  Uint8             *pBuffer;   /* Pointer to data buffer              */
  Uint32            BufOffLen;  /* Buffer Offset(MSW) and Length(LSW)  */
  Uint32            PktFlgLen;  /* Packet Flags(MSW) and Length(LSW)   */
} CPPI_Desc;

#ifdef __cplusplus
}
#endif

#endif /* __CPSW3G_COMMON_H__ */	
