/*
 *  Copyright 2007 by Texas Instruments Incorporated.
 *  All rights reserved. Property of Texas Instruments Incorporated.
 *  Restricted rights to use, duplicate or disclose this code are
 *  granted through contract.
 *
 *  @(#) TCP/IP_Network_Developers_Kit 1.92.00.13
 */
/**
 *
 * llpacket.h
 *
 * Useful equates for a packet driver
 *
 */

#ifndef _LLPACKET_H
#define _LLPACKET_H

#ifdef __cplusplus
extern "C" {
#endif

/**
 *
 * Pre-Pad Packet Data Offset
 *
 * The TCP/IP stack library requires that every packet device
 * include enough L2 header room for all supported headers. In
 * order to support PPPoE, this requires a 22 byte L2 header.
 * Thus, since standard Ethernet is only 14 bytes, we must add
 * on an additional 8 byte offset, or PPPoE can not function
 * with our driver.
 *
 */
#define PKT_PREPAD          (8u)

/**CHECK : Arrive at correct number for Max.multicast entries */
/**
 * Multicast Address List Size. We support multicast filtering through
 * ALE entries and there are a maximum of 1024 entries in ALE
 */
#define PKT_MAX_MCAST       (64u)

/**
 * Packet Queues
 */
extern PBMQ    PBMQ_rx;         /* Rx queue (one for all PKT devices) */

/**
 *
 * Packet device information
 *
 */
typedef struct _pdinfo {
    Uint32            PhysIdx;    /* Physical index of this device (0 to n-1) */
    HANDLE            hEther;     /* Handle to logical driver */
    STKEVENT_Handle   hEvent;
    Uint8             bMacAddr[6];/* MAC Address */
    Uint32            Filter;     /* Current RX filter */
    Uint32            MCastCnt;   /* Current MCast Address Counter */
    Uint8             bMCast[6*PKT_MAX_MCAST];
    /* Number of Multicast address from previous filter setting */
    Uint32	      OldMCastCnt;
    /*List of Multicast address from Previous Filter setting */
    Uint8 	      bOldMCast[6*PKT_MAX_MCAST];
    Uint32            TxFree;     /* Transmitter "free" flag */
    Uint32	      TxOn;		/* Driver can accept next Tx */
    PBMQ              PBMQ_tx;    /* Tx queue (one for each PKT device) */
    HANDLE            hNetDev;    /* Handle to HW bookkeeping */
} PDINFO;



/**
 *
 * Functions Provided by Hw specific code
 *
 */
extern Uint32 HwPktInit();
extern void HwPktShutdown();
extern Uint32 HwPktOpen( PDINFO *pi );
extern void HwPktClose( PDINFO *pi );
extern void HwPktSetRx( PDINFO *pi );
extern void HwPktTxNext( PDINFO *pi );
extern void _HwPktPoll( PDINFO *pi, Uint32 fTimerTick );
extern Uint32 HwPktIoctl(PDINFO *pi, Uint32 cmd, void* param);

extern Uint32 CPSW3G_set_connector(Uint32 use_SMA_on_port0,Uint32 use_SMA_on_port1);

#ifdef __cplusplus
}
#endif

#endif/* end of __LLPACKET_H__ */
