/*******************************************************************************
**+--------------------------------------------------------------------------+**
**|                            ****                                          |**
**|                            ****                                          |**
**|                            ******o***                                    |**
**|                      ********_///_****                                   |**
**|                      ***** /_//_/ ****                                   |**
**|                       ** ** (__/ ****                                    |**
**|                           *********                                      |**
**|                            ****                                          |**
**|                            ***                                           |**
**|                                                                          |**
**|         Copyright (c) 1998-2007 Texas Instruments Incorporated           |**
**|                        ALL RIGHTS RESERVED                               |**
**|                                                                          |**
**| Permission is hereby granted to licensees of Texas Instruments           |**
**| Incorporated (TI) products to use this computer program for the sole     |**
**| purpose of implementing a licensee product based on TI products.         |**
**| No other rights to reproduce, use, or disseminate this computer          |**
**| program, whether in part or in whole, are granted.                       |**
**|                                                                          |**
**| TI makes no representation or warranties with respect to the             |**
**| performance of this computer program, and specifically disclaims         |**
**| any responsibility for any damages, special or consequential,            |**
**| connected with the use of this program.                                  |**
**|                                                                          |**
**+--------------------------------------------------------------------------+**
*******************************************************************************/

/** \file   cpsw3g_core.h
    \brief  CPSW_3G Header file

 * Author: A.G.Sriramakrishnan
 */

#ifndef _CPSW3G_CORE_H
#define _CPSW3G_CORE_H

#include "cslr_cpsw3g.h"      /* CSL header file */
#include "cpsw3g_ioctl.h" /* Data structures required by Ioctls */
#include "cpsw3g_init_cfg.h"  /* Init time static config params */
#include  "cpsw_miimdio.h"

#ifdef __cplusplus
extern "C" {
#endif

/* Board Specific Parameters
 * */
#define CPSW3G_MAX_INSTANCES                1u           /**< Max CPSW3G instances */
#define CPMAC_MIN_ETHERNET_PKT_SIZE         60u          /**< Minimum Ethernet packet size */
#define CPSW3G_NUM_PORTS                    3u           /**< CPSW3G Port Count */
#define CPSW3G_NUM_MAC_PORTS                2u           /**< MAC Port Count */
#define CPSW3G_DMA_PORT_NUM                 2u           /**< DMA Port number */
#define CPSW3G_BRD_PORT                     0xFFu        /**< Virtual Broadcast Port from the  Host Port */
#define CPDMA_MAX_DIR                       2u           /**< Number of DMA data directions (tx and rx) */
#define CPSW3G_MAX_VLANS                    1024u        /**< Maximum number of VLANs supported */
#define CPDMA_MAX_CHANNELS                  8u           /**< Maximum num of channels supported by the DMA */

#define CPSW3G_MIN_FREQUENCY_FOR_10MBPS     5500000u     /**< Minimum CPMAC bus frequency for 10   Mbps operation is 5.5 MHz (as per specs) */
#define CPSW3G_MIN_FREQUENCY_FOR_100MBPS    55000000u    /**< Minimum CPMAC bus frequency for 100  Mbps operation is 55  MHz (as per specs) */
#define CPSW3G_MIN_FREQUENCY_FOR_1000MBPS   125000000u   /**< Minimum CPMAC bus frequency for 1000 Mbps operation is 125 MHz (as per specs) */


#define CPSW3G_ALE_TABLE_DEPTH              1024u        /**< Maximum number of ALE table entries */

#define CPSW3G_USE_DEFAULT                  0x0afbdce1u  /**< Flag to indicate use of a default */
#define CPSW3G_MIN_ETHERNET_PKT_SIZE        60u          /**< Minimum Ethernet packet size */
#define CPSW3G_PORT_STATE_DISABLED          0u
#define CPSW3G_PORT_STATE_BLOCKED           1u
#define CPSW3G_PORT_STATE_LEARN             2u
#define CPSW3G_PORT_STATE_FORWARD           3u
#define CPSW3G_NUM_STAT_REGS                36u
#define CPSW3G_STAT_CLEAR                   0xFFFFFFFFu


#define NET_CH_DIR_TX 0u
#define NET_CH_DIR_RX 1u
#define CONFIG_CPGMAC_NOPHY        9999u

/* Macros for Address conversions */
#define PAL_CPSW3G_VIRT_2_PHYS(addr)             PAL_osMemVirt2Phy((Ptr)(addr))
#define PAL_CPSW3G_VIRT_NOCACHE(addr)            PAL_osMemVirt2VirtNoCache((Ptr)(addr))
#define PAL_CPSW3G_CACHE_INVALIDATE(addr, size)  PAL_sysCacheInvalidate(PAL_OSMEM_ADDR_DAT, (Ptr)(addr), (Uint32)(size))

#define PAL_CPSW3G_CACHE_WRITEBACK(addr, size)               PAL_sysCacheFlush(PAL_OSMEM_ADDR_DAT, (Ptr)(addr), (Uint32)(size))

#define PAL_CPSW3G_CACHE_WRITEBACK_INVALIDATE(addr, size)    PAL_sysCacheFlushAndInvalidate(PAL_OSMEM_ADDR_DAT, (Ptr)(addr), (Uint32)(size))


/** Internal functions return error codes */
#define CPSW3G_INSTANCE_CODE                     0u 
#define CPSW3G_ERROR_BASE                        (0x200001Fu)   
#define CPSW3G_ERROR_CODE                        ((CPSW3G_ERROR_BASE | (CPSW3G_INSTANCE_CODE << 16)))
#define CPSW3G_ERROR_INFO                        (CPSW3G_ERROR_CODE)
#define CPSW3G_ERROR_WARNING                     (CPSW3G_ERROR_CODE | 0x10000000u)
#define CPSW3G_ERROR_MINOR                       (CPSW3G_ERROR_CODE | 0x20000000u)
#define CPSW3G_ERROR_MAJOR                       (CPSW3G_ERROR_CODE | 0x30000000u)
#define CPSW3G_ERROR_CRITICAL                    (CPSW3G_ERROR_CODE | 0x40000000u)

/* CPMAC Success code */
#define CPSW3G_SUCCESS                           0u

/* CPSW3G Error codes */
#define CPSW3G_ERR_DEV_ALREADY_INSTANTIATED(instID) (0x30000000u + CPSW3G_ERROR_BASE + ((instId) << 16) )
#define CPSW3G_ERR_DEV_NOT_INSTANTIATED          (CPSW3G_ERROR_MAJOR + 1u)
#define CPSW3G_INVALID_PARAM                     (CPSW3G_ERROR_MAJOR + 2u)
#define CPSW3G_ERR_CH_INVALID                    (CPSW3G_ERROR_CRITICAL + 3u)
#define CPSW3G_ERR_CH_ALREADY_INIT               (CPSW3G_ERROR_MAJOR + 4u)
#define CPSW3G_ERR_TX_CH_ALREADY_CLOSED          (CPSW3G_ERROR_MAJOR + 5u)
#define CPSW3G_ERR_TX_CH_NOT_OPEN                (CPSW3G_ERROR_MAJOR + 6u)
#define CPSW3G_ERR_TX_NO_LINK                    (CPSW3G_ERROR_MAJOR + 7u)
#define CPSW3G_ERR_TX_OUT_OF_BD                  (CPSW3G_ERROR_MAJOR + 8u)
#define CPSW3G_ERR_RX_CH_INVALID                 (CPSW3G_ERROR_CRITICAL + 9u)
#define CPSW3G_ERR_RX_CH_ALREADY_INIT            (CPSW3G_ERROR_MAJOR + 10u)
#define CPSW3G_ERR_RX_CH_ALREADY_CLOSED          (CPSW3G_ERROR_MAJOR + 11u)
#define CPSW3G_ERR_RX_CH_NOT_OPEN                (CPSW3G_ERROR_MAJOR + 12u)
#define CPSW3G_ERR_DEV_ALREADY_CREATED           (CPSW3G_ERROR_MAJOR + 13u)
#define CPSW3G_ERR_DEV_NOT_OPEN                  (CPSW3G_ERROR_MAJOR + 14u)
#define CPSW3G_ERR_DEV_ALREADY_CLOSED            (CPSW3G_ERROR_MAJOR + 15u)
#define CPSW3G_ERR_DEV_ALREADY_OPEN              (CPSW3G_ERROR_MAJOR + 16u)
#define CPSW3G_ERR_RX_BUFFER_ALLOC_FAIL          (CPSW3G_ERROR_CRITICAL +17u)
#define CPSW3G_INTERNAL_FAILURE                  (CPSW3G_ERROR_MAJOR + 18u)
#define CPSW3G_VLAN_UNAWARE_MODE                 (CPSW3G_ERROR_MAJOR + 19u)
#define CPSW3G_ALE_TABLE_FULL                    (CPSW3G_ERROR_MAJOR + 20u)
#define CPSW3G_ADDR_NOTFOUND                     (CPSW3G_ERROR_MAJOR + 21u)
#define CPSW3G_INVALID_VLANID                    (CPSW3G_ERROR_MAJOR + 22u)
#define CPSW3G_INVALID_PORT                      (CPSW3G_ERROR_MAJOR + 23u)
#define CPSW3G_BD_ALLOC_FAIL                    (CPSW3G_ERROR_MAJOR + 24u)
#define CPSW3G_RXBUFF_ALLOC_FAIL            (CPSW3G_ERROR_MAJOR +25u)

/**
 *  \brief CPSW3G Internal Control Function Ioctl Codes
 * Since all are internal functions, might as well call the local
 * functions instead of going thru a common control function.
 */
#define CPSW3G_CONTROL_IOCTL_BASE                     0u
#define CPSW3G_CONTROL_IOCTL_SET_ALECFG              (CPSW3G_CONTROL_IOCTL_BASE + 1u)
#define CPSW3G_CONTROL_IOCTL_SET_MACCFG              (CPSW3G_CONTROL_IOCTL_BASE + 2u)
#define CPSW3G_CONTROL_IOCTL_GET_STATUS              (CPSW3G_CONTROL_IOCTL_BASE + 3u)
#define CPSW3G_CONTROL_IOCTL_READ_PHY_REG            (CPSW3G_CONTROL_IOCTL_BASE + 4u)
#define CPSW3G_CONTROL_IOCTL_WRITE_PHY_REG           (CPSW3G_CONTROL_IOCTL_BASE + 5u)
#define CPSW3G_CONTROL_IOCTL_GET_STATISTICS          (CPSW3G_CONTROL_IOCTL_BASE + 6u)
#define CPSW3G_CONTROL_IOCTL_CLR_STATISTICS          (CPSW3G_CONTROL_IOCTL_BASE + 7u)
#define CPSW3G_CONTROL_IOCTL_MULTICAST_ADDR          (CPSW3G_CONTROL_IOCTL_BASE + 8u)
#define CPSW3G_CONTROL_IOCTL_ALL_MULTI               (CPSW3G_CONTROL_IOCTL_BASE + 9u)
#define CPSW3G_CONTROL_IOCTL_SET_MAC_ADDRESS         (CPSW3G_CONTROL_IOCTL_BASE + 10u)
#define CPSW3G_CONTROL_IOCTL_SET_SRC_MAC_ADDRESS     (CPSW3G_CONTROL_IOCTL_BASE + 11u)
#define CPSW3G_CONTROL_IOCTL_SET_ALEPORTCFG          (CPSW3G_CONTROL_IOCTL_BASE + 12u)
#define CPSW3G_CONTROL_IOCTL_SET_DMACFG              (CPSW3G_CONTROL_IOCTL_BASE + 13u)
#define CPSW3G_CONTROL_IOCTL_SET_CPSWCFG             (CPSW3G_CONTROL_IOCTL_BASE + 14u)
#define CPSW3G_CONTROL_IOCTL_ALE_AGEOUTNOW           (CPSW3G_CONTROL_IOCTL_BASE + 15u)
#define CPSW3G_CONTROL_IOCTL_SET_DEBUG_LEVEL         (CPSW3G_CONTROL_IOCTL_BASE + 16u)
#define CPSW3G_CONTROL_IOCTL_GET_DEBUG_LEVEL         (CPSW3G_CONTROL_IOCTL_BASE + 17u)
#define CPSW3G_CONTROL_IOCTL_SET_MAC_RXMAXLEN        (CPSW3G_CONTROL_IOCTL_BASE + 18u)
#define CPSW3G_CONTROL_IOCTL_SET_SHORTGAPTHRESH      (CPSW3G_CONTROL_IOCTL_BASE + 19u)
#define CPSW3G_CONTROL_IOCTL_PORT_STATISTICS_ENABLE  (CPSW3G_CONTROL_IOCTL_BASE + 20u)
#define CPSW3G_CONTROL_IOCTL_IF_PARAMS_UPDT          (CPSW3G_CONTROL_IOCTL_BASE + 21u)

/**
 *  \brief CPSW3G DDA Ioctl's
 *
 *  Called by the DDC layer, implemented by DDA layer in Control function
 */
#define DDA_NET_CPSW3G_IOCTL_BASE                0u    /* Arbitrary Base */
#define CPSW3G_DDA_IOCTL_TIMER_START             (DDA_NET_CPSW3G_IOCTL_BASE + 1u)
#define CPSW3G_DDA_IOCTL_TIMER_STOP              (DDA_NET_CPSW3G_IOCTL_BASE + 2u)
#define CPSW3G_DDA_IOCTL_STATUS_UPDATE           (DDA_NET_CPSW3G_IOCTL_BASE + 3u)
#define CPSW3G_DDA_IOCTL_TEARDOWN_PEND           (DDA_NET_CPSW3G_IOCTL_BASE + 4u)
#define CPSW3G_DDA_IOCTL_SET_MACCFG              (DDA_NET_CPSW3G_IOCTL_BASE + 5u)
#define CPSW3G_DDA_IOCTL_SET_ALEPORTCFG          (DDA_NET_CPSW3G_IOCTL_BASE + 6u)
#define CPSW3G_DDA_IOCTL_SET_ALECFG              (DDA_NET_CPSW3G_IOCTL_BASE + 7u)
#define CPSW3G_DDA_IOCTL_SET_CPSWCFG             (DDA_NET_CPSW3G_IOCTL_BASE + 8u)
#define CPSW3G_DDA_IOCTL_SET_DMACFG              (DDA_NET_CPSW3G_IOCTL_BASE + 9u)
#define CPSW3G_DDA_PRIV_MII_READ                 (DDA_NET_CPSW3G_IOCTL_BASE + 10u)
#define CPSW3G_DDA_PRIV_MII_WRITE                (DDA_NET_CPSW3G_IOCTL_BASE + 11u)
#define CPSW3G_DDA_PRIV_GET_STATS                (DDA_NET_CPSW3G_IOCTL_BASE + 12u)
#define CPSW3G_DDA_PRIV_CLR_STATS                (DDA_NET_CPSW3G_IOCTL_BASE + 13u)

/* Control Codes for internal control function*/
#define CPSW3G_PHY_STATUS_UPDATE			0u


/*
 * \brief MII module port settings
 *
 * Phy mode is constructed as a combination of the following in "phyMode" parameter
 * in the init configuration structure
 */
#define SNWAY_AUTOMDIX      (1<<16)   /* Bit 16 and above not used by MII register */
#define SNWAY_FD1000        (1<<13)
#define SNWAY_HD1000        (1<<12)
#define SNWAY_NOPHY         (1<<10)
#define SNWAY_LPBK          (1<<9)
#define SNWAY_FD100         (1<<8)
#define SNWAY_HD100         (1<<7)
#define SNWAY_FD10          (1<<6)
#define SNWAY_HD10          (1<<5)
#define SNWAY_AUTO          (1<<0)
#define SNWAY_AUTOALL       (SNWAY_AUTO|SNWAY_FD1000|SNWAY_FD100|SNWAY_FD10|SNWAY_HD100|SNWAY_HD10)


/**
 *  \brief DMA Net Status
 *
 */
typedef struct
{
  Bool   rxPending;  /**< rx packets pending? */
  Bool   txPending;  /**< tx packets pending? */
  Bool   errPending; /**< host DMA error occurred */
  Bool   statPending; /**<Stats Pending Interrupt */

  Uint32 rxChannel;  /**< channel needing service for Rx */
  Uint32 txChannel;  /**< channel needing service for Tx */
} CpdmaNetStatus;

/**
 *  \brief CPGMAC_SL PHY Status values
 *
 *  Provides PHY status of the device.
 *
 */
typedef struct
{
  Uint32      PhyLinked;      /**< Link status: 1=Linked, 0=No link */
  Uint32      PhyDuplex;      /**< Duplex status: 1=Full Duplex, 0=Half Duplex */
  Uint32      PhySpeed;       /**< Link Speed = 2= 1000 mbps, 1= 100 mbps, 0= 10 mbps*/
  Uint32      PhyNum;         /**< Phy number - useful if phy number is discovered */
} CpgmacMacStatus;

/**
 *  \brief Port structure
 *  
 */
typedef struct
{
  Uint32  portNum;     /**< Port number 0-2 */
  Uint32  chNum;       /**< Ch number 0-7 (currently unused - may not need it) */
} Cpsw3gPort;

typedef struct
{
  Uint32	    chNum;     
  Uint32       chDir;
  Uint32       numBD;
  Uint32       bufSize; 
}Cpsw3gChInfo;

/**
 *  \brief ALE Port configuration
 *
 *  This data structure contains configuration items related to the
 *  ALE_Port_Control register fields.
 */
typedef struct
{
  Uint8       bcastLimit;       /**< Broadcast Packet Rate Limit */
  Uint8       mcastLimit;       /**< Multicast Packet Rate Limit */
  Bool        noLearn;          /**< No Learn mode */
  Bool        vidIngressCheck;  /**< VLAN ID Ingress Check */
  Bool        dropUntagged;     /**< Drop untagged packets */
  Uint8       portState;        /**< Port State: 0-disabled, 1-blocked, 2-learn
                   3-forward */
} AlePortConfig;

/**
 *  \brief ALE configuration
 *
 *  This data structure contains configuration items related to the
 *  ALE_CONTROL register fields.
 */
typedef struct
{
  /* ALE Control fields */
  Bool        enableAle;        /**< Enable ALE */
  Bool        clearTable;       /**< Clear ALE Address table */
  Bool        ageOutNow;        /**< Age out address table now */
  Bool        learnNoVid;       /**< Learn no VID */
  Bool        enVid0Mode;       /**< Enable VLAN ID = 0 Mode */
  Bool        enableOuiDeny;    /**< Enable OUI Deny Mode */
  Bool        aleBypass;        /**< ALE bypass mode */
  Bool        rateLimitTx;      /**< Rate limit transmit mode */
  Bool        aleVlanAware;     /**< ALE Vlan Aware */
  Bool        enableAuthMode;   /**< Enable MAC Authorization mode */
  Bool        enableRateLimit;  /**< Enable broadcast and multicast rate limit */

  /* ALE Prescale register */
  Uint32      alePrescale;       /**< ALE Prescale */

  /* ALE Unknown VLAN register */
  Uint8       unknownForceUntaggedEgress; /**< Unknown VLAN Force Untagged Egress (except on port 2) */
  Uint8       unknownRegMcastFloodMask; /**< Unknown VLAN Registered Multicast Flood Mask */
  Uint8       unknownMcastFloodMask; /**< Unknown VLAN Multicast Flood Mask */
  Uint8       unknownVlanMemberList; /**< Unknown VLAN Member List */
} AleConfig;

/**
 *  \brief CPSW configuration
 *
 *  This data structure contains configuration items related to the
 *  CPSW_CONTROL and PTYPE register fields.
 */
typedef struct
{
  /* CPSW_CONTROL */
  Bool        p2PassPriTagged;  /**< Port 2 Pass Priority Tagged */
  Bool        p1PassPriTagged;  /**< Port 1 Pass Priority Tagged */
  Bool        p0PassPriTagged;  /**< Port 0 Pass Priority Tagged */
  Bool        vlanAware;        /**< VLAN aware mode */
  Bool        rxVlanEncap;      /**< Port 2 VLAN Encapsulation */
  Bool        p2P2RxFlowEn;     /**< Port 2 Tx flow enable from Port 2 Rx FIFO */
  Bool        p2P1TxFlowEn;     /**< Port 2 Tx flow enable from Port 1 Tx FIFO */
  Bool        p2P0TxFlowEn;     /**< Port 2 Tx flow enable from Port 0 Tx FIFO */
  Bool        p1P2TxFlowEn;     /**< Port 1 Rx flow enable from Port 2 Tx FIFO */
  Bool        p1P0TxFlowEn;     /**< Port 1 Rx flow enable from Port 0 Tx FIFO */
  Bool        p0P2TxFlowEn;     /**< Port 0 Rx flow enable from Port 2 Tx FIFO */
  Bool        p0P1TxFlowEn;     /**< Port 0 Rx flow enable from Port 1 Tx FIFO */
  Bool        fifoLoopback;     /**< FIFO Loopback mode */

  /* PTYPE register */
  Bool        p2PtypeEsc;       /**< Port 2 Priority Type escalate */
  Bool        p1PtypeEsc;       /**< Port 1 Priority Type escalate */
  Bool        p0PtypeEsc;       /**< Port 0 Priority Type escalate */
  Uint8       escPriLdVal;      /**< Escalate priority load value */

  /* Stat_Port_en register */
  Bool        p2StatEn;         /**< Port 2 statistics enable */
  Bool        p1StatEn;         /**< Port 1 statistics enable */
  Bool        p0StatEn;         /**< Port 0 statistics enable */

  /* Misc */
  Uint32      resetLine;        /**< Reset controller line # */
  Uint32      intrLine;         /**< Interrupt controller line # */
  Uint32      baseAddress;      /**< CPSW3G device's register overlay address */
  Uint32      cpmacBusFrequency;  /**< Bus frequency at which this module is operating */
  Uint32      mdioBaseAddress;    /**< MDIO Device base address */
  Uint32      mdioResetLine;      /**< MDIO Device Reset line number within the system */
  Uint32      mdioBusFrequency;   /**< Bus frequency for the MII module */
  Uint32      mdioClockFrequency; /**< Clock frequency for MDIO link */
  Uint32      mdioTickMSec;       /**<  MDIO Tick count in milliSeconds */
  Uint32	   sgmii0BaseAddress; /**< SGMII 0 Regs Base address */
  Uint32	   sgmii1BaseAddress; /**< SGMII 1 Regs Base address */
  Uint32	   cpsw3GSSBaseAddress; /**<CPSW_3GSS_S regs base address */
} Cpsw3gConfig;


/**
 *  \brief CPDMA Init Configuration
 *
 *  Configuration information provided during initialization.
 *  The config info can come from various sources - static compiled in info,
 *  boot time (Flash) info etc. Currently static compiled values supported.
 */
typedef struct
{
  Uint8       portPri;            /**< Port VLAN priority (7 is highest) */
  Bool        portCfi;            /**< Port CFI bit */
  Uint32      portVID;            /**< Port VLAN ID */
  Uint32      rxBufferOffset;     /**< Receive buffer offset */

  Uint32      numChannels[2];  /**< Number of Channels supported in each dir */

  /**Register control fields */
  /* DMA Control register */
  Bool        rxCef;            /**< Rx Copy Error Frames Enable */
  Bool        cmdIdle;          /**< Command Idle */
  Bool        rxOfflenBlock;    /**< Receive offset/Length word write block */
  Bool        rxOwnership;      /**< Rx ownership write bit value */
  Bool        txPtype;          /**< Transmit Queue Priority type */

  /* CPDMA_RX_CH_MAP Register: Host ch mapping only used when in bypass mode */
  Uint8       hostRxCh_gmac0Pri0; /**< Receive pkts from SL0 w/pri 0x0 on this ch */
  Uint8       hostRxCh_gmac0Pri1; /**< Receive pkts from SL0 w/pri 0x1 on this ch */
  Uint8       hostRxCh_gmac0Pri2; /**< Receive pkts from SL0 w/pri 0x2 on this ch */
  Uint8       hostRxCh_gmac0Pri3; /**< Receive pkts from SL0 w/pri 0x3 on this ch */
  Uint8       hostRxCh_gmac1Pri0; /**< Receive pkts from SL1 w/pri 0x0 on this ch */
  Uint8       hostRxCh_gmac1Pri1; /**< Receive pkts from SL1 w/pri 0x1 on this ch */
  Uint8       hostRxCh_gmac1Pri2; /**< Receive pkts from SL1 w/pri 0x2 on this ch */
  Uint8       hostRxCh_gmac1Pri3; /**< Receive pkts from SL1 w/pri 0x3 on this ch */
} CpdmaConfig;

/**
 *  \brief CPGMAC SL Init Configuration
 *
 *  Configuration information provided during initialization.
 *  The config info can come from various sources - static compiled in info,
 *  boot time (Flash) info etc. Currently static compiled values supported.
 */
typedef struct
{
  Uint32      PhyMask;            /**< Phy Mask for this CPMAC Phy  */
  Uint32      MLinkMask;          /**< MLink Mask for this CPMAC Phy  */
  Uint32      phyMode;            /**< Phy mode settings - Speed,Duplex */
  Uint32      sourceAddressHi;    /**< Source address high bits (47:16) */
  Uint32      sourceAddressLo;    /**< Source address low bits (15:0) */
  Uint8       portPri;            /**< Port VLAN priority (7 is highest) */
  Bool        portCfi;            /**< Port CFI bit */
  Uint32      portVID;            /**< Port VLAN ID */
  Uint32      rxMaxlen;           /**< Rx MaxFrame Length (default 1518, max 2047) */
  Bool        passCrc;            /**< If set, MAC won't generate new CRC per pkt */

  /* Register control fields */
  Bool        rxCmfEn;             /**< Rx Copy MAC Control Frames Enable */
  Bool        rxCsfEn;             /**< Rx Copy Short Frames Enable */
  Bool        rxCefEn;             /**< Rx Copy Error Frames Enable */
  Bool        extEn;               /**< External enable */
  Bool        gigForce;            /**< Force Gigabit mode */
  Bool        ifCtlB;              /**< general purpose output GMII */
  Bool        ifCtlA;              /**< general purpose output GMII */
  Bool        cmdIdle;             /**< enable / disable idle command */
  Bool        txShortGapEnable;    /**< Short Gap enable on transmit */
  Bool        gigaBitEnable;       /**< Gigabit mode */
  Bool        txPacingEnable;      /**< Transmit pacing enabled ? */
  Bool        gmiiEnable;
  Bool        txFlowEnable;        /**< TX Flow Control enabled ? */
  Bool        rxFlowEnable;        /**< TX Flow Control enabled ? */
  Bool        loopbackEnable;      /**< Loopback mode enabled ? */
  Bool        fullduplex;
  Bool        internalPhy;
} CpgmacMacConfig;

/**
 *  \brief CPSW3G Init Configuration
 *
 *  Configuration information provided during initialization.
 *  The config info can come from various sources - static compiled in info,
 *  boot time (Flash) info etc. Currently static compiled values supported.
 */
typedef struct
{
  /* Port specific items */
  CpgmacMacConfig  macInitCfg[CPSW3G_NUM_MAC_PORTS];     /**< CPGMAC SL Init Configuration */
  CpdmaConfig     dmaInitCfg;        /**< DMA Init Configuration */

  /* ALE specific items */
  AleConfig           aleCfg;            /**< ALE Init Configuration */
  AlePortConfig       alePortCfg[CPSW3G_NUM_PORTS];     /**< ALE Port Configuration */

  /* Switch specific items */
  Cpsw3gConfig        cpswCfg;           /**< CPSW Control register fields */
  Uint32 Mib64CntMsec;
} Cpsw3gInitConfig;

typedef enum
{
        BROADCAST = 0,
        MULTICAST,
        UNICAST
}typeOfData;



/* Book Keeping structure for CPSW, ports,CPGMAC_SL  */

/** ######### DDC Private DS definition block ############ **/
/* forward declarations to resolve dependencies */
struct Cpsw3gMode_t;
struct Cpsw3gDDCObj_t;
struct CpgmacSlDDCObj_t;
struct CpdmaDDCObj_t;

/**
 * Transmit/Receive Descriptor Channel Structure
 * (One receive and one transmit in this driver)
 */
typedef struct _CPPI_DescCh {
    PBMQ                    DescQueue;    /* Packets queued as desc */
    Uint32                  DescMax;      /* Max number of desc (buffs) */
    Uint32                  DescCount;    /* Current number of desc */
    CPPI_Desc               *pDescFirst;  /* First desc location */
    CPPI_Desc               *pDescLast;   /* Last desc location */
    CPPI_Desc               *pDescRead;   /* Location to read next desc */
    CPPI_Desc               *pDescWrite;  /* Location to write nest desc */
    Cpsw3gChInfo    *chInfo;
}CPPI_DescCh;

typedef CPPI_DescCh Cpsw3gTxCppiCh;
typedef CPPI_DescCh Cpsw3gRxCppiCh;


typedef struct CpgmacObj_t
{
    PHY_DEVICE  PhyDev;         /**< MII-MDIO module device structure */
    Uint32      macControl;      /**< MACControl Register mirror */
    Uint32      alePortControl;  /**< ALE_Port_Ctl register mirror */
    Uint32      portState;       /**< State of each port */

    /* Status related fields */
    Uint32      PhyLinked;      /**< Link status: 1=Linked, 0=No link */
    Uint32      PhyDuplex;      /**< Duplex status: 1=Full Duplex, 0=Half Duplex */
    Uint32      PhySpeed;       /**< Link Speed = 2= 1000 mbps, 1= 100 mbps, 0= 10 mbps*/
    Uint32      PhyNum;         /**< Phy number - useful if phy number is discovered */

    /* mode of operation related s/w fields */
    Bool	intPhy;
    Bool	promiscousEnable;
    Bool	broadcastEnable;
    Bool	multicastEnable;
    
}CpgmacObj;


typedef struct CpdmaObj_t
{
    Cpsw3gTxCppiCh      txCppi[CPDMA_MAX_CHANNELS];  /**< Tx Control struct ptrs */
    Cpsw3gRxCppiCh      rxCppi[CPDMA_MAX_CHANNELS];  /**< Rx Control struct ptrs */  
    Bool                chIsInit[CPDMA_MAX_DIR][CPDMA_MAX_CHANNELS]; /**< channel initialized ? */
    Bool                chIsOpen[CPDMA_MAX_DIR][CPDMA_MAX_CHANNELS]; /**< channel open ? */
    Bool                tdPending[CPDMA_MAX_DIR][CPDMA_MAX_CHANNELS]; /**< teardown pending ? */
    Int                 txIntThreshold[CPDMA_MAX_CHANNELS];    /**< TX  Completion Threshold count */

    Uint32              alePortControl;  /**< ALE_Port_Ctl register mirror */
    Uint32              portState;       /**< State of each port */
    Uint32              dmaControl;      /**< DMAControl register mirror */

    /* Status related fields */
    Uint32      hwStatus;       /**< Either NO_ERROR or combination of error bits from above status codes */
    Uint32      hwErrInfo;       /**< If error, contains DMASTATUS register contents  */
}CpdmaObj;

/** ######### DDC Private DS definition block ENDS############ **/




/**
 * \brief CPSW3G Private data structure
 *
 * Each CPSW3G device maintains its own private data structure.
 */
typedef struct Cpsw3gDevice_t
{
    PDINFO		            *pdinfo;	    /**<PDINFO structure ptr */	
    Uint32                  linkSpeed[2];   /**<Link Speed */
    Uint32                  linkMode[2];    /**<Link Mode */
    Uint32                  linkStatus[2];  /**<Link up/down status */
    Uint32  	            setToClose;         /**< Flag to indicate closing of device */

    /**<CPGMAC MAC Book keeping structures*/
    CpgmacObj		        cpgmacMac[CPSW3G_NUM_MAC_PORTS];
    /**<CPDMA Book keeping structures*/
    CpdmaObj		        cpdma;

    Cpsw3gPort		        cpsw3gPort[CPSW3G_NUM_PORTS];
    CSL_Cpsw3g_RegsOvly	 regs;          /**< Pointer points to base addr of cpsw3g*/
    CSL_EctlRegsOvly		 ectlRegs;   /**< Pointer to base addr of CPSW_3G_SS_S regs */
    CSL_SgmiiRegsOvly		 sgmii0Regs;/**<Pointer to base addr of SGMII 0 control regs */ 
    CSL_SgmiiRegsOvly		 sgmii1Regs;/**<Pointer to base addr of SGMII 1 control regs */ 
    
    Uint32		            cpswControl;   /**< CPSW_CONTROL register mirror */
    Uint32  		        aleControl;    /**< ALE Control register mirror */
    
    /* Configuration parameters */
    Uint8 	        	    macAddr[6];        /**< Mac (ethernet) address */
    Cpsw3gInitConfig        *initCfg;            /**< Init cfg parameters - contains rx and mac cfg structures */
    Uint32	                rxBufSize;          /**< RX Buffer Size - size to be allocated for RX */
    Uint32 	                rxBufOffset;        /**> RX Buffer Offset - extra bytes to be reserved before RX data begins in a buffer */

    /* Channel configuration - provision is made for max number of channels */
    Cpsw3gChInfo	        chInfo[2][CPDMA_MAX_CHANNELS];    /**< Channel configuration */

    Uint32		            periodicTicks;      /**< Ticks for this timer */
    Bool		            timerActive;        /**< Periodic timer active ??? */
    Uint32		            aleTicks;      /**< Ticks for this timer */
    Uint32 		     aleTimerActive; /**<ALE ageout timer active? */
    Uint32		            isrCount;           /**< Number of interrupts */

    Uint32		            BufPoolId;
    Uint32		            Clear_EOI;//check actual use

    Cpsw3gStatistics	statsObj; /**<Statistics object in s/w */

 }Cpsw3gDevice;


/*@}*/

#ifdef __cplusplus
}
#endif

#endif /* __CPSW3G_CORE_H__ */
