/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005, 2006, 2007
 *
 *   Use of this software is controlled by the terms and conditions found in the
 *   license agreement under which this software has been supplied.
 *   ===========================================================================
 */
/** ============================================================================
 *   @file  cslr_cpsw3g.h
 *
 *   @path  $(CSLPATH)\inc
 *
 *   @desc  This file contains the Register Descriptions for CPSW3G
 *
 *  ============================================================================
 */

#ifndef _CSLR_CPSW3G_H_
#define _CSLR_CPSW3G_H_

#include<cslr.h>

/* Minimum unit = 1 byte */

/**************************************************************************\
* Register Overlay Structure for GMAC_PORT
\**************************************************************************/
typedef struct  {
    volatile Uint32 P_MAX_BLKS;
    volatile Uint32 P_BLK_CNT;
    volatile Uint32 P_FLOW_THRESH;
    volatile Uint32 P_PORT_VLAN;
    volatile Uint32 P_TX_PRI_MAP;
    volatile Uint32 GMAC_GAP_THRESH;
    volatile Uint32 GMAC_SA_LO;
    volatile Uint32 GMAC_SA_HI;
} CSL_Cpsw3gGmac_portRegs;

/**************************************************************************\
* Register Overlay Structure for GMAC
\**************************************************************************/
typedef struct  {
    volatile Uint32 GMAC_IDVER;
    volatile Uint32 GMAC_MACCONTROL;
    volatile Uint32 GMAC_MACSTATUS;
    volatile Uint32 GMAC_SOFT_RESET;
    volatile Uint32 GMAC_RX_MAXLEN;
    volatile Uint32 GMAC_BOFFTEST;
    volatile Uint8 RSVD0[8];
    volatile Uint32 GMAC_EMCONTROL;
    volatile Uint32 GMAC_RX_PRI_MAP;
    volatile Uint8 RSVD01[24];
} CSL_Cpsw3gGmacRegs;

/**************************************************************************\
* Register Overlay Structure
\**************************************************************************/
typedef struct  {
    volatile Uint32 CPSW_ID_VER;
    volatile Uint32 CPSW_CONTROL;
    volatile Uint32 CPSW_SOFT_RESET;
    volatile Uint32 CPSW_STAT_PORT_EN;
    volatile Uint32 CPSW_PTYPE;
    CSL_Cpsw3gGmac_portRegs GMAC_PORT[2];
    volatile Uint32 P2_MAX_BLKS;
    volatile Uint32 P2_BLK_CNT;
    volatile Uint32 P2_FLOW_THRESH;
    volatile Uint32 P2_PORT_VLAN;
    volatile Uint32 P2_TX_PRI_MAP;
    volatile Uint32 CPDMA_TX_PRI_MAP;
    volatile Uint32 CPDMA_RX_CH_MAP;
    volatile Uint8 RSVD1[16];
    CSL_Cpsw3gGmacRegs GMAC[2];
    volatile Uint32 TX_IDVER;
    volatile Uint32 TX_CONTROL;
    volatile Uint32 TX_TEARDOWN;
    volatile Uint8 RSVD2[4];
    volatile Uint32 RX_IDVER;
    volatile Uint32 RX_CONTROL;
    volatile Uint32 RX_TEARDOWN;
    volatile Uint32 SOFT_RESET;
    volatile Uint32 DMACONTROL;
    volatile Uint32 DMASTATUS;
    volatile Uint32 RX_BUFFER_OFFSET;
    volatile Uint32 EMCONTROL;
    volatile Uint8 RSVD3[80];
    volatile Uint32 TX_INTSTAT_RAW;
    volatile Uint32 TX_INTSTAT_MASKED;
    volatile Uint32 TX_INTMASK_SET;
    volatile Uint32 TX_INTMASK_CLEAR;
    volatile Uint32 CPDMA_IN_VECTOR;
    volatile Uint32 CPDMA_EOI_VECTOR;
    volatile Uint8 RSVD4[8];
    volatile Uint32 RX_INTSTAT_RAW;
    volatile Uint32 RX_INTSTAT_MASKED;
    volatile Uint32 RX_INTMASK_SET;
    volatile Uint32 RX_INTMASK_CLEAR;
    volatile Uint32 DMA_INTSTAT_RAW;
    volatile Uint32 DMA_INTSTAT_MASKED;
    volatile Uint32 DMA_INTMASK_SET;
    volatile Uint32 DMA_INTMASK_CLEAR;
    volatile Uint32 RX_PENDTHRESH[8];
    volatile Uint32 RX_FREEBUFFER[8];
    volatile Uint32 TX_HDP[8];
    volatile Uint32 RX_HDP[8];
    volatile Uint32 TX_CP[8];
    volatile Uint32 RX_CP[8];
    volatile Uint8 RSVD5[384];
    volatile Uint32 RXGOODFRAMES;
    volatile Uint32 RXBROADCASTFRAMES;
    volatile Uint32 RXMULTICASTFRAMES;
    volatile Uint32 RXPAUSEFRAMES;
    volatile Uint32 RXCRCERRORS;
    volatile Uint32 RXALIGNCODEERRORS;
    volatile Uint32 RXOVERSIZEDFRAMES;
    volatile Uint32 RXJABBERFRAMES;
    volatile Uint32 RXUNDERSIZEDFRAMES;
    volatile Uint32 RXFRAGMENTS;
    volatile Uint8 RSVD6[8];
    volatile Uint32 RXOCTETS;
    volatile Uint32 TXGOODFRAMES;
    volatile Uint32 TXBROADCASTFRAMES;
    volatile Uint32 TXMULTICASTFRAMES;
    volatile Uint32 TXPAUSEFRAMES;
    volatile Uint32 TXDEFERREDFRAMES;
    volatile Uint32 TXCOLLISIONFRAMES;
    volatile Uint32 TXSINGLECOLLFRAMES;
    volatile Uint32 TXMULTCOLLFRAMES;
    volatile Uint32 TXEXCESSIVECOLLISIONS;
    volatile Uint32 TXLATECOLLISIONS;
    volatile Uint32 TXUNDERRUN;
    volatile Uint32 TXCARRIERSENSEERRORS;
    volatile Uint32 TXOCTETS;
    volatile Uint32 OCTETFRAMES64;
    volatile Uint32 OCTETFRAMES65T127;
    volatile Uint32 OCTETFRAMES128T255;
    volatile Uint32 OCTETFRAMES256T511;
    volatile Uint32 OCTETFRAMES512T1023;
    volatile Uint32 OCTETFRAMES1024TUP;
    volatile Uint32 NETOCTETS;
    volatile Uint32 RXSOFOVERRUNS;
    volatile Uint32 RXMOFOVERRUNS;
    volatile Uint32 RXDMAOVERRUNS;
    volatile Uint8 RSVD7[112];
    volatile Uint32 ALE_IDVER;
    volatile Uint8 RSVD8[4];
    volatile Uint32 ALE_CONTROL;
    volatile Uint8 RSVD9[4];
    volatile Uint32 ALE_PRESCALE;
    volatile Uint8 RSVD10[4];
    volatile Uint32 ALE_UNKNOWN_VLAN;
    volatile Uint8 RSVD11[4];
    volatile Uint32 ALE_TBLCTL;
    volatile Uint8 RSVD12[16];
    volatile Uint32 ALE_TBLW2;
    volatile Uint32 ALE_TBLW1;
    volatile Uint32 ALE_TBLW0;
    volatile Uint32 ALE_PORTCTL[3];
} CSL_Cpsw3gRegs;

/**************************************************************************\
* Field Definition Macros
\**************************************************************************/

/* P_MAX_BLKS */


#define CSL_CPSW3G_P_MAX_BLKS_P_TX_MAX_BLKS_MASK (0x000001F0u)
#define CSL_CPSW3G_P_MAX_BLKS_P_TX_MAX_BLKS_SHIFT (0x00000004u)
#define CSL_CPSW3G_P_MAX_BLKS_P_TX_MAX_BLKS_RESETVAL (0x00000011u)

#define CSL_CPSW3G_P_MAX_BLKS_P_RX_MAX_BLKS_MASK (0x0000000Fu)
#define CSL_CPSW3G_P_MAX_BLKS_P_RX_MAX_BLKS_SHIFT (0x00000000u)
#define CSL_CPSW3G_P_MAX_BLKS_P_RX_MAX_BLKS_RESETVAL (0x00000003u)

#define CSL_CPSW3G_P_MAX_BLKS_RESETVAL (0x00000113u)

/* P_BLK_CNT */


#define CSL_CPSW3G_P_BLK_CNT_P_TX_BLK_CNT_MASK (0x000001F0u)
#define CSL_CPSW3G_P_BLK_CNT_P_TX_BLK_CNT_SHIFT (0x00000004u)
#define CSL_CPSW3G_P_BLK_CNT_P_TX_BLK_CNT_RESETVAL (0x00000004u)

#define CSL_CPSW3G_P_BLK_CNT_P_RX_BLK_CNT_MASK (0x0000000Fu)
#define CSL_CPSW3G_P_BLK_CNT_P_RX_BLK_CNT_SHIFT (0x00000000u)
#define CSL_CPSW3G_P_BLK_CNT_P_RX_BLK_CNT_RESETVAL (0x00000001u)

#define CSL_CPSW3G_P_BLK_CNT_RESETVAL (0x00000041u)

/* P_FLOW_THRESH */


#define CSL_CPSW3G_P_FLOW_THRESH_P_P2TX_THRESH_MASK (0x00001F00u)
#define CSL_CPSW3G_P_FLOW_THRESH_P_P2TX_THRESH_SHIFT (0x00000008u)
#define CSL_CPSW3G_P_FLOW_THRESH_P_P2TX_THRESH_RESETVAL (0x0000000Bu)


#define CSL_CPSW3G_P_FLOW_THRESH_P_P1TX_THRESH_MASK (0x0000001Fu)
#define CSL_CPSW3G_P_FLOW_THRESH_P_P1TX_THRESH_SHIFT (0x00000000u)
#define CSL_CPSW3G_P_FLOW_THRESH_P_P1TX_THRESH_RESETVAL (0x0000000Bu)

#define CSL_CPSW3G_P_FLOW_THRESH_P_P0TX_THRESH_MASK (0x0000001Fu)
#define CSL_CPSW3G_P_FLOW_THRESH_P_P0TX_THRESH_SHIFT (0x00000000u)
#define CSL_CPSW3G_P_FLOW_THRESH_P_P0TX_THRESH_RESETVAL (0x0000000Bu)

#define CSL_CPSW3G_P_FLOW_THRESH_RESETVAL (0x00000B0Bu)

/* P_PORT_VLAN */


#define CSL_CPSW3G_P_PORT_VLAN_PORT_PRI_MASK (0x0000E000u)
#define CSL_CPSW3G_P_PORT_VLAN_PORT_PRI_SHIFT (0x0000000Du)
#define CSL_CPSW3G_P_PORT_VLAN_PORT_PRI_RESETVAL (0x00000000u)

#define CSL_CPSW3G_P_PORT_VLAN_PORT_CFI_MASK (0x00001000u)
#define CSL_CPSW3G_P_PORT_VLAN_PORT_CFI_SHIFT (0x0000000Cu)
#define CSL_CPSW3G_P_PORT_VLAN_PORT_CFI_RESETVAL (0x00000000u)

#define CSL_CPSW3G_P_PORT_VLAN_PORT_VID_MASK (0x00000FFFu)
#define CSL_CPSW3G_P_PORT_VLAN_PORT_VID_SHIFT (0x00000000u)
#define CSL_CPSW3G_P_PORT_VLAN_PORT_VID_RESETVAL (0x00000000u)

#define CSL_CPSW3G_P_PORT_VLAN_RESETVAL (0x00000000u)

/* P_Tx_Pri_Map */


#define CSL_CPSW3G_P_TX_PRI_MAP_PRI7_MASK (0x30000000u)
#define CSL_CPSW3G_P_TX_PRI_MAP_PRI7_SHIFT (0x0000001Cu)
#define CSL_CPSW3G_P_TX_PRI_MAP_PRI7_RESETVAL (0x00000003u)


#define CSL_CPSW3G_P_TX_PRI_MAP_PRI6_MASK (0x03000000u)
#define CSL_CPSW3G_P_TX_PRI_MAP_PRI6_SHIFT (0x00000018u)
#define CSL_CPSW3G_P_TX_PRI_MAP_PRI6_RESETVAL (0x00000003u)


#define CSL_CPSW3G_P_TX_PRI_MAP_PRI5_MASK (0x00300000u)
#define CSL_CPSW3G_P_TX_PRI_MAP_PRI5_SHIFT (0x00000014u)
#define CSL_CPSW3G_P_TX_PRI_MAP_PRI5_RESETVAL (0x00000002u)


#define CSL_CPSW3G_P_TX_PRI_MAP_PRI4_MASK (0x00030000u)
#define CSL_CPSW3G_P_TX_PRI_MAP_PRI4_SHIFT (0x00000010u)
#define CSL_CPSW3G_P_TX_PRI_MAP_PRI4_RESETVAL (0x00000002u)


#define CSL_CPSW3G_P_TX_PRI_MAP_PRI3_MASK (0x00003000u)
#define CSL_CPSW3G_P_TX_PRI_MAP_PRI3_SHIFT (0x0000000Cu)
#define CSL_CPSW3G_P_TX_PRI_MAP_PRI3_RESETVAL (0x00000001u)


#define CSL_CPSW3G_P_TX_PRI_MAP_PRI2_MASK (0x00000300u)
#define CSL_CPSW3G_P_TX_PRI_MAP_PRI2_SHIFT (0x00000008u)
#define CSL_CPSW3G_P_TX_PRI_MAP_PRI2_RESETVAL (0x00000000u)


#define CSL_CPSW3G_P_TX_PRI_MAP_PRI1_MASK (0x00000030u)
#define CSL_CPSW3G_P_TX_PRI_MAP_PRI1_SHIFT (0x00000004u)
#define CSL_CPSW3G_P_TX_PRI_MAP_PRI1_RESETVAL (0x00000000u)


#define CSL_CPSW3G_P_TX_PRI_MAP_PRI0_MASK (0x00000003u)
#define CSL_CPSW3G_P_TX_PRI_MAP_PRI0_SHIFT (0x00000000u)
#define CSL_CPSW3G_P_TX_PRI_MAP_PRI0_RESETVAL (0x00000001u)

#define CSL_CPSW3G_P_TX_PRI_MAP_RESETVAL (0x33221001u)

/* GMAC_Gap_Thresh */


#define CSL_CPSW3G_GMAC_GAP_THRESH_P_GAP_THRESH_MASK (0x0000001Fu)
#define CSL_CPSW3G_GMAC_GAP_THRESH_P_GAP_THRESH_SHIFT (0x00000000u)
#define CSL_CPSW3G_GMAC_GAP_THRESH_P_GAP_THRESH_RESETVAL (0x0000000Bu)

#define CSL_CPSW3G_GMAC_GAP_THRESH_RESETVAL (0x0000000Bu)

/* GMAC_SA_LO */


#define CSL_CPSW3G_GMAC_SA_LO_MACSRCADDR0_MASK (0x0000FF00u)
#define CSL_CPSW3G_GMAC_SA_LO_MACSRCADDR0_SHIFT (0x00000008u)
#define CSL_CPSW3G_GMAC_SA_LO_MACSRCADDR0_RESETVAL (0x00000000u)

#define CSL_CPSW3G_GMAC_SA_LO_MACSRCADDR1_MASK (0x000000FFu)
#define CSL_CPSW3G_GMAC_SA_LO_MACSRCADDR1_SHIFT (0x00000000u)
#define CSL_CPSW3G_GMAC_SA_LO_MACSRCADDR1_RESETVAL (0x00000000u)

#define CSL_CPSW3G_GMAC_SA_LO_RESETVAL (0x00000000u)

/* GMAC_SA_HI */

#define CSL_CPSW3G_GMAC_SA_HI_MACSRCADDR2_MASK (0xFF000000u)
#define CSL_CPSW3G_GMAC_SA_HI_MACSRCADDR2_SHIFT (0x00000018u)
#define CSL_CPSW3G_GMAC_SA_HI_MACSRCADDR2_RESETVAL (0x00000000u)

#define CSL_CPSW3G_GMAC_SA_HI_MACSRCADDR3_MASK (0x00FF0000u)
#define CSL_CPSW3G_GMAC_SA_HI_MACSRCADDR3_SHIFT (0x00000010u)
#define CSL_CPSW3G_GMAC_SA_HI_MACSRCADDR3_RESETVAL (0x00000000u)

#define CSL_CPSW3G_GMAC_SA_HI_MACSRCADDR4_MASK (0x0000FF00u)
#define CSL_CPSW3G_GMAC_SA_HI_MACSRCADDR4_SHIFT (0x00000008u)
#define CSL_CPSW3G_GMAC_SA_HI_MACSRCADDR4_RESETVAL (0x00000000u)

#define CSL_CPSW3G_GMAC_SA_HI_MACSRCADDR5_MASK (0x000000FFu)
#define CSL_CPSW3G_GMAC_SA_HI_MACSRCADDR5_SHIFT (0x00000000u)
#define CSL_CPSW3G_GMAC_SA_HI_MACSRCADDR5_RESETVAL (0x00000000u)

#define CSL_CPSW3G_GMAC_SA_HI_RESETVAL (0x00000000u)

/* GMAC_IDVER */

#define CSL_CPSW3G_GMAC_IDVER_RX_IDENT_MASK (0xFFFF0000u)
#define CSL_CPSW3G_GMAC_IDVER_RX_IDENT_SHIFT (0x00000010u)
#define CSL_CPSW3G_GMAC_IDVER_RX_IDENT_RESETVAL (0x00000017u)

#define CSL_CPSW3G_GMAC_IDVER_RX_Z_MASK (0x0000F800u)
#define CSL_CPSW3G_GMAC_IDVER_RX_Z_SHIFT (0x0000000Bu)
#define CSL_CPSW3G_GMAC_IDVER_RX_Z_RESETVAL (0x00000000u)

#define CSL_CPSW3G_GMAC_IDVER_RX_X_MASK (0x00000700u)
#define CSL_CPSW3G_GMAC_IDVER_RX_X_SHIFT (0x00000008u)
#define CSL_CPSW3G_GMAC_IDVER_RX_X_RESETVAL (0x00000001u)

#define CSL_CPSW3G_GMAC_IDVER_RX_Y_MASK (0x000000FFu)
#define CSL_CPSW3G_GMAC_IDVER_RX_Y_SHIFT (0x00000000u)
#define CSL_CPSW3G_GMAC_IDVER_RX_Y_RESETVAL (0x00000009u)

#define CSL_CPSW3G_GMAC_IDVER_RESETVAL (0x00170109u)

/* GMAC_MACCONTROL */


#define CSL_CPSW3G_GMAC_MACCONTROL_RX_CMF_EN_MASK (0x01000000u)
#define CSL_CPSW3G_GMAC_MACCONTROL_RX_CMF_EN_SHIFT (0x00000018u)
#define CSL_CPSW3G_GMAC_MACCONTROL_RX_CMF_EN_RESETVAL (0x00000000u)
/*----rx_cmf_en Tokens----*/
#define CSL_CPSW3G_GMAC_MACCONTROL_RX_CMF_EN_DISABLE (0x00000000u)
#define CSL_CPSW3G_GMAC_MACCONTROL_RX_CMF_EN_ENABLE (0x00000001u)

#define CSL_CPSW3G_GMAC_MACCONTROL_RX_CSF_EN_MASK (0x00800000u)
#define CSL_CPSW3G_GMAC_MACCONTROL_RX_CSF_EN_SHIFT (0x00000017u)
#define CSL_CPSW3G_GMAC_MACCONTROL_RX_CSF_EN_RESETVAL (0x00000000u)
/*----rx_csf_en Tokens----*/
#define CSL_CPSW3G_GMAC_MACCONTROL_RX_CSF_EN_DISABLE (0x00000000u)
#define CSL_CPSW3G_GMAC_MACCONTROL_RX_CSF_EN_ENABLE (0x00000001u)

#define CSL_CPSW3G_GMAC_MACCONTROL_RX_CEF_EN_MASK (0x00400000u)
#define CSL_CPSW3G_GMAC_MACCONTROL_RX_CEF_EN_SHIFT (0x00000016u)
#define CSL_CPSW3G_GMAC_MACCONTROL_RX_CEF_EN_RESETVAL (0x00000000u)
/*----rx_cef_en Tokens----*/
#define CSL_CPSW3G_GMAC_MACCONTROL_RX_CEF_EN_DISABLE (0x00000000u)
#define CSL_CPSW3G_GMAC_MACCONTROL_RX_CEF_EN_ENABLE (0x00000001u)


#define CSL_CPSW3G_GMAC_MACCONTROL_EXT_EN_MASK (0x00040000u)
#define CSL_CPSW3G_GMAC_MACCONTROL_EXT_EN_SHIFT (0x00000012u)
#define CSL_CPSW3G_GMAC_MACCONTROL_EXT_EN_RESETVAL (0x00000000u)

#define CSL_CPSW3G_GMAC_MACCONTROL_GIG_FORCE_MASK (0x00020000u)
#define CSL_CPSW3G_GMAC_MACCONTROL_GIG_FORCE_SHIFT (0x00000011u)
#define CSL_CPSW3G_GMAC_MACCONTROL_GIG_FORCE_RESETVAL (0x00000000u)

#define CSL_CPSW3G_GMAC_MACCONTROL_IFCTL_B_MASK (0x00010000u)
#define CSL_CPSW3G_GMAC_MACCONTROL_IFCTL_B_SHIFT (0x00000010u)
#define CSL_CPSW3G_GMAC_MACCONTROL_IFCTL_B_RESETVAL (0x00000000u)
/*----ifctl_b Tokens----*/
#define CSL_CPSW3G_GMAC_MACCONTROL_IFCTL_B_HALFDUPLEX (0x00000000u)
#define CSL_CPSW3G_GMAC_MACCONTROL_IFCTL_B_FULLDUPLEX (0x00000001u)

#define CSL_CPSW3G_GMAC_MACCONTROL_IFCTL_A_MASK (0x00008000u)
#define CSL_CPSW3G_GMAC_MACCONTROL_IFCTL_A_SHIFT (0x0000000Fu)
#define CSL_CPSW3G_GMAC_MACCONTROL_IFCTL_A_RESETVAL (0x00000000u)
/*----ifctl_a Tokens----*/
#define CSL_CPSW3G_GMAC_MACCONTROL_IFCTL_A_2_5MHZ (0x00000000u)
#define CSL_CPSW3G_GMAC_MACCONTROL_IFCTL_A_25MHZ (0x00000001u)


#define CSL_CPSW3G_GMAC_MACCONTROL_CMD_IDLE_MASK (0x00000800u)
#define CSL_CPSW3G_GMAC_MACCONTROL_CMD_IDLE_SHIFT (0x0000000Bu)
#define CSL_CPSW3G_GMAC_MACCONTROL_CMD_IDLE_RESETVAL (0x00000000u)
/*----CMD_IDLE Tokens----*/
#define CSL_CPSW3G_GMAC_MACCONTROL_CMD_IDLE_DISABLE (0x00000000u)
#define CSL_CPSW3G_GMAC_MACCONTROL_CMD_IDLE_ENABLE (0x00000001u)

#define CSL_CPSW3G_GMAC_MACCONTROL_TX_SHORT_GAP_EN_MASK (0x00000400u)
#define CSL_CPSW3G_GMAC_MACCONTROL_TX_SHORT_GAP_EN_SHIFT (0x0000000Au)
#define CSL_CPSW3G_GMAC_MACCONTROL_TX_SHORT_GAP_EN_RESETVAL (0x00000000u)
/*----TX_SHORT_GAP_EN Tokens----*/
#define CSL_CPSW3G_GMAC_MACCONTROL_TX_SHORT_GAP_EN_DISABLE (0x00000000u)
#define CSL_CPSW3G_GMAC_MACCONTROL_TX_SHORT_GAP_EN_ENABLE (0x00000001u)


#define CSL_CPSW3G_GMAC_MACCONTROL_GIG_MASK (0x00000080u)
#define CSL_CPSW3G_GMAC_MACCONTROL_GIG_SHIFT (0x00000007u)
#define CSL_CPSW3G_GMAC_MACCONTROL_GIG_RESETVAL (0x00000000u)
/*----GIG Tokens----*/
#define CSL_CPSW3G_GMAC_MACCONTROL_GIG_DISABLE (0x00000000u)
#define CSL_CPSW3G_GMAC_MACCONTROL_GIG_ENABLE (0x00000001u)

#define CSL_CPSW3G_GMAC_MACCONTROL_TX_PACE_MASK (0x00000040u)
#define CSL_CPSW3G_GMAC_MACCONTROL_TX_PACE_SHIFT (0x00000006u)
#define CSL_CPSW3G_GMAC_MACCONTROL_TX_PACE_RESETVAL (0x00000000u)
/*----TX_PACE Tokens----*/
#define CSL_CPSW3G_GMAC_MACCONTROL_TX_PACE_DISABLE (0x00000000u)
#define CSL_CPSW3G_GMAC_MACCONTROL_TX_PACE_ENABLE (0x00000001u)

#define CSL_CPSW3G_GMAC_MACCONTROL_GMII_EN_MASK (0x00000020u)
#define CSL_CPSW3G_GMAC_MACCONTROL_GMII_EN_SHIFT (0x00000005u)
#define CSL_CPSW3G_GMAC_MACCONTROL_GMII_EN_RESETVAL (0x00000000u)
/*----GMII_EN Tokens----*/
#define CSL_CPSW3G_GMAC_MACCONTROL_GMII_EN_DISABLE (0x00000000u)
#define CSL_CPSW3G_GMAC_MACCONTROL_GMII_EN_ENABLE (0x00000001u)

#define CSL_CPSW3G_GMAC_MACCONTROL_TX_FLOW_EN_MASK (0x00000010u)
#define CSL_CPSW3G_GMAC_MACCONTROL_TX_FLOW_EN_SHIFT (0x00000004u)
#define CSL_CPSW3G_GMAC_MACCONTROL_TX_FLOW_EN_RESETVAL (0x00000000u)
/*----TX_FLOW_EN Tokens----*/
#define CSL_CPSW3G_GMAC_MACCONTROL_TX_FLOW_EN_DISABLE (0x00000000u)
#define CSL_CPSW3G_GMAC_MACCONTROL_TX_FLOW_EN_ENABLE (0x00000001u)

#define CSL_CPSW3G_GMAC_MACCONTROL_RX_FLOW_EN_MASK (0x00000008u)
#define CSL_CPSW3G_GMAC_MACCONTROL_RX_FLOW_EN_SHIFT (0x00000003u)
#define CSL_CPSW3G_GMAC_MACCONTROL_RX_FLOW_EN_RESETVAL (0x00000000u)
/*----RX_FLOW_EN Tokens----*/
#define CSL_CPSW3G_GMAC_MACCONTROL_RX_FLOW_EN_DISABLE (0x00000000u)
#define CSL_CPSW3G_GMAC_MACCONTROL_RX_FLOW_EN_ENABLE (0x00000001u)

#define CSL_CPSW3G_GMAC_MACCONTROL_MTEST_MASK (0x00000004u)
#define CSL_CPSW3G_GMAC_MACCONTROL_MTEST_SHIFT (0x00000002u)
#define CSL_CPSW3G_GMAC_MACCONTROL_MTEST_RESETVAL (0x00000000u)

#define CSL_CPSW3G_GMAC_MACCONTROL_LOOPBACK_MASK (0x00000002u)
#define CSL_CPSW3G_GMAC_MACCONTROL_LOOPBACK_SHIFT (0x00000001u)
#define CSL_CPSW3G_GMAC_MACCONTROL_LOOPBACK_RESETVAL (0x00000000u)
/*----LOOPBACK Tokens----*/
#define CSL_CPSW3G_GMAC_MACCONTROL_LOOPBACK_DISABLE (0x00000000u)
#define CSL_CPSW3G_GMAC_MACCONTROL_LOOPBACK_ENABLE (0x00000001u)

#define CSL_CPSW3G_GMAC_MACCONTROL_FULLDUPLEX_MASK (0x00000001u)
#define CSL_CPSW3G_GMAC_MACCONTROL_FULLDUPLEX_SHIFT (0x00000000u)
#define CSL_CPSW3G_GMAC_MACCONTROL_FULLDUPLEX_RESETVAL (0x00000000u)
/*----FULLDUPLEX Tokens----*/
#define CSL_CPSW3G_GMAC_MACCONTROL_FULLDUPLEX_DISABLE (0x00000000u)
#define CSL_CPSW3G_GMAC_MACCONTROL_FULLDUPLEX_ENABLE (0x00000001u)

#define CSL_CPSW3G_GMAC_MACCONTROL_RESETVAL (0x00000000u)

/* GMAC_MACSTATUS */

#define CSL_CPSW3G_GMAC_MACSTATUS_IDLE_MASK (0x80000000u)
#define CSL_CPSW3G_GMAC_MACSTATUS_IDLE_SHIFT (0x0000001Fu)
#define CSL_CPSW3G_GMAC_MACSTATUS_IDLE_RESETVAL (0x00000001u)
/*----IDLE Tokens----*/
#define CSL_CPSW3G_GMAC_MACSTATUS_IDLE_NOIDLE (0x00000000u)
#define CSL_CPSW3G_GMAC_MACSTATUS_IDLE_IDLE (0x00000001u)


#define CSL_CPSW3G_GMAC_MACSTATUS_EXT_GIG_MASK (0x00000010u)
#define CSL_CPSW3G_GMAC_MACSTATUS_EXT_GIG_SHIFT (0x00000004u)
#define CSL_CPSW3G_GMAC_MACSTATUS_EXT_GIG_RESETVAL (0x00000000u)

#define CSL_CPSW3G_GMAC_MACSTATUS_EXT_FULLDUPLEX_MASK (0x00000008u)
#define CSL_CPSW3G_GMAC_MACSTATUS_EXT_FULLDUPLEX_SHIFT (0x00000003u)
#define CSL_CPSW3G_GMAC_MACSTATUS_EXT_FULLDUPLEX_RESETVAL (0x00000000u)


#define CSL_CPSW3G_GMAC_MACSTATUS_RX_FLOW_ACT_MASK (0x00000002u)
#define CSL_CPSW3G_GMAC_MACSTATUS_RX_FLOW_ACT_SHIFT (0x00000001u)
#define CSL_CPSW3G_GMAC_MACSTATUS_RX_FLOW_ACT_RESETVAL (0x00000000u)
/*----RX_FLOW_ACT Tokens----*/
#define CSL_CPSW3G_GMAC_MACSTATUS_RX_FLOW_ACT_INACTIVE (0x00000000u)
#define CSL_CPSW3G_GMAC_MACSTATUS_RX_FLOW_ACT_ACTIVE (0x00000001u)

#define CSL_CPSW3G_GMAC_MACSTATUS_TX_FLOW_ACT_MASK (0x00000001u)
#define CSL_CPSW3G_GMAC_MACSTATUS_TX_FLOW_ACT_SHIFT (0x00000000u)
#define CSL_CPSW3G_GMAC_MACSTATUS_TX_FLOW_ACT_RESETVAL (0x00000000u)
/*----TX_FLOW_ACT Tokens----*/
#define CSL_CPSW3G_GMAC_MACSTATUS_TX_FLOW_ACT_INACTIVE (0x00000000u)
#define CSL_CPSW3G_GMAC_MACSTATUS_TX_FLOW_ACT_ACTIVE (0x00000001u)

#define CSL_CPSW3G_GMAC_MACSTATUS_RESETVAL (0x80000000u)

/* GMAC_SOFT_RESET */


#define CSL_CPSW3G_GMAC_SOFT_RESET_SOFT_RESET_MASK (0x00000001u)
#define CSL_CPSW3G_GMAC_SOFT_RESET_SOFT_RESET_SHIFT (0x00000000u)
#define CSL_CPSW3G_GMAC_SOFT_RESET_SOFT_RESET_RESETVAL (0x00000000u)
#define CSL_CPSW3G_GMAC_SOFT_RESET_SOFT_RESET_NORESET (0x00000000u)
#define CSL_CPSW3G_GMAC_SOFT_RESET_SOFT_RESET_RESET (0x00000001u)

#define CSL_CPSW3G_GMAC_SOFT_RESET_RESETVAL (0x00000000u)

/* GMAC_RX_MAXLEN */


#define CSL_CPSW3G_GMAC_RX_MAXLEN_RX_MAXLEN_MASK (0x000007FFu)
#define CSL_CPSW3G_GMAC_RX_MAXLEN_RX_MAXLEN_SHIFT (0x00000000u)
#define CSL_CPSW3G_GMAC_RX_MAXLEN_RX_MAXLEN_RESETVAL (0x000005EEu)

#define CSL_CPSW3G_GMAC_RX_MAXLEN_RESETVAL (0x000005EEu)

/* GMAC_BOFFTEST */


#define CSL_CPSW3G_GMAC_BOFFTEST_PACEVAL_MASK (0x7C000000u)
#define CSL_CPSW3G_GMAC_BOFFTEST_PACEVAL_SHIFT (0x0000001Au)
#define CSL_CPSW3G_GMAC_BOFFTEST_PACEVAL_RESETVAL (0x00000000u)

#define CSL_CPSW3G_GMAC_BOFFTEST_RNDNUM_MASK (0x03FF0000u)
#define CSL_CPSW3G_GMAC_BOFFTEST_RNDNUM_SHIFT (0x00000010u)
#define CSL_CPSW3G_GMAC_BOFFTEST_RNDNUM_RESETVAL (0x00000000u)

#define CSL_CPSW3G_GMAC_BOFFTEST_COLL_COUNT_MASK (0x0000F000u)
#define CSL_CPSW3G_GMAC_BOFFTEST_COLL_COUNT_SHIFT (0x0000000Cu)
#define CSL_CPSW3G_GMAC_BOFFTEST_COLL_COUNT_RESETVAL (0x00000000u)


#define CSL_CPSW3G_GMAC_BOFFTEST_TX_BACKOFF_MASK (0x000003FFu)
#define CSL_CPSW3G_GMAC_BOFFTEST_TX_BACKOFF_SHIFT (0x00000000u)
#define CSL_CPSW3G_GMAC_BOFFTEST_TX_BACKOFF_RESETVAL (0x00000000u)

#define CSL_CPSW3G_GMAC_BOFFTEST_RESETVAL (0x00000000u)

/* GMAC_EMCONTROL */


#define CSL_CPSW3G_GMAC_EMCONTROL_SOFT_MASK (0x00000002u)
#define CSL_CPSW3G_GMAC_EMCONTROL_SOFT_SHIFT (0x00000001u)
#define CSL_CPSW3G_GMAC_EMCONTROL_SOFT_RESETVAL (0x00000000u)

#define CSL_CPSW3G_GMAC_EMCONTROL_FREE_MASK (0x00000001u)
#define CSL_CPSW3G_GMAC_EMCONTROL_FREE_SHIFT (0x00000000u)
#define CSL_CPSW3G_GMAC_EMCONTROL_FREE_RESETVAL (0x00000000u)

#define CSL_CPSW3G_GMAC_EMCONTROL_RESETVAL (0x00000000u)

/* GMAC_Rx_Pri_Map */


#define CSL_CPSW3G_GMAC_RX_PRI_MAP_PRI7_MASK (0x70000000u)
#define CSL_CPSW3G_GMAC_RX_PRI_MAP_PRI7_SHIFT (0x0000001Cu)
#define CSL_CPSW3G_GMAC_RX_PRI_MAP_PRI7_RESETVAL (0x00000007u)


#define CSL_CPSW3G_GMAC_RX_PRI_MAP_PRI6_MASK (0x07000000u)
#define CSL_CPSW3G_GMAC_RX_PRI_MAP_PRI6_SHIFT (0x00000018u)
#define CSL_CPSW3G_GMAC_RX_PRI_MAP_PRI6_RESETVAL (0x00000006u)


#define CSL_CPSW3G_GMAC_RX_PRI_MAP_PRI5_MASK (0x00700000u)
#define CSL_CPSW3G_GMAC_RX_PRI_MAP_PRI5_SHIFT (0x00000014u)
#define CSL_CPSW3G_GMAC_RX_PRI_MAP_PRI5_RESETVAL (0x00000005u)


#define CSL_CPSW3G_GMAC_RX_PRI_MAP_PRI4_MASK (0x00070000u)
#define CSL_CPSW3G_GMAC_RX_PRI_MAP_PRI4_SHIFT (0x00000010u)
#define CSL_CPSW3G_GMAC_RX_PRI_MAP_PRI4_RESETVAL (0x00000004u)


#define CSL_CPSW3G_GMAC_RX_PRI_MAP_PRI3_MASK (0x00007000u)
#define CSL_CPSW3G_GMAC_RX_PRI_MAP_PRI3_SHIFT (0x0000000Cu)
#define CSL_CPSW3G_GMAC_RX_PRI_MAP_PRI3_RESETVAL (0x00000003u)


#define CSL_CPSW3G_GMAC_RX_PRI_MAP_PRI2_MASK (0x00000700u)
#define CSL_CPSW3G_GMAC_RX_PRI_MAP_PRI2_SHIFT (0x00000008u)
#define CSL_CPSW3G_GMAC_RX_PRI_MAP_PRI2_RESETVAL (0x00000002u)


#define CSL_CPSW3G_GMAC_RX_PRI_MAP_PRI1_MASK (0x00000070u)
#define CSL_CPSW3G_GMAC_RX_PRI_MAP_PRI1_SHIFT (0x00000004u)
#define CSL_CPSW3G_GMAC_RX_PRI_MAP_PRI1_RESETVAL (0x00000001u)


#define CSL_CPSW3G_GMAC_RX_PRI_MAP_PRI0_MASK (0x00000007u)
#define CSL_CPSW3G_GMAC_RX_PRI_MAP_PRI0_SHIFT (0x00000000u)
#define CSL_CPSW3G_GMAC_RX_PRI_MAP_PRI0_RESETVAL (0x00000000u)

#define CSL_CPSW3G_GMAC_RX_PRI_MAP_RESETVAL (0x76543210u)

/* CPSW_ID_VER */

#define CSL_CPSW3G_CPSW_ID_VER_CPSW_3G_IDENT_MASK (0xFFFF0000u)
#define CSL_CPSW3G_CPSW_ID_VER_CPSW_3G_IDENT_SHIFT (0x00000010u)
#define CSL_CPSW3G_CPSW_ID_VER_CPSW_3G_IDENT_RESETVAL (0x00000019u)

#define CSL_CPSW3G_CPSW_ID_VER_CPSW_3G_RTL_VER_MASK (0x0000F800u)
#define CSL_CPSW3G_CPSW_ID_VER_CPSW_3G_RTL_VER_SHIFT (0x0000000Bu)
#define CSL_CPSW3G_CPSW_ID_VER_CPSW_3G_RTL_VER_RESETVAL (0x00000000u)

#define CSL_CPSW3G_CPSW_ID_VER_CPSW_3G_MAJ_VER_MASK (0x00000700u)
#define CSL_CPSW3G_CPSW_ID_VER_CPSW_3G_MAJ_VER_SHIFT (0x00000008u)
#define CSL_CPSW3G_CPSW_ID_VER_CPSW_3G_MAJ_VER_RESETVAL (0x00000001u)

#define CSL_CPSW3G_CPSW_ID_VER_CPSW_3G_MINOR_VER_MASK (0x000000FFu)
#define CSL_CPSW3G_CPSW_ID_VER_CPSW_3G_MINOR_VER_SHIFT (0x00000000u)
#define CSL_CPSW3G_CPSW_ID_VER_CPSW_3G_MINOR_VER_RESETVAL (0x00000002u)

#define CSL_CPSW3G_CPSW_ID_VER_RESETVAL (0x00190102u)

/* CPSW_CONTROL */


#define CSL_CPSW3G_CPSW_CONTROL_P2_PASS_PRI_TAGGED_MASK (0x00001000u)
#define CSL_CPSW3G_CPSW_CONTROL_P2_PASS_PRI_TAGGED_SHIFT (0x0000000Cu)
#define CSL_CPSW3G_CPSW_CONTROL_P2_PASS_PRI_TAGGED_RESETVAL (0x00000000u)
/*----P2_PASS_PRI_TAGGED Tokens----*/
#define CSL_CPSW3G_CPSW_CONTROL_P2_PASS_PRI_TAGGED_DISABLE (0x00000000u)
#define CSL_CPSW3G_CPSW_CONTROL_P2_PASS_PRI_TAGGED_ENABLE (0x00000001u)

#define CSL_CPSW3G_CPSW_CONTROL_P1_PASS_PRI_TAGGED_MASK (0x00000800u)
#define CSL_CPSW3G_CPSW_CONTROL_P1_PASS_PRI_TAGGED_SHIFT (0x0000000Bu)
#define CSL_CPSW3G_CPSW_CONTROL_P1_PASS_PRI_TAGGED_RESETVAL (0x00000000u)
/*----P1_PASS_PRI_TAGGED Tokens----*/
#define CSL_CPSW3G_CPSW_CONTROL_P1_PASS_PRI_TAGGED_DISABLE (0x00000000u)
#define CSL_CPSW3G_CPSW_CONTROL_P1_PASS_PRI_TAGGED_ENABLE (0x00000001u)

#define CSL_CPSW3G_CPSW_CONTROL_P0_PASS_PRI_TAGGED_MASK (0x00000400u)
#define CSL_CPSW3G_CPSW_CONTROL_P0_PASS_PRI_TAGGED_SHIFT (0x0000000Au)
#define CSL_CPSW3G_CPSW_CONTROL_P0_PASS_PRI_TAGGED_RESETVAL (0x00000000u)
/*----P0_PASS_PRI_TAGGED Tokens----*/
#define CSL_CPSW3G_CPSW_CONTROL_P0_PASS_PRI_TAGGED_DISABLE (0x00000000u)
#define CSL_CPSW3G_CPSW_CONTROL_P0_PASS_PRI_TAGGED_ENABLE (0x00000001u)

#define CSL_CPSW3G_CPSW_CONTROL_VLAN_AWARE_MASK (0x00000200u)
#define CSL_CPSW3G_CPSW_CONTROL_VLAN_AWARE_SHIFT (0x00000009u)
#define CSL_CPSW3G_CPSW_CONTROL_VLAN_AWARE_RESETVAL (0x00000000u)
/*----VLAN_AWARE Tokens----*/
#define CSL_CPSW3G_CPSW_CONTROL_VLAN_AWARE_DISABLE (0x00000000u)
#define CSL_CPSW3G_CPSW_CONTROL_VLAN_AWARE_ENABLE (0x00000001u)

#define CSL_CPSW3G_CPSW_CONTROL_RX_VLAN_ENCAP_MASK (0x00000100u)
#define CSL_CPSW3G_CPSW_CONTROL_RX_VLAN_ENCAP_SHIFT (0x00000008u)
#define CSL_CPSW3G_CPSW_CONTROL_RX_VLAN_ENCAP_RESETVAL (0x00000000u)
/*----RX_VLAN_ENCAP Tokens----*/
#define CSL_CPSW3G_CPSW_CONTROL_RX_VLAN_ENCAP_DISABLE (0x00000000u)
#define CSL_CPSW3G_CPSW_CONTROL_RX_VLAN_ENCAP_ENABLE (0x00000001u)

#define CSL_CPSW3G_CPSW_CONTROL_P2_P2RX_FLOW_EN_MASK (0x00000080u)
#define CSL_CPSW3G_CPSW_CONTROL_P2_P2RX_FLOW_EN_SHIFT (0x00000007u)
#define CSL_CPSW3G_CPSW_CONTROL_P2_P2RX_FLOW_EN_RESETVAL (0x00000001u)
/*----P2_P2RX_FLOW_EN Tokens----*/
#define CSL_CPSW3G_CPSW_CONTROL_P2_P2RX_FLOW_EN_DISABLE (0x00000000u)
#define CSL_CPSW3G_CPSW_CONTROL_P2_P2RX_FLOW_EN_ENABLE (0x00000001u)

#define CSL_CPSW3G_CPSW_CONTROL_P2_P1TX_FLOW_EN_MASK (0x00000040u)
#define CSL_CPSW3G_CPSW_CONTROL_P2_P1TX_FLOW_EN_SHIFT (0x00000006u)
#define CSL_CPSW3G_CPSW_CONTROL_P2_P1TX_FLOW_EN_RESETVAL (0x00000001u)
/*----P2_P1TX_FLOW_EN Tokens----*/
#define CSL_CPSW3G_CPSW_CONTROL_P2_P1TX_FLOW_EN_DISABLE (0x00000000u)
#define CSL_CPSW3G_CPSW_CONTROL_P2_P1TX_FLOW_EN_ENABLE (0x00000001u)

#define CSL_CPSW3G_CPSW_CONTROL_P2_P0TX_FLOW_EN_MASK (0x00000020u)
#define CSL_CPSW3G_CPSW_CONTROL_P2_P0TX_FLOW_EN_SHIFT (0x00000005u)
#define CSL_CPSW3G_CPSW_CONTROL_P2_P0TX_FLOW_EN_RESETVAL (0x00000001u)
/*----P2_P0TX_FLOW_EN Tokens----*/
#define CSL_CPSW3G_CPSW_CONTROL_P2_P0TX_FLOW_EN_DISABLE (0x00000000u)
#define CSL_CPSW3G_CPSW_CONTROL_P2_P0TX_FLOW_EN_ENABLE (0x00000001u)

#define CSL_CPSW3G_CPSW_CONTROL_P1_P2TX_FLOW_EN_MASK (0x00000010u)
#define CSL_CPSW3G_CPSW_CONTROL_P1_P2TX_FLOW_EN_SHIFT (0x00000004u)
#define CSL_CPSW3G_CPSW_CONTROL_P1_P2TX_FLOW_EN_RESETVAL (0x00000000u)
/*----P1_P2TX_FLOW_EN Tokens----*/
#define CSL_CPSW3G_CPSW_CONTROL_P1_P2TX_FLOW_EN_DISABLE (0x00000000u)
#define CSL_CPSW3G_CPSW_CONTROL_P1_P2TX_FLOW_EN_ENABLE (0x00000001u)

#define CSL_CPSW3G_CPSW_CONTROL_P1_P0TX_FLOW_EN_MASK (0x00000008u)
#define CSL_CPSW3G_CPSW_CONTROL_P1_P0TX_FLOW_EN_SHIFT (0x00000003u)
#define CSL_CPSW3G_CPSW_CONTROL_P1_P0TX_FLOW_EN_RESETVAL (0x00000000u)
/*----P1_P0TX_FLOW_EN Tokens----*/
#define CSL_CPSW3G_CPSW_CONTROL_P1_P0TX_FLOW_EN_DISABLE (0x00000000u)
#define CSL_CPSW3G_CPSW_CONTROL_P1_P0TX_FLOW_EN_ENABLE (0x00000001u)

#define CSL_CPSW3G_CPSW_CONTROL_P0_P2TX_FLOW_EN_MASK (0x00000004u)
#define CSL_CPSW3G_CPSW_CONTROL_P0_P2TX_FLOW_EN_SHIFT (0x00000002u)
#define CSL_CPSW3G_CPSW_CONTROL_P0_P2TX_FLOW_EN_RESETVAL (0x00000000u)
/*----P0_P2TX_FLOW_EN Tokens----*/
#define CSL_CPSW3G_CPSW_CONTROL_P0_P2TX_FLOW_EN_DISABLE (0x00000000u)
#define CSL_CPSW3G_CPSW_CONTROL_P0_P2TX_FLOW_EN_ENABLE (0x00000001u)

#define CSL_CPSW3G_CPSW_CONTROL_P0_P1TX_FLOW_EN_MASK (0x00000002u)
#define CSL_CPSW3G_CPSW_CONTROL_P0_P1TX_FLOW_EN_SHIFT (0x00000001u)
#define CSL_CPSW3G_CPSW_CONTROL_P0_P1TX_FLOW_EN_RESETVAL (0x00000000u)
/*----P0_P1TX_FLOW_EN Tokens----*/
#define CSL_CPSW3G_CPSW_CONTROL_P0_P1TX_FLOW_EN_DISABLE (0x00000000u)
#define CSL_CPSW3G_CPSW_CONTROL_P0_P1TX_FLOW_EN_ENABLE (0x00000001u)

#define CSL_CPSW3G_CPSW_CONTROL_FIFO_LOOPBACK_MASK (0x00000001u)
#define CSL_CPSW3G_CPSW_CONTROL_FIFO_LOOPBACK_SHIFT (0x00000000u)
#define CSL_CPSW3G_CPSW_CONTROL_FIFO_LOOPBACK_RESETVAL (0x00000000u)
/*----FIFO_LOOPBACK Tokens----*/
#define CSL_CPSW3G_CPSW_CONTROL_FIFO_LOOPBACK_DISABLE (0x00000000u)
#define CSL_CPSW3G_CPSW_CONTROL_FIFO_LOOPBACK_ENABLE (0x00000001u)

#define CSL_CPSW3G_CPSW_CONTROL_RESETVAL (0x000000E0u)

/* CPSW_SOFT_RESET */


#define CSL_CPSW3G_CPSW_SOFT_RESET_SOFT_RESET_MASK (0x00000001u)
#define CSL_CPSW3G_CPSW_SOFT_RESET_SOFT_RESET_SHIFT (0x00000000u)
#define CSL_CPSW3G_CPSW_SOFT_RESET_SOFT_RESET_RESETVAL (0x00000000u)
#define CSL_CPSW3G_CPSW_SOFT_RESET_SOFT_RESET_NORESET (0x00000000u)
#define CSL_CPSW3G_CPSW_SOFT_RESET_SOFT_RESET_RESET (0x00000001u)

#define CSL_CPSW3G_CPSW_SOFT_RESET_RESETVAL (0x00000000u)

/* CPSW_STAT_PORT_EN */


#define CSL_CPSW3G_CPSW_STAT_PORT_EN_P2_STAT_EN_MASK (0x00000004u)
#define CSL_CPSW3G_CPSW_STAT_PORT_EN_P2_STAT_EN_SHIFT (0x00000002u)
#define CSL_CPSW3G_CPSW_STAT_PORT_EN_P2_STAT_EN_RESETVAL (0x00000000u)
/*----p2_stat_en Tokens----*/
#define CSL_CPSW3G_CPSW_STAT_PORT_EN_P2_STAT_EN_DISABLE (0x00000000u)
#define CSL_CPSW3G_CPSW_STAT_PORT_EN_P2_STAT_EN_ENABLE (0x00000001u)

#define CSL_CPSW3G_CPSW_STAT_PORT_EN_P1_STAT_EN_MASK (0x00000002u)
#define CSL_CPSW3G_CPSW_STAT_PORT_EN_P1_STAT_EN_SHIFT (0x00000001u)
#define CSL_CPSW3G_CPSW_STAT_PORT_EN_P1_STAT_EN_RESETVAL (0x00000000u)
/*----p1_stat_en Tokens----*/
#define CSL_CPSW3G_CPSW_STAT_PORT_EN_P1_STAT_EN_DISABLE (0x00000000u)
#define CSL_CPSW3G_CPSW_STAT_PORT_EN_P1_STAT_EN_ENABLE (0x00000001u)

#define CSL_CPSW3G_CPSW_STAT_PORT_EN_P0_STAT_EN_MASK (0x00000001u)
#define CSL_CPSW3G_CPSW_STAT_PORT_EN_P0_STAT_EN_SHIFT (0x00000000u)
#define CSL_CPSW3G_CPSW_STAT_PORT_EN_P0_STAT_EN_RESETVAL (0x00000000u)
/*----p0_stat_en Tokens----*/
#define CSL_CPSW3G_CPSW_STAT_PORT_EN_P0_STAT_EN_DISABLE (0x00000000u)
#define CSL_CPSW3G_CPSW_STAT_PORT_EN_P0_STAT_EN_ENABLE (0x00000001u)

#define CSL_CPSW3G_CPSW_STAT_PORT_EN_RESETVAL (0x00000000u)

/* CPSW_PTYPE */


#define CSL_CPSW3G_CPSW_PTYPE_P2_PTYPE_ESC_MASK (0x00000400u)
#define CSL_CPSW3G_CPSW_PTYPE_P2_PTYPE_ESC_SHIFT (0x0000000Au)
#define CSL_CPSW3G_CPSW_PTYPE_P2_PTYPE_ESC_RESETVAL (0x00000000u)
/*----p2_ptype_esc Tokens----*/
#define CSL_CPSW3G_CPSW_PTYPE_P2_PTYPE_ESC_FIXED (0x00000000u)
#define CSL_CPSW3G_CPSW_PTYPE_P2_PTYPE_ESC_ESCALATE (0x00000001u)

#define CSL_CPSW3G_CPSW_PTYPE_P1_PTYPE_ESC_MASK (0x00000200u)
#define CSL_CPSW3G_CPSW_PTYPE_P1_PTYPE_ESC_SHIFT (0x00000009u)
#define CSL_CPSW3G_CPSW_PTYPE_P1_PTYPE_ESC_RESETVAL (0x00000000u)
/*----p1_ptype_esc Tokens----*/
#define CSL_CPSW3G_CPSW_PTYPE_P1_PTYPE_ESC_FIXED (0x00000000u)
#define CSL_CPSW3G_CPSW_PTYPE_P1_PTYPE_ESC_ESCALATE (0x00000001u)

#define CSL_CPSW3G_CPSW_PTYPE_P0_PTYPE_ESC_MASK (0x00000100u)
#define CSL_CPSW3G_CPSW_PTYPE_P0_PTYPE_ESC_SHIFT (0x00000008u)
#define CSL_CPSW3G_CPSW_PTYPE_P0_PTYPE_ESC_RESETVAL (0x00000000u)
/*----p0_ptype_esc Tokens----*/
#define CSL_CPSW3G_CPSW_PTYPE_P0_PTYPE_ESC_FIXED (0x00000000u)
#define CSL_CPSW3G_CPSW_PTYPE_P0_PTYPE_ESC_ESCALATE (0x00000001u)


#define CSL_CPSW3G_CPSW_PTYPE_ESC_PRI_LD_VAL_MASK (0x0000001Fu)
#define CSL_CPSW3G_CPSW_PTYPE_ESC_PRI_LD_VAL_SHIFT (0x00000000u)
#define CSL_CPSW3G_CPSW_PTYPE_ESC_PRI_LD_VAL_RESETVAL (0x00000000u)

#define CSL_CPSW3G_CPSW_PTYPE_RESETVAL (0x00000000u)

/* P2_MAX_BLKS */


#define CSL_CPSW3G_P2_MAX_BLKS_P2_TX_MAX_BLKS_MASK (0x000001F0u)
#define CSL_CPSW3G_P2_MAX_BLKS_P2_TX_MAX_BLKS_SHIFT (0x00000004u)
#define CSL_CPSW3G_P2_MAX_BLKS_P2_TX_MAX_BLKS_RESETVAL (0x00000010u)

#define CSL_CPSW3G_P2_MAX_BLKS_P2_RX_MAX_BLKS_MASK (0x0000000Fu)
#define CSL_CPSW3G_P2_MAX_BLKS_P2_RX_MAX_BLKS_SHIFT (0x00000000u)
#define CSL_CPSW3G_P2_MAX_BLKS_P2_RX_MAX_BLKS_RESETVAL (0x00000004u)

#define CSL_CPSW3G_P2_MAX_BLKS_RESETVAL (0x00000104u)

/* P2_BLK_CNT */


#define CSL_CPSW3G_P2_BLK_CNT_P2_TX_BLK_CNT_MASK (0x000001F0u)
#define CSL_CPSW3G_P2_BLK_CNT_P2_TX_BLK_CNT_SHIFT (0x00000004u)
#define CSL_CPSW3G_P2_BLK_CNT_P2_TX_BLK_CNT_RESETVAL (0x00000004u)

#define CSL_CPSW3G_P2_BLK_CNT_P2_RX_BLK_CNT_MASK (0x0000000Fu)
#define CSL_CPSW3G_P2_BLK_CNT_P2_RX_BLK_CNT_SHIFT (0x00000000u)
#define CSL_CPSW3G_P2_BLK_CNT_P2_RX_BLK_CNT_RESETVAL (0x00000001u)

#define CSL_CPSW3G_P2_BLK_CNT_RESETVAL (0x00000041u)

/* P2_FLOW_THRESH */


#define CSL_CPSW3G_P2_FLOW_THRESH_P2_P2RX_THRESH_MASK (0x000F0000u)
#define CSL_CPSW3G_P2_FLOW_THRESH_P2_P2RX_THRESH_SHIFT (0x00000010u)
#define CSL_CPSW3G_P2_FLOW_THRESH_P2_P2RX_THRESH_RESETVAL (0x00000003u)


#define CSL_CPSW3G_P2_FLOW_THRESH_P2_P1TX_THRESH_MASK (0x00001F00u)
#define CSL_CPSW3G_P2_FLOW_THRESH_P2_P1TX_THRESH_SHIFT (0x00000008u)
#define CSL_CPSW3G_P2_FLOW_THRESH_P2_P1TX_THRESH_RESETVAL (0x00000010u)


#define CSL_CPSW3G_P2_FLOW_THRESH_P2_P0TX_THRESH_MASK (0x0000001Fu)
#define CSL_CPSW3G_P2_FLOW_THRESH_P2_P0TX_THRESH_SHIFT (0x00000000u)
#define CSL_CPSW3G_P2_FLOW_THRESH_P2_P0TX_THRESH_RESETVAL (0x00000010u)

#define CSL_CPSW3G_P2_FLOW_THRESH_RESETVAL (0x00031010u)

/* P2_PORT_VLAN */


#define CSL_CPSW3G_P2_PORT_VLAN_PORT_PRI_MASK (0x0000E000u)
#define CSL_CPSW3G_P2_PORT_VLAN_PORT_PRI_SHIFT (0x0000000Du)
#define CSL_CPSW3G_P2_PORT_VLAN_PORT_PRI_RESETVAL (0x00000000u)

#define CSL_CPSW3G_P2_PORT_VLAN_PORT_CFI_MASK (0x00001000u)
#define CSL_CPSW3G_P2_PORT_VLAN_PORT_CFI_SHIFT (0x0000000Cu)
#define CSL_CPSW3G_P2_PORT_VLAN_PORT_CFI_RESETVAL (0x00000000u)

#define CSL_CPSW3G_P2_PORT_VLAN_PORT_VID_MASK (0x00000FFFu)
#define CSL_CPSW3G_P2_PORT_VLAN_PORT_VID_SHIFT (0x00000000u)
#define CSL_CPSW3G_P2_PORT_VLAN_PORT_VID_RESETVAL (0x00000000u)

#define CSL_CPSW3G_P2_PORT_VLAN_RESETVAL (0x00000000u)

/* P2_Tx_Pri_Map */


#define CSL_CPSW3G_P2_TX_PRI_MAP_PRI7_MASK (0x30000000u)
#define CSL_CPSW3G_P2_TX_PRI_MAP_PRI7_SHIFT (0x0000001Cu)
#define CSL_CPSW3G_P2_TX_PRI_MAP_PRI7_RESETVAL (0x00000003u)


#define CSL_CPSW3G_P2_TX_PRI_MAP_PRI6_MASK (0x03000000u)
#define CSL_CPSW3G_P2_TX_PRI_MAP_PRI6_SHIFT (0x00000018u)
#define CSL_CPSW3G_P2_TX_PRI_MAP_PRI6_RESETVAL (0x00000003u)


#define CSL_CPSW3G_P2_TX_PRI_MAP_PRI5_MASK (0x00300000u)
#define CSL_CPSW3G_P2_TX_PRI_MAP_PRI5_SHIFT (0x00000014u)
#define CSL_CPSW3G_P2_TX_PRI_MAP_PRI5_RESETVAL (0x00000002u)


#define CSL_CPSW3G_P2_TX_PRI_MAP_PRI4_MASK (0x00030000u)
#define CSL_CPSW3G_P2_TX_PRI_MAP_PRI4_SHIFT (0x00000010u)
#define CSL_CPSW3G_P2_TX_PRI_MAP_PRI4_RESETVAL (0x00000002u)


#define CSL_CPSW3G_P2_TX_PRI_MAP_PRI3_MASK (0x00003000u)
#define CSL_CPSW3G_P2_TX_PRI_MAP_PRI3_SHIFT (0x0000000Cu)
#define CSL_CPSW3G_P2_TX_PRI_MAP_PRI3_RESETVAL (0x00000001u)


#define CSL_CPSW3G_P2_TX_PRI_MAP_PRI2_MASK (0x00000300u)
#define CSL_CPSW3G_P2_TX_PRI_MAP_PRI2_SHIFT (0x00000008u)
#define CSL_CPSW3G_P2_TX_PRI_MAP_PRI2_RESETVAL (0x00000000u)


#define CSL_CPSW3G_P2_TX_PRI_MAP_PRI1_MASK (0x00000030u)
#define CSL_CPSW3G_P2_TX_PRI_MAP_PRI1_SHIFT (0x00000004u)
#define CSL_CPSW3G_P2_TX_PRI_MAP_PRI1_RESETVAL (0x00000000u)


#define CSL_CPSW3G_P2_TX_PRI_MAP_PRI0_MASK (0x00000003u)
#define CSL_CPSW3G_P2_TX_PRI_MAP_PRI0_SHIFT (0x00000000u)
#define CSL_CPSW3G_P2_TX_PRI_MAP_PRI0_RESETVAL (0x00000001u)

#define CSL_CPSW3G_P2_TX_PRI_MAP_RESETVAL (0x33221001u)

/* CPDMA_Tx_Pri_Map */


#define CSL_CPSW3G_CPDMA_TX_PRI_MAP_PRI7_MASK (0x70000000u)
#define CSL_CPSW3G_CPDMA_TX_PRI_MAP_PRI7_SHIFT (0x0000001Cu)
#define CSL_CPSW3G_CPDMA_TX_PRI_MAP_PRI7_RESETVAL (0x00000007u)


#define CSL_CPSW3G_CPDMA_TX_PRI_MAP_PRI6_MASK (0x07000000u)
#define CSL_CPSW3G_CPDMA_TX_PRI_MAP_PRI6_SHIFT (0x00000018u)
#define CSL_CPSW3G_CPDMA_TX_PRI_MAP_PRI6_RESETVAL (0x00000006u)


#define CSL_CPSW3G_CPDMA_TX_PRI_MAP_PRI5_MASK (0x00700000u)
#define CSL_CPSW3G_CPDMA_TX_PRI_MAP_PRI5_SHIFT (0x00000014u)
#define CSL_CPSW3G_CPDMA_TX_PRI_MAP_PRI5_RESETVAL (0x00000005u)


#define CSL_CPSW3G_CPDMA_TX_PRI_MAP_PRI4_MASK (0x00070000u)
#define CSL_CPSW3G_CPDMA_TX_PRI_MAP_PRI4_SHIFT (0x00000010u)
#define CSL_CPSW3G_CPDMA_TX_PRI_MAP_PRI4_RESETVAL (0x00000004u)


#define CSL_CPSW3G_CPDMA_TX_PRI_MAP_PRI3_MASK (0x00007000u)
#define CSL_CPSW3G_CPDMA_TX_PRI_MAP_PRI3_SHIFT (0x0000000Cu)
#define CSL_CPSW3G_CPDMA_TX_PRI_MAP_PRI3_RESETVAL (0x00000003u)


#define CSL_CPSW3G_CPDMA_TX_PRI_MAP_PRI2_MASK (0x00000700u)
#define CSL_CPSW3G_CPDMA_TX_PRI_MAP_PRI2_SHIFT (0x00000008u)
#define CSL_CPSW3G_CPDMA_TX_PRI_MAP_PRI2_RESETVAL (0x00000002u)


#define CSL_CPSW3G_CPDMA_TX_PRI_MAP_PRI1_MASK (0x00000070u)
#define CSL_CPSW3G_CPDMA_TX_PRI_MAP_PRI1_SHIFT (0x00000004u)
#define CSL_CPSW3G_CPDMA_TX_PRI_MAP_PRI1_RESETVAL (0x00000001u)


#define CSL_CPSW3G_CPDMA_TX_PRI_MAP_PRI0_MASK (0x00000007u)
#define CSL_CPSW3G_CPDMA_TX_PRI_MAP_PRI0_SHIFT (0x00000000u)
#define CSL_CPSW3G_CPDMA_TX_PRI_MAP_PRI0_RESETVAL (0x00000000u)

#define CSL_CPSW3G_CPDMA_TX_PRI_MAP_RESETVAL (0x76543210u)

/* CPDMA_Rx_Ch_Map */


#define CSL_CPSW3G_CPDMA_RX_CH_MAP_SU_CH3_MASK (0x70000000u)
#define CSL_CPSW3G_CPDMA_RX_CH_MAP_SU_CH3_SHIFT (0x0000001Cu)
#define CSL_CPSW3G_CPDMA_RX_CH_MAP_SU_CH3_RESETVAL (0x00000000u)


#define CSL_CPSW3G_CPDMA_RX_CH_MAP_SU_CH2_MASK (0x07000000u)
#define CSL_CPSW3G_CPDMA_RX_CH_MAP_SU_CH2_SHIFT (0x00000018u)
#define CSL_CPSW3G_CPDMA_RX_CH_MAP_SU_CH2_RESETVAL (0x00000000u)


#define CSL_CPSW3G_CPDMA_RX_CH_MAP_SU_CH1_MASK (0x00700000u)
#define CSL_CPSW3G_CPDMA_RX_CH_MAP_SU_CH1_SHIFT (0x00000014u)
#define CSL_CPSW3G_CPDMA_RX_CH_MAP_SU_CH1_RESETVAL (0x00000000u)


#define CSL_CPSW3G_CPDMA_RX_CH_MAP_SU_CH0_MASK (0x00070000u)
#define CSL_CPSW3G_CPDMA_RX_CH_MAP_SU_CH0_SHIFT (0x00000010u)
#define CSL_CPSW3G_CPDMA_RX_CH_MAP_SU_CH0_RESETVAL (0x00000000u)


#define CSL_CPSW3G_CPDMA_RX_CH_MAP_CH3_MASK (0x00007000u)
#define CSL_CPSW3G_CPDMA_RX_CH_MAP_CH3_SHIFT (0x0000000Cu)
#define CSL_CPSW3G_CPDMA_RX_CH_MAP_CH3_RESETVAL (0x00000000u)


#define CSL_CPSW3G_CPDMA_RX_CH_MAP_CH2_MASK (0x00000700u)
#define CSL_CPSW3G_CPDMA_RX_CH_MAP_CH2_SHIFT (0x00000008u)
#define CSL_CPSW3G_CPDMA_RX_CH_MAP_CH2_RESETVAL (0x00000000u)


#define CSL_CPSW3G_CPDMA_RX_CH_MAP_CH1_MASK (0x00000070u)
#define CSL_CPSW3G_CPDMA_RX_CH_MAP_CH1_SHIFT (0x00000004u)
#define CSL_CPSW3G_CPDMA_RX_CH_MAP_CH1_RESETVAL (0x00000000u)


#define CSL_CPSW3G_CPDMA_RX_CH_MAP_CH0_MASK (0x00000007u)
#define CSL_CPSW3G_CPDMA_RX_CH_MAP_CH0_SHIFT (0x00000000u)
#define CSL_CPSW3G_CPDMA_RX_CH_MAP_CH0_RESETVAL (0x00000000u)

#define CSL_CPSW3G_CPDMA_RX_CH_MAP_RESETVAL (0x00000000u)

/* TX_IDVER */

#define CSL_CPSW3G_TX_IDVER_TX_IDENT_MASK (0xFFFF0000u)
#define CSL_CPSW3G_TX_IDVER_TX_IDENT_SHIFT (0x00000010u)
#define CSL_CPSW3G_TX_IDVER_TX_IDENT_RESETVAL (0x0000000Cu)

#define CSL_CPSW3G_TX_IDVER_TX_MAJOR_VER_MASK (0x0000FF00u)
#define CSL_CPSW3G_TX_IDVER_TX_MAJOR_VER_SHIFT (0x00000008u)
#define CSL_CPSW3G_TX_IDVER_TX_MAJOR_VER_RESETVAL (0x00000001u)

#define CSL_CPSW3G_TX_IDVER_TX_MINOR_VER_MASK (0x000000FFu)
#define CSL_CPSW3G_TX_IDVER_TX_MINOR_VER_SHIFT (0x00000000u)
#define CSL_CPSW3G_TX_IDVER_TX_MINOR_VER_RESETVAL (0x00000006u)

#define CSL_CPSW3G_TX_IDVER_RESETVAL (0x000C0106u)

/* TX_CONTROL */


#define CSL_CPSW3G_TX_CONTROL_TX_EN_MASK (0x00000001u)
#define CSL_CPSW3G_TX_CONTROL_TX_EN_SHIFT (0x00000000u)
#define CSL_CPSW3G_TX_CONTROL_TX_EN_RESETVAL (0x00000000u)
/*----TX_EN Tokens----*/
#define CSL_CPSW3G_TX_CONTROL_TX_EN_DISABLE (0x00000000u)
#define CSL_CPSW3G_TX_CONTROL_TX_EN_ENABLE (0x00000001u)

#define CSL_CPSW3G_TX_CONTROL_RESETVAL (0x00000000u)

/* TX_TEARDOWN */

#define CSL_CPSW3G_TX_TEARDOWN_TX_TDN_RDY_MASK (0x80000000u)
#define CSL_CPSW3G_TX_TEARDOWN_TX_TDN_RDY_SHIFT (0x0000001Fu)
#define CSL_CPSW3G_TX_TEARDOWN_TX_TDN_RDY_RESETVAL (0x00000000u)


#define CSL_CPSW3G_TX_TEARDOWN_TX_TDN_CH_MASK (0x00000007u)
#define CSL_CPSW3G_TX_TEARDOWN_TX_TDN_CH_SHIFT (0x00000000u)
#define CSL_CPSW3G_TX_TEARDOWN_TX_TDN_CH_RESETVAL (0x00000000u)
#define CSL_CPSW3G_TX_TEARDOWN_TX_TDN_CH_CHA0 (0x00000000u)
#define CSL_CPSW3G_TX_TEARDOWN_TX_TDN_CH_CHA1 (0x00000001u)
#define CSL_CPSW3G_TX_TEARDOWN_TX_TDN_CH_CHA2 (0x00000002u)
#define CSL_CPSW3G_TX_TEARDOWN_TX_TDN_CH_CHA3 (0x00000003u)
#define CSL_CPSW3G_TX_TEARDOWN_TX_TDN_CH_CHA4 (0x00000004u)
#define CSL_CPSW3G_TX_TEARDOWN_TX_TDN_CH_CHA5 (0x00000005u)
#define CSL_CPSW3G_TX_TEARDOWN_TX_TDN_CH_CHA6 (0x00000006u)
#define CSL_CPSW3G_TX_TEARDOWN_TX_TDN_CH_CHA7 (0x00000007u)

#define CSL_CPSW3G_TX_TEARDOWN_RESETVAL (0x00000000u)

/* RX_IDVER */

#define CSL_CPSW3G_RX_IDVER_RX_IDENT_MASK (0xFFFF0000u)
#define CSL_CPSW3G_RX_IDVER_RX_IDENT_SHIFT (0x00000010u)
#define CSL_CPSW3G_RX_IDVER_RX_IDENT_RESETVAL (0x0000000Cu)

#define CSL_CPSW3G_RX_IDVER_RX_MAJOR_VER_MASK (0x0000FF00u)
#define CSL_CPSW3G_RX_IDVER_RX_MAJOR_VER_SHIFT (0x00000008u)
#define CSL_CPSW3G_RX_IDVER_RX_MAJOR_VER_RESETVAL (0x00000001u)

#define CSL_CPSW3G_RX_IDVER_RX_MINOR_VER_MASK (0x000000FFu)
#define CSL_CPSW3G_RX_IDVER_RX_MINOR_VER_SHIFT (0x00000000u)
#define CSL_CPSW3G_RX_IDVER_RX_MINOR_VER_RESETVAL (0x00000006u)

#define CSL_CPSW3G_RX_IDVER_RESETVAL (0x000C0106u)

/* RX_CONTROL */


#define CSL_CPSW3G_RX_CONTROL_RX_EN_MASK (0x00000001u)
#define CSL_CPSW3G_RX_CONTROL_RX_EN_SHIFT (0x00000000u)
#define CSL_CPSW3G_RX_CONTROL_RX_EN_RESETVAL (0x00000000u)
/*----RX_EN Tokens----*/
#define CSL_CPSW3G_RX_CONTROL_RX_EN_DISABLE (0x00000000u)
#define CSL_CPSW3G_RX_CONTROL_RX_EN_ENABLE (0x00000001u)

#define CSL_CPSW3G_RX_CONTROL_RESETVAL (0x00000000u)

/* RX_TEARDOWN */

#define CSL_CPSW3G_RX_TEARDOWN_RX_TDN_RDY_MASK (0x80000000u)
#define CSL_CPSW3G_RX_TEARDOWN_RX_TDN_RDY_SHIFT (0x0000001Fu)
#define CSL_CPSW3G_RX_TEARDOWN_RX_TDN_RDY_RESETVAL (0x00000000u)


#define CSL_CPSW3G_RX_TEARDOWN_RX_TDN_CH_MASK (0x00000007u)
#define CSL_CPSW3G_RX_TEARDOWN_RX_TDN_CH_SHIFT (0x00000000u)
#define CSL_CPSW3G_RX_TEARDOWN_RX_TDN_CH_RESETVAL (0x00000000u)
#define CSL_CPSW3G_RX_TEARDOWN_RX_TDN_CH_CHA0 (0x00000000u)
#define CSL_CPSW3G_RX_TEARDOWN_RX_TDN_CH_CHA1 (0x00000001u)
#define CSL_CPSW3G_RX_TEARDOWN_RX_TDN_CH_CHA2 (0x00000002u)
#define CSL_CPSW3G_RX_TEARDOWN_RX_TDN_CH_CHA3 (0x00000003u)
#define CSL_CPSW3G_RX_TEARDOWN_RX_TDN_CH_CHA4 (0x00000004u)
#define CSL_CPSW3G_RX_TEARDOWN_RX_TDN_CH_CHA5 (0x00000005u)
#define CSL_CPSW3G_RX_TEARDOWN_RX_TDN_CH_CHA6 (0x00000006u)
#define CSL_CPSW3G_RX_TEARDOWN_RX_TDN_CH_CHA7 (0x00000007u)

#define CSL_CPSW3G_RX_TEARDOWN_RESETVAL (0x00000000u)

/* SOFT_RESET */


#define CSL_CPSW3G_SOFT_RESET_SOFT_RESET_MASK (0x00000001u)
#define CSL_CPSW3G_SOFT_RESET_SOFT_RESET_SHIFT (0x00000000u)
#define CSL_CPSW3G_SOFT_RESET_SOFT_RESET_RESETVAL (0x00000000u)
#define CSL_CPSW3G_SOFT_RESET_SOFT_RESET_NORESET (0x00000000u)
#define CSL_CPSW3G_SOFT_RESET_SOFT_RESET_RESET (0x00000001u)

#define CSL_CPSW3G_SOFT_RESET_RESETVAL (0x00000000u)

/* DMACONTROL */


#define CSL_CPSW3G_DMACONTROL_RX_CEF_MASK (0x00000010u)
#define CSL_CPSW3G_DMACONTROL_RX_CEF_SHIFT (0x00000004u)
#define CSL_CPSW3G_DMACONTROL_RX_CEF_RESETVAL (0x00000000u)
/*----RX_CEF Tokens----*/
#define CSL_CPSW3G_DMACONTROL_RX_CEF_DISABLE (0x00000000u)
#define CSL_CPSW3G_DMACONTROL_RX_CEF_ENABLE (0x00000001u)

#define CSL_CPSW3G_DMACONTROL_CMD_IDLE_MASK (0x00000008u)
#define CSL_CPSW3G_DMACONTROL_CMD_IDLE_SHIFT (0x00000003u)
#define CSL_CPSW3G_DMACONTROL_CMD_IDLE_RESETVAL (0x00000000u)
/*----CMD_IDLE Tokens----*/
#define CSL_CPSW3G_DMACONTROL_CMD_IDLE_DISABLE (0x00000000u)
#define CSL_CPSW3G_DMACONTROL_CMD_IDLE_ENABLE (0x00000001u)

#define CSL_CPSW3G_DMACONTROL_RX_OFFLEN_BLOCK_MASK (0x00000004u)
#define CSL_CPSW3G_DMACONTROL_RX_OFFLEN_BLOCK_SHIFT (0x00000002u)
#define CSL_CPSW3G_DMACONTROL_RX_OFFLEN_BLOCK_RESETVAL (0x00000000u)
/*----RX_OFFLEN_BLOCK Tokens----*/
#define CSL_CPSW3G_DMACONTROL_RX_OFFLEN_BLOCK_NOBLOCK (0x00000000u)
#define CSL_CPSW3G_DMACONTROL_RX_OFFLEN_BLOCK_BLOCK (0x00000001u)

#define CSL_CPSW3G_DMACONTROL_RX_OWNERSHIP_MASK (0x00000002u)
#define CSL_CPSW3G_DMACONTROL_RX_OWNERSHIP_SHIFT (0x00000001u)
#define CSL_CPSW3G_DMACONTROL_RX_OWNERSHIP_RESETVAL (0x00000000u)
/*----RX_OWNERSHIP Tokens----*/
#define CSL_CPSW3G_DMACONTROL_RX_OWNERSHIP_ZERO (0x00000000u)
#define CSL_CPSW3G_DMACONTROL_RX_OWNERSHIP_ONE (0x00000001u)

#define CSL_CPSW3G_DMACONTROL_TX_PTYPE_MASK (0x00000001u)
#define CSL_CPSW3G_DMACONTROL_TX_PTYPE_SHIFT (0x00000000u)
#define CSL_CPSW3G_DMACONTROL_TX_PTYPE_RESETVAL (0x00000000u)
/*----TX_PTYPE Tokens----*/
#define CSL_CPSW3G_DMACONTROL_TX_PTYPE_RROBIN (0x00000000u)
#define CSL_CPSW3G_DMACONTROL_TX_PTYPE_CHANNELPRI (0x00000001u)

#define CSL_CPSW3G_DMACONTROL_RESETVAL (0x00000000u)

/* DMASTATUS */

#define CSL_CPSW3G_DMASTATUS_IDLE_MASK (0x80000000u)
#define CSL_CPSW3G_DMASTATUS_IDLE_SHIFT (0x0000001Fu)
#define CSL_CPSW3G_DMASTATUS_IDLE_RESETVAL (0x00000000u)
/*----IDLE Tokens----*/
#define CSL_CPSW3G_DMASTATUS_IDLE_NOIDLE (0x00000000u)
#define CSL_CPSW3G_DMASTATUS_IDLE_IDLE (0x00000001u)


#define CSL_CPSW3G_DMASTATUS_TX_HOST_ERR_CODE_MASK (0x00F00000u)
#define CSL_CPSW3G_DMASTATUS_TX_HOST_ERR_CODE_SHIFT (0x00000014u)
#define CSL_CPSW3G_DMASTATUS_TX_HOST_ERR_CODE_RESETVAL (0x00000000u)
#define CSL_CPSW3G_DMASTATUS_TX_HOST_ERR_CODE_NOERROR (0x00000000u)
#define CSL_CPSW3G_DMASTATUS_TX_HOST_ERR_CODE_SOPERROR (0x00000001u)
#define CSL_CPSW3G_DMASTATUS_TX_HOST_ERR_CODE_OWNERSHIP (0x00000002u)
#define CSL_CPSW3G_DMASTATUS_TX_HOST_ERR_CODE_NOEOP (0x00000003u)
#define CSL_CPSW3G_DMASTATUS_TX_HOST_ERR_CODE_NULLPTR (0x00000004u)
#define CSL_CPSW3G_DMASTATUS_TX_HOST_ERR_CODE_NULLEN (0x00000005u)
#define CSL_CPSW3G_DMASTATUS_TX_HOST_ERR_CODE_LENRRROR (0x00000006u)


#define CSL_CPSW3G_DMASTATUS_TX_ERR_CH_MASK (0x00070000u)
#define CSL_CPSW3G_DMASTATUS_TX_ERR_CH_SHIFT (0x00000010u)
#define CSL_CPSW3G_DMASTATUS_TX_ERR_CH_RESETVAL (0x00000000u)
#define CSL_CPSW3G_DMASTATUS_TX_ERR_CH_CHA0 (0x00000000u)
#define CSL_CPSW3G_DMASTATUS_TX_ERR_CH_CHA1 (0x00000001u)
#define CSL_CPSW3G_DMASTATUS_TX_ERR_CH_CHA2 (0x00000002u)
#define CSL_CPSW3G_DMASTATUS_TX_ERR_CH_CHA3 (0x00000003u)
#define CSL_CPSW3G_DMASTATUS_TX_ERR_CH_CHA4 (0x00000004u)
#define CSL_CPSW3G_DMASTATUS_TX_ERR_CH_CHA5 (0x00000005u)
#define CSL_CPSW3G_DMASTATUS_TX_ERR_CH_CHA6 (0x00000006u)
#define CSL_CPSW3G_DMASTATUS_TX_ERR_CH_CHA7 (0x00000007u)

#define CSL_CPSW3G_DMASTATUS_RX_HOST_ERR_CODE_MASK (0x0000F000u)
#define CSL_CPSW3G_DMASTATUS_RX_HOST_ERR_CODE_SHIFT (0x0000000Cu)
#define CSL_CPSW3G_DMASTATUS_RX_HOST_ERR_CODE_RESETVAL (0x00000000u)
#define CSL_CPSW3G_DMASTATUS_RX_HOST_ERR_CODE_NOERROR (0x00000000u)
#define CSL_CPSW3G_DMASTATUS_RX_HOST_ERR_CODE_OWNERSHIP (0x00000002u)
#define CSL_CPSW3G_DMASTATUS_RX_HOST_ERR_CODE_NULLPTR (0x00000004u)
#define CSL_CPSW3G_DMASTATUS_RX_HOST_ERR_CODE_NULLEN (0x00000005u)
#define CSL_CPSW3G_DMASTATUS_RX_HOST_ERR_CODE_SOPERROR (0x00000006u)


#define CSL_CPSW3G_DMASTATUS_RX_ERR_CH_MASK (0x00000700u)
#define CSL_CPSW3G_DMASTATUS_RX_ERR_CH_SHIFT (0x00000008u)
#define CSL_CPSW3G_DMASTATUS_RX_ERR_CH_RESETVAL (0x00000000u)
#define CSL_CPSW3G_DMASTATUS_RX_ERR_CH_CHA0 (0x00000000u)
#define CSL_CPSW3G_DMASTATUS_RX_ERR_CH_CHA1 (0x00000001u)
#define CSL_CPSW3G_DMASTATUS_RX_ERR_CH_CHA2 (0x00000002u)
#define CSL_CPSW3G_DMASTATUS_RX_ERR_CH_CHA3 (0x00000003u)
#define CSL_CPSW3G_DMASTATUS_RX_ERR_CH_CHA4 (0x00000004u)
#define CSL_CPSW3G_DMASTATUS_RX_ERR_CH_CHA5 (0x00000005u)
#define CSL_CPSW3G_DMASTATUS_RX_ERR_CH_CHA6 (0x00000006u)
#define CSL_CPSW3G_DMASTATUS_RX_ERR_CH_CHA7 (0x00000007u)


#define CSL_CPSW3G_DMASTATUS_RESETVAL (0x00000000u)

/* Rx_Buffer_Offset */


#define CSL_CPSW3G_RX_BUFFER_OFFSET_RX_BUFFER_OFFSET_MASK (0x0000FFFFu)
#define CSL_CPSW3G_RX_BUFFER_OFFSET_RX_BUFFER_OFFSET_SHIFT (0x00000000u)
#define CSL_CPSW3G_RX_BUFFER_OFFSET_RX_BUFFER_OFFSET_RESETVAL (0x00000000u)

#define CSL_CPSW3G_RX_BUFFER_OFFSET_RESETVAL (0x00000000u)

/* EMCONTROL */


#define CSL_CPSW3G_EMCONTROL_SOFT_MASK (0x00000002u)
#define CSL_CPSW3G_EMCONTROL_SOFT_SHIFT (0x00000001u)
#define CSL_CPSW3G_EMCONTROL_SOFT_RESETVAL (0x00000000u)

#define CSL_CPSW3G_EMCONTROL_FREE_MASK (0x00000001u)
#define CSL_CPSW3G_EMCONTROL_FREE_SHIFT (0x00000000u)
#define CSL_CPSW3G_EMCONTROL_FREE_RESETVAL (0x00000000u)

#define CSL_CPSW3G_EMCONTROL_RESETVAL (0x00000000u)

/* TX_INTSTAT_RAW */


#define CSL_CPSW3G_TX_INTSTAT_RAW_TX7_PEND_MASK (0x00000080u)
#define CSL_CPSW3G_TX_INTSTAT_RAW_TX7_PEND_SHIFT (0x00000007u)
#define CSL_CPSW3G_TX_INTSTAT_RAW_TX7_PEND_RESETVAL (0x00000000u)

#define CSL_CPSW3G_TX_INTSTAT_RAW_TX6_PEND_MASK (0x00000040u)
#define CSL_CPSW3G_TX_INTSTAT_RAW_TX6_PEND_SHIFT (0x00000006u)
#define CSL_CPSW3G_TX_INTSTAT_RAW_TX6_PEND_RESETVAL (0x00000000u)

#define CSL_CPSW3G_TX_INTSTAT_RAW_TX5_PEND_MASK (0x00000020u)
#define CSL_CPSW3G_TX_INTSTAT_RAW_TX5_PEND_SHIFT (0x00000005u)
#define CSL_CPSW3G_TX_INTSTAT_RAW_TX5_PEND_RESETVAL (0x00000000u)

#define CSL_CPSW3G_TX_INTSTAT_RAW_TX4_PEND_MASK (0x00000010u)
#define CSL_CPSW3G_TX_INTSTAT_RAW_TX4_PEND_SHIFT (0x00000004u)
#define CSL_CPSW3G_TX_INTSTAT_RAW_TX4_PEND_RESETVAL (0x00000000u)

#define CSL_CPSW3G_TX_INTSTAT_RAW_TX3_PEND_MASK (0x00000008u)
#define CSL_CPSW3G_TX_INTSTAT_RAW_TX3_PEND_SHIFT (0x00000003u)
#define CSL_CPSW3G_TX_INTSTAT_RAW_TX3_PEND_RESETVAL (0x00000000u)

#define CSL_CPSW3G_TX_INTSTAT_RAW_TX2_PEND_MASK (0x00000004u)
#define CSL_CPSW3G_TX_INTSTAT_RAW_TX2_PEND_SHIFT (0x00000002u)
#define CSL_CPSW3G_TX_INTSTAT_RAW_TX2_PEND_RESETVAL (0x00000000u)

#define CSL_CPSW3G_TX_INTSTAT_RAW_TX1_PEND_MASK (0x00000002u)
#define CSL_CPSW3G_TX_INTSTAT_RAW_TX1_PEND_SHIFT (0x00000001u)
#define CSL_CPSW3G_TX_INTSTAT_RAW_TX1_PEND_RESETVAL (0x00000000u)

#define CSL_CPSW3G_TX_INTSTAT_RAW_TX0_PEND_MASK (0x00000001u)
#define CSL_CPSW3G_TX_INTSTAT_RAW_TX0_PEND_SHIFT (0x00000000u)
#define CSL_CPSW3G_TX_INTSTAT_RAW_TX0_PEND_RESETVAL (0x00000000u)

#define CSL_CPSW3G_TX_INTSTAT_RAW_RESETVAL (0x00000000u)

/* TX_INTSTAT_MASKED */


#define CSL_CPSW3G_TX_INTSTAT_MASKED_TX7_PEND_MASK (0x00000080u)
#define CSL_CPSW3G_TX_INTSTAT_MASKED_TX7_PEND_SHIFT (0x00000007u)
#define CSL_CPSW3G_TX_INTSTAT_MASKED_TX7_PEND_RESETVAL (0x00000000u)

#define CSL_CPSW3G_TX_INTSTAT_MASKED_TX6_PEND_MASK (0x00000040u)
#define CSL_CPSW3G_TX_INTSTAT_MASKED_TX6_PEND_SHIFT (0x00000006u)
#define CSL_CPSW3G_TX_INTSTAT_MASKED_TX6_PEND_RESETVAL (0x00000000u)

#define CSL_CPSW3G_TX_INTSTAT_MASKED_TX5_PEND_MASK (0x00000020u)
#define CSL_CPSW3G_TX_INTSTAT_MASKED_TX5_PEND_SHIFT (0x00000005u)
#define CSL_CPSW3G_TX_INTSTAT_MASKED_TX5_PEND_RESETVAL (0x00000000u)

#define CSL_CPSW3G_TX_INTSTAT_MASKED_TX4_PEND_MASK (0x00000010u)
#define CSL_CPSW3G_TX_INTSTAT_MASKED_TX4_PEND_SHIFT (0x00000004u)
#define CSL_CPSW3G_TX_INTSTAT_MASKED_TX4_PEND_RESETVAL (0x00000000u)

#define CSL_CPSW3G_TX_INTSTAT_MASKED_TX3_PEND_MASK (0x00000008u)
#define CSL_CPSW3G_TX_INTSTAT_MASKED_TX3_PEND_SHIFT (0x00000003u)
#define CSL_CPSW3G_TX_INTSTAT_MASKED_TX3_PEND_RESETVAL (0x00000000u)

#define CSL_CPSW3G_TX_INTSTAT_MASKED_TX2_PEND_MASK (0x00000004u)
#define CSL_CPSW3G_TX_INTSTAT_MASKED_TX2_PEND_SHIFT (0x00000002u)
#define CSL_CPSW3G_TX_INTSTAT_MASKED_TX2_PEND_RESETVAL (0x00000000u)

#define CSL_CPSW3G_TX_INTSTAT_MASKED_TX1_PEND_MASK (0x00000002u)
#define CSL_CPSW3G_TX_INTSTAT_MASKED_TX1_PEND_SHIFT (0x00000001u)
#define CSL_CPSW3G_TX_INTSTAT_MASKED_TX1_PEND_RESETVAL (0x00000000u)

#define CSL_CPSW3G_TX_INTSTAT_MASKED_TX0_PEND_MASK (0x00000001u)
#define CSL_CPSW3G_TX_INTSTAT_MASKED_TX0_PEND_SHIFT (0x00000000u)
#define CSL_CPSW3G_TX_INTSTAT_MASKED_TX0_PEND_RESETVAL (0x00000000u)

#define CSL_CPSW3G_TX_INTSTAT_MASKED_RESETVAL (0x00000000u)

/* TX_INTMASK_SET */


#define CSL_CPSW3G_TX_INTMASK_SET_TX7_MASK_MASK (0x00000080u)
#define CSL_CPSW3G_TX_INTMASK_SET_TX7_MASK_SHIFT (0x00000007u)
#define CSL_CPSW3G_TX_INTMASK_SET_TX7_MASK_RESETVAL (0x00000000u)

#define CSL_CPSW3G_TX_INTMASK_SET_TX6_MASK_MASK (0x00000040u)
#define CSL_CPSW3G_TX_INTMASK_SET_TX6_MASK_SHIFT (0x00000006u)
#define CSL_CPSW3G_TX_INTMASK_SET_TX6_MASK_RESETVAL (0x00000000u)

#define CSL_CPSW3G_TX_INTMASK_SET_TX5_MASK_MASK (0x00000020u)
#define CSL_CPSW3G_TX_INTMASK_SET_TX5_MASK_SHIFT (0x00000005u)
#define CSL_CPSW3G_TX_INTMASK_SET_TX5_MASK_RESETVAL (0x00000000u)

#define CSL_CPSW3G_TX_INTMASK_SET_TX4_MASK_MASK (0x00000010u)
#define CSL_CPSW3G_TX_INTMASK_SET_TX4_MASK_SHIFT (0x00000004u)
#define CSL_CPSW3G_TX_INTMASK_SET_TX4_MASK_RESETVAL (0x00000000u)

#define CSL_CPSW3G_TX_INTMASK_SET_TX3_MASK_MASK (0x00000008u)
#define CSL_CPSW3G_TX_INTMASK_SET_TX3_MASK_SHIFT (0x00000003u)
#define CSL_CPSW3G_TX_INTMASK_SET_TX3_MASK_RESETVAL (0x00000000u)

#define CSL_CPSW3G_TX_INTMASK_SET_TX2_MASK_MASK (0x00000004u)
#define CSL_CPSW3G_TX_INTMASK_SET_TX2_MASK_SHIFT (0x00000002u)
#define CSL_CPSW3G_TX_INTMASK_SET_TX2_MASK_RESETVAL (0x00000000u)

#define CSL_CPSW3G_TX_INTMASK_SET_TX1_MASK_MASK (0x00000002u)
#define CSL_CPSW3G_TX_INTMASK_SET_TX1_MASK_SHIFT (0x00000001u)
#define CSL_CPSW3G_TX_INTMASK_SET_TX1_MASK_RESETVAL (0x00000000u)

#define CSL_CPSW3G_TX_INTMASK_SET_TX0_MASK_MASK (0x00000001u)
#define CSL_CPSW3G_TX_INTMASK_SET_TX0_MASK_SHIFT (0x00000000u)
#define CSL_CPSW3G_TX_INTMASK_SET_TX0_MASK_RESETVAL (0x00000000u)

#define CSL_CPSW3G_TX_INTMASK_SET_RESETVAL (0x00000000u)

/* TX_INTMASK_CLEAR */


#define CSL_CPSW3G_TX_INTMASK_CLEAR_TX7_MASK_MASK (0x00000080u)
#define CSL_CPSW3G_TX_INTMASK_CLEAR_TX7_MASK_SHIFT (0x00000007u)
#define CSL_CPSW3G_TX_INTMASK_CLEAR_TX7_MASK_RESETVAL (0x00000000u)

#define CSL_CPSW3G_TX_INTMASK_CLEAR_TX6_MASK_MASK (0x00000040u)
#define CSL_CPSW3G_TX_INTMASK_CLEAR_TX6_MASK_SHIFT (0x00000006u)
#define CSL_CPSW3G_TX_INTMASK_CLEAR_TX6_MASK_RESETVAL (0x00000000u)

#define CSL_CPSW3G_TX_INTMASK_CLEAR_TX5_MASK_MASK (0x00000020u)
#define CSL_CPSW3G_TX_INTMASK_CLEAR_TX5_MASK_SHIFT (0x00000005u)
#define CSL_CPSW3G_TX_INTMASK_CLEAR_TX5_MASK_RESETVAL (0x00000000u)

#define CSL_CPSW3G_TX_INTMASK_CLEAR_TX4_MASK_MASK (0x00000010u)
#define CSL_CPSW3G_TX_INTMASK_CLEAR_TX4_MASK_SHIFT (0x00000004u)
#define CSL_CPSW3G_TX_INTMASK_CLEAR_TX4_MASK_RESETVAL (0x00000000u)

#define CSL_CPSW3G_TX_INTMASK_CLEAR_TX3_MASK_MASK (0x00000008u)
#define CSL_CPSW3G_TX_INTMASK_CLEAR_TX3_MASK_SHIFT (0x00000003u)
#define CSL_CPSW3G_TX_INTMASK_CLEAR_TX3_MASK_RESETVAL (0x00000000u)

#define CSL_CPSW3G_TX_INTMASK_CLEAR_TX2_MASK_MASK (0x00000004u)
#define CSL_CPSW3G_TX_INTMASK_CLEAR_TX2_MASK_SHIFT (0x00000002u)
#define CSL_CPSW3G_TX_INTMASK_CLEAR_TX2_MASK_RESETVAL (0x00000000u)

#define CSL_CPSW3G_TX_INTMASK_CLEAR_TX1_MASK_MASK (0x00000002u)
#define CSL_CPSW3G_TX_INTMASK_CLEAR_TX1_MASK_SHIFT (0x00000001u)
#define CSL_CPSW3G_TX_INTMASK_CLEAR_TX1_MASK_RESETVAL (0x00000000u)

#define CSL_CPSW3G_TX_INTMASK_CLEAR_TX0_MASK_MASK (0x00000001u)
#define CSL_CPSW3G_TX_INTMASK_CLEAR_TX0_MASK_SHIFT (0x00000000u)
#define CSL_CPSW3G_TX_INTMASK_CLEAR_TX0_MASK_RESETVAL (0x00000000u)

#define CSL_CPSW3G_TX_INTMASK_CLEAR_RESETVAL (0x00000000u)

/* CPDMA_IN_VECTOR */


#define CSL_CPSW3G_CPDMA_IN_VECTOR_STAT_PEND_MASK (0x20000000u)
#define CSL_CPSW3G_CPDMA_IN_VECTOR_STAT_PEND_SHIFT (0x0000001Du)
#define CSL_CPSW3G_CPDMA_IN_VECTOR_STAT_PEND_RESETVAL (0x00000000u)

#define CSL_CPSW3G_CPDMA_IN_VECTOR_HOST_PEND_MASK (0x10000000u)
#define CSL_CPSW3G_CPDMA_IN_VECTOR_HOST_PEND_SHIFT (0x0000001Cu)
#define CSL_CPSW3G_CPDMA_IN_VECTOR_HOST_PEND_RESETVAL (0x00000000u)

#define CSL_CPSW3G_CPDMA_IN_VECTOR_MDIO_LINKINT_MASK (0x0C000000u)
#define CSL_CPSW3G_CPDMA_IN_VECTOR_MDIO_LINKINT_SHIFT (0x0000001Au)
#define CSL_CPSW3G_CPDMA_IN_VECTOR_MDIO_LINKINT_RESETVAL (0x00000000u)

#define CSL_CPSW3G_CPDMA_IN_VECTOR_MDIO_USERINT_MASK (0x03000000u)
#define CSL_CPSW3G_CPDMA_IN_VECTOR_MDIO_USERINT_SHIFT (0x00000018u)
#define CSL_CPSW3G_CPDMA_IN_VECTOR_MDIO_USERINT_RESETVAL (0x00000000u)

#define CSL_CPSW3G_CPDMA_IN_VECTOR_TX_PEND_MASK (0x00FF0000u)
#define CSL_CPSW3G_CPDMA_IN_VECTOR_TX_PEND_SHIFT (0x00000010u)
#define CSL_CPSW3G_CPDMA_IN_VECTOR_TX_PEND_RESETVAL (0x00000000u)

#define CSL_CPSW3G_CPDMA_IN_VECTOR_RX_THRESH_PEND_MASK (0x0000FF00u)
#define CSL_CPSW3G_CPDMA_IN_VECTOR_RX_THRESH_PEND_SHIFT (0x00000008u)
#define CSL_CPSW3G_CPDMA_IN_VECTOR_RX_THRESH_PEND_RESETVAL (0x00000000u)

#define CSL_CPSW3G_CPDMA_IN_VECTOR_RX_PEND_MASK (0x000000FFu)
#define CSL_CPSW3G_CPDMA_IN_VECTOR_RX_PEND_SHIFT (0x00000000u)
#define CSL_CPSW3G_CPDMA_IN_VECTOR_RX_PEND_RESETVAL (0x00000000u)

#define CSL_CPSW3G_CPDMA_IN_VECTOR_RESETVAL (0x00000000u)

/* CPDMA_EOI_VECTOR */


#define CSL_CPSW3G_CPDMA_EOI_VECTOR_DMA_EOI_VECTOR_MASK (0x0000001Fu)
#define CSL_CPSW3G_CPDMA_EOI_VECTOR_DMA_EOI_VECTOR_SHIFT (0x00000000u)
#define CSL_CPSW3G_CPDMA_EOI_VECTOR_DMA_EOI_VECTOR_RESETVAL (0x00000000u)

#define CSL_CPSW3G_CPDMA_EOI_VECTOR_RESETVAL (0x00000000u)

/* RX_INTSTAT_RAW */


#define CSL_CPSW3G_RX_INTSTAT_RAW_RX7_THRESH_PEND_MASK (0x00008000u)
#define CSL_CPSW3G_RX_INTSTAT_RAW_RX7_THRESH_PEND_SHIFT (0x0000000Fu)
#define CSL_CPSW3G_RX_INTSTAT_RAW_RX7_THRESH_PEND_RESETVAL (0x00000001u)

#define CSL_CPSW3G_RX_INTSTAT_RAW_RX6_THRESH_PEND_MASK (0x00004000u)
#define CSL_CPSW3G_RX_INTSTAT_RAW_RX6_THRESH_PEND_SHIFT (0x0000000Eu)
#define CSL_CPSW3G_RX_INTSTAT_RAW_RX6_THRESH_PEND_RESETVAL (0x00000001u)

#define CSL_CPSW3G_RX_INTSTAT_RAW_RX5_THRESH_PEND_MASK (0x00002000u)
#define CSL_CPSW3G_RX_INTSTAT_RAW_RX5_THRESH_PEND_SHIFT (0x0000000Du)
#define CSL_CPSW3G_RX_INTSTAT_RAW_RX5_THRESH_PEND_RESETVAL (0x00000001u)

#define CSL_CPSW3G_RX_INTSTAT_RAW_RX4_THRESH_PEND_MASK (0x00001000u)
#define CSL_CPSW3G_RX_INTSTAT_RAW_RX4_THRESH_PEND_SHIFT (0x0000000Cu)
#define CSL_CPSW3G_RX_INTSTAT_RAW_RX4_THRESH_PEND_RESETVAL (0x00000001u)

#define CSL_CPSW3G_RX_INTSTAT_RAW_RX3_THRESH_PEND_MASK (0x00000800u)
#define CSL_CPSW3G_RX_INTSTAT_RAW_RX3_THRESH_PEND_SHIFT (0x0000000Bu)
#define CSL_CPSW3G_RX_INTSTAT_RAW_RX3_THRESH_PEND_RESETVAL (0x00000001u)

#define CSL_CPSW3G_RX_INTSTAT_RAW_RX2_THRESH_PEND_MASK (0x00000400u)
#define CSL_CPSW3G_RX_INTSTAT_RAW_RX2_THRESH_PEND_SHIFT (0x0000000Au)
#define CSL_CPSW3G_RX_INTSTAT_RAW_RX2_THRESH_PEND_RESETVAL (0x00000001u)

#define CSL_CPSW3G_RX_INTSTAT_RAW_RX1_THRESH_PEND_MASK (0x00000200u)
#define CSL_CPSW3G_RX_INTSTAT_RAW_RX1_THRESH_PEND_SHIFT (0x00000009u)
#define CSL_CPSW3G_RX_INTSTAT_RAW_RX1_THRESH_PEND_RESETVAL (0x00000001u)

#define CSL_CPSW3G_RX_INTSTAT_RAW_RX0_THRESH_PEND_MASK (0x00000100u)
#define CSL_CPSW3G_RX_INTSTAT_RAW_RX0_THRESH_PEND_SHIFT (0x00000008u)
#define CSL_CPSW3G_RX_INTSTAT_RAW_RX0_THRESH_PEND_RESETVAL (0x00000001u)

#define CSL_CPSW3G_RX_INTSTAT_RAW_RX7_PEND_MASK (0x00000080u)
#define CSL_CPSW3G_RX_INTSTAT_RAW_RX7_PEND_SHIFT (0x00000007u)
#define CSL_CPSW3G_RX_INTSTAT_RAW_RX7_PEND_RESETVAL (0x00000000u)

#define CSL_CPSW3G_RX_INTSTAT_RAW_RX6_PEND_MASK (0x00000040u)
#define CSL_CPSW3G_RX_INTSTAT_RAW_RX6_PEND_SHIFT (0x00000006u)
#define CSL_CPSW3G_RX_INTSTAT_RAW_RX6_PEND_RESETVAL (0x00000000u)

#define CSL_CPSW3G_RX_INTSTAT_RAW_RX5_PEND_MASK (0x00000020u)
#define CSL_CPSW3G_RX_INTSTAT_RAW_RX5_PEND_SHIFT (0x00000005u)
#define CSL_CPSW3G_RX_INTSTAT_RAW_RX5_PEND_RESETVAL (0x00000000u)

#define CSL_CPSW3G_RX_INTSTAT_RAW_RX4_PEND_MASK (0x00000010u)
#define CSL_CPSW3G_RX_INTSTAT_RAW_RX4_PEND_SHIFT (0x00000004u)
#define CSL_CPSW3G_RX_INTSTAT_RAW_RX4_PEND_RESETVAL (0x00000000u)

#define CSL_CPSW3G_RX_INTSTAT_RAW_RX3_PEND_MASK (0x00000008u)
#define CSL_CPSW3G_RX_INTSTAT_RAW_RX3_PEND_SHIFT (0x00000003u)
#define CSL_CPSW3G_RX_INTSTAT_RAW_RX3_PEND_RESETVAL (0x00000000u)

#define CSL_CPSW3G_RX_INTSTAT_RAW_RX2_PEND_MASK (0x00000004u)
#define CSL_CPSW3G_RX_INTSTAT_RAW_RX2_PEND_SHIFT (0x00000002u)
#define CSL_CPSW3G_RX_INTSTAT_RAW_RX2_PEND_RESETVAL (0x00000000u)

#define CSL_CPSW3G_RX_INTSTAT_RAW_RX1_PEND_MASK (0x00000002u)
#define CSL_CPSW3G_RX_INTSTAT_RAW_RX1_PEND_SHIFT (0x00000001u)
#define CSL_CPSW3G_RX_INTSTAT_RAW_RX1_PEND_RESETVAL (0x00000000u)

#define CSL_CPSW3G_RX_INTSTAT_RAW_RX0_PEND_MASK (0x00000001u)
#define CSL_CPSW3G_RX_INTSTAT_RAW_RX0_PEND_SHIFT (0x00000000u)
#define CSL_CPSW3G_RX_INTSTAT_RAW_RX0_PEND_RESETVAL (0x00000000u)

#define CSL_CPSW3G_RX_INTSTAT_RAW_RESETVAL (0x0000FF00u)

/* RX_INTSTAT_MASKED */


#define CSL_CPSW3G_RX_INTSTAT_MASKED_RX7_THRESH_PEND_MASK (0x00008000u)
#define CSL_CPSW3G_RX_INTSTAT_MASKED_RX7_THRESH_PEND_SHIFT (0x0000000Fu)
#define CSL_CPSW3G_RX_INTSTAT_MASKED_RX7_THRESH_PEND_RESETVAL (0x00000000u)

#define CSL_CPSW3G_RX_INTSTAT_MASKED_RX6_THRESH_PEND_MASK (0x00004000u)
#define CSL_CPSW3G_RX_INTSTAT_MASKED_RX6_THRESH_PEND_SHIFT (0x0000000Eu)
#define CSL_CPSW3G_RX_INTSTAT_MASKED_RX6_THRESH_PEND_RESETVAL (0x00000000u)

#define CSL_CPSW3G_RX_INTSTAT_MASKED_RX5_THRESH_PEND_MASK (0x00002000u)
#define CSL_CPSW3G_RX_INTSTAT_MASKED_RX5_THRESH_PEND_SHIFT (0x0000000Du)
#define CSL_CPSW3G_RX_INTSTAT_MASKED_RX5_THRESH_PEND_RESETVAL (0x00000000u)

#define CSL_CPSW3G_RX_INTSTAT_MASKED_RX4_THRESH_PEND_MASK (0x00001000u)
#define CSL_CPSW3G_RX_INTSTAT_MASKED_RX4_THRESH_PEND_SHIFT (0x0000000Cu)
#define CSL_CPSW3G_RX_INTSTAT_MASKED_RX4_THRESH_PEND_RESETVAL (0x00000000u)

#define CSL_CPSW3G_RX_INTSTAT_MASKED_RX3_THRESH_PEND_MASK (0x00000800u)
#define CSL_CPSW3G_RX_INTSTAT_MASKED_RX3_THRESH_PEND_SHIFT (0x0000000Bu)
#define CSL_CPSW3G_RX_INTSTAT_MASKED_RX3_THRESH_PEND_RESETVAL (0x00000000u)

#define CSL_CPSW3G_RX_INTSTAT_MASKED_RX2_THRESH_PEND_MASK (0x00000400u)
#define CSL_CPSW3G_RX_INTSTAT_MASKED_RX2_THRESH_PEND_SHIFT (0x0000000Au)
#define CSL_CPSW3G_RX_INTSTAT_MASKED_RX2_THRESH_PEND_RESETVAL (0x00000000u)

#define CSL_CPSW3G_RX_INTSTAT_MASKED_RX1_THRESH_PEND_MASK (0x00000200u)
#define CSL_CPSW3G_RX_INTSTAT_MASKED_RX1_THRESH_PEND_SHIFT (0x00000009u)
#define CSL_CPSW3G_RX_INTSTAT_MASKED_RX1_THRESH_PEND_RESETVAL (0x00000000u)

#define CSL_CPSW3G_RX_INTSTAT_MASKED_RX0_THRESH_PEND_MASK (0x00000100u)
#define CSL_CPSW3G_RX_INTSTAT_MASKED_RX0_THRESH_PEND_SHIFT (0x00000008u)
#define CSL_CPSW3G_RX_INTSTAT_MASKED_RX0_THRESH_PEND_RESETVAL (0x00000000u)

#define CSL_CPSW3G_RX_INTSTAT_MASKED_RX7_PEND_MASK (0x00000080u)
#define CSL_CPSW3G_RX_INTSTAT_MASKED_RX7_PEND_SHIFT (0x00000007u)
#define CSL_CPSW3G_RX_INTSTAT_MASKED_RX7_PEND_RESETVAL (0x00000000u)

#define CSL_CPSW3G_RX_INTSTAT_MASKED_RX6_PEND_MASK (0x00000040u)
#define CSL_CPSW3G_RX_INTSTAT_MASKED_RX6_PEND_SHIFT (0x00000006u)
#define CSL_CPSW3G_RX_INTSTAT_MASKED_RX6_PEND_RESETVAL (0x00000000u)

#define CSL_CPSW3G_RX_INTSTAT_MASKED_RX5_PEND_MASK (0x00000020u)
#define CSL_CPSW3G_RX_INTSTAT_MASKED_RX5_PEND_SHIFT (0x00000005u)
#define CSL_CPSW3G_RX_INTSTAT_MASKED_RX5_PEND_RESETVAL (0x00000000u)

#define CSL_CPSW3G_RX_INTSTAT_MASKED_RX4_PEND_MASK (0x00000010u)
#define CSL_CPSW3G_RX_INTSTAT_MASKED_RX4_PEND_SHIFT (0x00000004u)
#define CSL_CPSW3G_RX_INTSTAT_MASKED_RX4_PEND_RESETVAL (0x00000000u)

#define CSL_CPSW3G_RX_INTSTAT_MASKED_RX3_PEND_MASK (0x00000008u)
#define CSL_CPSW3G_RX_INTSTAT_MASKED_RX3_PEND_SHIFT (0x00000003u)
#define CSL_CPSW3G_RX_INTSTAT_MASKED_RX3_PEND_RESETVAL (0x00000000u)

#define CSL_CPSW3G_RX_INTSTAT_MASKED_RX2_PEND_MASK (0x00000004u)
#define CSL_CPSW3G_RX_INTSTAT_MASKED_RX2_PEND_SHIFT (0x00000002u)
#define CSL_CPSW3G_RX_INTSTAT_MASKED_RX2_PEND_RESETVAL (0x00000000u)

#define CSL_CPSW3G_RX_INTSTAT_MASKED_RX1_PEND_MASK (0x00000002u)
#define CSL_CPSW3G_RX_INTSTAT_MASKED_RX1_PEND_SHIFT (0x00000001u)
#define CSL_CPSW3G_RX_INTSTAT_MASKED_RX1_PEND_RESETVAL (0x00000000u)

#define CSL_CPSW3G_RX_INTSTAT_MASKED_RX0_PEND_MASK (0x00000001u)
#define CSL_CPSW3G_RX_INTSTAT_MASKED_RX0_PEND_SHIFT (0x00000000u)
#define CSL_CPSW3G_RX_INTSTAT_MASKED_RX0_PEND_RESETVAL (0x00000000u)

#define CSL_CPSW3G_RX_INTSTAT_MASKED_RESETVAL (0x00000000u)

/* RX_INTMASK_SET */


#define CSL_CPSW3G_RX_INTMASK_SET_RX7_THRESH_PEND_MASK_MASK (0x00008000u)
#define CSL_CPSW3G_RX_INTMASK_SET_RX7_THRESH_PEND_MASK_SHIFT (0x0000000Fu)
#define CSL_CPSW3G_RX_INTMASK_SET_RX7_THRESH_PEND_MASK_RESETVAL (0x00000000u)

#define CSL_CPSW3G_RX_INTMASK_SET_RX6_THRESH_PEND_MASK_MASK (0x00004000u)
#define CSL_CPSW3G_RX_INTMASK_SET_RX6_THRESH_PEND_MASK_SHIFT (0x0000000Eu)
#define CSL_CPSW3G_RX_INTMASK_SET_RX6_THRESH_PEND_MASK_RESETVAL (0x00000000u)

#define CSL_CPSW3G_RX_INTMASK_SET_RX5_THRESH_PEND_MASK_MASK (0x00002000u)
#define CSL_CPSW3G_RX_INTMASK_SET_RX5_THRESH_PEND_MASK_SHIFT (0x0000000Du)
#define CSL_CPSW3G_RX_INTMASK_SET_RX5_THRESH_PEND_MASK_RESETVAL (0x00000000u)

#define CSL_CPSW3G_RX_INTMASK_SET_RX4_THRESH_PEND_MASK_MASK (0x00001000u)
#define CSL_CPSW3G_RX_INTMASK_SET_RX4_THRESH_PEND_MASK_SHIFT (0x0000000Cu)
#define CSL_CPSW3G_RX_INTMASK_SET_RX4_THRESH_PEND_MASK_RESETVAL (0x00000000u)

#define CSL_CPSW3G_RX_INTMASK_SET_RX3_THRESH_PEND_MASK_MASK (0x00000800u)
#define CSL_CPSW3G_RX_INTMASK_SET_RX3_THRESH_PEND_MASK_SHIFT (0x0000000Bu)
#define CSL_CPSW3G_RX_INTMASK_SET_RX3_THRESH_PEND_MASK_RESETVAL (0x00000000u)

#define CSL_CPSW3G_RX_INTMASK_SET_RX2_THRESH_PEND_MASK_MASK (0x00000400u)
#define CSL_CPSW3G_RX_INTMASK_SET_RX2_THRESH_PEND_MASK_SHIFT (0x0000000Au)
#define CSL_CPSW3G_RX_INTMASK_SET_RX2_THRESH_PEND_MASK_RESETVAL (0x00000000u)

#define CSL_CPSW3G_RX_INTMASK_SET_RX1_THRESH_PEND_MASK_MASK (0x00000200u)
#define CSL_CPSW3G_RX_INTMASK_SET_RX1_THRESH_PEND_MASK_SHIFT (0x00000009u)
#define CSL_CPSW3G_RX_INTMASK_SET_RX1_THRESH_PEND_MASK_RESETVAL (0x00000000u)

#define CSL_CPSW3G_RX_INTMASK_SET_RX0_THRESH_PEND_MASK_MASK (0x00000100u)
#define CSL_CPSW3G_RX_INTMASK_SET_RX0_THRESH_PEND_MASK_SHIFT (0x00000008u)
#define CSL_CPSW3G_RX_INTMASK_SET_RX0_THRESH_PEND_MASK_RESETVAL (0x00000000u)

#define CSL_CPSW3G_RX_INTMASK_SET_RX7_PEND_MASK_MASK (0x00000080u)
#define CSL_CPSW3G_RX_INTMASK_SET_RX7_PEND_MASK_SHIFT (0x00000007u)
#define CSL_CPSW3G_RX_INTMASK_SET_RX7_PEND_MASK_RESETVAL (0x00000000u)

#define CSL_CPSW3G_RX_INTMASK_SET_RX6_PEND_MASK_MASK (0x00000040u)
#define CSL_CPSW3G_RX_INTMASK_SET_RX6_PEND_MASK_SHIFT (0x00000006u)
#define CSL_CPSW3G_RX_INTMASK_SET_RX6_PEND_MASK_RESETVAL (0x00000000u)

#define CSL_CPSW3G_RX_INTMASK_SET_RX5_PEND_MASK_MASK (0x00000020u)
#define CSL_CPSW3G_RX_INTMASK_SET_RX5_PEND_MASK_SHIFT (0x00000005u)
#define CSL_CPSW3G_RX_INTMASK_SET_RX5_PEND_MASK_RESETVAL (0x00000000u)

#define CSL_CPSW3G_RX_INTMASK_SET_RX4_PEND_MASK_MASK (0x00000010u)
#define CSL_CPSW3G_RX_INTMASK_SET_RX4_PEND_MASK_SHIFT (0x00000004u)
#define CSL_CPSW3G_RX_INTMASK_SET_RX4_PEND_MASK_RESETVAL (0x00000000u)

#define CSL_CPSW3G_RX_INTMASK_SET_RX3_PEND_MASK_MASK (0x00000008u)
#define CSL_CPSW3G_RX_INTMASK_SET_RX3_PEND_MASK_SHIFT (0x00000003u)
#define CSL_CPSW3G_RX_INTMASK_SET_RX3_PEND_MASK_RESETVAL (0x00000000u)

#define CSL_CPSW3G_RX_INTMASK_SET_RX2_PEND_MASK_MASK (0x00000004u)
#define CSL_CPSW3G_RX_INTMASK_SET_RX2_PEND_MASK_SHIFT (0x00000002u)
#define CSL_CPSW3G_RX_INTMASK_SET_RX2_PEND_MASK_RESETVAL (0x00000000u)

#define CSL_CPSW3G_RX_INTMASK_SET_RX1_PEND_MASK_MASK (0x00000002u)
#define CSL_CPSW3G_RX_INTMASK_SET_RX1_PEND_MASK_SHIFT (0x00000001u)
#define CSL_CPSW3G_RX_INTMASK_SET_RX1_PEND_MASK_RESETVAL (0x00000000u)

#define CSL_CPSW3G_RX_INTMASK_SET_RX0_PEND_MASK_MASK (0x00000001u)
#define CSL_CPSW3G_RX_INTMASK_SET_RX0_PEND_MASK_SHIFT (0x00000000u)
#define CSL_CPSW3G_RX_INTMASK_SET_RX0_PEND_MASK_RESETVAL (0x00000000u)

#define CSL_CPSW3G_RX_INTMASK_SET_RESETVAL (0x00000000u)

/* RX_INTMASK_CLEAR */


#define CSL_CPSW3G_RX_INTMASK_CLEAR_RX7_THRESH_PEND_MASK_MASK (0x00008000u)
#define CSL_CPSW3G_RX_INTMASK_CLEAR_RX7_THRESH_PEND_MASK_SHIFT (0x0000000Fu)
#define CSL_CPSW3G_RX_INTMASK_CLEAR_RX7_THRESH_PEND_MASK_RESETVAL (0x00000000u)

#define CSL_CPSW3G_RX_INTMASK_CLEAR_RX6_THRESH_PEND_MASK_MASK (0x00004000u)
#define CSL_CPSW3G_RX_INTMASK_CLEAR_RX6_THRESH_PEND_MASK_SHIFT (0x0000000Eu)
#define CSL_CPSW3G_RX_INTMASK_CLEAR_RX6_THRESH_PEND_MASK_RESETVAL (0x00000000u)

#define CSL_CPSW3G_RX_INTMASK_CLEAR_RX5_THRESH_PEND_MASK_MASK (0x00002000u)
#define CSL_CPSW3G_RX_INTMASK_CLEAR_RX5_THRESH_PEND_MASK_SHIFT (0x0000000Du)
#define CSL_CPSW3G_RX_INTMASK_CLEAR_RX5_THRESH_PEND_MASK_RESETVAL (0x00000000u)

#define CSL_CPSW3G_RX_INTMASK_CLEAR_RX4_THRESH_PEND_MASK_MASK (0x00001000u)
#define CSL_CPSW3G_RX_INTMASK_CLEAR_RX4_THRESH_PEND_MASK_SHIFT (0x0000000Cu)
#define CSL_CPSW3G_RX_INTMASK_CLEAR_RX4_THRESH_PEND_MASK_RESETVAL (0x00000000u)

#define CSL_CPSW3G_RX_INTMASK_CLEAR_RX3_THRESH_PEND_MASK_MASK (0x00000800u)
#define CSL_CPSW3G_RX_INTMASK_CLEAR_RX3_THRESH_PEND_MASK_SHIFT (0x0000000Bu)
#define CSL_CPSW3G_RX_INTMASK_CLEAR_RX3_THRESH_PEND_MASK_RESETVAL (0x00000000u)

#define CSL_CPSW3G_RX_INTMASK_CLEAR_RX2_THRESH_PEND_MASK_MASK (0x00000400u)
#define CSL_CPSW3G_RX_INTMASK_CLEAR_RX2_THRESH_PEND_MASK_SHIFT (0x0000000Au)
#define CSL_CPSW3G_RX_INTMASK_CLEAR_RX2_THRESH_PEND_MASK_RESETVAL (0x00000000u)

#define CSL_CPSW3G_RX_INTMASK_CLEAR_RX1_THRESH_PEND_MASK_MASK (0x00000200u)
#define CSL_CPSW3G_RX_INTMASK_CLEAR_RX1_THRESH_PEND_MASK_SHIFT (0x00000009u)
#define CSL_CPSW3G_RX_INTMASK_CLEAR_RX1_THRESH_PEND_MASK_RESETVAL (0x00000000u)

#define CSL_CPSW3G_RX_INTMASK_CLEAR_RX0_THRESH_PEND_MASK_MASK (0x00000100u)
#define CSL_CPSW3G_RX_INTMASK_CLEAR_RX0_THRESH_PEND_MASK_SHIFT (0x00000008u)
#define CSL_CPSW3G_RX_INTMASK_CLEAR_RX0_THRESH_PEND_MASK_RESETVAL (0x00000000u)

#define CSL_CPSW3G_RX_INTMASK_CLEAR_RX7_PEND_MASK_MASK (0x00000080u)
#define CSL_CPSW3G_RX_INTMASK_CLEAR_RX7_PEND_MASK_SHIFT (0x00000007u)
#define CSL_CPSW3G_RX_INTMASK_CLEAR_RX7_PEND_MASK_RESETVAL (0x00000000u)

#define CSL_CPSW3G_RX_INTMASK_CLEAR_RX6_PEND_MASK_MASK (0x00000040u)
#define CSL_CPSW3G_RX_INTMASK_CLEAR_RX6_PEND_MASK_SHIFT (0x00000006u)
#define CSL_CPSW3G_RX_INTMASK_CLEAR_RX6_PEND_MASK_RESETVAL (0x00000000u)

#define CSL_CPSW3G_RX_INTMASK_CLEAR_RX5_PEND_MASK_MASK (0x00000020u)
#define CSL_CPSW3G_RX_INTMASK_CLEAR_RX5_PEND_MASK_SHIFT (0x00000005u)
#define CSL_CPSW3G_RX_INTMASK_CLEAR_RX5_PEND_MASK_RESETVAL (0x00000000u)

#define CSL_CPSW3G_RX_INTMASK_CLEAR_RX4_PEND_MASK_MASK (0x00000010u)
#define CSL_CPSW3G_RX_INTMASK_CLEAR_RX4_PEND_MASK_SHIFT (0x00000004u)
#define CSL_CPSW3G_RX_INTMASK_CLEAR_RX4_PEND_MASK_RESETVAL (0x00000000u)

#define CSL_CPSW3G_RX_INTMASK_CLEAR_RX3_PEND_MASK_MASK (0x00000008u)
#define CSL_CPSW3G_RX_INTMASK_CLEAR_RX3_PEND_MASK_SHIFT (0x00000003u)
#define CSL_CPSW3G_RX_INTMASK_CLEAR_RX3_PEND_MASK_RESETVAL (0x00000000u)

#define CSL_CPSW3G_RX_INTMASK_CLEAR_RX2_PEND_MASK_MASK (0x00000004u)
#define CSL_CPSW3G_RX_INTMASK_CLEAR_RX2_PEND_MASK_SHIFT (0x00000002u)
#define CSL_CPSW3G_RX_INTMASK_CLEAR_RX2_PEND_MASK_RESETVAL (0x00000000u)

#define CSL_CPSW3G_RX_INTMASK_CLEAR_RX1_PEND_MASK_MASK (0x00000002u)
#define CSL_CPSW3G_RX_INTMASK_CLEAR_RX1_PEND_MASK_SHIFT (0x00000001u)
#define CSL_CPSW3G_RX_INTMASK_CLEAR_RX1_PEND_MASK_RESETVAL (0x00000000u)

#define CSL_CPSW3G_RX_INTMASK_CLEAR_RX0_PEND_MASK_MASK (0x00000001u)
#define CSL_CPSW3G_RX_INTMASK_CLEAR_RX0_PEND_MASK_SHIFT (0x00000000u)
#define CSL_CPSW3G_RX_INTMASK_CLEAR_RX0_PEND_MASK_RESETVAL (0x00000000u)

#define CSL_CPSW3G_RX_INTMASK_CLEAR_RESETVAL (0x00000000u)

/* DMA_INTSTAT_RAW */


#define CSL_CPSW3G_DMA_INTSTAT_RAW_HOST_PEND_MASK (0x00000002u)
#define CSL_CPSW3G_DMA_INTSTAT_RAW_HOST_PEND_SHIFT (0x00000001u)
#define CSL_CPSW3G_DMA_INTSTAT_RAW_HOST_PEND_RESETVAL (0x00000000u)

#define CSL_CPSW3G_DMA_INTSTAT_RAW_STAT_PEND_MASK (0x00000001u)
#define CSL_CPSW3G_DMA_INTSTAT_RAW_STAT_PEND_SHIFT (0x00000000u)
#define CSL_CPSW3G_DMA_INTSTAT_RAW_STAT_PEND_RESETVAL (0x00000000u)

#define CSL_CPSW3G_DMA_INTSTAT_RAW_RESETVAL (0x00000000u)

/* DMA_INTSTAT_MASKED */


#define CSL_CPSW3G_DMA_INTSTAT_MASKED_HOST_PEND_MASK (0x00000002u)
#define CSL_CPSW3G_DMA_INTSTAT_MASKED_HOST_PEND_SHIFT (0x00000001u)
#define CSL_CPSW3G_DMA_INTSTAT_MASKED_HOST_PEND_RESETVAL (0x00000000u)

#define CSL_CPSW3G_DMA_INTSTAT_MASKED_STAT_PEND_MASK (0x00000001u)
#define CSL_CPSW3G_DMA_INTSTAT_MASKED_STAT_PEND_SHIFT (0x00000000u)
#define CSL_CPSW3G_DMA_INTSTAT_MASKED_STAT_PEND_RESETVAL (0x00000000u)

#define CSL_CPSW3G_DMA_INTSTAT_MASKED_RESETVAL (0x00000000u)

/* DMA_INTMASK_SET */


#define CSL_CPSW3G_DMA_INTMASK_SET_HOST_ERR_INT_MASK_MASK (0x00000002u)
#define CSL_CPSW3G_DMA_INTMASK_SET_HOST_ERR_INT_MASK_SHIFT (0x00000001u)
#define CSL_CPSW3G_DMA_INTMASK_SET_HOST_ERR_INT_MASK_RESETVAL (0x00000000u)

#define CSL_CPSW3G_DMA_INTMASK_SET_STAT_INT_MASK_MASK (0x00000001u)
#define CSL_CPSW3G_DMA_INTMASK_SET_STAT_INT_MASK_SHIFT (0x00000000u)
#define CSL_CPSW3G_DMA_INTMASK_SET_STAT_INT_MASK_RESETVAL (0x00000000u)

#define CSL_CPSW3G_DMA_INTMASK_SET_RESETVAL (0x00000000u)

/* DMA_INTMASK_CLEAR */


#define CSL_CPSW3G_DMA_INTMASK_CLEAR_HOST_ERR_INTMASK_MASK (0x00000002u)
#define CSL_CPSW3G_DMA_INTMASK_CLEAR_HOST_ERR_INTMASK_SHIFT (0x00000001u)
#define CSL_CPSW3G_DMA_INTMASK_CLEAR_HOST_ERR_INTMASK_RESETVAL (0x00000000u)

#define CSL_CPSW3G_DMA_INTMASK_CLEAR_STAT_INT_MASK_MASK (0x00000001u)
#define CSL_CPSW3G_DMA_INTMASK_CLEAR_STAT_INT_MASK_SHIFT (0x00000000u)
#define CSL_CPSW3G_DMA_INTMASK_CLEAR_STAT_INT_MASK_RESETVAL (0x00000000u)

#define CSL_CPSW3G_DMA_INTMASK_CLEAR_RESETVAL (0x00000000u)

/* RX_PENDTHRESH */


#define CSL_CPSW3G_RX_PENDTHRESH_RX_PENDTHRESH_MASK (0x000000FFu)
#define CSL_CPSW3G_RX_PENDTHRESH_RX_PENDTHRESH_SHIFT (0x00000000u)
#define CSL_CPSW3G_RX_PENDTHRESH_RX_PENDTHRESH_RESETVAL (0x00000000u)

#define CSL_CPSW3G_RX_PENDTHRESH_RESETVAL (0x00000000u)

/* RX_FREEBUFFER */


#define CSL_CPSW3G_RX_FREEBUFFER_RX_FREEBUF_MASK (0x0000FFFFu)
#define CSL_CPSW3G_RX_FREEBUFFER_RX_FREEBUF_SHIFT (0x00000000u)
#define CSL_CPSW3G_RX_FREEBUFFER_RX_FREEBUF_RESETVAL (0x00000000u)

#define CSL_CPSW3G_RX_FREEBUFFER_RESETVAL (0x00000000u)

/* TX_HDP */

#define CSL_CPSW3G_TX_HDP_TX_HDP_MASK (0xFFFFFFFFu)
#define CSL_CPSW3G_TX_HDP_TX_HDP_SHIFT (0x00000000u)
#define CSL_CPSW3G_TX_HDP_TX_HDP_RESETVAL (0x00000000u)

#define CSL_CPSW3G_TX_HDP_RESETVAL (0x00000000u)

/* RX_HDP */

#define CSL_CPSW3G_RX_HDP_RX_HDP_MASK (0xFFFFFFFFu)
#define CSL_CPSW3G_RX_HDP_RX_HDP_SHIFT (0x00000000u)
#define CSL_CPSW3G_RX_HDP_RX_HDP_RESETVAL (0x00000000u)

#define CSL_CPSW3G_RX_HDP_RESETVAL (0x00000000u)

/* TX_CP */

#define CSL_CPSW3G_TX_CP_TX_CP_MASK (0xFFFFFFFFu)
#define CSL_CPSW3G_TX_CP_TX_CP_SHIFT (0x00000000u)
#define CSL_CPSW3G_TX_CP_TX_CP_RESETVAL (0x00000000u)

#define CSL_CPSW3G_TX_CP_RESETVAL (0x00000000u)

/* RX_CP */

#define CSL_CPSW3G_RX_CP_RX_CP_MASK (0xFFFFFFFFu)
#define CSL_CPSW3G_RX_CP_RX_CP_SHIFT (0x00000000u)
#define CSL_CPSW3G_RX_CP_RX_CP_RESETVAL (0x00000000u)

#define CSL_CPSW3G_RX_CP_RESETVAL (0x00000000u)

/* RXGOODFRAMES */

#define CSL_CPSW3G_RXGOODFRAMES_COUNT_MASK (0xFFFFFFFFu)
#define CSL_CPSW3G_RXGOODFRAMES_COUNT_SHIFT (0x00000000u)
#define CSL_CPSW3G_RXGOODFRAMES_COUNT_RESETVAL (0x00000000u)

#define CSL_CPSW3G_RXGOODFRAMES_RESETVAL (0x00000000u)

/* RXBROADCASTFRAMES */

#define CSL_CPSW3G_RXBROADCASTFRAMES_COUNT_MASK (0xFFFFFFFFu)
#define CSL_CPSW3G_RXBROADCASTFRAMES_COUNT_SHIFT (0x00000000u)
#define CSL_CPSW3G_RXBROADCASTFRAMES_COUNT_RESETVAL (0x00000000u)

#define CSL_CPSW3G_RXBROADCASTFRAMES_RESETVAL (0x00000000u)

/* RXMULTICASTFRAMES */

#define CSL_CPSW3G_RXMULTICASTFRAMES_COUNT_MASK (0xFFFFFFFFu)
#define CSL_CPSW3G_RXMULTICASTFRAMES_COUNT_SHIFT (0x00000000u)
#define CSL_CPSW3G_RXMULTICASTFRAMES_COUNT_RESETVAL (0x00000000u)

#define CSL_CPSW3G_RXMULTICASTFRAMES_RESETVAL (0x00000000u)

/* RXPAUSEFRAMES */

#define CSL_CPSW3G_RXPAUSEFRAMES_COUNT_MASK (0xFFFFFFFFu)
#define CSL_CPSW3G_RXPAUSEFRAMES_COUNT_SHIFT (0x00000000u)
#define CSL_CPSW3G_RXPAUSEFRAMES_COUNT_RESETVAL (0x00000000u)

#define CSL_CPSW3G_RXPAUSEFRAMES_RESETVAL (0x00000000u)

/* RXCRCERRORS */

#define CSL_CPSW3G_RXCRCERRORS_COUNT_MASK (0xFFFFFFFFu)
#define CSL_CPSW3G_RXCRCERRORS_COUNT_SHIFT (0x00000000u)
#define CSL_CPSW3G_RXCRCERRORS_COUNT_RESETVAL (0x00000000u)

#define CSL_CPSW3G_RXCRCERRORS_RESETVAL (0x00000000u)

/* RXALIGNCODEERRORS */

#define CSL_CPSW3G_RXALIGNCODEERRORS_COUNT_MASK (0xFFFFFFFFu)
#define CSL_CPSW3G_RXALIGNCODEERRORS_COUNT_SHIFT (0x00000000u)
#define CSL_CPSW3G_RXALIGNCODEERRORS_COUNT_RESETVAL (0x00000000u)

#define CSL_CPSW3G_RXALIGNCODEERRORS_RESETVAL (0x00000000u)

/* RXOVERSIZEDFRAMES */

#define CSL_CPSW3G_RXOVERSIZEDFRAMES_COUNT_MASK (0xFFFFFFFFu)
#define CSL_CPSW3G_RXOVERSIZEDFRAMES_COUNT_SHIFT (0x00000000u)
#define CSL_CPSW3G_RXOVERSIZEDFRAMES_COUNT_RESETVAL (0x00000000u)

#define CSL_CPSW3G_RXOVERSIZEDFRAMES_RESETVAL (0x00000000u)

/* RXJABBERFRAMES */

#define CSL_CPSW3G_RXJABBERFRAMES_COUNT_MASK (0xFFFFFFFFu)
#define CSL_CPSW3G_RXJABBERFRAMES_COUNT_SHIFT (0x00000000u)
#define CSL_CPSW3G_RXJABBERFRAMES_COUNT_RESETVAL (0x00000000u)

#define CSL_CPSW3G_RXJABBERFRAMES_RESETVAL (0x00000000u)

/* RXUNDERSIZEDFRAMES */

#define CSL_CPSW3G_RXUNDERSIZEDFRAMES_COUNT_MASK (0xFFFFFFFFu)
#define CSL_CPSW3G_RXUNDERSIZEDFRAMES_COUNT_SHIFT (0x00000000u)
#define CSL_CPSW3G_RXUNDERSIZEDFRAMES_COUNT_RESETVAL (0x00000000u)

#define CSL_CPSW3G_RXUNDERSIZEDFRAMES_RESETVAL (0x00000000u)

/* RXFRAGMENTS */

#define CSL_CPSW3G_RXFRAGMENTS_COUNT_MASK (0xFFFFFFFFu)
#define CSL_CPSW3G_RXFRAGMENTS_COUNT_SHIFT (0x00000000u)
#define CSL_CPSW3G_RXFRAGMENTS_COUNT_RESETVAL (0x00000000u)

#define CSL_CPSW3G_RXFRAGMENTS_RESETVAL (0x00000000u)

/* RXOCTETS */

#define CSL_CPSW3G_RXOCTETS_COUNT_MASK (0xFFFFFFFFu)
#define CSL_CPSW3G_RXOCTETS_COUNT_SHIFT (0x00000000u)
#define CSL_CPSW3G_RXOCTETS_COUNT_RESETVAL (0x00000000u)

#define CSL_CPSW3G_RXOCTETS_RESETVAL (0x00000000u)

/* TXGOODFRAMES */

#define CSL_CPSW3G_TXGOODFRAMES_COUNT_MASK (0xFFFFFFFFu)
#define CSL_CPSW3G_TXGOODFRAMES_COUNT_SHIFT (0x00000000u)
#define CSL_CPSW3G_TXGOODFRAMES_COUNT_RESETVAL (0x00000000u)

#define CSL_CPSW3G_TXGOODFRAMES_RESETVAL (0x00000000u)

/* TXBROADCASTFRAMES */

#define CSL_CPSW3G_TXBROADCASTFRAMES_COUNT_MASK (0xFFFFFFFFu)
#define CSL_CPSW3G_TXBROADCASTFRAMES_COUNT_SHIFT (0x00000000u)
#define CSL_CPSW3G_TXBROADCASTFRAMES_COUNT_RESETVAL (0x00000000u)

#define CSL_CPSW3G_TXBROADCASTFRAMES_RESETVAL (0x00000000u)

/* TXMULTICASTFRAMES */

#define CSL_CPSW3G_TXMULTICASTFRAMES_COUNT_MASK (0xFFFFFFFFu)
#define CSL_CPSW3G_TXMULTICASTFRAMES_COUNT_SHIFT (0x00000000u)
#define CSL_CPSW3G_TXMULTICASTFRAMES_COUNT_RESETVAL (0x00000000u)

#define CSL_CPSW3G_TXMULTICASTFRAMES_RESETVAL (0x00000000u)

/* TXPAUSEFRAMES */

#define CSL_CPSW3G_TXPAUSEFRAMES_COUNT_MASK (0xFFFFFFFFu)
#define CSL_CPSW3G_TXPAUSEFRAMES_COUNT_SHIFT (0x00000000u)
#define CSL_CPSW3G_TXPAUSEFRAMES_COUNT_RESETVAL (0x00000000u)

#define CSL_CPSW3G_TXPAUSEFRAMES_RESETVAL (0x00000000u)

/* TXDEFERREDFRAMES */

#define CSL_CPSW3G_TXDEFERREDFRAMES_COUNT_MASK (0xFFFFFFFFu)
#define CSL_CPSW3G_TXDEFERREDFRAMES_COUNT_SHIFT (0x00000000u)
#define CSL_CPSW3G_TXDEFERREDFRAMES_COUNT_RESETVAL (0x00000000u)

#define CSL_CPSW3G_TXDEFERREDFRAMES_RESETVAL (0x00000000u)

/* TXCOLLISIONFRAMES */

#define CSL_CPSW3G_TXCOLLISIONFRAMES_COUNT_MASK (0xFFFFFFFFu)
#define CSL_CPSW3G_TXCOLLISIONFRAMES_COUNT_SHIFT (0x00000000u)
#define CSL_CPSW3G_TXCOLLISIONFRAMES_COUNT_RESETVAL (0x00000000u)

#define CSL_CPSW3G_TXCOLLISIONFRAMES_RESETVAL (0x00000000u)

/* TXSINGLECOLLFRAMES */

#define CSL_CPSW3G_TXSINGLECOLLFRAMES_COUNT_MASK (0xFFFFFFFFu)
#define CSL_CPSW3G_TXSINGLECOLLFRAMES_COUNT_SHIFT (0x00000000u)
#define CSL_CPSW3G_TXSINGLECOLLFRAMES_COUNT_RESETVAL (0x00000000u)

#define CSL_CPSW3G_TXSINGLECOLLFRAMES_RESETVAL (0x00000000u)

/* TXMULTCOLLFRAMES */

#define CSL_CPSW3G_TXMULTCOLLFRAMES_COUNT_MASK (0xFFFFFFFFu)
#define CSL_CPSW3G_TXMULTCOLLFRAMES_COUNT_SHIFT (0x00000000u)
#define CSL_CPSW3G_TXMULTCOLLFRAMES_COUNT_RESETVAL (0x00000000u)

#define CSL_CPSW3G_TXMULTCOLLFRAMES_RESETVAL (0x00000000u)

/* TXEXCESSIVECOLLISIONS */

#define CSL_CPSW3G_TXEXCESSIVECOLLISIONS_COUNT_MASK (0xFFFFFFFFu)
#define CSL_CPSW3G_TXEXCESSIVECOLLISIONS_COUNT_SHIFT (0x00000000u)
#define CSL_CPSW3G_TXEXCESSIVECOLLISIONS_COUNT_RESETVAL (0x00000000u)

#define CSL_CPSW3G_TXEXCESSIVECOLLISIONS_RESETVAL (0x00000000u)

/* TXLATECOLLISIONS */

#define CSL_CPSW3G_TXLATECOLLISIONS_COUNT_MASK (0xFFFFFFFFu)
#define CSL_CPSW3G_TXLATECOLLISIONS_COUNT_SHIFT (0x00000000u)
#define CSL_CPSW3G_TXLATECOLLISIONS_COUNT_RESETVAL (0x00000000u)

#define CSL_CPSW3G_TXLATECOLLISIONS_RESETVAL (0x00000000u)

/* TXUNDERRUN */

#define CSL_CPSW3G_TXUNDERRUN_COUNT_MASK (0xFFFFFFFFu)
#define CSL_CPSW3G_TXUNDERRUN_COUNT_SHIFT (0x00000000u)
#define CSL_CPSW3G_TXUNDERRUN_COUNT_RESETVAL (0x00000000u)

#define CSL_CPSW3G_TXUNDERRUN_RESETVAL (0x00000000u)

/* TXCARRIERSENSEERRORS */

#define CSL_CPSW3G_TXCARRIERSENSEERRORS_COUNT_MASK (0xFFFFFFFFu)
#define CSL_CPSW3G_TXCARRIERSENSEERRORS_COUNT_SHIFT (0x00000000u)
#define CSL_CPSW3G_TXCARRIERSENSEERRORS_COUNT_RESETVAL (0x00000000u)

#define CSL_CPSW3G_TXCARRIERSENSEERRORS_RESETVAL (0x00000000u)

/* TXOCTETS */

#define CSL_CPSW3G_TXOCTETS_COUNT_MASK (0xFFFFFFFFu)
#define CSL_CPSW3G_TXOCTETS_COUNT_SHIFT (0x00000000u)
#define CSL_CPSW3G_TXOCTETS_COUNT_RESETVAL (0x00000000u)

#define CSL_CPSW3G_TXOCTETS_RESETVAL (0x00000000u)

/* OCTETFRAMES64 */

#define CSL_CPSW3G_OCTETFRAMES64_COUNT_MASK (0xFFFFFFFFu)
#define CSL_CPSW3G_OCTETFRAMES64_COUNT_SHIFT (0x00000000u)
#define CSL_CPSW3G_OCTETFRAMES64_COUNT_RESETVAL (0x00000000u)

#define CSL_CPSW3G_OCTETFRAMES64_RESETVAL (0x00000000u)

/* OCTETFRAMES65T127 */

#define CSL_CPSW3G_OCTETFRAMES65T127_COUNT_MASK (0xFFFFFFFFu)
#define CSL_CPSW3G_OCTETFRAMES65T127_COUNT_SHIFT (0x00000000u)
#define CSL_CPSW3G_OCTETFRAMES65T127_COUNT_RESETVAL (0x00000000u)

#define CSL_CPSW3G_OCTETFRAMES65T127_RESETVAL (0x00000000u)

/* OCTETFRAMES128T255 */

#define CSL_CPSW3G_OCTETFRAMES128T255_COUNT_MASK (0xFFFFFFFFu)
#define CSL_CPSW3G_OCTETFRAMES128T255_COUNT_SHIFT (0x00000000u)
#define CSL_CPSW3G_OCTETFRAMES128T255_COUNT_RESETVAL (0x00000000u)

#define CSL_CPSW3G_OCTETFRAMES128T255_RESETVAL (0x00000000u)

/* OCTETFRAMES256T511 */

#define CSL_CPSW3G_OCTETFRAMES256T511_COUNT_MASK (0xFFFFFFFFu)
#define CSL_CPSW3G_OCTETFRAMES256T511_COUNT_SHIFT (0x00000000u)
#define CSL_CPSW3G_OCTETFRAMES256T511_COUNT_RESETVAL (0x00000000u)

#define CSL_CPSW3G_OCTETFRAMES256T511_RESETVAL (0x00000000u)

/* OCTETFRAMES512T1023 */

#define CSL_CPSW3G_OCTETFRAMES512T1023_COUNT_MASK (0xFFFFFFFFu)
#define CSL_CPSW3G_OCTETFRAMES512T1023_COUNT_SHIFT (0x00000000u)
#define CSL_CPSW3G_OCTETFRAMES512T1023_COUNT_RESETVAL (0x00000000u)

#define CSL_CPSW3G_OCTETFRAMES512T1023_RESETVAL (0x00000000u)

/* OCTETFRAMES1024TUP */

#define CSL_CPSW3G_OCTETFRAMES1024TUP_COUNT_MASK (0xFFFFFFFFu)
#define CSL_CPSW3G_OCTETFRAMES1024TUP_COUNT_SHIFT (0x00000000u)
#define CSL_CPSW3G_OCTETFRAMES1024TUP_COUNT_RESETVAL (0x00000000u)

#define CSL_CPSW3G_OCTETFRAMES1024TUP_RESETVAL (0x00000000u)

/* NETOCTETS */

#define CSL_CPSW3G_NETOCTETS_COUNT_MASK (0xFFFFFFFFu)
#define CSL_CPSW3G_NETOCTETS_COUNT_SHIFT (0x00000000u)
#define CSL_CPSW3G_NETOCTETS_COUNT_RESETVAL (0x00000000u)

#define CSL_CPSW3G_NETOCTETS_RESETVAL (0x00000000u)

/* RXSOFOVERRUNS */

#define CSL_CPSW3G_RXSOFOVERRUNS_COUNT_MASK (0xFFFFFFFFu)
#define CSL_CPSW3G_RXSOFOVERRUNS_COUNT_SHIFT (0x00000000u)
#define CSL_CPSW3G_RXSOFOVERRUNS_COUNT_RESETVAL (0x00000000u)

#define CSL_CPSW3G_RXSOFOVERRUNS_RESETVAL (0x00000000u)

/* RXMOFOVERRUNS */

#define CSL_CPSW3G_RXMOFOVERRUNS_COUNT_MASK (0xFFFFFFFFu)
#define CSL_CPSW3G_RXMOFOVERRUNS_COUNT_SHIFT (0x00000000u)
#define CSL_CPSW3G_RXMOFOVERRUNS_COUNT_RESETVAL (0x00000000u)

#define CSL_CPSW3G_RXMOFOVERRUNS_RESETVAL (0x00000000u)

/* RXDMAOVERRUNS */

#define CSL_CPSW3G_RXDMAOVERRUNS_COUNT_MASK (0xFFFFFFFFu)
#define CSL_CPSW3G_RXDMAOVERRUNS_COUNT_SHIFT (0x00000000u)
#define CSL_CPSW3G_RXDMAOVERRUNS_COUNT_RESETVAL (0x00000000u)

#define CSL_CPSW3G_RXDMAOVERRUNS_RESETVAL (0x00000000u)

/* ALE_IDVER */

#define CSL_CPSW3G_ALE_IDVER_ALE_IDENT_MASK (0xFFFF0000u)
#define CSL_CPSW3G_ALE_IDVER_ALE_IDENT_SHIFT (0x00000010u)
#define CSL_CPSW3G_ALE_IDVER_ALE_IDENT_RESETVAL (0x00000029u)

#define CSL_CPSW3G_ALE_IDVER_ALE_MAJ_VER_MASK (0x0000FF00u)
#define CSL_CPSW3G_ALE_IDVER_ALE_MAJ_VER_SHIFT (0x00000008u)
#define CSL_CPSW3G_ALE_IDVER_ALE_MAJ_VER_RESETVAL (0x00000001u)

#define CSL_CPSW3G_ALE_IDVER_ALE_MINOR_VER_MASK (0x000000FFu)
#define CSL_CPSW3G_ALE_IDVER_ALE_MINOR_VER_SHIFT (0x00000000u)
#define CSL_CPSW3G_ALE_IDVER_ALE_MINOR_VER_RESETVAL (0x00000001u)

#define CSL_CPSW3G_ALE_IDVER_RESETVAL (0x00290101u)

/* ALE_Control */

#define CSL_CPSW3G_ALE_CONTROL_ENABLE_ALE_MASK (0x80000000u)
#define CSL_CPSW3G_ALE_CONTROL_ENABLE_ALE_SHIFT (0x0000001Fu)
#define CSL_CPSW3G_ALE_CONTROL_ENABLE_ALE_RESETVAL (0x00000000u)
/*----enable_ale Tokens----*/
#define CSL_CPSW3G_ALE_CONTROL_ENABLE_ALE_DISABLE (0x00000000u)
#define CSL_CPSW3G_ALE_CONTROL_ENABLE_ALE_ENABLE (0x00000001u)

#define CSL_CPSW3G_ALE_CONTROL_CLEAR_TABLE_MASK (0x40000000u)
#define CSL_CPSW3G_ALE_CONTROL_CLEAR_TABLE_SHIFT (0x0000001Eu)
#define CSL_CPSW3G_ALE_CONTROL_CLEAR_TABLE_RESETVAL (0x00000000u)
/*----clear_table Tokens----*/
#define CSL_CPSW3G_ALE_CONTROL_CLEAR_TABLE_DISABLE (0x00000000u)
#define CSL_CPSW3G_ALE_CONTROL_CLEAR_TABLE_ENABLE (0x00000001u)

#define CSL_CPSW3G_ALE_CONTROL_AGE_OUT_NOW_MASK (0x20000000u)
#define CSL_CPSW3G_ALE_CONTROL_AGE_OUT_NOW_SHIFT (0x0000001Du)
#define CSL_CPSW3G_ALE_CONTROL_AGE_OUT_NOW_RESETVAL (0x00000000u)
/*----age_out_now Tokens----*/
#define CSL_CPSW3G_ALE_CONTROL_AGE_OUT_NOW_DISABLE (0x00000000u)
#define CSL_CPSW3G_ALE_CONTROL_AGE_OUT_NOW_ENABLE (0x00000001u)


#define CSL_CPSW3G_ALE_CONTROL_LEARN_NO_VID_MASK (0x00000080u)
#define CSL_CPSW3G_ALE_CONTROL_LEARN_NO_VID_SHIFT (0x00000007u)
#define CSL_CPSW3G_ALE_CONTROL_LEARN_NO_VID_RESETVAL (0x00000000u)
/*----learn_no_vid Tokens----*/
#define CSL_CPSW3G_ALE_CONTROL_LEARN_NO_VID_DISABLE (0x00000000u)
#define CSL_CPSW3G_ALE_CONTROL_LEARN_NO_VID_ENABLE (0x00000001u)

#define CSL_CPSW3G_ALE_CONTROL_EN_VID0_MODE_MASK (0x00000040u)
#define CSL_CPSW3G_ALE_CONTROL_EN_VID0_MODE_SHIFT (0x00000006u)
#define CSL_CPSW3G_ALE_CONTROL_EN_VID0_MODE_RESETVAL (0x00000000u)
/*----en_vid0_mode Tokens----*/
#define CSL_CPSW3G_ALE_CONTROL_EN_VID0_MODE_DISABLE (0x00000000u)
#define CSL_CPSW3G_ALE_CONTROL_EN_VID0_MODE_ENABLE (0x00000001u)

#define CSL_CPSW3G_ALE_CONTROL_ENABLE_OUI_DENY_MASK (0x00000020u)
#define CSL_CPSW3G_ALE_CONTROL_ENABLE_OUI_DENY_SHIFT (0x00000005u)
#define CSL_CPSW3G_ALE_CONTROL_ENABLE_OUI_DENY_RESETVAL (0x00000000u)
/*----enable_oui_deny Tokens----*/
#define CSL_CPSW3G_ALE_CONTROL_ENABLE_OUI_DENY_DISABLE (0x00000000u)
#define CSL_CPSW3G_ALE_CONTROL_ENABLE_OUI_DENY_ENABLE (0x00000001u)

#define CSL_CPSW3G_ALE_CONTROL_ALE_BYPASS_MASK (0x00000010u)
#define CSL_CPSW3G_ALE_CONTROL_ALE_BYPASS_SHIFT (0x00000004u)
#define CSL_CPSW3G_ALE_CONTROL_ALE_BYPASS_RESETVAL (0x00000000u)
/*----ale_bypass Tokens----*/
#define CSL_CPSW3G_ALE_CONTROL_ALE_BYPASS_DISABLE (0x00000000u)
#define CSL_CPSW3G_ALE_CONTROL_ALE_BYPASS_ENABLE (0x00000001u)

#define CSL_CPSW3G_ALE_CONTROL_RATE_LIMIT_TX_MASK (0x00000008u)
#define CSL_CPSW3G_ALE_CONTROL_RATE_LIMIT_TX_SHIFT (0x00000003u)
#define CSL_CPSW3G_ALE_CONTROL_RATE_LIMIT_TX_RESETVAL (0x00000000u)
/*----rate_limit_tx Tokens----*/
#define CSL_CPSW3G_ALE_CONTROL_RATE_LIMIT_TX_DISABLE (0x00000000u)
#define CSL_CPSW3G_ALE_CONTROL_RATE_LIMIT_TX_ENABLE (0x00000001u)

#define CSL_CPSW3G_ALE_CONTROL_ALE_VLAN_AWARE_MASK (0x00000004u)
#define CSL_CPSW3G_ALE_CONTROL_ALE_VLAN_AWARE_SHIFT (0x00000002u)
#define CSL_CPSW3G_ALE_CONTROL_ALE_VLAN_AWARE_RESETVAL (0x00000000u)
/*----ale_vlan_aware Tokens----*/
#define CSL_CPSW3G_ALE_CONTROL_ALE_VLAN_AWARE_DISABLE (0x00000000u)
#define CSL_CPSW3G_ALE_CONTROL_ALE_VLAN_AWARE_ENABLE (0x00000001u)

#define CSL_CPSW3G_ALE_CONTROL_ENABLE_AUTH_MODE_MASK (0x00000002u)
#define CSL_CPSW3G_ALE_CONTROL_ENABLE_AUTH_MODE_SHIFT (0x00000001u)
#define CSL_CPSW3G_ALE_CONTROL_ENABLE_AUTH_MODE_RESETVAL (0x00000000u)
/*----enable_auth_mode Tokens----*/
#define CSL_CPSW3G_ALE_CONTROL_ENABLE_AUTH_MODE_DISABLE (0x00000000u)
#define CSL_CPSW3G_ALE_CONTROL_ENABLE_AUTH_MODE_ENABLE (0x00000001u)

#define CSL_CPSW3G_ALE_CONTROL_ENABLE_RATE_LIMIT_MASK (0x00000001u)
#define CSL_CPSW3G_ALE_CONTROL_ENABLE_RATE_LIMIT_SHIFT (0x00000000u)
#define CSL_CPSW3G_ALE_CONTROL_ENABLE_RATE_LIMIT_RESETVAL (0x00000000u)
/*----enable_rate_limit Tokens----*/
#define CSL_CPSW3G_ALE_CONTROL_ENABLE_RATE_LIMIT_DISABLE (0x00000000u)
#define CSL_CPSW3G_ALE_CONTROL_ENABLE_RATE_LIMIT_ENABLE (0x00000001u)

#define CSL_CPSW3G_ALE_CONTROL_RESETVAL (0x00000000u)

/* ALE_Prescale */


#define CSL_CPSW3G_ALE_PRESCALE_ALE_PRESCALE_MASK (0x000FFFFFu)
#define CSL_CPSW3G_ALE_PRESCALE_ALE_PRESCALE_SHIFT (0x00000000u)
#define CSL_CPSW3G_ALE_PRESCALE_ALE_PRESCALE_RESETVAL (0x00000000u)

#define CSL_CPSW3G_ALE_PRESCALE_RESETVAL (0x00000000u)

/* ALE_Unknown_VLAN */


#define CSL_CPSW3G_ALE_UNKNOWN_VLAN_UNKNOWN_FORCE_UNTAGGED_EGRESS_MASK (0x07000000u)
#define CSL_CPSW3G_ALE_UNKNOWN_VLAN_UNKNOWN_FORCE_UNTAGGED_EGRESS_SHIFT (0x00000018u)
#define CSL_CPSW3G_ALE_UNKNOWN_VLAN_UNKNOWN_FORCE_UNTAGGED_EGRESS_RESETVAL (0x00000000u)


#define CSL_CPSW3G_ALE_UNKNOWN_VLAN_UNKNOWN_REG_MCAST_FLOOD_MASK_MASK (0x00070000u)
#define CSL_CPSW3G_ALE_UNKNOWN_VLAN_UNKNOWN_REG_MCAST_FLOOD_MASK_SHIFT (0x00000010u)
#define CSL_CPSW3G_ALE_UNKNOWN_VLAN_UNKNOWN_REG_MCAST_FLOOD_MASK_RESETVAL (0x00000000u)


#define CSL_CPSW3G_ALE_UNKNOWN_VLAN_UNKNOWN_MCAST_FLOOD_MASK_MASK (0x00000700u)
#define CSL_CPSW3G_ALE_UNKNOWN_VLAN_UNKNOWN_MCAST_FLOOD_MASK_SHIFT (0x00000008u)
#define CSL_CPSW3G_ALE_UNKNOWN_VLAN_UNKNOWN_MCAST_FLOOD_MASK_RESETVAL (0x00000000u)


#define CSL_CPSW3G_ALE_UNKNOWN_VLAN_UNKNOWN_VLAN_MEMBER_LIST_MASK (0x00000007u)
#define CSL_CPSW3G_ALE_UNKNOWN_VLAN_UNKNOWN_VLAN_MEMBER_LIST_SHIFT (0x00000000u)
#define CSL_CPSW3G_ALE_UNKNOWN_VLAN_UNKNOWN_VLAN_MEMBER_LIST_RESETVAL (0x00000000u)

#define CSL_CPSW3G_ALE_UNKNOWN_VLAN_RESETVAL (0x00000000u)

/* ALE_TBLCTL */

#define CSL_CPSW3G_ALE_TBLCTL_WRITE_RDZ_MASK (0x80000000u)
#define CSL_CPSW3G_ALE_TBLCTL_WRITE_RDZ_SHIFT (0x0000001Fu)
#define CSL_CPSW3G_ALE_TBLCTL_WRITE_RDZ_RESETVAL (0x00000000u)


#define CSL_CPSW3G_ALE_TBLCTL_ENTRY_POINTER_MASK (0x000003FFu)
#define CSL_CPSW3G_ALE_TBLCTL_ENTRY_POINTER_SHIFT (0x00000000u)
#define CSL_CPSW3G_ALE_TBLCTL_ENTRY_POINTER_RESETVAL (0x00000000u)

#define CSL_CPSW3G_ALE_TBLCTL_RESETVAL (0x00000000u)

/* ALE_TBLW2 */


#define CSL_CPSW3G_ALE_TBLW2_ENTRY_MASK (0x0000000Fu)
#define CSL_CPSW3G_ALE_TBLW2_ENTRY_SHIFT (0x00000000u)
#define CSL_CPSW3G_ALE_TBLW2_ENTRY_RESETVAL (0x00000000u)

#define CSL_CPSW3G_ALE_TBLW2_RESETVAL (0x00000000u)

/* ALE_TBLW1 */

#define CSL_CPSW3G_ALE_TBLW1_ENTRY_MASK (0xFFFFFFFFu)
#define CSL_CPSW3G_ALE_TBLW1_ENTRY_SHIFT (0x00000000u)
#define CSL_CPSW3G_ALE_TBLW1_ENTRY_RESETVAL (0x00000000u)

#define CSL_CPSW3G_ALE_TBLW1_RESETVAL (0x00000000u)

/* ALE_TBLW0 */

#define CSL_CPSW3G_ALE_TBLW0_ENTRY_MASK (0xFFFFFFFFu)
#define CSL_CPSW3G_ALE_TBLW0_ENTRY_SHIFT (0x00000000u)
#define CSL_CPSW3G_ALE_TBLW0_ENTRY_RESETVAL (0x00000000u)

#define CSL_CPSW3G_ALE_TBLW0_RESETVAL (0x00000000u)

/* ALE_PORTCTL */

#define CSL_CPSW3G_ALE_PORTCTL_BCAST_LIMIT_MASK (0xFF000000u)
#define CSL_CPSW3G_ALE_PORTCTL_BCAST_LIMIT_SHIFT (0x00000018u)
#define CSL_CPSW3G_ALE_PORTCTL_BCAST_LIMIT_RESETVAL (0x00000000u)

#define CSL_CPSW3G_ALE_PORTCTL_MCAST_LIMIT_MASK (0x00FF0000u)
#define CSL_CPSW3G_ALE_PORTCTL_MCAST_LIMIT_SHIFT (0x00000010u)
#define CSL_CPSW3G_ALE_PORTCTL_MCAST_LIMIT_RESETVAL (0x00000000u)


#define CSL_CPSW3G_ALE_PORTCTL_NO_LEARN_MASK (0x00000010u)
#define CSL_CPSW3G_ALE_PORTCTL_NO_LEARN_SHIFT (0x00000004u)
#define CSL_CPSW3G_ALE_PORTCTL_NO_LEARN_RESETVAL (0x00000000u)

#define CSL_CPSW3G_ALE_PORTCTL_VID_INGRESS_CHECK_MASK (0x00000008u)
#define CSL_CPSW3G_ALE_PORTCTL_VID_INGRESS_CHECK_SHIFT (0x00000003u)
#define CSL_CPSW3G_ALE_PORTCTL_VID_INGRESS_CHECK_RESETVAL (0x00000000u)

#define CSL_CPSW3G_ALE_PORTCTL_DROP_UNTAGGED_MASK (0x00000004u)
#define CSL_CPSW3G_ALE_PORTCTL_DROP_UNTAGGED_SHIFT (0x00000002u)
#define CSL_CPSW3G_ALE_PORTCTL_DROP_UNTAGGED_RESETVAL (0x00000000u)

#define CSL_CPSW3G_ALE_PORTCTL_PORT_STATE_MASK (0x00000003u)
#define CSL_CPSW3G_ALE_PORTCTL_PORT_STATE_SHIFT (0x00000000u)
#define CSL_CPSW3G_ALE_PORTCTL_PORT_STATE_RESETVAL (0x00000000u)
/*----port_state Tokens----*/
#define CSL_CPSW3G_ALE_PORTCTL_PORT_STATE_DISABLE (0x00000000u)
#define CSL_CPSW3G_ALE_PORTCTL_PORT_STATE_BLOCK (0x00000001u)
#define CSL_CPSW3G_ALE_PORTCTL_PORT_STATE_LEARN (0x00000002u)
#define CSL_CPSW3G_ALE_PORTCTL_PORT_STATE_FORWARD (0x00000003u)

#define CSL_CPSW3G_ALE_PORTCTL_RESETVAL (0x00000000u)

#endif
