/*******************************************************************************
**+--------------------------------------------------------------------------+**
**|                            ****                                          |**
**|                            ****                                          |**
**|                            ******o***                                    |**
**|                      ********_///_****                                   |**
**|                      ***** /_//_/ ****                                   |**
**|                       ** ** (__/ ****                                    |**
**|                           *********                                      |**
**|                            ****                                          |**
**|                            ***                                           |**
**|                                                                          |**
**|         Copyright (c) 1998-2006 Texas Instruments Incorporated           |**
**|                        ALL RIGHTS RESERVED                               |**
**|                                                                          |**
**| Permission is hereby granted to licensees of Texas Instruments           |**
**| Incorporated (TI) products to use this computer program for the sole     |**
**| purpose of implementing a licensee product based on TI products.         |**
**| No other rights to reproduce, use, or disseminate this computer          |**
**| program, whether in part or in whole, are granted.                       |**
**|                                                                          |**
**| TI makes no representation or warranties with respect to the             |**
**| performance of this computer program, and specifically disclaims         |**
**| any responsibility for any damages, special or consequential,            |**
**| connected with the use of this program.                                  |**
**|                                                                          |**
**+--------------------------------------------------------------------------+**
*******************************************************************************/

/** \file   pal_sysvlynq.c
 *
 *  \brief  This file contains the PAL SYS driver API's for the VLYNQ.
 *
 *  (C) Copyright 2006, Texas Instruments, Inc
 *
 *  \author     Suraj
 *  \version    0.3
 *  \author     0.4 modified for DM6437
 *
 */

#include <ti/sdo/pspdrivers/pal_sys/vlynq/src/pal_sysvlynqOs.h>
#include <ti/sdo/pspdrivers/pal_sys/vlynq/pal_sysvlynqDev.h>
#include <ti/sdo/pspdrivers/pal_sys/vlynq/pal_sysvlynqIoctl.h>
#include <ti/sdo/pspdrivers/pal_os/pal_osProtect.h>
#include <ti/sdo/pspdrivers/pal_os/pal_oswait.h>

#ifdef CHIP_DM6437
#include <ti/sdo/pspdrivers/soc/dm6437/dsp/soc.h>
#include <ti/sdo/pspdrivers/soc/dm6437/dsp/cslr_vlynq.h>
#endif

#ifdef CHIP_C6424
#include <ti/sdo/pspdrivers/soc/c6424/dsp/soc.h>
#include <ti/sdo/pspdrivers/soc/c6424/dsp/cslr_vlynq.h>
#endif

#ifdef CHIP_DM648
#include <ti/sdo/pspdrivers/soc/dm648/dsp/soc.h>
#include <ti/sdo/pspdrivers/soc/dm648/dsp/cslr_vlynq.h>
#endif

#ifdef CHIP_C6452
#include <ti/sdo/pspdrivers/soc/c6452/dsp/soc.h>
#include <ti/sdo/pspdrivers/soc/c6452/dsp/cslr_vlynq.h>
#endif

#ifdef VLYNQ_INSTRUMENTATION_ENABLED
    #include <ti/sdo/pspdrivers/pal_os/bios/psp_log.h>
#endif /*I2C_INSTRUMENTATION_ENABLED*/

/**< Interrupt vector offset  */
#define VLYNQ_IVEC_OFFSET(line)         ((line)*8u)
/**< Interrupt vector polling bit map  */
#define VLYNQ_IVEC_POL_BIT_MAP          (1 << 5)
/**< Interrupt vector polling bit mask  */
#define VLYNQ_IVEC_POL_MASK(line)       (VLYNQ_IVEC_POL_BIT_MAP << ((line)*8u))
/**< Interrupt vector polling bit value  */
#define VLYNQ_IVEC_POL_VAL(val)         (((val) & 0x1u) << 5)
/**< Interrupt vector polling bit deinitialize value  */
#define VLYNQ_IVEC_POL_DE_VAL(val)      (((val) >>  5) & 1u)
/**< Interrupt vector IRQ bit map  */
#define VLYNQ_IVEC_IRQ_BIT_MAP          (0x1f)
/**< Interrupt vector IRQ bit mask  */
#define VLYNQ_IVEC_IRQ_MASK(line)       (VLYNQ_IVEC_IRQ_BIT_MAP << ((line)*8u))
/**< Interrupt vector IRQ bit value  */
#define VLYNQ_IVEC_IRQ_VAL(val)         ((val) & 0x1fu)
/**< Interrupt vector IRQ bit deinitaliza value  */
#define VLYNQ_IVEC_IRQ_DE_VAL(val)      ((val) & 0x1fu)
/**< Interrupt vector type bit map  */
#define VLYNQ_IVEC_TYPE_BIT_MAP         (1 << 6)
/**< Interrupt vector type bit mask  */
#define VLYNQ_IVEC_TYPE_MASK(line)      (VLYNQ_IVEC_TYPE_BIT_MAP << ((line)*8u))
/**< Interrupt vector type bit value */
#define VLYNQ_IVEC_TYPE_VAL(val)        (((val) & 0x1u) << 6)
/**< Interrupt vector type bit De - value  */
#define VLYNQ_IVEC_TYPE_DE_VAL(val)     (((val) >>  6) & 1)
/**< Interrupt vector enable bit map  */
#define VLYNQ_IVEC_EN_BIT_MAP           (1 << 7)
/**< Interrupt vector enable bit mask  */
#define VLYNQ_IVEC_EN_MASK(line)        (VLYNQ_IVEC_EN_BIT_MAP << ((line)*8))
/**< Interrupt vector enable bit value  */
#define VLYNQ_IVEC_EN_VAL(val)          (((val) & 0x1) << 7)
/**< Interrupt vector enable bit de - value  */
#define VLYNQ_IVEC_EN_DE_VAL(val)       (((val) >> 7) & 1)
/**< Interrupt vector Hw line adjust bit   */
#define VLYNQ_IVEC_HW_LINE_ADJUST(line) (((line) > 3) ? (line) - 4u: (line))

/**< Return the base address of the local vlynq */
#define LOCAL_REGS(p) (VLYNQ_REG_T*)((p)->base)
/**< Return the base address of the remote vlynq.*/
#ifndef VLYNQ_LOOPBACK_MODE
#define PEER_REGS(p)  ((VLYNQ_REG_T*)(((p)->base) + 0x80u))
#else
#define PEER_REGS(p)  (VLYNQ_REG_T*)((p)->base)
#endif
/**< Max ISR information                                 */
#define MAX_NUM_ISR             (TYPICAL_NUM_ISR_PER_IRQ*MAX_IRQ_PER_CHAIN)

/**< Enable RTM macro                  */
#define RTM_ENABLE_BIT          0x1u
/**<  RTM sample mask value            */
#define RTM_SAMPLE_VAL_MASK     0x7u
/**<  RTM force written value          */
#define RTM_FORCE_VAL_WR        0x1u
/**< RTM status  bit                   */
#define RTM_STATUS_BIT          0x1u
/**<    Tx fast path                   */
#define TX_FAST_PATH            0x1u

/*Defines for errors*/
#define VLYNQ_STS_LERR         0x80u
#define VLYNQ_STS_RERR         0x100u
#define VLYNQ_STS_LERR_RERR    0x180u

/*Defines for clock bits in the control register*/
#define VLYNQ_CTL_CLKDIR       15u
#define VLYNQ_CTL_CLKDIV       16u
#define VLYNQ_CTL_INT_CLK_BITS 0x7F80u

/*Defines for bit settings for clock direction and division*/
#define VLYNQ_CLKDIR_IN         0x1u
#define VLYNQ_CLKDIV_MAX        0x7u

/**< Extern Decleration */
/* extern PAL_VLYNQ_HND       * p_vlynq;*/
extern Int32 vlynq_dev_dump_dev(PAL_VLYNQ_DEV_HND *vlynq_dev, Char *buf,
                                Int32 limit, Int32 *eof);
extern Int32 vlynq_dump_ioctl (volatile Uint32 *start_reg, Uint32 dump_type,
                                Char *buf, Int32 limit, Uint32 vlynq_rev);

Bool vlynq_swap_hack;

static PAL_VLYNQ_T *free_pal_vlynq_list = NULL;
static PAL_VLYNQ_T *root_pal_vlynq[MAX_ROOT_VLYNQ];
static PAL_VLYNQ_T *vlynq_get_free_vlynq(void);
static PAL_Result vlynq_isr_info_init(void);
static PAL_VLYNQ_ISR_INFO_T* vlynq_get_free_isr_info(void);
static void         vlynq_free_vlynq(PAL_VLYNQ_T * p_vlynq_vlynq);
static Bool vlynq_detect_link_status(PAL_VLYNQ_T * p_vlynq_link);
static PAL_VLYNQ_T *irq_swap_map[MAX_IRQ_PER_CHAIN];


/**< free_vlynq_isr_info_list is of type PAL_VLYNQ_ISR_INFO_T
  *         and initialized with NULL   */
static PAL_VLYNQ_ISR_INFO_T *free_vlynq_isr_info_list = NULL;


/**
 * \brief ISR Information: Takes care of user's drivers and error handling
 *
 */
typedef Int32 (*PAL_VLYNQ_INTERN_ISR_FN)(PAL_VLYNQ_T*);


/**
 * \brief  Structure holds the information of internal vlynq ISR.
 */
typedef struct pal_vlynq_intern_isr_info_t
{
    PAL_VLYNQ_INTERN_ISR_FN            isr;
    /**< Points to the vlynq internal isr and is of type PAL_VLYNQ_INTERN_ISR_FN   */
    PAL_VLYNQ_T                        *vlynq;
    /**< Pointer to the vlynq object.    */

} PAL_VLYNQ_INTERN_ISR_INFO_T;

/**
 * \brief  Structure holds the information of vlynq device ISR.
 */
typedef struct pal_vlynq_dev_isr_info_t
{
    PAL_VLYNQ_DEV_ISR_FN             isr;
    /**< Points to the vlynq device isr and is of type PAL_VLYNQ_DEV_ISR_FN    */
    PAL_VLYNQ_DEV_ISR_PARAM_GRP_T    * isr_param;
     /**<  Pointer to the device ISR parameters   */

} PAL_VLYNQ_DEV_ISR_INFO_T;

/**
 * \brief  Structure holds the information of all vlynq ISR's.
 */
struct pal_vlynq_isr_info_t
{
    /**
     * \brief  Can have either device ISR or VLYNQ ISR
     */
    union one_of_isr_info_t
    {
        /**< Device ISR information*/
        PAL_VLYNQ_DEV_ISR_INFO_T    dev_isr_info;
        /**< Internal ISR information*/
        PAL_VLYNQ_INTERN_ISR_INFO_T intern_isr_info;

    } one_of_isr_info;

    struct pal_vlynq_isr_info_t     * next;
    /**<  Pointer to next vlynq ISR information     */
    Int8                            irq_type;
    /**<  Type of IRQ device/internal               */

};




/**
  * \brief Initialize Vlynq param
  */
static void vlynq_param_init(PAL_VLYNQ_T * p_vlynq_init)
{
    Int32 j;

    if(p_vlynq_init != NULL)
    {
        for(j = 0; j < MAX_DEV_PER_VLYNQ; j++)
        {
            p_vlynq_init->local_dev[j] = NULL;
            p_vlynq_init->peer_dev[j]  = NULL;
        }

        for(j = 0; j < MAX_VLYNQ_REGION; j++)
        {
            p_vlynq_init->local_region_info[j].owner_dev_index  = (Int8) -1;
            p_vlynq_init->remote_region_info[j].owner_dev_index = (Int8) -1;
        }

        p_vlynq_init->local_isr_info            = NULL;
        p_vlynq_init->peer_isr_info             = NULL;
        p_vlynq_init->root_irq_map              = NULL;
        p_vlynq_init->root_irq_info             = NULL;
        p_vlynq_init->prev                      = NULL;
        p_vlynq_init->next                      = NULL;
        p_vlynq_init->local_swap                = False;
        p_vlynq_init->peer_swap                 = False;
        p_vlynq_init->base                      = 0;
        p_vlynq_init->soc                       = False;    /*VLYNQ module is not on the SOC*/
        p_vlynq_init->vlynq_version             = 0;
        p_vlynq_init->timeout_ms                = 0;
        p_vlynq_init->backup_local_cntl_word    = 0;
        p_vlynq_init->backup_local_intr_ptr     = 0;
        p_vlynq_init->backup_local_tx_map       = 0;
        p_vlynq_init->backup_local_endian       = 0;
        p_vlynq_init->backup_peer_cntl_word     = 0;
        p_vlynq_init->backup_peer_intr_ptr      = 0;
        p_vlynq_init->backup_peer_tx_map        = 0;
        p_vlynq_init->backup_peer_endian        = 0;
        p_vlynq_init->local_irq                 = 1;       /*Local irq is set to 1 as both local and peer cannot have
                                                        same value      */
        p_vlynq_init->peer_irq                  = 0;
    }
}
/*
 *  This function initializes the vlynq list and root vlynq list
 *
 *  Input:
 *          void
 *  Return:
 *          PAL_VLYNQ_OK on success
  */
static PAL_Result vlynq_init(void)
{
    static PAL_VLYNQ_T pal_vlynq[MAX_VLYNQ_COUNT];
    Uint32 root_count       = 0, i;

    /*Form the free vlynq list*/
    for(i = 0 ; i < MAX_VLYNQ_COUNT; i++)
    {
        vlynq_param_init(&(pal_vlynq[i]));
        (pal_vlynq[i]).next       = free_pal_vlynq_list;
        free_pal_vlynq_list = &pal_vlynq[i];
    }

    while(root_count < MAX_ROOT_VLYNQ){
        root_pal_vlynq[root_count++] = NULL;
    }

    for( i = 0; i < MAX_IRQ_PER_CHAIN; i++){
        irq_swap_map[i] = NULL;
    }
    return (PAL_VLYNQ_OK);
}

/*
 *  This function adds the vlynq to the vlynq root list
 *
 *  Input:
 *         p_vlynq_root   [IN]  Handle to the vlynq structure to be added to the list
 *  Return:
 *          PAL_VLYNQ_OK on success;   else failure
 */
static PAL_Result vlynq_add_root( PAL_VLYNQ_T * p_vlynq_root)
{
    Int32 i;
    PAL_Result ret = PAL_VLYNQ_OK;
    if(NULL == p_vlynq_root){
        ret = PAL_VLYNQ_INTERNAL_ERROR;
    }
    else{
        for(i = 0; i < MAX_ROOT_VLYNQ; i++)
        {
            if(NULL == root_pal_vlynq[i])
            {
                root_pal_vlynq[i] = p_vlynq_root;
                break;
            }
        }
    }
    return (ret);
}

/*
 *  This function removes the structure passed from the list of root.
 *
 *  Input:
 *         p_vlynq_remove   [IN]  Handle to the vlynq structure which is to be removed from the root
 *  Return:
 *          PAL_VLYNQ_OK on success; else failure
 */
static PAL_Result vlynq_remove_root( const PAL_VLYNQ_T *p_vlynq_remove)
{
    Int32 i;
    PAL_Result ret = PAL_VLYNQ_INTERNAL_ERROR;
    if(NULL != p_vlynq_remove)
    {
        for(i = 0; i < MAX_ROOT_VLYNQ; i++)
        {
            if(NULL != root_pal_vlynq[i])
            {
                if(root_pal_vlynq[i] == p_vlynq_remove)
                {
                    ret = PAL_VLYNQ_OK;
                    root_pal_vlynq[i] = NULL;
                    break;
                }
            }
        }
    }

    return (ret);
}

/*
 *  This function gets a free vlynq from the free list of vlynq
 *
 *  Input:
 *          void
 *  Return:
 *          Returns handle to the free vlynq
 */
static PAL_VLYNQ_T* vlynq_get_free_vlynq(void)
{
    PAL_VLYNQ_T * p_vlynq_free = free_pal_vlynq_list;

    if(NULL != p_vlynq_free)
    {
        free_pal_vlynq_list = free_pal_vlynq_list->next;
        p_vlynq_free->next = NULL;
    }

    return (p_vlynq_free);
}

/*
 *  This function frees the vlynq and hence adds it to the free vlynq list
 *
 *  Input:
 *         p_vlynq   [IN]  Handle to the vlynq structure which is to be free
 *  Return:
 *         void
 */

static void vlynq_free_vlynq(PAL_VLYNQ_T * p_vlynq_vlynq)
{
    if(NULL != p_vlynq_vlynq)
    {
        vlynq_param_init(p_vlynq_vlynq);
        p_vlynq_vlynq->next       = free_pal_vlynq_list;
        free_pal_vlynq_list = p_vlynq_vlynq;
    }
}

/*
 *  This function finds the root of the vlynq handle passed by traversing the link
 *
 *  Input:
 *         p_vlynq_find   [IN]  Handle to the vlynq structure whose root is to be found
 *  Return:
 *         Returns the pointer to the root vlynq if found else NULL
 */
static PAL_VLYNQ_T *vlynq_find_root_vlynq(PAL_VLYNQ_T * p_vlynq_find)
{
    if(p_vlynq_find == NULL){
        return NULL;
    }
    while(NULL != p_vlynq_find->prev){
        p_vlynq_find = p_vlynq_find->prev;
    }
    return (p_vlynq_find->soc ? p_vlynq_find : NULL);
}

/*
 *  This function finds the index where the device instance is and whether it is peer or local
 *
 *  Input:
 *         p_vlynq_index   [IN]  Handle to the vlynq
 *         vlynq_dev       [IN]  Device instance
 *         peer            [OUT] returns if the device is peer or not
 *         index           [OUT] returns the index number on the device array
 *  Return:
 *          PAL_VLYNQ_OK on success; else failure
  */
static Bool vlynq_find_dev_index(const PAL_VLYNQ_T * p_vlynq_index, const PAL_VLYNQ_DEV_HND * vlynq_dev,
        Bool * peer, Int32 * index)
{
    Int32           dev_index      = 0;
    Int32           ret_val        = True;

    if( (NULL != p_vlynq_index ) || (NULL != vlynq_dev) ){
        while(dev_index < MAX_DEV_PER_VLYNQ)
        {
            if(p_vlynq_index->peer_dev[dev_index] == vlynq_dev)
            {
                ret_val = False;
                * peer   = 1; /* True */
            }
            if((ret_val != 0) && (p_vlynq_index->local_dev[dev_index] == vlynq_dev))
            {
                ret_val = False;
                * peer   = 0; /* False */
            }
            if (ret_val == False)
            {
                break;
            }
            dev_index++;
        }
        *index = dev_index;
    }
    return (ret_val);
}

/******************************************************************************
 * Interrupts galore: data structures and private functions.
 ******************************************************************************/
 /**
   * \brief Interrupts galore: data structures and private functions.
   */
#if (PAL_VLYNQ_DEV_ISR_PARM_NUM == 0)
#define PAL_VLYNQ_DEV_ISR_SIGNATURE (p)
#elif (PAL_VLYNQ_DEV_ISR_PARM_NUM == 1)
#define PAL_VLYNQ_DEV_ISR_SIGNATURE(p) (p)->arg1
#elif (PAL_VLYNQ_DEV_ISR_PARM_NUM == 2)
#define PAL_VLYNQ_DEV_ISR_SIGNATURE(p) (p)->arg1, (p)->arg2
#elif (PAL_VLYNQ_DEV_ISR_PARM_NUM == 3)
#define PAL_VLYNQ_DEV_ISR_SIGNATURE(p) (p)->arg1, (p)->arg2, (p)->arg3
#elif (PAL_VLYNQ_DEV_ISR_PARM_NUM == 4)
#define PAL_VLYNQ_DEV_ISR_SIGNATURE(p) (p)->arg1, (p)->arg2, (p)->arg3, (p)->arg4
#elif (PAL_VLYNQ_DEV_ISR_PARM_NUM == 5)
#define PAL_VLYNQ_DEV_ISR_SIGNATURE(p) (p)->arg1, (p)->arg2, (p)->arg3, (p)->arg4, (p)->arg5
#elif (PAL_VLYNQ_DEV_ISR_PARM_NUM == 6)
#define PAL_VLYNQ_DEV_ISR_SIGNATURE(p) (p)->arg1, (p)->arg2, (p)->arg3, (p)->arg4, (p)->arg5, \
                                   (p)->arg6
#elif (PAL_VLYNQ_DEV_ISR_PARM_NUM == 7)
#define PAL_VLYNQ_DEV_ISR_SIGNATURE(p) (p)->arg1, (p)->arg2, (p)->arg3, (p)->arg4, (p)->arg5, \
                                   (p)->arg6, (p)->arg7
#elif (PAL_VLYNQ_DEV_ISR_PARM_NUM == 8)
#define PAL_VLYNQ_DEV_ISR_SIGNATURE(p) (p)->arg1, (p)->arg2, (p)->arg3, (p)->arg4, (p)->arg5, \
                                   (p)->arg6, (p)->arg7, (p)->arg8
#elif (PAL_VLYNQ_DEV_ISR_PARM_NUM == 9)
#define PAL_VLYNQ_DEV_ISR_SIGNATURE(p) (p)->arg1, (p)->arg2, (p)->arg3, (p)->arg4, (p)->arg5, \
                                   (p)->arg6, (p)->arg7, (p)->arg8, (p)->arg9
#elif (PAL_VLYNQ_DEV_ISR_PARM_NUM == 10)
#define PAL_VLYNQ_DEV_ISR_SIGNATURE(p) (p)->arg1, (p)->arg2, (p)->arg3, (p)->arg4, (p)->arg5, \
                                   (p)->arg6, (p)->arg7, (p)->arg8, (p)->arg9, (p)->arg10
#else
#error "Please define the number of parameters in the ISR for the OS."
#endif

/*------------------------------------------------------------------------------
 * Endian Private functions.
 *----------------------------------------------------------------------------*/
 /*
 * Interprets the IRQ to the indented value as dispatched by the peer vlynq,
 * overcoming the endian mismatch.
 */
Uint8 irq_val_swap[ ] = { 24, 25, 26, 27, 28, 29, 30, 31,
                          16, 17, 18, 19, 20, 21, 22, 23,
                           8,  9, 10, 11, 12, 13, 14, 15,
                           0,  1,  2,  3,  4,  5,  6,  7 };
/*
 *  This function performs the byte wise swap of the value passed
 *
 *  Input:
 *         val   [IN]  The value to be swapped
 *  Return:
 *          Returns the swapped value
 */
Uint32 vlynq_endian_swap(Uint32 val)
{
    return ((val << 24) | (val >> 24) | ((val >> 8) & 0xff00u) | ((val << 8) & 0xff0000u));
}

/*
 *  This function finds whether the value needs to be swaped before storage
 *
 *  Input:
 *         p_vlynq_need   [IN]  Handle to the vlynq structure which has to be checked
 *         peer           [IN]  whether peer or not
 *  Return:
 *          PAL_VLYNQ_OK on success; else failure
 */
static Bool need_swap(const PAL_VLYNQ_T * p_vlynq_need, Bool peer)
{
    Bool ret_val = False;
    if(NULL != p_vlynq_need)
    {
        if((p_vlynq_need->peer_swap == True) && (peer != FALSE)){
            ret_val = True;
        }
        else if((p_vlynq_need->local_swap == True) && (FALSE == peer)){
            ret_val = True;
        }
        else{
            ret_val = False;
        }
    }
    return ret_val;
}

/*
 *  This function writes the value to the stated register
 *
 *  Input:
 *         p_vlynq_wr[IN]  Handle to the vlynq structure
 *         peer      [IN]  Whether peer or not
 *         reg_addr  [IN]  Address where value is to be written
 *         val       [IN]  Value to be written
 *  Return:
 *          void
  */
void vlynq_wr_reg(const PAL_VLYNQ_T * p_vlynq_wr, Bool peer, volatile Uint32 *reg_addr, Uint32 val)
{
    if(TRUE == need_swap(p_vlynq_wr, peer)){
        val = vlynq_endian_swap(val);
    }
    *reg_addr = val;
}

/*
 *  This function reads the value of the stated register
 *
 *  Input:
 *         p_vlynq_rd[IN]  Handle to the vlynq structure
 *         peer      [IN]  Whether peer or not
 *         reg_addr  [IN]  Address where value is to be written
 *  Return:
 *          Returns value read
 */
Uint32 vlynq_rd_reg(const PAL_VLYNQ_T * p_vlynq_rd, Bool peer, volatile const Uint32 *reg_addr)
{
    Uint32 val = 0;
    if(NULL != reg_addr)
    {
         val = *reg_addr;
        if(TRUE == need_swap(p_vlynq_rd, peer))
        {
        val = vlynq_endian_swap(val);
        }
    }
    return (val);
}



/**
  * \brief Vlynq isr initailazation info
  */
static PAL_Result vlynq_isr_info_init(void)
{
    PAL_VLYNQ_ISR_INFO_T * p_isr_info = NULL;
    Int32 i = 0;
    static PAL_VLYNQ_ISR_INFO_T vlynq_isr_info[MAX_NUM_ISR];

    for(i = 0; i < MAX_NUM_ISR; i++)
    {
        p_isr_info               = &vlynq_isr_info[i];
        if( p_isr_info != NULL) {
            p_isr_info->one_of_isr_info.dev_isr_info.isr        = NULL;
            p_isr_info->one_of_isr_info.dev_isr_info.isr_param  = NULL;

            p_isr_info->irq_type     = (Int8) -1;
            p_isr_info->next         = free_vlynq_isr_info_list;
            free_vlynq_isr_info_list = p_isr_info;
        }
    }

    return (PAL_VLYNQ_OK);
}

/*
 *  This function gets free ISR information from list
 *
 *  Input:
 *        void
 *  Return:
 *        Returns PAL_VLYNQ_ISR_INFO_T free isr information
 */
static PAL_VLYNQ_ISR_INFO_T* vlynq_get_free_isr_info(void)
{
    PAL_VLYNQ_ISR_INFO_T * p_isr_info = free_vlynq_isr_info_list;

    if(NULL != p_isr_info)
    {
        free_vlynq_isr_info_list = free_vlynq_isr_info_list->next;
        p_isr_info->next         = NULL;
    }

    return (p_isr_info);
}

/*
 *  This functions free ISR information
 *
 *  Input:
 *        p_isr_info    ISR information to make free
 *  Return:
 *        Returns PAL_VLYNQ_ISR_INFO_T free isr information
 */
static void vlynq_free_isr_info(PAL_VLYNQ_ISR_INFO_T * p_isr_info)
{
    if(NULL != p_isr_info)
    {
        p_isr_info->irq_type     = (Int8) -1;
        p_isr_info->next         = free_vlynq_isr_info_list;

        p_isr_info->one_of_isr_info.dev_isr_info.isr        = NULL;
        p_isr_info->one_of_isr_info.dev_isr_info.isr_param  = NULL;

        free_vlynq_isr_info_list = p_isr_info;
    }
}

/*-----------------------------------------------------------------------------
 * IRQ Information. House keeping and maintains information for multiple ISR(s).
 *---------------------------------------------------------------------------*/

/**
 * \brief  Holds the IRQ ISR's information.
 */
struct pal_vlynq_irq_info_t
{
    PAL_VLYNQ_ISR_INFO_T  * isr_info;
    /**< Holds the ISR information with the IRQ map     */
    Uint32                count;
    /**<  Count of IRQ's      */
};

/**
 * \brief  Irq information list.
 */
typedef struct pal_vlynq_irq_info_list_t
{
    PAL_VLYNQ_IRQ_INFO_T                 irq_info[MAX_IRQ_PER_CHAIN];
    /**<  Max no of IRQ's per chain of type PAL_VLYNQ_IRQ_INFO_T     */
    struct pal_vlynq_irq_info_list_t     * next;
    /**< Holds the pointer to next node in IRQ info list      */

} PAL_VLYNQ_IRQ_INFO_LIST_T;

/**< Start node initiallized to NULL                        */
static PAL_VLYNQ_IRQ_INFO_LIST_T * free_vlynq_irq_info_list = NULL;

/*
 *  This function initializes the irq list
 *
 *  Input:
 *          void
 *  Return:
 *          0 on success; else failure
 */
static PAL_Result vlynq_irq_info_init(void)
{
    PAL_VLYNQ_IRQ_INFO_LIST_T * p_irq_info_list = NULL;
    PAL_VLYNQ_IRQ_INFO_T      * p_irq_info = NULL;
    Int32 i, j = 0;
    /**< Static irq info list array for max no. of root vlynq.*/
    static PAL_VLYNQ_IRQ_INFO_LIST_T  vlynq_irq_info_list[MAX_ROOT_VLYNQ];

    for(i = 0; i < MAX_ROOT_VLYNQ; i++)
    {
        p_irq_info_list  = &vlynq_irq_info_list[i];
        if (p_irq_info_list != NULL)
        {
            p_irq_info       = (PAL_VLYNQ_IRQ_INFO_T* ) p_irq_info_list;

            for(j = 0; j < MAX_IRQ_PER_CHAIN; j++)
            {
                p_irq_info->isr_info = NULL;
                p_irq_info->count    = 0; /* what about irq. ? */
                p_irq_info++;
            }
            p_irq_info_list->next    = free_vlynq_irq_info_list;
            free_vlynq_irq_info_list = p_irq_info_list;
        }
    }
    return (PAL_VLYNQ_OK);
}

/*
 *  This function gives a free irq from the list
 *
 *  Input:
 *          void
 *  Return:
 *          pointer to a free irq from the list
 */
static PAL_VLYNQ_IRQ_INFO_T * vlynq_get_free_irq_info(void)
{
    PAL_VLYNQ_IRQ_INFO_LIST_T * p_irq_info_list = free_vlynq_irq_info_list;

    if(NULL != p_irq_info_list)
    {
        free_vlynq_irq_info_list = free_vlynq_irq_info_list->next;
        p_irq_info_list->next    = NULL;
    }

    return ((PAL_VLYNQ_IRQ_INFO_T* )p_irq_info_list);
}
/*
 *  This function frees the irq info passed to it and adds it to the list
 *
 *  Input:
 *          p_irq_info  [IN]  irq to be freed
 *  Return:
 *          void
 */

static void vlynq_free_irq_info(PAL_VLYNQ_IRQ_INFO_T *p_irq_info)
{
    PAL_VLYNQ_IRQ_INFO_LIST_T *p_irq_info_list =
        (PAL_VLYNQ_IRQ_INFO_LIST_T*)p_irq_info;
    Int32 i =0;
    if(p_irq_info_list != NULL){
        for(i = 0; i < MAX_IRQ_PER_CHAIN; i++)
        {
            p_irq_info->isr_info = NULL;
            p_irq_info->count    = 0;
            p_irq_info++;
        }
        p_irq_info_list->next    = free_vlynq_irq_info_list;
        free_vlynq_irq_info_list = p_irq_info_list;
    }
    return;
}

/*-----------------------------------------------------------------------------
 * IRQ Mapping: maps hw line to irq.
 *---------------------------------------------------------------------------*/
 /**
  * \brief  Holds information of IRQ map.
  */
struct pal_vlynq_irq_map_t
{
    PAL_VLYNQ_T             *vlynq;
   /**< Object of the VLYNQ for which mapping has to be done     */
    Int8                    hw_intr_line;
   /**<  Hardware line number which has to be mapped            */
    Bool                    peer;
    /**< IRQ map information is for peer/local                  */
};

 /**
  * \brief  Holds information of all IRQ map nodes in list.
  */
typedef struct pal_vlynq_irq_map_list_t
{
     PAL_VLYNQ_IRQ_MAP_T                  irq_map[MAX_IRQ_PER_CHAIN];
    /**< Max no of IRQ's per chain                              */
    struct pal_vlynq_irq_map_list_t      *next;
     /**<  Holds the pointer to next node in map list           */

} PAL_VLYNQ_IRQ_MAP_LIST_T;

/**< Node initiallized to NULL                  */
static PAL_VLYNQ_IRQ_MAP_LIST_T  *free_vlynq_irq_map_list = NULL;

/*
 *  This function initializes a map for the IRQ
 *
 *  Input:
 *          void
 *  Return:
 *          PAL_VLYNQ_OK on success, else failure
 */
static PAL_Result vlynq_irq_map_init(void)
{
    PAL_VLYNQ_IRQ_MAP_LIST_T *p_irq_map_list = NULL;
    PAL_VLYNQ_IRQ_MAP_T      *p_irq_map = NULL;
    Int32 i,j = 0;
    /**< Static irq map list array for max no. of root vlynq.*/
    static PAL_VLYNQ_IRQ_MAP_LIST_T  vlynq_irq_map_list[MAX_ROOT_VLYNQ];

    for(i = 0; i < MAX_ROOT_VLYNQ; i++)
    {
        p_irq_map_list  = &vlynq_irq_map_list[i];
        if(p_irq_map_list != NULL) {
            p_irq_map       = (PAL_VLYNQ_IRQ_MAP_T*) p_irq_map_list;
            for(j = 0; j < MAX_IRQ_PER_CHAIN; j++)
            {
                p_irq_map->vlynq        = NULL;
                p_irq_map->hw_intr_line = (Int8) -1;
                p_irq_map++;
            }
            p_irq_map_list->next    = free_vlynq_irq_map_list;
            free_vlynq_irq_map_list = p_irq_map_list;
        }
    }
    return (PAL_VLYNQ_OK);
}

/*
 *  This function gives a free irq map from the list
 *
 *  Input:
 *          void
 *  Return:
 *          pointer to a free irq map from the list
 */

static PAL_VLYNQ_IRQ_MAP_T* vlynq_get_free_irq_map(void)
{
    PAL_VLYNQ_IRQ_MAP_LIST_T * p_irq_map_list = free_vlynq_irq_map_list;

    if(NULL != p_irq_map_list)
    {
        free_vlynq_irq_map_list = free_vlynq_irq_map_list->next;
        p_irq_map_list->next    = NULL;
    }

    return ((PAL_VLYNQ_IRQ_MAP_T* )p_irq_map_list);
}
/*
 *  This function frees irq and adds to the list
 *
 *  Input:
 *          p_irq_map  [IN] irq map to be freed and added to the list
 *  Return:
 *          void
 */

static void vlynq_free_irq_map(PAL_VLYNQ_IRQ_MAP_T * p_irq_map)
{
    PAL_VLYNQ_IRQ_MAP_LIST_T * p_irq_map_list =
        (PAL_VLYNQ_IRQ_MAP_LIST_T* )p_irq_map;
    Int32 i = 0;

    if(p_irq_map_list != NULL){
        for(i = 0; i < MAX_IRQ_PER_CHAIN; i++)
        {
            p_irq_map->vlynq         = NULL;
            p_irq_map->hw_intr_line  = (Int8) -1;
            p_irq_map++;
        }

        p_irq_map_list->next    = free_vlynq_irq_map_list;
        free_vlynq_irq_map_list = p_irq_map_list;
    }

    return;
}
/*
 *  This function checks if the hw line is already mapped or is available
 *
 *  Input:
 *          p_vlynq_map  [IN] vlynq instance
 *          irq          [IN] check the map for this irq
 *  Return:
 *          null if line free, else returns pointer to the irq map
 */

static PAL_VLYNQ_IRQ_MAP_T* vlynq_get_map_for_irq(PAL_VLYNQ_T * p_vlynq_map, Uint8 irq)
{
    PAL_VLYNQ_IRQ_MAP_T * p_irq_map = NULL;
    PAL_VLYNQ_T         * p_root_vlynq = NULL ;

    if(NULL != p_vlynq_map)
    {
        p_root_vlynq = vlynq_find_root_vlynq(p_vlynq_map);

        if((NULL != p_root_vlynq) && (NULL != p_root_vlynq->root_irq_map))
        {
            p_irq_map = irq + p_root_vlynq->root_irq_map ;

        }
    }
    return (p_irq_map);
}
/**
 * \brief   Initialize the VLYNQ control module.
 *
 * \return   Success or failure error code
 */

PAL_Result PAL_sysVlynqInit(void)
{
    vlynq_isr_info_init();
    vlynq_irq_info_init();
    vlynq_irq_map_init();
    vlynq_init();
    pal_vlynq_dev_init();

    return (PAL_VLYNQ_OK);
}

/*
 *  This function allows to add an isr to the irq passed
 *
 *  Input:
 *          p_root_vlynq  [IN]  handle to the root vlynq
 *          irq           [IN]  irq to which the isr info is to be added
 *          p_isr_info    [IN]  isr info to be added
 *  Return:
 *          PAL_VLYNQ_OK on success; else failure
 */
static PAL_Result vlynq_add_intern_isr(const PAL_VLYNQ_T * p_root_vlynq, Uint8 irq,
                                       PAL_VLYNQ_ISR_INFO_T * p_isr_info)
{
    PAL_VLYNQ_IRQ_INFO_T * p_irq_info = NULL;
    PAL_Result retval = PAL_VLYNQ_INVALID_PARAM;

    if(( p_root_vlynq != NULL) ||(NULL != p_isr_info))
    {
        p_irq_info = p_root_vlynq->root_irq_info;
        if( p_irq_info != NULL)
        {
            p_irq_info += irq;
            p_isr_info->next     = p_irq_info->isr_info;
            p_irq_info->isr_info = p_isr_info;
            retval = PAL_VLYNQ_OK;
        }
    }
    return (retval);
}

/*
 *  This function allows to remove an isr to the irq passed
 *
 *  Input:
 *          p_root_vlynq  [IN]  handle to the root vlynq
 *          irq           [IN]  irq to which the isr info is to be removed
 *          p_isr_info    [IN]  isr info to be removed
 *  Return:
 *          PAL_VLYNQ_OK on success; else failure
 */
static PAL_Result vlynq_remove_intern_isr(const PAL_VLYNQ_T *p_root_vlynq, Uint8 irq,
        PAL_VLYNQ_ISR_INFO_T *isr_info)
{
    PAL_VLYNQ_IRQ_INFO_T *p_irq_info      = NULL;
    PAL_VLYNQ_ISR_INFO_T *p_isr_info      = NULL;
    PAL_VLYNQ_ISR_INFO_T *p_last_isr_info = NULL;
    PAL_Result           ret_val          = PAL_VLYNQ_INTERNAL_ERROR;

    if(NULL == p_root_vlynq)
    {
        ret_val = PAL_VLYNQ_INTERNAL_ERROR;
    }
    else
    {
         if( (NULL != isr_info) && (p_root_vlynq->root_irq_info != NULL))
        {
            p_irq_info = p_root_vlynq->root_irq_info + irq;
            p_isr_info = p_irq_info->isr_info;

            for(; p_isr_info != NULL; p_isr_info = p_isr_info->next)
            {
                if(p_isr_info == isr_info)
                {
                    if(NULL == p_last_isr_info)
                    {
                        p_irq_info->isr_info  = p_isr_info->next;
                    }
                    else{
                        p_last_isr_info->next = p_isr_info->next;
                    }
                    ret_val = PAL_VLYNQ_OK;
                    break;
                }
                p_last_isr_info = p_isr_info;
            }
        }
    }
    return (ret_val);
}


/**
 * \brief   Add the device reference into VLYNQ
 *
 *
 * \param   vlynq               [IN]    Handle to the opened Resource Manager
 *
 * \param   vlynq_dev           [IN]    The device instance, which has to be added into the VLYNQ.
 *                                      This value would have been returned by PAL_sysVlynqDevCreate().
 * \param   peer                [IN]    The flag whether the device is associated with the local
 *                                      VLYNQ or the peer.
 *
 * \return                              PAL_VLYNQ_OK on success , -1 on failure.
 *
 */
PAL_Result PAL_sysVlynqAddDevice(PAL_VLYNQ_HND * vlynq, PAL_VLYNQ_DEV_HND * vlynq_dev,
        Bool peer)
{
    PAL_VLYNQ_T     * p_vlynq_add_dev       = (PAL_VLYNQ_T* ) vlynq;
    Int32           dev_count      = MAX_DEV_PER_VLYNQ;
    PAL_Result      ret_val        = PAL_VLYNQ_INTERNAL_ERROR;
    PAL_VLYNQ_DEV_HND * * pp_vlynq_dev = NULL;

    if((vlynq == NULL) || ((vlynq_dev == NULL) || (p_vlynq_add_dev == NULL)))
    {
        ret_val = PAL_VLYNQ_INVALID_PARAM ;
    } else {

        pp_vlynq_dev = (PAL_VLYNQ_DEV_HND* * )
                       (peer ? &p_vlynq_add_dev->peer_dev : &p_vlynq_add_dev->local_dev);
        if(pp_vlynq_dev != NULL)
        {
            while(dev_count--)
            {
                if(NULL == (* pp_vlynq_dev))
                {
                    * pp_vlynq_dev = (PAL_VLYNQ_DEV_HND* ) vlynq_dev;
                      ret_val       = PAL_VLYNQ_OK;
                    break;
                }
                else{
                    pp_vlynq_dev++;
                }
            }
        }
    }
    return (ret_val);
}

/**
 * \brief   Removes the device reference from VLYNQ.
 *
 *
 * \param   vlynq               [IN]    The VLYNQ module instance, from
 *                                      which the device instance has to be removed.
 *
 * \param   vlynq_dev           [IN]    The device instance, which is to be removed from the VLYNQ.
 *
 * \return  PAL_VLYNQ_OK on success.,-1 on failure.
 */
PAL_Result PAL_sysVlynqRemoveDevice( PAL_VLYNQ_HND * vlynq, const PAL_VLYNQ_DEV_HND * vlynq_dev)
{
    PAL_VLYNQ_T     * p_vlynq_dev       = (PAL_VLYNQ_T* ) vlynq;
    PAL_Result      ret_val        = PAL_VLYNQ_OK;
    Bool            peer = False;
    Int32           index = 0;

    PAL_VLYNQ_DEV_HND * * pp_vlynq_dev = NULL;

    if((vlynq == NULL) || ((vlynq_dev == NULL) || (p_vlynq_dev == NULL) ) )
    {
        ret_val = PAL_VLYNQ_INVALID_PARAM ;
    }
    else if(TRUE == vlynq_find_dev_index(p_vlynq_dev, vlynq_dev, &peer, &index))
    {
        ret_val = PAL_VLYNQ_INTERNAL_ERROR ;
    } else {
        pp_vlynq_dev = (PAL_VLYNQ_DEV_HND * * )
                       (peer ? &p_vlynq_dev->peer_dev : &p_vlynq_dev->local_dev);
        if(pp_vlynq_dev != NULL)
        {
            pp_vlynq_dev[index] = NULL ;
        }
    }
    return (ret_val);
}


/**
 * \brief   UnMap the memory regions of the device.
 *
 *
 * \param   vlynq               [IN]    The VLYNQ instance, on which previously mapped
 *                                      regions have to be un-mapped.
 * \param   remote              [IN]    Identifies whether the region
 *                                      to be mapped is on remote/peer or local VLYNQ.
 * \param   region_id           [IN]    Identifier of the RX region; valid values are from 0 to 3.
 * \param   vlynq_dev           [IN]    The device instance for which certain
 *                                      regions have been previously mapped; and now are being un-mapped.
 *
 * \return                               0 on success.,-1 on failure.
 */
PAL_Result PAL_sysVlynqUnMapRegion(PAL_VLYNQ_HND * vlynq, Bool remote, Uint32 region_id,
        PAL_VLYNQ_DEV_HND * vlynq_dev)
{
    PAL_VLYNQ_DEV_HND *p_vlynq_dev = vlynq_dev;
    PAL_VLYNQ_T       *p_vlynq_unmap     = vlynq;
    PAL_Result        ret_val = PAL_VLYNQ_OK;

    Bool                    peer = False;
    Int32                   index = 0;
    PAL_VLYNQ_REGION_INFO_T *p_region = NULL;
    PAL_VLYNQ_REGION_INFO_T *p_local_region = NULL;
    PAL_VLYNQ_REGION_INFO_T *p_remote_region = NULL;
    VLYNQ_RX_REG_T          *p_rx_reg = NULL;
    VLYNQ_REG_T             *p_remote_reg = NULL;
    VLYNQ_REG_T             *p_local_reg = NULL;

    if((p_vlynq_dev == NULL) || (p_vlynq_unmap == NULL)){
        ret_val = (PAL_VLYNQ_INVALID_PARAM);

    }
    else if(TRUE == vlynq_find_dev_index(p_vlynq_unmap, p_vlynq_dev, &peer, &index))
    {
        ret_val = (PAL_VLYNQ_INTERNAL_ERROR);

    }
    else if(region_id >= MAX_VLYNQ_REGION)
    {
        ret_val =  (PAL_VLYNQ_INVALID_PARAM);
    }else {

        p_local_region  = p_vlynq_unmap->local_region_info  + region_id;
        p_remote_region = p_vlynq_unmap->remote_region_info + region_id;

        p_local_reg     = LOCAL_REGS(p_vlynq_unmap);

        /* To configure Peer register check the status of link */
        if(FALSE == vlynq_detect_link_status(p_vlynq_unmap))
        {
            ret_val =  PAL_VLYNQ_NO_LINK;
        }
        else
        {
        p_remote_reg    = PEER_REGS(p_vlynq_unmap);

        if((p_local_reg == NULL) || (p_remote_reg == NULL))
        {
            ret_val =  (PAL_VLYNQ_INVALID_PARAM);
        }
        if((p_local_region == NULL) || (p_remote_region == NULL))
        {
            ret_val =  (PAL_VLYNQ_INVALID_PARAM);
        }

   /**
     * local vlynq <----------------bus/remoteness--------------> peer vlynq
     *
     * Interpretation has to be made in the perspective of the device and its
     * location i.e. association of the device with the local vlynq or peer
     * vlynq.
     *
     * A true value for 'remote' means that a device wants to export the
     * local memory to other devices, otherwise, the device intends to import
     * portion of external memory into it.
     *
     * A device connected to 'peer' vlynq exports memory region by programming
     * peer vlynq rx registers and imports memory region by programming the
     * rx registers of local vlynq.
     *
     * A device connected to local vlynq exports memory region by programming
     * local vlynq rx registers and imports memory region by programming the
     * rx registers of peer vlynq.
     *
     * Complex eh ? Yep, seems so.
     */
        if(TRUE == peer)
        {
            p_region   = remote ? p_remote_region : p_local_region;
            p_rx_reg   = remote ? p_remote_reg->rx_set : p_local_reg->rx_set;
        }
        else
        {
            p_region   = remote ? p_local_region : p_remote_region;
            p_rx_reg   = remote ? p_local_reg->rx_set : p_remote_reg->rx_set;
        }

        if(p_region->owner_dev_index == ((Int8) -1))
        {
            ret_val = (PAL_VLYNQ_INTERNAL_ERROR); /* Region Not allocated. */
        }
        else if (p_rx_reg != NULL) {
            p_rx_reg = p_rx_reg + region_id;
            p_rx_reg->size   = 0;
            p_rx_reg->offset = 0;

            p_region->owner_dev_locale = peer;
            p_region->owner_dev_index  = (Int8) -1;
            ret_val = PAL_VLYNQ_OK;
        } else {
        }
    }
    }
    return (ret_val);
}

/**
 * \brief   Map the memory regions of the device.
 *
 *
 * \param   vlynq               [IN]    The VLYNQ instance, on which previously mapped
 *                                      regions have to be un-mapped.
 * \param   remote              [IN]    Identifies whether the region
 *                                      to be mapped is on remote/peer or local VLYNQ.
 * \param   region_id           [IN]    Identifier of the RX region; valid values are from 0 to 3.
 * \param   vlynq_dev           [IN]    The device instance for which certain
 *                                      regions have been previously mapped; and now are being un-mapped.
 *
 * \return                               0 on success.,-1 on failure.
 */

PAL_Result PAL_sysVlynqMapRegion(PAL_VLYNQ_HND * vlynq, Bool remote, Uint32 region_id,
        Uint32 region_offset, Uint32 region_size,
        PAL_VLYNQ_DEV_HND * vlynq_dev)
{
    PAL_VLYNQ_DEV_HND * p_vlynq_dev = vlynq_dev;
    PAL_VLYNQ_T       * p_vlynq_map_sys     = (PAL_VLYNQ_T* ) vlynq;

    Bool                    peer = False;
    Int32                   index = 0;
    PAL_VLYNQ_REGION_INFO_T * p_region = NULL;
    PAL_VLYNQ_REGION_INFO_T * p_local_region = NULL;
    PAL_VLYNQ_REGION_INFO_T * p_remote_region = NULL;
    VLYNQ_RX_REG_T          * p_rx_reg = NULL;
    VLYNQ_REG_T             * p_remote_reg = NULL;
    VLYNQ_REG_T             * p_local_reg = NULL;
    Bool                      peer_reg_flag = False;
    PAL_Result                ret_val = PAL_VLYNQ_OK;

    if((p_vlynq_dev == NULL) || (p_vlynq_map_sys == NULL))
    {
        ret_val = PAL_VLYNQ_INVALID_PARAM;
    }
    if((vlynq_find_dev_index(p_vlynq_map_sys, p_vlynq_dev, &peer, &index) != 0)
            && (ret_val == 0))
    {
        ret_val = PAL_VLYNQ_INTERNAL_ERROR;
    }
    else if((region_id >= MAX_VLYNQ_REGION) && ( ret_val == 0))
    {
        ret_val = PAL_VLYNQ_INVALID_PARAM;
    }else{

        p_local_region  = p_vlynq_map_sys->local_region_info  + region_id;
        p_remote_region = p_vlynq_map_sys->remote_region_info + region_id;
        p_local_reg     = LOCAL_REGS(p_vlynq_map_sys);

        /* To configure Peer register check the status of link */
        if(FALSE == vlynq_detect_link_status(p_vlynq_map_sys))
        {
            ret_val = (PAL_VLYNQ_NO_LINK);
        }
        else
        {
        p_remote_reg    = PEER_REGS(p_vlynq_map_sys);
        if((p_local_reg == NULL) || (p_remote_reg == NULL)){
            ret_val =  (PAL_VLYNQ_INVALID_PARAM);
        }
        if((p_local_region == NULL) || (p_remote_region == NULL)){
            ret_val =  (PAL_VLYNQ_INVALID_PARAM);
        }

                /*
                 * local vlynq <----------------bus/remoteness--------------> peer vlynq
                 *
                 * Interpretation has to be made in the perspective of the device and its
                 * location i.e. association of the device with the local vlynq or peer
                 * vlynq.
                 *
                 * A true value for 'remote' means that a device wants to export the
                 * local memory to other devices, otherwise, the device intends to import
                 * portion of external memory into it.
                 *
                 * A device connected to 'peer' vlynq exports memory region by programming
                 * peer vlynq rx registers and imports memory region by programming the
                 * rx registers of local vlynq.
                 *
                 * A device connected to local vlynq exports memory region by programming
                 * local vlynq rx registers and imports memory region by programming the
                 * rx registers of peer vlynq.
                 *
                 * Complex eh ? Yep, seems so.
                 */
        if(TRUE == peer){
            p_region   = remote ? p_remote_region : p_local_region;
            p_rx_reg   = remote ? p_remote_reg->rx_set : p_local_reg->rx_set;
            peer_reg_flag = remote ? True : False;
        }
        else {
            p_region   = remote ? p_local_region : p_remote_region;
            p_rx_reg   = remote ? p_local_reg->rx_set : p_remote_reg->rx_set;
            peer_reg_flag = remote ? False: True;
        }
        if((p_region == NULL) || (p_rx_reg == NULL)){
            ret_val =  (PAL_VLYNQ_INVALID_PARAM);
        }
        if(p_region->owner_dev_index != -1){
            return (PAL_VLYNQ_INTERNAL_ERROR); /* Region already allocated. */
        }
        p_rx_reg = p_rx_reg + region_id;
        vlynq_wr_reg(p_vlynq_map_sys, peer_reg_flag, &p_rx_reg->size,   region_size);
        vlynq_wr_reg(p_vlynq_map_sys, peer_reg_flag, &p_rx_reg->offset, region_offset);

        p_region->owner_dev_locale = peer;
        p_region->owner_dev_index  = (Int8)index;
    }
    }
    return (ret_val);
}

/**
 * brief   Get the physical  base address of the device.
 *
 *
 * param   vlynq       [IN]    The instance on which the physical base address
 *                              is being sought.
 * param  offset       [IN]    The offset (in bytes) into the remote device
 *                              memory map.
 * param  base_addr    [IN]    The placeholder for the evaluated physical base
 *                              address of the remote device in the context of
 *                              the root SOC. The caller manages the memory
 *                              for this.
 * param   vlynq_dev   [IN]    The handle to remote device instance; would
 *                              have been returned by PAL_sysVlynqDevFind( ).
 *                              The offset is being sought for this device.
 *
 * return  PAL_VLYNQ_OK on success.,negative on failure.
 */

static PAL_Result vlynq_calculate_base_addr(PAL_VLYNQ_T * p_vlynq_base, Uint32 offset,
                                            Uint32 * base_addr, Uint32 index)
{
    VLYNQ_REG_T    * p_local_reg = NULL;
    VLYNQ_REG_T    * p_vlynq_reg = NULL;
    VLYNQ_RX_REG_T * p_rx_reg    = NULL;
    Uint32 i, size               = 0;
    Int32 offset_diff            = 0;
    PAL_Result     retCode       =  PAL_VLYNQ_OK;

    if((NULL != p_vlynq_base) && (NULL != base_addr))
    {
        p_local_reg = LOCAL_REGS(p_vlynq_base);
        /* To configure Peer register check the status of link */
        if(FALSE == vlynq_detect_link_status(p_vlynq_base))
        {
            return (PAL_VLYNQ_NO_LINK);
        }
        p_vlynq_reg = PEER_REGS(p_vlynq_base);
        p_rx_reg    = p_vlynq_reg->rx_set;

        index = index;
        for(i = 0; i < MAX_VLYNQ_REGION; i++)
        {
            offset_diff = (Int32)(offset - vlynq_rd_reg(p_vlynq_base, True,
                                                        &p_rx_reg[i].offset));

            if(offset_diff < 0)
            {
                retCode = PAL_VLYNQ_INTERNAL_ERROR;
            }
            if(offset_diff <= vlynq_rd_reg(p_vlynq_base, True, &p_rx_reg[i].size))
            {
                *base_addr = (Uint32)offset_diff +
                                     size +
                                     vlynq_rd_reg(  p_vlynq_base, False,
                                                    &p_local_reg->txMap);
                break;
            }
            size += vlynq_rd_reg(p_vlynq_base, True, &p_rx_reg[i].size);
        }
    }
    else {
            retCode = PAL_VLYNQ_INTERNAL_ERROR;
    }
    return (retCode);
}

/**
 * \brief   find device and Get the physical  base address of the device.
 *
 *
 * \param   vlynq       [IN]    The instance on which the physical base address
 *                              is being sought.
 * \param  offset       [IN]    The offset (in bytes) into the remote device
 *                              memory map.
 * \param  base_addr    [out]    The placeholder for the evaluated physical base
 *                              address of the remote device in the context of
 *                              the root SOC. The caller manages the memory
 *                              for this.
 * \param   vlynq_dev   [IN]    The handle to remote device instance; would
 *                              have been returned by PAL_sysVlynqDevFind( ).
 *                              The offset is being sought for this device.
 *
 * \return  PAL_VLYNQ_OK on success.,negative on failure.
 */
PAL_Result PAL_sysVlynqGetDevBase(PAL_VLYNQ_HND     * vlynq,
        Uint32            offset,
        Uint32            * base_addr,
        PAL_VLYNQ_DEV_HND * vlynq_dev)
{
    PAL_VLYNQ_DEV_HND        * p_vlynq_dev = vlynq_dev;
    PAL_VLYNQ_T              * p_vlynq_devbase     = vlynq;
    Int32                    index = 0;
    Bool                     peer = False;
    Int32                    ret_val = PAL_VLYNQ_OK;

    if(((NULL == p_vlynq_devbase )|| (NULL == p_vlynq_dev)) || (NULL == base_addr)) {
        ret_val = PAL_VLYNQ_INVALID_PARAM;
    }
    else{
        if( (vlynq_find_dev_index(p_vlynq_devbase, p_vlynq_dev, &peer, &index)
            != 0) && ( ret_val == 0) ) {
            ret_val = PAL_VLYNQ_INTERNAL_ERROR;
        }
         /*
         * Not sure why would one require to calculate base address for the
         * device which is not associated with the peer VLYNQ.
         */

            /* Let us now calculate the base address back up to the root. */
            while((p_vlynq_devbase != NULL) && (ret_val == 0))
            {
                ret_val = vlynq_calculate_base_addr(p_vlynq_devbase,
                                                    offset, base_addr,
                                                    (Uint32)index);
                if(ret_val != 0){
                    break;
                }
                offset  = * base_addr;
                p_vlynq_devbase = p_vlynq_devbase->prev;
            }

     }
    return (ret_val);
}

/******************************************************************************
 * VLYNQ Configuration API(s): Private ones.
 *****************************************************************************/
/*
 *  This function gets the right register for interrupt vectors and pointer to
 *  hw line
 *
 *  Input:
 *          p_vlynq_param   [IN]    handle to the vlynq
 *          irq             [IN]    irq to which the hw line is to be added
 *          p_reg           [OUT]   Interrupt vector register
 *          p_hw_intr_line  [OUT]   Pointer to the hw line from the irqmap
 *  Return:
 *          PAL_VLYNQ_OK on success; else failure
  */
static PAL_Result vlynq_validate_param_and_find_ivr_info(
        PAL_VLYNQ_T * p_vlynq_param,
        Uint32 irq,
        volatile Uint32 * * p_reg,
        Uint8  * p_hw_intr_line)
{
    PAL_VLYNQ_IRQ_MAP_T   * p_irq_map = NULL;
    VLYNQ_REG_T           * p_vlynq_reg = NULL;
    Int32       ret_val = PAL_VLYNQ_OK;

    if(((NULL == p_vlynq_param) || (p_reg == NULL)) || (p_hw_intr_line == NULL))
    {
        ret_val = PAL_VLYNQ_INVALID_PARAM;
    }
    else
    {
        if((irq >= MAX_DEV_PER_VLYNQ*MAX_IRQ_PER_VLYNQ) && (ret_val == 0) )
        {
            ret_val = PAL_VLYNQ_INVALID_PARAM;

        }
        else
         {

            p_irq_map = vlynq_get_map_for_irq(p_vlynq_param, (Uint8)irq);
            if(p_irq_map == NULL)
            {
                ret_val = PAL_VLYNQ_INTERNAL_ERROR;
            }
            else
            {
                /* To configure Peer register check the status of link */
                if(FALSE == vlynq_detect_link_status(p_vlynq_param))
             {
                    return (PAL_VLYNQ_NO_LINK);
                }

                p_vlynq_reg    = (p_irq_map->peer == True) ?
                                    PEER_REGS(p_vlynq_param):
                                 LOCAL_REGS(p_vlynq_param);
                if(NULL != p_vlynq_reg )
                {
                    *p_hw_intr_line = (Uint8)p_irq_map->hw_intr_line;
                    *p_reg          = (p_irq_map->hw_intr_line < 4u) ? &p_vlynq_reg->ivr30 :
                        &p_vlynq_reg->ivr74;
                }
                else
                {
                    ret_val = PAL_VLYNQ_INTERNAL_ERROR;
                }
             }
          }
        }
    return (ret_val);
}
/*
 *  brief   This function is called for local error and it clears the interrupts after processing routines
 *          and give call to the event to handle error
 *  param   p_vlynq_local   [IN]    Local vlynq module
 * return   success if call to event gets success
 *          error code else
 */

static PAL_Result vlynq_root_isr_local_error(PAL_VLYNQ_T * p_vlynq_local)
{
    PAL_Result          ret_val = PAL_VLYNQ_OK;
    volatile Uint32     val = 0;
    Int32               i = 0;

    if(NULL != p_vlynq_local )
    {
        VLYNQ_REG_T * p_reg    = LOCAL_REGS(p_vlynq_local);
        PAL_VLYNQ_DEV_HND * * pp_dev  = p_vlynq_local->local_dev;
        if(NULL != pp_dev)
        {
            val    = vlynq_rd_reg(p_vlynq_local, False, &p_reg->status);
            i    = 0;
            val |= VLYNQ_STS_LERR;
            vlynq_wr_reg(p_vlynq_local, False, &p_reg->status, val);

            while(i++ < MAX_DEV_PER_VLYNQ){
                pal_vlynq_dev_handle_event(* pp_dev++, PAL_VLYNQ_EVENT_LOCAL_ERROR, val);
            }
        }
    } else{
        ret_val = PAL_VLYNQ_INVALID_PARAM;
    }
    return (ret_val);
}

/*
 *  brief   This function is called for Peer error and it clears the interrupts after processing routines
 *          and give call to the event to handle peer error
 *  param   p_vlynq_local   [IN]    Peer vlynq module
 * return   success if call to event gets success
 *          error code else
 */

static PAL_Result vlynq_root_isr_peer_error(PAL_VLYNQ_T * p_vlynq_peer)
{
    VLYNQ_REG_T         *p_reg = NULL;
    PAL_Result          retCode = PAL_VLYNQ_OK;
    PAL_VLYNQ_DEV_HND   **pp_dev = NULL ;
    volatile Uint32     val = 0;
    Int32               i = 0;

    if(p_vlynq_peer == NULL)
    {
        retCode = PAL_VLYNQ_INVALID_PARAM;
    }
    else
    {
        pp_dev = p_vlynq_peer->peer_dev;
        p_reg     = LOCAL_REGS(p_vlynq_peer);
        val = vlynq_rd_reg(p_vlynq_peer, False, &p_reg->status);
        val |= VLYNQ_STS_RERR;
        vlynq_wr_reg(p_vlynq_peer, False, &p_reg->status, val);

        while(i++ < MAX_DEV_PER_VLYNQ)
        {
            pal_vlynq_dev_handle_event(*pp_dev++, PAL_VLYNQ_EVENT_PEER_ERROR, val);
        }
    }
    return (retCode);
}

/**
 *  \brief  This function checks whether the parameters passed in initialization
 *          configuration are valid to not
 *
 *  Input:
 *          pal_vlynq_config  [IN]  The configuration parameters which have to be validated
 *  Return:
 *          0 on success; else failure
 */
static PAL_Result vlynq_validate_init_params(const PAL_VLYNQ_CONFIG_T *pal_vlynq_config)
{
    Int32     ret_val = 0;
    if(pal_vlynq_config == NULL)
    {
        ret_val = PAL_VLYNQ_INVALID_PARAM;
    }
    else{
#ifndef VLYNQ_LOOPBACK_MODE
        /* Both peers of the VLYNQ bridge can not be sourcing. */
        if((pal_vlynq_config->local_clock_dir  == pal_vlynq_clk_out) &&
                (pal_vlynq_config->peer_clock_dir   == pal_vlynq_clk_out)){
            ret_val = PAL_VLYNQ_INVALID_PARAM;
        }
#endif
        /* We can not accept zero divisors. */
        if((pal_vlynq_config->local_clock_div == 0) ||
                (pal_vlynq_config->peer_clock_div  == 0)){
            ret_val = PAL_VLYNQ_INVALID_PARAM;
        }
        /* This vlynq has to handle irqs locally and peer should
         * be sending the irq to the local VLYNQ. */
        if((pal_vlynq_config->local_intr_local== 0) &&
                (pal_vlynq_config->peer_intr_local == 0 )){
            ret_val = PAL_VLYNQ_INVALID_PARAM;
        }
        /* Non-on chip VLYNQ(s) have to write to a specific
         * register to get the interrupts to the root vlynq. */
        if((pal_vlynq_config->on_soc != 0) &&
                (0 == (pal_vlynq_config->local_int2cfg))){
            ret_val = PAL_VLYNQ_INVALID_PARAM;
        }
        /* Validate the clock divisor values. */
        if((pal_vlynq_config->local_clock_div > VLYNQ_CLKDIV_MAX)||
                (pal_vlynq_config->peer_clock_div > VLYNQ_CLKDIV_MAX)){
            ret_val = PAL_VLYNQ_INVALID_PARAM;
        }
        /* Validate the interrupt vector values. */
        if((pal_vlynq_config->local_intr_vector >= MAX_IRQ_PER_CHAIN) ||
                (pal_vlynq_config->peer_intr_vector >= MAX_IRQ_PER_CHAIN)) {
            ret_val = PAL_VLYNQ_INVALID_PARAM;
        }
    }
    return (ret_val);
}

volatile Int vlynq_delay_value_new = 0;

/**
  * \brief This function allows to add a delay to the module
 *
 *  Input:
 *          count     [IN]  the number of cycles that have to be spent for delay
 *  Return:
 *          void
 */
void vlynq_delay_wait(Uint32 count)
{
    /* Code adopted from original vlynq driver */
    Int             i = 0;
    volatile Int    *ptr = &vlynq_delay_value_new;
    if(ptr == NULL){
        return;
    }
    *ptr = 0;

    /* We are assuming that the each cycle takes about
     * 23 assembly instructions. */
    for(i = 0; i < ((count + 23u)/23u); i++)
    {
        *ptr = *ptr + 1u;
    }
    return;
}


/*
 *  This function reads the status register and returns the link status
 *
 *  Input:
 *          p_vlynq_link [IN]   handle to the vlynq
 *  Return:
 *          1 on success; 0 on failure
 */
static Bool vlynq_detect_link_status(PAL_VLYNQ_T * p_vlynq_link)
{
    Bool link_status = False;
    VLYNQ_REG_T * p_reg = NULL;

    if(NULL != p_vlynq_link)
    {
      p_reg = LOCAL_REGS(p_vlynq_link);
      link_status = (vlynq_rd_reg(p_vlynq_link, False, &p_reg->status) & 0x1u) ? True: False;
    }
    return (link_status);
}


/*
 *  This function traverses through the chain to check whether link is established throughout
 *
 *  Input:
 *          p_vlynq_chain  [IN] Handle to vlynq
 *  Return:
 *          1 on success; 0 on failure
 */

static Bool vlynq_touch_vlynq_through_chain(PAL_VLYNQ_T * p_vlynq_chain)
{
    /*
     * We need to go back to the root vlynq to ensure that the link exists
     * from the root to the vlynq under consideration i.e. p_vlynq.
     *
     * If we find any of the intermediate links as failed, then we cannot
     * access the p_vlynq and we return that the link is down.
     *
     * This shall avoid a possible system hang.
     */

    PAL_VLYNQ_T * p_temp_vlynq = NULL;
    Bool link_status = False;

    if(NULL !=  p_vlynq_chain )
    {
        p_temp_vlynq   = vlynq_find_root_vlynq(p_vlynq_chain);
        while(NULL != p_temp_vlynq)
        {
            if(p_temp_vlynq == p_vlynq_chain)
            {
                link_status = vlynq_detect_link_status(p_vlynq_chain);
                break;
            }
            p_temp_vlynq = p_temp_vlynq->next;
        }
    }
    return (link_status);
}


/*
 *  get the status of link
 *
 *  Input:
 *          vlynq  [IN] Handle to vlynq
 *  Return:
 *          1 on success; 0 on failure
 */
Bool PAL_sysVlynqGetLinkStatus(PAL_VLYNQ_HND * vlynq)
{
    Bool ret_val = False;
    if(NULL != vlynq)
    {
        ret_val = vlynq_touch_vlynq_through_chain((PAL_VLYNQ_T* )vlynq);
    }
    return (ret_val);
}

/*
 *  configuration and bridge of endianess betwee local and peer
 *
 *  Input:
 *          vlynq  [IN] Handle to vlynq
 *  Return:
 *          1 on success; 0 on failure
 */

/**<  The Endian Register is removed for DM6437 LC
The functionality is still there to support endianess for
other SoC. Define INCLUDE_ENDIAN_REGISTER to support it */

#ifdef INCLUDE_ENDIAN_REGISTER
static PAL_Result vlynq_config_bridge_endianness(PAL_VLYNQ_T * p_vlynq_config,
        PAL_VLYNQ_ENDIAN_ENUM_T local_endianness,
        PAL_VLYNQ_ENDIAN_ENUM_T peer_endianness)
{
    PAL_Result retCode = PAL_VLYNQ_OK;
    /* The following implementation has been hacked for 1350, the correct state
     * ment should be (... < 0x00010205) instead (... <= 0x00010206). */
    if(NULL == p_vlynq_config)
    {
        retCode = PAL_VLYNQ_INVALID_PARAM;
    }
    else
    {
    VLYNQ_REG_T * p_reg = LOCAL_REGS(p_vlynq_config);

        if( (vlynq_rd_reg(p_vlynq_config, False, &p_reg->revision) >= VLYNQ_REV_10200) &&
              (vlynq_rd_reg(p_vlynq_config, False, &p_reg->revision) <= LATEST_VLYNQ_REV))
        {
            if(TRUE == local_endianness)
            {
                p_reg->endian = (Uint32)local_endianness;
            }
        }

    /* To configure Peer register check the status of link */
    if(FALSE == vlynq_detect_link_status(p_vlynq_config))
    {
        return (PAL_VLYNQ_NO_LINK);
    }

    p_reg = PEER_REGS(p_vlynq_config);
    if( ( (vlynq_rd_reg(p_vlynq_config, True, &p_reg->revision) >= VLYNQ_REV_10200) &&
        (vlynq_rd_reg(p_vlynq_config, True, &p_reg->revision) <= LATEST_VLYNQ_REV) ) &&
         (FALSE != peer_endianness))
    {
        p_reg->endian = (Uint32)peer_endianness;
    }

    if(local_endianness != peer_endianness)
    {
        p_vlynq_config->peer_swap = (p_vlynq_config->peer_swap == True) ? False : True;
    }
    }

    return (retCode);
}
#endif
/** \breif  This function finds the default clock direction input/output
 *
 *  Input:
 *          p_vlynq_clock  [IN] handle to the root vlynq
 *  Return:
 *          PAL_VLYNQ_OK on success; else failure
 */
static PAL_Result vlynq_enable_HW_default_clock(PAL_VLYNQ_T * p_vlynq_clock)
{
    VLYNQ_REG_T *p_vlynq_reg = NULL;
    Uint32      val = 0;
    Uint32      clk_div = 0;
    Int32       ret_val = PAL_VLYNQ_INTERNAL_ERROR;
    /*
     * The intent here is to find the default clock directions. The qualifying
     * factor for the default clock directions would be the link detection.
     */
    if(p_vlynq_clock == NULL)
    {
        return (ret_val);
    }
    p_vlynq_reg = LOCAL_REGS(p_vlynq_clock);
    val         = vlynq_rd_reg(p_vlynq_clock, False, &p_vlynq_reg->control);
    /* Set the clock direction to be in sink mode. */
    val &= (~CSL_VLYNQ_CTRL_CLKDIR_MASK);
    val &= (~(VLYNQ_CLKDIV_MAX << CSL_VLYNQ_CTRL_CLKDIV_SHIFT));
    vlynq_wr_reg(p_vlynq_clock, False, &p_vlynq_reg->control, val);
    vlynq_delay_wait(0xffffffU);

    /* To configure Peer register check the status of link */
    if(TRUE == vlynq_detect_link_status(p_vlynq_clock))
    {
        ret_val = PAL_VLYNQ_OK; /* Yes, we have the link. */
    }else{

        /* So, we did not find default clock direction as yet. Let us set the clock
         * in the source mode.
         */
        for(clk_div = 1U; clk_div < 9u; clk_div++)
        {
            val  = vlynq_rd_reg(p_vlynq_clock, False, &p_vlynq_reg->control);
            val |=  (VLYNQ_CLKDIR_IN << CSL_VLYNQ_CTRL_CLKDIR_SHIFT);
            val &= ~(VLYNQ_CLKDIV_MAX << CSL_VLYNQ_CTRL_CLKDIV_SHIFT);
            val |=  ((clk_div - 1u) << CSL_VLYNQ_CTRL_CLKDIV_SHIFT);
            vlynq_wr_reg(p_vlynq_clock, False, &p_vlynq_reg->control, val);

            vlynq_delay_wait(0xffffu);

            if(TRUE == vlynq_detect_link_status(p_vlynq_clock))
            {
                ret_val = PAL_VLYNQ_OK; /* Yes, we have the link. */
            }
            /* Not yet, let us try getting the link at a lower frequency. */
        }
    }
    return (ret_val);
}


/*
 *  This function configures the clock as per the configuration passed
 *
 *  Input:
 *          p_vlynq_bridge         [IN] handle to the root vlynq
 *          local_clock_dir [IN]    direction of local clock
 *          peer_clock_dir  [IN]    direction of peer clock
 *          local_clock_div [IN]    local clock to be divided by this
 *          peer_clock_div [IN]     peer clock to be divided by this
 *  Return:
 *          PAL_VLYNQ_OK on success; else failure
 */

static PAL_Result vlynq_config_bridge_clock(PAL_VLYNQ_T * p_vlynq_bridge,
                        PAL_VLYNQ_CLOCK_DIR_ENUM_T local_clock_dir,
                        PAL_VLYNQ_CLOCK_DIR_ENUM_T peer_clock_dir,
                        Uint8       local_clock_div,
                        Uint8       peer_clock_div)
{
    VLYNQ_REG_T *p_vlynq_reg = NULL;
    Uint32               val = 0;
    Int32       ret_val = PAL_VLYNQ_OK;
    /* Clock configuration is hardware driven. We do some basic configuration
     * to aid the hardware setup. Lest, the software configuration is aligned
     * with the hardware setup, expect the ultimate, "the hang". Read on.....
     */
    /* We must have the Link at this stage. We have to go over the link for
     * peer clock.*/
    if((pal_vlynq_clk_out   ==  local_clock_dir) &&
      (pal_vlynq_clk_in     ==  peer_clock_dir))
    {
        /* For master mode*/
        if(p_vlynq_bridge == NULL)
        {
            ret_val = PAL_VLYNQ_INTERNAL_ERROR;
        }else{
            /* Clock configuration for Master VLYNQ module */
            p_vlynq_reg = LOCAL_REGS(p_vlynq_bridge);
            val = vlynq_rd_reg(p_vlynq_bridge, False, &p_vlynq_reg->control);
            val &= ~(VLYNQ_CLKDIR_IN << CSL_VLYNQ_CTRL_CLKDIR_SHIFT);
            val &= ~(VLYNQ_CLKDIV_MAX << CSL_VLYNQ_CTRL_CLKDIV_SHIFT);
            val |=  ((Uint32)(local_clock_div - 1u) << CSL_VLYNQ_CTRL_CLKDIV_SHIFT) | (local_clock_dir << CSL_VLYNQ_CTRL_CLKDIR_SHIFT);
            vlynq_wr_reg(p_vlynq_bridge, False, &p_vlynq_reg->control, val);

            vlynq_delay_wait(0xffffu);
            /* We must have the Link at this stage */
            if(vlynq_detect_link_status(p_vlynq_bridge) == 0)
            {
                ret_val = PAL_VLYNQ_NO_LINK;
            }
            else
            {
                /* Clock configuration for slave VLYNQ module */
                p_vlynq_reg = PEER_REGS(p_vlynq_bridge);
                val  = vlynq_rd_reg(p_vlynq_bridge, True, &p_vlynq_reg->control);

                val &= ~(VLYNQ_CLKDIR_IN << 15);
                val &= ~(VLYNQ_CLKDIV_MAX << 16);
                val |= ((Uint32)((peer_clock_div - 1u) << 16)) |((Uint32) (peer_clock_dir << 15));
                vlynq_wr_reg(p_vlynq_bridge, True, &p_vlynq_reg->control, val);

                /* We must have the Link at this stage */
                if(vlynq_detect_link_status(p_vlynq_bridge) == 0)
                {
                    ret_val = PAL_VLYNQ_NO_LINK;
                }
            }
        }
    }
    else
    {
        /* for Slave mode */
        if( (p_vlynq_bridge == NULL)
            ||(vlynq_detect_link_status(p_vlynq_bridge) == 0))
        {
            ret_val = PAL_VLYNQ_NO_LINK;
        }else{

            p_vlynq_reg = LOCAL_REGS(p_vlynq_bridge);
            val = vlynq_rd_reg(p_vlynq_bridge, False, &p_vlynq_reg->control);
            val &= ~(VLYNQ_CLKDIR_IN << CSL_VLYNQ_CTRL_CLKDIR_SHIFT);
            val &= ~(VLYNQ_CLKDIV_MAX << CSL_VLYNQ_CTRL_CLKDIV_SHIFT);
            val |=  ((Uint32)(local_clock_div - 1u) << CSL_VLYNQ_CTRL_CLKDIV_SHIFT) | (local_clock_dir << CSL_VLYNQ_CTRL_CLKDIR_SHIFT);
            vlynq_wr_reg(p_vlynq_bridge, False, &p_vlynq_reg->control, val);

            vlynq_delay_wait(0xffffu);
            /* We must have the Link at this stage */
            if(vlynq_detect_link_status(p_vlynq_bridge) == 0)
            {
                ret_val = PAL_VLYNQ_NO_LINK;
            }
        }

    }

    return (ret_val);
}


/*
 *  This function uninstalls the internal isr
 *
 *  Input:
 *          p_vlynq_intern       [IN]   handle to the vlynq
 *  Return:
 *          PAL_VLYNQ_OK on success; else failure
 */

static PAL_Result vlynq_uninstall_intern_isr(PAL_VLYNQ_T *p_vlynq_intern)
{
    PAL_VLYNQ_ISR_INFO_T *p_isr_info = NULL;
    VLYNQ_REG_T *p_reg = NULL;
    Uint32 cookie = 0;
    if(p_vlynq_intern == NULL){
        return (PAL_VLYNQ_INTERNAL_ERROR);
    }

    /* To configure Peer register check the status of link */
    if(FALSE == vlynq_detect_link_status(p_vlynq_intern))
    {
        return (PAL_VLYNQ_NO_LINK);
    }

    PAL_osProtectEntry(PAL_OSPROTECT_INTERRUPT, &cookie);
    p_reg = LOCAL_REGS(p_vlynq_intern);
    vlynq_wr_reg(p_vlynq_intern, True, (volatile Uint32*)&p_reg->control,
    vlynq_rd_reg(p_vlynq_intern, True, (volatile Uint32*)&p_reg->control) & (~ (VLYNQ_CTL_INT_CLK_BITS)));
    PAL_osProtectExit(PAL_OSPROTECT_INTERRUPT, cookie);

    if(p_vlynq_intern->peer_isr_info != NULL)
    {
        p_isr_info = p_vlynq_intern->peer_isr_info;
        if(p_isr_info == NULL){
            return (PAL_VLYNQ_INTERNAL_ERROR);
        }
        else{
            p_isr_info->one_of_isr_info.intern_isr_info.isr   = NULL;
            p_isr_info->one_of_isr_info.intern_isr_info.vlynq = NULL;
            vlynq_free_isr_info(p_isr_info);
        }
    }

    PAL_osProtectEntry(PAL_OSPROTECT_INTERRUPT, &cookie);
    p_reg = PEER_REGS(p_vlynq_intern);
    vlynq_wr_reg(p_vlynq_intern, False, (volatile Uint32*)&p_reg->control,
    vlynq_rd_reg(p_vlynq_intern, False,(volatile Uint32*)&p_reg->control) & (~(VLYNQ_CTL_INT_CLK_BITS)));
    PAL_osProtectExit(PAL_OSPROTECT_INTERRUPT, cookie);

    if(NULL != p_vlynq_intern->local_isr_info)
    {
        p_isr_info = p_vlynq_intern->local_isr_info;
        p_isr_info->one_of_isr_info.intern_isr_info.isr   = NULL;
        p_isr_info->one_of_isr_info.intern_isr_info.vlynq = NULL;

        vlynq_free_isr_info(p_isr_info);
    }

    return (PAL_VLYNQ_OK);
}



/*
 *  This function configures the registers as per the interrupt configuration passed
 *
 *  Input:
 *          p_vlynq_error   [IN]    handle to the vlynq
 *          intr_local      [IN]    Interrupt local
 *          intr_enable     [IN]    Interrupt Enable
 *          intr_vec        [IN]    Interrupt vector
 *          int2cfg         [IN]    Interrupt to configuration register
 *          intr_pointer    [IN]    Interrupt pointer reg value
 *          peer            [IN]    whether peer or not
 *  Return:
 *          PAL_VLYNQ_OK on success; else failure
 */
static PAL_VLYNQ_ISR_INFO_T * vlynq_config_intern_error_intr(PAL_VLYNQ_T * p_vlynq_error,
                                                             Uint8       intr_local,
                                                             Uint8       intr_enable,
                                                             Uint8       intr_vec,
                                                             Uint8       int2cfg,
                                                             Uint32      intr_pointer,
                                                             Bool        peer)
{
    PAL_VLYNQ_ISR_INFO_T * p_isr_info = NULL;
    PAL_VLYNQ_ISR_INFO_T * ret_val    = NULL;
    volatile Uint32 val = 0;
    VLYNQ_REG_T  * p_reg = NULL;

    if((NULL != p_vlynq_error) && (TRUE == vlynq_detect_link_status(p_vlynq_error)))
    {
        p_reg = ((peer == True)? PEER_REGS(p_vlynq_error) : LOCAL_REGS(p_vlynq_error));
        p_isr_info = vlynq_get_free_isr_info();

        if(p_isr_info == NULL)
        {
            ret_val = p_isr_info;
        }else
          {
            ret_val = p_isr_info;
            if(TRUE == peer)
            {
                p_isr_info->one_of_isr_info.intern_isr_info.isr = &vlynq_root_isr_peer_error;
            }
            else
            {
                p_isr_info->one_of_isr_info.intern_isr_info.isr = &vlynq_root_isr_local_error;
            }

            p_isr_info->one_of_isr_info.intern_isr_info.vlynq = p_vlynq_error;
            p_isr_info->irq_type                              = 0x1;

            if(0 != int2cfg)
            {
                vlynq_wr_reg(p_vlynq_error, peer, &p_reg->intPtr, PAL_VLYNQ_IOCTL_INT_PEND_REG);
            }
            else {
                vlynq_wr_reg(p_vlynq_error, peer, &p_reg->intPtr, intr_pointer);
            }
            val  = vlynq_rd_reg(p_vlynq_error, peer, &p_reg->control);
            val &= (~(VLYNQ_CTL_INT_CLK_BITS));
            val |= (Uint32)((Uint32)intr_local  << CSL_VLYNQ_CTRL_INTLOCAL_SHIFT);
            val |= (Uint32)((Uint32)intr_enable << CSL_VLYNQ_CTRL_INTENABLE_SHIFT);
            val |= (Uint32)((Uint32)intr_vec    << CSL_VLYNQ_CTRL_INTVEC_SHIFT);
            val |= (Uint32)((Uint32)int2cfg     <<  CSL_VLYNQ_CTRL_INT2CFG_SHIFT);
            vlynq_wr_reg(p_vlynq_error, peer, &p_reg->control, val);
        }
    }

    return (ret_val);
}

/*
 *  This function installs the interrupt configuration for local and peer
 *
 *  Input:
 *          p_vlynq_install     [IN]    handle to the vlynq
 *          p_vlynq_config      [IN]    vlynq configuration
 *
 *  Return:
 *          PAL_VLYNQ_OK on success; else failure
 */
static PAL_Result vlynq_install_intern_isr(PAL_VLYNQ_T * p_vlynq_install,
        const PAL_VLYNQ_CONFIG_T* p_vlynq_config)
{
    PAL_VLYNQ_ISR_INFO_T        * p_intern_isr   = NULL;
    PAL_Result                    ret_val   = PAL_VLYNQ_OK;

    if((NULL == p_vlynq_install) || (NULL == p_vlynq_config) )
    {
        ret_val = PAL_VLYNQ_INTERNAL_ERROR;
    }else{
        /* Local interrupt configuration from master side */

        p_intern_isr = vlynq_config_intern_error_intr(p_vlynq_install,
        p_vlynq_config->local_intr_local,
        p_vlynq_config->local_intr_enable,
        p_vlynq_config->local_intr_vector,
        p_vlynq_config->local_int2cfg,
        p_vlynq_config->local_intr_pointer, 0);

        if(NULL == p_intern_isr)
        {
            ret_val = PAL_VLYNQ_INTERNAL_ERROR;
        }
        else
        {
            p_vlynq_install->local_isr_info = p_intern_isr;
            p_vlynq_install->local_irq      = (Int8)p_vlynq_config->local_intr_vector;
            if(((pal_vlynq_clk_out  ==  p_vlynq_config->local_clock_dir) &&
            (pal_vlynq_clk_in     ==  p_vlynq_config->peer_clock_dir)) == TRUE)
            {
                /* Peer interrupt configuration from master side */
                p_intern_isr = vlynq_config_intern_error_intr(p_vlynq_install,
                p_vlynq_config->peer_intr_local,
                p_vlynq_config->peer_intr_enable,
                p_vlynq_config->peer_intr_vector,
                p_vlynq_config->peer_int2cfg,
                p_vlynq_config->peer_intr_pointer,1);

                if(NULL == p_intern_isr)
                {
                    vlynq_free_isr_info(p_vlynq_install->local_isr_info);
                    p_vlynq_install->local_isr_info = NULL;
                    ret_val = PAL_VLYNQ_INTERNAL_ERROR;
                }
                else
                {
                    p_vlynq_install->peer_isr_info = p_intern_isr;
                    p_vlynq_install->peer_irq      = (Int8)p_vlynq_config->peer_intr_vector;
                }
            }/* if Master Mode*/
        }
    }
    return (ret_val);
}


/**
 * \brief   Get the number of the root VLYNQ(s).
 *
 *
 * \return  The number of root VLYNQ modules on the SOC.
 *          0 means no VLYNQ,1 means an root index of 0,2 mean
 *          indices 0 and 1.
 */
Int32 PAL_sysVlynqGetNumRoot(void)
{
    Int32 root_count = 0, index = 0;

    while(index < MAX_ROOT_VLYNQ){
        if(NULL != root_pal_vlynq[index++]) {
            root_count++;
        }
    }
    return (root_count);
}


/**
 * \brief   Get the handle to the specified root VLYNQ
 *
 *
 * \param   index       [IN]    0 based. Starts at 0 and extends to (inclusive of)
 *                              one less number of roots returned by
 *                              PAL_sysVlynqGetNumRoot ( )
 *
 * \return                      NULL, on failure otherwise a valid handle
 *                              to access the root VLYNQ module.
 */
PAL_VLYNQ_HND* PAL_sysVlynqGetRoot(Int32 index)
{
    PAL_VLYNQ_T *p_vlynq_getroot = NULL;

    if(index < MAX_ROOT_VLYNQ) {
        p_vlynq_getroot = root_pal_vlynq[index];
    }
    return ((PAL_VLYNQ_HND*) p_vlynq_getroot);
}


/**
 * \brief   Get the next VLYNQ module in the chain
 *
 *
 * \param   this        [IN]    The VLYNQ module instance whose next
 *                              chained entity (away from the root) is
 *                              being sought.
 *
 * \return                      NULL, on failure otherwise a valid handle
 *                              to access the neighbor module.
 */
PAL_VLYNQ_HND* PAL_sysVlynqGetNext(PAL_VLYNQ_HND * this)
{
    PAL_VLYNQ_T * p_vlynq_getnext = NULL;

    if(this != NULL) {
        p_vlynq_getnext = (PAL_VLYNQ_T*) this;
        p_vlynq_getnext = p_vlynq_getnext->next;
    }
    return ((PAL_VLYNQ_HND* )p_vlynq_getnext);
}


/**
 * \brief   Is this VLYNQ module the last one in the chain
 *
 *
 * \param   this        [IN]    The VLYNQ module instance
 *                              to be ascertained whether last in the
 *                              chain (away from the root).
 * \return                      0 on false.,1 on true.
 */
Int32 PAL_sysVlynqIsLast(PAL_VLYNQ_HND *this)
{
    PAL_VLYNQ_T *p_vlynq_islast = NULL;
    Int32 ret_val = PAL_VLYNQ_INTERNAL_ERROR;

    if(this != NULL) {
        p_vlynq_islast = (PAL_VLYNQ_T*) this;
        ret_val = p_vlynq_islast->next ? 0 : 1;
    }
    return (ret_val);
}


/**
 * \brief   Get the length of the VLYNQ chain
 *
 *
 * \param   this        [IN]    The starting VLYNQ module instance
 *                              inclusive of which, the number
 *                              of VLYNQ modules existing in the chain
 *                              (away from root) is being
 *                              sought..If this happens to be the root
 *                              VLYNQ module, then the
 *                              length of the entire chain is ascertained.
 * \return                      The number of VLYNQ modules in the chain
 *                              (away from the root).
 */
Int32 PAL_sysVlynqGetChainLength(PAL_VLYNQ_HND * this)
{
    PAL_VLYNQ_T * p_vlynq_length = NULL;
    Int32 length = 0;
    if(this == NULL)
    {
        return (PAL_VLYNQ_INVALID_PARAM);
    }else{
        p_vlynq_length  = (PAL_VLYNQ_T* )this;
        for(; p_vlynq_length != NULL; p_vlynq_length  = p_vlynq_length->next)
        {
           length++;
        }
    }
    return (this ? length : PAL_VLYNQ_INVALID_PARAM);
}


/**
 * \brief   Returns the base address of the VLYNQ
 *
 *
 * \param   vlynq       [IN]    The Vlynq module whose base address is being sought.
 * \param   base        [IN]    The placeholder for the virtual base address of the
 *                              VLYNQ module on the SOC.
 *
 * \return  PAL_VLYNQ_OK  on success, negative on failure.
 */
PAL_Result PAL_sysVlynqGetBaseAddr(PAL_VLYNQ_HND *vlynq, Uint32 *base)
{
    PAL_VLYNQ_T *p_vlynq_base_add = NULL;
    PAL_Result  ret_val = PAL_VLYNQ_OK;
    if((vlynq == NULL) || (base == NULL)){
        ret_val = PAL_VLYNQ_INVALID_PARAM;
    }
    if(ret_val == PAL_VLYNQ_OK)
    {
        p_vlynq_base_add = vlynq;
        if(base == NULL)
        {
            ret_val = PAL_VLYNQ_INVALID_PARAM;
        }
        *base = p_vlynq_base_add->base;
    }
    return (ret_val);
}


/**
 * \brief   Get the root VLYNQ  at the  base address.
 *
 *
 * \param   base_addr   [IN]    The virtual base address of the VLYNQ
 *                              module on the SOC.
 *
 * \return                      NULL, on failure otherwise a valid handle
 *                              to access the root VLYNQ module.
 */
PAL_VLYNQ_HND *PAL_sysVlynqGetRootAtBase(Uint32 base_addr)
{
    PAL_VLYNQ_T *p_ret_vlynq = NULL;
    Int32 i = 0;

    for(i = 0; i < MAX_ROOT_VLYNQ; i++)
    {
        if(NULL != root_pal_vlynq[i])
        {
            if(root_pal_vlynq[i]->base == base_addr)
            {
                p_ret_vlynq = root_pal_vlynq[i];
                break;
            }
        }
    }
    return ((PAL_VLYNQ_HND *)p_ret_vlynq);
}


/**
 * \brief   Get root for the given VLYNQ.
 *
 *
 * \param   vlynq               [IN]    Handle to the VLYNQ whose root is being sought.
 *
 * \return  NULL, on failure otherwise a valid handle, to access the root VLYNQ module.
 */
PAL_VLYNQ_HND *PAL_sysVlynqGetRootVlynq(PAL_VLYNQ_HND * vlynq)
{
    PAL_VLYNQ_HND *p_vlynq_root_get = NULL;
    if(vlynq != NULL){
        p_vlynq_root_get = (vlynq_find_root_vlynq(vlynq));
    }
    else{
        p_vlynq_root_get = NULL;
    }
    return (p_vlynq_root_get);
}


/**
 * \brief   Append to  the VLYNQ chain
 *
 *
 * \param   this                [IN]    The VLYNQ module instance, which has to be added to the chain (away from the root).
 *                                      This value would have been returned by PAL_sysVlynqInit( ).
 * \param   to                  [IN]    The VLYNQ module instance, to which this has to be chained (away from the root).
 *                                      This value would have been returned by PAL_sysVlynqInit( )..
 *
 * \return  PAL_VLYNQ_OK  on success, negative on failure.
 */
PAL_Result PAL_sysVlynqChainAppend(PAL_VLYNQ_HND * this, PAL_VLYNQ_HND * to)
{
    PAL_VLYNQ_T * this_vlynq = NULL;
    PAL_VLYNQ_T * to_vlynq = NULL;
    PAL_VLYNQ_T * root_vlynq = NULL;
    PAL_Result      ret_val = PAL_VLYNQ_OK;

    if((NULL == this ) || (NULL == to))
    {
        ret_val = PAL_VLYNQ_INVALID_PARAM;
    }else {
        this_vlynq = (PAL_VLYNQ_T* ) this;
        to_vlynq   = (PAL_VLYNQ_T* ) to;

        if((NULL != to_vlynq->next ) && (PAL_VLYNQ_OK == ret_val) )
        {
            ret_val = PAL_VLYNQ_INVALID_PARAM;
        }
        else{
            root_vlynq = vlynq_find_root_vlynq(to_vlynq);
            if( (NULL == root_vlynq ) || (NULL == root_vlynq->root_irq_info) )
            {
                ret_val = PAL_VLYNQ_INTERNAL_ERROR;
            }else{
                /* Load the local isr information into the root vlynq. */
                vlynq_add_intern_isr(root_vlynq, (Uint8)to_vlynq->local_irq,
                                     to_vlynq->local_isr_info);

                /* Load the peer isr information into the root vlynq. */
                vlynq_add_intern_isr(root_vlynq, (Uint8)to_vlynq->peer_irq,
                        to_vlynq->peer_isr_info);

                to_vlynq->next   = this_vlynq;
                this_vlynq->prev = to_vlynq;
                if(to_vlynq->peer_swap == True)
                {
                    this_vlynq->local_swap = True;
                }
            }
        }
    }
    return (ret_val);
}


/**
 * \brief   Remove (the tail) from the VLYNQ chain
 *
 *
 * \param   this                [IN]    The VLYNQ module instance, which has to be removed
 *                                      from the chain (away from the root).
 * \param   from                [IN]    The VLYNQ module instance, from which
 *                                      this has to be removed (away from the root).
 *
 * \return  PAL_VLYNQ_OK on success, negative on failure.
 */
PAL_Result PAL_sysVlynqChainUnAppend(PAL_VLYNQ_HND * this, PAL_VLYNQ_HND * from)
{
    PAL_VLYNQ_T * this_vlynq = NULL;
    PAL_VLYNQ_T * from_vlynq = NULL;
    PAL_Result      ret_val = PAL_VLYNQ_OK;
    PAL_VLYNQ_T * root_vlynq = NULL;

    if((this == NULL) || (from == NULL))
    {
        ret_val = PAL_VLYNQ_INVALID_PARAM ;
    }else{
        this_vlynq = (PAL_VLYNQ_T* ) this;
        from_vlynq = (PAL_VLYNQ_T* ) from;

        if((this_vlynq->next != NULL) && (ret_val == 0) ){
            ret_val = PAL_VLYNQ_INVALID_PARAM ;
        }
        if( (from_vlynq->next != this_vlynq) && (ret_val == 0) ){
            ret_val = PAL_VLYNQ_INTERNAL_ERROR;
        }else{

            root_vlynq = vlynq_find_root_vlynq(from_vlynq);

            if((NULL == root_vlynq ) || (NULL == root_vlynq->root_irq_info ) ) {
                ret_val = PAL_VLYNQ_INTERNAL_ERROR;
            }else{
                vlynq_remove_intern_isr(root_vlynq, (Uint8)from_vlynq->local_irq,
                                        from_vlynq->local_isr_info);
                vlynq_remove_intern_isr(root_vlynq, (Uint8)from_vlynq->peer_irq,
                                        from_vlynq->peer_isr_info);
                from_vlynq->next       = this_vlynq->next;
                this_vlynq->next->prev = from_vlynq;
            }
        }
    }
    return (ret_val);
}


/**
 * \brief   Maps the IRQ hardware line onto the VLYNQ
 *
 *
 * \param   vlynq               [IN]    The vlynq instance on which the IRQ mapping is to be carried out.
 *                                      This value would have been returned by PAL_sysVlynqInit( ).
 * \param   irq_hw_line         [IN]    Identifies the hardware vector line (in the perspective of the VLYNQ module), which runs from
 *                                      the device to the VLYNQ module. The valid values are 0 to 7 (both inclusive).
 * \param   irq                 [IN]    Identifies the IRQ number to which the interrupt hardware line shall be mapped.
 *                                      The valid values are 0 to 31 (both inclusive). It is the
 *                                      responsibility of the user to ensure that there is a unique irq_hw_line to irq mapping
 *                                      within a VLYNQ chain.
 * \param   vlynq_dev           [IN]    The device instance for which certain hardware interrupts have to be mapped
 *                                      on the VLYNQ;this value would have been returned by PAL_sysVlynqDevCreate().
 * \return  PAL_VLYNQ_OK on success, negative on failure.
 */
PAL_Result PAL_sysVlynqMapIrq(PAL_VLYNQ_HND *vlynq, Uint32 hw_intr_line,
                              Uint32 irq, PAL_VLYNQ_DEV_HND *vlynq_dev)
{
    PAL_VLYNQ_DEV_HND    *p_vlynq_dev = NULL;
    PAL_VLYNQ_T          *p_vlynq_map_irq = NULL;
    PAL_VLYNQ_IRQ_MAP_T  *p_irq_map = NULL;
    volatile Uint32      *p_reg, val = NULL;
    VLYNQ_REG_T          *p_vlynq_reg = NULL;
    PAL_Result           ret_val = PAL_VLYNQ_OK;
    Int32    index = 0;
    Bool     peer = False;
    Uint32 cookie = 0;

    if((NULL == vlynq_dev ) || (NULL == vlynq ) ){
        ret_val = PAL_VLYNQ_INVALID_PARAM;
    }
    else{
    p_vlynq_dev = (PAL_VLYNQ_DEV_HND*) vlynq_dev;
        p_vlynq_map_irq     = vlynq;
        if( (irq >= MAX_IRQ_PER_CHAIN) || (hw_intr_line > 7u) )
        {
            ret_val = PAL_VLYNQ_INVALID_PARAM;
        }else{
        /* Has this irq been already mapped. */
            if((p_irq_map = vlynq_get_map_for_irq((PAL_VLYNQ_T*)vlynq, irq)) == NULL)
            {
            ret_val = PAL_VLYNQ_INTERNAL_ERROR;
        }else{
            PAL_osProtectEntry(PAL_OSPROTECT_INTERRUPT, &cookie);

                if((vlynq_find_dev_index(p_vlynq_map_irq, p_vlynq_dev, &peer, &index) != 0)
                                         && (ret_val == 0))
                {
                PAL_osProtectExit(PAL_OSPROTECT_INTERRUPT, cookie);
                return PAL_VLYNQ_INTERNAL_ERROR;
            }
            /* Add information into the device. */
            if((pal_vlynq_dev_ioctl(p_vlynq_dev, PAL_VLYNQ_DEV_ADD_IRQ, irq) != 0)
                                        && (ret_val == 0))
                {
                ret_val = PAL_VLYNQ_INTERNAL_ERROR;
            }else{
                /* Update the VLYNQ hardware. */
                    /* To configure Peer register check the status of link */
                    if(FALSE == vlynq_detect_link_status(p_vlynq_map_irq))
                    {
                        return (PAL_VLYNQ_NO_LINK);
                    }
                    p_vlynq_reg = (peer == True) ? PEER_REGS(p_vlynq_map_irq): LOCAL_REGS(p_vlynq_map_irq);

                    if(p_vlynq_reg == NULL)
                    {
                    PAL_osProtectExit(PAL_OSPROTECT_INTERRUPT, cookie);
                        ret_val = PAL_VLYNQ_INVALID_PARAM;
                    }else{

                        p_reg = (hw_intr_line < 4u) ? &p_vlynq_reg->ivr30 : &p_vlynq_reg->ivr74;

                        p_irq_map->hw_intr_line = (Int8)hw_intr_line;
                        p_irq_map->vlynq        = p_vlynq_map_irq;
                        p_irq_map->peer         = peer;

                        hw_intr_line  =  (Uint8) VLYNQ_IVEC_HW_LINE_ADJUST(hw_intr_line);

                        val  = vlynq_rd_reg(p_vlynq_map_irq, peer, p_reg);
                        val &= (~(VLYNQ_IVEC_IRQ_MASK(hw_intr_line)));
                        val |= (VLYNQ_IVEC_IRQ_VAL(irq) << VLYNQ_IVEC_OFFSET(hw_intr_line));
                        vlynq_wr_reg(p_vlynq_map_irq, peer, p_reg, val);

                        if(p_vlynq_map_irq->peer_swap == True)
                        {
                            irq = irq_val_swap[irq];
                        }
                        irq_swap_map[irq] = p_vlynq_map_irq;

                    }
            }
             PAL_osProtectExit(PAL_OSPROTECT_INTERRUPT, cookie);
        }
    }
    }
    return (ret_val);
}


/**
 * \brief   UnMaps the IRQ hardware line.
 *
 *
 * \param   vlynq       [IN]    The VLYNQ instance on which the un-mapping has to be carried out.
 * \param   irq         [IN]    Identifies the IRQ number for which the interrupt hardware
 *                              line shall be un-mapped. The valid values are 0 to 31 (both inclusive).
 * \param   vlynq_dev   [IN]    The device instance for which certain hardware interrupts are
 *                              required to be un-mapped on VLYNQ; this value would have been
 *                              returned by PAL_sysVlynqDevCreate().
 * \return                      0 on success.-1 on failure.
 */
PAL_Result PAL_sysVlynqUnMapIrq(PAL_VLYNQ_HND * vlynq, Uint32 irq,
                                PAL_VLYNQ_DEV_HND * vlynq_dev)
{
    PAL_VLYNQ_DEV_HND     *p_vlynq_dev = NULL;
    PAL_VLYNQ_IRQ_MAP_T   *p_irq_map = NULL;
    PAL_VLYNQ_T           * p_vlynq_Irq_unmap = NULL;
    PAL_Result            ret_val = PAL_VLYNQ_OK;
    PAL_VLYNQ_T           *p_vlynq = NULL;
    Int32                 index = 0;
    Bool                  peer = False;
    Uint32                cookie = 0;

    if((NULL == vlynq_dev) || (NULL == vlynq ))
    {
        ret_val = PAL_VLYNQ_INVALID_PARAM;
    }
    else
    {
        p_vlynq      = (PAL_VLYNQ_T*) vlynq;
    }

    if((irq >= MAX_IRQ_PER_CHAIN) && (ret_val == 0))
    {
        ret_val = PAL_VLYNQ_INVALID_PARAM;
    }else{

        p_vlynq_dev  = (PAL_VLYNQ_DEV_HND*) vlynq_dev;
        p_vlynq_Irq_unmap      = (PAL_VLYNQ_T* ) vlynq;
        PAL_osProtectEntry(PAL_OSPROTECT_INTERRUPT, &cookie);
        p_irq_map = vlynq_get_map_for_irq(p_vlynq, (Uint8)irq);
        if(p_irq_map == NULL)
        {
            ret_val = PAL_VLYNQ_INTERNAL_ERROR;
        }
        /* Was it mapped by this VLYNQ. */
        else if((p_irq_map->vlynq != vlynq) && (ret_val == 0))
        {
            ret_val = PAL_VLYNQ_INTERNAL_ERROR;
        }
        /* Still have ISR attached. */
        else if((p_vlynq_Irq_unmap->root_irq_info[irq].isr_info != 0)&&
            (ret_val == 0))
        {
            ret_val = PAL_VLYNQ_INTERNAL_ERROR;
        }
        else if( ( TRUE == vlynq_find_dev_index(p_vlynq_Irq_unmap, p_vlynq_dev, &peer, &index) )
            && (ret_val == 0) )
        {
            ret_val = PAL_VLYNQ_INTERNAL_ERROR;
        }
        /* Add information into the device. */
        else if(PAL_VLYNQ_OK != pal_vlynq_dev_ioctl(p_vlynq_dev, PAL_VLYNQ_DEV_REMOVE_IRQ, irq))
        {
            ret_val = PAL_VLYNQ_INTERNAL_ERROR;
        }
    }
    if(ret_val == PAL_VLYNQ_OK)
    {
        p_irq_map->hw_intr_line = (Int8)PAL_VLYNQ_INVALID_PARAM;
        p_irq_map->vlynq       = NULL;
        if(p_vlynq_Irq_unmap->peer_swap == True)
        {
            irq = vlynq_endian_swap(irq);
        }
        irq_swap_map[irq] = NULL;
    }
    PAL_osProtectExit(PAL_OSPROTECT_INTERRUPT, cookie);
    return (ret_val);
}


/**
 * \brief   Install the ISR for the device.
 *
 *
 * \param   vlynq               [IN]    The VLYNQ module instance for whose associated remote device, an isr is being installed.
 * \param   irq                 [IN]    One of the identifier of the IRQ as returned by
 *                                      PAL_sysVlynqGetDevIrq( )or VLYNQ module specific interrupt.
 * \param   dev_isr             [IN]    The OS specific function pointer (ISR handler); the type of the function PAL_VLYNQ_DEV_ISR_FN shall be defined for each of the OS by
 *                                      the user. Driver for the remote device shall load
 *                                      appropriate function instance.
 * \param   isr_param           [IN]    It is a collection of parameters for each instance of the remote device driver.
 *
 * \return  PAL_VLYNQ_OK on success., negative on error.
 */
PAL_Result PAL_sysVlynqAddIsr(PAL_VLYNQ_HND * vlynq, Uint32 irq,
        PAL_VLYNQ_DEV_ISR_FN  dev_isr,
        PAL_VLYNQ_DEV_ISR_PARAM_GRP_T* isr_param)
{
    PAL_VLYNQ_T            * p_root_vlynq = NULL;
    PAL_VLYNQ_ISR_INFO_T   * p_isr_info = NULL;
    Uint32                 cookie = 0;
    PAL_Result             ret_val = PAL_VLYNQ_OK;

    if((vlynq == NULL) || (dev_isr == NULL)) {/* || !isr_param) */
        ret_val = PAL_VLYNQ_INVALID_PARAM;
    }
    if((irq > 31u) && (ret_val == PAL_VLYNQ_OK)){
        ret_val = PAL_VLYNQ_INVALID_PARAM;
    }else{

        PAL_osProtectEntry(PAL_OSPROTECT_INTERRUPT, &cookie);
        /* Ascertain whether the IRQ has been already mapped. */
        if(NULL == vlynq_get_map_for_irq((PAL_VLYNQ_T* )vlynq, (Uint8)irq))
        {
            ret_val = PAL_VLYNQ_INTERNAL_ERROR;
        }else{
            p_root_vlynq = vlynq_find_root_vlynq((PAL_VLYNQ_T* )vlynq);
            if( ((p_root_vlynq == NULL) ||
                (p_root_vlynq->root_irq_info == NULL))||
                (p_root_vlynq->root_irq_info[irq].isr_info != NULL))
            {
                ret_val = PAL_VLYNQ_INVALID_PARAM;
            }else{
                /* Get a place holder for ISR information. */
                p_isr_info = vlynq_get_free_isr_info();
                if(p_isr_info == NULL)
                {
                    ret_val = PAL_VLYNQ_INTERNAL_ERROR;
                }
            }

        }
        PAL_osProtectExit(PAL_OSPROTECT_INTERRUPT, cookie);
    }
    if(PAL_VLYNQ_OK == ret_val) {
        /* House keeping; you see. */
        p_isr_info->one_of_isr_info.dev_isr_info.isr       = dev_isr;
        p_isr_info->one_of_isr_info.dev_isr_info.isr_param = isr_param;
        p_isr_info->irq_type                               = 0x0;

        p_isr_info->next = p_root_vlynq->root_irq_info[irq].isr_info;
        p_root_vlynq->root_irq_info[irq].isr_info = p_isr_info;
    }

    return (ret_val);
}

/**
 * \brief   Uinstall the previously installed ISR
 *
 *
 * \param   vlynq               [IN]    The VLYNQ module instance for whose
 *                                      associated remote device, an isr is being removed
 *                                      object.
 * \param   irq                 [IN]    The identifier of the IRQ as
 *                                      provided in the PAL_sysVlynqAddIsr( ).
 * \param   isr_param           [IN]    Same as that provided in the PAL_sysVlynqAddIsr( ).
 *
 * \return PAL_VLYNQ_OK on success, negative on error
 */
PAL_Result PAL_sysVlynqRemoveIsr(PAL_VLYNQ_HND *vlynq, Uint32 irq,
        const PAL_VLYNQ_DEV_ISR_PARAM_GRP_T *isr_param)
{
    PAL_VLYNQ_T              *p_root_vlynq;
    PAL_VLYNQ_ISR_INFO_T     *p_isr_info, *p_last_isr_info;
    Uint32                   cookie;

    if( (NULL == vlynq) || (NULL == isr_param)){
        return  (PAL_VLYNQ_INVALID_PARAM);
    }
    if(irq >= MAX_IRQ_PER_CHAIN){
        return (PAL_VLYNQ_INVALID_PARAM);
    }

    PAL_osProtectEntry(PAL_OSPROTECT_INTERRUPT, &cookie);

    p_root_vlynq = vlynq_find_root_vlynq((PAL_VLYNQ_T* )vlynq);
    if((NULL == p_root_vlynq) || (NULL == p_root_vlynq->root_irq_info))
    {
        PAL_osProtectExit(PAL_OSPROTECT_INTERRUPT, cookie);
        return (PAL_VLYNQ_INTERNAL_ERROR);
    }

    p_isr_info = p_root_vlynq->root_irq_info[irq].isr_info;

    for(p_last_isr_info = NULL;p_isr_info != NULL;
        p_isr_info = p_isr_info->next)
    {

        PAL_VLYNQ_DEV_ISR_INFO_T *p_dev_isr_info =
                                 (PAL_VLYNQ_DEV_ISR_INFO_T*)p_isr_info;

        if(p_dev_isr_info->isr_param == isr_param)
        {
            if(NULL == p_last_isr_info)
            {
                p_root_vlynq->root_irq_info[irq].isr_info =  p_isr_info->next;
            }
            else{
                p_last_isr_info->next = p_isr_info->next;
            }
            vlynq_free_isr_info(p_isr_info);
            PAL_osProtectExit(PAL_OSPROTECT_INTERRUPT, cookie);
            return (PAL_VLYNQ_OK);
        }
        p_last_isr_info = p_isr_info;
    }
    PAL_osProtectExit(PAL_OSPROTECT_INTERRUPT, cookie);
    return (PAL_VLYNQ_INTERNAL_ERROR);
}

/**
 * \brief   The Root ISR; register it with the system
 *
 *
 * \return                      0 on success., -1 on error
 */
PAL_Result PAL_sysVlynqRootIsr(PAL_VLYNQ_T *p_vlynq)
{

    Int32 count = 0;
    volatile Int32 irq = 0;
    volatile Int32 clear_irq = 0;
    PAL_VLYNQ_T *p_vlynq_t = p_vlynq;
    PAL_VLYNQ_ISR_INFO_T        *p_vlynq_isr_info = NULL;
    PAL_VLYNQ_IRQ_INFO_T        *p_vlynq_irq_info = NULL;
    PAL_VLYNQ_DEV_ISR_INFO_T    *p_dev_isr_info = NULL;
    PAL_VLYNQ_INTERN_ISR_INFO_T *p_intern_isr_info = NULL;
    register volatile Uint32 irq_status_map = 0;
    VLYNQ_REG_T *p_vlynq_reg = NULL;
    PAL_Result             ret_val = PAL_VLYNQ_INVALID_PARAM;

#ifdef VLYNQ_INSTRUMENTATION_ENABLED
    PSP_LOG_EVENT(  &DVTEvent_Log,
                    "VLYNQ",
                     PSP_DVT_DESC(PSP_DVT_eINT_START,
                                  PSP_DVT_dNONE,
                                  PSP_DVT_dNONE,
                                  PSP_DVT_dNONE));
#endif

    if(NULL != p_vlynq_t)
    {
        p_vlynq_reg = LOCAL_REGS(p_vlynq_t);
        if(NULL != p_vlynq_reg)
        {
            ret_val = PAL_VLYNQ_OK;
            irq_status_map    = p_vlynq_reg->intStatus;

            /* No more than 32 consecutive interrupts for VLYNQ; lest it thrashes
             * the system; safety measures you see.
             */
            for(count = 0; count < MAX_IRQ_PER_CHAIN; count++)
            {
                if(p_vlynq_reg->revision >= VLYNQ_REV_10200)
                {
                    volatile Uint32 val = p_vlynq_reg->intPriority;

                    /*Checks whether there are any pending interrupts in the interrupt status/clear register*/
                    if(0 != (val & CSL_VLYNQ_INTPRI_NOINTPEND_MASK))
                    {
                        break;
                    }
                    /*Bits 0:4 indicate highest priority interrupt bit that is pending(0-31)*/
                    irq        = (Int32)val & 0x1fu;
                }
                else
                {
                    volatile Uint8 val = (Uint8)irq_status_map & 1u;
                    if(0 == irq_status_map)
                    {
                        break;
                    }

                    irq_status_map >>= 1u;
                    if(val != FALSE)
                    {
                        irq = count;
                    }
                    else{
                        continue;
                    }
                }
                /*Note:Clearing the interrupt status register here is not functional*/
                clear_irq = irq;
                /* p_vlynq_reg->intStatus = (1 << irq); */

                if(irq_swap_map[irq]->peer_swap == True)
                {
                    irq = (Int32)irq_val_swap[irq];
                }

                p_vlynq_irq_info  = p_vlynq_t->root_irq_info + irq;
                if(p_vlynq_irq_info == NULL) {
                    ret_val = (PAL_VLYNQ_INVALID_PARAM);
                    break;
                }
                p_vlynq_isr_info  = p_vlynq_irq_info->isr_info;

                p_vlynq_irq_info->count++;

                while(NULL != p_vlynq_isr_info)
                {
                    p_dev_isr_info    = (PAL_VLYNQ_DEV_ISR_INFO_T*)p_vlynq_isr_info;
                    p_intern_isr_info = (PAL_VLYNQ_INTERN_ISR_INFO_T*)p_vlynq_isr_info;

                    /*Change done for freq interrupts*/
                    /* Disable VLYNQ interrupts */
                    if(NULL == p_vlynq_isr_info->irq_type)
                    {
                        p_dev_isr_info->isr(PAL_VLYNQ_DEV_ISR_SIGNATURE(p_dev_isr_info->isr_param));
                    }

                    else {
                        p_intern_isr_info->isr(p_intern_isr_info->vlynq);
                    }
                    /* enable the interrupt */
                    p_vlynq_isr_info = p_vlynq_isr_info->next;
                }
                p_vlynq_reg->intStatus = (1 << clear_irq);
            }
            /* Clear the interrupt again. It was observed that at some instances the
            data transfer completes but the interrupt is still generated/not cleared. Clearing the interrupt
            before leaving this function solves the problem. The problem was seen mainly
            in Debug configuration and not Release*/

            if(PAL_VLYNQ_OK == ret_val)
            {
                p_vlynq_reg->intStatus = (1 << clear_irq);
            }
        }
    }

#ifdef VLYNQ_INSTRUMENTATION_ENABLED
    PSP_LOG_EVENT(  &DVTEvent_Log,
                    "VLYNQ",
                     PSP_DVT_DESC(PSP_DVT_eINT_END,
                                  PSP_DVT_dNONE,
                                  PSP_DVT_dNONE,
                                  PSP_DVT_dNONE));
#endif

    return (ret_val);
}

/**
 * \brief   Get the number of times this IRQ occurred
 *
 *
 * \param   vlynq               [IN]    The VLYNQ module instance for whose associated
 *                                      irq has to be queried for number of dispatches so far.
 * \param   irq                 [IN]    The interrupt number representing the mapped interrupt hardware line on
 *                                      the VLYNQ module. This should be unique for a given VLYNQ chain.
 * \param   count               [IN]    Placeholder to store the number of times the interrupt irq has been raised.
 *                                      The value in the placeholder is valid only if the function returns success.
 *
 * \return  PAL_VLYNQ_OK on success, negative on error
     */
    PAL_Result PAL_sysVlynqGetIrqCount(PAL_VLYNQ_HND * vlynq, Uint32 irq, Uint32 * count)
    {
        PAL_VLYNQ_T           * p_root_vlynq = NULL;
        PAL_VLYNQ_IRQ_INFO_T  * p_irq_info = NULL;
        PAL_Result              ret_val = PAL_VLYNQ_OK;

        if(NULL == vlynq )
        {
            ret_val =  PAL_VLYNQ_INVALID_PARAM;
        }
        else{
            if(((irq >= MAX_IRQ_PER_CHAIN) && (ret_val == 0) ) && (count == NULL))
            {
                ret_val = PAL_VLYNQ_INVALID_PARAM;
            }
            else{
                p_root_vlynq = vlynq_find_root_vlynq((PAL_VLYNQ_T* )vlynq);
                if( (NULL == p_root_vlynq ) ||
                    (NULL == p_root_vlynq->root_irq_info))
                {
                    ret_val = PAL_VLYNQ_INTERNAL_ERROR;
                }
                else{
                    p_irq_info = p_root_vlynq->root_irq_info + irq;
                    if(p_irq_info == NULL)
                    {
                        ret_val = PAL_VLYNQ_INTERNAL_ERROR;
                    }
                    else{
                        * count     = p_irq_info->count;
                     }
                }
            }

        }
    return (ret_val);
}


/**
 * \brief   Get the VLYNQ for the IRQ.
 *
 *
 *          root                [IN]    The VLYNQ chain identifier (the root VLYNQ);
 *                                      the interrupt numbers are unique with in a chain.
 *                                      object.
 *          irq                 [IN]    The interrupt number whose association with a VLYNQ module
 *                                      is being sought. The valid values are 0 to 31 (both inclusive).
 *
 * \return                              Handle on success or NULL on error
 */
PAL_VLYNQ_HND* PAL_sysVlynqGetForIrq(PAL_VLYNQ_HND * root, Uint32 irq)
{
    PAL_VLYNQ_IRQ_MAP_T *p_irq_map = NULL;

    if((root == NULL) || (irq >= MAX_IRQ_PER_CHAIN)) {
        return (NULL);
    }

    p_irq_map = vlynq_get_map_for_irq(root, (Uint8)irq);

    return (PAL_VLYNQ_HND * )(p_irq_map ? p_irq_map->vlynq : NULL);
}


/**
 * \brief   Set the polarity of the hardware IRQ line
 *
 *
 *
 * \param   vlynq               [IN]    The VLYNQ instance whose hardware
 *                                      interrupt line is to be set for polarity
 * \param   irq                 [IN]    The interrupt number representing the mapped interrupt hardware
 *                                      line on the VLYNQ module. This should be unique for a given VLYNQ chain.
 * \param   polarity            [IN]    The polarity of the line. Refer to the data structure in Appendix A.
 *
 * \return  PAL_VLYNQ_OK on success, negative on error
 */
PAL_Result PAL_sysVlynqSetIrqPol(PAL_VLYNQ_HND * vlynq, Uint32 irq,
        PAL_VLYNQ_IRQ_POL_ENUM_T pol)
{
    Uint8             hw_intr_line = FALSE;
    volatile Uint32  * p_reg = NULL;
    PAL_Result       ret_val = 1;
    volatile Uint32  val = 0;

    if(NULL != vlynq)
    {
        ret_val = vlynq_validate_param_and_find_ivr_info((PAL_VLYNQ_T* ) vlynq,
                irq, &p_reg, (Uint8* )&hw_intr_line);
        if(ret_val == 0)
        {
            hw_intr_line  = (Uint8) VLYNQ_IVEC_HW_LINE_ADJUST(hw_intr_line);
            val  = vlynq_rd_reg((PAL_VLYNQ_T*)vlynq, True, p_reg);
            val &= (~ (VLYNQ_IVEC_POL_MASK(hw_intr_line) ));
            val |= ((VLYNQ_IVEC_POL_VAL(pol)) << (VLYNQ_IVEC_OFFSET(hw_intr_line)));
            vlynq_wr_reg((PAL_VLYNQ_T* )vlynq, True, p_reg, val);
        }
    }
    return (ret_val);
}


/**
 * \brief   Get the polarity of the hardware IRQ line
 *
 *
 * \param   vlynq               [IN]    The VLYNQ instance whose hardware interrupt
 *                                      line is to being looked up for polarity setting.
 * \param   Irq                 [IN]    The interrupt number representing the mapped interrupt hardware line on
 *                                      the VLYNQ module. This should be unique for a given VLYNQ chain
 * \param   polarity            [IN]    The polarity of the line. The caller manages memory
 *
 * \return  PAL_VLYNQ_OK on success., negative on error
 */
PAL_Result PAL_sysVlynqGetIrqPol(PAL_VLYNQ_HND *vlynq, Uint32 irq,
        PAL_VLYNQ_IRQ_POL_ENUM_T *pol)
{
    Uint8            hw_intr_line = FALSE;
    volatile Uint32 *p_reg = NULL;
    PAL_Result      ret_val = 1;
    volatile Uint32  val =0;

    if(pol == NULL){
        return (PAL_VLYNQ_INVALID_PARAM);
    }

    ret_val = vlynq_validate_param_and_find_ivr_info((PAL_VLYNQ_T*) vlynq,
            irq, &p_reg,
            (Uint8*)&hw_intr_line);
    if(ret_val == 0) {
        hw_intr_line = (Uint8) VLYNQ_IVEC_HW_LINE_ADJUST(hw_intr_line);
        val  = vlynq_rd_reg((PAL_VLYNQ_T*) vlynq, True, p_reg);
        *pol = (PAL_VLYNQ_IRQ_POL_ENUM_T)(val & VLYNQ_IVEC_POL_MASK(hw_intr_line));
        *pol = (PAL_VLYNQ_IRQ_POL_ENUM_T)((*pol) >> VLYNQ_IVEC_OFFSET(hw_intr_line));
        *pol = (PAL_VLYNQ_IRQ_POL_ENUM_T)(VLYNQ_IVEC_POL_DE_VAL(*pol));
    }
    return (ret_val);
}

/**
 * \brief   Get the type of the hardware IRQ type
 *
 *
 * \param   vlynq               [IN]    The VLYNQ instance whose hardware interrupt line
 *                                      is being looked up for trigger type.
 * \param   Irq                 [IN]    The interrupt number representing the mapped interrupt hardware
 *                                      line on the VLYNQ module. This should be unique for a given VLYNQ chain.
 * \param   type                [IN]    The type of the interrupt line. The caller manages memory
 *
 * \return  PAL_VLYNQ_OK on success., negative on error
 */
PAL_Result PAL_sysVlynqSetIrqType(PAL_VLYNQ_HND *vlynq, Uint32 irq,
        PAL_VLYNQ_IRQ_TYPE_ENUM_T type)
{
    Uint8                hw_intr_line = FALSE;
    volatile Uint32      *p_reg = NULL;
    PAL_Result           ret_val = 1;
    volatile Uint32      val = 0;

    ret_val = vlynq_validate_param_and_find_ivr_info((PAL_VLYNQ_T*) vlynq,
                                                      irq,
                                                      &p_reg,
            (Uint8*)&hw_intr_line);
    if(ret_val == 0)
    {
        hw_intr_line = (Uint8) VLYNQ_IVEC_HW_LINE_ADJUST(hw_intr_line);
        val  = vlynq_rd_reg((PAL_VLYNQ_T*) vlynq, True, p_reg);
        val &= (~(VLYNQ_IVEC_TYPE_MASK(hw_intr_line)));
        val |= ((VLYNQ_IVEC_TYPE_VAL(type)) << (VLYNQ_IVEC_OFFSET(hw_intr_line)));
        vlynq_wr_reg((PAL_VLYNQ_T*) vlynq, True, p_reg, val);
    }
    return (ret_val);
}


/**
 * \brief   Get the type of the hardware IRQ type
 *
 *
 * \param   vlynq               [IN]    The VLYNQ instance whose hardware interrupt line
 *                                      is being looked up for trigger type.
 * \param   Irq                 [IN]    The interrupt number representing the mapped interrupt hardware
 *                                      line on the VLYNQ module. This should be unique for a given VLYNQ chain.
 * \param   type                [IN]    The type of the interrupt line. The caller manages memory
 *
 * \return  PAL_VLYNQ_OK on success., negative on error
 */
PAL_Result PAL_sysVlynqGetIrqType(PAL_VLYNQ_HND * vlynq, Uint32 irq,
        PAL_VLYNQ_IRQ_TYPE_ENUM_T *type)
{
    Uint8                hw_intr_line = FALSE;
    volatile Uint32      *p_reg = NULL;
    PAL_Result           ret_val = 1;
    volatile Uint32      val = 0;

    if((NULL == type ) || (NULL == vlynq) )
    {
        return (PAL_VLYNQ_INVALID_PARAM);
    }
    else{
        ret_val = vlynq_validate_param_and_find_ivr_info((PAL_VLYNQ_T* ) vlynq,
                                irq, &p_reg, &hw_intr_line);
        if(ret_val == 0) {
            hw_intr_line = (Uint8) VLYNQ_IVEC_HW_LINE_ADJUST(hw_intr_line);
            val   = vlynq_rd_reg((PAL_VLYNQ_T*) vlynq, True, p_reg);
            *type = (PAL_VLYNQ_IRQ_TYPE_ENUM_T)(val & VLYNQ_IVEC_TYPE_MASK(hw_intr_line));
            *type = (*type) >> VLYNQ_IVEC_OFFSET(hw_intr_line);
            *type = (PAL_VLYNQ_IRQ_TYPE_ENUM_T)(VLYNQ_IVEC_TYPE_DE_VAL(*type));
        }
    }
    return (ret_val);
}


/**
 * \brief   Disable the IRQ
 *
 *
 * \param   vlynq               [IN]    The VLYNQ module instance for whose associated
 *                                      irq hardware line is to be disabled for generating interrupts.
 * \param   irq                 [IN]    The interrupt number representing the mapped interrupt hardware line on the VLYNQ module.
 *                                      This should be unique for a given VLYNQ chain. .
 *
 * \return  PAL_VLYNQ_OK on success., negative on error
 */
PAL_Result PAL_sysVlynqDisableIrq(PAL_VLYNQ_HND * vlynq, Uint32 irq)
{
    Uint8                hw_intr_line = FALSE;
    volatile Uint32      *p_reg = NULL;
    PAL_Result           ret_val = PAL_VLYNQ_INVALID_PARAM;
    volatile Uint32      val = 0;

    if(NULL != vlynq)
    {
        ret_val = vlynq_validate_param_and_find_ivr_info((PAL_VLYNQ_T* ) vlynq,
                irq, &p_reg,&hw_intr_line);
        if(PAL_VLYNQ_OK == ret_val )
        {
            hw_intr_line = (Uint8) VLYNQ_IVEC_HW_LINE_ADJUST(hw_intr_line);
            val  = vlynq_rd_reg((PAL_VLYNQ_T*) vlynq, True, p_reg);
            val &= (~(VLYNQ_IVEC_EN_MASK(hw_intr_line)));
            vlynq_wr_reg((PAL_VLYNQ_T*) vlynq, True, p_reg, val);
        }
    }
    return (ret_val);
}


/**
 * \brief   Enable  the IRQ
 *
 *
 * \param   vlynq               [IN]    The VLYNQ module instance for whose associated
 *                                      "irq" hardware line is to be enabled for generating interrupts
 * \param   irq                 [IN]    The interrupt number representing the mapped interrupt hardware line
 *                                      on the VLYNQ module. This should be unique for a given VLYNQ chain.
 *
 * \return  PAL_VLYNQ_OK on success., negative on error
 */
PAL_Result PAL_sysVlynqEnableIrq(PAL_VLYNQ_HND * vlynq, Uint32 irq)
{
    Uint8                hw_intr_line = FALSE;
    volatile Uint32      * p_reg = NULL;
    PAL_Result           ret_val = PAL_VLYNQ_INVALID_PARAM;
    volatile Uint32      val = 0;

    if( (NULL != vlynq) && (irq <= MAX_IRQ_PER_CHAIN) )
    {
        ret_val = vlynq_validate_param_and_find_ivr_info((PAL_VLYNQ_T* ) vlynq,
                    irq, &p_reg, &hw_intr_line);
        if(PAL_VLYNQ_OK == ret_val )
        {
            hw_intr_line = (Uint8) VLYNQ_IVEC_HW_LINE_ADJUST(hw_intr_line);
            val  = vlynq_rd_reg((PAL_VLYNQ_T* ) vlynq, True, p_reg);
            val |= (VLYNQ_IVEC_EN_VAL(1) << VLYNQ_IVEC_OFFSET(hw_intr_line));
            vlynq_wr_reg((PAL_VLYNQ_T* ) vlynq, True, p_reg, val);
        }
    }
    return (ret_val);
}

/*
 *  This function applies soft reset by toggling the reset bit
 *
 *  Input:
 *          p_vlynq_soft        [IN]    handle to the vlynq
 *
 *  Return:
 *          void
  */
static void vlynq_soft_reset(PAL_VLYNQ_T * p_vlynq_soft)
{
    VLYNQ_REG_T * p_reg = NULL;

    if(p_vlynq_soft != NULL)
    {
        p_reg = LOCAL_REGS(p_vlynq_soft);
        if(vlynq_rd_reg(p_vlynq_soft, False, (volatile Uint32*)&p_reg->revision) >= VLYNQ_REV_10200)
        {
            vlynq_wr_reg(p_vlynq_soft, False, (volatile Uint32*)&p_reg->control,
            vlynq_rd_reg(p_vlynq_soft, False, (volatile Uint32*)&p_reg->control) | 0x1u);

            /* Provide sufficient time for reset. Refer 2.4.2 of 2.6 VLYNQ specifications. */
            vlynq_delay_wait(0xffffffu);
            vlynq_wr_reg(p_vlynq_soft, False, (volatile Uint32*)&p_reg->control,
            vlynq_rd_reg(p_vlynq_soft, False, (volatile Uint32*)&p_reg->control) & (~0x1));
        }
    }
}

/**
  * \brief To cofigure the RTM
  *
  */
static PAL_Result vlynq_config_RTM(PAL_VLYNQ_T               * p_vlynq_rtm,
        Bool                      peer,
        PAL_VLYNQ_RTM_CFG_ENUM_T  rtm_cfg_type,
        Uint8                     rtm_sample_value,
        Bool                      tx_fast_path)
{
    /* Let us get on with the RTM configuration first. We will follow it up with the
       TX Fast path configuration. */

    /* Refer to Section 2.4.2 and 4.3.4 of 2.6 VLYNQ specifications for clarifications on
     * the configuration aspects of the RTM and Fast Path. It seems there is a window in
     * the hardware state machine, under which the configuration of the RTM and Fast Path
     * can cause hang. It is recommended in the specifications not to set the values when
     * link or auto negotiation is going on the VLYNQ bridge.
     *
     * We should be here once, the link has been established after sufficient reset time,
     * It is still ok to configure the local VLYNQ because we can configure it and check
     * for the link. For the peer VLYNQ, we must have the link to configure on the peer
     * RTM and if link goes down because of the RTM configuration on the peer VLYNQ, then
     * be ready to emberace the ultimate "the hang".
     */
    volatile Uint32 val = 0;
    VLYNQ_REG_T   * p_reg = NULL;
    PAL_Result retCode = PAL_VLYNQ_OK;

    if(p_vlynq_rtm == NULL){
        retCode = PAL_VLYNQ_INVALID_PARAM;
    }
    else{
        /* To configure Peer register check the status of link */
        if(FALSE == vlynq_detect_link_status(p_vlynq_rtm))
        {
            return (PAL_VLYNQ_NO_LINK);
        }

        p_reg = (peer == True) ? PEER_REGS(p_vlynq_rtm) : LOCAL_REGS(p_vlynq_rtm);

        if(rtm_cfg_type == rtm_auto_select_sample_val)
        {
            val = vlynq_rd_reg(p_vlynq_rtm, peer, &p_reg->control);
            val |= (RTM_ENABLE_BIT << 22);
            vlynq_wr_reg(p_vlynq_rtm, peer, &p_reg->control, val);
        }
        else if(rtm_cfg_type == rtm_force_sample_val)
        {
            if(rtm_sample_value > 0x7u)
            {
                retCode = PAL_VLYNQ_INVALID_PARAM;
            }
            else{
                /* Clear RTM enable bit & RTM sample value */
                val = vlynq_rd_reg(p_vlynq_rtm, peer, &p_reg->control);
                val &= ~((RTM_ENABLE_BIT << CSL_VLYNQ_CTRL_RTMENABLE_SHIFT) | (RTM_SAMPLE_VAL_MASK << CSL_VLYNQ_CTRL_RXSAMPELVAL_SHIFT));
                val |= (RTM_FORCE_VAL_WR << CSL_VLYNQ_CTRL_RTMVALIDWR_SHIFT) | (Uint32)((Uint32)rtm_sample_value << CSL_VLYNQ_CTRL_RXSAMPELVAL_SHIFT); /* Populate the new sample value. */
                vlynq_wr_reg(p_vlynq_rtm, peer, &p_reg->control, val);
            }
        }
        else
        {
            ; /* Nothing for now. We did not mess the RTM configuration. */
        }
        if(PAL_VLYNQ_OK == retCode){
            val = vlynq_rd_reg(p_vlynq_rtm, peer, &p_reg->control);
            val &= ~(TX_FAST_PATH << CSL_VLYNQ_CTRL_TXFASTPATH_SHIFT);    /* Clear the value of the fast path */
            val |= (tx_fast_path << CSL_VLYNQ_CTRL_TXFASTPATH_SHIFT);     /* Set the new value. */
            vlynq_wr_reg(p_vlynq_rtm, peer, &p_reg->control, val);
        }
    }
    return (retCode);
}

/**
  * \brief To configure bridge RTM
  */
static PAL_Result vlynq_config_bridge_RTM(PAL_VLYNQ_T     *p_vlynq_rtm_config,
        PAL_VLYNQ_RTM_CFG_ENUM_T       local_rtm_cfg_type,
        Uint8                          local_sample_value,
        Bool                           local_tx_fast_path,
        PAL_VLYNQ_RTM_CFG_ENUM_T       peer_rtm_cfg_type,
        Uint8                          peer_sample_value,
        Bool                           peer_tx_fast_path)
{
    PAL_Result    ret_val = PAL_VLYNQ_OK;
    VLYNQ_REG_T   *p_reg = NULL;
    Uint32        reg_status = 0;
    if(p_vlynq_rtm_config == NULL) {
        return (PAL_VLYNQ_INVALID_PARAM);
    }

    p_reg  = LOCAL_REGS(p_vlynq_rtm_config);
    reg_status = p_reg->status & ( RTM_STATUS_BIT << 11);
    if((p_reg->revision >= 0x00010205u) && (reg_status != 0))
    {
        ret_val = vlynq_config_RTM(p_vlynq_rtm_config, False, local_rtm_cfg_type, local_sample_value, local_tx_fast_path);

        if(ret_val != PAL_VLYNQ_OK) {
            return (ret_val);
        }

        /* Provide time for the bus to settle down. */
        vlynq_delay_wait(0xffffffu);
    }

    /* We must have the Link at this stage after we played with the RTM. */
    if(NULL == vlynq_detect_link_status(p_vlynq_rtm_config)){
        return (PAL_VLYNQ_NO_LINK);
    }

    p_reg = PEER_REGS(p_vlynq_rtm_config);
    reg_status = p_reg->status & ( RTM_STATUS_BIT << 11);
    if((p_reg->revision >= 0x00010205u) && (reg_status != 0))
    {
        ret_val = vlynq_config_RTM(p_vlynq_rtm_config, True, peer_rtm_cfg_type, peer_sample_value, peer_tx_fast_path);

        /* Provide time for the bus to settle down. */
        vlynq_delay_wait(0xffffffu);
    }

    return (ret_val);
}


/**
 * \brief   Configures the Clock for the VLYNQ bridge
 *
 */
PAL_Result PAL_sysVlynqConfigClock(PAL_VLYNQ_HND                *p_vlynq_clocksys,
        PAL_VLYNQ_CLOCK_DIR_ENUM_T   local_clock_dir,
        PAL_VLYNQ_CLOCK_DIR_ENUM_T   peer_clock_dir,
        Uint8                        local_clock_div,
        Uint8                        peer_clock_div)
{
    PAL_Result ret_val = PAL_VLYNQ_OK;

    if(p_vlynq_clocksys == NULL) {
        ret_val = (PAL_VLYNQ_INVALID_PARAM);
    }
    else if((local_clock_dir == pal_vlynq_clk_out) &&
            (peer_clock_dir  == pal_vlynq_clk_out))
    {

    /* Valid clock directions: Either of the peers to source the clock or both
     * of the peers to sink in external board clock.
     */

        ret_val = (PAL_VLYNQ_INVALID_PARAM);
    } else if((local_clock_div == FALSE) ||
            (peer_clock_div  == FALSE)) {
        ret_val = (PAL_VLYNQ_INVALID_PARAM);
    } else {
        ret_val = vlynq_config_bridge_clock(p_vlynq_clocksys, local_clock_dir, peer_clock_dir,
                local_clock_div, peer_clock_div);
    }

    return(ret_val);
}

/**
 * \brief   Return the Mapped Region configuration for Local/Peer
 *
 *
 * \param   p_vlynq_mapped      [IN]    Handle to the opened Resource Manager
 *
 * \param   address             [OUT]   Return values of TxMap,RxMap.size[4] & RxMap.offset[4].
 *
 * \param   peer                [IN]    The flag whether the device is associated with the local
 *                                      VLYNQ or the peer.
 *
 * \return                              void.
 *
 */
void PAL_sysVlynqMappedRegion(const PAL_VLYNQ_T * p_vlynq_mapped,  Uint32 *address, Uint32 peer)
{
    VLYNQ_REG_T  *p_reg          = NULL;
    Uint32        i              = 0;
    PAL_VLYNQ_T* dummy           = NULL;

    if((NULL != address) && (NULL != p_vlynq_mapped))
    {
        dummy = (PAL_VLYNQ_T*)p_vlynq_mapped;

        if(FALSE == peer)
        {
            p_reg       = LOCAL_REGS(p_vlynq_mapped);
            *address++ = vlynq_rd_reg(p_vlynq_mapped, False, &p_reg->txMap);
            for(i=0;i<4u;i++)
            {
                *address++ = vlynq_rd_reg(p_vlynq_mapped, False, &p_reg->rx_set[i].offset);
                *address++ = vlynq_rd_reg(p_vlynq_mapped, False, &p_reg->rx_set[i].size);
            }
        }
        else{
            /* To configure Peer register check the status of link */
            if(TRUE == vlynq_detect_link_status(dummy))
            {
            p_reg =  PEER_REGS(p_vlynq_mapped);
            * address++ = vlynq_rd_reg(p_vlynq_mapped, True, &p_reg->txMap);
                for(i=0;i<MAX_VLYNQ_REGION;i++)
            {

                *address++ = vlynq_rd_reg(p_vlynq_mapped, True, &p_reg->rx_set[i].offset);
                *address++ = vlynq_rd_reg(p_vlynq_mapped, True, &p_reg->rx_set[i].size);
            }
            }

        }
    }
}


/**
 * \brief   Initialize the VLYNQ control module
 *
 *
 * \param   pal_vlynq_config    [IN]              The collection of configuration parameters; to initialize
 *                                      the VLYNQ interface.
 *
 * \return  On failure, it returns a NULL, otherwise, it returns a valid handle to the instance so initialized.
 */
PAL_VLYNQ_HND *PAL_sysVlynqInitSoc(PAL_VLYNQ_CONFIG_T *pal_vlynq_config)
{
    PAL_VLYNQ_T                  *p_vlynq_soc        = NULL;
    VLYNQ_REG_T                 *p_reg          = NULL;
    PAL_VLYNQ_IRQ_MAP_T         *p_root_irq_map = NULL;
    PAL_VLYNQ_IRQ_INFO_T        *p_root_irq_info= NULL;
    Uint32                      val             = 0;
    Uint32                      rev_val         = 0;

    if(pal_vlynq_config == NULL)
    {
        return (NULL);
    }

    if(PAL_VLYNQ_OK != vlynq_validate_init_params(pal_vlynq_config))
    {
        pal_vlynq_config->error_status = pal_vlynq_init_invalid_param;
        strcpy(pal_vlynq_config->error_msg, "Invalid init params.");
        return (NULL);
    }

    /* We are done with the param validation and are
     * set for configuring the hardware. Here we go...*/
    p_vlynq_soc = vlynq_get_free_vlynq();
    if(p_vlynq_soc == NULL)
    {
        pal_vlynq_config->error_status = pal_vlynq_init_no_mem;
        strcpy(pal_vlynq_config->error_msg, "Mem alloc failed for VLYNQ.");
        return (NULL);
    }

    /* Let us give some more time for the VLYNQ to settle down after the
     * hardware reset.
     */
     /*Testing was done using PAL_osWaitMsecs() function here instead of the
     vlynq_delay_wait(). But it is observed that VLYNQ setup is not possible.
     Testing was also done using various ranges of delay for PAL_osWaitMsecs().
     Using the vlynq_delay_wait() function till the clock is configured*/
    vlynq_delay_wait(0xffffu);

    p_vlynq_soc->base         = pal_vlynq_config->base_addr;
    if(FALSE != pal_vlynq_config->init_swap_flag)
    {
        p_vlynq_soc->local_swap = True;
        p_vlynq_soc->peer_swap  = True;
    }

        /* Put the vlynq in reset, if the version is more than
         * 2.0 for more than 256 serial cycles. Finally bring it out
         * of reset. */
        vlynq_soft_reset(p_vlynq_soc);

#ifdef VLYNQ_LOOPBACK_MODE
    /** Set in into Loopback Mode **/
    p_reg            = LOCAL_REGS(p_vlynq_soc);
    vlynq_wr_reg(p_vlynq_soc, False,(volatile Uint32*)&p_reg->control,
    vlynq_rd_reg(p_vlynq_soc, False,(volatile Uint32*)&p_reg->control) | 0x2);
#endif

    /* Provide sufficient time for reset to settle down. Refer 2.4.6 of 2.6 VLYNQ specifications. */
    vlynq_delay_wait(0xffffffu);

    /* Do we have the link on the VLYNQ bridge on reset. We must have the
     * link on reset. It indicates that the hw state machine has  settled
     * down and hw clocks are working fine. This is must when we are sink
     * ing the clock. */

    if(((pal_vlynq_clk_out  ==  pal_vlynq_config->local_clock_dir) &&
      (pal_vlynq_clk_in     ==  pal_vlynq_config->peer_clock_dir)) != TRUE)
    {
        /* For slave mode only */
        if(PAL_VLYNQ_OK != vlynq_enable_HW_default_clock(p_vlynq_soc))
        {
            pal_vlynq_config->error_status = pal_vlynq_init_no_link_on_reset;
            strcpy(pal_vlynq_config->error_msg, "No link detected on reset.");
            goto pal_vlynq_init_link_error_1;
        }
    }
    if(PAL_VLYNQ_OK != vlynq_config_bridge_clock(p_vlynq_soc,
                pal_vlynq_config->local_clock_dir,
                pal_vlynq_config->peer_clock_dir,
                pal_vlynq_config->local_clock_div,
                pal_vlynq_config->peer_clock_div))
    {

        pal_vlynq_config->error_status =  pal_vlynq_init_clk_cfg;
        strcpy(pal_vlynq_config->error_msg, "Error in configuring clocks.");
        goto pal_vlynq_init_clock_config_error;
    }

    /* Let us wait for the Link to settle down. */
    vlynq_delay_wait(0xfffff);


    /* We have just updated the clock, let us check the health of the link.
     * We must have the link, if not it is over for us. */
    if(NULL == vlynq_detect_link_status(p_vlynq_soc))
    {
        pal_vlynq_config->error_status = pal_vlynq_init_no_link_on_clk_cfg;
        strcpy(pal_vlynq_config->error_msg, "No link detected post clk config.");
        goto pal_vlynq_init_link_error_2;
    }

    /* We must clear the spur interrupts. */
    if(((pal_vlynq_clk_out  ==  pal_vlynq_config->local_clock_dir) &&
      (pal_vlynq_clk_in     ==  pal_vlynq_config->peer_clock_dir)) == TRUE)
    {
        /* Peer configuration from master side*/

        p_reg            = PEER_REGS(p_vlynq_soc);
        vlynq_wr_reg(p_vlynq_soc, True, (volatile Uint32*)&p_reg->status,
        vlynq_rd_reg(p_vlynq_soc, True, (volatile Uint32*)&p_reg->status) | CSL_VLYNQ_STAT_RERROR_MASK | CSL_VLYNQ_STAT_LERROR_MASK);

        p_reg            = LOCAL_REGS(p_vlynq_soc);
        vlynq_wr_reg(p_vlynq_soc, False,(volatile Uint32*)&p_reg->status,
        vlynq_rd_reg(p_vlynq_soc, False,(volatile Uint32*)&p_reg->status) | CSL_VLYNQ_STAT_RERROR_MASK | CSL_VLYNQ_STAT_LERROR_MASK);

        /* Are we equipped enough to support the VLYNQ bridge ? */

        p_reg         = PEER_REGS(p_vlynq_soc);
        rev_val = vlynq_rd_reg(p_vlynq_soc, True, &p_reg->revision);

        if( rev_val > LATEST_VLYNQ_REV)
        {
            pal_vlynq_config->error_status = pal_vlynq_init_peer_high_rev;
            strcpy(pal_vlynq_config->error_msg, "Peer VLYNQ revision higher than SW.");
            goto pal_vlynq_init_peer_rev_error;
        }

        p_reg         = LOCAL_REGS(p_vlynq_soc);
        rev_val = vlynq_rd_reg(p_vlynq_soc, False, &p_reg->revision);
        if(rev_val > LATEST_VLYNQ_REV)
        {
            pal_vlynq_config->error_status = pal_vlynq_init_local_high_rev;
            strcpy(pal_vlynq_config->error_msg, "Local VLYNQ revision higher than SW.");
            goto pal_vlynq_init_local_rev_error;
        }


        /* Let us configure the RTM for VLYNQ 2.5 and higher. */
        if(PAL_VLYNQ_OK != vlynq_config_bridge_RTM(p_vlynq_soc,
                                    pal_vlynq_config->local_rtm_cfg_type,
                                    pal_vlynq_config->local_rtm_sample_value,
                                    pal_vlynq_config->local_tx_fast_path,
                                    pal_vlynq_config->peer_rtm_cfg_type,
                                    pal_vlynq_config->peer_rtm_sample_value,
                                    pal_vlynq_config->peer_tx_fast_path))
        {
            pal_vlynq_config->error_status = pal_vlynq_init_rtm_cfg;
            strcpy(pal_vlynq_config->error_msg, "Error in configuring RTM.");
            goto pal_vlynq_init_rtm_config_error;
        }

        /* We have just updated the RTM, let us check the health of the link.
        * We must have the link, if not it is over for us. */
        if(NULL == vlynq_detect_link_status(p_vlynq_soc))
        {
            pal_vlynq_config->error_status = pal_vlynq_init_no_link_on_rtm_cfg;
            strcpy(pal_vlynq_config->error_msg, "No link detected post RTM config.");
            goto pal_vlynq_init_link_error_3;
        }

        /* Again, We must clear the spur interrupts. */
        p_reg            = PEER_REGS(p_vlynq_soc);
        vlynq_wr_reg(p_vlynq_soc, True, (volatile Uint32*)&p_reg->status,
        vlynq_rd_reg(p_vlynq_soc, True, (volatile Uint32*)&p_reg->status) | CSL_VLYNQ_STAT_RERROR_MASK | CSL_VLYNQ_STAT_LERROR_MASK);

        p_reg            = LOCAL_REGS(p_vlynq_soc);
        vlynq_wr_reg(p_vlynq_soc, False, (volatile Uint32*)&p_reg->status,
        vlynq_rd_reg(p_vlynq_soc, False, (volatile Uint32*)&p_reg->status) | CSL_VLYNQ_STAT_RERROR_MASK | CSL_VLYNQ_STAT_LERROR_MASK);
    }
    /* Let us go ahead and initialize the interal interrupts mechanisms
     * for the local VLYNQ. */
    if(FALSE != pal_vlynq_config->on_soc)
    {
        p_root_irq_map  = vlynq_get_free_irq_map();
        p_root_irq_info = vlynq_get_free_irq_info();

        if((NULL == p_root_irq_map) || (NULL == p_root_irq_info))
        {
            pal_vlynq_config->error_status = pal_vlynq_init_internal_problem;
            strcpy(pal_vlynq_config->error_msg, "Could not allocate root irq structs.");
            goto pal_vlynq_init_root_irq_map_error;
        }
    }
    p_vlynq_soc->soc           = pal_vlynq_config->on_soc;
    p_vlynq_soc->root_irq_map  = p_root_irq_map;
    p_vlynq_soc->root_irq_info = p_root_irq_info;

    if(pal_vlynq_config->on_soc != 0 )
    {
        if (PAL_VLYNQ_OK != vlynq_add_root(p_vlynq_soc))
        {
            pal_vlynq_config->error_status = pal_vlynq_init_internal_problem;
            strcpy(pal_vlynq_config->error_msg, "Could not add root vlynq.");
            goto pal_vlynq_init_root_add_error;
        }
    }

    if(PAL_VLYNQ_OK != vlynq_install_intern_isr(p_vlynq_soc, pal_vlynq_config))
    {
        pal_vlynq_config->error_status = pal_vlynq_init_internal_problem;
        strcpy(pal_vlynq_config->error_msg, "Could not install internal isr.");
        goto pal_vlynq_init_install_intern_isr_error;
    }

    if(TRUE == p_vlynq_soc->soc)
    {
        if(PAL_VLYNQ_OK != vlynq_add_intern_isr(p_vlynq_soc, pal_vlynq_config->local_intr_vector,
                    p_vlynq_soc->local_isr_info))
        {
            pal_vlynq_config->error_status = pal_vlynq_init_internal_problem;
            strcpy(pal_vlynq_config->error_msg, "Could not add local isr.");
            goto pal_vlynq_init_add_intern_local_isr_error;
        }

        if(PAL_VLYNQ_OK != vlynq_add_intern_isr(p_vlynq_soc, pal_vlynq_config->peer_intr_vector,
                    p_vlynq_soc->peer_isr_info))
        {
            pal_vlynq_config->error_status = pal_vlynq_init_internal_problem;
            strcpy(pal_vlynq_config->error_msg, "Could not add peer isr.");
            goto pal_vlynq_init_add_intern_peer_isr_error;
        }
    }

    if(((pal_vlynq_clk_out  ==  pal_vlynq_config->local_clock_dir) &&
      (pal_vlynq_clk_in     ==  pal_vlynq_config->peer_clock_dir)) == TRUE)
    {
        /* Peer setting from master side */
        /* To configure Peer register check the status of link */
        if(False == vlynq_detect_link_status(p_vlynq_soc))
        {
            pal_vlynq_config->error_status = pal_vlynq_init_internal_problem;
            strcpy(pal_vlynq_config->error_msg, "No link detected on adding isr.");
            goto pal_vlynq_init_link_error_2;
        }

        p_reg            = PEER_REGS(p_vlynq_soc);
        vlynq_wr_reg(p_vlynq_soc, True, (volatile Uint32*)&p_reg->txMap, pal_vlynq_config->peer_tx_addr);
        vlynq_wr_reg(p_vlynq_soc, True, (volatile Uint32*)&p_reg->status,
        vlynq_rd_reg(p_vlynq_soc, True, (volatile Uint32*)&p_reg->status) | 0x180);

        val              = vlynq_rd_reg(p_vlynq_soc, True, (volatile Uint32*)&p_reg->intStatus);
        vlynq_wr_reg(p_vlynq_soc, True, (volatile Uint32*)&p_reg->intStatus, val);

        p_reg            = LOCAL_REGS(p_vlynq_soc);
        vlynq_wr_reg(p_vlynq_soc, False, (volatile Uint32*)&p_reg->txMap, pal_vlynq_config->local_tx_addr);
        vlynq_wr_reg(p_vlynq_soc, False, (volatile Uint32*)&p_reg->status,
        vlynq_rd_reg(p_vlynq_soc, True, (volatile Uint32*)&p_reg->status) | 0x180);

        val              = vlynq_rd_reg(p_vlynq_soc, False, (volatile Uint32*)&p_reg->intStatus);
        vlynq_wr_reg(p_vlynq_soc, False, (volatile Uint32*)&p_reg->intStatus, val);

#ifdef INCLUDE_ENDIAN_REGISTER
        vlynq_config_bridge_endianness(p_vlynq_soc,
        pal_vlynq_config->local_endianness,
        pal_vlynq_config->peer_endianness);
#endif
        pal_vlynq_config->error_status = pal_vlynq_init_success;
        strcpy(pal_vlynq_config->error_msg, "Success");
    }
    return (PAL_VLYNQ_HND *)(p_vlynq_soc);

pal_vlynq_init_add_intern_peer_isr_error:

    vlynq_remove_intern_isr(p_vlynq_soc, pal_vlynq_config->local_intr_vector,
            p_vlynq_soc->local_isr_info);

pal_vlynq_init_add_intern_local_isr_error:

    if(((pal_vlynq_clk_out  ==  pal_vlynq_config->local_clock_dir) &&
      (pal_vlynq_clk_in     ==  pal_vlynq_config->peer_clock_dir)) == TRUE)
    {
        /* Uninstall Interrupt for master only */
        vlynq_uninstall_intern_isr(p_vlynq_soc);
    }
pal_vlynq_init_install_intern_isr_error:

    if(TRUE == pal_vlynq_config->on_soc) {
        vlynq_remove_root(p_vlynq_soc);
    }

pal_vlynq_init_root_add_error:
    if((pal_vlynq_config->on_soc != 0) && (NULL != p_vlynq_soc->root_irq_info)) {
        vlynq_free_irq_info(p_vlynq_soc->root_irq_info);
    }

    if((pal_vlynq_config->on_soc != 0) && (NULL != p_vlynq_soc->root_irq_info)){
        vlynq_free_irq_map(p_vlynq_soc->root_irq_map);
    }

pal_vlynq_init_root_irq_map_error:

pal_vlynq_init_link_error_3:
pal_vlynq_init_rtm_config_error:

pal_vlynq_init_local_rev_error:
pal_vlynq_init_peer_rev_error:

pal_vlynq_init_link_error_2:
pal_vlynq_init_clock_config_error:

pal_vlynq_init_link_error_1:
    vlynq_free_vlynq(p_vlynq_soc);
    p_vlynq_soc = NULL;
    return (PAL_VLYNQ_HND *)(p_vlynq_soc);
}

/**
 * \brief   Un-Initialize the VLYNQ control module.
 *
 *
 * \param   vlynq    [IN]    Handle to the VLYNQ module instance; would have been returned by PAL_sysVlynqInit( ).
 *                           Consequence of using this handle after a call to this function
 *                           is undefined.
 *
 * \return  PAL_VLYNQ_OK on success., negative on error
 */
PAL_Result PAL_sysVlynqCleanUp(PAL_VLYNQ_HND *vlynq)
{
    PAL_VLYNQ_T     *p_vlynq_cleanup  = NULL;
    volatile Uint32 val = 0;
    VLYNQ_REG_T     *p_reg = NULL;
    PAL_Result      temp_ret_val = PAL_VLYNQ_OK;
    PAL_Result      ret_val = PAL_VLYNQ_INVALID_PARAM;

    if(NULL == vlynq) {
        return  (PAL_VLYNQ_INVALID_PARAM);
    }
    p_vlynq_cleanup = (PAL_VLYNQ_T*)vlynq;

    p_reg               = LOCAL_REGS(p_vlynq_cleanup);
    if(p_reg == NULL) {
        return (PAL_VLYNQ_INVALID_PARAM);
    }

    val                 = vlynq_rd_reg(p_vlynq_cleanup, False, &p_reg->intStatus);
    vlynq_wr_reg(p_vlynq_cleanup, False, &p_reg->intStatus, val);

    val                 = vlynq_rd_reg(p_vlynq_cleanup, False, &p_reg->status);
    val                |= (VLYNQ_STS_LERR_RERR);
    vlynq_wr_reg(p_vlynq_cleanup, False, &p_reg->status, val);
    p_reg->txMap        = 0;

    if(FALSE == vlynq_detect_link_status(p_vlynq_cleanup))
    {
        ret_val = PAL_VLYNQ_NO_LINK;
    }
    else
    {
    p_reg               = PEER_REGS(p_vlynq_cleanup);
    if(p_reg == NULL) {
        return (PAL_VLYNQ_INVALID_PARAM);
    }

    val                 = vlynq_rd_reg(p_vlynq_cleanup, True, &p_reg->intStatus);
    vlynq_wr_reg(p_vlynq_cleanup, True, &p_reg->intStatus, val);

    val                 = vlynq_rd_reg(p_vlynq_cleanup, True, &p_reg->status);
    val                |= VLYNQ_STS_LERR_RERR;
    vlynq_wr_reg(p_vlynq_cleanup, True, &p_reg->status, val);

    p_reg->txMap        = 0;
    }


    /*
     * Here, we can not do much about the errors. We simply keep moving on
     * and return the error status. Thats all we can do.
     */
    temp_ret_val = vlynq_remove_intern_isr(p_vlynq_cleanup, p_vlynq_cleanup->local_irq,
            p_vlynq_cleanup->local_isr_info);
    if(temp_ret_val == PAL_VLYNQ_OK) {
        ret_val = temp_ret_val;
    }
    temp_ret_val = vlynq_remove_intern_isr(p_vlynq_cleanup, p_vlynq_cleanup->peer_irq,
            p_vlynq_cleanup->peer_isr_info);

    if(temp_ret_val == PAL_VLYNQ_OK) {
        ret_val = temp_ret_val;
    }

    temp_ret_val = vlynq_uninstall_intern_isr(p_vlynq_cleanup);
    if(temp_ret_val == PAL_VLYNQ_OK) {
        ret_val = temp_ret_val;
    }

    if(TRUE == p_vlynq_cleanup->soc ) {
        vlynq_remove_root(p_vlynq_cleanup);
    }

    vlynq_free_irq_map(p_vlynq_cleanup->root_irq_map);
    vlynq_free_irq_info(p_vlynq_cleanup->root_irq_info);

    p_reg = LOCAL_REGS(p_vlynq_cleanup);

    /* Put the the local device in reset. */
    if(vlynq_rd_reg(p_vlynq_cleanup, False, (volatile Uint32*)&p_reg->revision) >= VLYNQ_REV_10200)
    {
        vlynq_wr_reg(p_vlynq_cleanup, False, (volatile Uint32*)&p_reg->control,
        vlynq_rd_reg(p_vlynq_cleanup, False, (volatile Uint32*)&p_reg->control) | 0x1);
    }

    vlynq_free_vlynq(p_vlynq_cleanup);

    return (ret_val);
}

/*
 *  This function gives back the popular name against the id passed
 *
 *  Input:
 *          id          [IN]   ID which maps to the popular names
 *          soc_name    [OUT]  String which contains the name
 *
 *  Return:
 * \return  PAL_VLYNQ_OK on success., negative on error
 */
static Char* vlynq_get_popular_name(Uint32 id,  Char *soc_name)
{
    const Char *name = NULL;

    switch(id)
    {
        case 0x0001:{
                        name = "avalanche-i";
                        break;
                    }

        case 0x0002:{
                        name = "avalanche-d";
                        break;
                    }

        case 0x0003:{
                        name = "taos";
                        break;
                    }

        case 0x0004:{
                        name = "puma";
                        break;
                    }

        case 0x0104:{
                        name = "puma-s";
                        break;
                    }

        case 0x0204:{
                        name = "puma-III";
                        break;
                    }

        case 0x0304:{
                        name = "puma-IV";
                        break;
                    }

        case 0x0005:{
                        name = "sangam";
                        break;
                    }

        case 0x0006:{
                        name = "vdsp";
                        break;
                    }

        case 0x0007:{
                        name = "titan";
                        break;
                    }

        case 0x0008:{
                        name = "vlynq2pci";
                        break;
                    }

        case 0x0009:{
                        name = "acx111";
                        break;
                    }

        case 0x000b:{
                        name = "apex";
                        break;
                    }

        case 0x000c:{
                        name = "vlynq2usb";
                        break;
                    }
        case 0x000d:{
                        name = "vlynq2ipsec";
                        break;
                    }

        case 0x000e:{
                        name = "omap730";
                        break;
                    }

        case 0x000f:{
                        name = "omap1611";
                        break;
                    }

        case 0x0010:{
                        name = "omap1710";
                        break;
                    }

        case 0x0011:{
                        name = "tnetw1150";
                        break;
                    }

        case 0x0012:{
                        name = "omap331";
                        break;
                    }

        case 0x0013:{
                        name = "DM320";
                        break;
                    }
        case 0x0014:{
                        name = "omap2410";
                        break;
                    }

        case 0x0015:{
                        name = "omap2420";
                        break;
                    }

        case 0x0016:{
                        name = "huawei-SD705";
                        break;
                    }

        case 0x0017:{
                        name = "trinity";
                        break;
                    }

        case 0x0018:{
                        name = "ohio";
                        break;
                    }

        case 0x0019:{
                        name = "sierra";
                        break;
                    }

        case 0x0020:{
                        name = "Psyloke";
                        break;
                    }

        case 0x0021:{
                        name = "tnetw1251";
                        break;
                    }

        case 0x0022:{
                        name = "himalaya";
                        break;
                    }

        case 0x0023:{
                        name = "monticello";
                        break;
                    }

        case 0x0024:{
                        name = "DDP3020";
                        break;
                    }

        case 0x0025:{
                        name = "Davinci";
                        break;
                    }

        case 0x0026:{
                        name = "TUSB6010";
                        break;
                    }

        case 0x0027:{
                        name = "tnetw1160";
                        break;
                    }

        case 0x0028:{
                        name = "petra";
                        break;
                    }

        case 0x0029:{
                        name = "1150v";
                        break;
                    }

        case 0x002a:{
                        name = "triveni";
                        break;
                    }
        case 0x002b:{
                        name = "ohio250";
                        break;
                    }

        case 0x002c:{
                        name = "tomahawk";
                        break;
                    }

        case 0x002d:{
                        name = "dm6437";
                        break;
                    }

        case 0x002e:{
                        name = "jacinto";
                        break;
                    }

        case 0x002f:{
                        name = "aries";
                        break;
                    }

        case 0x0030:{
                        name = "yamuna";
                        break;
                    }

        case 0x0031:{
                        name = "dm648";
                        break;
                    }

        case 0x0032:{
                        name = "Passave-PON";
                        break;
                    }

        case 0x0033:{
                        name = "Davinci-HD";
                        break;
                    }

        default:{
                    name = "unknown";
                    break;
                }
    }

    if( ( soc_name != NULL) && (name != NULL ))
    {
        strcpy(soc_name, name);
    }
    return (soc_name);
}

/*
 *  This function dumps the register information depending on local or peer
 *
 *  Input:
 *          p_vlynq_dump    [IN]    handle to the vlynq
 *          buf             [OUT]   pointer to the buffer to hold the dump
 *          limit           [IN]    limit of data to be dumped
 *          eof             [OUT]   whether the buffer was insufficient or not
 *
 *  Return:
 *          returns the length of data dumped
 */
static Int32 vlynq_dump_raw(const PAL_VLYNQ_T * p_vlynq_dump, Char *buf,
        Uint32 limit, Uint32 *eof,
        Bool peer)
{
    Uint8 *p_addr = NULL;
    Int32 i = 0;
    Int32 j = 0;
    Int32 len = 0;
    PAL_VLYNQ_T* dummy = (PAL_VLYNQ_T*)p_vlynq_dump;

    /* To configure Peer register check the status of link */
    if ( ( (buf != NULL) && (p_vlynq_dump != NULL)) &&
         ( (eof != NULL) && (TRUE == vlynq_detect_link_status(dummy))))
    {
        p_addr = ((peer == True) ? (Uint8 * )PEER_REGS(p_vlynq_dump): (Uint8* )LOCAL_REGS(p_vlynq_dump));

        if(p_addr != NULL)
        {
            for(i=0; i < 16; i++)
            {
                if(len < limit) {
                    len += sprintf(buf + len, "%08x:", (Uint32)p_addr);
                }
                else {
                    break;
                }

                for(j=0; j < 8; j++)
                {
                    if(((j%4)==0) && (len < limit))
                    {
                        len += sprintf(buf + len, " ");
                    }

                    if(len  < limit)
                    {
                        len += sprintf(buf + len, "%02x ", (Uint32)*p_addr++);
                    }
                    else {
                        break;
                    }

                }
                if(len < limit) {
                    len += sprintf(buf + len, "\n");
                }
                else {
                    break;
                }
            }
        }
    }
    return (len);

}

/*
 *  This function checks the presence of the link till root and then dumps registers
 *  depending on whether on SOC or not
 *
 *  Input:
 *          vlynq         [IN]  handle to the vlynq
 *          buf             [OUT]   pointer to the buffer to hold the dump
 *          limit           [IN]    limit of data to be dumped
 *          eof             [OUT]   whether the buffer was insufficient or not
 *
 *  Return:
 *          returns the length of data dumped
 */
static Int32 vlynq_dump_raw_reg( PAL_VLYNQ_HND *vlynq, Char *buf,
        Uint32 limit, Uint32 *eof)
{
    PAL_VLYNQ_T *p_vlynq_raw_reg = NULL;
    Int32            len = 0;

    if((vlynq == NULL) || (buf == NULL)){
        return (len);
    }
    p_vlynq_raw_reg = (PAL_VLYNQ_T*)vlynq;

    if(FALSE == p_vlynq_raw_reg->soc)
    {
        if(FALSE == vlynq_touch_vlynq_through_chain(p_vlynq_raw_reg))
        {
            len += sprintf(buf + len, "Link failure.\n");
            return (len);
        }
    }

    len = vlynq_dump_raw(p_vlynq_raw_reg, buf, limit, eof, False);

    if(FALSE == vlynq_touch_vlynq_through_chain(p_vlynq_raw_reg))
    {
        len += sprintf(buf + len, "Link to peer failed.\n");
        return (len);
    }

    return (len + vlynq_dump_raw(p_vlynq_raw_reg, buf + len, (limit - (Uint32)len), eof, True));
}

/*
 *  This function finds the number of hops of the vlynq from the root
 *
 *  Input:
 *          p_root_vlynq         [IN]   handle to the root vlynq
 *          this_vlynq      [IN]   number of hops of this handle from the root
 *
 *  Return:
 *         number of hops ; error on failure
 */
static Int32 vlynq_get_hop_in_chain(PAL_VLYNQ_T *p_root_vlynq, PAL_VLYNQ_T *this_vlynq)
{
    PAL_VLYNQ_T * p_vlynq_hop = NULL;
    Int32       hop = PAL_VLYNQ_INVALID_PARAM;
    Int32       found = 0;

    if((p_root_vlynq == NULL) || (this_vlynq == NULL)){
        return (PAL_VLYNQ_INTERNAL_ERROR);
    }
    p_vlynq_hop = p_root_vlynq;
    do
    {
        hop++;

        if(p_vlynq_hop == this_vlynq)
        {
            found = 1;
            break;
        }

        p_vlynq_hop = p_vlynq_hop->next;

    } while(p_vlynq_hop);

    return ( found ? hop : PAL_VLYNQ_INTERNAL_ERROR);
}


static Int32 vlynq_dump_root_vlynq( PAL_VLYNQ_T *p_root_vlynq, Int32 root, Char *buf,
        Int32 limit, Int32 *eof)
{
    PAL_VLYNQ_IRQ_MAP_T *p_irq_map = NULL;
    Int32 irq = 0;
    Int32 hop = 0;
    Int32 len = 0;


    if ( ((buf != NULL) && (p_root_vlynq != NULL)) && (eof != NULL) ) {
        if(len < limit) {
            len += sprintf(buf + len, "\nRoot Vlynq %d 0x%08x\n  IRQ Mapping:\n    ",
                    root, p_root_vlynq->base);
        }
        for(p_irq_map = p_root_vlynq->root_irq_map;
                ((p_irq_map != NULL) && (irq < MAX_IRQ_PER_CHAIN));
                irq++)
        {
            Int disp_count = 0;

            if(p_irq_map->hw_intr_line != PAL_VLYNQ_INVALID_PARAM)
            {
                hop = vlynq_get_hop_in_chain(p_root_vlynq, p_irq_map->vlynq);

                if(hop > -1)
                {
                    if(len < limit)
                    {
                        len += sprintf(buf + len, "%d for Bridge %d%d %s hw-line %d, ",
                                irq, root, hop,
                                p_irq_map->peer ? "remote" : "local",
                                p_irq_map->hw_intr_line);
                        disp_count++;
                        if(FALSE == (disp_count % 8))
                        {
                            if(len < limit) {
                                len += sprintf(buf + len, "\n");
                            }
                        }
                        if(FALSE == (disp_count % 2))
                        {
                            if(len < limit)
                            {
                                len += sprintf(buf + len, "\n    ");
                            }
                        }
                    }

                }
            }
            p_irq_map++;
        }
        if(len < limit) {
            len += sprintf(buf + len, "\n");
        }
    }
    return (len);
}


/*This function dumps the vlynq configuration txmap,rxmap,etc*/
static Int32 vlynq_dump_vlynq(PAL_VLYNQ_T *p_vlynq_vlynq_dump, Char *buf, Int32 limit, Int32 *eof)
{
    Int32 index, len = 0;
    VLYNQ_REG_T *p_local_reg = NULL;
    VLYNQ_REG_T *p_peer_reg = NULL;
    PAL_VLYNQ_DEV_HND *p_vlynq_dev_hnd = NULL;

    if( ( (p_vlynq_vlynq_dump == NULL) || (buf == NULL)) || (eof == NULL)) {
        return (len);
    }
    /* To configure Peer register check the status of link */
    if(FALSE == vlynq_detect_link_status(p_vlynq_vlynq_dump))
    {
        return (PAL_VLYNQ_NO_LINK);
    }

    p_local_reg = LOCAL_REGS(p_vlynq_vlynq_dump);
    p_peer_reg  = PEER_REGS(p_vlynq_vlynq_dump);
    if(len < limit) {
        len += sprintf(buf + len, "  Tx Mapping:\n");
    }

    if(len < limit) {
        len += sprintf(buf + len, "    %22s 0x%08x <-> 0x%08x\n", " ",
                vlynq_rd_reg(p_vlynq_vlynq_dump, False, &p_local_reg->txMap),
                vlynq_rd_reg(p_vlynq_vlynq_dump, True,  &p_peer_reg->txMap));
    }

    if(len < limit) {
        len += sprintf(buf + len, "  Rx Mapping:\n");
    }

    for(index = 0; index < MAX_VLYNQ_REGION; index++)
    {
        PAL_VLYNQ_REGION_INFO_T *p_lregion = &p_vlynq_vlynq_dump->local_region_info[index];
        PAL_VLYNQ_REGION_INFO_T *p_rregion = &p_vlynq_vlynq_dump->remote_region_info[index];

        if(len < limit) {
            len += sprintf(buf + len, "    Rx[%d]: ", index);
        }

        if(p_lregion->owner_dev_index != PAL_VLYNQ_INVALID_PARAM)
        {
            if(len < limit)
            {
                len += sprintf(buf + len, "S:0x%08x, O:0x%08x <-> ",
                        vlynq_rd_reg(p_vlynq_vlynq_dump, False, &p_local_reg->rx_set[index].size),
                        vlynq_rd_reg(p_vlynq_vlynq_dump, False, &p_local_reg->rx_set[index].offset));
            }
        }
        else
        {
            if(len < limit)
            {
                len += sprintf(buf + len, "<-> ");
            }
        }

        if(p_rregion->owner_dev_index != PAL_VLYNQ_INVALID_PARAM)
        {
            if(len < limit)
            {
                len += sprintf(buf + len, "S:0x%08x, O:0x%08x",
                        vlynq_rd_reg(p_vlynq_vlynq_dump, True, &p_peer_reg->rx_set[index].size),
                        vlynq_rd_reg(p_vlynq_vlynq_dump, True, &p_peer_reg->rx_set[index].offset));
            }
        }

        if(len < limit) {
            len += sprintf(buf + len, "\n");
        }
    }

    if(len < limit) {
        len += sprintf(buf + len, "  Local devices:\n");
    }

    for( index = 0; index < MAX_DEV_PER_VLYNQ; index++)
    {
        p_vlynq_dev_hnd = p_vlynq_vlynq_dump->local_dev[index];

        if(NULL != p_vlynq_dev_hnd)
        {
            if(len < limit) {
                len += vlynq_dev_dump_dev(p_vlynq_dev_hnd, buf+len, limit-len, eof);
            }
        }
    }

    if(len < limit) {
        len += sprintf(buf + len, "\n  Remote devices:\n");
    }

    for( index = 0; index < MAX_DEV_PER_VLYNQ; index++)
    {
        p_vlynq_dev_hnd = p_vlynq_vlynq_dump->peer_dev[index];

        if(NULL != p_vlynq_dev_hnd)
        {
            if(len < limit) {
                len += vlynq_dev_dump_dev(p_vlynq_dev_hnd, buf+len, limit-len, eof);
            }
        }
    }

    return (len);
}

static Int32 vlynq_dump_global(Char *buf, Int32 limit, Int32 *eof)
{
    Int32 root = 0;
    Int32 len = 0;
    Int32 hop = 0;

    if((buf == NULL) || (eof == NULL)) {
        return (len);
    }

    for(root = 0; root < MAX_ROOT_VLYNQ; root++)
    {
        PAL_VLYNQ_T *p_root_vlynq = root_pal_vlynq[root];
        PAL_VLYNQ_T *p_vlynq_global      = p_root_vlynq;

        if(p_root_vlynq != NULL) {
            if(len < limit) {
                len += vlynq_dump_root_vlynq(p_root_vlynq, root, buf+len, limit-len, eof);
            }

            if(FALSE == vlynq_detect_link_status(p_root_vlynq))
            {
                if(len < limit){
                    len += sprintf(buf + len, "Link failure for Bridge %d0.\n", root);
                }

            }
            else{
                hop = 0;
                while(p_vlynq_global)
                {
                    VLYNQ_REG_T *p_local_reg = LOCAL_REGS(p_vlynq_global);
                    VLYNQ_REG_T *p_peer_reg  = PEER_REGS(p_vlynq_global);
                    Char lname[30], pname[30];

                    if(len < limit) {
                        len += sprintf(buf + len, "\nVlynq Bridge %d%d :", root, hop);
                    }

                    if(FALSE == vlynq_detect_link_status(p_vlynq_global))
                    {
                        if(len < limit) {
                            len += sprintf(buf + len, "Link failure for Bridge %d%d\n",
                                    root, hop);
                        }
                        break;
                    }

                    if(len < limit) {
                        len += sprintf(buf + len, "%20s <-> %s\n",
                                vlynq_get_popular_name(vlynq_rd_reg(p_vlynq_global, False, &p_local_reg->chipVersion) & 0xffff, lname),
                                vlynq_get_popular_name(vlynq_rd_reg(p_vlynq_global, True, &p_peer_reg->chipVersion) & 0xffff, pname));
                    }
                    if(len < limit) {
                        len += vlynq_dump_vlynq(p_vlynq_global, (buf + len), (limit-len), eof);
                    }

                    p_vlynq_global = p_vlynq_global->next;
                    hop++;
                }
            }
        }
    }

    *eof = 1;
    return (len);

}

/**
 * \brief   Dumps vital VLYNQ information into the buffer.
 *
 *
 * \param   vlynq                [IN]    The vlynq instance for which the dump has to be provided.
 * \param   dump_type            [IN]   Identifies the information being sought.Some of the commands can be raw byte dump of the hardware, complete chain dump, raw register values or specific
 *                                      register value with enumeration such as status register or control register
 * \param   buf                  [IN]    The placeholder for the buffer. After the function, the buffer can be printed out for reading and information.
 * \param   limit                [IN]    The size of the buffer. It is strongly recommended to provide a buffer of at least 4096 bytes.
 * \param   eof                  [IN]    Whether the buffer was insufficient.
 *
 * \return  The number of bytes that have been formatted and placed in the buffer,-1 on error.
 */
Int32 PAL_sysVlynqDump(PAL_VLYNQ_HND *vlynq, Uint32 dump_type,
        Char *buf, Int32 limit, Int32 *eof)
{
    Int32 len = 0, valid = 0;
    volatile Uint32 *local_addr = NULL, *peer_addr = NULL;
    VLYNQ_REG_T *p_reg = NULL;
    PAL_VLYNQ_T *p_vlynq_sys_dump = NULL;

    if( ((vlynq == NULL) || (buf == NULL)) ||
        ((eof == NULL) || (0 > limit)))
    {
        return (len);
    }

    p_vlynq_sys_dump = (PAL_VLYNQ_T *)vlynq;
    p_reg   = LOCAL_REGS(p_vlynq_sys_dump);

    if(dump_type == PAL_VLYNQ_DUMP_RAW_DATA)
    {
        return (vlynq_dump_raw_reg(p_vlynq_sys_dump, buf, (Uint32)limit,(Uint32*)eof));
    }

    if(dump_type == PAL_VLYNQ_DUMP_ALL_ROOT) {
        return (vlynq_dump_global(buf, limit, eof));
    }

    if(p_reg == NULL) {
        return (PAL_VLYNQ_INVALID_PARAM);
    }

    switch(dump_type)
    {

        case PAL_VLYNQ_DUMP_STS_REG:

            local_addr = (volatile Uint32 *)&p_reg->status;
            p_reg = PEER_REGS(p_vlynq_sys_dump);
            peer_addr  = (volatile Uint32 *)&p_reg->status;
            break;

        case PAL_VLYNQ_DUMP_CNTL_REG:

            local_addr = (volatile Uint32 *)&p_reg->control;
            p_reg = PEER_REGS(p_vlynq_sys_dump);
            peer_addr  = (volatile Uint32 *)&p_reg->control;
            break;

        case PAL_VLYNQ_DUMP_ALL_REGS:

            local_addr = (volatile Uint32 *)p_reg;
            p_reg = PEER_REGS(p_vlynq_sys_dump);
            peer_addr  = (volatile Uint32 *)p_reg;
            break;

        default:
            valid = PAL_VLYNQ_INVALID_PARAM;
            break;
    }

    if(valid == PAL_VLYNQ_INVALID_PARAM) {
        return (len);
    }

    p_reg = LOCAL_REGS(p_vlynq_sys_dump);

    if(len < limit) {
        len += sprintf(buf + len, "\nLocal ver#: 0x%08x\n\n",
                vlynq_rd_reg(p_vlynq_sys_dump, False, &p_reg->revision));
    }

    vlynq_swap_hack = p_vlynq_sys_dump->local_swap;

    if(len < limit) {
        len += vlynq_dump_ioctl (local_addr, dump_type, buf + len, limit - len,
                vlynq_rd_reg(p_vlynq_sys_dump, False, &p_reg->revision));
    }

    if(FALSE == vlynq_touch_vlynq_through_chain(p_vlynq_sys_dump))
    {
        len += sprintf(buf + len, "Link to peer failed.\n");
        return (len);
    }

    p_reg = PEER_REGS(p_vlynq_sys_dump);

    if(len < limit) {
        len += sprintf(buf + len, "\nPeer/Remote ver#: 0x%08x\n\n",
                vlynq_rd_reg(p_vlynq_sys_dump, True, &p_reg->revision));
    }

    vlynq_swap_hack = p_vlynq_sys_dump->peer_swap;

    if(len < limit) {
        len += vlynq_dump_ioctl (peer_addr, dump_type, buf + len, limit - len,
                vlynq_rd_reg(p_vlynq_sys_dump, True, &p_reg->revision));
    }
    *eof = 1;
    return (len);
}

/**< To read or write */
extern PAL_Result vlynq_read_write_ioctl(volatile Uint32 *p_start_reg, Uint32 cmd,
        Uint32 *pVal, Uint32 vlynq_rev);

/* Cmd Code:
 *
 * -------------------------------------------------------------------------------------------------------------------------
 * |31: Bitop | 30: R/W* |29: Remote | 28-24:reserved | 23-16 major id of entity | 15-8 reserved|7 - 0 minor id of entity  |
 * -------------------------------------------------------------------------------------------------------------------------
 */

static PAL_Result vlynq_non_bit_op_ioctl(PAL_VLYNQ_T * p_vlynq_ioctl, Uint32 cmd, Uint32 *cmd_val)
{
    VLYNQ_REG_T *p_vlynq_reg;
    volatile Uint32      *p_start_reg   = NULL;

    PAL_Result           ret_val    = 0;
    Uint32               vlynq_rev  = 0;
    volatile Uint32      val        = 0;

    if(p_vlynq_ioctl == NULL) {
        return (PAL_VLYNQ_INVALID_PARAM);
    }
    /* To configure Peer register check the status of link */
    if((TRUE == (cmd & PAL_VLYNQ_IOCTL_REMOTE_CMD)) && (FALSE == vlynq_detect_link_status(p_vlynq_ioctl)))
    {
        return (PAL_VLYNQ_NO_LINK);
    }

    p_vlynq_reg = LOCAL_REGS(p_vlynq_ioctl);
    switch(PAL_VLYNQ_IOCTL_MAJOR_DE_VAL(cmd))
    {
        case PAL_VLYNQ_IOCTL_REG_CMD:

            if(FALSE != (cmd & PAL_VLYNQ_IOCTL_REMOTE_CMD) ) {
                p_vlynq_reg = PEER_REGS(p_vlynq_ioctl);
            }

            p_start_reg = (volatile Uint32* )p_vlynq_reg;
            break;

        case PAL_VLYNQ_IOCTL_PREP_LINK_DOWN:
            /* Backup of LOCAL registers */
            p_vlynq_ioctl->backup_local_cntl_word = p_vlynq_reg->control;
            p_vlynq_ioctl->backup_local_intr_ptr  = p_vlynq_reg->intPtr;
            p_vlynq_ioctl->backup_local_tx_map    = p_vlynq_reg->txMap;
#ifdef INCLUDE_ENDIAN_REGISTER
            p_vlynq_ioctl->backup_local_endian    = p_vlynq_reg->endian;
#endif
            /* Let us disable the interrupts, spur interrupts are not invited. */
            val = vlynq_rd_reg(p_vlynq_ioctl, False, &p_vlynq_reg->control) & (~(1 << 13));
            vlynq_wr_reg(p_vlynq_ioctl, False, &p_vlynq_reg->control, val);

            /* Backup of PEER registers */
            p_vlynq_reg = PEER_REGS(p_vlynq_ioctl);

            p_vlynq_ioctl->backup_peer_cntl_word = p_vlynq_reg->control;
            p_vlynq_ioctl->backup_peer_intr_ptr  = p_vlynq_reg->intPtr;
            p_vlynq_ioctl->backup_peer_tx_map    = p_vlynq_reg->txMap;
#ifdef INCLUDE_ENDIAN_REGISTER
            p_vlynq_ioctl->backup_peer_endian    = p_vlynq_reg->endian;
#endif

            /* PAL_VLYNQ_IOCTL_PREP_LINK_DOWN is not behaving as expected.
            this IOCTL should break/tear the link between local and peer */

            /* RESET LOCAL */
              p_vlynq_reg = LOCAL_REGS(p_vlynq_ioctl);

            if(vlynq_rd_reg(p_vlynq_ioctl, False, (volatile Uint32*)&p_vlynq_reg->revision) >= VLYNQ_REV_10200)
            {
                vlynq_wr_reg(p_vlynq_ioctl, False, (volatile Uint32*)&p_vlynq_reg->control,
                vlynq_rd_reg(p_vlynq_ioctl, False, (volatile Uint32*)&p_vlynq_reg->control) | 0x1u);

                /* Provide sufficient time for reset. Refer 2.4.2 of 2.6 VLYNQ specifications. */
                vlynq_delay_wait(0xffffffu);
            }

            if(NULL == vlynq_detect_link_status(p_vlynq_ioctl))
            {
                /* Link is Lost */
                ret_val = PAL_VLYNQ_OK;
            }
            else
            {
                /* Link is Still there */
                ret_val = PAL_VLYNQ_INTERNAL_ERROR;
            }
            break;

        case PAL_VLYNQ_IOCTL_PREP_LINK_UP:

            /* PAL_VLYNQ_IOCTL_PREP_LINK_UP is not behaving as expected.
            this IOCTL should establish the link between local and peer */
            p_vlynq_reg = LOCAL_REGS(p_vlynq_ioctl);

            if(vlynq_rd_reg(p_vlynq_ioctl, False, (volatile Uint32*)&p_vlynq_reg->revision) >= VLYNQ_REV_10200)
            {
                vlynq_wr_reg(p_vlynq_ioctl, False, (volatile Uint32*)&p_vlynq_reg->control,
                vlynq_rd_reg(p_vlynq_ioctl, False, (volatile Uint32*)&p_vlynq_reg->control) & (~(0x1u)));

                /* Provide sufficient time for reset. Refer 2.4.2 of 2.6 VLYNQ specifications. */
                vlynq_delay_wait(0xffffffu);
            }

            if(NULL == vlynq_detect_link_status(p_vlynq_ioctl))
            {
                /* Link is still Lost */
                ret_val = PAL_VLYNQ_INTERNAL_ERROR;
            }
            else
            {
                /* Link is now established */
                ret_val = PAL_VLYNQ_OK;
            }


            /* Clearing the spur interrupts, lest it locks up the bus. */
            val = vlynq_rd_reg(p_vlynq_ioctl, False, &p_vlynq_reg->status) | CSL_VLYNQ_STAT_RERROR_MASK | CSL_VLYNQ_STAT_LERROR_MASK;
            vlynq_wr_reg(p_vlynq_ioctl, False, &p_vlynq_reg->status, val);

            p_vlynq_reg->control = p_vlynq_ioctl->backup_local_cntl_word;
            p_vlynq_reg->intPtr  = p_vlynq_ioctl->backup_local_intr_ptr;
            p_vlynq_reg->txMap   = p_vlynq_ioctl->backup_local_tx_map;
#ifdef INCLUDE_ENDIAN_REGISTER
            p_vlynq_reg->endian  = p_vlynq_ioctl->backup_local_endian;
#endif

            p_vlynq_reg = PEER_REGS(p_vlynq_ioctl);
            p_vlynq_ioctl->peer_swap = p_vlynq_ioctl->local_swap;

            /* Clearing the spur interrupts, lest it locks up the bus. */
            val = vlynq_rd_reg(p_vlynq_ioctl, True, &p_vlynq_reg->status) |  CSL_VLYNQ_STAT_RERROR_MASK | CSL_VLYNQ_STAT_LERROR_MASK;
            vlynq_wr_reg(p_vlynq_ioctl, True, &p_vlynq_reg->status, val);

#ifdef INCLUDE_ENDIAN_REGISTER
            vlynq_wr_reg(p_vlynq_ioctl, True, &p_vlynq_reg->endian, p_vlynq_ioctl->backup_peer_endian);
#endif
            if(p_vlynq_ioctl->backup_local_endian != p_vlynq_ioctl->backup_peer_endian) {
                p_vlynq_ioctl->peer_swap = p_vlynq_ioctl->peer_swap ? False : True;
            }
            p_vlynq_reg->control = p_vlynq_ioctl->backup_peer_cntl_word;
            p_vlynq_reg->intPtr  = p_vlynq_ioctl->backup_peer_intr_ptr;
            p_vlynq_reg->txMap   = p_vlynq_ioctl->backup_peer_tx_map;
            break;

        case PAL_VLYNQ_IOCTL_CLEAR_INTERN_ERR:

            p_vlynq_reg = LOCAL_REGS(p_vlynq_ioctl);
            val  = vlynq_rd_reg(p_vlynq_ioctl, False, &p_vlynq_reg->status) |  CSL_VLYNQ_STAT_RERROR_MASK | CSL_VLYNQ_STAT_LERROR_MASK;
            vlynq_wr_reg(p_vlynq_ioctl, False, &p_vlynq_reg->status, val);

            p_vlynq_reg = PEER_REGS(p_vlynq_ioctl);

            vlynq_delay_wait(0x100);

            val = vlynq_rd_reg(p_vlynq_ioctl, True, &p_vlynq_reg->status) |  CSL_VLYNQ_STAT_RERROR_MASK | CSL_VLYNQ_STAT_LERROR_MASK;
            vlynq_wr_reg(p_vlynq_ioctl, True, &p_vlynq_reg->status, val);

            break;

        default:
            ret_val = PAL_VLYNQ_INVALID_PARAM;
            break;
    }

    if( PAL_VLYNQ_IOCTL_MAJOR_DE_VAL(cmd)   == PAL_VLYNQ_IOCTL_REG_CMD)
    {
        if(p_start_reg == NULL) {
            ret_val = PAL_VLYNQ_INVALID_PARAM;
        }
        else{
            /*To read Revision will only required in PAL_VLYNQ_IOCTL_REG_CMD */
            vlynq_rev = vlynq_rd_reg(p_vlynq_ioctl,(cmd & PAL_VLYNQ_IOCTL_REMOTE_CMD) ? True : False,
                                    &p_vlynq_reg->revision);

            vlynq_swap_hack = (cmd & PAL_VLYNQ_IOCTL_REMOTE_CMD) ? p_vlynq_ioctl->peer_swap : p_vlynq_ioctl->local_swap;
            ret_val = vlynq_read_write_ioctl(p_start_reg, cmd, cmd_val,
                    vlynq_rev);
        }
    }

    return (ret_val);
}


/**
 * \brief   Read/Write  register of the VLYNQ module
 *
 *
 * \param   vlynq               [IN]    The VLYNQ module instance, whose register has to be controlled; this value would have been returned by PAL_sysVlynqInit().
 * \param   cmd                 [IN]    Various read and write commands to be carried out. Refer below for the 32 bit break up of the command.
 * \param   cmd_val             [IN/OUT]For write command(s) this provides the value to be written and for
 *                                      read operations it provides the placeholder for the value to be read.
 *
 * \return  PAL_VLYNQ_OK on success., negative on error
 */
PAL_Result PAL_sysVlynqIoctl(PAL_VLYNQ_HND *vlynq_hnd, Uint32 cmd, Uint32 *cmd_val)
{
    VLYNQ_REG_T *p_vlynq_reg;
    volatile Uint32      *p_start_reg = NULL;

    PAL_Result           ret_val    = PAL_VLYNQ_INVALID_PARAM;
    PAL_VLYNQ_T          * p_vlynq_sysioctl     = NULL;
    Int32                valid      = 1;
    Uint32               vlynq_rev  = 0;
    Bool                 peer       = True;

    if(vlynq_hnd == NULL)
    {
        return (PAL_VLYNQ_INVALID_PARAM);
    }
    p_vlynq_sysioctl    = (PAL_VLYNQ_T *)vlynq_hnd;

    /*  Expected behavior: while PAL_VLYNQ_IOCTL_PREP_LINK_UP, the link will be down
                          so this should not return error and flow should go ahed.
    */
    if((FALSE == vlynq_touch_vlynq_through_chain(p_vlynq_sysioctl)))
    {
      if(PAL_VLYNQ_IOCTL_MAJOR_DE_VAL(cmd) != PAL_VLYNQ_IOCTL_PREP_LINK_UP)
      {
        return (PAL_VLYNQ_INTERNAL_ERROR);
    }
    }

    if(0 != (cmd & PAL_VLYNQ_IOCTL_REMOTE_CMD))
    {
        if(TRUE == vlynq_detect_link_status(p_vlynq_sysioctl))
        {
        p_vlynq_reg = PEER_REGS(p_vlynq_sysioctl);
    }
    }
    else
    {
        p_vlynq_reg = LOCAL_REGS(p_vlynq_sysioctl);
        peer        = False;
    }
    if(p_vlynq_reg == NULL)
    {
        return (PAL_VLYNQ_INVALID_PARAM);
    }

    /* Hack for now as we support just one major non bit cmd. */
    if(FALSE ==(cmd & (Uint32)PAL_VLYNQ_IOCTL_BIT_CMD))
    {
         ret_val = vlynq_non_bit_op_ioctl(p_vlynq_sysioctl, cmd, cmd_val);
         valid   = 0; /* We do not require register access. */
    }
    else
    {
        switch(PAL_VLYNQ_IOCTL_MAJOR_DE_VAL(cmd))
        {
            case  PAL_VLYNQ_IOCTL_STATUS_REG:

                p_start_reg = (volatile Uint32*)&p_vlynq_reg->status;
                break;

            case PAL_VLYNQ_IOCTL_CONTROL_REG:

                p_start_reg = (volatile Uint32*)&p_vlynq_reg->control;
                break;

            default:
                valid = 0;
                break;

        }
    }

    if(valid == TRUE)
    {
        /* Needs to check revision only for bit operations */
        vlynq_rev = vlynq_rd_reg(p_vlynq_sysioctl, peer, &p_vlynq_reg->revision);
        vlynq_swap_hack = peer ? p_vlynq_sysioctl->peer_swap : p_vlynq_sysioctl->local_swap;
         ret_val = vlynq_read_write_ioctl(p_start_reg, cmd, cmd_val, vlynq_rev);
    }
    return (ret_val);
}



