/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005, 2006
 *
 *   Use of this software is controlled by the terms and conditions found in the
 *   license agreement under which this software has been supplied.
 *   ===========================================================================
 */
/** ============================================================================
 *   @file  cslr_gpio.h
 *
 *   @path  $(CSLPATH)\inc
 *
 *   @desc  This file contains the Register Descriptions for GPIO
 *          Reference: User Guide SPRU988
 *  ============================================================================
 */
#ifndef _CSLR_GPIO_H_
#define _CSLR_GPIO_H_

#ifdef __cplusplus
extern "C" {
#endif

#include <ti/sdo/pspdrivers/soc/c6424/dsp/cslr.h>
#include <ti/sdo/pspdrivers/soc/c6424/dsp/tistdtypes.h>

/* Minimum unit = 1 byte */

/**************************************************************************\
* Register Overlay Structure
\**************************************************************************/
typedef struct  {
    volatile Uint32 PID;
    volatile Uint32 PCR;
    volatile Uint32 BINTEN;
    volatile Uint8 RSVD0[4];
    volatile Uint32 DIR01;
    volatile Uint32 OUT_DATA01;
    volatile Uint32 SET_DATA01;
    volatile Uint32 CLR_DATA01;
    volatile Uint32 IN_DATA01;
    volatile Uint32 SET_RIS_TRIG01;
    volatile Uint32 CLR_RIS_TRIG01;
    volatile Uint32 SET_FAL_TRIG01;
    volatile Uint32 CLR_FAL_TRIG01;
    volatile Uint32 INTSTAT01;
    volatile Uint32 DIR23;
    volatile Uint32 OUT_DATA23;
    volatile Uint32 SET_DATA23;
    volatile Uint32 CLR_DATA23;
    volatile Uint32 IN_DATA23;
    volatile Uint32 SET_RIS_TRIG23;
    volatile Uint32 CLR_RIS_TRIG23;
    volatile Uint32 SET_FAL_TRIG23;
    volatile Uint32 CLR_FAL_TRIG23;
    volatile Uint32 INTSTAT23;
    volatile Uint32 DIR45;
    volatile Uint32 OUT_DATA45;
    volatile Uint32 SET_DATA45;
    volatile Uint32 CLR_DATA45;
    volatile Uint32 IN_DATA45;
    volatile Uint32 SET_RIS_TRIG45;
    volatile Uint32 CLR_RIS_TRIG45;
    volatile Uint32 SET_FAL_TRIG45;
    volatile Uint32 CLR_FAL_TRIG45;
    volatile Uint32 INTSTAT45;
    volatile Uint32 DIR6;
    volatile Uint32 OUT_DATA6;
    volatile Uint32 SET_DATA6;
    volatile Uint32 CLR_DATA6;
    volatile Uint32 IN_DATA6;
    volatile Uint32 SET_RIS_TRIG6;
    volatile Uint32 CLR_RIS_TRIG6;
    volatile Uint32 SET_FAL_TRIG6;
    volatile Uint32 CLR_FAL_TRIG6;
    volatile Uint32 INTSTAT6;
} CSL_GpioRegs;

/**************************************************************************\
* Overlay structure typedef definition
\**************************************************************************/
typedef volatile CSL_GpioRegs  * CSL_GpioRegsOvly;

/**************************************************************************\
* Field Definition Macros
\**************************************************************************/

/* PID */

#define CSL_GPIO_PID_SCHEME_MASK (0xC0000000u)
#define CSL_GPIO_PID_SCHEME_SHIFT (0x0000001Eu)
#define CSL_GPIO_PID_SCHEME_RESETVAL (0x00000001u)


#define CSL_GPIO_PID_FUNCTION_MASK (0x0FFF0000u)
#define CSL_GPIO_PID_FUNCTION_SHIFT (0x00000010u)
#define CSL_GPIO_PID_FUNCTION_RESETVAL (0x00000483u)

#define CSL_GPIO_PID_RTL_MASK (0x0000F800u)
#define CSL_GPIO_PID_RTL_SHIFT (0x0000000Bu)
#define CSL_GPIO_PID_RTL_RESETVAL (0x00000000u)

#define CSL_GPIO_PID_MAJOR_MASK (0x00000700u)
#define CSL_GPIO_PID_MAJOR_SHIFT (0x00000008u)
#define CSL_GPIO_PID_MAJOR_RESETVAL (0x00000001u)

#define CSL_GPIO_PID_CUSTOM_MASK (0x000000C0u)
#define CSL_GPIO_PID_CUSTOM_SHIFT (0x00000006u)
#define CSL_GPIO_PID_CUSTOM_RESETVAL (0x00000000u)

#define CSL_GPIO_PID_MINOR_MASK (0x0000003Fu)
#define CSL_GPIO_PID_MINOR_SHIFT (0x00000000u)
#define CSL_GPIO_PID_MINOR_RESETVAL (0x00000005u)

#define CSL_GPIO_PID_RESETVAL (0x44830105u)

/* PCR */


#define CSL_GPIO_PCR_SOFT_MASK (0x00000002u)
#define CSL_GPIO_PCR_SOFT_SHIFT (0x00000001u)
#define CSL_GPIO_PCR_SOFT_RESETVAL (0x00000000u)
/*----SOFT Tokens----*/
#define CSL_GPIO_PCR_SOFT_ENABLE (0x00000000u)

#define CSL_GPIO_PCR_FREE_MASK (0x00000001u)
#define CSL_GPIO_PCR_FREE_SHIFT (0x00000000u)
#define CSL_GPIO_PCR_FREE_RESETVAL (0x00000001u)
/*----FREE Tokens----*/
#define CSL_GPIO_PCR_FREE_ENABLE (0x00000001u)

#define CSL_GPIO_PCR_RESETVAL (0x00000001u)

/* BINTEN */


#define CSL_GPIO_BINTEN_EN7_MASK (0x00000040u)
#define CSL_GPIO_BINTEN_EN7_SHIFT (0x00000006u)
#define CSL_GPIO_BINTEN_EN7_RESETVAL (0x00000000u)
/*----EN7 Tokens----*/
#define CSL_GPIO_BINTEN_EN7_DISABLE (0x00000000u)
#define CSL_GPIO_BINTEN_EN7_ENABLE (0x00000001u)

#define CSL_GPIO_BINTEN_EN0_MASK (0x0000007Fu)
#define CSL_GPIO_BINTEN_EN0_SHIFT (0x00000000u)
#define CSL_GPIO_BINTEN_EN0_RESETVAL (0x00000000u)
/*----EN0 Tokens----*/
#define CSL_GPIO_BINTEN_EN0_DISABLE (0x00000000u)
#define CSL_GPIO_BINTEN_EN0_ENABLE (0x00000001u)

#define CSL_GPIO_BINTEN_EN6_MASK (0x00000020u)
#define CSL_GPIO_BINTEN_EN6_SHIFT (0x00000005u)
#define CSL_GPIO_BINTEN_EN6_RESETVAL (0x00000000u)
/*----EN6 Tokens----*/
#define CSL_GPIO_BINTEN_EN6_DISABLE (0x00000000u)
#define CSL_GPIO_BINTEN_EN6_ENABLE (0x00000001u)

#define CSL_GPIO_BINTEN_EN5_MASK (0x00000010u)
#define CSL_GPIO_BINTEN_EN5_SHIFT (0x00000004u)
#define CSL_GPIO_BINTEN_EN5_RESETVAL (0x00000000u)
/*----EN5 Tokens----*/
#define CSL_GPIO_BINTEN_EN5_DISABLE (0x00000000u)
#define CSL_GPIO_BINTEN_EN5_ENABLE (0x00000001u)

#define CSL_GPIO_BINTEN_EN4_MASK (0x00000008u)
#define CSL_GPIO_BINTEN_EN4_SHIFT (0x00000003u)
#define CSL_GPIO_BINTEN_EN4_RESETVAL (0x00000000u)
/*----EN4 Tokens----*/
#define CSL_GPIO_BINTEN_EN4_DISABLE (0x00000000u)
#define CSL_GPIO_BINTEN_EN4_ENABLE (0x00000001u)

#define CSL_GPIO_BINTEN_EN3_MASK (0x00000004u)
#define CSL_GPIO_BINTEN_EN3_SHIFT (0x00000002u)
#define CSL_GPIO_BINTEN_EN3_RESETVAL (0x00000000u)
/*----EN3 Tokens----*/
#define CSL_GPIO_BINTEN_EN3_DISABLE (0x00000000u)
#define CSL_GPIO_BINTEN_EN3_ENABLE (0x00000001u)

#define CSL_GPIO_BINTEN_EN2_MASK (0x00000002u)
#define CSL_GPIO_BINTEN_EN2_SHIFT (0x00000001u)
#define CSL_GPIO_BINTEN_EN2_RESETVAL (0x00000000u)
/*----EN2 Tokens----*/
#define CSL_GPIO_BINTEN_EN2_DISABLE (0x00000000u)
#define CSL_GPIO_BINTEN_EN2_ENABLE (0x00000001u)

#define CSL_GPIO_BINTEN_EN1_MASK (0x00000001u)
#define CSL_GPIO_BINTEN_EN1_SHIFT (0x00000000u)
#define CSL_GPIO_BINTEN_EN1_RESETVAL (0x00000000u)
/*----EN1 Tokens----*/
#define CSL_GPIO_BINTEN_EN1_DISABLE (0x00000000u)
#define CSL_GPIO_BINTEN_EN1_ENABLE (0x00000001u)

#define CSL_GPIO_BINTEN_RESETVAL (0x00000000u)

/* DIR01 */

#define CSL_GPIO_DIR01_DIR31_MASK (0x80000000u)
#define CSL_GPIO_DIR01_DIR31_SHIFT (0x0000001Fu)
#define CSL_GPIO_DIR01_DIR31_RESETVAL (0x00000001u)
/*----DIR31 Tokens----*/
#define CSL_GPIO_DIR01_DIR31_OUT (0x00000000u)
#define CSL_GPIO_DIR01_DIR31_IN (0x00000001u)

#define CSL_GPIO_DIR01_DIR30_MASK (0x40000000u)
#define CSL_GPIO_DIR01_DIR30_SHIFT (0x0000001Eu)
#define CSL_GPIO_DIR01_DIR30_RESETVAL (0x00000001u)
/*----DIR30 Tokens----*/
#define CSL_GPIO_DIR01_DIR30_OUT (0x00000000u)
#define CSL_GPIO_DIR01_DIR30_IN (0x00000001u)

#define CSL_GPIO_DIR01_DIR29_MASK (0x20000000u)
#define CSL_GPIO_DIR01_DIR29_SHIFT (0x0000001Du)
#define CSL_GPIO_DIR01_DIR29_RESETVAL (0x00000001u)
/*----DIR29 Tokens----*/
#define CSL_GPIO_DIR01_DIR29_OUT (0x00000000u)
#define CSL_GPIO_DIR01_DIR29_IN (0x00000001u)

#define CSL_GPIO_DIR01_DIR28_MASK (0x10000000u)
#define CSL_GPIO_DIR01_DIR28_SHIFT (0x0000001Cu)
#define CSL_GPIO_DIR01_DIR28_RESETVAL (0x00000001u)
/*----DIR28 Tokens----*/
#define CSL_GPIO_DIR01_DIR28_OUT (0x00000000u)
#define CSL_GPIO_DIR01_DIR28_IN (0x00000001u)

#define CSL_GPIO_DIR01_DIR27_MASK (0x08000000u)
#define CSL_GPIO_DIR01_DIR27_SHIFT (0x0000001Bu)
#define CSL_GPIO_DIR01_DIR27_RESETVAL (0x00000001u)
/*----DIR27 Tokens----*/
#define CSL_GPIO_DIR01_DIR27_OUT (0x00000000u)
#define CSL_GPIO_DIR01_DIR27_IN (0x00000001u)

#define CSL_GPIO_DIR01_DIR26_MASK (0x04000000u)
#define CSL_GPIO_DIR01_DIR26_SHIFT (0x0000001Au)
#define CSL_GPIO_DIR01_DIR26_RESETVAL (0x00000001u)
/*----DIR26 Tokens----*/
#define CSL_GPIO_DIR01_DIR26_OUT (0x00000000u)
#define CSL_GPIO_DIR01_DIR26_IN (0x00000001u)

#define CSL_GPIO_DIR01_DIR25_MASK (0x02000000u)
#define CSL_GPIO_DIR01_DIR25_SHIFT (0x00000019u)
#define CSL_GPIO_DIR01_DIR25_RESETVAL (0x00000001u)
/*----DIR25 Tokens----*/
#define CSL_GPIO_DIR01_DIR25_OUT (0x00000000u)
#define CSL_GPIO_DIR01_DIR25_IN (0x00000001u)

#define CSL_GPIO_DIR01_DIR24_MASK (0x01000000u)
#define CSL_GPIO_DIR01_DIR24_SHIFT (0x00000018u)
#define CSL_GPIO_DIR01_DIR24_RESETVAL (0x00000001u)
/*----DIR24 Tokens----*/
#define CSL_GPIO_DIR01_DIR24_OUT (0x00000000u)
#define CSL_GPIO_DIR01_DIR24_IN (0x00000001u)

#define CSL_GPIO_DIR01_DIR23_MASK (0x00800000u)
#define CSL_GPIO_DIR01_DIR23_SHIFT (0x00000017u)
#define CSL_GPIO_DIR01_DIR23_RESETVAL (0x00000001u)
/*----DIR23 Tokens----*/
#define CSL_GPIO_DIR01_DIR23_OUT (0x00000000u)
#define CSL_GPIO_DIR01_DIR23_IN (0x00000001u)

#define CSL_GPIO_DIR01_DIR22_MASK (0x00400000u)
#define CSL_GPIO_DIR01_DIR22_SHIFT (0x00000016u)
#define CSL_GPIO_DIR01_DIR22_RESETVAL (0x00000001u)
/*----DIR22 Tokens----*/
#define CSL_GPIO_DIR01_DIR22_OUT (0x00000000u)
#define CSL_GPIO_DIR01_DIR22_IN (0x00000001u)

#define CSL_GPIO_DIR01_DIR21_MASK (0x00200000u)
#define CSL_GPIO_DIR01_DIR21_SHIFT (0x00000015u)
#define CSL_GPIO_DIR01_DIR21_RESETVAL (0x00000001u)
/*----DIR21 Tokens----*/
#define CSL_GPIO_DIR01_DIR21_OUT (0x00000000u)
#define CSL_GPIO_DIR01_DIR21_IN (0x00000001u)

#define CSL_GPIO_DIR01_DIR20_MASK (0x00100000u)
#define CSL_GPIO_DIR01_DIR20_SHIFT (0x00000014u)
#define CSL_GPIO_DIR01_DIR20_RESETVAL (0x00000001u)
/*----DIR20 Tokens----*/
#define CSL_GPIO_DIR01_DIR20_OUT (0x00000000u)
#define CSL_GPIO_DIR01_DIR20_IN (0x00000001u)

#define CSL_GPIO_DIR01_DIR19_MASK (0x00080000u)
#define CSL_GPIO_DIR01_DIR19_SHIFT (0x00000013u)
#define CSL_GPIO_DIR01_DIR19_RESETVAL (0x00000001u)
/*----DIR19 Tokens----*/
#define CSL_GPIO_DIR01_DIR19_OUT (0x00000000u)
#define CSL_GPIO_DIR01_DIR19_IN (0x00000001u)

#define CSL_GPIO_DIR01_DIR18_MASK (0x00040000u)
#define CSL_GPIO_DIR01_DIR18_SHIFT (0x00000012u)
#define CSL_GPIO_DIR01_DIR18_RESETVAL (0x00000001u)
/*----DIR18 Tokens----*/
#define CSL_GPIO_DIR01_DIR18_OUT (0x00000000u)
#define CSL_GPIO_DIR01_DIR18_IN (0x00000001u)

#define CSL_GPIO_DIR01_DIR17_MASK (0x00020000u)
#define CSL_GPIO_DIR01_DIR17_SHIFT (0x00000011u)
#define CSL_GPIO_DIR01_DIR17_RESETVAL (0x00000001u)
/*----DIR17 Tokens----*/
#define CSL_GPIO_DIR01_DIR17_OUT (0x00000000u)
#define CSL_GPIO_DIR01_DIR17_IN (0x00000001u)

#define CSL_GPIO_DIR01_DIR16_MASK (0x00010000u)
#define CSL_GPIO_DIR01_DIR16_SHIFT (0x00000010u)
#define CSL_GPIO_DIR01_DIR16_RESETVAL (0x00000001u)
/*----DIR16 Tokens----*/
#define CSL_GPIO_DIR01_DIR16_OUT (0x00000000u)
#define CSL_GPIO_DIR01_DIR16_IN (0x00000001u)

#define CSL_GPIO_DIR01_DIR15_MASK (0x00008000u)
#define CSL_GPIO_DIR01_DIR15_SHIFT (0x0000000Fu)
#define CSL_GPIO_DIR01_DIR15_RESETVAL (0x00000001u)
/*----DIR15 Tokens----*/
#define CSL_GPIO_DIR01_DIR15_OUT (0x00000000u)
#define CSL_GPIO_DIR01_DIR15_IN (0x00000001u)

#define CSL_GPIO_DIR01_DIR14_MASK (0x00004000u)
#define CSL_GPIO_DIR01_DIR14_SHIFT (0x0000000Eu)
#define CSL_GPIO_DIR01_DIR14_RESETVAL (0x00000001u)
/*----DIR14 Tokens----*/
#define CSL_GPIO_DIR01_DIR14_OUT (0x00000000u)
#define CSL_GPIO_DIR01_DIR14_IN (0x00000001u)

#define CSL_GPIO_DIR01_DIR13_MASK (0x00002000u)
#define CSL_GPIO_DIR01_DIR13_SHIFT (0x0000000Du)
#define CSL_GPIO_DIR01_DIR13_RESETVAL (0x00000001u)
/*----DIR13 Tokens----*/
#define CSL_GPIO_DIR01_DIR13_OUT (0x00000000u)
#define CSL_GPIO_DIR01_DIR13_IN (0x00000001u)

#define CSL_GPIO_DIR01_DIR12_MASK (0x00001000u)
#define CSL_GPIO_DIR01_DIR12_SHIFT (0x0000000Cu)
#define CSL_GPIO_DIR01_DIR12_RESETVAL (0x00000001u)
/*----DIR12 Tokens----*/
#define CSL_GPIO_DIR01_DIR12_OUT (0x00000000u)
#define CSL_GPIO_DIR01_DIR12_IN (0x00000001u)

#define CSL_GPIO_DIR01_DIR11_MASK (0x00000800u)
#define CSL_GPIO_DIR01_DIR11_SHIFT (0x0000000Bu)
#define CSL_GPIO_DIR01_DIR11_RESETVAL (0x00000001u)
/*----DIR11 Tokens----*/
#define CSL_GPIO_DIR01_DIR11_OUT (0x00000000u)
#define CSL_GPIO_DIR01_DIR11_IN (0x00000001u)

#define CSL_GPIO_DIR01_DIR10_MASK (0x00000400u)
#define CSL_GPIO_DIR01_DIR10_SHIFT (0x0000000Au)
#define CSL_GPIO_DIR01_DIR10_RESETVAL (0x00000001u)
/*----DIR10 Tokens----*/
#define CSL_GPIO_DIR01_DIR10_OUT (0x00000000u)
#define CSL_GPIO_DIR01_DIR10_IN (0x00000001u)

#define CSL_GPIO_DIR01_DIR9_MASK (0x00000200u)
#define CSL_GPIO_DIR01_DIR9_SHIFT (0x00000009u)
#define CSL_GPIO_DIR01_DIR9_RESETVAL (0x00000001u)
/*----DIR9 Tokens----*/
#define CSL_GPIO_DIR01_DIR9_OUT (0x00000000u)
#define CSL_GPIO_DIR01_DIR9_IN (0x00000001u)

#define CSL_GPIO_DIR01_DIR8_MASK (0x00000100u)
#define CSL_GPIO_DIR01_DIR8_SHIFT (0x00000008u)
#define CSL_GPIO_DIR01_DIR8_RESETVAL (0x00000001u)
/*----DIR8 Tokens----*/
#define CSL_GPIO_DIR01_DIR8_OUT (0x00000000u)
#define CSL_GPIO_DIR01_DIR8_IN (0x00000001u)

#define CSL_GPIO_DIR01_DIR7_MASK (0x00000080u)
#define CSL_GPIO_DIR01_DIR7_SHIFT (0x00000007u)
#define CSL_GPIO_DIR01_DIR7_RESETVAL (0x00000001u)
/*----DIR7 Tokens----*/
#define CSL_GPIO_DIR01_DIR7_OUT (0x00000000u)
#define CSL_GPIO_DIR01_DIR7_IN (0x00000001u)

#define CSL_GPIO_DIR01_DIR6_MASK (0x00000040u)
#define CSL_GPIO_DIR01_DIR6_SHIFT (0x00000006u)
#define CSL_GPIO_DIR01_DIR6_RESETVAL (0x00000001u)
/*----DIR6 Tokens----*/
#define CSL_GPIO_DIR01_DIR6_OUT (0x00000000u)
#define CSL_GPIO_DIR01_DIR6_IN (0x00000001u)

#define CSL_GPIO_DIR01_DIR5_MASK (0x00000020u)
#define CSL_GPIO_DIR01_DIR5_SHIFT (0x00000005u)
#define CSL_GPIO_DIR01_DIR5_RESETVAL (0x00000001u)
/*----DIR5 Tokens----*/
#define CSL_GPIO_DIR01_DIR5_OUT (0x00000000u)
#define CSL_GPIO_DIR01_DIR5_IN (0x00000001u)

#define CSL_GPIO_DIR01_DIR4_MASK (0x00000010u)
#define CSL_GPIO_DIR01_DIR4_SHIFT (0x00000004u)
#define CSL_GPIO_DIR01_DIR4_RESETVAL (0x00000001u)
/*----DIR4 Tokens----*/
#define CSL_GPIO_DIR01_DIR4_OUT (0x00000000u)
#define CSL_GPIO_DIR01_DIR4_IN (0x00000001u)

#define CSL_GPIO_DIR01_DIR3_MASK (0x00000008u)
#define CSL_GPIO_DIR01_DIR3_SHIFT (0x00000003u)
#define CSL_GPIO_DIR01_DIR3_RESETVAL (0x00000001u)
/*----DIR3 Tokens----*/
#define CSL_GPIO_DIR01_DIR3_OUT (0x00000000u)
#define CSL_GPIO_DIR01_DIR3_IN (0x00000001u)

#define CSL_GPIO_DIR01_DIR2_MASK (0x00000004u)
#define CSL_GPIO_DIR01_DIR2_SHIFT (0x00000002u)
#define CSL_GPIO_DIR01_DIR2_RESETVAL (0x00000001u)
/*----DIR2 Tokens----*/
#define CSL_GPIO_DIR01_DIR2_OUT (0x00000000u)
#define CSL_GPIO_DIR01_DIR2_IN (0x00000001u)

#define CSL_GPIO_DIR01_DIR1_MASK (0x00000002u)
#define CSL_GPIO_DIR01_DIR1_SHIFT (0x00000001u)
#define CSL_GPIO_DIR01_DIR1_RESETVAL (0x00000001u)
/*----DIR1 Tokens----*/
#define CSL_GPIO_DIR01_DIR1_OUT (0x00000000u)
#define CSL_GPIO_DIR01_DIR1_IN (0x00000001u)

#define CSL_GPIO_DIR01_DIR0_MASK (0x00000001u)
#define CSL_GPIO_DIR01_DIR0_SHIFT (0x00000000u)
#define CSL_GPIO_DIR01_DIR0_RESETVAL (0x00000001u)
/*----DIR0 Tokens----*/
#define CSL_GPIO_DIR01_DIR0_OUT (0x00000000u)
#define CSL_GPIO_DIR01_DIR0_IN (0x00000001u)

#define CSL_GPIO_DIR01_RESETVAL (0xFFFFFFFFu)

/* OUT_DATA01 */

#define CSL_GPIO_OUT_DATA01_OUT31_MASK (0x80000000u)
#define CSL_GPIO_OUT_DATA01_OUT31_SHIFT (0x0000001Fu)
#define CSL_GPIO_OUT_DATA01_OUT31_RESETVAL (0x00000000u)
/*----OUT31 Tokens----*/
#define CSL_GPIO_OUT_DATA01_OUT31_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA01_OUT31_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA01_OUT30_MASK (0x40000000u)
#define CSL_GPIO_OUT_DATA01_OUT30_SHIFT (0x0000001Eu)
#define CSL_GPIO_OUT_DATA01_OUT30_RESETVAL (0x00000000u)
/*----OUT30 Tokens----*/
#define CSL_GPIO_OUT_DATA01_OUT30_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA01_OUT30_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA01_OUT29_MASK (0x20000000u)
#define CSL_GPIO_OUT_DATA01_OUT29_SHIFT (0x0000001Du)
#define CSL_GPIO_OUT_DATA01_OUT29_RESETVAL (0x00000000u)
/*----OUT29 Tokens----*/
#define CSL_GPIO_OUT_DATA01_OUT29_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA01_OUT29_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA01_OUT28_MASK (0x10000000u)
#define CSL_GPIO_OUT_DATA01_OUT28_SHIFT (0x0000001Cu)
#define CSL_GPIO_OUT_DATA01_OUT28_RESETVAL (0x00000000u)
/*----OUT28 Tokens----*/
#define CSL_GPIO_OUT_DATA01_OUT28_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA01_OUT28_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA01_OUT27_MASK (0x08000000u)
#define CSL_GPIO_OUT_DATA01_OUT27_SHIFT (0x0000001Bu)
#define CSL_GPIO_OUT_DATA01_OUT27_RESETVAL (0x00000000u)
/*----OUT27 Tokens----*/
#define CSL_GPIO_OUT_DATA01_OUT27_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA01_OUT27_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA01_OUT26_MASK (0x04000000u)
#define CSL_GPIO_OUT_DATA01_OUT26_SHIFT (0x0000001Au)
#define CSL_GPIO_OUT_DATA01_OUT26_RESETVAL (0x00000000u)
/*----OUT26 Tokens----*/
#define CSL_GPIO_OUT_DATA01_OUT26_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA01_OUT26_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA01_OUT25_MASK (0x02000000u)
#define CSL_GPIO_OUT_DATA01_OUT25_SHIFT (0x00000019u)
#define CSL_GPIO_OUT_DATA01_OUT25_RESETVAL (0x00000000u)
/*----OUT25 Tokens----*/
#define CSL_GPIO_OUT_DATA01_OUT25_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA01_OUT25_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA01_OUT24_MASK (0x01000000u)
#define CSL_GPIO_OUT_DATA01_OUT24_SHIFT (0x00000018u)
#define CSL_GPIO_OUT_DATA01_OUT24_RESETVAL (0x00000000u)
/*----OUT24 Tokens----*/
#define CSL_GPIO_OUT_DATA01_OUT24_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA01_OUT24_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA01_OUT23_MASK (0x00800000u)
#define CSL_GPIO_OUT_DATA01_OUT23_SHIFT (0x00000017u)
#define CSL_GPIO_OUT_DATA01_OUT23_RESETVAL (0x00000000u)
/*----OUT23 Tokens----*/
#define CSL_GPIO_OUT_DATA01_OUT23_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA01_OUT23_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA01_OUT22_MASK (0x00400000u)
#define CSL_GPIO_OUT_DATA01_OUT22_SHIFT (0x00000016u)
#define CSL_GPIO_OUT_DATA01_OUT22_RESETVAL (0x00000000u)
/*----OUT22 Tokens----*/
#define CSL_GPIO_OUT_DATA01_OUT22_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA01_OUT22_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA01_OUT21_MASK (0x00200000u)
#define CSL_GPIO_OUT_DATA01_OUT21_SHIFT (0x00000015u)
#define CSL_GPIO_OUT_DATA01_OUT21_RESETVAL (0x00000000u)
/*----OUT21 Tokens----*/
#define CSL_GPIO_OUT_DATA01_OUT21_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA01_OUT21_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA01_OUT20_MASK (0x00100000u)
#define CSL_GPIO_OUT_DATA01_OUT20_SHIFT (0x00000014u)
#define CSL_GPIO_OUT_DATA01_OUT20_RESETVAL (0x00000000u)
/*----OUT20 Tokens----*/
#define CSL_GPIO_OUT_DATA01_OUT20_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA01_OUT20_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA01_OUT19_MASK (0x00080000u)
#define CSL_GPIO_OUT_DATA01_OUT19_SHIFT (0x00000013u)
#define CSL_GPIO_OUT_DATA01_OUT19_RESETVAL (0x00000000u)
/*----OUT19 Tokens----*/
#define CSL_GPIO_OUT_DATA01_OUT19_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA01_OUT19_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA01_OUT18_MASK (0x00040000u)
#define CSL_GPIO_OUT_DATA01_OUT18_SHIFT (0x00000012u)
#define CSL_GPIO_OUT_DATA01_OUT18_RESETVAL (0x00000000u)
/*----OUT18 Tokens----*/
#define CSL_GPIO_OUT_DATA01_OUT18_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA01_OUT18_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA01_OUT17_MASK (0x00020000u)
#define CSL_GPIO_OUT_DATA01_OUT17_SHIFT (0x00000011u)
#define CSL_GPIO_OUT_DATA01_OUT17_RESETVAL (0x00000000u)
/*----OUT17 Tokens----*/
#define CSL_GPIO_OUT_DATA01_OUT17_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA01_OUT17_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA01_OUT16_MASK (0x00010000u)
#define CSL_GPIO_OUT_DATA01_OUT16_SHIFT (0x00000010u)
#define CSL_GPIO_OUT_DATA01_OUT16_RESETVAL (0x00000000u)
/*----OUT16 Tokens----*/
#define CSL_GPIO_OUT_DATA01_OUT16_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA01_OUT16_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA01_OUT15_MASK (0x00008000u)
#define CSL_GPIO_OUT_DATA01_OUT15_SHIFT (0x0000000Fu)
#define CSL_GPIO_OUT_DATA01_OUT15_RESETVAL (0x00000000u)
/*----OUT15 Tokens----*/
#define CSL_GPIO_OUT_DATA01_OUT15_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA01_OUT15_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA01_OUT14_MASK (0x00004000u)
#define CSL_GPIO_OUT_DATA01_OUT14_SHIFT (0x0000000Eu)
#define CSL_GPIO_OUT_DATA01_OUT14_RESETVAL (0x00000000u)
/*----OUT14 Tokens----*/
#define CSL_GPIO_OUT_DATA01_OUT14_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA01_OUT14_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA01_OUT13_MASK (0x00002000u)
#define CSL_GPIO_OUT_DATA01_OUT13_SHIFT (0x0000000Du)
#define CSL_GPIO_OUT_DATA01_OUT13_RESETVAL (0x00000000u)
/*----OUT13 Tokens----*/
#define CSL_GPIO_OUT_DATA01_OUT13_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA01_OUT13_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA01_OUT12_MASK (0x00001000u)
#define CSL_GPIO_OUT_DATA01_OUT12_SHIFT (0x0000000Cu)
#define CSL_GPIO_OUT_DATA01_OUT12_RESETVAL (0x00000000u)
/*----OUT12 Tokens----*/
#define CSL_GPIO_OUT_DATA01_OUT12_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA01_OUT12_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA01_OUT11_MASK (0x00000800u)
#define CSL_GPIO_OUT_DATA01_OUT11_SHIFT (0x0000000Bu)
#define CSL_GPIO_OUT_DATA01_OUT11_RESETVAL (0x00000000u)
/*----OUT11 Tokens----*/
#define CSL_GPIO_OUT_DATA01_OUT11_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA01_OUT11_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA01_OUT10_MASK (0x00000400u)
#define CSL_GPIO_OUT_DATA01_OUT10_SHIFT (0x0000000Au)
#define CSL_GPIO_OUT_DATA01_OUT10_RESETVAL (0x00000000u)
/*----OUT10 Tokens----*/
#define CSL_GPIO_OUT_DATA01_OUT10_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA01_OUT10_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA01_OUT9_MASK (0x00000200u)
#define CSL_GPIO_OUT_DATA01_OUT9_SHIFT (0x00000009u)
#define CSL_GPIO_OUT_DATA01_OUT9_RESETVAL (0x00000000u)
/*----OUT9 Tokens----*/
#define CSL_GPIO_OUT_DATA01_OUT9_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA01_OUT9_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA01_OUT8_MASK (0x00000100u)
#define CSL_GPIO_OUT_DATA01_OUT8_SHIFT (0x00000008u)
#define CSL_GPIO_OUT_DATA01_OUT8_RESETVAL (0x00000000u)
/*----OUT8 Tokens----*/
#define CSL_GPIO_OUT_DATA01_OUT8_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA01_OUT8_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA01_OUT7_MASK (0x00000080u)
#define CSL_GPIO_OUT_DATA01_OUT7_SHIFT (0x00000007u)
#define CSL_GPIO_OUT_DATA01_OUT7_RESETVAL (0x00000000u)
/*----OUT7 Tokens----*/
#define CSL_GPIO_OUT_DATA01_OUT7_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA01_OUT7_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA01_OUT6_MASK (0x00000040u)
#define CSL_GPIO_OUT_DATA01_OUT6_SHIFT (0x00000006u)
#define CSL_GPIO_OUT_DATA01_OUT6_RESETVAL (0x00000000u)
/*----OUT6 Tokens----*/
#define CSL_GPIO_OUT_DATA01_OUT6_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA01_OUT6_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA01_OUT5_MASK (0x00000020u)
#define CSL_GPIO_OUT_DATA01_OUT5_SHIFT (0x00000005u)
#define CSL_GPIO_OUT_DATA01_OUT5_RESETVAL (0x00000000u)
/*----OUT5 Tokens----*/
#define CSL_GPIO_OUT_DATA01_OUT5_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA01_OUT5_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA01_OUT4_MASK (0x00000010u)
#define CSL_GPIO_OUT_DATA01_OUT4_SHIFT (0x00000004u)
#define CSL_GPIO_OUT_DATA01_OUT4_RESETVAL (0x00000000u)
/*----OUT4 Tokens----*/
#define CSL_GPIO_OUT_DATA01_OUT4_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA01_OUT4_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA01_OUT3_MASK (0x00000008u)
#define CSL_GPIO_OUT_DATA01_OUT3_SHIFT (0x00000003u)
#define CSL_GPIO_OUT_DATA01_OUT3_RESETVAL (0x00000000u)
/*----OUT3 Tokens----*/
#define CSL_GPIO_OUT_DATA01_OUT3_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA01_OUT3_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA01_OUT2_MASK (0x00000004u)
#define CSL_GPIO_OUT_DATA01_OUT2_SHIFT (0x00000002u)
#define CSL_GPIO_OUT_DATA01_OUT2_RESETVAL (0x00000000u)
/*----OUT2 Tokens----*/
#define CSL_GPIO_OUT_DATA01_OUT2_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA01_OUT2_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA01_OUT1_MASK (0x00000002u)
#define CSL_GPIO_OUT_DATA01_OUT1_SHIFT (0x00000001u)
#define CSL_GPIO_OUT_DATA01_OUT1_RESETVAL (0x00000000u)
/*----OUT1 Tokens----*/
#define CSL_GPIO_OUT_DATA01_OUT1_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA01_OUT1_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA01_OUT0_MASK (0x00000001u)
#define CSL_GPIO_OUT_DATA01_OUT0_SHIFT (0x00000000u)
#define CSL_GPIO_OUT_DATA01_OUT0_RESETVAL (0x00000000u)
/*----OUT0 Tokens----*/
#define CSL_GPIO_OUT_DATA01_OUT0_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA01_OUT0_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA01_RESETVAL (0x00000000u)

/* SET_DATA01 */

#define CSL_GPIO_SET_DATA01_SET31_MASK (0x80000000u)
#define CSL_GPIO_SET_DATA01_SET31_SHIFT (0x0000001Fu)
#define CSL_GPIO_SET_DATA01_SET31_RESETVAL (0x00000000u)
/*----SET31 Tokens----*/
#define CSL_GPIO_SET_DATA01_SET31_SET (0x00000001u)

#define CSL_GPIO_SET_DATA01_SET30_MASK (0x40000000u)
#define CSL_GPIO_SET_DATA01_SET30_SHIFT (0x0000001Eu)
#define CSL_GPIO_SET_DATA01_SET30_RESETVAL (0x00000000u)
/*----SET30 Tokens----*/
#define CSL_GPIO_SET_DATA01_SET30_SET (0x00000001u)

#define CSL_GPIO_SET_DATA01_SET29_MASK (0x20000000u)
#define CSL_GPIO_SET_DATA01_SET29_SHIFT (0x0000001Du)
#define CSL_GPIO_SET_DATA01_SET29_RESETVAL (0x00000000u)
/*----SET29 Tokens----*/
#define CSL_GPIO_SET_DATA01_SET29_SET (0x00000001u)

#define CSL_GPIO_SET_DATA01_SET28_MASK (0x10000000u)
#define CSL_GPIO_SET_DATA01_SET28_SHIFT (0x0000001Cu)
#define CSL_GPIO_SET_DATA01_SET28_RESETVAL (0x00000000u)
/*----SET28 Tokens----*/
#define CSL_GPIO_SET_DATA01_SET28_SET (0x00000001u)

#define CSL_GPIO_SET_DATA01_SET27_MASK (0x08000000u)
#define CSL_GPIO_SET_DATA01_SET27_SHIFT (0x0000001Bu)
#define CSL_GPIO_SET_DATA01_SET27_RESETVAL (0x00000000u)
/*----SET27 Tokens----*/
#define CSL_GPIO_SET_DATA01_SET27_SET (0x00000001u)

#define CSL_GPIO_SET_DATA01_SET26_MASK (0x04000000u)
#define CSL_GPIO_SET_DATA01_SET26_SHIFT (0x0000001Au)
#define CSL_GPIO_SET_DATA01_SET26_RESETVAL (0x00000000u)
/*----SET26 Tokens----*/
#define CSL_GPIO_SET_DATA01_SET26_SET (0x00000001u)

#define CSL_GPIO_SET_DATA01_SET25_MASK (0x02000000u)
#define CSL_GPIO_SET_DATA01_SET25_SHIFT (0x00000019u)
#define CSL_GPIO_SET_DATA01_SET25_RESETVAL (0x00000000u)
/*----SET25 Tokens----*/
#define CSL_GPIO_SET_DATA01_SET25_SET (0x00000001u)

#define CSL_GPIO_SET_DATA01_SET24_MASK (0x01000000u)
#define CSL_GPIO_SET_DATA01_SET24_SHIFT (0x00000018u)
#define CSL_GPIO_SET_DATA01_SET24_RESETVAL (0x00000000u)
/*----SET24 Tokens----*/
#define CSL_GPIO_SET_DATA01_SET24_SET (0x00000001u)

#define CSL_GPIO_SET_DATA01_SET23_MASK (0x00800000u)
#define CSL_GPIO_SET_DATA01_SET23_SHIFT (0x00000017u)
#define CSL_GPIO_SET_DATA01_SET23_RESETVAL (0x00000000u)
/*----SET23 Tokens----*/
#define CSL_GPIO_SET_DATA01_SET23_SET (0x00000001u)

#define CSL_GPIO_SET_DATA01_SET22_MASK (0x00400000u)
#define CSL_GPIO_SET_DATA01_SET22_SHIFT (0x00000016u)
#define CSL_GPIO_SET_DATA01_SET22_RESETVAL (0x00000000u)
/*----SET22 Tokens----*/
#define CSL_GPIO_SET_DATA01_SET22_SET (0x00000001u)

#define CSL_GPIO_SET_DATA01_SET21_MASK (0x00200000u)
#define CSL_GPIO_SET_DATA01_SET21_SHIFT (0x00000015u)
#define CSL_GPIO_SET_DATA01_SET21_RESETVAL (0x00000000u)
/*----SET21 Tokens----*/
#define CSL_GPIO_SET_DATA01_SET21_SET (0x00000001u)

#define CSL_GPIO_SET_DATA01_SET20_MASK (0x00100000u)
#define CSL_GPIO_SET_DATA01_SET20_SHIFT (0x00000014u)
#define CSL_GPIO_SET_DATA01_SET20_RESETVAL (0x00000000u)
/*----SET20 Tokens----*/
#define CSL_GPIO_SET_DATA01_SET20_SET (0x00000001u)

#define CSL_GPIO_SET_DATA01_SET19_MASK (0x00080000u)
#define CSL_GPIO_SET_DATA01_SET19_SHIFT (0x00000013u)
#define CSL_GPIO_SET_DATA01_SET19_RESETVAL (0x00000000u)
/*----SET19 Tokens----*/
#define CSL_GPIO_SET_DATA01_SET19_SET (0x00000001u)

#define CSL_GPIO_SET_DATA01_SET18_MASK (0x00040000u)
#define CSL_GPIO_SET_DATA01_SET18_SHIFT (0x00000012u)
#define CSL_GPIO_SET_DATA01_SET18_RESETVAL (0x00000000u)
/*----SET18 Tokens----*/
#define CSL_GPIO_SET_DATA01_SET18_SET (0x00000001u)

#define CSL_GPIO_SET_DATA01_SET17_MASK (0x00020000u)
#define CSL_GPIO_SET_DATA01_SET17_SHIFT (0x00000011u)
#define CSL_GPIO_SET_DATA01_SET17_RESETVAL (0x00000000u)
/*----SET17 Tokens----*/
#define CSL_GPIO_SET_DATA01_SET17_SET (0x00000001u)

#define CSL_GPIO_SET_DATA01_SET16_MASK (0x00010000u)
#define CSL_GPIO_SET_DATA01_SET16_SHIFT (0x00000010u)
#define CSL_GPIO_SET_DATA01_SET16_RESETVAL (0x00000000u)
/*----SET16 Tokens----*/
#define CSL_GPIO_SET_DATA01_SET16_SET (0x00000001u)

#define CSL_GPIO_SET_DATA01_SET15_MASK (0x00008000u)
#define CSL_GPIO_SET_DATA01_SET15_SHIFT (0x0000000Fu)
#define CSL_GPIO_SET_DATA01_SET15_RESETVAL (0x00000000u)
/*----SET15 Tokens----*/
#define CSL_GPIO_SET_DATA01_SET15_SET (0x00000001u)

#define CSL_GPIO_SET_DATA01_SET14_MASK (0x00004000u)
#define CSL_GPIO_SET_DATA01_SET14_SHIFT (0x0000000Eu)
#define CSL_GPIO_SET_DATA01_SET14_RESETVAL (0x00000000u)
/*----SET14 Tokens----*/
#define CSL_GPIO_SET_DATA01_SET14_SET (0x00000001u)

#define CSL_GPIO_SET_DATA01_SET13_MASK (0x00002000u)
#define CSL_GPIO_SET_DATA01_SET13_SHIFT (0x0000000Du)
#define CSL_GPIO_SET_DATA01_SET13_RESETVAL (0x00000000u)
/*----SET13 Tokens----*/
#define CSL_GPIO_SET_DATA01_SET13_SET (0x00000001u)

#define CSL_GPIO_SET_DATA01_SET12_MASK (0x00001000u)
#define CSL_GPIO_SET_DATA01_SET12_SHIFT (0x0000000Cu)
#define CSL_GPIO_SET_DATA01_SET12_RESETVAL (0x00000000u)
/*----SET12 Tokens----*/
#define CSL_GPIO_SET_DATA01_SET12_SET (0x00000001u)

#define CSL_GPIO_SET_DATA01_SET11_MASK (0x00000800u)
#define CSL_GPIO_SET_DATA01_SET11_SHIFT (0x0000000Bu)
#define CSL_GPIO_SET_DATA01_SET11_RESETVAL (0x00000000u)
/*----SET11 Tokens----*/
#define CSL_GPIO_SET_DATA01_SET11_SET (0x00000001u)

#define CSL_GPIO_SET_DATA01_SET10_MASK (0x00000400u)
#define CSL_GPIO_SET_DATA01_SET10_SHIFT (0x0000000Au)
#define CSL_GPIO_SET_DATA01_SET10_RESETVAL (0x00000000u)
/*----SET10 Tokens----*/
#define CSL_GPIO_SET_DATA01_SET10_SET (0x00000001u)

#define CSL_GPIO_SET_DATA01_SET9_MASK (0x00000200u)
#define CSL_GPIO_SET_DATA01_SET9_SHIFT (0x00000009u)
#define CSL_GPIO_SET_DATA01_SET9_RESETVAL (0x00000000u)
/*----SET9 Tokens----*/
#define CSL_GPIO_SET_DATA01_SET9_SET (0x00000001u)

#define CSL_GPIO_SET_DATA01_SET8_MASK (0x00000100u)
#define CSL_GPIO_SET_DATA01_SET8_SHIFT (0x00000008u)
#define CSL_GPIO_SET_DATA01_SET8_RESETVAL (0x00000000u)
/*----SET8 Tokens----*/
#define CSL_GPIO_SET_DATA01_SET8_SET (0x00000001u)

#define CSL_GPIO_SET_DATA01_SET7_MASK (0x00000080u)
#define CSL_GPIO_SET_DATA01_SET7_SHIFT (0x00000007u)
#define CSL_GPIO_SET_DATA01_SET7_RESETVAL (0x00000000u)
/*----SET7 Tokens----*/
#define CSL_GPIO_SET_DATA01_SET7_SET (0x00000001u)

#define CSL_GPIO_SET_DATA01_SET6_MASK (0x00000040u)
#define CSL_GPIO_SET_DATA01_SET6_SHIFT (0x00000006u)
#define CSL_GPIO_SET_DATA01_SET6_RESETVAL (0x00000000u)
/*----SET6 Tokens----*/
#define CSL_GPIO_SET_DATA01_SET6_SET (0x00000001u)

#define CSL_GPIO_SET_DATA01_SET5_MASK (0x00000020u)
#define CSL_GPIO_SET_DATA01_SET5_SHIFT (0x00000005u)
#define CSL_GPIO_SET_DATA01_SET5_RESETVAL (0x00000000u)
/*----SET5 Tokens----*/
#define CSL_GPIO_SET_DATA01_SET5_SET (0x00000001u)

#define CSL_GPIO_SET_DATA01_SET4_MASK (0x00000010u)
#define CSL_GPIO_SET_DATA01_SET4_SHIFT (0x00000004u)
#define CSL_GPIO_SET_DATA01_SET4_RESETVAL (0x00000000u)
/*----SET4 Tokens----*/
#define CSL_GPIO_SET_DATA01_SET4_SET (0x00000001u)

#define CSL_GPIO_SET_DATA01_SET3_MASK (0x00000008u)
#define CSL_GPIO_SET_DATA01_SET3_SHIFT (0x00000003u)
#define CSL_GPIO_SET_DATA01_SET3_RESETVAL (0x00000000u)
/*----SET3 Tokens----*/
#define CSL_GPIO_SET_DATA01_SET3_SET (0x00000001u)

#define CSL_GPIO_SET_DATA01_SET2_MASK (0x00000004u)
#define CSL_GPIO_SET_DATA01_SET2_SHIFT (0x00000002u)
#define CSL_GPIO_SET_DATA01_SET2_RESETVAL (0x00000000u)
/*----SET2 Tokens----*/
#define CSL_GPIO_SET_DATA01_SET2_SET (0x00000001u)

#define CSL_GPIO_SET_DATA01_SET1_MASK (0x00000002u)
#define CSL_GPIO_SET_DATA01_SET1_SHIFT (0x00000001u)
#define CSL_GPIO_SET_DATA01_SET1_RESETVAL (0x00000000u)
/*----SET1 Tokens----*/
#define CSL_GPIO_SET_DATA01_SET1_SET (0x00000001u)

#define CSL_GPIO_SET_DATA01_SET0_MASK (0x00000001u)
#define CSL_GPIO_SET_DATA01_SET0_SHIFT (0x00000000u)
#define CSL_GPIO_SET_DATA01_SET0_RESETVAL (0x00000000u)
/*----SET0 Tokens----*/
#define CSL_GPIO_SET_DATA01_SET0_SET (0x00000001u)

#define CSL_GPIO_SET_DATA01_RESETVAL (0x00000000u)

/* CLR_DATA01 */

#define CSL_GPIO_CLR_DATA01_CLR31_MASK (0x80000000u)
#define CSL_GPIO_CLR_DATA01_CLR31_SHIFT (0x0000001Fu)
#define CSL_GPIO_CLR_DATA01_CLR31_RESETVAL (0x00000000u)
/*----CLR31 Tokens----*/
#define CSL_GPIO_CLR_DATA01_CLR31_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA01_CLR30_MASK (0x40000000u)
#define CSL_GPIO_CLR_DATA01_CLR30_SHIFT (0x0000001Eu)
#define CSL_GPIO_CLR_DATA01_CLR30_RESETVAL (0x00000000u)
/*----CLR30 Tokens----*/
#define CSL_GPIO_CLR_DATA01_CLR30_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA01_CLR29_MASK (0x20000000u)
#define CSL_GPIO_CLR_DATA01_CLR29_SHIFT (0x0000001Du)
#define CSL_GPIO_CLR_DATA01_CLR29_RESETVAL (0x00000000u)
/*----CLR29 Tokens----*/
#define CSL_GPIO_CLR_DATA01_CLR29_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA01_CLR28_MASK (0x10000000u)
#define CSL_GPIO_CLR_DATA01_CLR28_SHIFT (0x0000001Cu)
#define CSL_GPIO_CLR_DATA01_CLR28_RESETVAL (0x00000000u)
/*----CLR28 Tokens----*/
#define CSL_GPIO_CLR_DATA01_CLR28_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA01_CLR27_MASK (0x08000000u)
#define CSL_GPIO_CLR_DATA01_CLR27_SHIFT (0x0000001Bu)
#define CSL_GPIO_CLR_DATA01_CLR27_RESETVAL (0x00000000u)
/*----CLR27 Tokens----*/
#define CSL_GPIO_CLR_DATA01_CLR27_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA01_CLR26_MASK (0x04000000u)
#define CSL_GPIO_CLR_DATA01_CLR26_SHIFT (0x0000001Au)
#define CSL_GPIO_CLR_DATA01_CLR26_RESETVAL (0x00000000u)
/*----CLR26 Tokens----*/
#define CSL_GPIO_CLR_DATA01_CLR26_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA01_CLR25_MASK (0x02000000u)
#define CSL_GPIO_CLR_DATA01_CLR25_SHIFT (0x00000019u)
#define CSL_GPIO_CLR_DATA01_CLR25_RESETVAL (0x00000000u)
/*----CLR25 Tokens----*/
#define CSL_GPIO_CLR_DATA01_CLR25_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA01_CLR24_MASK (0x01000000u)
#define CSL_GPIO_CLR_DATA01_CLR24_SHIFT (0x00000018u)
#define CSL_GPIO_CLR_DATA01_CLR24_RESETVAL (0x00000000u)
/*----CLR24 Tokens----*/
#define CSL_GPIO_CLR_DATA01_CLR24_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA01_CLR23_MASK (0x00800000u)
#define CSL_GPIO_CLR_DATA01_CLR23_SHIFT (0x00000017u)
#define CSL_GPIO_CLR_DATA01_CLR23_RESETVAL (0x00000000u)
/*----CLR23 Tokens----*/
#define CSL_GPIO_CLR_DATA01_CLR23_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA01_CLR22_MASK (0x00400000u)
#define CSL_GPIO_CLR_DATA01_CLR22_SHIFT (0x00000016u)
#define CSL_GPIO_CLR_DATA01_CLR22_RESETVAL (0x00000000u)
/*----CLR22 Tokens----*/
#define CSL_GPIO_CLR_DATA01_CLR22_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA01_CLR21_MASK (0x00200000u)
#define CSL_GPIO_CLR_DATA01_CLR21_SHIFT (0x00000015u)
#define CSL_GPIO_CLR_DATA01_CLR21_RESETVAL (0x00000000u)
/*----CLR21 Tokens----*/
#define CSL_GPIO_CLR_DATA01_CLR21_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA01_CLR20_MASK (0x00100000u)
#define CSL_GPIO_CLR_DATA01_CLR20_SHIFT (0x00000014u)
#define CSL_GPIO_CLR_DATA01_CLR20_RESETVAL (0x00000000u)
/*----CLR20 Tokens----*/
#define CSL_GPIO_CLR_DATA01_CLR20_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA01_CLR19_MASK (0x00080000u)
#define CSL_GPIO_CLR_DATA01_CLR19_SHIFT (0x00000013u)
#define CSL_GPIO_CLR_DATA01_CLR19_RESETVAL (0x00000000u)
/*----CLR19 Tokens----*/
#define CSL_GPIO_CLR_DATA01_CLR19_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA01_CLR18_MASK (0x00040000u)
#define CSL_GPIO_CLR_DATA01_CLR18_SHIFT (0x00000012u)
#define CSL_GPIO_CLR_DATA01_CLR18_RESETVAL (0x00000000u)
/*----CLR18 Tokens----*/
#define CSL_GPIO_CLR_DATA01_CLR18_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA01_CLR17_MASK (0x00020000u)
#define CSL_GPIO_CLR_DATA01_CLR17_SHIFT (0x00000011u)
#define CSL_GPIO_CLR_DATA01_CLR17_RESETVAL (0x00000000u)
/*----CLR17 Tokens----*/
#define CSL_GPIO_CLR_DATA01_CLR17_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA01_CLR16_MASK (0x00010000u)
#define CSL_GPIO_CLR_DATA01_CLR16_SHIFT (0x00000010u)
#define CSL_GPIO_CLR_DATA01_CLR16_RESETVAL (0x00000000u)
/*----CLR16 Tokens----*/
#define CSL_GPIO_CLR_DATA01_CLR16_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA01_CLR15_MASK (0x00008000u)
#define CSL_GPIO_CLR_DATA01_CLR15_SHIFT (0x0000000Fu)
#define CSL_GPIO_CLR_DATA01_CLR15_RESETVAL (0x00000000u)
/*----CLR15 Tokens----*/
#define CSL_GPIO_CLR_DATA01_CLR15_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA01_CLR14_MASK (0x00004000u)
#define CSL_GPIO_CLR_DATA01_CLR14_SHIFT (0x0000000Eu)
#define CSL_GPIO_CLR_DATA01_CLR14_RESETVAL (0x00000000u)
/*----CLR14 Tokens----*/
#define CSL_GPIO_CLR_DATA01_CLR14_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA01_CLR13_MASK (0x00002000u)
#define CSL_GPIO_CLR_DATA01_CLR13_SHIFT (0x0000000Du)
#define CSL_GPIO_CLR_DATA01_CLR13_RESETVAL (0x00000000u)
/*----CLR13 Tokens----*/
#define CSL_GPIO_CLR_DATA01_CLR13_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA01_CLR12_MASK (0x00001000u)
#define CSL_GPIO_CLR_DATA01_CLR12_SHIFT (0x0000000Cu)
#define CSL_GPIO_CLR_DATA01_CLR12_RESETVAL (0x00000000u)
/*----CLR12 Tokens----*/
#define CSL_GPIO_CLR_DATA01_CLR12_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA01_CLR11_MASK (0x00000800u)
#define CSL_GPIO_CLR_DATA01_CLR11_SHIFT (0x0000000Bu)
#define CSL_GPIO_CLR_DATA01_CLR11_RESETVAL (0x00000000u)
/*----CLR11 Tokens----*/
#define CSL_GPIO_CLR_DATA01_CLR11_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA01_CLR10_MASK (0x00000400u)
#define CSL_GPIO_CLR_DATA01_CLR10_SHIFT (0x0000000Au)
#define CSL_GPIO_CLR_DATA01_CLR10_RESETVAL (0x00000000u)
/*----CLR10 Tokens----*/
#define CSL_GPIO_CLR_DATA01_CLR10_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA01_CLR9_MASK (0x00000200u)
#define CSL_GPIO_CLR_DATA01_CLR9_SHIFT (0x00000009u)
#define CSL_GPIO_CLR_DATA01_CLR9_RESETVAL (0x00000000u)
/*----CLR9 Tokens----*/
#define CSL_GPIO_CLR_DATA01_CLR9_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA01_CLR8_MASK (0x00000100u)
#define CSL_GPIO_CLR_DATA01_CLR8_SHIFT (0x00000008u)
#define CSL_GPIO_CLR_DATA01_CLR8_RESETVAL (0x00000000u)
/*----CLR8 Tokens----*/
#define CSL_GPIO_CLR_DATA01_CLR8_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA01_CLR7_MASK (0x00000080u)
#define CSL_GPIO_CLR_DATA01_CLR7_SHIFT (0x00000007u)
#define CSL_GPIO_CLR_DATA01_CLR7_RESETVAL (0x00000000u)
/*----CLR7 Tokens----*/
#define CSL_GPIO_CLR_DATA01_CLR7_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA01_CLR6_MASK (0x00000040u)
#define CSL_GPIO_CLR_DATA01_CLR6_SHIFT (0x00000006u)
#define CSL_GPIO_CLR_DATA01_CLR6_RESETVAL (0x00000000u)
/*----CLR6 Tokens----*/
#define CSL_GPIO_CLR_DATA01_CLR6_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA01_CLR5_MASK (0x00000020u)
#define CSL_GPIO_CLR_DATA01_CLR5_SHIFT (0x00000005u)
#define CSL_GPIO_CLR_DATA01_CLR5_RESETVAL (0x00000000u)
/*----CLR5 Tokens----*/
#define CSL_GPIO_CLR_DATA01_CLR5_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA01_CLR4_MASK (0x00000010u)
#define CSL_GPIO_CLR_DATA01_CLR4_SHIFT (0x00000004u)
#define CSL_GPIO_CLR_DATA01_CLR4_RESETVAL (0x00000000u)
/*----CLR4 Tokens----*/
#define CSL_GPIO_CLR_DATA01_CLR4_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA01_CLR3_MASK (0x00000008u)
#define CSL_GPIO_CLR_DATA01_CLR3_SHIFT (0x00000003u)
#define CSL_GPIO_CLR_DATA01_CLR3_RESETVAL (0x00000000u)
/*----CLR3 Tokens----*/
#define CSL_GPIO_CLR_DATA01_CLR3_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA01_CLR2_MASK (0x00000004u)
#define CSL_GPIO_CLR_DATA01_CLR2_SHIFT (0x00000002u)
#define CSL_GPIO_CLR_DATA01_CLR2_RESETVAL (0x00000000u)
/*----CLR2 Tokens----*/
#define CSL_GPIO_CLR_DATA01_CLR2_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA01_CLR1_MASK (0x00000002u)
#define CSL_GPIO_CLR_DATA01_CLR1_SHIFT (0x00000001u)
#define CSL_GPIO_CLR_DATA01_CLR1_RESETVAL (0x00000000u)
/*----CLR1 Tokens----*/
#define CSL_GPIO_CLR_DATA01_CLR1_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA01_CLR0_MASK (0x00000001u)
#define CSL_GPIO_CLR_DATA01_CLR0_SHIFT (0x00000000u)
#define CSL_GPIO_CLR_DATA01_CLR0_RESETVAL (0x00000000u)
/*----CLR0 Tokens----*/
#define CSL_GPIO_CLR_DATA01_CLR0_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA01_RESETVAL (0x00000000u)

/* IN_DATA01 */

#define CSL_GPIO_IN_DATA01_IN31_MASK (0x80000000u)
#define CSL_GPIO_IN_DATA01_IN31_SHIFT (0x0000001Fu)
#define CSL_GPIO_IN_DATA01_IN31_RESETVAL (0x00000000u)
/*----IN31 Tokens----*/
#define CSL_GPIO_IN_DATA01_IN31_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA01_IN31_SET (0x00000001u)

#define CSL_GPIO_IN_DATA01_IN30_MASK (0x40000000u)
#define CSL_GPIO_IN_DATA01_IN30_SHIFT (0x0000001Eu)
#define CSL_GPIO_IN_DATA01_IN30_RESETVAL (0x00000000u)
/*----IN30 Tokens----*/
#define CSL_GPIO_IN_DATA01_IN30_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA01_IN30_SET (0x00000001u)

#define CSL_GPIO_IN_DATA01_IN29_MASK (0x20000000u)
#define CSL_GPIO_IN_DATA01_IN29_SHIFT (0x0000001Du)
#define CSL_GPIO_IN_DATA01_IN29_RESETVAL (0x00000000u)
/*----IN29 Tokens----*/
#define CSL_GPIO_IN_DATA01_IN29_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA01_IN29_SET (0x00000001u)

#define CSL_GPIO_IN_DATA01_IN28_MASK (0x10000000u)
#define CSL_GPIO_IN_DATA01_IN28_SHIFT (0x0000001Cu)
#define CSL_GPIO_IN_DATA01_IN28_RESETVAL (0x00000000u)
/*----IN28 Tokens----*/
#define CSL_GPIO_IN_DATA01_IN28_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA01_IN28_SET (0x00000001u)

#define CSL_GPIO_IN_DATA01_IN27_MASK (0x08000000u)
#define CSL_GPIO_IN_DATA01_IN27_SHIFT (0x0000001Bu)
#define CSL_GPIO_IN_DATA01_IN27_RESETVAL (0x00000000u)
/*----IN27 Tokens----*/
#define CSL_GPIO_IN_DATA01_IN27_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA01_IN27_SET (0x00000001u)

#define CSL_GPIO_IN_DATA01_IN26_MASK (0x04000000u)
#define CSL_GPIO_IN_DATA01_IN26_SHIFT (0x0000001Au)
#define CSL_GPIO_IN_DATA01_IN26_RESETVAL (0x00000000u)
/*----IN26 Tokens----*/
#define CSL_GPIO_IN_DATA01_IN26_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA01_IN26_SET (0x00000001u)

#define CSL_GPIO_IN_DATA01_IN25_MASK (0x02000000u)
#define CSL_GPIO_IN_DATA01_IN25_SHIFT (0x00000019u)
#define CSL_GPIO_IN_DATA01_IN25_RESETVAL (0x00000000u)
/*----IN25 Tokens----*/
#define CSL_GPIO_IN_DATA01_IN25_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA01_IN25_SET (0x00000001u)

#define CSL_GPIO_IN_DATA01_IN24_MASK (0x01000000u)
#define CSL_GPIO_IN_DATA01_IN24_SHIFT (0x00000018u)
#define CSL_GPIO_IN_DATA01_IN24_RESETVAL (0x00000000u)
/*----IN24 Tokens----*/
#define CSL_GPIO_IN_DATA01_IN24_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA01_IN24_SET (0x00000001u)

#define CSL_GPIO_IN_DATA01_IN23_MASK (0x00800000u)
#define CSL_GPIO_IN_DATA01_IN23_SHIFT (0x00000017u)
#define CSL_GPIO_IN_DATA01_IN23_RESETVAL (0x00000000u)
/*----IN23 Tokens----*/
#define CSL_GPIO_IN_DATA01_IN23_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA01_IN23_SET (0x00000001u)

#define CSL_GPIO_IN_DATA01_IN22_MASK (0x00400000u)
#define CSL_GPIO_IN_DATA01_IN22_SHIFT (0x00000016u)
#define CSL_GPIO_IN_DATA01_IN22_RESETVAL (0x00000000u)
/*----IN22 Tokens----*/
#define CSL_GPIO_IN_DATA01_IN22_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA01_IN22_SET (0x00000001u)

#define CSL_GPIO_IN_DATA01_IN21_MASK (0x00200000u)
#define CSL_GPIO_IN_DATA01_IN21_SHIFT (0x00000015u)
#define CSL_GPIO_IN_DATA01_IN21_RESETVAL (0x00000000u)
/*----IN21 Tokens----*/
#define CSL_GPIO_IN_DATA01_IN21_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA01_IN21_SET (0x00000001u)

#define CSL_GPIO_IN_DATA01_IN20_MASK (0x00100000u)
#define CSL_GPIO_IN_DATA01_IN20_SHIFT (0x00000014u)
#define CSL_GPIO_IN_DATA01_IN20_RESETVAL (0x00000000u)
/*----IN20 Tokens----*/
#define CSL_GPIO_IN_DATA01_IN20_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA01_IN20_SET (0x00000001u)

#define CSL_GPIO_IN_DATA01_IN19_MASK (0x00080000u)
#define CSL_GPIO_IN_DATA01_IN19_SHIFT (0x00000013u)
#define CSL_GPIO_IN_DATA01_IN19_RESETVAL (0x00000000u)
/*----IN19 Tokens----*/
#define CSL_GPIO_IN_DATA01_IN19_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA01_IN19_SET (0x00000001u)

#define CSL_GPIO_IN_DATA01_IN18_MASK (0x00040000u)
#define CSL_GPIO_IN_DATA01_IN18_SHIFT (0x00000012u)
#define CSL_GPIO_IN_DATA01_IN18_RESETVAL (0x00000000u)
/*----IN18 Tokens----*/
#define CSL_GPIO_IN_DATA01_IN18_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA01_IN18_SET (0x00000001u)

#define CSL_GPIO_IN_DATA01_IN17_MASK (0x00020000u)
#define CSL_GPIO_IN_DATA01_IN17_SHIFT (0x00000011u)
#define CSL_GPIO_IN_DATA01_IN17_RESETVAL (0x00000000u)
/*----IN17 Tokens----*/
#define CSL_GPIO_IN_DATA01_IN17_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA01_IN17_SET (0x00000001u)

#define CSL_GPIO_IN_DATA01_IN16_MASK (0x00010000u)
#define CSL_GPIO_IN_DATA01_IN16_SHIFT (0x00000010u)
#define CSL_GPIO_IN_DATA01_IN16_RESETVAL (0x00000000u)
/*----IN16 Tokens----*/
#define CSL_GPIO_IN_DATA01_IN16_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA01_IN16_SET (0x00000001u)

#define CSL_GPIO_IN_DATA01_IN15_MASK (0x00008000u)
#define CSL_GPIO_IN_DATA01_IN15_SHIFT (0x0000000Fu)
#define CSL_GPIO_IN_DATA01_IN15_RESETVAL (0x00000000u)
/*----IN15 Tokens----*/
#define CSL_GPIO_IN_DATA01_IN15_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA01_IN15_SET (0x00000001u)

#define CSL_GPIO_IN_DATA01_IN14_MASK (0x00004000u)
#define CSL_GPIO_IN_DATA01_IN14_SHIFT (0x0000000Eu)
#define CSL_GPIO_IN_DATA01_IN14_RESETVAL (0x00000000u)
/*----IN14 Tokens----*/
#define CSL_GPIO_IN_DATA01_IN14_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA01_IN14_SET (0x00000001u)

#define CSL_GPIO_IN_DATA01_IN13_MASK (0x00002000u)
#define CSL_GPIO_IN_DATA01_IN13_SHIFT (0x0000000Du)
#define CSL_GPIO_IN_DATA01_IN13_RESETVAL (0x00000000u)
/*----IN13 Tokens----*/
#define CSL_GPIO_IN_DATA01_IN13_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA01_IN13_SET (0x00000001u)

#define CSL_GPIO_IN_DATA01_IN12_MASK (0x00001000u)
#define CSL_GPIO_IN_DATA01_IN12_SHIFT (0x0000000Cu)
#define CSL_GPIO_IN_DATA01_IN12_RESETVAL (0x00000000u)
/*----IN12 Tokens----*/
#define CSL_GPIO_IN_DATA01_IN12_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA01_IN12_SET (0x00000001u)

#define CSL_GPIO_IN_DATA01_IN11_MASK (0x00000800u)
#define CSL_GPIO_IN_DATA01_IN11_SHIFT (0x0000000Bu)
#define CSL_GPIO_IN_DATA01_IN11_RESETVAL (0x00000000u)
/*----IN11 Tokens----*/
#define CSL_GPIO_IN_DATA01_IN11_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA01_IN11_SET (0x00000001u)

#define CSL_GPIO_IN_DATA01_IN10_MASK (0x00000400u)
#define CSL_GPIO_IN_DATA01_IN10_SHIFT (0x0000000Au)
#define CSL_GPIO_IN_DATA01_IN10_RESETVAL (0x00000000u)
/*----IN10 Tokens----*/
#define CSL_GPIO_IN_DATA01_IN10_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA01_IN10_SET (0x00000001u)

#define CSL_GPIO_IN_DATA01_IN9_MASK (0x00000200u)
#define CSL_GPIO_IN_DATA01_IN9_SHIFT (0x00000009u)
#define CSL_GPIO_IN_DATA01_IN9_RESETVAL (0x00000000u)
/*----IN9 Tokens----*/
#define CSL_GPIO_IN_DATA01_IN9_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA01_IN9_SET (0x00000001u)

#define CSL_GPIO_IN_DATA01_IN8_MASK (0x00000100u)
#define CSL_GPIO_IN_DATA01_IN8_SHIFT (0x00000008u)
#define CSL_GPIO_IN_DATA01_IN8_RESETVAL (0x00000000u)
/*----IN8 Tokens----*/
#define CSL_GPIO_IN_DATA01_IN8_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA01_IN8_SET (0x00000001u)

#define CSL_GPIO_IN_DATA01_IN7_MASK (0x00000080u)
#define CSL_GPIO_IN_DATA01_IN7_SHIFT (0x00000007u)
#define CSL_GPIO_IN_DATA01_IN7_RESETVAL (0x00000000u)
/*----IN7 Tokens----*/
#define CSL_GPIO_IN_DATA01_IN7_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA01_IN7_SET (0x00000001u)

#define CSL_GPIO_IN_DATA01_IN6_MASK (0x00000040u)
#define CSL_GPIO_IN_DATA01_IN6_SHIFT (0x00000006u)
#define CSL_GPIO_IN_DATA01_IN6_RESETVAL (0x00000000u)
/*----IN6 Tokens----*/
#define CSL_GPIO_IN_DATA01_IN6_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA01_IN6_SET (0x00000001u)

#define CSL_GPIO_IN_DATA01_IN5_MASK (0x00000020u)
#define CSL_GPIO_IN_DATA01_IN5_SHIFT (0x00000005u)
#define CSL_GPIO_IN_DATA01_IN5_RESETVAL (0x00000000u)
/*----IN5 Tokens----*/
#define CSL_GPIO_IN_DATA01_IN5_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA01_IN5_SET (0x00000001u)

#define CSL_GPIO_IN_DATA01_IN4_MASK (0x00000010u)
#define CSL_GPIO_IN_DATA01_IN4_SHIFT (0x00000004u)
#define CSL_GPIO_IN_DATA01_IN4_RESETVAL (0x00000000u)
/*----IN4 Tokens----*/
#define CSL_GPIO_IN_DATA01_IN4_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA01_IN4_SET (0x00000001u)

#define CSL_GPIO_IN_DATA01_IN3_MASK (0x00000008u)
#define CSL_GPIO_IN_DATA01_IN3_SHIFT (0x00000003u)
#define CSL_GPIO_IN_DATA01_IN3_RESETVAL (0x00000000u)
/*----IN3 Tokens----*/
#define CSL_GPIO_IN_DATA01_IN3_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA01_IN3_SET (0x00000001u)

#define CSL_GPIO_IN_DATA01_IN2_MASK (0x00000004u)
#define CSL_GPIO_IN_DATA01_IN2_SHIFT (0x00000002u)
#define CSL_GPIO_IN_DATA01_IN2_RESETVAL (0x00000000u)
/*----IN2 Tokens----*/
#define CSL_GPIO_IN_DATA01_IN2_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA01_IN2_SET (0x00000001u)

#define CSL_GPIO_IN_DATA01_IN1_MASK (0x00000002u)
#define CSL_GPIO_IN_DATA01_IN1_SHIFT (0x00000001u)
#define CSL_GPIO_IN_DATA01_IN1_RESETVAL (0x00000000u)
/*----IN1 Tokens----*/
#define CSL_GPIO_IN_DATA01_IN1_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA01_IN1_SET (0x00000001u)

#define CSL_GPIO_IN_DATA01_IN0_MASK (0x00000001u)
#define CSL_GPIO_IN_DATA01_IN0_SHIFT (0x00000000u)
#define CSL_GPIO_IN_DATA01_IN0_RESETVAL (0x00000000u)
/*----IN0 Tokens----*/
#define CSL_GPIO_IN_DATA01_IN0_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA01_IN0_SET (0x00000001u)

#define CSL_GPIO_IN_DATA01_RESETVAL (0x00000000u)

/* SET_RIS_TRIG01 */

#define CSL_GPIO_SET_RIS_TRIG01_SETRIS31_MASK (0x80000000u)
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS31_SHIFT (0x0000001Fu)
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS31_RESETVAL (0x00000000u)
/*----SETRIS31 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS31_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG01_SETRIS30_MASK (0x40000000u)
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS30_SHIFT (0x0000001Eu)
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS30_RESETVAL (0x00000000u)
/*----SETRIS30 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS30_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG01_SETRIS29_MASK (0x20000000u)
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS29_SHIFT (0x0000001Du)
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS29_RESETVAL (0x00000000u)
/*----SETRIS29 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS29_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG01_SETRIS28_MASK (0x10000000u)
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS28_SHIFT (0x0000001Cu)
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS28_RESETVAL (0x00000000u)
/*----SETRIS28 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS28_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG01_SETRIS27_MASK (0x08000000u)
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS27_SHIFT (0x0000001Bu)
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS27_RESETVAL (0x00000000u)
/*----SETRIS27 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS27_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG01_SETRIS26_MASK (0x04000000u)
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS26_SHIFT (0x0000001Au)
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS26_RESETVAL (0x00000000u)
/*----SETRIS26 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS26_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG01_SETRIS25_MASK (0x02000000u)
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS25_SHIFT (0x00000019u)
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS25_RESETVAL (0x00000000u)
/*----SETRIS25 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS25_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG01_SETRIS24_MASK (0x01000000u)
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS24_SHIFT (0x00000018u)
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS24_RESETVAL (0x00000000u)
/*----SETRIS24 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS24_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG01_SETRIS23_MASK (0x00800000u)
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS23_SHIFT (0x00000017u)
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS23_RESETVAL (0x00000000u)
/*----SETRIS23 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS23_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG01_SETRIS22_MASK (0x00400000u)
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS22_SHIFT (0x00000016u)
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS22_RESETVAL (0x00000000u)
/*----SETRIS22 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS22_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG01_SETRIS21_MASK (0x00200000u)
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS21_SHIFT (0x00000015u)
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS21_RESETVAL (0x00000000u)
/*----SETRIS21 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS21_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG01_SETRIS20_MASK (0x00100000u)
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS20_SHIFT (0x00000014u)
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS20_RESETVAL (0x00000000u)
/*----SETRIS20 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS20_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG01_SETRIS19_MASK (0x00080000u)
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS19_SHIFT (0x00000013u)
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS19_RESETVAL (0x00000000u)
/*----SETRIS19 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS19_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG01_SETRIS18_MASK (0x00040000u)
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS18_SHIFT (0x00000012u)
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS18_RESETVAL (0x00000000u)
/*----SETRIS18 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS18_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG01_SETRIS17_MASK (0x00020000u)
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS17_SHIFT (0x00000011u)
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS17_RESETVAL (0x00000000u)
/*----SETRIS17 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS17_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG01_SETRIS16_MASK (0x00010000u)
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS16_SHIFT (0x00000010u)
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS16_RESETVAL (0x00000000u)
/*----SETRIS16 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS16_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG01_SETRIS15_MASK (0x00008000u)
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS15_SHIFT (0x0000000Fu)
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS15_RESETVAL (0x00000000u)
/*----SETRIS15 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS15_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG01_SETRIS14_MASK (0x00004000u)
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS14_SHIFT (0x0000000Eu)
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS14_RESETVAL (0x00000000u)
/*----SETRIS14 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS14_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG01_SETRIS13_MASK (0x00002000u)
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS13_SHIFT (0x0000000Du)
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS13_RESETVAL (0x00000000u)
/*----SETRIS13 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS13_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG01_SETRIS12_MASK (0x00001000u)
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS12_SHIFT (0x0000000Cu)
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS12_RESETVAL (0x00000000u)
/*----SETRIS12 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS12_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG01_SETRIS11_MASK (0x00000800u)
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS11_SHIFT (0x0000000Bu)
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS11_RESETVAL (0x00000000u)
/*----SETRIS11 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS11_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG01_SETRIS10_MASK (0x00000400u)
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS10_SHIFT (0x0000000Au)
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS10_RESETVAL (0x00000000u)
/*----SETRIS10 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS10_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG01_SETRIS9_MASK (0x00000200u)
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS9_SHIFT (0x00000009u)
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS9_RESETVAL (0x00000000u)
/*----SETRIS9 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS9_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG01_SETRIS8_MASK (0x00000100u)
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS8_SHIFT (0x00000008u)
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS8_RESETVAL (0x00000000u)
/*----SETRIS8 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS8_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG01_SETRIS7_MASK (0x00000080u)
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS7_SHIFT (0x00000007u)
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS7_RESETVAL (0x00000000u)
/*----SETRIS7 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS7_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG01_SETRIS6_MASK (0x00000040u)
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS6_SHIFT (0x00000006u)
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS6_RESETVAL (0x00000000u)
/*----SETRIS6 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS6_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG01_SETRIS5_MASK (0x00000020u)
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS5_SHIFT (0x00000005u)
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS5_RESETVAL (0x00000000u)
/*----SETRIS5 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS5_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG01_SETRIS4_MASK (0x00000010u)
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS4_SHIFT (0x00000004u)
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS4_RESETVAL (0x00000000u)
/*----SETRIS4 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS4_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG01_SETRIS3_MASK (0x00000008u)
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS3_SHIFT (0x00000003u)
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS3_RESETVAL (0x00000000u)
/*----SETRIS3 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS3_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG01_SETRIS2_MASK (0x00000004u)
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS2_SHIFT (0x00000002u)
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS2_RESETVAL (0x00000000u)
/*----SETRIS2 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS2_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG01_SETRIS1_MASK (0x00000002u)
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS1_SHIFT (0x00000001u)
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS1_RESETVAL (0x00000000u)
/*----SETRIS1 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS1_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG01_SETRIS0_MASK (0x00000001u)
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS0_SHIFT (0x00000000u)
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS0_RESETVAL (0x00000000u)
/*----SETRIS0 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG01_SETRIS0_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG01_RESETVAL (0x00000000u)

/* CLR_RIS_TRIG01 */

#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS31_MASK (0x80000000u)
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS31_SHIFT (0x0000001Fu)
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS31_RESETVAL (0x00000000u)
/*----CLRRIS31 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS31_DISABLE (0x00000001u)

#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS30_MASK (0x40000000u)
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS30_SHIFT (0x0000001Eu)
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS30_RESETVAL (0x00000000u)
/*----CLRRIS30 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS30_DISABLE (0x00000001u)

#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS29_MASK (0x20000000u)
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS29_SHIFT (0x0000001Du)
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS29_RESETVAL (0x00000000u)
/*----CLRRIS29 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS29_DISABLE (0x00000001u)

#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS28_MASK (0x10000000u)
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS28_SHIFT (0x0000001Cu)
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS28_RESETVAL (0x00000000u)
/*----CLRRIS28 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS28_DISABLE (0x00000001u)

#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS27_MASK (0x08000000u)
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS27_SHIFT (0x0000001Bu)
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS27_RESETVAL (0x00000000u)
/*----CLRRIS27 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS27_DISABLE (0x00000001u)

#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS26_MASK (0x04000000u)
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS26_SHIFT (0x0000001Au)
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS26_RESETVAL (0x00000000u)
/*----CLRRIS26 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS26_DISABLE (0x00000001u)

#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS25_MASK (0x02000000u)
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS25_SHIFT (0x00000019u)
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS25_RESETVAL (0x00000000u)
/*----CLRRIS25 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS25_DISABLE (0x00000001u)

#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS24_MASK (0x01000000u)
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS24_SHIFT (0x00000018u)
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS24_RESETVAL (0x00000000u)
/*----CLRRIS24 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS24_DISABLE (0x00000001u)

#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS23_MASK (0x00800000u)
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS23_SHIFT (0x00000017u)
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS23_RESETVAL (0x00000000u)
/*----CLRRIS23 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS23_DISABLE (0x00000001u)

#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS22_MASK (0x00400000u)
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS22_SHIFT (0x00000016u)
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS22_RESETVAL (0x00000000u)
/*----CLRRIS22 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS22_DISABLE (0x00000001u)

#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS21_MASK (0x00200000u)
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS21_SHIFT (0x00000015u)
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS21_RESETVAL (0x00000000u)
/*----CLRRIS21 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS21_DISABLE (0x00000001u)

#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS20_MASK (0x00100000u)
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS20_SHIFT (0x00000014u)
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS20_RESETVAL (0x00000000u)
/*----CLRRIS20 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS20_DISABLE (0x00000001u)

#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS19_MASK (0x00080000u)
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS19_SHIFT (0x00000013u)
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS19_RESETVAL (0x00000000u)
/*----CLRRIS19 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS19_DISABLE (0x00000001u)

#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS18_MASK (0x00040000u)
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS18_SHIFT (0x00000012u)
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS18_RESETVAL (0x00000000u)
/*----CLRRIS18 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS18_DISABLE (0x00000001u)

#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS17_MASK (0x00020000u)
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS17_SHIFT (0x00000011u)
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS17_RESETVAL (0x00000000u)
/*----CLRRIS17 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS17_DISABLE (0x00000001u)

#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS16_MASK (0x00010000u)
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS16_SHIFT (0x00000010u)
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS16_RESETVAL (0x00000000u)
/*----CLRRIS16 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS16_DISABLE (0x00000001u)

#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS15_MASK (0x00008000u)
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS15_SHIFT (0x0000000Fu)
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS15_RESETVAL (0x00000000u)
/*----CLRRIS15 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS15_DISABLE (0x00000001u)

#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS14_MASK (0x00004000u)
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS14_SHIFT (0x0000000Eu)
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS14_RESETVAL (0x00000000u)
/*----CLRRIS14 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS14_DISABLE (0x00000001u)

#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS13_MASK (0x00002000u)
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS13_SHIFT (0x0000000Du)
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS13_RESETVAL (0x00000000u)
/*----CLRRIS13 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS13_DISABLE (0x00000001u)

#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS12_MASK (0x00001000u)
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS12_SHIFT (0x0000000Cu)
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS12_RESETVAL (0x00000000u)
/*----CLRRIS12 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS12_DISABLE (0x00000001u)

#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS11_MASK (0x00000800u)
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS11_SHIFT (0x0000000Bu)
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS11_RESETVAL (0x00000000u)
/*----CLRRIS11 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS11_DISABLE (0x00000001u)

#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS10_MASK (0x00000400u)
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS10_SHIFT (0x0000000Au)
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS10_RESETVAL (0x00000000u)
/*----CLRRIS10 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS10_DISABLE (0x00000001u)

#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS9_MASK (0x00000200u)
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS9_SHIFT (0x00000009u)
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS9_RESETVAL (0x00000000u)
/*----CLRRIS9 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS9_DISABLE (0x00000001u)

#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS8_MASK (0x00000100u)
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS8_SHIFT (0x00000008u)
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS8_RESETVAL (0x00000000u)
/*----CLRRIS8 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS8_DISABLE (0x00000001u)

#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS7_MASK (0x00000080u)
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS7_SHIFT (0x00000007u)
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS7_RESETVAL (0x00000000u)
/*----CLRRIS7 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS7_DISABLE (0x00000001u)

#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS6_MASK (0x00000040u)
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS6_SHIFT (0x00000006u)
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS6_RESETVAL (0x00000000u)
/*----CLRRIS6 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS6_DISABLE (0x00000001u)

#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS5_MASK (0x00000020u)
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS5_SHIFT (0x00000005u)
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS5_RESETVAL (0x00000000u)
/*----CLRRIS5 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS5_DISABLE (0x00000001u)

#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS4_MASK (0x00000010u)
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS4_SHIFT (0x00000004u)
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS4_RESETVAL (0x00000000u)
/*----CLRRIS4 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS4_DISABLE (0x00000001u)

#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS3_MASK (0x00000008u)
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS3_SHIFT (0x00000003u)
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS3_RESETVAL (0x00000000u)
/*----CLRRIS3 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS3_DISABLE (0x00000001u)

#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS2_MASK (0x00000004u)
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS2_SHIFT (0x00000002u)
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS2_RESETVAL (0x00000000u)
/*----CLRRIS2 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS2_DISABLE (0x00000001u)

#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS1_MASK (0x00000002u)
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS1_SHIFT (0x00000001u)
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS1_RESETVAL (0x00000000u)
/*----CLRRIS1 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS1_DISABLE (0x00000001u)

#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS0_MASK (0x00000001u)
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS0_SHIFT (0x00000000u)
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS0_RESETVAL (0x00000000u)
/*----CLRRIS0 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG01_CLRRIS0_DISABLE (0x00000001u)

#define CSL_GPIO_CLR_RIS_TRIG01_RESETVAL (0x00000000u)

/* SET_FAL_TRIG01 */

#define CSL_GPIO_SET_FAL_TRIG01_SETFAL31_MASK (0x80000000u)
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL31_SHIFT (0x0000001Fu)
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL31_RESETVAL (0x00000000u)
/*----SETFAL31 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL31_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG01_SETFAL30_MASK (0x40000000u)
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL30_SHIFT (0x0000001Eu)
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL30_RESETVAL (0x00000000u)
/*----SETFAL30 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL30_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG01_SETFAL29_MASK (0x20000000u)
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL29_SHIFT (0x0000001Du)
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL29_RESETVAL (0x00000000u)
/*----SETFAL29 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL29_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG01_SETFAL28_MASK (0x10000000u)
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL28_SHIFT (0x0000001Cu)
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL28_RESETVAL (0x00000000u)
/*----SETFAL28 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL28_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG01_SETFAL27_MASK (0x08000000u)
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL27_SHIFT (0x0000001Bu)
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL27_RESETVAL (0x00000000u)
/*----SETFAL27 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL27_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG01_SETFAL26_MASK (0x04000000u)
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL26_SHIFT (0x0000001Au)
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL26_RESETVAL (0x00000000u)
/*----SETFAL26 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL26_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG01_SETFAL25_MASK (0x02000000u)
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL25_SHIFT (0x00000019u)
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL25_RESETVAL (0x00000000u)
/*----SETFAL25 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL25_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG01_SETFAL24_MASK (0x01000000u)
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL24_SHIFT (0x00000018u)
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL24_RESETVAL (0x00000000u)
/*----SETFAL24 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL24_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG01_SETFAL23_MASK (0x00800000u)
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL23_SHIFT (0x00000017u)
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL23_RESETVAL (0x00000000u)
/*----SETFAL23 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL23_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG01_SETFAL22_MASK (0x00400000u)
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL22_SHIFT (0x00000016u)
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL22_RESETVAL (0x00000000u)
/*----SETFAL22 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL22_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG01_SETFAL21_MASK (0x00200000u)
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL21_SHIFT (0x00000015u)
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL21_RESETVAL (0x00000000u)
/*----SETFAL21 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL21_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG01_SETFAL20_MASK (0x00100000u)
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL20_SHIFT (0x00000014u)
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL20_RESETVAL (0x00000000u)
/*----SETFAL20 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL20_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG01_SETFAL19_MASK (0x00080000u)
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL19_SHIFT (0x00000013u)
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL19_RESETVAL (0x00000000u)
/*----SETFAL19 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL19_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG01_SETFAL18_MASK (0x00040000u)
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL18_SHIFT (0x00000012u)
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL18_RESETVAL (0x00000000u)
/*----SETFAL18 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL18_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG01_SETFAL17_MASK (0x00020000u)
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL17_SHIFT (0x00000011u)
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL17_RESETVAL (0x00000000u)
/*----SETFAL17 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL17_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG01_SETFAL16_MASK (0x00010000u)
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL16_SHIFT (0x00000010u)
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL16_RESETVAL (0x00000000u)
/*----SETFAL16 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL16_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG01_SETFAL15_MASK (0x00008000u)
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL15_SHIFT (0x0000000Fu)
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL15_RESETVAL (0x00000000u)
/*----SETFAL15 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL15_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG01_SETFAL14_MASK (0x00004000u)
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL14_SHIFT (0x0000000Eu)
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL14_RESETVAL (0x00000000u)
/*----SETFAL14 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL14_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG01_SETFAL13_MASK (0x00002000u)
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL13_SHIFT (0x0000000Du)
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL13_RESETVAL (0x00000000u)
/*----SETFAL13 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL13_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG01_SETFAL12_MASK (0x00001000u)
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL12_SHIFT (0x0000000Cu)
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL12_RESETVAL (0x00000000u)
/*----SETFAL12 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL12_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG01_SETFAL11_MASK (0x00000800u)
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL11_SHIFT (0x0000000Bu)
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL11_RESETVAL (0x00000000u)
/*----SETFAL11 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL11_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG01_SETFAL10_MASK (0x00000400u)
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL10_SHIFT (0x0000000Au)
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL10_RESETVAL (0x00000000u)
/*----SETFAL10 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL10_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG01_SETFAL9_MASK (0x00000200u)
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL9_SHIFT (0x00000009u)
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL9_RESETVAL (0x00000000u)
/*----SETFAL9 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL9_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG01_SETFAL8_MASK (0x00000100u)
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL8_SHIFT (0x00000008u)
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL8_RESETVAL (0x00000000u)
/*----SETFAL8 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL8_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG01_SETFAL7_MASK (0x00000080u)
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL7_SHIFT (0x00000007u)
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL7_RESETVAL (0x00000000u)
/*----SETFAL7 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL7_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG01_SETFAL6_MASK (0x00000040u)
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL6_SHIFT (0x00000006u)
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL6_RESETVAL (0x00000000u)
/*----SETFAL6 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL6_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG01_SETFAL5_MASK (0x00000020u)
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL5_SHIFT (0x00000005u)
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL5_RESETVAL (0x00000000u)
/*----SETFAL5 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL5_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG01_SETFAL4_MASK (0x00000010u)
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL4_SHIFT (0x00000004u)
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL4_RESETVAL (0x00000000u)
/*----SETFAL4 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL4_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG01_SETFAL3_MASK (0x00000008u)
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL3_SHIFT (0x00000003u)
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL3_RESETVAL (0x00000000u)
/*----SETFAL3 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL3_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG01_SETFAL2_MASK (0x00000004u)
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL2_SHIFT (0x00000002u)
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL2_RESETVAL (0x00000000u)
/*----SETFAL2 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL2_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG01_SETFAL1_MASK (0x00000002u)
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL1_SHIFT (0x00000001u)
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL1_RESETVAL (0x00000000u)
/*----SETFAL1 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL1_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG01_SETFAL0_MASK (0x00000001u)
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL0_SHIFT (0x00000000u)
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL0_RESETVAL (0x00000000u)
/*----SETFAL0 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG01_SETFAL0_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG01_RESETVAL (0x00000000u)

/* CLR_FAL_TRIG01 */

#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL31_MASK (0x80000000u)
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL31_SHIFT (0x0000001Fu)
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL31_RESETVAL (0x00000000u)
/*----CLRFAL31 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL31_DISABLE (0x00000001u)

#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL30_MASK (0x40000000u)
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL30_SHIFT (0x0000001Eu)
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL30_RESETVAL (0x00000000u)
/*----CLRFAL30 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL30_DISABLE (0x00000001u)

#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL29_MASK (0x20000000u)
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL29_SHIFT (0x0000001Du)
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL29_RESETVAL (0x00000000u)
/*----CLRFAL29 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL29_DISABLE (0x00000001u)

#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL28_MASK (0x10000000u)
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL28_SHIFT (0x0000001Cu)
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL28_RESETVAL (0x00000000u)
/*----CLRFAL28 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL28_DISABLE (0x00000001u)

#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL27_MASK (0x08000000u)
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL27_SHIFT (0x0000001Bu)
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL27_RESETVAL (0x00000000u)
/*----CLRFAL27 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL27_DISABLE (0x00000001u)

#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL26_MASK (0x04000000u)
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL26_SHIFT (0x0000001Au)
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL26_RESETVAL (0x00000000u)
/*----CLRFAL26 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL26_DISABLE (0x00000001u)

#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL25_MASK (0x02000000u)
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL25_SHIFT (0x00000019u)
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL25_RESETVAL (0x00000000u)
/*----CLRFAL25 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL25_DISABLE (0x00000001u)

#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL24_MASK (0x01000000u)
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL24_SHIFT (0x00000018u)
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL24_RESETVAL (0x00000000u)
/*----CLRFAL24 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL24_DISABLE (0x00000001u)

#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL23_MASK (0x00800000u)
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL23_SHIFT (0x00000017u)
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL23_RESETVAL (0x00000000u)
/*----CLRFAL23 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL23_DISABLE (0x00000001u)

#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL22_MASK (0x00400000u)
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL22_SHIFT (0x00000016u)
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL22_RESETVAL (0x00000000u)
/*----CLRFAL22 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL22_DISABLE (0x00000001u)

#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL21_MASK (0x00200000u)
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL21_SHIFT (0x00000015u)
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL21_RESETVAL (0x00000000u)
/*----CLRFAL21 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL21_DISABLE (0x00000001u)

#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL20_MASK (0x00100000u)
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL20_SHIFT (0x00000014u)
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL20_RESETVAL (0x00000000u)
/*----CLRFAL20 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL20_DISABLE (0x00000001u)

#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL19_MASK (0x00080000u)
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL19_SHIFT (0x00000013u)
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL19_RESETVAL (0x00000000u)
/*----CLRFAL19 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL19_DISABLE (0x00000001u)

#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL18_MASK (0x00040000u)
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL18_SHIFT (0x00000012u)
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL18_RESETVAL (0x00000000u)
/*----CLRFAL18 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL18_DISABLE (0x00000001u)

#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL17_MASK (0x00020000u)
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL17_SHIFT (0x00000011u)
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL17_RESETVAL (0x00000000u)
/*----CLRFAL17 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL17_DISABLE (0x00000001u)

#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL16_MASK (0x00010000u)
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL16_SHIFT (0x00000010u)
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL16_RESETVAL (0x00000000u)
/*----CLRFAL16 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL16_DISABLE (0x00000001u)

#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL15_MASK (0x00008000u)
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL15_SHIFT (0x0000000Fu)
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL15_RESETVAL (0x00000000u)
/*----CLRFAL15 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL15_DISABLE (0x00000001u)

#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL14_MASK (0x00004000u)
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL14_SHIFT (0x0000000Eu)
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL14_RESETVAL (0x00000000u)
/*----CLRFAL14 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL14_DISABLE (0x00000001u)

#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL13_MASK (0x00002000u)
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL13_SHIFT (0x0000000Du)
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL13_RESETVAL (0x00000000u)
/*----CLRFAL13 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL13_DISABLE (0x00000001u)

#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL12_MASK (0x00001000u)
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL12_SHIFT (0x0000000Cu)
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL12_RESETVAL (0x00000000u)
/*----CLRFAL12 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL12_DISABLE (0x00000001u)

#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL11_MASK (0x00000800u)
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL11_SHIFT (0x0000000Bu)
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL11_RESETVAL (0x00000000u)
/*----CLRFAL11 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL11_DISABLE (0x00000001u)

#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL10_MASK (0x00000400u)
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL10_SHIFT (0x0000000Au)
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL10_RESETVAL (0x00000000u)
/*----CLRFAL10 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL10_DISABLE (0x00000001u)

#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL9_MASK (0x00000200u)
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL9_SHIFT (0x00000009u)
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL9_RESETVAL (0x00000000u)
/*----CLRFAL9 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL9_DISABLE (0x00000001u)

#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL8_MASK (0x00000100u)
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL8_SHIFT (0x00000008u)
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL8_RESETVAL (0x00000000u)
/*----CLRFAL8 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL8_DISABLE (0x00000001u)

#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL7_MASK (0x00000080u)
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL7_SHIFT (0x00000007u)
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL7_RESETVAL (0x00000000u)
/*----CLRFAL7 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL7_DISABLE (0x00000001u)

#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL6_MASK (0x00000040u)
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL6_SHIFT (0x00000006u)
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL6_RESETVAL (0x00000000u)
/*----CLRFAL6 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL6_DISABLE (0x00000001u)

#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL5_MASK (0x00000020u)
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL5_SHIFT (0x00000005u)
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL5_RESETVAL (0x00000000u)
/*----CLRFAL5 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL5_DISABLE (0x00000001u)

#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL4_MASK (0x00000010u)
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL4_SHIFT (0x00000004u)
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL4_RESETVAL (0x00000000u)
/*----CLRFAL4 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL4_DISABLE (0x00000001u)

#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL3_MASK (0x00000008u)
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL3_SHIFT (0x00000003u)
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL3_RESETVAL (0x00000000u)
/*----CLRFAL3 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL3_DISABLE (0x00000001u)

#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL2_MASK (0x00000004u)
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL2_SHIFT (0x00000002u)
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL2_RESETVAL (0x00000000u)
/*----CLRFAL2 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL2_DISABLE (0x00000001u)

#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL1_MASK (0x00000002u)
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL1_SHIFT (0x00000001u)
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL1_RESETVAL (0x00000000u)
/*----CLRFAL1 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL1_DISABLE (0x00000001u)

#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL0_MASK (0x00000001u)
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL0_SHIFT (0x00000000u)
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL0_RESETVAL (0x00000000u)
/*----CLRFAL0 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG01_CLRFAL0_DISABLE (0x00000001u)

#define CSL_GPIO_CLR_FAL_TRIG01_RESETVAL (0x00000000u)

/* INTSTAT01 */

#define CSL_GPIO_INTSTAT01_STAT31_MASK (0x80000000u)
#define CSL_GPIO_INTSTAT01_STAT31_SHIFT (0x0000001Fu)
#define CSL_GPIO_INTSTAT01_STAT31_RESETVAL (0x00000000u)
/*----STAT31 Tokens----*/
#define CSL_GPIO_INTSTAT01_STAT31_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT01_STAT31_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT01_STAT30_MASK (0x40000000u)
#define CSL_GPIO_INTSTAT01_STAT30_SHIFT (0x0000001Eu)
#define CSL_GPIO_INTSTAT01_STAT30_RESETVAL (0x00000000u)
/*----STAT30 Tokens----*/
#define CSL_GPIO_INTSTAT01_STAT30_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT01_STAT30_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT01_STAT29_MASK (0x20000000u)
#define CSL_GPIO_INTSTAT01_STAT29_SHIFT (0x0000001Du)
#define CSL_GPIO_INTSTAT01_STAT29_RESETVAL (0x00000000u)
/*----STAT29 Tokens----*/
#define CSL_GPIO_INTSTAT01_STAT29_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT01_STAT29_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT01_STAT28_MASK (0x10000000u)
#define CSL_GPIO_INTSTAT01_STAT28_SHIFT (0x0000001Cu)
#define CSL_GPIO_INTSTAT01_STAT28_RESETVAL (0x00000000u)
/*----STAT28 Tokens----*/
#define CSL_GPIO_INTSTAT01_STAT28_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT01_STAT28_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT01_STAT27_MASK (0x08000000u)
#define CSL_GPIO_INTSTAT01_STAT27_SHIFT (0x0000001Bu)
#define CSL_GPIO_INTSTAT01_STAT27_RESETVAL (0x00000000u)
/*----STAT27 Tokens----*/
#define CSL_GPIO_INTSTAT01_STAT27_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT01_STAT27_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT01_STAT26_MASK (0x04000000u)
#define CSL_GPIO_INTSTAT01_STAT26_SHIFT (0x0000001Au)
#define CSL_GPIO_INTSTAT01_STAT26_RESETVAL (0x00000000u)
/*----STAT26 Tokens----*/
#define CSL_GPIO_INTSTAT01_STAT26_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT01_STAT26_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT01_STAT25_MASK (0x02000000u)
#define CSL_GPIO_INTSTAT01_STAT25_SHIFT (0x00000019u)
#define CSL_GPIO_INTSTAT01_STAT25_RESETVAL (0x00000000u)
/*----STAT25 Tokens----*/
#define CSL_GPIO_INTSTAT01_STAT25_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT01_STAT25_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT01_STAT24_MASK (0x01000000u)
#define CSL_GPIO_INTSTAT01_STAT24_SHIFT (0x00000018u)
#define CSL_GPIO_INTSTAT01_STAT24_RESETVAL (0x00000000u)
/*----STAT24 Tokens----*/
#define CSL_GPIO_INTSTAT01_STAT24_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT01_STAT24_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT01_STAT23_MASK (0x00800000u)
#define CSL_GPIO_INTSTAT01_STAT23_SHIFT (0x00000017u)
#define CSL_GPIO_INTSTAT01_STAT23_RESETVAL (0x00000000u)
/*----STAT23 Tokens----*/
#define CSL_GPIO_INTSTAT01_STAT23_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT01_STAT23_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT01_STAT22_MASK (0x00400000u)
#define CSL_GPIO_INTSTAT01_STAT22_SHIFT (0x00000016u)
#define CSL_GPIO_INTSTAT01_STAT22_RESETVAL (0x00000000u)
/*----STAT22 Tokens----*/
#define CSL_GPIO_INTSTAT01_STAT22_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT01_STAT22_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT01_STAT21_MASK (0x00200000u)
#define CSL_GPIO_INTSTAT01_STAT21_SHIFT (0x00000015u)
#define CSL_GPIO_INTSTAT01_STAT21_RESETVAL (0x00000000u)
/*----STAT21 Tokens----*/
#define CSL_GPIO_INTSTAT01_STAT21_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT01_STAT21_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT01_STAT20_MASK (0x00100000u)
#define CSL_GPIO_INTSTAT01_STAT20_SHIFT (0x00000014u)
#define CSL_GPIO_INTSTAT01_STAT20_RESETVAL (0x00000000u)
/*----STAT20 Tokens----*/
#define CSL_GPIO_INTSTAT01_STAT20_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT01_STAT20_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT01_STAT19_MASK (0x00080000u)
#define CSL_GPIO_INTSTAT01_STAT19_SHIFT (0x00000013u)
#define CSL_GPIO_INTSTAT01_STAT19_RESETVAL (0x00000000u)
/*----STAT19 Tokens----*/
#define CSL_GPIO_INTSTAT01_STAT19_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT01_STAT19_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT01_STAT18_MASK (0x00040000u)
#define CSL_GPIO_INTSTAT01_STAT18_SHIFT (0x00000012u)
#define CSL_GPIO_INTSTAT01_STAT18_RESETVAL (0x00000000u)
/*----STAT18 Tokens----*/
#define CSL_GPIO_INTSTAT01_STAT18_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT01_STAT18_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT01_STAT17_MASK (0x00020000u)
#define CSL_GPIO_INTSTAT01_STAT17_SHIFT (0x00000011u)
#define CSL_GPIO_INTSTAT01_STAT17_RESETVAL (0x00000000u)
/*----STAT17 Tokens----*/
#define CSL_GPIO_INTSTAT01_STAT17_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT01_STAT17_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT01_STAT16_MASK (0x00010000u)
#define CSL_GPIO_INTSTAT01_STAT16_SHIFT (0x00000010u)
#define CSL_GPIO_INTSTAT01_STAT16_RESETVAL (0x00000000u)
/*----STAT16 Tokens----*/
#define CSL_GPIO_INTSTAT01_STAT16_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT01_STAT16_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT01_STAT15_MASK (0x00008000u)
#define CSL_GPIO_INTSTAT01_STAT15_SHIFT (0x0000000Fu)
#define CSL_GPIO_INTSTAT01_STAT15_RESETVAL (0x00000000u)
/*----STAT15 Tokens----*/
#define CSL_GPIO_INTSTAT01_STAT15_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT01_STAT15_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT01_STAT14_MASK (0x00004000u)
#define CSL_GPIO_INTSTAT01_STAT14_SHIFT (0x0000000Eu)
#define CSL_GPIO_INTSTAT01_STAT14_RESETVAL (0x00000000u)
/*----STAT14 Tokens----*/
#define CSL_GPIO_INTSTAT01_STAT14_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT01_STAT14_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT01_STAT13_MASK (0x00002000u)
#define CSL_GPIO_INTSTAT01_STAT13_SHIFT (0x0000000Du)
#define CSL_GPIO_INTSTAT01_STAT13_RESETVAL (0x00000000u)
/*----STAT13 Tokens----*/
#define CSL_GPIO_INTSTAT01_STAT13_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT01_STAT13_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT01_STAT12_MASK (0x00001000u)
#define CSL_GPIO_INTSTAT01_STAT12_SHIFT (0x0000000Cu)
#define CSL_GPIO_INTSTAT01_STAT12_RESETVAL (0x00000000u)
/*----STAT12 Tokens----*/
#define CSL_GPIO_INTSTAT01_STAT12_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT01_STAT12_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT01_STAT11_MASK (0x00000800u)
#define CSL_GPIO_INTSTAT01_STAT11_SHIFT (0x0000000Bu)
#define CSL_GPIO_INTSTAT01_STAT11_RESETVAL (0x00000000u)
/*----STAT11 Tokens----*/
#define CSL_GPIO_INTSTAT01_STAT11_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT01_STAT11_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT01_STAT10_MASK (0x00000400u)
#define CSL_GPIO_INTSTAT01_STAT10_SHIFT (0x0000000Au)
#define CSL_GPIO_INTSTAT01_STAT10_RESETVAL (0x00000000u)
/*----STAT10 Tokens----*/
#define CSL_GPIO_INTSTAT01_STAT10_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT01_STAT10_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT01_STAT9_MASK (0x00000200u)
#define CSL_GPIO_INTSTAT01_STAT9_SHIFT (0x00000009u)
#define CSL_GPIO_INTSTAT01_STAT9_RESETVAL (0x00000000u)
/*----STAT9 Tokens----*/
#define CSL_GPIO_INTSTAT01_STAT9_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT01_STAT9_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT01_STAT8_MASK (0x00000100u)
#define CSL_GPIO_INTSTAT01_STAT8_SHIFT (0x00000008u)
#define CSL_GPIO_INTSTAT01_STAT8_RESETVAL (0x00000000u)
/*----STAT8 Tokens----*/
#define CSL_GPIO_INTSTAT01_STAT8_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT01_STAT8_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT01_STAT7_MASK (0x00000080u)
#define CSL_GPIO_INTSTAT01_STAT7_SHIFT (0x00000007u)
#define CSL_GPIO_INTSTAT01_STAT7_RESETVAL (0x00000000u)
/*----STAT7 Tokens----*/
#define CSL_GPIO_INTSTAT01_STAT7_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT01_STAT7_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT01_STAT6_MASK (0x00000040u)
#define CSL_GPIO_INTSTAT01_STAT6_SHIFT (0x00000006u)
#define CSL_GPIO_INTSTAT01_STAT6_RESETVAL (0x00000000u)
/*----STAT6 Tokens----*/
#define CSL_GPIO_INTSTAT01_STAT6_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT01_STAT6_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT01_STAT5_MASK (0x00000020u)
#define CSL_GPIO_INTSTAT01_STAT5_SHIFT (0x00000005u)
#define CSL_GPIO_INTSTAT01_STAT5_RESETVAL (0x00000000u)
/*----STAT5 Tokens----*/
#define CSL_GPIO_INTSTAT01_STAT5_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT01_STAT5_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT01_STAT4_MASK (0x00000010u)
#define CSL_GPIO_INTSTAT01_STAT4_SHIFT (0x00000004u)
#define CSL_GPIO_INTSTAT01_STAT4_RESETVAL (0x00000000u)
/*----STAT4 Tokens----*/
#define CSL_GPIO_INTSTAT01_STAT4_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT01_STAT4_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT01_STAT3_MASK (0x00000008u)
#define CSL_GPIO_INTSTAT01_STAT3_SHIFT (0x00000003u)
#define CSL_GPIO_INTSTAT01_STAT3_RESETVAL (0x00000000u)
/*----STAT3 Tokens----*/
#define CSL_GPIO_INTSTAT01_STAT3_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT01_STAT3_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT01_STAT2_MASK (0x00000004u)
#define CSL_GPIO_INTSTAT01_STAT2_SHIFT (0x00000002u)
#define CSL_GPIO_INTSTAT01_STAT2_RESETVAL (0x00000000u)
/*----STAT2 Tokens----*/
#define CSL_GPIO_INTSTAT01_STAT2_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT01_STAT2_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT01_STAT1_MASK (0x00000002u)
#define CSL_GPIO_INTSTAT01_STAT1_SHIFT (0x00000001u)
#define CSL_GPIO_INTSTAT01_STAT1_RESETVAL (0x00000000u)
/*----STAT1 Tokens----*/
#define CSL_GPIO_INTSTAT01_STAT1_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT01_STAT1_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT01_STAT0_MASK (0x00000001u)
#define CSL_GPIO_INTSTAT01_STAT0_SHIFT (0x00000000u)
#define CSL_GPIO_INTSTAT01_STAT0_RESETVAL (0x00000000u)
/*----STAT0 Tokens----*/
#define CSL_GPIO_INTSTAT01_STAT0_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT01_STAT0_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT01_RESETVAL (0x00000000u)

/* DIR23 */

#define CSL_GPIO_DIR23_DIR31_MASK (0x80000000u)
#define CSL_GPIO_DIR23_DIR31_SHIFT (0x0000001Fu)
#define CSL_GPIO_DIR23_DIR31_RESETVAL (0x00000001u)
/*----DIR31 Tokens----*/
#define CSL_GPIO_DIR23_DIR31_OUT (0x00000000u)
#define CSL_GPIO_DIR23_DIR31_IN (0x00000001u)

#define CSL_GPIO_DIR23_DIR30_MASK (0x40000000u)
#define CSL_GPIO_DIR23_DIR30_SHIFT (0x0000001Eu)
#define CSL_GPIO_DIR23_DIR30_RESETVAL (0x00000001u)
/*----DIR30 Tokens----*/
#define CSL_GPIO_DIR23_DIR30_OUT (0x00000000u)
#define CSL_GPIO_DIR23_DIR30_IN (0x00000001u)

#define CSL_GPIO_DIR23_DIR29_MASK (0x20000000u)
#define CSL_GPIO_DIR23_DIR29_SHIFT (0x0000001Du)
#define CSL_GPIO_DIR23_DIR29_RESETVAL (0x00000001u)
/*----DIR29 Tokens----*/
#define CSL_GPIO_DIR23_DIR29_OUT (0x00000000u)
#define CSL_GPIO_DIR23_DIR29_IN (0x00000001u)

#define CSL_GPIO_DIR23_DIR28_MASK (0x10000000u)
#define CSL_GPIO_DIR23_DIR28_SHIFT (0x0000001Cu)
#define CSL_GPIO_DIR23_DIR28_RESETVAL (0x00000001u)
/*----DIR28 Tokens----*/
#define CSL_GPIO_DIR23_DIR28_OUT (0x00000000u)
#define CSL_GPIO_DIR23_DIR28_IN (0x00000001u)

#define CSL_GPIO_DIR23_DIR27_MASK (0x08000000u)
#define CSL_GPIO_DIR23_DIR27_SHIFT (0x0000001Bu)
#define CSL_GPIO_DIR23_DIR27_RESETVAL (0x00000001u)
/*----DIR27 Tokens----*/
#define CSL_GPIO_DIR23_DIR27_OUT (0x00000000u)
#define CSL_GPIO_DIR23_DIR27_IN (0x00000001u)

#define CSL_GPIO_DIR23_DIR26_MASK (0x04000000u)
#define CSL_GPIO_DIR23_DIR26_SHIFT (0x0000001Au)
#define CSL_GPIO_DIR23_DIR26_RESETVAL (0x00000001u)
/*----DIR26 Tokens----*/
#define CSL_GPIO_DIR23_DIR26_OUT (0x00000000u)
#define CSL_GPIO_DIR23_DIR26_IN (0x00000001u)

#define CSL_GPIO_DIR23_DIR25_MASK (0x02000000u)
#define CSL_GPIO_DIR23_DIR25_SHIFT (0x00000019u)
#define CSL_GPIO_DIR23_DIR25_RESETVAL (0x00000001u)
/*----DIR25 Tokens----*/
#define CSL_GPIO_DIR23_DIR25_OUT (0x00000000u)
#define CSL_GPIO_DIR23_DIR25_IN (0x00000001u)

#define CSL_GPIO_DIR23_DIR24_MASK (0x01000000u)
#define CSL_GPIO_DIR23_DIR24_SHIFT (0x00000018u)
#define CSL_GPIO_DIR23_DIR24_RESETVAL (0x00000001u)
/*----DIR24 Tokens----*/
#define CSL_GPIO_DIR23_DIR24_OUT (0x00000000u)
#define CSL_GPIO_DIR23_DIR24_IN (0x00000001u)

#define CSL_GPIO_DIR23_DIR23_MASK (0x00800000u)
#define CSL_GPIO_DIR23_DIR23_SHIFT (0x00000017u)
#define CSL_GPIO_DIR23_DIR23_RESETVAL (0x00000001u)
/*----DIR23 Tokens----*/
#define CSL_GPIO_DIR23_DIR23_OUT (0x00000000u)
#define CSL_GPIO_DIR23_DIR23_IN (0x00000001u)

#define CSL_GPIO_DIR23_DIR22_MASK (0x00400000u)
#define CSL_GPIO_DIR23_DIR22_SHIFT (0x00000016u)
#define CSL_GPIO_DIR23_DIR22_RESETVAL (0x00000001u)
/*----DIR22 Tokens----*/
#define CSL_GPIO_DIR23_DIR22_OUT (0x00000000u)
#define CSL_GPIO_DIR23_DIR22_IN (0x00000001u)

#define CSL_GPIO_DIR23_DIR21_MASK (0x00200000u)
#define CSL_GPIO_DIR23_DIR21_SHIFT (0x00000015u)
#define CSL_GPIO_DIR23_DIR21_RESETVAL (0x00000001u)
/*----DIR21 Tokens----*/
#define CSL_GPIO_DIR23_DIR21_OUT (0x00000000u)
#define CSL_GPIO_DIR23_DIR21_IN (0x00000001u)

#define CSL_GPIO_DIR23_DIR20_MASK (0x00100000u)
#define CSL_GPIO_DIR23_DIR20_SHIFT (0x00000014u)
#define CSL_GPIO_DIR23_DIR20_RESETVAL (0x00000001u)
/*----DIR20 Tokens----*/
#define CSL_GPIO_DIR23_DIR20_OUT (0x00000000u)
#define CSL_GPIO_DIR23_DIR20_IN (0x00000001u)

#define CSL_GPIO_DIR23_DIR19_MASK (0x00080000u)
#define CSL_GPIO_DIR23_DIR19_SHIFT (0x00000013u)
#define CSL_GPIO_DIR23_DIR19_RESETVAL (0x00000001u)
/*----DIR19 Tokens----*/
#define CSL_GPIO_DIR23_DIR19_OUT (0x00000000u)
#define CSL_GPIO_DIR23_DIR19_IN (0x00000001u)

#define CSL_GPIO_DIR23_DIR18_MASK (0x00040000u)
#define CSL_GPIO_DIR23_DIR18_SHIFT (0x00000012u)
#define CSL_GPIO_DIR23_DIR18_RESETVAL (0x00000001u)
/*----DIR18 Tokens----*/
#define CSL_GPIO_DIR23_DIR18_OUT (0x00000000u)
#define CSL_GPIO_DIR23_DIR18_IN (0x00000001u)

#define CSL_GPIO_DIR23_DIR17_MASK (0x00020000u)
#define CSL_GPIO_DIR23_DIR17_SHIFT (0x00000011u)
#define CSL_GPIO_DIR23_DIR17_RESETVAL (0x00000001u)
/*----DIR17 Tokens----*/
#define CSL_GPIO_DIR23_DIR17_OUT (0x00000000u)
#define CSL_GPIO_DIR23_DIR17_IN (0x00000001u)

#define CSL_GPIO_DIR23_DIR16_MASK (0x00010000u)
#define CSL_GPIO_DIR23_DIR16_SHIFT (0x00000010u)
#define CSL_GPIO_DIR23_DIR16_RESETVAL (0x00000001u)
/*----DIR16 Tokens----*/
#define CSL_GPIO_DIR23_DIR16_OUT (0x00000000u)
#define CSL_GPIO_DIR23_DIR16_IN (0x00000001u)

#define CSL_GPIO_DIR23_DIR15_MASK (0x00008000u)
#define CSL_GPIO_DIR23_DIR15_SHIFT (0x0000000Fu)
#define CSL_GPIO_DIR23_DIR15_RESETVAL (0x00000001u)
/*----DIR15 Tokens----*/
#define CSL_GPIO_DIR23_DIR15_OUT (0x00000000u)
#define CSL_GPIO_DIR23_DIR15_IN (0x00000001u)

#define CSL_GPIO_DIR23_DIR14_MASK (0x00004000u)
#define CSL_GPIO_DIR23_DIR14_SHIFT (0x0000000Eu)
#define CSL_GPIO_DIR23_DIR14_RESETVAL (0x00000001u)
/*----DIR14 Tokens----*/
#define CSL_GPIO_DIR23_DIR14_OUT (0x00000000u)
#define CSL_GPIO_DIR23_DIR14_IN (0x00000001u)

#define CSL_GPIO_DIR23_DIR13_MASK (0x00002000u)
#define CSL_GPIO_DIR23_DIR13_SHIFT (0x0000000Du)
#define CSL_GPIO_DIR23_DIR13_RESETVAL (0x00000001u)
/*----DIR13 Tokens----*/
#define CSL_GPIO_DIR23_DIR13_OUT (0x00000000u)
#define CSL_GPIO_DIR23_DIR13_IN (0x00000001u)

#define CSL_GPIO_DIR23_DIR12_MASK (0x00001000u)
#define CSL_GPIO_DIR23_DIR12_SHIFT (0x0000000Cu)
#define CSL_GPIO_DIR23_DIR12_RESETVAL (0x00000001u)
/*----DIR12 Tokens----*/
#define CSL_GPIO_DIR23_DIR12_OUT (0x00000000u)
#define CSL_GPIO_DIR23_DIR12_IN (0x00000001u)

#define CSL_GPIO_DIR23_DIR11_MASK (0x00000800u)
#define CSL_GPIO_DIR23_DIR11_SHIFT (0x0000000Bu)
#define CSL_GPIO_DIR23_DIR11_RESETVAL (0x00000001u)
/*----DIR11 Tokens----*/
#define CSL_GPIO_DIR23_DIR11_OUT (0x00000000u)
#define CSL_GPIO_DIR23_DIR11_IN (0x00000001u)

#define CSL_GPIO_DIR23_DIR10_MASK (0x00000400u)
#define CSL_GPIO_DIR23_DIR10_SHIFT (0x0000000Au)
#define CSL_GPIO_DIR23_DIR10_RESETVAL (0x00000001u)
/*----DIR10 Tokens----*/
#define CSL_GPIO_DIR23_DIR10_OUT (0x00000000u)
#define CSL_GPIO_DIR23_DIR10_IN (0x00000001u)

#define CSL_GPIO_DIR23_DIR9_MASK (0x00000200u)
#define CSL_GPIO_DIR23_DIR9_SHIFT (0x00000009u)
#define CSL_GPIO_DIR23_DIR9_RESETVAL (0x00000001u)
/*----DIR9 Tokens----*/
#define CSL_GPIO_DIR23_DIR9_OUT (0x00000000u)
#define CSL_GPIO_DIR23_DIR9_IN (0x00000001u)

#define CSL_GPIO_DIR23_DIR8_MASK (0x00000100u)
#define CSL_GPIO_DIR23_DIR8_SHIFT (0x00000008u)
#define CSL_GPIO_DIR23_DIR8_RESETVAL (0x00000001u)
/*----DIR8 Tokens----*/
#define CSL_GPIO_DIR23_DIR8_OUT (0x00000000u)
#define CSL_GPIO_DIR23_DIR8_IN (0x00000001u)

#define CSL_GPIO_DIR23_DIR7_MASK (0x00000080u)
#define CSL_GPIO_DIR23_DIR7_SHIFT (0x00000007u)
#define CSL_GPIO_DIR23_DIR7_RESETVAL (0x00000001u)
/*----DIR7 Tokens----*/
#define CSL_GPIO_DIR23_DIR7_OUT (0x00000000u)
#define CSL_GPIO_DIR23_DIR7_IN (0x00000001u)

#define CSL_GPIO_DIR23_DIR6_MASK (0x00000040u)
#define CSL_GPIO_DIR23_DIR6_SHIFT (0x00000006u)
#define CSL_GPIO_DIR23_DIR6_RESETVAL (0x00000001u)
/*----DIR6 Tokens----*/
#define CSL_GPIO_DIR23_DIR6_OUT (0x00000000u)
#define CSL_GPIO_DIR23_DIR6_IN (0x00000001u)

#define CSL_GPIO_DIR23_DIR5_MASK (0x00000020u)
#define CSL_GPIO_DIR23_DIR5_SHIFT (0x00000005u)
#define CSL_GPIO_DIR23_DIR5_RESETVAL (0x00000001u)
/*----DIR5 Tokens----*/
#define CSL_GPIO_DIR23_DIR5_OUT (0x00000000u)
#define CSL_GPIO_DIR23_DIR5_IN (0x00000001u)

#define CSL_GPIO_DIR23_DIR4_MASK (0x00000010u)
#define CSL_GPIO_DIR23_DIR4_SHIFT (0x00000004u)
#define CSL_GPIO_DIR23_DIR4_RESETVAL (0x00000001u)
/*----DIR4 Tokens----*/
#define CSL_GPIO_DIR23_DIR4_OUT (0x00000000u)
#define CSL_GPIO_DIR23_DIR4_IN (0x00000001u)

#define CSL_GPIO_DIR23_DIR3_MASK (0x00000008u)
#define CSL_GPIO_DIR23_DIR3_SHIFT (0x00000003u)
#define CSL_GPIO_DIR23_DIR3_RESETVAL (0x00000001u)
/*----DIR3 Tokens----*/
#define CSL_GPIO_DIR23_DIR3_OUT (0x00000000u)
#define CSL_GPIO_DIR23_DIR3_IN (0x00000001u)

#define CSL_GPIO_DIR23_DIR2_MASK (0x00000004u)
#define CSL_GPIO_DIR23_DIR2_SHIFT (0x00000002u)
#define CSL_GPIO_DIR23_DIR2_RESETVAL (0x00000001u)
/*----DIR2 Tokens----*/
#define CSL_GPIO_DIR23_DIR2_OUT (0x00000000u)
#define CSL_GPIO_DIR23_DIR2_IN (0x00000001u)

#define CSL_GPIO_DIR23_DIR1_MASK (0x00000002u)
#define CSL_GPIO_DIR23_DIR1_SHIFT (0x00000001u)
#define CSL_GPIO_DIR23_DIR1_RESETVAL (0x00000001u)
/*----DIR1 Tokens----*/
#define CSL_GPIO_DIR23_DIR1_OUT (0x00000000u)
#define CSL_GPIO_DIR23_DIR1_IN (0x00000001u)

#define CSL_GPIO_DIR23_DIR0_MASK (0x00000001u)
#define CSL_GPIO_DIR23_DIR0_SHIFT (0x00000000u)
#define CSL_GPIO_DIR23_DIR0_RESETVAL (0x00000001u)
/*----DIR0 Tokens----*/
#define CSL_GPIO_DIR23_DIR0_OUT (0x00000000u)
#define CSL_GPIO_DIR23_DIR0_IN (0x00000001u)

#define CSL_GPIO_DIR23_RESETVAL (0xFFFFFFFFu)

/* OUT_DATA23 */

#define CSL_GPIO_OUT_DATA23_OUT31_MASK (0x80000000u)
#define CSL_GPIO_OUT_DATA23_OUT31_SHIFT (0x0000001Fu)
#define CSL_GPIO_OUT_DATA23_OUT31_RESETVAL (0x00000000u)
/*----OUT31 Tokens----*/
#define CSL_GPIO_OUT_DATA23_OUT31_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA23_OUT31_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA23_OUT30_MASK (0x40000000u)
#define CSL_GPIO_OUT_DATA23_OUT30_SHIFT (0x0000001Eu)
#define CSL_GPIO_OUT_DATA23_OUT30_RESETVAL (0x00000000u)
/*----OUT30 Tokens----*/
#define CSL_GPIO_OUT_DATA23_OUT30_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA23_OUT30_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA23_OUT29_MASK (0x20000000u)
#define CSL_GPIO_OUT_DATA23_OUT29_SHIFT (0x0000001Du)
#define CSL_GPIO_OUT_DATA23_OUT29_RESETVAL (0x00000000u)
/*----OUT29 Tokens----*/
#define CSL_GPIO_OUT_DATA23_OUT29_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA23_OUT29_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA23_OUT28_MASK (0x10000000u)
#define CSL_GPIO_OUT_DATA23_OUT28_SHIFT (0x0000001Cu)
#define CSL_GPIO_OUT_DATA23_OUT28_RESETVAL (0x00000000u)
/*----OUT28 Tokens----*/
#define CSL_GPIO_OUT_DATA23_OUT28_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA23_OUT28_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA23_OUT27_MASK (0x08000000u)
#define CSL_GPIO_OUT_DATA23_OUT27_SHIFT (0x0000001Bu)
#define CSL_GPIO_OUT_DATA23_OUT27_RESETVAL (0x00000000u)
/*----OUT27 Tokens----*/
#define CSL_GPIO_OUT_DATA23_OUT27_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA23_OUT27_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA23_OUT26_MASK (0x04000000u)
#define CSL_GPIO_OUT_DATA23_OUT26_SHIFT (0x0000001Au)
#define CSL_GPIO_OUT_DATA23_OUT26_RESETVAL (0x00000000u)
/*----OUT26 Tokens----*/
#define CSL_GPIO_OUT_DATA23_OUT26_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA23_OUT26_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA23_OUT25_MASK (0x02000000u)
#define CSL_GPIO_OUT_DATA23_OUT25_SHIFT (0x00000019u)
#define CSL_GPIO_OUT_DATA23_OUT25_RESETVAL (0x00000000u)
/*----OUT25 Tokens----*/
#define CSL_GPIO_OUT_DATA23_OUT25_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA23_OUT25_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA23_OUT24_MASK (0x01000000u)
#define CSL_GPIO_OUT_DATA23_OUT24_SHIFT (0x00000018u)
#define CSL_GPIO_OUT_DATA23_OUT24_RESETVAL (0x00000000u)
/*----OUT24 Tokens----*/
#define CSL_GPIO_OUT_DATA23_OUT24_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA23_OUT24_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA23_OUT23_MASK (0x00800000u)
#define CSL_GPIO_OUT_DATA23_OUT23_SHIFT (0x00000017u)
#define CSL_GPIO_OUT_DATA23_OUT23_RESETVAL (0x00000000u)
/*----OUT23 Tokens----*/
#define CSL_GPIO_OUT_DATA23_OUT23_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA23_OUT23_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA23_OUT22_MASK (0x00400000u)
#define CSL_GPIO_OUT_DATA23_OUT22_SHIFT (0x00000016u)
#define CSL_GPIO_OUT_DATA23_OUT22_RESETVAL (0x00000000u)
/*----OUT22 Tokens----*/
#define CSL_GPIO_OUT_DATA23_OUT22_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA23_OUT22_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA23_OUT21_MASK (0x00200000u)
#define CSL_GPIO_OUT_DATA23_OUT21_SHIFT (0x00000015u)
#define CSL_GPIO_OUT_DATA23_OUT21_RESETVAL (0x00000000u)
/*----OUT21 Tokens----*/
#define CSL_GPIO_OUT_DATA23_OUT21_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA23_OUT21_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA23_OUT20_MASK (0x00100000u)
#define CSL_GPIO_OUT_DATA23_OUT20_SHIFT (0x00000014u)
#define CSL_GPIO_OUT_DATA23_OUT20_RESETVAL (0x00000000u)
/*----OUT20 Tokens----*/
#define CSL_GPIO_OUT_DATA23_OUT20_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA23_OUT20_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA23_OUT19_MASK (0x00080000u)
#define CSL_GPIO_OUT_DATA23_OUT19_SHIFT (0x00000013u)
#define CSL_GPIO_OUT_DATA23_OUT19_RESETVAL (0x00000000u)
/*----OUT19 Tokens----*/
#define CSL_GPIO_OUT_DATA23_OUT19_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA23_OUT19_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA23_OUT18_MASK (0x00040000u)
#define CSL_GPIO_OUT_DATA23_OUT18_SHIFT (0x00000012u)
#define CSL_GPIO_OUT_DATA23_OUT18_RESETVAL (0x00000000u)
/*----OUT18 Tokens----*/
#define CSL_GPIO_OUT_DATA23_OUT18_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA23_OUT18_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA23_OUT17_MASK (0x00020000u)
#define CSL_GPIO_OUT_DATA23_OUT17_SHIFT (0x00000011u)
#define CSL_GPIO_OUT_DATA23_OUT17_RESETVAL (0x00000000u)
/*----OUT17 Tokens----*/
#define CSL_GPIO_OUT_DATA23_OUT17_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA23_OUT17_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA23_OUT16_MASK (0x00010000u)
#define CSL_GPIO_OUT_DATA23_OUT16_SHIFT (0x00000010u)
#define CSL_GPIO_OUT_DATA23_OUT16_RESETVAL (0x00000000u)
/*----OUT16 Tokens----*/
#define CSL_GPIO_OUT_DATA23_OUT16_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA23_OUT16_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA23_OUT15_MASK (0x00008000u)
#define CSL_GPIO_OUT_DATA23_OUT15_SHIFT (0x0000000Fu)
#define CSL_GPIO_OUT_DATA23_OUT15_RESETVAL (0x00000000u)
/*----OUT15 Tokens----*/
#define CSL_GPIO_OUT_DATA23_OUT15_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA23_OUT15_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA23_OUT14_MASK (0x00004000u)
#define CSL_GPIO_OUT_DATA23_OUT14_SHIFT (0x0000000Eu)
#define CSL_GPIO_OUT_DATA23_OUT14_RESETVAL (0x00000000u)
/*----OUT14 Tokens----*/
#define CSL_GPIO_OUT_DATA23_OUT14_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA23_OUT14_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA23_OUT13_MASK (0x00002000u)
#define CSL_GPIO_OUT_DATA23_OUT13_SHIFT (0x0000000Du)
#define CSL_GPIO_OUT_DATA23_OUT13_RESETVAL (0x00000000u)
/*----OUT13 Tokens----*/
#define CSL_GPIO_OUT_DATA23_OUT13_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA23_OUT13_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA23_OUT12_MASK (0x00001000u)
#define CSL_GPIO_OUT_DATA23_OUT12_SHIFT (0x0000000Cu)
#define CSL_GPIO_OUT_DATA23_OUT12_RESETVAL (0x00000000u)
/*----OUT12 Tokens----*/
#define CSL_GPIO_OUT_DATA23_OUT12_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA23_OUT12_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA23_OUT11_MASK (0x00000800u)
#define CSL_GPIO_OUT_DATA23_OUT11_SHIFT (0x0000000Bu)
#define CSL_GPIO_OUT_DATA23_OUT11_RESETVAL (0x00000000u)
/*----OUT11 Tokens----*/
#define CSL_GPIO_OUT_DATA23_OUT11_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA23_OUT11_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA23_OUT10_MASK (0x00000400u)
#define CSL_GPIO_OUT_DATA23_OUT10_SHIFT (0x0000000Au)
#define CSL_GPIO_OUT_DATA23_OUT10_RESETVAL (0x00000000u)
/*----OUT10 Tokens----*/
#define CSL_GPIO_OUT_DATA23_OUT10_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA23_OUT10_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA23_OUT9_MASK (0x00000200u)
#define CSL_GPIO_OUT_DATA23_OUT9_SHIFT (0x00000009u)
#define CSL_GPIO_OUT_DATA23_OUT9_RESETVAL (0x00000000u)
/*----OUT9 Tokens----*/
#define CSL_GPIO_OUT_DATA23_OUT9_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA23_OUT9_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA23_OUT8_MASK (0x00000100u)
#define CSL_GPIO_OUT_DATA23_OUT8_SHIFT (0x00000008u)
#define CSL_GPIO_OUT_DATA23_OUT8_RESETVAL (0x00000000u)
/*----OUT8 Tokens----*/
#define CSL_GPIO_OUT_DATA23_OUT8_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA23_OUT8_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA23_OUT7_MASK (0x00000080u)
#define CSL_GPIO_OUT_DATA23_OUT7_SHIFT (0x00000007u)
#define CSL_GPIO_OUT_DATA23_OUT7_RESETVAL (0x00000000u)
/*----OUT7 Tokens----*/
#define CSL_GPIO_OUT_DATA23_OUT7_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA23_OUT7_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA23_OUT6_MASK (0x00000040u)
#define CSL_GPIO_OUT_DATA23_OUT6_SHIFT (0x00000006u)
#define CSL_GPIO_OUT_DATA23_OUT6_RESETVAL (0x00000000u)
/*----OUT6 Tokens----*/
#define CSL_GPIO_OUT_DATA23_OUT6_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA23_OUT6_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA23_OUT5_MASK (0x00000020u)
#define CSL_GPIO_OUT_DATA23_OUT5_SHIFT (0x00000005u)
#define CSL_GPIO_OUT_DATA23_OUT5_RESETVAL (0x00000000u)
/*----OUT5 Tokens----*/
#define CSL_GPIO_OUT_DATA23_OUT5_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA23_OUT5_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA23_OUT4_MASK (0x00000010u)
#define CSL_GPIO_OUT_DATA23_OUT4_SHIFT (0x00000004u)
#define CSL_GPIO_OUT_DATA23_OUT4_RESETVAL (0x00000000u)
/*----OUT4 Tokens----*/
#define CSL_GPIO_OUT_DATA23_OUT4_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA23_OUT4_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA23_OUT3_MASK (0x00000008u)
#define CSL_GPIO_OUT_DATA23_OUT3_SHIFT (0x00000003u)
#define CSL_GPIO_OUT_DATA23_OUT3_RESETVAL (0x00000000u)
/*----OUT3 Tokens----*/
#define CSL_GPIO_OUT_DATA23_OUT3_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA23_OUT3_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA23_OUT2_MASK (0x00000004u)
#define CSL_GPIO_OUT_DATA23_OUT2_SHIFT (0x00000002u)
#define CSL_GPIO_OUT_DATA23_OUT2_RESETVAL (0x00000000u)
/*----OUT2 Tokens----*/
#define CSL_GPIO_OUT_DATA23_OUT2_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA23_OUT2_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA23_OUT1_MASK (0x00000002u)
#define CSL_GPIO_OUT_DATA23_OUT1_SHIFT (0x00000001u)
#define CSL_GPIO_OUT_DATA23_OUT1_RESETVAL (0x00000000u)
/*----OUT1 Tokens----*/
#define CSL_GPIO_OUT_DATA23_OUT1_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA23_OUT1_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA23_OUT0_MASK (0x00000001u)
#define CSL_GPIO_OUT_DATA23_OUT0_SHIFT (0x00000000u)
#define CSL_GPIO_OUT_DATA23_OUT0_RESETVAL (0x00000000u)
/*----OUT0 Tokens----*/
#define CSL_GPIO_OUT_DATA23_OUT0_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA23_OUT0_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA23_RESETVAL (0x00000000u)

/* SET_DATA23 */

#define CSL_GPIO_SET_DATA23_SET31_MASK (0x80000000u)
#define CSL_GPIO_SET_DATA23_SET31_SHIFT (0x0000001Fu)
#define CSL_GPIO_SET_DATA23_SET31_RESETVAL (0x00000000u)
/*----SET31 Tokens----*/
#define CSL_GPIO_SET_DATA23_SET31_SET (0x00000001u)

#define CSL_GPIO_SET_DATA23_SET30_MASK (0x40000000u)
#define CSL_GPIO_SET_DATA23_SET30_SHIFT (0x0000001Eu)
#define CSL_GPIO_SET_DATA23_SET30_RESETVAL (0x00000000u)
/*----SET30 Tokens----*/
#define CSL_GPIO_SET_DATA23_SET30_SET (0x00000001u)

#define CSL_GPIO_SET_DATA23_SET29_MASK (0x20000000u)
#define CSL_GPIO_SET_DATA23_SET29_SHIFT (0x0000001Du)
#define CSL_GPIO_SET_DATA23_SET29_RESETVAL (0x00000000u)
/*----SET29 Tokens----*/
#define CSL_GPIO_SET_DATA23_SET29_SET (0x00000001u)

#define CSL_GPIO_SET_DATA23_SET28_MASK (0x10000000u)
#define CSL_GPIO_SET_DATA23_SET28_SHIFT (0x0000001Cu)
#define CSL_GPIO_SET_DATA23_SET28_RESETVAL (0x00000000u)
/*----SET28 Tokens----*/
#define CSL_GPIO_SET_DATA23_SET28_SET (0x00000001u)

#define CSL_GPIO_SET_DATA23_SET27_MASK (0x08000000u)
#define CSL_GPIO_SET_DATA23_SET27_SHIFT (0x0000001Bu)
#define CSL_GPIO_SET_DATA23_SET27_RESETVAL (0x00000000u)
/*----SET27 Tokens----*/
#define CSL_GPIO_SET_DATA23_SET27_SET (0x00000001u)

#define CSL_GPIO_SET_DATA23_SET26_MASK (0x04000000u)
#define CSL_GPIO_SET_DATA23_SET26_SHIFT (0x0000001Au)
#define CSL_GPIO_SET_DATA23_SET26_RESETVAL (0x00000000u)
/*----SET26 Tokens----*/
#define CSL_GPIO_SET_DATA23_SET26_SET (0x00000001u)

#define CSL_GPIO_SET_DATA23_SET25_MASK (0x02000000u)
#define CSL_GPIO_SET_DATA23_SET25_SHIFT (0x00000019u)
#define CSL_GPIO_SET_DATA23_SET25_RESETVAL (0x00000000u)
/*----SET25 Tokens----*/
#define CSL_GPIO_SET_DATA23_SET25_SET (0x00000001u)

#define CSL_GPIO_SET_DATA23_SET24_MASK (0x01000000u)
#define CSL_GPIO_SET_DATA23_SET24_SHIFT (0x00000018u)
#define CSL_GPIO_SET_DATA23_SET24_RESETVAL (0x00000000u)
/*----SET24 Tokens----*/
#define CSL_GPIO_SET_DATA23_SET24_SET (0x00000001u)

#define CSL_GPIO_SET_DATA23_SET23_MASK (0x00800000u)
#define CSL_GPIO_SET_DATA23_SET23_SHIFT (0x00000017u)
#define CSL_GPIO_SET_DATA23_SET23_RESETVAL (0x00000000u)
/*----SET23 Tokens----*/
#define CSL_GPIO_SET_DATA23_SET23_SET (0x00000001u)

#define CSL_GPIO_SET_DATA23_SET22_MASK (0x00400000u)
#define CSL_GPIO_SET_DATA23_SET22_SHIFT (0x00000016u)
#define CSL_GPIO_SET_DATA23_SET22_RESETVAL (0x00000000u)
/*----SET22 Tokens----*/
#define CSL_GPIO_SET_DATA23_SET22_SET (0x00000001u)

#define CSL_GPIO_SET_DATA23_SET21_MASK (0x00200000u)
#define CSL_GPIO_SET_DATA23_SET21_SHIFT (0x00000015u)
#define CSL_GPIO_SET_DATA23_SET21_RESETVAL (0x00000000u)
/*----SET21 Tokens----*/
#define CSL_GPIO_SET_DATA23_SET21_SET (0x00000001u)

#define CSL_GPIO_SET_DATA23_SET20_MASK (0x00100000u)
#define CSL_GPIO_SET_DATA23_SET20_SHIFT (0x00000014u)
#define CSL_GPIO_SET_DATA23_SET20_RESETVAL (0x00000000u)
/*----SET20 Tokens----*/
#define CSL_GPIO_SET_DATA23_SET20_SET (0x00000001u)

#define CSL_GPIO_SET_DATA23_SET19_MASK (0x00080000u)
#define CSL_GPIO_SET_DATA23_SET19_SHIFT (0x00000013u)
#define CSL_GPIO_SET_DATA23_SET19_RESETVAL (0x00000000u)
/*----SET19 Tokens----*/
#define CSL_GPIO_SET_DATA23_SET19_SET (0x00000001u)

#define CSL_GPIO_SET_DATA23_SET18_MASK (0x00040000u)
#define CSL_GPIO_SET_DATA23_SET18_SHIFT (0x00000012u)
#define CSL_GPIO_SET_DATA23_SET18_RESETVAL (0x00000000u)
/*----SET18 Tokens----*/
#define CSL_GPIO_SET_DATA23_SET18_SET (0x00000001u)

#define CSL_GPIO_SET_DATA23_SET17_MASK (0x00020000u)
#define CSL_GPIO_SET_DATA23_SET17_SHIFT (0x00000011u)
#define CSL_GPIO_SET_DATA23_SET17_RESETVAL (0x00000000u)
/*----SET17 Tokens----*/
#define CSL_GPIO_SET_DATA23_SET17_SET (0x00000001u)

#define CSL_GPIO_SET_DATA23_SET16_MASK (0x00010000u)
#define CSL_GPIO_SET_DATA23_SET16_SHIFT (0x00000010u)
#define CSL_GPIO_SET_DATA23_SET16_RESETVAL (0x00000000u)
/*----SET16 Tokens----*/
#define CSL_GPIO_SET_DATA23_SET16_SET (0x00000001u)

#define CSL_GPIO_SET_DATA23_SET15_MASK (0x00008000u)
#define CSL_GPIO_SET_DATA23_SET15_SHIFT (0x0000000Fu)
#define CSL_GPIO_SET_DATA23_SET15_RESETVAL (0x00000000u)
/*----SET15 Tokens----*/
#define CSL_GPIO_SET_DATA23_SET15_SET (0x00000001u)

#define CSL_GPIO_SET_DATA23_SET14_MASK (0x00004000u)
#define CSL_GPIO_SET_DATA23_SET14_SHIFT (0x0000000Eu)
#define CSL_GPIO_SET_DATA23_SET14_RESETVAL (0x00000000u)
/*----SET14 Tokens----*/
#define CSL_GPIO_SET_DATA23_SET14_SET (0x00000001u)

#define CSL_GPIO_SET_DATA23_SET13_MASK (0x00002000u)
#define CSL_GPIO_SET_DATA23_SET13_SHIFT (0x0000000Du)
#define CSL_GPIO_SET_DATA23_SET13_RESETVAL (0x00000000u)
/*----SET13 Tokens----*/
#define CSL_GPIO_SET_DATA23_SET13_SET (0x00000001u)

#define CSL_GPIO_SET_DATA23_SET12_MASK (0x00001000u)
#define CSL_GPIO_SET_DATA23_SET12_SHIFT (0x0000000Cu)
#define CSL_GPIO_SET_DATA23_SET12_RESETVAL (0x00000000u)
/*----SET12 Tokens----*/
#define CSL_GPIO_SET_DATA23_SET12_SET (0x00000001u)

#define CSL_GPIO_SET_DATA23_SET11_MASK (0x00000800u)
#define CSL_GPIO_SET_DATA23_SET11_SHIFT (0x0000000Bu)
#define CSL_GPIO_SET_DATA23_SET11_RESETVAL (0x00000000u)
/*----SET11 Tokens----*/
#define CSL_GPIO_SET_DATA23_SET11_SET (0x00000001u)

#define CSL_GPIO_SET_DATA23_SET10_MASK (0x00000400u)
#define CSL_GPIO_SET_DATA23_SET10_SHIFT (0x0000000Au)
#define CSL_GPIO_SET_DATA23_SET10_RESETVAL (0x00000000u)
/*----SET10 Tokens----*/
#define CSL_GPIO_SET_DATA23_SET10_SET (0x00000001u)

#define CSL_GPIO_SET_DATA23_SET9_MASK (0x00000200u)
#define CSL_GPIO_SET_DATA23_SET9_SHIFT (0x00000009u)
#define CSL_GPIO_SET_DATA23_SET9_RESETVAL (0x00000000u)
/*----SET9 Tokens----*/
#define CSL_GPIO_SET_DATA23_SET9_SET (0x00000001u)

#define CSL_GPIO_SET_DATA23_SET8_MASK (0x00000100u)
#define CSL_GPIO_SET_DATA23_SET8_SHIFT (0x00000008u)
#define CSL_GPIO_SET_DATA23_SET8_RESETVAL (0x00000000u)
/*----SET8 Tokens----*/
#define CSL_GPIO_SET_DATA23_SET8_SET (0x00000001u)

#define CSL_GPIO_SET_DATA23_SET7_MASK (0x00000080u)
#define CSL_GPIO_SET_DATA23_SET7_SHIFT (0x00000007u)
#define CSL_GPIO_SET_DATA23_SET7_RESETVAL (0x00000000u)
/*----SET7 Tokens----*/
#define CSL_GPIO_SET_DATA23_SET7_SET (0x00000001u)

#define CSL_GPIO_SET_DATA23_SET6_MASK (0x00000040u)
#define CSL_GPIO_SET_DATA23_SET6_SHIFT (0x00000006u)
#define CSL_GPIO_SET_DATA23_SET6_RESETVAL (0x00000000u)
/*----SET6 Tokens----*/
#define CSL_GPIO_SET_DATA23_SET6_SET (0x00000001u)

#define CSL_GPIO_SET_DATA23_SET5_MASK (0x00000020u)
#define CSL_GPIO_SET_DATA23_SET5_SHIFT (0x00000005u)
#define CSL_GPIO_SET_DATA23_SET5_RESETVAL (0x00000000u)
/*----SET5 Tokens----*/
#define CSL_GPIO_SET_DATA23_SET5_SET (0x00000001u)

#define CSL_GPIO_SET_DATA23_SET4_MASK (0x00000010u)
#define CSL_GPIO_SET_DATA23_SET4_SHIFT (0x00000004u)
#define CSL_GPIO_SET_DATA23_SET4_RESETVAL (0x00000000u)
/*----SET4 Tokens----*/
#define CSL_GPIO_SET_DATA23_SET4_SET (0x00000001u)

#define CSL_GPIO_SET_DATA23_SET3_MASK (0x00000008u)
#define CSL_GPIO_SET_DATA23_SET3_SHIFT (0x00000003u)
#define CSL_GPIO_SET_DATA23_SET3_RESETVAL (0x00000000u)
/*----SET3 Tokens----*/
#define CSL_GPIO_SET_DATA23_SET3_SET (0x00000001u)

#define CSL_GPIO_SET_DATA23_SET2_MASK (0x00000004u)
#define CSL_GPIO_SET_DATA23_SET2_SHIFT (0x00000002u)
#define CSL_GPIO_SET_DATA23_SET2_RESETVAL (0x00000000u)
/*----SET2 Tokens----*/
#define CSL_GPIO_SET_DATA23_SET2_SET (0x00000001u)

#define CSL_GPIO_SET_DATA23_SET1_MASK (0x00000002u)
#define CSL_GPIO_SET_DATA23_SET1_SHIFT (0x00000001u)
#define CSL_GPIO_SET_DATA23_SET1_RESETVAL (0x00000000u)
/*----SET1 Tokens----*/
#define CSL_GPIO_SET_DATA23_SET1_SET (0x00000001u)

#define CSL_GPIO_SET_DATA23_SET0_MASK (0x00000001u)
#define CSL_GPIO_SET_DATA23_SET0_SHIFT (0x00000000u)
#define CSL_GPIO_SET_DATA23_SET0_RESETVAL (0x00000000u)
/*----SET0 Tokens----*/
#define CSL_GPIO_SET_DATA23_SET0_SET (0x00000001u)

#define CSL_GPIO_SET_DATA23_RESETVAL (0x00000000u)

/* CLR_DATA23 */

#define CSL_GPIO_CLR_DATA23_CLR31_MASK (0x80000000u)
#define CSL_GPIO_CLR_DATA23_CLR31_SHIFT (0x0000001Fu)
#define CSL_GPIO_CLR_DATA23_CLR31_RESETVAL (0x00000000u)
/*----CLR31 Tokens----*/
#define CSL_GPIO_CLR_DATA23_CLR31_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA23_CLR30_MASK (0x40000000u)
#define CSL_GPIO_CLR_DATA23_CLR30_SHIFT (0x0000001Eu)
#define CSL_GPIO_CLR_DATA23_CLR30_RESETVAL (0x00000000u)
/*----CLR30 Tokens----*/
#define CSL_GPIO_CLR_DATA23_CLR30_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA23_CLR29_MASK (0x20000000u)
#define CSL_GPIO_CLR_DATA23_CLR29_SHIFT (0x0000001Du)
#define CSL_GPIO_CLR_DATA23_CLR29_RESETVAL (0x00000000u)
/*----CLR29 Tokens----*/
#define CSL_GPIO_CLR_DATA23_CLR29_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA23_CLR28_MASK (0x10000000u)
#define CSL_GPIO_CLR_DATA23_CLR28_SHIFT (0x0000001Cu)
#define CSL_GPIO_CLR_DATA23_CLR28_RESETVAL (0x00000000u)
/*----CLR28 Tokens----*/
#define CSL_GPIO_CLR_DATA23_CLR28_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA23_CLR27_MASK (0x08000000u)
#define CSL_GPIO_CLR_DATA23_CLR27_SHIFT (0x0000001Bu)
#define CSL_GPIO_CLR_DATA23_CLR27_RESETVAL (0x00000000u)
/*----CLR27 Tokens----*/
#define CSL_GPIO_CLR_DATA23_CLR27_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA23_CLR26_MASK (0x04000000u)
#define CSL_GPIO_CLR_DATA23_CLR26_SHIFT (0x0000001Au)
#define CSL_GPIO_CLR_DATA23_CLR26_RESETVAL (0x00000000u)
/*----CLR26 Tokens----*/
#define CSL_GPIO_CLR_DATA23_CLR26_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA23_CLR25_MASK (0x02000000u)
#define CSL_GPIO_CLR_DATA23_CLR25_SHIFT (0x00000019u)
#define CSL_GPIO_CLR_DATA23_CLR25_RESETVAL (0x00000000u)
/*----CLR25 Tokens----*/
#define CSL_GPIO_CLR_DATA23_CLR25_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA23_CLR24_MASK (0x01000000u)
#define CSL_GPIO_CLR_DATA23_CLR24_SHIFT (0x00000018u)
#define CSL_GPIO_CLR_DATA23_CLR24_RESETVAL (0x00000000u)
/*----CLR24 Tokens----*/
#define CSL_GPIO_CLR_DATA23_CLR24_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA23_CLR23_MASK (0x00800000u)
#define CSL_GPIO_CLR_DATA23_CLR23_SHIFT (0x00000017u)
#define CSL_GPIO_CLR_DATA23_CLR23_RESETVAL (0x00000000u)
/*----CLR23 Tokens----*/
#define CSL_GPIO_CLR_DATA23_CLR23_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA23_CLR22_MASK (0x00400000u)
#define CSL_GPIO_CLR_DATA23_CLR22_SHIFT (0x00000016u)
#define CSL_GPIO_CLR_DATA23_CLR22_RESETVAL (0x00000000u)
/*----CLR22 Tokens----*/
#define CSL_GPIO_CLR_DATA23_CLR22_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA23_CLR21_MASK (0x00200000u)
#define CSL_GPIO_CLR_DATA23_CLR21_SHIFT (0x00000015u)
#define CSL_GPIO_CLR_DATA23_CLR21_RESETVAL (0x00000000u)
/*----CLR21 Tokens----*/
#define CSL_GPIO_CLR_DATA23_CLR21_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA23_CLR20_MASK (0x00100000u)
#define CSL_GPIO_CLR_DATA23_CLR20_SHIFT (0x00000014u)
#define CSL_GPIO_CLR_DATA23_CLR20_RESETVAL (0x00000000u)
/*----CLR20 Tokens----*/
#define CSL_GPIO_CLR_DATA23_CLR20_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA23_CLR19_MASK (0x00080000u)
#define CSL_GPIO_CLR_DATA23_CLR19_SHIFT (0x00000013u)
#define CSL_GPIO_CLR_DATA23_CLR19_RESETVAL (0x00000000u)
/*----CLR19 Tokens----*/
#define CSL_GPIO_CLR_DATA23_CLR19_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA23_CLR18_MASK (0x00040000u)
#define CSL_GPIO_CLR_DATA23_CLR18_SHIFT (0x00000012u)
#define CSL_GPIO_CLR_DATA23_CLR18_RESETVAL (0x00000000u)
/*----CLR18 Tokens----*/
#define CSL_GPIO_CLR_DATA23_CLR18_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA23_CLR17_MASK (0x00020000u)
#define CSL_GPIO_CLR_DATA23_CLR17_SHIFT (0x00000011u)
#define CSL_GPIO_CLR_DATA23_CLR17_RESETVAL (0x00000000u)
/*----CLR17 Tokens----*/
#define CSL_GPIO_CLR_DATA23_CLR17_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA23_CLR16_MASK (0x00010000u)
#define CSL_GPIO_CLR_DATA23_CLR16_SHIFT (0x00000010u)
#define CSL_GPIO_CLR_DATA23_CLR16_RESETVAL (0x00000000u)
/*----CLR16 Tokens----*/
#define CSL_GPIO_CLR_DATA23_CLR16_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA23_CLR15_MASK (0x00008000u)
#define CSL_GPIO_CLR_DATA23_CLR15_SHIFT (0x0000000Fu)
#define CSL_GPIO_CLR_DATA23_CLR15_RESETVAL (0x00000000u)
/*----CLR15 Tokens----*/
#define CSL_GPIO_CLR_DATA23_CLR15_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA23_CLR14_MASK (0x00004000u)
#define CSL_GPIO_CLR_DATA23_CLR14_SHIFT (0x0000000Eu)
#define CSL_GPIO_CLR_DATA23_CLR14_RESETVAL (0x00000000u)
/*----CLR14 Tokens----*/
#define CSL_GPIO_CLR_DATA23_CLR14_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA23_CLR13_MASK (0x00002000u)
#define CSL_GPIO_CLR_DATA23_CLR13_SHIFT (0x0000000Du)
#define CSL_GPIO_CLR_DATA23_CLR13_RESETVAL (0x00000000u)
/*----CLR13 Tokens----*/
#define CSL_GPIO_CLR_DATA23_CLR13_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA23_CLR12_MASK (0x00001000u)
#define CSL_GPIO_CLR_DATA23_CLR12_SHIFT (0x0000000Cu)
#define CSL_GPIO_CLR_DATA23_CLR12_RESETVAL (0x00000000u)
/*----CLR12 Tokens----*/
#define CSL_GPIO_CLR_DATA23_CLR12_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA23_CLR11_MASK (0x00000800u)
#define CSL_GPIO_CLR_DATA23_CLR11_SHIFT (0x0000000Bu)
#define CSL_GPIO_CLR_DATA23_CLR11_RESETVAL (0x00000000u)
/*----CLR11 Tokens----*/
#define CSL_GPIO_CLR_DATA23_CLR11_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA23_CLR10_MASK (0x00000400u)
#define CSL_GPIO_CLR_DATA23_CLR10_SHIFT (0x0000000Au)
#define CSL_GPIO_CLR_DATA23_CLR10_RESETVAL (0x00000000u)
/*----CLR10 Tokens----*/
#define CSL_GPIO_CLR_DATA23_CLR10_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA23_CLR9_MASK (0x00000200u)
#define CSL_GPIO_CLR_DATA23_CLR9_SHIFT (0x00000009u)
#define CSL_GPIO_CLR_DATA23_CLR9_RESETVAL (0x00000000u)
/*----CLR9 Tokens----*/
#define CSL_GPIO_CLR_DATA23_CLR9_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA23_CLR8_MASK (0x00000100u)
#define CSL_GPIO_CLR_DATA23_CLR8_SHIFT (0x00000008u)
#define CSL_GPIO_CLR_DATA23_CLR8_RESETVAL (0x00000000u)
/*----CLR8 Tokens----*/
#define CSL_GPIO_CLR_DATA23_CLR8_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA23_CLR7_MASK (0x00000080u)
#define CSL_GPIO_CLR_DATA23_CLR7_SHIFT (0x00000007u)
#define CSL_GPIO_CLR_DATA23_CLR7_RESETVAL (0x00000000u)
/*----CLR7 Tokens----*/
#define CSL_GPIO_CLR_DATA23_CLR7_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA23_CLR6_MASK (0x00000040u)
#define CSL_GPIO_CLR_DATA23_CLR6_SHIFT (0x00000006u)
#define CSL_GPIO_CLR_DATA23_CLR6_RESETVAL (0x00000000u)
/*----CLR6 Tokens----*/
#define CSL_GPIO_CLR_DATA23_CLR6_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA23_CLR5_MASK (0x00000020u)
#define CSL_GPIO_CLR_DATA23_CLR5_SHIFT (0x00000005u)
#define CSL_GPIO_CLR_DATA23_CLR5_RESETVAL (0x00000000u)
/*----CLR5 Tokens----*/
#define CSL_GPIO_CLR_DATA23_CLR5_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA23_CLR4_MASK (0x00000010u)
#define CSL_GPIO_CLR_DATA23_CLR4_SHIFT (0x00000004u)
#define CSL_GPIO_CLR_DATA23_CLR4_RESETVAL (0x00000000u)
/*----CLR4 Tokens----*/
#define CSL_GPIO_CLR_DATA23_CLR4_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA23_CLR3_MASK (0x00000008u)
#define CSL_GPIO_CLR_DATA23_CLR3_SHIFT (0x00000003u)
#define CSL_GPIO_CLR_DATA23_CLR3_RESETVAL (0x00000000u)
/*----CLR3 Tokens----*/
#define CSL_GPIO_CLR_DATA23_CLR3_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA23_CLR2_MASK (0x00000004u)
#define CSL_GPIO_CLR_DATA23_CLR2_SHIFT (0x00000002u)
#define CSL_GPIO_CLR_DATA23_CLR2_RESETVAL (0x00000000u)
/*----CLR2 Tokens----*/
#define CSL_GPIO_CLR_DATA23_CLR2_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA23_CLR1_MASK (0x00000002u)
#define CSL_GPIO_CLR_DATA23_CLR1_SHIFT (0x00000001u)
#define CSL_GPIO_CLR_DATA23_CLR1_RESETVAL (0x00000000u)
/*----CLR1 Tokens----*/
#define CSL_GPIO_CLR_DATA23_CLR1_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA23_CLR0_MASK (0x00000001u)
#define CSL_GPIO_CLR_DATA23_CLR0_SHIFT (0x00000000u)
#define CSL_GPIO_CLR_DATA23_CLR0_RESETVAL (0x00000000u)
/*----CLR0 Tokens----*/
#define CSL_GPIO_CLR_DATA23_CLR0_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA23_RESETVAL (0x00000000u)

/* IN_DATA23 */

#define CSL_GPIO_IN_DATA23_IN31_MASK (0x80000000u)
#define CSL_GPIO_IN_DATA23_IN31_SHIFT (0x0000001Fu)
#define CSL_GPIO_IN_DATA23_IN31_RESETVAL (0x00000000u)
/*----IN31 Tokens----*/
#define CSL_GPIO_IN_DATA23_IN31_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA23_IN31_SET (0x00000001u)

#define CSL_GPIO_IN_DATA23_IN30_MASK (0x40000000u)
#define CSL_GPIO_IN_DATA23_IN30_SHIFT (0x0000001Eu)
#define CSL_GPIO_IN_DATA23_IN30_RESETVAL (0x00000000u)
/*----IN30 Tokens----*/
#define CSL_GPIO_IN_DATA23_IN30_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA23_IN30_SET (0x00000001u)

#define CSL_GPIO_IN_DATA23_IN29_MASK (0x20000000u)
#define CSL_GPIO_IN_DATA23_IN29_SHIFT (0x0000001Du)
#define CSL_GPIO_IN_DATA23_IN29_RESETVAL (0x00000000u)
/*----IN29 Tokens----*/
#define CSL_GPIO_IN_DATA23_IN29_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA23_IN29_SET (0x00000001u)

#define CSL_GPIO_IN_DATA23_IN28_MASK (0x10000000u)
#define CSL_GPIO_IN_DATA23_IN28_SHIFT (0x0000001Cu)
#define CSL_GPIO_IN_DATA23_IN28_RESETVAL (0x00000000u)
/*----IN28 Tokens----*/
#define CSL_GPIO_IN_DATA23_IN28_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA23_IN28_SET (0x00000001u)

#define CSL_GPIO_IN_DATA23_IN27_MASK (0x08000000u)
#define CSL_GPIO_IN_DATA23_IN27_SHIFT (0x0000001Bu)
#define CSL_GPIO_IN_DATA23_IN27_RESETVAL (0x00000000u)
/*----IN27 Tokens----*/
#define CSL_GPIO_IN_DATA23_IN27_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA23_IN27_SET (0x00000001u)

#define CSL_GPIO_IN_DATA23_IN26_MASK (0x04000000u)
#define CSL_GPIO_IN_DATA23_IN26_SHIFT (0x0000001Au)
#define CSL_GPIO_IN_DATA23_IN26_RESETVAL (0x00000000u)
/*----IN26 Tokens----*/
#define CSL_GPIO_IN_DATA23_IN26_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA23_IN26_SET (0x00000001u)

#define CSL_GPIO_IN_DATA23_IN25_MASK (0x02000000u)
#define CSL_GPIO_IN_DATA23_IN25_SHIFT (0x00000019u)
#define CSL_GPIO_IN_DATA23_IN25_RESETVAL (0x00000000u)
/*----IN25 Tokens----*/
#define CSL_GPIO_IN_DATA23_IN25_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA23_IN25_SET (0x00000001u)

#define CSL_GPIO_IN_DATA23_IN24_MASK (0x01000000u)
#define CSL_GPIO_IN_DATA23_IN24_SHIFT (0x00000018u)
#define CSL_GPIO_IN_DATA23_IN24_RESETVAL (0x00000000u)
/*----IN24 Tokens----*/
#define CSL_GPIO_IN_DATA23_IN24_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA23_IN24_SET (0x00000001u)

#define CSL_GPIO_IN_DATA23_IN23_MASK (0x00800000u)
#define CSL_GPIO_IN_DATA23_IN23_SHIFT (0x00000017u)
#define CSL_GPIO_IN_DATA23_IN23_RESETVAL (0x00000000u)
/*----IN23 Tokens----*/
#define CSL_GPIO_IN_DATA23_IN23_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA23_IN23_SET (0x00000001u)

#define CSL_GPIO_IN_DATA23_IN22_MASK (0x00400000u)
#define CSL_GPIO_IN_DATA23_IN22_SHIFT (0x00000016u)
#define CSL_GPIO_IN_DATA23_IN22_RESETVAL (0x00000000u)
/*----IN22 Tokens----*/
#define CSL_GPIO_IN_DATA23_IN22_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA23_IN22_SET (0x00000001u)

#define CSL_GPIO_IN_DATA23_IN21_MASK (0x00200000u)
#define CSL_GPIO_IN_DATA23_IN21_SHIFT (0x00000015u)
#define CSL_GPIO_IN_DATA23_IN21_RESETVAL (0x00000000u)
/*----IN21 Tokens----*/
#define CSL_GPIO_IN_DATA23_IN21_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA23_IN21_SET (0x00000001u)

#define CSL_GPIO_IN_DATA23_IN20_MASK (0x00100000u)
#define CSL_GPIO_IN_DATA23_IN20_SHIFT (0x00000014u)
#define CSL_GPIO_IN_DATA23_IN20_RESETVAL (0x00000000u)
/*----IN20 Tokens----*/
#define CSL_GPIO_IN_DATA23_IN20_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA23_IN20_SET (0x00000001u)

#define CSL_GPIO_IN_DATA23_IN19_MASK (0x00080000u)
#define CSL_GPIO_IN_DATA23_IN19_SHIFT (0x00000013u)
#define CSL_GPIO_IN_DATA23_IN19_RESETVAL (0x00000000u)
/*----IN19 Tokens----*/
#define CSL_GPIO_IN_DATA23_IN19_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA23_IN19_SET (0x00000001u)

#define CSL_GPIO_IN_DATA23_IN18_MASK (0x00040000u)
#define CSL_GPIO_IN_DATA23_IN18_SHIFT (0x00000012u)
#define CSL_GPIO_IN_DATA23_IN18_RESETVAL (0x00000000u)
/*----IN18 Tokens----*/
#define CSL_GPIO_IN_DATA23_IN18_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA23_IN18_SET (0x00000001u)

#define CSL_GPIO_IN_DATA23_IN17_MASK (0x00020000u)
#define CSL_GPIO_IN_DATA23_IN17_SHIFT (0x00000011u)
#define CSL_GPIO_IN_DATA23_IN17_RESETVAL (0x00000000u)
/*----IN17 Tokens----*/
#define CSL_GPIO_IN_DATA23_IN17_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA23_IN17_SET (0x00000001u)

#define CSL_GPIO_IN_DATA23_IN16_MASK (0x00010000u)
#define CSL_GPIO_IN_DATA23_IN16_SHIFT (0x00000010u)
#define CSL_GPIO_IN_DATA23_IN16_RESETVAL (0x00000000u)
/*----IN16 Tokens----*/
#define CSL_GPIO_IN_DATA23_IN16_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA23_IN16_SET (0x00000001u)

#define CSL_GPIO_IN_DATA23_IN15_MASK (0x00008000u)
#define CSL_GPIO_IN_DATA23_IN15_SHIFT (0x0000000Fu)
#define CSL_GPIO_IN_DATA23_IN15_RESETVAL (0x00000000u)
/*----IN15 Tokens----*/
#define CSL_GPIO_IN_DATA23_IN15_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA23_IN15_SET (0x00000001u)

#define CSL_GPIO_IN_DATA23_IN14_MASK (0x00004000u)
#define CSL_GPIO_IN_DATA23_IN14_SHIFT (0x0000000Eu)
#define CSL_GPIO_IN_DATA23_IN14_RESETVAL (0x00000000u)
/*----IN14 Tokens----*/
#define CSL_GPIO_IN_DATA23_IN14_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA23_IN14_SET (0x00000001u)

#define CSL_GPIO_IN_DATA23_IN13_MASK (0x00002000u)
#define CSL_GPIO_IN_DATA23_IN13_SHIFT (0x0000000Du)
#define CSL_GPIO_IN_DATA23_IN13_RESETVAL (0x00000000u)
/*----IN13 Tokens----*/
#define CSL_GPIO_IN_DATA23_IN13_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA23_IN13_SET (0x00000001u)

#define CSL_GPIO_IN_DATA23_IN12_MASK (0x00001000u)
#define CSL_GPIO_IN_DATA23_IN12_SHIFT (0x0000000Cu)
#define CSL_GPIO_IN_DATA23_IN12_RESETVAL (0x00000000u)
/*----IN12 Tokens----*/
#define CSL_GPIO_IN_DATA23_IN12_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA23_IN12_SET (0x00000001u)

#define CSL_GPIO_IN_DATA23_IN11_MASK (0x00000800u)
#define CSL_GPIO_IN_DATA23_IN11_SHIFT (0x0000000Bu)
#define CSL_GPIO_IN_DATA23_IN11_RESETVAL (0x00000000u)
/*----IN11 Tokens----*/
#define CSL_GPIO_IN_DATA23_IN11_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA23_IN11_SET (0x00000001u)

#define CSL_GPIO_IN_DATA23_IN10_MASK (0x00000400u)
#define CSL_GPIO_IN_DATA23_IN10_SHIFT (0x0000000Au)
#define CSL_GPIO_IN_DATA23_IN10_RESETVAL (0x00000000u)
/*----IN10 Tokens----*/
#define CSL_GPIO_IN_DATA23_IN10_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA23_IN10_SET (0x00000001u)

#define CSL_GPIO_IN_DATA23_IN9_MASK (0x00000200u)
#define CSL_GPIO_IN_DATA23_IN9_SHIFT (0x00000009u)
#define CSL_GPIO_IN_DATA23_IN9_RESETVAL (0x00000000u)
/*----IN9 Tokens----*/
#define CSL_GPIO_IN_DATA23_IN9_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA23_IN9_SET (0x00000001u)

#define CSL_GPIO_IN_DATA23_IN8_MASK (0x00000100u)
#define CSL_GPIO_IN_DATA23_IN8_SHIFT (0x00000008u)
#define CSL_GPIO_IN_DATA23_IN8_RESETVAL (0x00000000u)
/*----IN8 Tokens----*/
#define CSL_GPIO_IN_DATA23_IN8_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA23_IN8_SET (0x00000001u)

#define CSL_GPIO_IN_DATA23_IN7_MASK (0x00000080u)
#define CSL_GPIO_IN_DATA23_IN7_SHIFT (0x00000007u)
#define CSL_GPIO_IN_DATA23_IN7_RESETVAL (0x00000000u)
/*----IN7 Tokens----*/
#define CSL_GPIO_IN_DATA23_IN7_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA23_IN7_SET (0x00000001u)

#define CSL_GPIO_IN_DATA23_IN6_MASK (0x00000040u)
#define CSL_GPIO_IN_DATA23_IN6_SHIFT (0x00000006u)
#define CSL_GPIO_IN_DATA23_IN6_RESETVAL (0x00000000u)
/*----IN6 Tokens----*/
#define CSL_GPIO_IN_DATA23_IN6_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA23_IN6_SET (0x00000001u)

#define CSL_GPIO_IN_DATA23_IN5_MASK (0x00000020u)
#define CSL_GPIO_IN_DATA23_IN5_SHIFT (0x00000005u)
#define CSL_GPIO_IN_DATA23_IN5_RESETVAL (0x00000000u)
/*----IN5 Tokens----*/
#define CSL_GPIO_IN_DATA23_IN5_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA23_IN5_SET (0x00000001u)

#define CSL_GPIO_IN_DATA23_IN4_MASK (0x00000010u)
#define CSL_GPIO_IN_DATA23_IN4_SHIFT (0x00000004u)
#define CSL_GPIO_IN_DATA23_IN4_RESETVAL (0x00000000u)
/*----IN4 Tokens----*/
#define CSL_GPIO_IN_DATA23_IN4_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA23_IN4_SET (0x00000001u)

#define CSL_GPIO_IN_DATA23_IN3_MASK (0x00000008u)
#define CSL_GPIO_IN_DATA23_IN3_SHIFT (0x00000003u)
#define CSL_GPIO_IN_DATA23_IN3_RESETVAL (0x00000000u)
/*----IN3 Tokens----*/
#define CSL_GPIO_IN_DATA23_IN3_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA23_IN3_SET (0x00000001u)

#define CSL_GPIO_IN_DATA23_IN2_MASK (0x00000004u)
#define CSL_GPIO_IN_DATA23_IN2_SHIFT (0x00000002u)
#define CSL_GPIO_IN_DATA23_IN2_RESETVAL (0x00000000u)
/*----IN2 Tokens----*/
#define CSL_GPIO_IN_DATA23_IN2_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA23_IN2_SET (0x00000001u)

#define CSL_GPIO_IN_DATA23_IN1_MASK (0x00000002u)
#define CSL_GPIO_IN_DATA23_IN1_SHIFT (0x00000001u)
#define CSL_GPIO_IN_DATA23_IN1_RESETVAL (0x00000000u)
/*----IN1 Tokens----*/
#define CSL_GPIO_IN_DATA23_IN1_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA23_IN1_SET (0x00000001u)

#define CSL_GPIO_IN_DATA23_IN0_MASK (0x00000001u)
#define CSL_GPIO_IN_DATA23_IN0_SHIFT (0x00000000u)
#define CSL_GPIO_IN_DATA23_IN0_RESETVAL (0x00000000u)
/*----IN0 Tokens----*/
#define CSL_GPIO_IN_DATA23_IN0_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA23_IN0_SET (0x00000001u)

#define CSL_GPIO_IN_DATA23_RESETVAL (0x00000000u)

/* SET_RIS_TRIG23 */

#define CSL_GPIO_SET_RIS_TRIG23_SETRIS31_MASK (0x80000000u)
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS31_SHIFT (0x0000001Fu)
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS31_RESETVAL (0x00000000u)
/*----SETRIS31 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS31_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG23_SETRIS30_MASK (0x40000000u)
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS30_SHIFT (0x0000001Eu)
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS30_RESETVAL (0x00000000u)
/*----SETRIS30 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS30_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG23_SETRIS29_MASK (0x20000000u)
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS29_SHIFT (0x0000001Du)
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS29_RESETVAL (0x00000000u)
/*----SETRIS29 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS29_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG23_SETRIS28_MASK (0x10000000u)
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS28_SHIFT (0x0000001Cu)
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS28_RESETVAL (0x00000000u)
/*----SETRIS28 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS28_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG23_SETRIS27_MASK (0x08000000u)
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS27_SHIFT (0x0000001Bu)
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS27_RESETVAL (0x00000000u)
/*----SETRIS27 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS27_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG23_SETRIS26_MASK (0x04000000u)
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS26_SHIFT (0x0000001Au)
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS26_RESETVAL (0x00000000u)
/*----SETRIS26 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS26_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG23_SETRIS25_MASK (0x02000000u)
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS25_SHIFT (0x00000019u)
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS25_RESETVAL (0x00000000u)
/*----SETRIS25 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS25_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG23_SETRIS24_MASK (0x01000000u)
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS24_SHIFT (0x00000018u)
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS24_RESETVAL (0x00000000u)
/*----SETRIS24 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS24_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG23_SETRIS23_MASK (0x00800000u)
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS23_SHIFT (0x00000017u)
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS23_RESETVAL (0x00000000u)
/*----SETRIS23 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS23_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG23_SETRIS22_MASK (0x00400000u)
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS22_SHIFT (0x00000016u)
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS22_RESETVAL (0x00000000u)
/*----SETRIS22 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS22_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG23_SETRIS21_MASK (0x00200000u)
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS21_SHIFT (0x00000015u)
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS21_RESETVAL (0x00000000u)
/*----SETRIS21 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS21_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG23_SETRIS20_MASK (0x00100000u)
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS20_SHIFT (0x00000014u)
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS20_RESETVAL (0x00000000u)
/*----SETRIS20 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS20_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG23_SETRIS19_MASK (0x00080000u)
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS19_SHIFT (0x00000013u)
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS19_RESETVAL (0x00000000u)
/*----SETRIS19 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS19_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG23_SETRIS18_MASK (0x00040000u)
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS18_SHIFT (0x00000012u)
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS18_RESETVAL (0x00000000u)
/*----SETRIS18 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS18_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG23_SETRIS17_MASK (0x00020000u)
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS17_SHIFT (0x00000011u)
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS17_RESETVAL (0x00000000u)
/*----SETRIS17 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS17_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG23_SETRIS16_MASK (0x00010000u)
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS16_SHIFT (0x00000010u)
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS16_RESETVAL (0x00000000u)
/*----SETRIS16 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS16_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG23_SETRIS15_MASK (0x00008000u)
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS15_SHIFT (0x0000000Fu)
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS15_RESETVAL (0x00000000u)
/*----SETRIS15 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS15_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG23_SETRIS14_MASK (0x00004000u)
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS14_SHIFT (0x0000000Eu)
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS14_RESETVAL (0x00000000u)
/*----SETRIS14 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS14_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG23_SETRIS13_MASK (0x00002000u)
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS13_SHIFT (0x0000000Du)
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS13_RESETVAL (0x00000000u)
/*----SETRIS13 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS13_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG23_SETRIS12_MASK (0x00001000u)
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS12_SHIFT (0x0000000Cu)
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS12_RESETVAL (0x00000000u)
/*----SETRIS12 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS12_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG23_SETRIS11_MASK (0x00000800u)
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS11_SHIFT (0x0000000Bu)
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS11_RESETVAL (0x00000000u)
/*----SETRIS11 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS11_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG23_SETRIS10_MASK (0x00000400u)
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS10_SHIFT (0x0000000Au)
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS10_RESETVAL (0x00000000u)
/*----SETRIS10 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS10_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG23_SETRIS9_MASK (0x00000200u)
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS9_SHIFT (0x00000009u)
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS9_RESETVAL (0x00000000u)
/*----SETRIS9 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS9_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG23_SETRIS8_MASK (0x00000100u)
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS8_SHIFT (0x00000008u)
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS8_RESETVAL (0x00000000u)
/*----SETRIS8 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS8_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG23_SETRIS7_MASK (0x00000080u)
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS7_SHIFT (0x00000007u)
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS7_RESETVAL (0x00000000u)
/*----SETRIS7 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS7_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG23_SETRIS6_MASK (0x00000040u)
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS6_SHIFT (0x00000006u)
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS6_RESETVAL (0x00000000u)
/*----SETRIS6 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS6_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG23_SETRIS5_MASK (0x00000020u)
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS5_SHIFT (0x00000005u)
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS5_RESETVAL (0x00000000u)
/*----SETRIS5 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS5_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG23_SETRIS4_MASK (0x00000010u)
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS4_SHIFT (0x00000004u)
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS4_RESETVAL (0x00000000u)
/*----SETRIS4 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS4_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG23_SETRIS3_MASK (0x00000008u)
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS3_SHIFT (0x00000003u)
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS3_RESETVAL (0x00000000u)
/*----SETRIS3 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS3_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG23_SETRIS2_MASK (0x00000004u)
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS2_SHIFT (0x00000002u)
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS2_RESETVAL (0x00000000u)
/*----SETRIS2 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS2_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG23_SETRIS1_MASK (0x00000002u)
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS1_SHIFT (0x00000001u)
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS1_RESETVAL (0x00000000u)
/*----SETRIS1 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS1_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG23_SETRIS0_MASK (0x00000001u)
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS0_SHIFT (0x00000000u)
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS0_RESETVAL (0x00000000u)
/*----SETRIS0 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG23_SETRIS0_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG23_RESETVAL (0x00000000u)

/* CLR_RIS_TRIG23 */

#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS31_MASK (0x80000000u)
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS31_SHIFT (0x0000001Fu)
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS31_RESETVAL (0x00000000u)
/*----CLRRIS31 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS31_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS30_MASK (0x40000000u)
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS30_SHIFT (0x0000001Eu)
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS30_RESETVAL (0x00000000u)
/*----CLRRIS30 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS30_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS29_MASK (0x20000000u)
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS29_SHIFT (0x0000001Du)
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS29_RESETVAL (0x00000000u)
/*----CLRRIS29 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS29_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS28_MASK (0x10000000u)
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS28_SHIFT (0x0000001Cu)
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS28_RESETVAL (0x00000000u)
/*----CLRRIS28 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS28_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS27_MASK (0x08000000u)
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS27_SHIFT (0x0000001Bu)
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS27_RESETVAL (0x00000000u)
/*----CLRRIS27 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS27_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS26_MASK (0x04000000u)
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS26_SHIFT (0x0000001Au)
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS26_RESETVAL (0x00000000u)
/*----CLRRIS26 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS26_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS25_MASK (0x02000000u)
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS25_SHIFT (0x00000019u)
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS25_RESETVAL (0x00000000u)
/*----CLRRIS25 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS25_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS24_MASK (0x01000000u)
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS24_SHIFT (0x00000018u)
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS24_RESETVAL (0x00000000u)
/*----CLRRIS24 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS24_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS23_MASK (0x00800000u)
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS23_SHIFT (0x00000017u)
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS23_RESETVAL (0x00000000u)
/*----CLRRIS23 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS23_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS22_MASK (0x00400000u)
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS22_SHIFT (0x00000016u)
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS22_RESETVAL (0x00000000u)
/*----CLRRIS22 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS22_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS21_MASK (0x00200000u)
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS21_SHIFT (0x00000015u)
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS21_RESETVAL (0x00000000u)
/*----CLRRIS21 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS21_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS20_MASK (0x00100000u)
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS20_SHIFT (0x00000014u)
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS20_RESETVAL (0x00000000u)
/*----CLRRIS20 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS20_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS19_MASK (0x00080000u)
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS19_SHIFT (0x00000013u)
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS19_RESETVAL (0x00000000u)
/*----CLRRIS19 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS19_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS18_MASK (0x00040000u)
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS18_SHIFT (0x00000012u)
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS18_RESETVAL (0x00000000u)
/*----CLRRIS18 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS18_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS17_MASK (0x00020000u)
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS17_SHIFT (0x00000011u)
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS17_RESETVAL (0x00000000u)
/*----CLRRIS17 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS17_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS16_MASK (0x00010000u)
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS16_SHIFT (0x00000010u)
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS16_RESETVAL (0x00000000u)
/*----CLRRIS16 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS16_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS15_MASK (0x00008000u)
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS15_SHIFT (0x0000000Fu)
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS15_RESETVAL (0x00000000u)
/*----CLRRIS15 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS15_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS14_MASK (0x00004000u)
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS14_SHIFT (0x0000000Eu)
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS14_RESETVAL (0x00000000u)
/*----CLRRIS14 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS14_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS13_MASK (0x00002000u)
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS13_SHIFT (0x0000000Du)
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS13_RESETVAL (0x00000000u)
/*----CLRRIS13 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS13_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS12_MASK (0x00001000u)
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS12_SHIFT (0x0000000Cu)
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS12_RESETVAL (0x00000000u)
/*----CLRRIS12 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS12_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS11_MASK (0x00000800u)
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS11_SHIFT (0x0000000Bu)
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS11_RESETVAL (0x00000000u)
/*----CLRRIS11 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS11_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS10_MASK (0x00000400u)
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS10_SHIFT (0x0000000Au)
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS10_RESETVAL (0x00000000u)
/*----CLRRIS10 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS10_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS9_MASK (0x00000200u)
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS9_SHIFT (0x00000009u)
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS9_RESETVAL (0x00000000u)
/*----CLRRIS9 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS9_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS8_MASK (0x00000100u)
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS8_SHIFT (0x00000008u)
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS8_RESETVAL (0x00000000u)
/*----CLRRIS8 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS8_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS7_MASK (0x00000080u)
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS7_SHIFT (0x00000007u)
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS7_RESETVAL (0x00000000u)
/*----CLRRIS7 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS7_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS6_MASK (0x00000040u)
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS6_SHIFT (0x00000006u)
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS6_RESETVAL (0x00000000u)
/*----CLRRIS6 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS6_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS5_MASK (0x00000020u)
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS5_SHIFT (0x00000005u)
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS5_RESETVAL (0x00000000u)
/*----CLRRIS5 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS5_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS4_MASK (0x00000010u)
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS4_SHIFT (0x00000004u)
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS4_RESETVAL (0x00000000u)
/*----CLRRIS4 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS4_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS3_MASK (0x00000008u)
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS3_SHIFT (0x00000003u)
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS3_RESETVAL (0x00000000u)
/*----CLRRIS3 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS3_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS2_MASK (0x00000004u)
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS2_SHIFT (0x00000002u)
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS2_RESETVAL (0x00000000u)
/*----CLRRIS2 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS2_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS1_MASK (0x00000002u)
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS1_SHIFT (0x00000001u)
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS1_RESETVAL (0x00000000u)
/*----CLRRIS1 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS1_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS0_MASK (0x00000001u)
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS0_SHIFT (0x00000000u)
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS0_RESETVAL (0x00000000u)
/*----CLRRIS0 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG23_CLRRIS0_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_RIS_TRIG23_RESETVAL (0x00000000u)

/* SET_FAL_TRIG23 */

#define CSL_GPIO_SET_FAL_TRIG23_SETFAL31_MASK (0x80000000u)
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL31_SHIFT (0x0000001Fu)
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL31_RESETVAL (0x00000000u)
/*----SETFAL31 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL31_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG23_SETFAL30_MASK (0x40000000u)
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL30_SHIFT (0x0000001Eu)
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL30_RESETVAL (0x00000000u)
/*----SETFAL30 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL30_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG23_SETFAL29_MASK (0x20000000u)
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL29_SHIFT (0x0000001Du)
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL29_RESETVAL (0x00000000u)
/*----SETFAL29 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL29_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG23_SETFAL28_MASK (0x10000000u)
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL28_SHIFT (0x0000001Cu)
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL28_RESETVAL (0x00000000u)
/*----SETFAL28 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL28_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG23_SETFAL27_MASK (0x08000000u)
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL27_SHIFT (0x0000001Bu)
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL27_RESETVAL (0x00000000u)
/*----SETFAL27 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL27_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG23_SETFAL26_MASK (0x04000000u)
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL26_SHIFT (0x0000001Au)
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL26_RESETVAL (0x00000000u)
/*----SETFAL26 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL26_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG23_SETFAL25_MASK (0x02000000u)
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL25_SHIFT (0x00000019u)
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL25_RESETVAL (0x00000000u)
/*----SETFAL25 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL25_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG23_SETFAL24_MASK (0x01000000u)
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL24_SHIFT (0x00000018u)
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL24_RESETVAL (0x00000000u)
/*----SETFAL24 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL24_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG23_SETFAL23_MASK (0x00800000u)
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL23_SHIFT (0x00000017u)
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL23_RESETVAL (0x00000000u)
/*----SETFAL23 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL23_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG23_SETFAL22_MASK (0x00400000u)
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL22_SHIFT (0x00000016u)
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL22_RESETVAL (0x00000000u)
/*----SETFAL22 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL22_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG23_SETFAL21_MASK (0x00200000u)
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL21_SHIFT (0x00000015u)
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL21_RESETVAL (0x00000000u)
/*----SETFAL21 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL21_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG23_SETFAL20_MASK (0x00100000u)
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL20_SHIFT (0x00000014u)
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL20_RESETVAL (0x00000000u)
/*----SETFAL20 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL20_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG23_SETFAL19_MASK (0x00080000u)
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL19_SHIFT (0x00000013u)
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL19_RESETVAL (0x00000000u)
/*----SETFAL19 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL19_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG23_SETFAL18_MASK (0x00040000u)
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL18_SHIFT (0x00000012u)
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL18_RESETVAL (0x00000000u)
/*----SETFAL18 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL18_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG23_SETFAL17_MASK (0x00020000u)
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL17_SHIFT (0x00000011u)
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL17_RESETVAL (0x00000000u)
/*----SETFAL17 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL17_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG23_SETFAL16_MASK (0x00010000u)
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL16_SHIFT (0x00000010u)
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL16_RESETVAL (0x00000000u)
/*----SETFAL16 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL16_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG23_SETFAL15_MASK (0x00008000u)
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL15_SHIFT (0x0000000Fu)
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL15_RESETVAL (0x00000000u)
/*----SETFAL15 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL15_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG23_SETFAL14_MASK (0x00004000u)
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL14_SHIFT (0x0000000Eu)
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL14_RESETVAL (0x00000000u)
/*----SETFAL14 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL14_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG23_SETFAL13_MASK (0x00002000u)
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL13_SHIFT (0x0000000Du)
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL13_RESETVAL (0x00000000u)
/*----SETFAL13 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL13_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG23_SETFAL12_MASK (0x00001000u)
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL12_SHIFT (0x0000000Cu)
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL12_RESETVAL (0x00000000u)
/*----SETFAL12 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL12_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG23_SETFAL11_MASK (0x00000800u)
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL11_SHIFT (0x0000000Bu)
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL11_RESETVAL (0x00000000u)
/*----SETFAL11 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL11_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG23_SETFAL10_MASK (0x00000400u)
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL10_SHIFT (0x0000000Au)
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL10_RESETVAL (0x00000000u)
/*----SETFAL10 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL10_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG23_SETFAL9_MASK (0x00000200u)
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL9_SHIFT (0x00000009u)
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL9_RESETVAL (0x00000000u)
/*----SETFAL9 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL9_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG23_SETFAL8_MASK (0x00000100u)
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL8_SHIFT (0x00000008u)
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL8_RESETVAL (0x00000000u)
/*----SETFAL8 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL8_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG23_SETFAL7_MASK (0x00000080u)
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL7_SHIFT (0x00000007u)
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL7_RESETVAL (0x00000000u)
/*----SETFAL7 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL7_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG23_SETFAL6_MASK (0x00000040u)
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL6_SHIFT (0x00000006u)
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL6_RESETVAL (0x00000000u)
/*----SETFAL6 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL6_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG23_SETFAL5_MASK (0x00000020u)
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL5_SHIFT (0x00000005u)
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL5_RESETVAL (0x00000000u)
/*----SETFAL5 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL5_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG23_SETFAL4_MASK (0x00000010u)
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL4_SHIFT (0x00000004u)
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL4_RESETVAL (0x00000000u)
/*----SETFAL4 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL4_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG23_SETFAL3_MASK (0x00000008u)
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL3_SHIFT (0x00000003u)
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL3_RESETVAL (0x00000000u)
/*----SETFAL3 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL3_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG23_SETFAL2_MASK (0x00000004u)
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL2_SHIFT (0x00000002u)
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL2_RESETVAL (0x00000000u)
/*----SETFAL2 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL2_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG23_SETFAL1_MASK (0x00000002u)
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL1_SHIFT (0x00000001u)
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL1_RESETVAL (0x00000000u)
/*----SETFAL1 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL1_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG23_SETFAL0_MASK (0x00000001u)
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL0_SHIFT (0x00000000u)
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL0_RESETVAL (0x00000000u)
/*----SETFAL0 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG23_SETFAL0_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG23_RESETVAL (0x00000000u)

/* CLR_FAL_TRIG23 */

#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL31_MASK (0x80000000u)
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL31_SHIFT (0x0000001Fu)
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL31_RESETVAL (0x00000000u)
/*----CLRFAL31 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL31_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL30_MASK (0x40000000u)
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL30_SHIFT (0x0000001Eu)
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL30_RESETVAL (0x00000000u)
/*----CLRFAL30 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL30_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL29_MASK (0x20000000u)
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL29_SHIFT (0x0000001Du)
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL29_RESETVAL (0x00000000u)
/*----CLRFAL29 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL29_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL28_MASK (0x10000000u)
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL28_SHIFT (0x0000001Cu)
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL28_RESETVAL (0x00000000u)
/*----CLRFAL28 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL28_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL27_MASK (0x08000000u)
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL27_SHIFT (0x0000001Bu)
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL27_RESETVAL (0x00000000u)
/*----CLRFAL27 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL27_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL26_MASK (0x04000000u)
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL26_SHIFT (0x0000001Au)
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL26_RESETVAL (0x00000000u)
/*----CLRFAL26 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL26_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL25_MASK (0x02000000u)
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL25_SHIFT (0x00000019u)
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL25_RESETVAL (0x00000000u)
/*----CLRFAL25 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL25_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL24_MASK (0x01000000u)
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL24_SHIFT (0x00000018u)
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL24_RESETVAL (0x00000000u)
/*----CLRFAL24 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL24_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL23_MASK (0x00800000u)
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL23_SHIFT (0x00000017u)
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL23_RESETVAL (0x00000000u)
/*----CLRFAL23 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL23_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL22_MASK (0x00400000u)
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL22_SHIFT (0x00000016u)
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL22_RESETVAL (0x00000000u)
/*----CLRFAL22 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL22_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL21_MASK (0x00200000u)
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL21_SHIFT (0x00000015u)
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL21_RESETVAL (0x00000000u)
/*----CLRFAL21 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL21_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL20_MASK (0x00100000u)
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL20_SHIFT (0x00000014u)
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL20_RESETVAL (0x00000000u)
/*----CLRFAL20 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL20_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL19_MASK (0x00080000u)
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL19_SHIFT (0x00000013u)
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL19_RESETVAL (0x00000000u)
/*----CLRFAL19 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL19_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL18_MASK (0x00040000u)
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL18_SHIFT (0x00000012u)
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL18_RESETVAL (0x00000000u)
/*----CLRFAL18 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL18_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL17_MASK (0x00020000u)
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL17_SHIFT (0x00000011u)
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL17_RESETVAL (0x00000000u)
/*----CLRFAL17 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL17_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL16_MASK (0x00010000u)
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL16_SHIFT (0x00000010u)
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL16_RESETVAL (0x00000000u)
/*----CLRFAL16 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL16_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL15_MASK (0x00008000u)
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL15_SHIFT (0x0000000Fu)
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL15_RESETVAL (0x00000000u)
/*----CLRFAL15 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL15_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL14_MASK (0x00004000u)
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL14_SHIFT (0x0000000Eu)
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL14_RESETVAL (0x00000000u)
/*----CLRFAL14 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL14_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL13_MASK (0x00002000u)
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL13_SHIFT (0x0000000Du)
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL13_RESETVAL (0x00000000u)
/*----CLRFAL13 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL13_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL12_MASK (0x00001000u)
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL12_SHIFT (0x0000000Cu)
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL12_RESETVAL (0x00000000u)
/*----CLRFAL12 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL12_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL11_MASK (0x00000800u)
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL11_SHIFT (0x0000000Bu)
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL11_RESETVAL (0x00000000u)
/*----CLRFAL11 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL11_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL10_MASK (0x00000400u)
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL10_SHIFT (0x0000000Au)
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL10_RESETVAL (0x00000000u)
/*----CLRFAL10 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL10_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL9_MASK (0x00000200u)
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL9_SHIFT (0x00000009u)
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL9_RESETVAL (0x00000000u)
/*----CLRFAL9 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL9_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL8_MASK (0x00000100u)
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL8_SHIFT (0x00000008u)
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL8_RESETVAL (0x00000000u)
/*----CLRFAL8 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL8_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL7_MASK (0x00000080u)
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL7_SHIFT (0x00000007u)
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL7_RESETVAL (0x00000000u)
/*----CLRFAL7 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL7_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL6_MASK (0x00000040u)
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL6_SHIFT (0x00000006u)
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL6_RESETVAL (0x00000000u)
/*----CLRFAL6 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL6_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL5_MASK (0x00000020u)
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL5_SHIFT (0x00000005u)
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL5_RESETVAL (0x00000000u)
/*----CLRFAL5 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL5_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL4_MASK (0x00000010u)
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL4_SHIFT (0x00000004u)
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL4_RESETVAL (0x00000000u)
/*----CLRFAL4 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL4_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL3_MASK (0x00000008u)
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL3_SHIFT (0x00000003u)
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL3_RESETVAL (0x00000000u)
/*----CLRFAL3 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL3_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL2_MASK (0x00000004u)
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL2_SHIFT (0x00000002u)
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL2_RESETVAL (0x00000000u)
/*----CLRFAL2 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL2_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL1_MASK (0x00000002u)
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL1_SHIFT (0x00000001u)
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL1_RESETVAL (0x00000000u)
/*----CLRFAL1 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL1_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL0_MASK (0x00000001u)
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL0_SHIFT (0x00000000u)
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL0_RESETVAL (0x00000000u)
/*----CLRFAL0 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG23_CLRFAL0_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_FAL_TRIG23_RESETVAL (0x00000000u)

/* INTSTAT23 */

#define CSL_GPIO_INTSTAT23_STAT31_MASK (0x80000000u)
#define CSL_GPIO_INTSTAT23_STAT31_SHIFT (0x0000001Fu)
#define CSL_GPIO_INTSTAT23_STAT31_RESETVAL (0x00000000u)
/*----STAT31 Tokens----*/
#define CSL_GPIO_INTSTAT23_STAT31_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT23_STAT31_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT23_STAT30_MASK (0x40000000u)
#define CSL_GPIO_INTSTAT23_STAT30_SHIFT (0x0000001Eu)
#define CSL_GPIO_INTSTAT23_STAT30_RESETVAL (0x00000000u)
/*----STAT30 Tokens----*/
#define CSL_GPIO_INTSTAT23_STAT30_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT23_STAT30_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT23_STAT29_MASK (0x20000000u)
#define CSL_GPIO_INTSTAT23_STAT29_SHIFT (0x0000001Du)
#define CSL_GPIO_INTSTAT23_STAT29_RESETVAL (0x00000000u)
/*----STAT29 Tokens----*/
#define CSL_GPIO_INTSTAT23_STAT29_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT23_STAT29_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT23_STAT28_MASK (0x10000000u)
#define CSL_GPIO_INTSTAT23_STAT28_SHIFT (0x0000001Cu)
#define CSL_GPIO_INTSTAT23_STAT28_RESETVAL (0x00000000u)
/*----STAT28 Tokens----*/
#define CSL_GPIO_INTSTAT23_STAT28_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT23_STAT28_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT23_STAT27_MASK (0x08000000u)
#define CSL_GPIO_INTSTAT23_STAT27_SHIFT (0x0000001Bu)
#define CSL_GPIO_INTSTAT23_STAT27_RESETVAL (0x00000000u)
/*----STAT27 Tokens----*/
#define CSL_GPIO_INTSTAT23_STAT27_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT23_STAT27_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT23_STAT26_MASK (0x04000000u)
#define CSL_GPIO_INTSTAT23_STAT26_SHIFT (0x0000001Au)
#define CSL_GPIO_INTSTAT23_STAT26_RESETVAL (0x00000000u)
/*----STAT26 Tokens----*/
#define CSL_GPIO_INTSTAT23_STAT26_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT23_STAT26_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT23_STAT25_MASK (0x02000000u)
#define CSL_GPIO_INTSTAT23_STAT25_SHIFT (0x00000019u)
#define CSL_GPIO_INTSTAT23_STAT25_RESETVAL (0x00000000u)
/*----STAT25 Tokens----*/
#define CSL_GPIO_INTSTAT23_STAT25_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT23_STAT25_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT23_STAT24_MASK (0x01000000u)
#define CSL_GPIO_INTSTAT23_STAT24_SHIFT (0x00000018u)
#define CSL_GPIO_INTSTAT23_STAT24_RESETVAL (0x00000000u)
/*----STAT24 Tokens----*/
#define CSL_GPIO_INTSTAT23_STAT24_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT23_STAT24_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT23_STAT23_MASK (0x00800000u)
#define CSL_GPIO_INTSTAT23_STAT23_SHIFT (0x00000017u)
#define CSL_GPIO_INTSTAT23_STAT23_RESETVAL (0x00000000u)
/*----STAT23 Tokens----*/
#define CSL_GPIO_INTSTAT23_STAT23_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT23_STAT23_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT23_STAT22_MASK (0x00400000u)
#define CSL_GPIO_INTSTAT23_STAT22_SHIFT (0x00000016u)
#define CSL_GPIO_INTSTAT23_STAT22_RESETVAL (0x00000000u)
/*----STAT22 Tokens----*/
#define CSL_GPIO_INTSTAT23_STAT22_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT23_STAT22_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT23_STAT21_MASK (0x00200000u)
#define CSL_GPIO_INTSTAT23_STAT21_SHIFT (0x00000015u)
#define CSL_GPIO_INTSTAT23_STAT21_RESETVAL (0x00000000u)
/*----STAT21 Tokens----*/
#define CSL_GPIO_INTSTAT23_STAT21_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT23_STAT21_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT23_STAT20_MASK (0x00100000u)
#define CSL_GPIO_INTSTAT23_STAT20_SHIFT (0x00000014u)
#define CSL_GPIO_INTSTAT23_STAT20_RESETVAL (0x00000000u)
/*----STAT20 Tokens----*/
#define CSL_GPIO_INTSTAT23_STAT20_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT23_STAT20_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT23_STAT19_MASK (0x00080000u)
#define CSL_GPIO_INTSTAT23_STAT19_SHIFT (0x00000013u)
#define CSL_GPIO_INTSTAT23_STAT19_RESETVAL (0x00000000u)
/*----STAT19 Tokens----*/
#define CSL_GPIO_INTSTAT23_STAT19_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT23_STAT19_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT23_STAT18_MASK (0x00040000u)
#define CSL_GPIO_INTSTAT23_STAT18_SHIFT (0x00000012u)
#define CSL_GPIO_INTSTAT23_STAT18_RESETVAL (0x00000000u)
/*----STAT18 Tokens----*/
#define CSL_GPIO_INTSTAT23_STAT18_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT23_STAT18_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT23_STAT17_MASK (0x00020000u)
#define CSL_GPIO_INTSTAT23_STAT17_SHIFT (0x00000011u)
#define CSL_GPIO_INTSTAT23_STAT17_RESETVAL (0x00000000u)
/*----STAT17 Tokens----*/
#define CSL_GPIO_INTSTAT23_STAT17_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT23_STAT17_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT23_STAT16_MASK (0x00010000u)
#define CSL_GPIO_INTSTAT23_STAT16_SHIFT (0x00000010u)
#define CSL_GPIO_INTSTAT23_STAT16_RESETVAL (0x00000000u)
/*----STAT16 Tokens----*/
#define CSL_GPIO_INTSTAT23_STAT16_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT23_STAT16_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT23_STAT15_MASK (0x00008000u)
#define CSL_GPIO_INTSTAT23_STAT15_SHIFT (0x0000000Fu)
#define CSL_GPIO_INTSTAT23_STAT15_RESETVAL (0x00000000u)
/*----STAT15 Tokens----*/
#define CSL_GPIO_INTSTAT23_STAT15_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT23_STAT15_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT23_STAT14_MASK (0x00004000u)
#define CSL_GPIO_INTSTAT23_STAT14_SHIFT (0x0000000Eu)
#define CSL_GPIO_INTSTAT23_STAT14_RESETVAL (0x00000000u)
/*----STAT14 Tokens----*/
#define CSL_GPIO_INTSTAT23_STAT14_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT23_STAT14_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT23_STAT13_MASK (0x00002000u)
#define CSL_GPIO_INTSTAT23_STAT13_SHIFT (0x0000000Du)
#define CSL_GPIO_INTSTAT23_STAT13_RESETVAL (0x00000000u)
/*----STAT13 Tokens----*/
#define CSL_GPIO_INTSTAT23_STAT13_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT23_STAT13_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT23_STAT12_MASK (0x00001000u)
#define CSL_GPIO_INTSTAT23_STAT12_SHIFT (0x0000000Cu)
#define CSL_GPIO_INTSTAT23_STAT12_RESETVAL (0x00000000u)
/*----STAT12 Tokens----*/
#define CSL_GPIO_INTSTAT23_STAT12_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT23_STAT12_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT23_STAT11_MASK (0x00000800u)
#define CSL_GPIO_INTSTAT23_STAT11_SHIFT (0x0000000Bu)
#define CSL_GPIO_INTSTAT23_STAT11_RESETVAL (0x00000000u)
/*----STAT11 Tokens----*/
#define CSL_GPIO_INTSTAT23_STAT11_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT23_STAT11_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT23_STAT10_MASK (0x00000400u)
#define CSL_GPIO_INTSTAT23_STAT10_SHIFT (0x0000000Au)
#define CSL_GPIO_INTSTAT23_STAT10_RESETVAL (0x00000000u)
/*----STAT10 Tokens----*/
#define CSL_GPIO_INTSTAT23_STAT10_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT23_STAT10_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT23_STAT9_MASK (0x00000200u)
#define CSL_GPIO_INTSTAT23_STAT9_SHIFT (0x00000009u)
#define CSL_GPIO_INTSTAT23_STAT9_RESETVAL (0x00000000u)
/*----STAT9 Tokens----*/
#define CSL_GPIO_INTSTAT23_STAT9_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT23_STAT9_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT23_STAT8_MASK (0x00000100u)
#define CSL_GPIO_INTSTAT23_STAT8_SHIFT (0x00000008u)
#define CSL_GPIO_INTSTAT23_STAT8_RESETVAL (0x00000000u)
/*----STAT8 Tokens----*/
#define CSL_GPIO_INTSTAT23_STAT8_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT23_STAT8_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT23_STAT7_MASK (0x00000080u)
#define CSL_GPIO_INTSTAT23_STAT7_SHIFT (0x00000007u)
#define CSL_GPIO_INTSTAT23_STAT7_RESETVAL (0x00000000u)
/*----STAT7 Tokens----*/
#define CSL_GPIO_INTSTAT23_STAT7_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT23_STAT7_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT23_STAT6_MASK (0x00000040u)
#define CSL_GPIO_INTSTAT23_STAT6_SHIFT (0x00000006u)
#define CSL_GPIO_INTSTAT23_STAT6_RESETVAL (0x00000000u)
/*----STAT6 Tokens----*/
#define CSL_GPIO_INTSTAT23_STAT6_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT23_STAT6_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT23_STAT5_MASK (0x00000020u)
#define CSL_GPIO_INTSTAT23_STAT5_SHIFT (0x00000005u)
#define CSL_GPIO_INTSTAT23_STAT5_RESETVAL (0x00000000u)
/*----STAT5 Tokens----*/
#define CSL_GPIO_INTSTAT23_STAT5_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT23_STAT5_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT23_STAT4_MASK (0x00000010u)
#define CSL_GPIO_INTSTAT23_STAT4_SHIFT (0x00000004u)
#define CSL_GPIO_INTSTAT23_STAT4_RESETVAL (0x00000000u)
/*----STAT4 Tokens----*/
#define CSL_GPIO_INTSTAT23_STAT4_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT23_STAT4_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT23_STAT3_MASK (0x00000008u)
#define CSL_GPIO_INTSTAT23_STAT3_SHIFT (0x00000003u)
#define CSL_GPIO_INTSTAT23_STAT3_RESETVAL (0x00000000u)
/*----STAT3 Tokens----*/
#define CSL_GPIO_INTSTAT23_STAT3_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT23_STAT3_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT23_STAT2_MASK (0x00000004u)
#define CSL_GPIO_INTSTAT23_STAT2_SHIFT (0x00000002u)
#define CSL_GPIO_INTSTAT23_STAT2_RESETVAL (0x00000000u)
/*----STAT2 Tokens----*/
#define CSL_GPIO_INTSTAT23_STAT2_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT23_STAT2_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT23_STAT1_MASK (0x00000002u)
#define CSL_GPIO_INTSTAT23_STAT1_SHIFT (0x00000001u)
#define CSL_GPIO_INTSTAT23_STAT1_RESETVAL (0x00000000u)
/*----STAT1 Tokens----*/
#define CSL_GPIO_INTSTAT23_STAT1_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT23_STAT1_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT23_STAT0_MASK (0x00000001u)
#define CSL_GPIO_INTSTAT23_STAT0_SHIFT (0x00000000u)
#define CSL_GPIO_INTSTAT23_STAT0_RESETVAL (0x00000000u)
/*----STAT0 Tokens----*/
#define CSL_GPIO_INTSTAT23_STAT0_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT23_STAT0_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT23_RESETVAL (0x00000000u)

/* DIR45 */

#define CSL_GPIO_DIR45_DIR31_MASK (0x80000000u)
#define CSL_GPIO_DIR45_DIR31_SHIFT (0x0000001Fu)
#define CSL_GPIO_DIR45_DIR31_RESETVAL (0x00000001u)
/*----DIR31 Tokens----*/
#define CSL_GPIO_DIR45_DIR31_OUT (0x00000000u)
#define CSL_GPIO_DIR45_DIR31_IN (0x00000001u)

#define CSL_GPIO_DIR45_DIR30_MASK (0x40000000u)
#define CSL_GPIO_DIR45_DIR30_SHIFT (0x0000001Eu)
#define CSL_GPIO_DIR45_DIR30_RESETVAL (0x00000001u)
/*----DIR30 Tokens----*/
#define CSL_GPIO_DIR45_DIR30_OUT (0x00000000u)
#define CSL_GPIO_DIR45_DIR30_IN (0x00000001u)

#define CSL_GPIO_DIR45_DIR29_MASK (0x20000000u)
#define CSL_GPIO_DIR45_DIR29_SHIFT (0x0000001Du)
#define CSL_GPIO_DIR45_DIR29_RESETVAL (0x00000001u)
/*----DIR29 Tokens----*/
#define CSL_GPIO_DIR45_DIR29_OUT (0x00000000u)
#define CSL_GPIO_DIR45_DIR29_IN (0x00000001u)

#define CSL_GPIO_DIR45_DIR28_MASK (0x10000000u)
#define CSL_GPIO_DIR45_DIR28_SHIFT (0x0000001Cu)
#define CSL_GPIO_DIR45_DIR28_RESETVAL (0x00000001u)
/*----DIR28 Tokens----*/
#define CSL_GPIO_DIR45_DIR28_OUT (0x00000000u)
#define CSL_GPIO_DIR45_DIR28_IN (0x00000001u)

#define CSL_GPIO_DIR45_DIR27_MASK (0x08000000u)
#define CSL_GPIO_DIR45_DIR27_SHIFT (0x0000001Bu)
#define CSL_GPIO_DIR45_DIR27_RESETVAL (0x00000001u)
/*----DIR27 Tokens----*/
#define CSL_GPIO_DIR45_DIR27_OUT (0x00000000u)
#define CSL_GPIO_DIR45_DIR27_IN (0x00000001u)

#define CSL_GPIO_DIR45_DIR26_MASK (0x04000000u)
#define CSL_GPIO_DIR45_DIR26_SHIFT (0x0000001Au)
#define CSL_GPIO_DIR45_DIR26_RESETVAL (0x00000001u)
/*----DIR26 Tokens----*/
#define CSL_GPIO_DIR45_DIR26_OUT (0x00000000u)
#define CSL_GPIO_DIR45_DIR26_IN (0x00000001u)

#define CSL_GPIO_DIR45_DIR25_MASK (0x02000000u)
#define CSL_GPIO_DIR45_DIR25_SHIFT (0x00000019u)
#define CSL_GPIO_DIR45_DIR25_RESETVAL (0x00000001u)
/*----DIR25 Tokens----*/
#define CSL_GPIO_DIR45_DIR25_OUT (0x00000000u)
#define CSL_GPIO_DIR45_DIR25_IN (0x00000001u)

#define CSL_GPIO_DIR45_DIR24_MASK (0x01000000u)
#define CSL_GPIO_DIR45_DIR24_SHIFT (0x00000018u)
#define CSL_GPIO_DIR45_DIR24_RESETVAL (0x00000001u)
/*----DIR24 Tokens----*/
#define CSL_GPIO_DIR45_DIR24_OUT (0x00000000u)
#define CSL_GPIO_DIR45_DIR24_IN (0x00000001u)

#define CSL_GPIO_DIR45_DIR23_MASK (0x00800000u)
#define CSL_GPIO_DIR45_DIR23_SHIFT (0x00000017u)
#define CSL_GPIO_DIR45_DIR23_RESETVAL (0x00000001u)
/*----DIR23 Tokens----*/
#define CSL_GPIO_DIR45_DIR23_OUT (0x00000000u)
#define CSL_GPIO_DIR45_DIR23_IN (0x00000001u)

#define CSL_GPIO_DIR45_DIR22_MASK (0x00400000u)
#define CSL_GPIO_DIR45_DIR22_SHIFT (0x00000016u)
#define CSL_GPIO_DIR45_DIR22_RESETVAL (0x00000001u)
/*----DIR22 Tokens----*/
#define CSL_GPIO_DIR45_DIR22_OUT (0x00000000u)
#define CSL_GPIO_DIR45_DIR22_IN (0x00000001u)

#define CSL_GPIO_DIR45_DIR21_MASK (0x00200000u)
#define CSL_GPIO_DIR45_DIR21_SHIFT (0x00000015u)
#define CSL_GPIO_DIR45_DIR21_RESETVAL (0x00000001u)
/*----DIR21 Tokens----*/
#define CSL_GPIO_DIR45_DIR21_OUT (0x00000000u)
#define CSL_GPIO_DIR45_DIR21_IN (0x00000001u)

#define CSL_GPIO_DIR45_DIR20_MASK (0x00100000u)
#define CSL_GPIO_DIR45_DIR20_SHIFT (0x00000014u)
#define CSL_GPIO_DIR45_DIR20_RESETVAL (0x00000001u)
/*----DIR20 Tokens----*/
#define CSL_GPIO_DIR45_DIR20_OUT (0x00000000u)
#define CSL_GPIO_DIR45_DIR20_IN (0x00000001u)

#define CSL_GPIO_DIR45_DIR19_MASK (0x00080000u)
#define CSL_GPIO_DIR45_DIR19_SHIFT (0x00000013u)
#define CSL_GPIO_DIR45_DIR19_RESETVAL (0x00000001u)
/*----DIR19 Tokens----*/
#define CSL_GPIO_DIR45_DIR19_OUT (0x00000000u)
#define CSL_GPIO_DIR45_DIR19_IN (0x00000001u)

#define CSL_GPIO_DIR45_DIR18_MASK (0x00040000u)
#define CSL_GPIO_DIR45_DIR18_SHIFT (0x00000012u)
#define CSL_GPIO_DIR45_DIR18_RESETVAL (0x00000001u)
/*----DIR18 Tokens----*/
#define CSL_GPIO_DIR45_DIR18_OUT (0x00000000u)
#define CSL_GPIO_DIR45_DIR18_IN (0x00000001u)

#define CSL_GPIO_DIR45_DIR17_MASK (0x00020000u)
#define CSL_GPIO_DIR45_DIR17_SHIFT (0x00000011u)
#define CSL_GPIO_DIR45_DIR17_RESETVAL (0x00000001u)
/*----DIR17 Tokens----*/
#define CSL_GPIO_DIR45_DIR17_OUT (0x00000000u)
#define CSL_GPIO_DIR45_DIR17_IN (0x00000001u)

#define CSL_GPIO_DIR45_DIR16_MASK (0x00010000u)
#define CSL_GPIO_DIR45_DIR16_SHIFT (0x00000010u)
#define CSL_GPIO_DIR45_DIR16_RESETVAL (0x00000001u)
/*----DIR16 Tokens----*/
#define CSL_GPIO_DIR45_DIR16_OUT (0x00000000u)
#define CSL_GPIO_DIR45_DIR16_IN (0x00000001u)

#define CSL_GPIO_DIR45_DIR15_MASK (0x00008000u)
#define CSL_GPIO_DIR45_DIR15_SHIFT (0x0000000Fu)
#define CSL_GPIO_DIR45_DIR15_RESETVAL (0x00000001u)
/*----DIR15 Tokens----*/
#define CSL_GPIO_DIR45_DIR15_OUT (0x00000000u)
#define CSL_GPIO_DIR45_DIR15_IN (0x00000001u)

#define CSL_GPIO_DIR45_DIR14_MASK (0x00004000u)
#define CSL_GPIO_DIR45_DIR14_SHIFT (0x0000000Eu)
#define CSL_GPIO_DIR45_DIR14_RESETVAL (0x00000001u)
/*----DIR14 Tokens----*/
#define CSL_GPIO_DIR45_DIR14_OUT (0x00000000u)
#define CSL_GPIO_DIR45_DIR14_IN (0x00000001u)

#define CSL_GPIO_DIR45_DIR13_MASK (0x00002000u)
#define CSL_GPIO_DIR45_DIR13_SHIFT (0x0000000Du)
#define CSL_GPIO_DIR45_DIR13_RESETVAL (0x00000001u)
/*----DIR13 Tokens----*/
#define CSL_GPIO_DIR45_DIR13_OUT (0x00000000u)
#define CSL_GPIO_DIR45_DIR13_IN (0x00000001u)

#define CSL_GPIO_DIR45_DIR12_MASK (0x00001000u)
#define CSL_GPIO_DIR45_DIR12_SHIFT (0x0000000Cu)
#define CSL_GPIO_DIR45_DIR12_RESETVAL (0x00000001u)
/*----DIR12 Tokens----*/
#define CSL_GPIO_DIR45_DIR12_OUT (0x00000000u)
#define CSL_GPIO_DIR45_DIR12_IN (0x00000001u)

#define CSL_GPIO_DIR45_DIR11_MASK (0x00000800u)
#define CSL_GPIO_DIR45_DIR11_SHIFT (0x0000000Bu)
#define CSL_GPIO_DIR45_DIR11_RESETVAL (0x00000001u)
/*----DIR11 Tokens----*/
#define CSL_GPIO_DIR45_DIR11_OUT (0x00000000u)
#define CSL_GPIO_DIR45_DIR11_IN (0x00000001u)

#define CSL_GPIO_DIR45_DIR10_MASK (0x00000400u)
#define CSL_GPIO_DIR45_DIR10_SHIFT (0x0000000Au)
#define CSL_GPIO_DIR45_DIR10_RESETVAL (0x00000001u)
/*----DIR10 Tokens----*/
#define CSL_GPIO_DIR45_DIR10_OUT (0x00000000u)
#define CSL_GPIO_DIR45_DIR10_IN (0x00000001u)

#define CSL_GPIO_DIR45_DIR9_MASK (0x00000200u)
#define CSL_GPIO_DIR45_DIR9_SHIFT (0x00000009u)
#define CSL_GPIO_DIR45_DIR9_RESETVAL (0x00000001u)
/*----DIR9 Tokens----*/
#define CSL_GPIO_DIR45_DIR9_OUT (0x00000000u)
#define CSL_GPIO_DIR45_DIR9_IN (0x00000001u)

#define CSL_GPIO_DIR45_DIR8_MASK (0x00000100u)
#define CSL_GPIO_DIR45_DIR8_SHIFT (0x00000008u)
#define CSL_GPIO_DIR45_DIR8_RESETVAL (0x00000001u)
/*----DIR8 Tokens----*/
#define CSL_GPIO_DIR45_DIR8_OUT (0x00000000u)
#define CSL_GPIO_DIR45_DIR8_IN (0x00000001u)

#define CSL_GPIO_DIR45_DIR7_MASK (0x00000080u)
#define CSL_GPIO_DIR45_DIR7_SHIFT (0x00000007u)
#define CSL_GPIO_DIR45_DIR7_RESETVAL (0x00000001u)
/*----DIR7 Tokens----*/
#define CSL_GPIO_DIR45_DIR7_OUT (0x00000000u)
#define CSL_GPIO_DIR45_DIR7_IN (0x00000001u)

#define CSL_GPIO_DIR45_DIR6_MASK (0x00000040u)
#define CSL_GPIO_DIR45_DIR6_SHIFT (0x00000006u)
#define CSL_GPIO_DIR45_DIR6_RESETVAL (0x00000001u)
/*----DIR6 Tokens----*/
#define CSL_GPIO_DIR45_DIR6_OUT (0x00000000u)
#define CSL_GPIO_DIR45_DIR6_IN (0x00000001u)

#define CSL_GPIO_DIR45_DIR5_MASK (0x00000020u)
#define CSL_GPIO_DIR45_DIR5_SHIFT (0x00000005u)
#define CSL_GPIO_DIR45_DIR5_RESETVAL (0x00000001u)
/*----DIR5 Tokens----*/
#define CSL_GPIO_DIR45_DIR5_OUT (0x00000000u)
#define CSL_GPIO_DIR45_DIR5_IN (0x00000001u)

#define CSL_GPIO_DIR45_DIR4_MASK (0x00000010u)
#define CSL_GPIO_DIR45_DIR4_SHIFT (0x00000004u)
#define CSL_GPIO_DIR45_DIR4_RESETVAL (0x00000001u)
/*----DIR4 Tokens----*/
#define CSL_GPIO_DIR45_DIR4_OUT (0x00000000u)
#define CSL_GPIO_DIR45_DIR4_IN (0x00000001u)

#define CSL_GPIO_DIR45_DIR3_MASK (0x00000008u)
#define CSL_GPIO_DIR45_DIR3_SHIFT (0x00000003u)
#define CSL_GPIO_DIR45_DIR3_RESETVAL (0x00000001u)
/*----DIR3 Tokens----*/
#define CSL_GPIO_DIR45_DIR3_OUT (0x00000000u)
#define CSL_GPIO_DIR45_DIR3_IN (0x00000001u)

#define CSL_GPIO_DIR45_DIR2_MASK (0x00000004u)
#define CSL_GPIO_DIR45_DIR2_SHIFT (0x00000002u)
#define CSL_GPIO_DIR45_DIR2_RESETVAL (0x00000001u)
/*----DIR2 Tokens----*/
#define CSL_GPIO_DIR45_DIR2_OUT (0x00000000u)
#define CSL_GPIO_DIR45_DIR2_IN (0x00000001u)

#define CSL_GPIO_DIR45_DIR1_MASK (0x00000002u)
#define CSL_GPIO_DIR45_DIR1_SHIFT (0x00000001u)
#define CSL_GPIO_DIR45_DIR1_RESETVAL (0x00000001u)
/*----DIR1 Tokens----*/
#define CSL_GPIO_DIR45_DIR1_OUT (0x00000000u)
#define CSL_GPIO_DIR45_DIR1_IN (0x00000001u)

#define CSL_GPIO_DIR45_DIR0_MASK (0x00000001u)
#define CSL_GPIO_DIR45_DIR0_SHIFT (0x00000000u)
#define CSL_GPIO_DIR45_DIR0_RESETVAL (0x00000001u)
/*----DIR0 Tokens----*/
#define CSL_GPIO_DIR45_DIR0_OUT (0x00000000u)
#define CSL_GPIO_DIR45_DIR0_IN (0x00000001u)

#define CSL_GPIO_DIR45_RESETVAL (0xFFFFFFFFu)

/* OUT_DATA45 */

#define CSL_GPIO_OUT_DATA45_OUT31_MASK (0x80000000u)
#define CSL_GPIO_OUT_DATA45_OUT31_SHIFT (0x0000001Fu)
#define CSL_GPIO_OUT_DATA45_OUT31_RESETVAL (0x00000000u)
/*----OUT31 Tokens----*/
#define CSL_GPIO_OUT_DATA45_OUT31_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA45_OUT31_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA45_OUT30_MASK (0x40000000u)
#define CSL_GPIO_OUT_DATA45_OUT30_SHIFT (0x0000001Eu)
#define CSL_GPIO_OUT_DATA45_OUT30_RESETVAL (0x00000000u)
/*----OUT30 Tokens----*/
#define CSL_GPIO_OUT_DATA45_OUT30_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA45_OUT30_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA45_OUT29_MASK (0x20000000u)
#define CSL_GPIO_OUT_DATA45_OUT29_SHIFT (0x0000001Du)
#define CSL_GPIO_OUT_DATA45_OUT29_RESETVAL (0x00000000u)
/*----OUT29 Tokens----*/
#define CSL_GPIO_OUT_DATA45_OUT29_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA45_OUT29_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA45_OUT28_MASK (0x10000000u)
#define CSL_GPIO_OUT_DATA45_OUT28_SHIFT (0x0000001Cu)
#define CSL_GPIO_OUT_DATA45_OUT28_RESETVAL (0x00000000u)
/*----OUT28 Tokens----*/
#define CSL_GPIO_OUT_DATA45_OUT28_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA45_OUT28_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA45_OUT27_MASK (0x08000000u)
#define CSL_GPIO_OUT_DATA45_OUT27_SHIFT (0x0000001Bu)
#define CSL_GPIO_OUT_DATA45_OUT27_RESETVAL (0x00000000u)
/*----OUT27 Tokens----*/
#define CSL_GPIO_OUT_DATA45_OUT27_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA45_OUT27_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA45_OUT26_MASK (0x04000000u)
#define CSL_GPIO_OUT_DATA45_OUT26_SHIFT (0x0000001Au)
#define CSL_GPIO_OUT_DATA45_OUT26_RESETVAL (0x00000000u)
/*----OUT26 Tokens----*/
#define CSL_GPIO_OUT_DATA45_OUT26_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA45_OUT26_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA45_OUT25_MASK (0x02000000u)
#define CSL_GPIO_OUT_DATA45_OUT25_SHIFT (0x00000019u)
#define CSL_GPIO_OUT_DATA45_OUT25_RESETVAL (0x00000000u)
/*----OUT25 Tokens----*/
#define CSL_GPIO_OUT_DATA45_OUT25_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA45_OUT25_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA45_OUT24_MASK (0x01000000u)
#define CSL_GPIO_OUT_DATA45_OUT24_SHIFT (0x00000018u)
#define CSL_GPIO_OUT_DATA45_OUT24_RESETVAL (0x00000000u)
/*----OUT24 Tokens----*/
#define CSL_GPIO_OUT_DATA45_OUT24_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA45_OUT24_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA45_OUT23_MASK (0x00800000u)
#define CSL_GPIO_OUT_DATA45_OUT23_SHIFT (0x00000017u)
#define CSL_GPIO_OUT_DATA45_OUT23_RESETVAL (0x00000000u)
/*----OUT23 Tokens----*/
#define CSL_GPIO_OUT_DATA45_OUT23_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA45_OUT23_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA45_OUT22_MASK (0x00400000u)
#define CSL_GPIO_OUT_DATA45_OUT22_SHIFT (0x00000016u)
#define CSL_GPIO_OUT_DATA45_OUT22_RESETVAL (0x00000000u)
/*----OUT22 Tokens----*/
#define CSL_GPIO_OUT_DATA45_OUT22_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA45_OUT22_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA45_OUT21_MASK (0x00200000u)
#define CSL_GPIO_OUT_DATA45_OUT21_SHIFT (0x00000015u)
#define CSL_GPIO_OUT_DATA45_OUT21_RESETVAL (0x00000000u)
/*----OUT21 Tokens----*/
#define CSL_GPIO_OUT_DATA45_OUT21_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA45_OUT21_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA45_OUT20_MASK (0x00100000u)
#define CSL_GPIO_OUT_DATA45_OUT20_SHIFT (0x00000014u)
#define CSL_GPIO_OUT_DATA45_OUT20_RESETVAL (0x00000000u)
/*----OUT20 Tokens----*/
#define CSL_GPIO_OUT_DATA45_OUT20_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA45_OUT20_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA45_OUT19_MASK (0x00080000u)
#define CSL_GPIO_OUT_DATA45_OUT19_SHIFT (0x00000013u)
#define CSL_GPIO_OUT_DATA45_OUT19_RESETVAL (0x00000000u)
/*----OUT19 Tokens----*/
#define CSL_GPIO_OUT_DATA45_OUT19_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA45_OUT19_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA45_OUT18_MASK (0x00040000u)
#define CSL_GPIO_OUT_DATA45_OUT18_SHIFT (0x00000012u)
#define CSL_GPIO_OUT_DATA45_OUT18_RESETVAL (0x00000000u)
/*----OUT18 Tokens----*/
#define CSL_GPIO_OUT_DATA45_OUT18_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA45_OUT18_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA45_OUT17_MASK (0x00020000u)
#define CSL_GPIO_OUT_DATA45_OUT17_SHIFT (0x00000011u)
#define CSL_GPIO_OUT_DATA45_OUT17_RESETVAL (0x00000000u)
/*----OUT17 Tokens----*/
#define CSL_GPIO_OUT_DATA45_OUT17_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA45_OUT17_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA45_OUT16_MASK (0x00010000u)
#define CSL_GPIO_OUT_DATA45_OUT16_SHIFT (0x00000010u)
#define CSL_GPIO_OUT_DATA45_OUT16_RESETVAL (0x00000000u)
/*----OUT16 Tokens----*/
#define CSL_GPIO_OUT_DATA45_OUT16_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA45_OUT16_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA45_OUT15_MASK (0x00008000u)
#define CSL_GPIO_OUT_DATA45_OUT15_SHIFT (0x0000000Fu)
#define CSL_GPIO_OUT_DATA45_OUT15_RESETVAL (0x00000000u)
/*----OUT15 Tokens----*/
#define CSL_GPIO_OUT_DATA45_OUT15_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA45_OUT15_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA45_OUT14_MASK (0x00004000u)
#define CSL_GPIO_OUT_DATA45_OUT14_SHIFT (0x0000000Eu)
#define CSL_GPIO_OUT_DATA45_OUT14_RESETVAL (0x00000000u)
/*----OUT14 Tokens----*/
#define CSL_GPIO_OUT_DATA45_OUT14_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA45_OUT14_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA45_OUT13_MASK (0x00002000u)
#define CSL_GPIO_OUT_DATA45_OUT13_SHIFT (0x0000000Du)
#define CSL_GPIO_OUT_DATA45_OUT13_RESETVAL (0x00000000u)
/*----OUT13 Tokens----*/
#define CSL_GPIO_OUT_DATA45_OUT13_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA45_OUT13_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA45_OUT12_MASK (0x00001000u)
#define CSL_GPIO_OUT_DATA45_OUT12_SHIFT (0x0000000Cu)
#define CSL_GPIO_OUT_DATA45_OUT12_RESETVAL (0x00000000u)
/*----OUT12 Tokens----*/
#define CSL_GPIO_OUT_DATA45_OUT12_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA45_OUT12_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA45_OUT11_MASK (0x00000800u)
#define CSL_GPIO_OUT_DATA45_OUT11_SHIFT (0x0000000Bu)
#define CSL_GPIO_OUT_DATA45_OUT11_RESETVAL (0x00000000u)
/*----OUT11 Tokens----*/
#define CSL_GPIO_OUT_DATA45_OUT11_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA45_OUT11_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA45_OUT10_MASK (0x00000400u)
#define CSL_GPIO_OUT_DATA45_OUT10_SHIFT (0x0000000Au)
#define CSL_GPIO_OUT_DATA45_OUT10_RESETVAL (0x00000000u)
/*----OUT10 Tokens----*/
#define CSL_GPIO_OUT_DATA45_OUT10_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA45_OUT10_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA45_OUT9_MASK (0x00000200u)
#define CSL_GPIO_OUT_DATA45_OUT9_SHIFT (0x00000009u)
#define CSL_GPIO_OUT_DATA45_OUT9_RESETVAL (0x00000000u)
/*----OUT9 Tokens----*/
#define CSL_GPIO_OUT_DATA45_OUT9_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA45_OUT9_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA45_OUT8_MASK (0x00000100u)
#define CSL_GPIO_OUT_DATA45_OUT8_SHIFT (0x00000008u)
#define CSL_GPIO_OUT_DATA45_OUT8_RESETVAL (0x00000000u)
/*----OUT8 Tokens----*/
#define CSL_GPIO_OUT_DATA45_OUT8_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA45_OUT8_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA45_OUT7_MASK (0x00000080u)
#define CSL_GPIO_OUT_DATA45_OUT7_SHIFT (0x00000007u)
#define CSL_GPIO_OUT_DATA45_OUT7_RESETVAL (0x00000000u)
/*----OUT7 Tokens----*/
#define CSL_GPIO_OUT_DATA45_OUT7_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA45_OUT7_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA45_OUT6_MASK (0x00000040u)
#define CSL_GPIO_OUT_DATA45_OUT6_SHIFT (0x00000006u)
#define CSL_GPIO_OUT_DATA45_OUT6_RESETVAL (0x00000000u)
/*----OUT6 Tokens----*/
#define CSL_GPIO_OUT_DATA45_OUT6_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA45_OUT6_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA45_OUT5_MASK (0x00000020u)
#define CSL_GPIO_OUT_DATA45_OUT5_SHIFT (0x00000005u)
#define CSL_GPIO_OUT_DATA45_OUT5_RESETVAL (0x00000000u)
/*----OUT5 Tokens----*/
#define CSL_GPIO_OUT_DATA45_OUT5_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA45_OUT5_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA45_OUT4_MASK (0x00000010u)
#define CSL_GPIO_OUT_DATA45_OUT4_SHIFT (0x00000004u)
#define CSL_GPIO_OUT_DATA45_OUT4_RESETVAL (0x00000000u)
/*----OUT4 Tokens----*/
#define CSL_GPIO_OUT_DATA45_OUT4_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA45_OUT4_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA45_OUT3_MASK (0x00000008u)
#define CSL_GPIO_OUT_DATA45_OUT3_SHIFT (0x00000003u)
#define CSL_GPIO_OUT_DATA45_OUT3_RESETVAL (0x00000000u)
/*----OUT3 Tokens----*/
#define CSL_GPIO_OUT_DATA45_OUT3_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA45_OUT3_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA45_OUT2_MASK (0x00000004u)
#define CSL_GPIO_OUT_DATA45_OUT2_SHIFT (0x00000002u)
#define CSL_GPIO_OUT_DATA45_OUT2_RESETVAL (0x00000000u)
/*----OUT2 Tokens----*/
#define CSL_GPIO_OUT_DATA45_OUT2_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA45_OUT2_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA45_OUT1_MASK (0x00000002u)
#define CSL_GPIO_OUT_DATA45_OUT1_SHIFT (0x00000001u)
#define CSL_GPIO_OUT_DATA45_OUT1_RESETVAL (0x00000000u)
/*----OUT1 Tokens----*/
#define CSL_GPIO_OUT_DATA45_OUT1_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA45_OUT1_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA45_OUT0_MASK (0x00000001u)
#define CSL_GPIO_OUT_DATA45_OUT0_SHIFT (0x00000000u)
#define CSL_GPIO_OUT_DATA45_OUT0_RESETVAL (0x00000000u)
/*----OUT0 Tokens----*/
#define CSL_GPIO_OUT_DATA45_OUT0_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA45_OUT0_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA45_RESETVAL (0x00000000u)

/* SET_DATA45 */

#define CSL_GPIO_SET_DATA45_SET31_MASK (0x80000000u)
#define CSL_GPIO_SET_DATA45_SET31_SHIFT (0x0000001Fu)
#define CSL_GPIO_SET_DATA45_SET31_RESETVAL (0x00000000u)
/*----SET31 Tokens----*/
#define CSL_GPIO_SET_DATA45_SET31_SET (0x00000001u)

#define CSL_GPIO_SET_DATA45_SET30_MASK (0x40000000u)
#define CSL_GPIO_SET_DATA45_SET30_SHIFT (0x0000001Eu)
#define CSL_GPIO_SET_DATA45_SET30_RESETVAL (0x00000000u)
/*----SET30 Tokens----*/
#define CSL_GPIO_SET_DATA45_SET30_SET (0x00000001u)

#define CSL_GPIO_SET_DATA45_SET29_MASK (0x20000000u)
#define CSL_GPIO_SET_DATA45_SET29_SHIFT (0x0000001Du)
#define CSL_GPIO_SET_DATA45_SET29_RESETVAL (0x00000000u)
/*----SET29 Tokens----*/
#define CSL_GPIO_SET_DATA45_SET29_SET (0x00000001u)

#define CSL_GPIO_SET_DATA45_SET28_MASK (0x10000000u)
#define CSL_GPIO_SET_DATA45_SET28_SHIFT (0x0000001Cu)
#define CSL_GPIO_SET_DATA45_SET28_RESETVAL (0x00000000u)
/*----SET28 Tokens----*/
#define CSL_GPIO_SET_DATA45_SET28_SET (0x00000001u)

#define CSL_GPIO_SET_DATA45_SET27_MASK (0x08000000u)
#define CSL_GPIO_SET_DATA45_SET27_SHIFT (0x0000001Bu)
#define CSL_GPIO_SET_DATA45_SET27_RESETVAL (0x00000000u)
/*----SET27 Tokens----*/
#define CSL_GPIO_SET_DATA45_SET27_SET (0x00000001u)

#define CSL_GPIO_SET_DATA45_SET26_MASK (0x04000000u)
#define CSL_GPIO_SET_DATA45_SET26_SHIFT (0x0000001Au)
#define CSL_GPIO_SET_DATA45_SET26_RESETVAL (0x00000000u)
/*----SET26 Tokens----*/
#define CSL_GPIO_SET_DATA45_SET26_SET (0x00000001u)

#define CSL_GPIO_SET_DATA45_SET25_MASK (0x02000000u)
#define CSL_GPIO_SET_DATA45_SET25_SHIFT (0x00000019u)
#define CSL_GPIO_SET_DATA45_SET25_RESETVAL (0x00000000u)
/*----SET25 Tokens----*/
#define CSL_GPIO_SET_DATA45_SET25_SET (0x00000001u)

#define CSL_GPIO_SET_DATA45_SET24_MASK (0x01000000u)
#define CSL_GPIO_SET_DATA45_SET24_SHIFT (0x00000018u)
#define CSL_GPIO_SET_DATA45_SET24_RESETVAL (0x00000000u)
/*----SET24 Tokens----*/
#define CSL_GPIO_SET_DATA45_SET24_SET (0x00000001u)

#define CSL_GPIO_SET_DATA45_SET23_MASK (0x00800000u)
#define CSL_GPIO_SET_DATA45_SET23_SHIFT (0x00000017u)
#define CSL_GPIO_SET_DATA45_SET23_RESETVAL (0x00000000u)
/*----SET23 Tokens----*/
#define CSL_GPIO_SET_DATA45_SET23_SET (0x00000001u)

#define CSL_GPIO_SET_DATA45_SET22_MASK (0x00400000u)
#define CSL_GPIO_SET_DATA45_SET22_SHIFT (0x00000016u)
#define CSL_GPIO_SET_DATA45_SET22_RESETVAL (0x00000000u)
/*----SET22 Tokens----*/
#define CSL_GPIO_SET_DATA45_SET22_SET (0x00000001u)

#define CSL_GPIO_SET_DATA45_SET21_MASK (0x00200000u)
#define CSL_GPIO_SET_DATA45_SET21_SHIFT (0x00000015u)
#define CSL_GPIO_SET_DATA45_SET21_RESETVAL (0x00000000u)
/*----SET21 Tokens----*/
#define CSL_GPIO_SET_DATA45_SET21_SET (0x00000001u)

#define CSL_GPIO_SET_DATA45_SET20_MASK (0x00100000u)
#define CSL_GPIO_SET_DATA45_SET20_SHIFT (0x00000014u)
#define CSL_GPIO_SET_DATA45_SET20_RESETVAL (0x00000000u)
/*----SET20 Tokens----*/
#define CSL_GPIO_SET_DATA45_SET20_SET (0x00000001u)

#define CSL_GPIO_SET_DATA45_SET19_MASK (0x00080000u)
#define CSL_GPIO_SET_DATA45_SET19_SHIFT (0x00000013u)
#define CSL_GPIO_SET_DATA45_SET19_RESETVAL (0x00000000u)
/*----SET19 Tokens----*/
#define CSL_GPIO_SET_DATA45_SET19_SET (0x00000001u)

#define CSL_GPIO_SET_DATA45_SET18_MASK (0x00040000u)
#define CSL_GPIO_SET_DATA45_SET18_SHIFT (0x00000012u)
#define CSL_GPIO_SET_DATA45_SET18_RESETVAL (0x00000000u)
/*----SET18 Tokens----*/
#define CSL_GPIO_SET_DATA45_SET18_SET (0x00000001u)

#define CSL_GPIO_SET_DATA45_SET17_MASK (0x00020000u)
#define CSL_GPIO_SET_DATA45_SET17_SHIFT (0x00000011u)
#define CSL_GPIO_SET_DATA45_SET17_RESETVAL (0x00000000u)
/*----SET17 Tokens----*/
#define CSL_GPIO_SET_DATA45_SET17_SET (0x00000001u)

#define CSL_GPIO_SET_DATA45_SET16_MASK (0x00010000u)
#define CSL_GPIO_SET_DATA45_SET16_SHIFT (0x00000010u)
#define CSL_GPIO_SET_DATA45_SET16_RESETVAL (0x00000000u)
/*----SET16 Tokens----*/
#define CSL_GPIO_SET_DATA45_SET16_SET (0x00000001u)

#define CSL_GPIO_SET_DATA45_SET15_MASK (0x00008000u)
#define CSL_GPIO_SET_DATA45_SET15_SHIFT (0x0000000Fu)
#define CSL_GPIO_SET_DATA45_SET15_RESETVAL (0x00000000u)
/*----SET15 Tokens----*/
#define CSL_GPIO_SET_DATA45_SET15_SET (0x00000001u)

#define CSL_GPIO_SET_DATA45_SET14_MASK (0x00004000u)
#define CSL_GPIO_SET_DATA45_SET14_SHIFT (0x0000000Eu)
#define CSL_GPIO_SET_DATA45_SET14_RESETVAL (0x00000000u)
/*----SET14 Tokens----*/
#define CSL_GPIO_SET_DATA45_SET14_SET (0x00000001u)

#define CSL_GPIO_SET_DATA45_SET13_MASK (0x00002000u)
#define CSL_GPIO_SET_DATA45_SET13_SHIFT (0x0000000Du)
#define CSL_GPIO_SET_DATA45_SET13_RESETVAL (0x00000000u)
/*----SET13 Tokens----*/
#define CSL_GPIO_SET_DATA45_SET13_SET (0x00000001u)

#define CSL_GPIO_SET_DATA45_SET12_MASK (0x00001000u)
#define CSL_GPIO_SET_DATA45_SET12_SHIFT (0x0000000Cu)
#define CSL_GPIO_SET_DATA45_SET12_RESETVAL (0x00000000u)
/*----SET12 Tokens----*/
#define CSL_GPIO_SET_DATA45_SET12_SET (0x00000001u)

#define CSL_GPIO_SET_DATA45_SET11_MASK (0x00000800u)
#define CSL_GPIO_SET_DATA45_SET11_SHIFT (0x0000000Bu)
#define CSL_GPIO_SET_DATA45_SET11_RESETVAL (0x00000000u)
/*----SET11 Tokens----*/
#define CSL_GPIO_SET_DATA45_SET11_SET (0x00000001u)

#define CSL_GPIO_SET_DATA45_SET10_MASK (0x00000400u)
#define CSL_GPIO_SET_DATA45_SET10_SHIFT (0x0000000Au)
#define CSL_GPIO_SET_DATA45_SET10_RESETVAL (0x00000000u)
/*----SET10 Tokens----*/
#define CSL_GPIO_SET_DATA45_SET10_SET (0x00000001u)

#define CSL_GPIO_SET_DATA45_SET9_MASK (0x00000200u)
#define CSL_GPIO_SET_DATA45_SET9_SHIFT (0x00000009u)
#define CSL_GPIO_SET_DATA45_SET9_RESETVAL (0x00000000u)
/*----SET9 Tokens----*/
#define CSL_GPIO_SET_DATA45_SET9_SET (0x00000001u)

#define CSL_GPIO_SET_DATA45_SET8_MASK (0x00000100u)
#define CSL_GPIO_SET_DATA45_SET8_SHIFT (0x00000008u)
#define CSL_GPIO_SET_DATA45_SET8_RESETVAL (0x00000000u)
/*----SET8 Tokens----*/
#define CSL_GPIO_SET_DATA45_SET8_SET (0x00000001u)

#define CSL_GPIO_SET_DATA45_SET7_MASK (0x00000080u)
#define CSL_GPIO_SET_DATA45_SET7_SHIFT (0x00000007u)
#define CSL_GPIO_SET_DATA45_SET7_RESETVAL (0x00000000u)
/*----SET7 Tokens----*/
#define CSL_GPIO_SET_DATA45_SET7_SET (0x00000001u)

#define CSL_GPIO_SET_DATA45_SET6_MASK (0x00000040u)
#define CSL_GPIO_SET_DATA45_SET6_SHIFT (0x00000006u)
#define CSL_GPIO_SET_DATA45_SET6_RESETVAL (0x00000000u)
/*----SET6 Tokens----*/
#define CSL_GPIO_SET_DATA45_SET6_SET (0x00000001u)

#define CSL_GPIO_SET_DATA45_SET5_MASK (0x00000020u)
#define CSL_GPIO_SET_DATA45_SET5_SHIFT (0x00000005u)
#define CSL_GPIO_SET_DATA45_SET5_RESETVAL (0x00000000u)
/*----SET5 Tokens----*/
#define CSL_GPIO_SET_DATA45_SET5_SET (0x00000001u)

#define CSL_GPIO_SET_DATA45_SET4_MASK (0x00000010u)
#define CSL_GPIO_SET_DATA45_SET4_SHIFT (0x00000004u)
#define CSL_GPIO_SET_DATA45_SET4_RESETVAL (0x00000000u)
/*----SET4 Tokens----*/
#define CSL_GPIO_SET_DATA45_SET4_SET (0x00000001u)

#define CSL_GPIO_SET_DATA45_SET3_MASK (0x00000008u)
#define CSL_GPIO_SET_DATA45_SET3_SHIFT (0x00000003u)
#define CSL_GPIO_SET_DATA45_SET3_RESETVAL (0x00000000u)
/*----SET3 Tokens----*/
#define CSL_GPIO_SET_DATA45_SET3_SET (0x00000001u)

#define CSL_GPIO_SET_DATA45_SET2_MASK (0x00000004u)
#define CSL_GPIO_SET_DATA45_SET2_SHIFT (0x00000002u)
#define CSL_GPIO_SET_DATA45_SET2_RESETVAL (0x00000000u)
/*----SET2 Tokens----*/
#define CSL_GPIO_SET_DATA45_SET2_SET (0x00000001u)

#define CSL_GPIO_SET_DATA45_SET1_MASK (0x00000002u)
#define CSL_GPIO_SET_DATA45_SET1_SHIFT (0x00000001u)
#define CSL_GPIO_SET_DATA45_SET1_RESETVAL (0x00000000u)
/*----SET1 Tokens----*/
#define CSL_GPIO_SET_DATA45_SET1_SET (0x00000001u)

#define CSL_GPIO_SET_DATA45_SET0_MASK (0x00000001u)
#define CSL_GPIO_SET_DATA45_SET0_SHIFT (0x00000000u)
#define CSL_GPIO_SET_DATA45_SET0_RESETVAL (0x00000000u)
/*----SET0 Tokens----*/
#define CSL_GPIO_SET_DATA45_SET0_SET (0x00000001u)

#define CSL_GPIO_SET_DATA45_RESETVAL (0x00000000u)

/* CLR_DATA45 */

#define CSL_GPIO_CLR_DATA45_CLR31_MASK (0x80000000u)
#define CSL_GPIO_CLR_DATA45_CLR31_SHIFT (0x0000001Fu)
#define CSL_GPIO_CLR_DATA45_CLR31_RESETVAL (0x00000000u)
/*----CLR31 Tokens----*/
#define CSL_GPIO_CLR_DATA45_CLR31_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA45_CLR30_MASK (0x40000000u)
#define CSL_GPIO_CLR_DATA45_CLR30_SHIFT (0x0000001Eu)
#define CSL_GPIO_CLR_DATA45_CLR30_RESETVAL (0x00000000u)
/*----CLR30 Tokens----*/
#define CSL_GPIO_CLR_DATA45_CLR30_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA45_CLR29_MASK (0x20000000u)
#define CSL_GPIO_CLR_DATA45_CLR29_SHIFT (0x0000001Du)
#define CSL_GPIO_CLR_DATA45_CLR29_RESETVAL (0x00000000u)
/*----CLR29 Tokens----*/
#define CSL_GPIO_CLR_DATA45_CLR29_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA45_CLR28_MASK (0x10000000u)
#define CSL_GPIO_CLR_DATA45_CLR28_SHIFT (0x0000001Cu)
#define CSL_GPIO_CLR_DATA45_CLR28_RESETVAL (0x00000000u)
/*----CLR28 Tokens----*/
#define CSL_GPIO_CLR_DATA45_CLR28_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA45_CLR27_MASK (0x08000000u)
#define CSL_GPIO_CLR_DATA45_CLR27_SHIFT (0x0000001Bu)
#define CSL_GPIO_CLR_DATA45_CLR27_RESETVAL (0x00000000u)
/*----CLR27 Tokens----*/
#define CSL_GPIO_CLR_DATA45_CLR27_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA45_CLR26_MASK (0x04000000u)
#define CSL_GPIO_CLR_DATA45_CLR26_SHIFT (0x0000001Au)
#define CSL_GPIO_CLR_DATA45_CLR26_RESETVAL (0x00000000u)
/*----CLR26 Tokens----*/
#define CSL_GPIO_CLR_DATA45_CLR26_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA45_CLR25_MASK (0x02000000u)
#define CSL_GPIO_CLR_DATA45_CLR25_SHIFT (0x00000019u)
#define CSL_GPIO_CLR_DATA45_CLR25_RESETVAL (0x00000000u)
/*----CLR25 Tokens----*/
#define CSL_GPIO_CLR_DATA45_CLR25_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA45_CLR24_MASK (0x01000000u)
#define CSL_GPIO_CLR_DATA45_CLR24_SHIFT (0x00000018u)
#define CSL_GPIO_CLR_DATA45_CLR24_RESETVAL (0x00000000u)
/*----CLR24 Tokens----*/
#define CSL_GPIO_CLR_DATA45_CLR24_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA45_CLR23_MASK (0x00800000u)
#define CSL_GPIO_CLR_DATA45_CLR23_SHIFT (0x00000017u)
#define CSL_GPIO_CLR_DATA45_CLR23_RESETVAL (0x00000000u)
/*----CLR23 Tokens----*/
#define CSL_GPIO_CLR_DATA45_CLR23_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA45_CLR22_MASK (0x00400000u)
#define CSL_GPIO_CLR_DATA45_CLR22_SHIFT (0x00000016u)
#define CSL_GPIO_CLR_DATA45_CLR22_RESETVAL (0x00000000u)
/*----CLR22 Tokens----*/
#define CSL_GPIO_CLR_DATA45_CLR22_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA45_CLR21_MASK (0x00200000u)
#define CSL_GPIO_CLR_DATA45_CLR21_SHIFT (0x00000015u)
#define CSL_GPIO_CLR_DATA45_CLR21_RESETVAL (0x00000000u)
/*----CLR21 Tokens----*/
#define CSL_GPIO_CLR_DATA45_CLR21_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA45_CLR20_MASK (0x00100000u)
#define CSL_GPIO_CLR_DATA45_CLR20_SHIFT (0x00000014u)
#define CSL_GPIO_CLR_DATA45_CLR20_RESETVAL (0x00000000u)
/*----CLR20 Tokens----*/
#define CSL_GPIO_CLR_DATA45_CLR20_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA45_CLR19_MASK (0x00080000u)
#define CSL_GPIO_CLR_DATA45_CLR19_SHIFT (0x00000013u)
#define CSL_GPIO_CLR_DATA45_CLR19_RESETVAL (0x00000000u)
/*----CLR19 Tokens----*/
#define CSL_GPIO_CLR_DATA45_CLR19_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA45_CLR18_MASK (0x00040000u)
#define CSL_GPIO_CLR_DATA45_CLR18_SHIFT (0x00000012u)
#define CSL_GPIO_CLR_DATA45_CLR18_RESETVAL (0x00000000u)
/*----CLR18 Tokens----*/
#define CSL_GPIO_CLR_DATA45_CLR18_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA45_CLR17_MASK (0x00020000u)
#define CSL_GPIO_CLR_DATA45_CLR17_SHIFT (0x00000011u)
#define CSL_GPIO_CLR_DATA45_CLR17_RESETVAL (0x00000000u)
/*----CLR17 Tokens----*/
#define CSL_GPIO_CLR_DATA45_CLR17_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA45_CLR16_MASK (0x00010000u)
#define CSL_GPIO_CLR_DATA45_CLR16_SHIFT (0x00000010u)
#define CSL_GPIO_CLR_DATA45_CLR16_RESETVAL (0x00000000u)
/*----CLR16 Tokens----*/
#define CSL_GPIO_CLR_DATA45_CLR16_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA45_CLR15_MASK (0x00008000u)
#define CSL_GPIO_CLR_DATA45_CLR15_SHIFT (0x0000000Fu)
#define CSL_GPIO_CLR_DATA45_CLR15_RESETVAL (0x00000000u)
/*----CLR15 Tokens----*/
#define CSL_GPIO_CLR_DATA45_CLR15_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA45_CLR14_MASK (0x00004000u)
#define CSL_GPIO_CLR_DATA45_CLR14_SHIFT (0x0000000Eu)
#define CSL_GPIO_CLR_DATA45_CLR14_RESETVAL (0x00000000u)
/*----CLR14 Tokens----*/
#define CSL_GPIO_CLR_DATA45_CLR14_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA45_CLR13_MASK (0x00002000u)
#define CSL_GPIO_CLR_DATA45_CLR13_SHIFT (0x0000000Du)
#define CSL_GPIO_CLR_DATA45_CLR13_RESETVAL (0x00000000u)
/*----CLR13 Tokens----*/
#define CSL_GPIO_CLR_DATA45_CLR13_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA45_CLR12_MASK (0x00001000u)
#define CSL_GPIO_CLR_DATA45_CLR12_SHIFT (0x0000000Cu)
#define CSL_GPIO_CLR_DATA45_CLR12_RESETVAL (0x00000000u)
/*----CLR12 Tokens----*/
#define CSL_GPIO_CLR_DATA45_CLR12_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA45_CLR11_MASK (0x00000800u)
#define CSL_GPIO_CLR_DATA45_CLR11_SHIFT (0x0000000Bu)
#define CSL_GPIO_CLR_DATA45_CLR11_RESETVAL (0x00000000u)
/*----CLR11 Tokens----*/
#define CSL_GPIO_CLR_DATA45_CLR11_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA45_CLR10_MASK (0x00000400u)
#define CSL_GPIO_CLR_DATA45_CLR10_SHIFT (0x0000000Au)
#define CSL_GPIO_CLR_DATA45_CLR10_RESETVAL (0x00000000u)
/*----CLR10 Tokens----*/
#define CSL_GPIO_CLR_DATA45_CLR10_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA45_CLR9_MASK (0x00000200u)
#define CSL_GPIO_CLR_DATA45_CLR9_SHIFT (0x00000009u)
#define CSL_GPIO_CLR_DATA45_CLR9_RESETVAL (0x00000000u)
/*----CLR9 Tokens----*/
#define CSL_GPIO_CLR_DATA45_CLR9_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA45_CLR8_MASK (0x00000100u)
#define CSL_GPIO_CLR_DATA45_CLR8_SHIFT (0x00000008u)
#define CSL_GPIO_CLR_DATA45_CLR8_RESETVAL (0x00000000u)
/*----CLR8 Tokens----*/
#define CSL_GPIO_CLR_DATA45_CLR8_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA45_CLR7_MASK (0x00000080u)
#define CSL_GPIO_CLR_DATA45_CLR7_SHIFT (0x00000007u)
#define CSL_GPIO_CLR_DATA45_CLR7_RESETVAL (0x00000000u)
/*----CLR7 Tokens----*/
#define CSL_GPIO_CLR_DATA45_CLR7_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA45_CLR6_MASK (0x00000040u)
#define CSL_GPIO_CLR_DATA45_CLR6_SHIFT (0x00000006u)
#define CSL_GPIO_CLR_DATA45_CLR6_RESETVAL (0x00000000u)
/*----CLR6 Tokens----*/
#define CSL_GPIO_CLR_DATA45_CLR6_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA45_CLR5_MASK (0x00000020u)
#define CSL_GPIO_CLR_DATA45_CLR5_SHIFT (0x00000005u)
#define CSL_GPIO_CLR_DATA45_CLR5_RESETVAL (0x00000000u)
/*----CLR5 Tokens----*/
#define CSL_GPIO_CLR_DATA45_CLR5_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA45_CLR4_MASK (0x00000010u)
#define CSL_GPIO_CLR_DATA45_CLR4_SHIFT (0x00000004u)
#define CSL_GPIO_CLR_DATA45_CLR4_RESETVAL (0x00000000u)
/*----CLR4 Tokens----*/
#define CSL_GPIO_CLR_DATA45_CLR4_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA45_CLR3_MASK (0x00000008u)
#define CSL_GPIO_CLR_DATA45_CLR3_SHIFT (0x00000003u)
#define CSL_GPIO_CLR_DATA45_CLR3_RESETVAL (0x00000000u)
/*----CLR3 Tokens----*/
#define CSL_GPIO_CLR_DATA45_CLR3_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA45_CLR2_MASK (0x00000004u)
#define CSL_GPIO_CLR_DATA45_CLR2_SHIFT (0x00000002u)
#define CSL_GPIO_CLR_DATA45_CLR2_RESETVAL (0x00000000u)
/*----CLR2 Tokens----*/
#define CSL_GPIO_CLR_DATA45_CLR2_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA45_CLR1_MASK (0x00000002u)
#define CSL_GPIO_CLR_DATA45_CLR1_SHIFT (0x00000001u)
#define CSL_GPIO_CLR_DATA45_CLR1_RESETVAL (0x00000000u)
/*----CLR1 Tokens----*/
#define CSL_GPIO_CLR_DATA45_CLR1_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA45_CLR0_MASK (0x00000001u)
#define CSL_GPIO_CLR_DATA45_CLR0_SHIFT (0x00000000u)
#define CSL_GPIO_CLR_DATA45_CLR0_RESETVAL (0x00000000u)
/*----CLR0 Tokens----*/
#define CSL_GPIO_CLR_DATA45_CLR0_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA45_RESETVAL (0x00000000u)

/* IN_DATA45 */

#define CSL_GPIO_IN_DATA45_IN31_MASK (0x80000000u)
#define CSL_GPIO_IN_DATA45_IN31_SHIFT (0x0000001Fu)
#define CSL_GPIO_IN_DATA45_IN31_RESETVAL (0x00000000u)
/*----IN31 Tokens----*/
#define CSL_GPIO_IN_DATA45_IN31_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA45_IN31_SET (0x00000001u)

#define CSL_GPIO_IN_DATA45_IN30_MASK (0x40000000u)
#define CSL_GPIO_IN_DATA45_IN30_SHIFT (0x0000001Eu)
#define CSL_GPIO_IN_DATA45_IN30_RESETVAL (0x00000000u)
/*----IN30 Tokens----*/
#define CSL_GPIO_IN_DATA45_IN30_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA45_IN30_SET (0x00000001u)

#define CSL_GPIO_IN_DATA45_IN29_MASK (0x20000000u)
#define CSL_GPIO_IN_DATA45_IN29_SHIFT (0x0000001Du)
#define CSL_GPIO_IN_DATA45_IN29_RESETVAL (0x00000000u)
/*----IN29 Tokens----*/
#define CSL_GPIO_IN_DATA45_IN29_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA45_IN29_SET (0x00000001u)

#define CSL_GPIO_IN_DATA45_IN28_MASK (0x10000000u)
#define CSL_GPIO_IN_DATA45_IN28_SHIFT (0x0000001Cu)
#define CSL_GPIO_IN_DATA45_IN28_RESETVAL (0x00000000u)
/*----IN28 Tokens----*/
#define CSL_GPIO_IN_DATA45_IN28_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA45_IN28_SET (0x00000001u)

#define CSL_GPIO_IN_DATA45_IN27_MASK (0x08000000u)
#define CSL_GPIO_IN_DATA45_IN27_SHIFT (0x0000001Bu)
#define CSL_GPIO_IN_DATA45_IN27_RESETVAL (0x00000000u)
/*----IN27 Tokens----*/
#define CSL_GPIO_IN_DATA45_IN27_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA45_IN27_SET (0x00000001u)

#define CSL_GPIO_IN_DATA45_IN26_MASK (0x04000000u)
#define CSL_GPIO_IN_DATA45_IN26_SHIFT (0x0000001Au)
#define CSL_GPIO_IN_DATA45_IN26_RESETVAL (0x00000000u)
/*----IN26 Tokens----*/
#define CSL_GPIO_IN_DATA45_IN26_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA45_IN26_SET (0x00000001u)

#define CSL_GPIO_IN_DATA45_IN25_MASK (0x02000000u)
#define CSL_GPIO_IN_DATA45_IN25_SHIFT (0x00000019u)
#define CSL_GPIO_IN_DATA45_IN25_RESETVAL (0x00000000u)
/*----IN25 Tokens----*/
#define CSL_GPIO_IN_DATA45_IN25_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA45_IN25_SET (0x00000001u)

#define CSL_GPIO_IN_DATA45_IN24_MASK (0x01000000u)
#define CSL_GPIO_IN_DATA45_IN24_SHIFT (0x00000018u)
#define CSL_GPIO_IN_DATA45_IN24_RESETVAL (0x00000000u)
/*----IN24 Tokens----*/
#define CSL_GPIO_IN_DATA45_IN24_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA45_IN24_SET (0x00000001u)

#define CSL_GPIO_IN_DATA45_IN23_MASK (0x00800000u)
#define CSL_GPIO_IN_DATA45_IN23_SHIFT (0x00000017u)
#define CSL_GPIO_IN_DATA45_IN23_RESETVAL (0x00000000u)
/*----IN23 Tokens----*/
#define CSL_GPIO_IN_DATA45_IN23_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA45_IN23_SET (0x00000001u)

#define CSL_GPIO_IN_DATA45_IN22_MASK (0x00400000u)
#define CSL_GPIO_IN_DATA45_IN22_SHIFT (0x00000016u)
#define CSL_GPIO_IN_DATA45_IN22_RESETVAL (0x00000000u)
/*----IN22 Tokens----*/
#define CSL_GPIO_IN_DATA45_IN22_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA45_IN22_SET (0x00000001u)

#define CSL_GPIO_IN_DATA45_IN21_MASK (0x00200000u)
#define CSL_GPIO_IN_DATA45_IN21_SHIFT (0x00000015u)
#define CSL_GPIO_IN_DATA45_IN21_RESETVAL (0x00000000u)
/*----IN21 Tokens----*/
#define CSL_GPIO_IN_DATA45_IN21_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA45_IN21_SET (0x00000001u)

#define CSL_GPIO_IN_DATA45_IN20_MASK (0x00100000u)
#define CSL_GPIO_IN_DATA45_IN20_SHIFT (0x00000014u)
#define CSL_GPIO_IN_DATA45_IN20_RESETVAL (0x00000000u)
/*----IN20 Tokens----*/
#define CSL_GPIO_IN_DATA45_IN20_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA45_IN20_SET (0x00000001u)

#define CSL_GPIO_IN_DATA45_IN19_MASK (0x00080000u)
#define CSL_GPIO_IN_DATA45_IN19_SHIFT (0x00000013u)
#define CSL_GPIO_IN_DATA45_IN19_RESETVAL (0x00000000u)
/*----IN19 Tokens----*/
#define CSL_GPIO_IN_DATA45_IN19_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA45_IN19_SET (0x00000001u)

#define CSL_GPIO_IN_DATA45_IN18_MASK (0x00040000u)
#define CSL_GPIO_IN_DATA45_IN18_SHIFT (0x00000012u)
#define CSL_GPIO_IN_DATA45_IN18_RESETVAL (0x00000000u)
/*----IN18 Tokens----*/
#define CSL_GPIO_IN_DATA45_IN18_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA45_IN18_SET (0x00000001u)

#define CSL_GPIO_IN_DATA45_IN17_MASK (0x00020000u)
#define CSL_GPIO_IN_DATA45_IN17_SHIFT (0x00000011u)
#define CSL_GPIO_IN_DATA45_IN17_RESETVAL (0x00000000u)
/*----IN17 Tokens----*/
#define CSL_GPIO_IN_DATA45_IN17_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA45_IN17_SET (0x00000001u)

#define CSL_GPIO_IN_DATA45_IN16_MASK (0x00010000u)
#define CSL_GPIO_IN_DATA45_IN16_SHIFT (0x00000010u)
#define CSL_GPIO_IN_DATA45_IN16_RESETVAL (0x00000000u)
/*----IN16 Tokens----*/
#define CSL_GPIO_IN_DATA45_IN16_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA45_IN16_SET (0x00000001u)

#define CSL_GPIO_IN_DATA45_IN15_MASK (0x00008000u)
#define CSL_GPIO_IN_DATA45_IN15_SHIFT (0x0000000Fu)
#define CSL_GPIO_IN_DATA45_IN15_RESETVAL (0x00000000u)
/*----IN15 Tokens----*/
#define CSL_GPIO_IN_DATA45_IN15_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA45_IN15_SET (0x00000001u)

#define CSL_GPIO_IN_DATA45_IN14_MASK (0x00004000u)
#define CSL_GPIO_IN_DATA45_IN14_SHIFT (0x0000000Eu)
#define CSL_GPIO_IN_DATA45_IN14_RESETVAL (0x00000000u)
/*----IN14 Tokens----*/
#define CSL_GPIO_IN_DATA45_IN14_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA45_IN14_SET (0x00000001u)

#define CSL_GPIO_IN_DATA45_IN13_MASK (0x00002000u)
#define CSL_GPIO_IN_DATA45_IN13_SHIFT (0x0000000Du)
#define CSL_GPIO_IN_DATA45_IN13_RESETVAL (0x00000000u)
/*----IN13 Tokens----*/
#define CSL_GPIO_IN_DATA45_IN13_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA45_IN13_SET (0x00000001u)

#define CSL_GPIO_IN_DATA45_IN12_MASK (0x00001000u)
#define CSL_GPIO_IN_DATA45_IN12_SHIFT (0x0000000Cu)
#define CSL_GPIO_IN_DATA45_IN12_RESETVAL (0x00000000u)
/*----IN12 Tokens----*/
#define CSL_GPIO_IN_DATA45_IN12_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA45_IN12_SET (0x00000001u)

#define CSL_GPIO_IN_DATA45_IN11_MASK (0x00000800u)
#define CSL_GPIO_IN_DATA45_IN11_SHIFT (0x0000000Bu)
#define CSL_GPIO_IN_DATA45_IN11_RESETVAL (0x00000000u)
/*----IN11 Tokens----*/
#define CSL_GPIO_IN_DATA45_IN11_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA45_IN11_SET (0x00000001u)

#define CSL_GPIO_IN_DATA45_IN10_MASK (0x00000400u)
#define CSL_GPIO_IN_DATA45_IN10_SHIFT (0x0000000Au)
#define CSL_GPIO_IN_DATA45_IN10_RESETVAL (0x00000000u)
/*----IN10 Tokens----*/
#define CSL_GPIO_IN_DATA45_IN10_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA45_IN10_SET (0x00000001u)

#define CSL_GPIO_IN_DATA45_IN9_MASK (0x00000200u)
#define CSL_GPIO_IN_DATA45_IN9_SHIFT (0x00000009u)
#define CSL_GPIO_IN_DATA45_IN9_RESETVAL (0x00000000u)
/*----IN9 Tokens----*/
#define CSL_GPIO_IN_DATA45_IN9_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA45_IN9_SET (0x00000001u)

#define CSL_GPIO_IN_DATA45_IN8_MASK (0x00000100u)
#define CSL_GPIO_IN_DATA45_IN8_SHIFT (0x00000008u)
#define CSL_GPIO_IN_DATA45_IN8_RESETVAL (0x00000000u)
/*----IN8 Tokens----*/
#define CSL_GPIO_IN_DATA45_IN8_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA45_IN8_SET (0x00000001u)

#define CSL_GPIO_IN_DATA45_IN7_MASK (0x00000080u)
#define CSL_GPIO_IN_DATA45_IN7_SHIFT (0x00000007u)
#define CSL_GPIO_IN_DATA45_IN7_RESETVAL (0x00000000u)
/*----IN7 Tokens----*/
#define CSL_GPIO_IN_DATA45_IN7_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA45_IN7_SET (0x00000001u)

#define CSL_GPIO_IN_DATA45_IN6_MASK (0x00000040u)
#define CSL_GPIO_IN_DATA45_IN6_SHIFT (0x00000006u)
#define CSL_GPIO_IN_DATA45_IN6_RESETVAL (0x00000000u)
/*----IN6 Tokens----*/
#define CSL_GPIO_IN_DATA45_IN6_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA45_IN6_SET (0x00000001u)

#define CSL_GPIO_IN_DATA45_IN5_MASK (0x00000020u)
#define CSL_GPIO_IN_DATA45_IN5_SHIFT (0x00000005u)
#define CSL_GPIO_IN_DATA45_IN5_RESETVAL (0x00000000u)
/*----IN5 Tokens----*/
#define CSL_GPIO_IN_DATA45_IN5_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA45_IN5_SET (0x00000001u)

#define CSL_GPIO_IN_DATA45_IN4_MASK (0x00000010u)
#define CSL_GPIO_IN_DATA45_IN4_SHIFT (0x00000004u)
#define CSL_GPIO_IN_DATA45_IN4_RESETVAL (0x00000000u)
/*----IN4 Tokens----*/
#define CSL_GPIO_IN_DATA45_IN4_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA45_IN4_SET (0x00000001u)

#define CSL_GPIO_IN_DATA45_IN3_MASK (0x00000008u)
#define CSL_GPIO_IN_DATA45_IN3_SHIFT (0x00000003u)
#define CSL_GPIO_IN_DATA45_IN3_RESETVAL (0x00000000u)
/*----IN3 Tokens----*/
#define CSL_GPIO_IN_DATA45_IN3_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA45_IN3_SET (0x00000001u)

#define CSL_GPIO_IN_DATA45_IN2_MASK (0x00000004u)
#define CSL_GPIO_IN_DATA45_IN2_SHIFT (0x00000002u)
#define CSL_GPIO_IN_DATA45_IN2_RESETVAL (0x00000000u)
/*----IN2 Tokens----*/
#define CSL_GPIO_IN_DATA45_IN2_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA45_IN2_SET (0x00000001u)

#define CSL_GPIO_IN_DATA45_IN1_MASK (0x00000002u)
#define CSL_GPIO_IN_DATA45_IN1_SHIFT (0x00000001u)
#define CSL_GPIO_IN_DATA45_IN1_RESETVAL (0x00000000u)
/*----IN1 Tokens----*/
#define CSL_GPIO_IN_DATA45_IN1_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA45_IN1_SET (0x00000001u)

#define CSL_GPIO_IN_DATA45_IN0_MASK (0x00000001u)
#define CSL_GPIO_IN_DATA45_IN0_SHIFT (0x00000000u)
#define CSL_GPIO_IN_DATA45_IN0_RESETVAL (0x00000000u)
/*----IN0 Tokens----*/
#define CSL_GPIO_IN_DATA45_IN0_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA45_IN0_SET (0x00000001u)

#define CSL_GPIO_IN_DATA45_RESETVAL (0x00000000u)

/* SET_RIS_TRIG45 */

#define CSL_GPIO_SET_RIS_TRIG45_SETRIS31_MASK (0x80000000u)
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS31_SHIFT (0x0000001Fu)
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS31_RESETVAL (0x00000000u)
/*----SETRIS31 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS31_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG45_SETRIS30_MASK (0x40000000u)
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS30_SHIFT (0x0000001Eu)
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS30_RESETVAL (0x00000000u)
/*----SETRIS30 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS30_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG45_SETRIS29_MASK (0x20000000u)
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS29_SHIFT (0x0000001Du)
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS29_RESETVAL (0x00000000u)
/*----SETRIS29 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS29_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG45_SETRIS28_MASK (0x10000000u)
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS28_SHIFT (0x0000001Cu)
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS28_RESETVAL (0x00000000u)
/*----SETRIS28 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS28_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG45_SETRIS27_MASK (0x08000000u)
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS27_SHIFT (0x0000001Bu)
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS27_RESETVAL (0x00000000u)
/*----SETRIS27 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS27_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG45_SETRIS26_MASK (0x04000000u)
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS26_SHIFT (0x0000001Au)
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS26_RESETVAL (0x00000000u)
/*----SETRIS26 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS26_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG45_SETRIS25_MASK (0x02000000u)
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS25_SHIFT (0x00000019u)
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS25_RESETVAL (0x00000000u)
/*----SETRIS25 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS25_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG45_SETRIS24_MASK (0x01000000u)
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS24_SHIFT (0x00000018u)
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS24_RESETVAL (0x00000000u)
/*----SETRIS24 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS24_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG45_SETRIS23_MASK (0x00800000u)
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS23_SHIFT (0x00000017u)
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS23_RESETVAL (0x00000000u)
/*----SETRIS23 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS23_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG45_SETRIS22_MASK (0x00400000u)
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS22_SHIFT (0x00000016u)
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS22_RESETVAL (0x00000000u)
/*----SETRIS22 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS22_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG45_SETRIS21_MASK (0x00200000u)
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS21_SHIFT (0x00000015u)
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS21_RESETVAL (0x00000000u)
/*----SETRIS21 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS21_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG45_SETRIS20_MASK (0x00100000u)
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS20_SHIFT (0x00000014u)
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS20_RESETVAL (0x00000000u)
/*----SETRIS20 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS20_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG45_SETRIS19_MASK (0x00080000u)
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS19_SHIFT (0x00000013u)
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS19_RESETVAL (0x00000000u)
/*----SETRIS19 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS19_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG45_SETRIS18_MASK (0x00040000u)
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS18_SHIFT (0x00000012u)
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS18_RESETVAL (0x00000000u)
/*----SETRIS18 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS18_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG45_SETRIS17_MASK (0x00020000u)
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS17_SHIFT (0x00000011u)
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS17_RESETVAL (0x00000000u)
/*----SETRIS17 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS17_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG45_SETRIS16_MASK (0x00010000u)
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS16_SHIFT (0x00000010u)
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS16_RESETVAL (0x00000000u)
/*----SETRIS16 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS16_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG45_SETRIS15_MASK (0x00008000u)
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS15_SHIFT (0x0000000Fu)
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS15_RESETVAL (0x00000000u)
/*----SETRIS15 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS15_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG45_SETRIS14_MASK (0x00004000u)
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS14_SHIFT (0x0000000Eu)
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS14_RESETVAL (0x00000000u)
/*----SETRIS14 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS14_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG45_SETRIS13_MASK (0x00002000u)
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS13_SHIFT (0x0000000Du)
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS13_RESETVAL (0x00000000u)
/*----SETRIS13 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS13_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG45_SETRIS12_MASK (0x00001000u)
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS12_SHIFT (0x0000000Cu)
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS12_RESETVAL (0x00000000u)
/*----SETRIS12 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS12_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG45_SETRIS11_MASK (0x00000800u)
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS11_SHIFT (0x0000000Bu)
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS11_RESETVAL (0x00000000u)
/*----SETRIS11 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS11_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG45_SETRIS10_MASK (0x00000400u)
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS10_SHIFT (0x0000000Au)
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS10_RESETVAL (0x00000000u)
/*----SETRIS10 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS10_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG45_SETRIS9_MASK (0x00000200u)
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS9_SHIFT (0x00000009u)
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS9_RESETVAL (0x00000000u)
/*----SETRIS9 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS9_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG45_SETRIS8_MASK (0x00000100u)
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS8_SHIFT (0x00000008u)
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS8_RESETVAL (0x00000000u)
/*----SETRIS8 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS8_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG45_SETRIS7_MASK (0x00000080u)
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS7_SHIFT (0x00000007u)
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS7_RESETVAL (0x00000000u)
/*----SETRIS7 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS7_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG45_SETRIS6_MASK (0x00000040u)
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS6_SHIFT (0x00000006u)
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS6_RESETVAL (0x00000000u)
/*----SETRIS6 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS6_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG45_SETRIS5_MASK (0x00000020u)
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS5_SHIFT (0x00000005u)
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS5_RESETVAL (0x00000000u)
/*----SETRIS5 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS5_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG45_SETRIS4_MASK (0x00000010u)
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS4_SHIFT (0x00000004u)
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS4_RESETVAL (0x00000000u)
/*----SETRIS4 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS4_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG45_SETRIS3_MASK (0x00000008u)
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS3_SHIFT (0x00000003u)
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS3_RESETVAL (0x00000000u)
/*----SETRIS3 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS3_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG45_SETRIS2_MASK (0x00000004u)
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS2_SHIFT (0x00000002u)
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS2_RESETVAL (0x00000000u)
/*----SETRIS2 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS2_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG45_SETRIS1_MASK (0x00000002u)
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS1_SHIFT (0x00000001u)
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS1_RESETVAL (0x00000000u)
/*----SETRIS1 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS1_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG45_SETRIS0_MASK (0x00000001u)
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS0_SHIFT (0x00000000u)
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS0_RESETVAL (0x00000000u)
/*----SETRIS0 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG45_SETRIS0_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG45_RESETVAL (0x00000000u)

/* CLR_RIS_TRIG45 */

#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS31_MASK (0x80000000u)
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS31_SHIFT (0x0000001Fu)
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS31_RESETVAL (0x00000000u)
/*----CLRRIS31 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS31_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS30_MASK (0x40000000u)
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS30_SHIFT (0x0000001Eu)
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS30_RESETVAL (0x00000000u)
/*----CLRRIS30 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS30_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS29_MASK (0x20000000u)
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS29_SHIFT (0x0000001Du)
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS29_RESETVAL (0x00000000u)
/*----CLRRIS29 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS29_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS28_MASK (0x10000000u)
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS28_SHIFT (0x0000001Cu)
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS28_RESETVAL (0x00000000u)
/*----CLRRIS28 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS28_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS27_MASK (0x08000000u)
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS27_SHIFT (0x0000001Bu)
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS27_RESETVAL (0x00000000u)
/*----CLRRIS27 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS27_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS26_MASK (0x04000000u)
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS26_SHIFT (0x0000001Au)
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS26_RESETVAL (0x00000000u)
/*----CLRRIS26 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS26_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS25_MASK (0x02000000u)
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS25_SHIFT (0x00000019u)
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS25_RESETVAL (0x00000000u)
/*----CLRRIS25 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS25_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS24_MASK (0x01000000u)
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS24_SHIFT (0x00000018u)
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS24_RESETVAL (0x00000000u)
/*----CLRRIS24 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS24_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS23_MASK (0x00800000u)
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS23_SHIFT (0x00000017u)
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS23_RESETVAL (0x00000000u)
/*----CLRRIS23 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS23_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS22_MASK (0x00400000u)
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS22_SHIFT (0x00000016u)
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS22_RESETVAL (0x00000000u)
/*----CLRRIS22 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS22_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS21_MASK (0x00200000u)
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS21_SHIFT (0x00000015u)
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS21_RESETVAL (0x00000000u)
/*----CLRRIS21 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS21_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS20_MASK (0x00100000u)
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS20_SHIFT (0x00000014u)
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS20_RESETVAL (0x00000000u)
/*----CLRRIS20 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS20_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS19_MASK (0x00080000u)
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS19_SHIFT (0x00000013u)
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS19_RESETVAL (0x00000000u)
/*----CLRRIS19 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS19_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS18_MASK (0x00040000u)
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS18_SHIFT (0x00000012u)
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS18_RESETVAL (0x00000000u)
/*----CLRRIS18 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS18_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS17_MASK (0x00020000u)
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS17_SHIFT (0x00000011u)
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS17_RESETVAL (0x00000000u)
/*----CLRRIS17 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS17_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS16_MASK (0x00010000u)
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS16_SHIFT (0x00000010u)
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS16_RESETVAL (0x00000000u)
/*----CLRRIS16 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS16_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS15_MASK (0x00008000u)
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS15_SHIFT (0x0000000Fu)
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS15_RESETVAL (0x00000000u)
/*----CLRRIS15 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS15_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS14_MASK (0x00004000u)
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS14_SHIFT (0x0000000Eu)
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS14_RESETVAL (0x00000000u)
/*----CLRRIS14 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS14_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS13_MASK (0x00002000u)
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS13_SHIFT (0x0000000Du)
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS13_RESETVAL (0x00000000u)
/*----CLRRIS13 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS13_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS12_MASK (0x00001000u)
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS12_SHIFT (0x0000000Cu)
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS12_RESETVAL (0x00000000u)
/*----CLRRIS12 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS12_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS11_MASK (0x00000800u)
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS11_SHIFT (0x0000000Bu)
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS11_RESETVAL (0x00000000u)
/*----CLRRIS11 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS11_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS10_MASK (0x00000400u)
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS10_SHIFT (0x0000000Au)
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS10_RESETVAL (0x00000000u)
/*----CLRRIS10 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS10_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS9_MASK (0x00000200u)
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS9_SHIFT (0x00000009u)
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS9_RESETVAL (0x00000000u)
/*----CLRRIS9 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS9_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS8_MASK (0x00000100u)
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS8_SHIFT (0x00000008u)
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS8_RESETVAL (0x00000000u)
/*----CLRRIS8 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS8_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS7_MASK (0x00000080u)
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS7_SHIFT (0x00000007u)
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS7_RESETVAL (0x00000000u)
/*----CLRRIS7 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS7_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS6_MASK (0x00000040u)
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS6_SHIFT (0x00000006u)
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS6_RESETVAL (0x00000000u)
/*----CLRRIS6 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS6_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS5_MASK (0x00000020u)
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS5_SHIFT (0x00000005u)
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS5_RESETVAL (0x00000000u)
/*----CLRRIS5 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS5_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS4_MASK (0x00000010u)
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS4_SHIFT (0x00000004u)
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS4_RESETVAL (0x00000000u)
/*----CLRRIS4 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS4_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS3_MASK (0x00000008u)
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS3_SHIFT (0x00000003u)
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS3_RESETVAL (0x00000000u)
/*----CLRRIS3 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS3_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS2_MASK (0x00000004u)
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS2_SHIFT (0x00000002u)
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS2_RESETVAL (0x00000000u)
/*----CLRRIS2 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS2_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS1_MASK (0x00000002u)
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS1_SHIFT (0x00000001u)
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS1_RESETVAL (0x00000000u)
/*----CLRRIS1 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS1_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS0_MASK (0x00000001u)
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS0_SHIFT (0x00000000u)
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS0_RESETVAL (0x00000000u)
/*----CLRRIS0 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG45_CLRRIS0_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_RIS_TRIG45_RESETVAL (0x00000000u)

/* SET_FAL_TRIG45 */

#define CSL_GPIO_SET_FAL_TRIG45_SETFAL31_MASK (0x80000000u)
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL31_SHIFT (0x0000001Fu)
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL31_RESETVAL (0x00000000u)
/*----SETFAL31 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL31_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG45_SETFAL30_MASK (0x40000000u)
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL30_SHIFT (0x0000001Eu)
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL30_RESETVAL (0x00000000u)
/*----SETFAL30 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL30_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG45_SETFAL29_MASK (0x20000000u)
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL29_SHIFT (0x0000001Du)
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL29_RESETVAL (0x00000000u)
/*----SETFAL29 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL29_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG45_SETFAL28_MASK (0x10000000u)
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL28_SHIFT (0x0000001Cu)
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL28_RESETVAL (0x00000000u)
/*----SETFAL28 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL28_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG45_SETFAL27_MASK (0x08000000u)
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL27_SHIFT (0x0000001Bu)
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL27_RESETVAL (0x00000000u)
/*----SETFAL27 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL27_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG45_SETFAL26_MASK (0x04000000u)
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL26_SHIFT (0x0000001Au)
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL26_RESETVAL (0x00000000u)
/*----SETFAL26 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL26_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG45_SETFAL25_MASK (0x02000000u)
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL25_SHIFT (0x00000019u)
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL25_RESETVAL (0x00000000u)
/*----SETFAL25 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL25_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG45_SETFAL24_MASK (0x01000000u)
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL24_SHIFT (0x00000018u)
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL24_RESETVAL (0x00000000u)
/*----SETFAL24 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL24_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG45_SETFAL23_MASK (0x00800000u)
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL23_SHIFT (0x00000017u)
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL23_RESETVAL (0x00000000u)
/*----SETFAL23 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL23_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG45_SETFAL22_MASK (0x00400000u)
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL22_SHIFT (0x00000016u)
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL22_RESETVAL (0x00000000u)
/*----SETFAL22 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL22_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG45_SETFAL21_MASK (0x00200000u)
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL21_SHIFT (0x00000015u)
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL21_RESETVAL (0x00000000u)
/*----SETFAL21 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL21_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG45_SETFAL20_MASK (0x00100000u)
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL20_SHIFT (0x00000014u)
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL20_RESETVAL (0x00000000u)
/*----SETFAL20 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL20_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG45_SETFAL19_MASK (0x00080000u)
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL19_SHIFT (0x00000013u)
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL19_RESETVAL (0x00000000u)
/*----SETFAL19 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL19_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG45_SETFAL18_MASK (0x00040000u)
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL18_SHIFT (0x00000012u)
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL18_RESETVAL (0x00000000u)
/*----SETFAL18 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL18_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG45_SETFAL17_MASK (0x00020000u)
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL17_SHIFT (0x00000011u)
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL17_RESETVAL (0x00000000u)
/*----SETFAL17 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL17_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG45_SETFAL16_MASK (0x00010000u)
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL16_SHIFT (0x00000010u)
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL16_RESETVAL (0x00000000u)
/*----SETFAL16 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL16_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG45_SETFAL15_MASK (0x00008000u)
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL15_SHIFT (0x0000000Fu)
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL15_RESETVAL (0x00000000u)
/*----SETFAL15 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL15_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG45_SETFAL14_MASK (0x00004000u)
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL14_SHIFT (0x0000000Eu)
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL14_RESETVAL (0x00000000u)
/*----SETFAL14 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL14_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG45_SETFAL13_MASK (0x00002000u)
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL13_SHIFT (0x0000000Du)
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL13_RESETVAL (0x00000000u)
/*----SETFAL13 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL13_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG45_SETFAL12_MASK (0x00001000u)
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL12_SHIFT (0x0000000Cu)
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL12_RESETVAL (0x00000000u)
/*----SETFAL12 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL12_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG45_SETFAL11_MASK (0x00000800u)
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL11_SHIFT (0x0000000Bu)
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL11_RESETVAL (0x00000000u)
/*----SETFAL11 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL11_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG45_SETFAL10_MASK (0x00000400u)
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL10_SHIFT (0x0000000Au)
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL10_RESETVAL (0x00000000u)
/*----SETFAL10 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL10_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG45_SETFAL9_MASK (0x00000200u)
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL9_SHIFT (0x00000009u)
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL9_RESETVAL (0x00000000u)
/*----SETFAL9 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL9_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG45_SETFAL8_MASK (0x00000100u)
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL8_SHIFT (0x00000008u)
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL8_RESETVAL (0x00000000u)
/*----SETFAL8 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL8_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG45_SETFAL7_MASK (0x00000080u)
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL7_SHIFT (0x00000007u)
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL7_RESETVAL (0x00000000u)
/*----SETFAL7 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL7_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG45_SETFAL6_MASK (0x00000040u)
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL6_SHIFT (0x00000006u)
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL6_RESETVAL (0x00000000u)
/*----SETFAL6 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL6_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG45_SETFAL5_MASK (0x00000020u)
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL5_SHIFT (0x00000005u)
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL5_RESETVAL (0x00000000u)
/*----SETFAL5 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL5_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG45_SETFAL4_MASK (0x00000010u)
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL4_SHIFT (0x00000004u)
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL4_RESETVAL (0x00000000u)
/*----SETFAL4 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL4_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG45_SETFAL3_MASK (0x00000008u)
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL3_SHIFT (0x00000003u)
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL3_RESETVAL (0x00000000u)
/*----SETFAL3 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL3_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG45_SETFAL2_MASK (0x00000004u)
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL2_SHIFT (0x00000002u)
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL2_RESETVAL (0x00000000u)
/*----SETFAL2 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL2_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG45_SETFAL1_MASK (0x00000002u)
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL1_SHIFT (0x00000001u)
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL1_RESETVAL (0x00000000u)
/*----SETFAL1 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL1_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG45_SETFAL0_MASK (0x00000001u)
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL0_SHIFT (0x00000000u)
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL0_RESETVAL (0x00000000u)
/*----SETFAL0 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG45_SETFAL0_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG45_RESETVAL (0x00000000u)

/* CLR_FAL_TRIG45 */

#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL31_MASK (0x80000000u)
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL31_SHIFT (0x0000001Fu)
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL31_RESETVAL (0x00000000u)
/*----CLRFAL31 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL31_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL30_MASK (0x40000000u)
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL30_SHIFT (0x0000001Eu)
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL30_RESETVAL (0x00000000u)
/*----CLRFAL30 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL30_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL29_MASK (0x20000000u)
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL29_SHIFT (0x0000001Du)
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL29_RESETVAL (0x00000000u)
/*----CLRFAL29 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL29_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL28_MASK (0x10000000u)
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL28_SHIFT (0x0000001Cu)
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL28_RESETVAL (0x00000000u)
/*----CLRFAL28 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL28_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL27_MASK (0x08000000u)
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL27_SHIFT (0x0000001Bu)
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL27_RESETVAL (0x00000000u)
/*----CLRFAL27 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL27_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL26_MASK (0x04000000u)
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL26_SHIFT (0x0000001Au)
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL26_RESETVAL (0x00000000u)
/*----CLRFAL26 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL26_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL25_MASK (0x02000000u)
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL25_SHIFT (0x00000019u)
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL25_RESETVAL (0x00000000u)
/*----CLRFAL25 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL25_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL24_MASK (0x01000000u)
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL24_SHIFT (0x00000018u)
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL24_RESETVAL (0x00000000u)
/*----CLRFAL24 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL24_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL23_MASK (0x00800000u)
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL23_SHIFT (0x00000017u)
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL23_RESETVAL (0x00000000u)
/*----CLRFAL23 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL23_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL22_MASK (0x00400000u)
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL22_SHIFT (0x00000016u)
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL22_RESETVAL (0x00000000u)
/*----CLRFAL22 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL22_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL21_MASK (0x00200000u)
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL21_SHIFT (0x00000015u)
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL21_RESETVAL (0x00000000u)
/*----CLRFAL21 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL21_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL20_MASK (0x00100000u)
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL20_SHIFT (0x00000014u)
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL20_RESETVAL (0x00000000u)
/*----CLRFAL20 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL20_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL19_MASK (0x00080000u)
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL19_SHIFT (0x00000013u)
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL19_RESETVAL (0x00000000u)
/*----CLRFAL19 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL19_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL18_MASK (0x00040000u)
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL18_SHIFT (0x00000012u)
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL18_RESETVAL (0x00000000u)
/*----CLRFAL18 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL18_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL17_MASK (0x00020000u)
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL17_SHIFT (0x00000011u)
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL17_RESETVAL (0x00000000u)
/*----CLRFAL17 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL17_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL16_MASK (0x00010000u)
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL16_SHIFT (0x00000010u)
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL16_RESETVAL (0x00000000u)
/*----CLRFAL16 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL16_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL15_MASK (0x00008000u)
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL15_SHIFT (0x0000000Fu)
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL15_RESETVAL (0x00000000u)
/*----CLRFAL15 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL15_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL14_MASK (0x00004000u)
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL14_SHIFT (0x0000000Eu)
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL14_RESETVAL (0x00000000u)
/*----CLRFAL14 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL14_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL13_MASK (0x00002000u)
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL13_SHIFT (0x0000000Du)
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL13_RESETVAL (0x00000000u)
/*----CLRFAL13 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL13_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL12_MASK (0x00001000u)
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL12_SHIFT (0x0000000Cu)
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL12_RESETVAL (0x00000000u)
/*----CLRFAL12 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL12_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL11_MASK (0x00000800u)
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL11_SHIFT (0x0000000Bu)
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL11_RESETVAL (0x00000000u)
/*----CLRFAL11 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL11_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL10_MASK (0x00000400u)
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL10_SHIFT (0x0000000Au)
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL10_RESETVAL (0x00000000u)
/*----CLRFAL10 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL10_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL9_MASK (0x00000200u)
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL9_SHIFT (0x00000009u)
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL9_RESETVAL (0x00000000u)
/*----CLRFAL9 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL9_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL8_MASK (0x00000100u)
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL8_SHIFT (0x00000008u)
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL8_RESETVAL (0x00000000u)
/*----CLRFAL8 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL8_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL7_MASK (0x00000080u)
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL7_SHIFT (0x00000007u)
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL7_RESETVAL (0x00000000u)
/*----CLRFAL7 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL7_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL6_MASK (0x00000040u)
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL6_SHIFT (0x00000006u)
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL6_RESETVAL (0x00000000u)
/*----CLRFAL6 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL6_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL5_MASK (0x00000020u)
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL5_SHIFT (0x00000005u)
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL5_RESETVAL (0x00000000u)
/*----CLRFAL5 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL5_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL4_MASK (0x00000010u)
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL4_SHIFT (0x00000004u)
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL4_RESETVAL (0x00000000u)
/*----CLRFAL4 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL4_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL3_MASK (0x00000008u)
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL3_SHIFT (0x00000003u)
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL3_RESETVAL (0x00000000u)
/*----CLRFAL3 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL3_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL2_MASK (0x00000004u)
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL2_SHIFT (0x00000002u)
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL2_RESETVAL (0x00000000u)
/*----CLRFAL2 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL2_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL1_MASK (0x00000002u)
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL1_SHIFT (0x00000001u)
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL1_RESETVAL (0x00000000u)
/*----CLRFAL1 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL1_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL0_MASK (0x00000001u)
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL0_SHIFT (0x00000000u)
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL0_RESETVAL (0x00000000u)
/*----CLRFAL0 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG45_CLRFAL0_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_FAL_TRIG45_RESETVAL (0x00000000u)

/* INTSTAT45 */

#define CSL_GPIO_INTSTAT45_STAT31_MASK (0x80000000u)
#define CSL_GPIO_INTSTAT45_STAT31_SHIFT (0x0000001Fu)
#define CSL_GPIO_INTSTAT45_STAT31_RESETVAL (0x00000000u)
/*----STAT31 Tokens----*/
#define CSL_GPIO_INTSTAT45_STAT31_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT45_STAT31_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT45_STAT30_MASK (0x40000000u)
#define CSL_GPIO_INTSTAT45_STAT30_SHIFT (0x0000001Eu)
#define CSL_GPIO_INTSTAT45_STAT30_RESETVAL (0x00000000u)
/*----STAT30 Tokens----*/
#define CSL_GPIO_INTSTAT45_STAT30_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT45_STAT30_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT45_STAT29_MASK (0x20000000u)
#define CSL_GPIO_INTSTAT45_STAT29_SHIFT (0x0000001Du)
#define CSL_GPIO_INTSTAT45_STAT29_RESETVAL (0x00000000u)
/*----STAT29 Tokens----*/
#define CSL_GPIO_INTSTAT45_STAT29_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT45_STAT29_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT45_STAT28_MASK (0x10000000u)
#define CSL_GPIO_INTSTAT45_STAT28_SHIFT (0x0000001Cu)
#define CSL_GPIO_INTSTAT45_STAT28_RESETVAL (0x00000000u)
/*----STAT28 Tokens----*/
#define CSL_GPIO_INTSTAT45_STAT28_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT45_STAT28_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT45_STAT27_MASK (0x08000000u)
#define CSL_GPIO_INTSTAT45_STAT27_SHIFT (0x0000001Bu)
#define CSL_GPIO_INTSTAT45_STAT27_RESETVAL (0x00000000u)
/*----STAT27 Tokens----*/
#define CSL_GPIO_INTSTAT45_STAT27_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT45_STAT27_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT45_STAT26_MASK (0x04000000u)
#define CSL_GPIO_INTSTAT45_STAT26_SHIFT (0x0000001Au)
#define CSL_GPIO_INTSTAT45_STAT26_RESETVAL (0x00000000u)
/*----STAT26 Tokens----*/
#define CSL_GPIO_INTSTAT45_STAT26_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT45_STAT26_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT45_STAT25_MASK (0x02000000u)
#define CSL_GPIO_INTSTAT45_STAT25_SHIFT (0x00000019u)
#define CSL_GPIO_INTSTAT45_STAT25_RESETVAL (0x00000000u)
/*----STAT25 Tokens----*/
#define CSL_GPIO_INTSTAT45_STAT25_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT45_STAT25_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT45_STAT24_MASK (0x01000000u)
#define CSL_GPIO_INTSTAT45_STAT24_SHIFT (0x00000018u)
#define CSL_GPIO_INTSTAT45_STAT24_RESETVAL (0x00000000u)
/*----STAT24 Tokens----*/
#define CSL_GPIO_INTSTAT45_STAT24_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT45_STAT24_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT45_STAT23_MASK (0x00800000u)
#define CSL_GPIO_INTSTAT45_STAT23_SHIFT (0x00000017u)
#define CSL_GPIO_INTSTAT45_STAT23_RESETVAL (0x00000000u)
/*----STAT23 Tokens----*/
#define CSL_GPIO_INTSTAT45_STAT23_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT45_STAT23_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT45_STAT22_MASK (0x00400000u)
#define CSL_GPIO_INTSTAT45_STAT22_SHIFT (0x00000016u)
#define CSL_GPIO_INTSTAT45_STAT22_RESETVAL (0x00000000u)
/*----STAT22 Tokens----*/
#define CSL_GPIO_INTSTAT45_STAT22_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT45_STAT22_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT45_STAT21_MASK (0x00200000u)
#define CSL_GPIO_INTSTAT45_STAT21_SHIFT (0x00000015u)
#define CSL_GPIO_INTSTAT45_STAT21_RESETVAL (0x00000000u)
/*----STAT21 Tokens----*/
#define CSL_GPIO_INTSTAT45_STAT21_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT45_STAT21_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT45_STAT20_MASK (0x00100000u)
#define CSL_GPIO_INTSTAT45_STAT20_SHIFT (0x00000014u)
#define CSL_GPIO_INTSTAT45_STAT20_RESETVAL (0x00000000u)
/*----STAT20 Tokens----*/
#define CSL_GPIO_INTSTAT45_STAT20_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT45_STAT20_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT45_STAT19_MASK (0x00080000u)
#define CSL_GPIO_INTSTAT45_STAT19_SHIFT (0x00000013u)
#define CSL_GPIO_INTSTAT45_STAT19_RESETVAL (0x00000000u)
/*----STAT19 Tokens----*/
#define CSL_GPIO_INTSTAT45_STAT19_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT45_STAT19_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT45_STAT18_MASK (0x00040000u)
#define CSL_GPIO_INTSTAT45_STAT18_SHIFT (0x00000012u)
#define CSL_GPIO_INTSTAT45_STAT18_RESETVAL (0x00000000u)
/*----STAT18 Tokens----*/
#define CSL_GPIO_INTSTAT45_STAT18_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT45_STAT18_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT45_STAT17_MASK (0x00020000u)
#define CSL_GPIO_INTSTAT45_STAT17_SHIFT (0x00000011u)
#define CSL_GPIO_INTSTAT45_STAT17_RESETVAL (0x00000000u)
/*----STAT17 Tokens----*/
#define CSL_GPIO_INTSTAT45_STAT17_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT45_STAT17_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT45_STAT16_MASK (0x00010000u)
#define CSL_GPIO_INTSTAT45_STAT16_SHIFT (0x00000010u)
#define CSL_GPIO_INTSTAT45_STAT16_RESETVAL (0x00000000u)
/*----STAT16 Tokens----*/
#define CSL_GPIO_INTSTAT45_STAT16_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT45_STAT16_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT45_STAT15_MASK (0x00008000u)
#define CSL_GPIO_INTSTAT45_STAT15_SHIFT (0x0000000Fu)
#define CSL_GPIO_INTSTAT45_STAT15_RESETVAL (0x00000000u)
/*----STAT15 Tokens----*/
#define CSL_GPIO_INTSTAT45_STAT15_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT45_STAT15_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT45_STAT14_MASK (0x00004000u)
#define CSL_GPIO_INTSTAT45_STAT14_SHIFT (0x0000000Eu)
#define CSL_GPIO_INTSTAT45_STAT14_RESETVAL (0x00000000u)
/*----STAT14 Tokens----*/
#define CSL_GPIO_INTSTAT45_STAT14_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT45_STAT14_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT45_STAT13_MASK (0x00002000u)
#define CSL_GPIO_INTSTAT45_STAT13_SHIFT (0x0000000Du)
#define CSL_GPIO_INTSTAT45_STAT13_RESETVAL (0x00000000u)
/*----STAT13 Tokens----*/
#define CSL_GPIO_INTSTAT45_STAT13_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT45_STAT13_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT45_STAT12_MASK (0x00001000u)
#define CSL_GPIO_INTSTAT45_STAT12_SHIFT (0x0000000Cu)
#define CSL_GPIO_INTSTAT45_STAT12_RESETVAL (0x00000000u)
/*----STAT12 Tokens----*/
#define CSL_GPIO_INTSTAT45_STAT12_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT45_STAT12_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT45_STAT11_MASK (0x00000800u)
#define CSL_GPIO_INTSTAT45_STAT11_SHIFT (0x0000000Bu)
#define CSL_GPIO_INTSTAT45_STAT11_RESETVAL (0x00000000u)
/*----STAT11 Tokens----*/
#define CSL_GPIO_INTSTAT45_STAT11_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT45_STAT11_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT45_STAT10_MASK (0x00000400u)
#define CSL_GPIO_INTSTAT45_STAT10_SHIFT (0x0000000Au)
#define CSL_GPIO_INTSTAT45_STAT10_RESETVAL (0x00000000u)
/*----STAT10 Tokens----*/
#define CSL_GPIO_INTSTAT45_STAT10_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT45_STAT10_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT45_STAT9_MASK (0x00000200u)
#define CSL_GPIO_INTSTAT45_STAT9_SHIFT (0x00000009u)
#define CSL_GPIO_INTSTAT45_STAT9_RESETVAL (0x00000000u)
/*----STAT9 Tokens----*/
#define CSL_GPIO_INTSTAT45_STAT9_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT45_STAT9_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT45_STAT8_MASK (0x00000100u)
#define CSL_GPIO_INTSTAT45_STAT8_SHIFT (0x00000008u)
#define CSL_GPIO_INTSTAT45_STAT8_RESETVAL (0x00000000u)
/*----STAT8 Tokens----*/
#define CSL_GPIO_INTSTAT45_STAT8_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT45_STAT8_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT45_STAT7_MASK (0x00000080u)
#define CSL_GPIO_INTSTAT45_STAT7_SHIFT (0x00000007u)
#define CSL_GPIO_INTSTAT45_STAT7_RESETVAL (0x00000000u)
/*----STAT7 Tokens----*/
#define CSL_GPIO_INTSTAT45_STAT7_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT45_STAT7_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT45_STAT6_MASK (0x00000040u)
#define CSL_GPIO_INTSTAT45_STAT6_SHIFT (0x00000006u)
#define CSL_GPIO_INTSTAT45_STAT6_RESETVAL (0x00000000u)
/*----STAT6 Tokens----*/
#define CSL_GPIO_INTSTAT45_STAT6_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT45_STAT6_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT45_STAT5_MASK (0x00000020u)
#define CSL_GPIO_INTSTAT45_STAT5_SHIFT (0x00000005u)
#define CSL_GPIO_INTSTAT45_STAT5_RESETVAL (0x00000000u)
/*----STAT5 Tokens----*/
#define CSL_GPIO_INTSTAT45_STAT5_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT45_STAT5_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT45_STAT4_MASK (0x00000010u)
#define CSL_GPIO_INTSTAT45_STAT4_SHIFT (0x00000004u)
#define CSL_GPIO_INTSTAT45_STAT4_RESETVAL (0x00000000u)
/*----STAT4 Tokens----*/
#define CSL_GPIO_INTSTAT45_STAT4_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT45_STAT4_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT45_STAT3_MASK (0x00000008u)
#define CSL_GPIO_INTSTAT45_STAT3_SHIFT (0x00000003u)
#define CSL_GPIO_INTSTAT45_STAT3_RESETVAL (0x00000000u)
/*----STAT3 Tokens----*/
#define CSL_GPIO_INTSTAT45_STAT3_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT45_STAT3_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT45_STAT2_MASK (0x00000004u)
#define CSL_GPIO_INTSTAT45_STAT2_SHIFT (0x00000002u)
#define CSL_GPIO_INTSTAT45_STAT2_RESETVAL (0x00000000u)
/*----STAT2 Tokens----*/
#define CSL_GPIO_INTSTAT45_STAT2_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT45_STAT2_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT45_STAT1_MASK (0x00000002u)
#define CSL_GPIO_INTSTAT45_STAT1_SHIFT (0x00000001u)
#define CSL_GPIO_INTSTAT45_STAT1_RESETVAL (0x00000000u)
/*----STAT1 Tokens----*/
#define CSL_GPIO_INTSTAT45_STAT1_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT45_STAT1_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT45_STAT0_MASK (0x00000001u)
#define CSL_GPIO_INTSTAT45_STAT0_SHIFT (0x00000000u)
#define CSL_GPIO_INTSTAT45_STAT0_RESETVAL (0x00000000u)
/*----STAT0 Tokens----*/
#define CSL_GPIO_INTSTAT45_STAT0_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT45_STAT0_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT45_RESETVAL (0x00000000u)

/* DIR6 */


#define CSL_GPIO_DIR6_DIR14_MASK (0x00004000u)
#define CSL_GPIO_DIR6_DIR14_SHIFT (0x0000000Eu)
#define CSL_GPIO_DIR6_DIR14_RESETVAL (0x00000001u)
/*----DIR14 Tokens----*/
#define CSL_GPIO_DIR6_DIR14_OUT (0x00000000u)
#define CSL_GPIO_DIR6_DIR14_IN (0x00000001u)

#define CSL_GPIO_DIR6_DIR13_MASK (0x00002000u)
#define CSL_GPIO_DIR6_DIR13_SHIFT (0x0000000Du)
#define CSL_GPIO_DIR6_DIR13_RESETVAL (0x00000001u)
/*----DIR13 Tokens----*/
#define CSL_GPIO_DIR6_DIR13_OUT (0x00000000u)
#define CSL_GPIO_DIR6_DIR13_IN (0x00000001u)

#define CSL_GPIO_DIR6_DIR12_MASK (0x00001000u)
#define CSL_GPIO_DIR6_DIR12_SHIFT (0x0000000Cu)
#define CSL_GPIO_DIR6_DIR12_RESETVAL (0x00000001u)
/*----DIR12 Tokens----*/
#define CSL_GPIO_DIR6_DIR12_OUT (0x00000000u)
#define CSL_GPIO_DIR6_DIR12_IN (0x00000001u)

#define CSL_GPIO_DIR6_DIR11_MASK (0x00000800u)
#define CSL_GPIO_DIR6_DIR11_SHIFT (0x0000000Bu)
#define CSL_GPIO_DIR6_DIR11_RESETVAL (0x00000001u)
/*----DIR11 Tokens----*/
#define CSL_GPIO_DIR6_DIR11_OUT (0x00000000u)
#define CSL_GPIO_DIR6_DIR11_IN (0x00000001u)

#define CSL_GPIO_DIR6_DIR10_MASK (0x00000400u)
#define CSL_GPIO_DIR6_DIR10_SHIFT (0x0000000Au)
#define CSL_GPIO_DIR6_DIR10_RESETVAL (0x00000001u)
/*----DIR10 Tokens----*/
#define CSL_GPIO_DIR6_DIR10_OUT (0x00000000u)
#define CSL_GPIO_DIR6_DIR10_IN (0x00000001u)

#define CSL_GPIO_DIR6_DIR9_MASK (0x00000200u)
#define CSL_GPIO_DIR6_DIR9_SHIFT (0x00000009u)
#define CSL_GPIO_DIR6_DIR9_RESETVAL (0x00000001u)
/*----DIR9 Tokens----*/
#define CSL_GPIO_DIR6_DIR9_OUT (0x00000000u)
#define CSL_GPIO_DIR6_DIR9_IN (0x00000001u)

#define CSL_GPIO_DIR6_DIR8_MASK (0x00000100u)
#define CSL_GPIO_DIR6_DIR8_SHIFT (0x00000008u)
#define CSL_GPIO_DIR6_DIR8_RESETVAL (0x00000001u)
/*----DIR8 Tokens----*/
#define CSL_GPIO_DIR6_DIR8_OUT (0x00000000u)
#define CSL_GPIO_DIR6_DIR8_IN (0x00000001u)

#define CSL_GPIO_DIR6_DIR7_MASK (0x00000080u)
#define CSL_GPIO_DIR6_DIR7_SHIFT (0x00000007u)
#define CSL_GPIO_DIR6_DIR7_RESETVAL (0x00000001u)
/*----DIR7 Tokens----*/
#define CSL_GPIO_DIR6_DIR7_OUT (0x00000000u)
#define CSL_GPIO_DIR6_DIR7_IN (0x00000001u)

#define CSL_GPIO_DIR6_DIR6_MASK (0x00000040u)
#define CSL_GPIO_DIR6_DIR6_SHIFT (0x00000006u)
#define CSL_GPIO_DIR6_DIR6_RESETVAL (0x00000001u)
/*----DIR6 Tokens----*/
#define CSL_GPIO_DIR6_DIR6_OUT (0x00000000u)
#define CSL_GPIO_DIR6_DIR6_IN (0x00000001u)

#define CSL_GPIO_DIR6_DIR5_MASK (0x00000020u)
#define CSL_GPIO_DIR6_DIR5_SHIFT (0x00000005u)
#define CSL_GPIO_DIR6_DIR5_RESETVAL (0x00000001u)
/*----DIR5 Tokens----*/
#define CSL_GPIO_DIR6_DIR5_OUT (0x00000000u)
#define CSL_GPIO_DIR6_DIR5_IN (0x00000001u)

#define CSL_GPIO_DIR6_DIR4_MASK (0x00000010u)
#define CSL_GPIO_DIR6_DIR4_SHIFT (0x00000004u)
#define CSL_GPIO_DIR6_DIR4_RESETVAL (0x00000001u)
/*----DIR4 Tokens----*/
#define CSL_GPIO_DIR6_DIR4_OUT (0x00000000u)
#define CSL_GPIO_DIR6_DIR4_IN (0x00000001u)

#define CSL_GPIO_DIR6_DIR3_MASK (0x00000008u)
#define CSL_GPIO_DIR6_DIR3_SHIFT (0x00000003u)
#define CSL_GPIO_DIR6_DIR3_RESETVAL (0x00000001u)
/*----DIR3 Tokens----*/
#define CSL_GPIO_DIR6_DIR3_OUT (0x00000000u)
#define CSL_GPIO_DIR6_DIR3_IN (0x00000001u)

#define CSL_GPIO_DIR6_DIR2_MASK (0x00000004u)
#define CSL_GPIO_DIR6_DIR2_SHIFT (0x00000002u)
#define CSL_GPIO_DIR6_DIR2_RESETVAL (0x00000001u)
/*----DIR2 Tokens----*/
#define CSL_GPIO_DIR6_DIR2_OUT (0x00000000u)
#define CSL_GPIO_DIR6_DIR2_IN (0x00000001u)

#define CSL_GPIO_DIR6_DIR1_MASK (0x00000002u)
#define CSL_GPIO_DIR6_DIR1_SHIFT (0x00000001u)
#define CSL_GPIO_DIR6_DIR1_RESETVAL (0x00000001u)
/*----DIR1 Tokens----*/
#define CSL_GPIO_DIR6_DIR1_OUT (0x00000000u)
#define CSL_GPIO_DIR6_DIR1_IN (0x00000001u)

#define CSL_GPIO_DIR6_DIR0_MASK (0x00000001u)
#define CSL_GPIO_DIR6_DIR0_SHIFT (0x00000000u)
#define CSL_GPIO_DIR6_DIR0_RESETVAL (0x00000001u)
/*----DIR0 Tokens----*/
#define CSL_GPIO_DIR6_DIR0_OUT (0x00000000u)
#define CSL_GPIO_DIR6_DIR0_IN (0x00000001u)

#define CSL_GPIO_DIR6_RESETVAL (0x00007FFFu)

/* OUT_DATA6 */


#define CSL_GPIO_OUT_DATA6_OUT14_MASK (0x00004000u)
#define CSL_GPIO_OUT_DATA6_OUT14_SHIFT (0x0000000Eu)
#define CSL_GPIO_OUT_DATA6_OUT14_RESETVAL (0x00000000u)
/*----OUT14 Tokens----*/
#define CSL_GPIO_OUT_DATA6_OUT14_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA6_OUT14_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA6_OUT13_MASK (0x00002000u)
#define CSL_GPIO_OUT_DATA6_OUT13_SHIFT (0x0000000Du)
#define CSL_GPIO_OUT_DATA6_OUT13_RESETVAL (0x00000000u)
/*----OUT13 Tokens----*/
#define CSL_GPIO_OUT_DATA6_OUT13_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA6_OUT13_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA6_OUT12_MASK (0x00001000u)
#define CSL_GPIO_OUT_DATA6_OUT12_SHIFT (0x0000000Cu)
#define CSL_GPIO_OUT_DATA6_OUT12_RESETVAL (0x00000000u)
/*----OUT12 Tokens----*/
#define CSL_GPIO_OUT_DATA6_OUT12_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA6_OUT12_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA6_OUT11_MASK (0x00000800u)
#define CSL_GPIO_OUT_DATA6_OUT11_SHIFT (0x0000000Bu)
#define CSL_GPIO_OUT_DATA6_OUT11_RESETVAL (0x00000000u)
/*----OUT11 Tokens----*/
#define CSL_GPIO_OUT_DATA6_OUT11_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA6_OUT11_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA6_OUT10_MASK (0x00000400u)
#define CSL_GPIO_OUT_DATA6_OUT10_SHIFT (0x0000000Au)
#define CSL_GPIO_OUT_DATA6_OUT10_RESETVAL (0x00000000u)
/*----OUT10 Tokens----*/
#define CSL_GPIO_OUT_DATA6_OUT10_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA6_OUT10_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA6_OUT9_MASK (0x00000200u)
#define CSL_GPIO_OUT_DATA6_OUT9_SHIFT (0x00000009u)
#define CSL_GPIO_OUT_DATA6_OUT9_RESETVAL (0x00000000u)
/*----OUT9 Tokens----*/
#define CSL_GPIO_OUT_DATA6_OUT9_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA6_OUT9_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA6_OUT8_MASK (0x00000100u)
#define CSL_GPIO_OUT_DATA6_OUT8_SHIFT (0x00000008u)
#define CSL_GPIO_OUT_DATA6_OUT8_RESETVAL (0x00000000u)
/*----OUT8 Tokens----*/
#define CSL_GPIO_OUT_DATA6_OUT8_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA6_OUT8_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA6_OUT7_MASK (0x00000080u)
#define CSL_GPIO_OUT_DATA6_OUT7_SHIFT (0x00000007u)
#define CSL_GPIO_OUT_DATA6_OUT7_RESETVAL (0x00000000u)
/*----OUT7 Tokens----*/
#define CSL_GPIO_OUT_DATA6_OUT7_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA6_OUT7_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA6_OUT6_MASK (0x00000040u)
#define CSL_GPIO_OUT_DATA6_OUT6_SHIFT (0x00000006u)
#define CSL_GPIO_OUT_DATA6_OUT6_RESETVAL (0x00000000u)
/*----OUT6 Tokens----*/
#define CSL_GPIO_OUT_DATA6_OUT6_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA6_OUT6_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA6_OUT5_MASK (0x00000020u)
#define CSL_GPIO_OUT_DATA6_OUT5_SHIFT (0x00000005u)
#define CSL_GPIO_OUT_DATA6_OUT5_RESETVAL (0x00000000u)
/*----OUT5 Tokens----*/
#define CSL_GPIO_OUT_DATA6_OUT5_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA6_OUT5_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA6_OUT4_MASK (0x00000010u)
#define CSL_GPIO_OUT_DATA6_OUT4_SHIFT (0x00000004u)
#define CSL_GPIO_OUT_DATA6_OUT4_RESETVAL (0x00000000u)
/*----OUT4 Tokens----*/
#define CSL_GPIO_OUT_DATA6_OUT4_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA6_OUT4_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA6_OUT3_MASK (0x00000008u)
#define CSL_GPIO_OUT_DATA6_OUT3_SHIFT (0x00000003u)
#define CSL_GPIO_OUT_DATA6_OUT3_RESETVAL (0x00000000u)
/*----OUT3 Tokens----*/
#define CSL_GPIO_OUT_DATA6_OUT3_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA6_OUT3_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA6_OUT2_MASK (0x00000004u)
#define CSL_GPIO_OUT_DATA6_OUT2_SHIFT (0x00000002u)
#define CSL_GPIO_OUT_DATA6_OUT2_RESETVAL (0x00000000u)
/*----OUT2 Tokens----*/
#define CSL_GPIO_OUT_DATA6_OUT2_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA6_OUT2_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA6_OUT1_MASK (0x00000002u)
#define CSL_GPIO_OUT_DATA6_OUT1_SHIFT (0x00000001u)
#define CSL_GPIO_OUT_DATA6_OUT1_RESETVAL (0x00000000u)
/*----OUT1 Tokens----*/
#define CSL_GPIO_OUT_DATA6_OUT1_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA6_OUT1_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA6_OUT0_MASK (0x00000001u)
#define CSL_GPIO_OUT_DATA6_OUT0_SHIFT (0x00000000u)
#define CSL_GPIO_OUT_DATA6_OUT0_RESETVAL (0x00000000u)
/*----OUT0 Tokens----*/
#define CSL_GPIO_OUT_DATA6_OUT0_CLR (0x00000000u)
#define CSL_GPIO_OUT_DATA6_OUT0_SET (0x00000001u)

#define CSL_GPIO_OUT_DATA6_RESETVAL (0x00000000u)

/* SET_DATA6 */


#define CSL_GPIO_SET_DATA6_SET14_MASK (0x00004000u)
#define CSL_GPIO_SET_DATA6_SET14_SHIFT (0x0000000Eu)
#define CSL_GPIO_SET_DATA6_SET14_RESETVAL (0x00000000u)
/*----SET14 Tokens----*/
#define CSL_GPIO_SET_DATA6_SET14_SET (0x00000001u)

#define CSL_GPIO_SET_DATA6_SET13_MASK (0x00002000u)
#define CSL_GPIO_SET_DATA6_SET13_SHIFT (0x0000000Du)
#define CSL_GPIO_SET_DATA6_SET13_RESETVAL (0x00000000u)
/*----SET13 Tokens----*/
#define CSL_GPIO_SET_DATA6_SET13_SET (0x00000001u)

#define CSL_GPIO_SET_DATA6_SET12_MASK (0x00001000u)
#define CSL_GPIO_SET_DATA6_SET12_SHIFT (0x0000000Cu)
#define CSL_GPIO_SET_DATA6_SET12_RESETVAL (0x00000000u)
/*----SET12 Tokens----*/
#define CSL_GPIO_SET_DATA6_SET12_SET (0x00000001u)

#define CSL_GPIO_SET_DATA6_SET11_MASK (0x00000800u)
#define CSL_GPIO_SET_DATA6_SET11_SHIFT (0x0000000Bu)
#define CSL_GPIO_SET_DATA6_SET11_RESETVAL (0x00000000u)
/*----SET11 Tokens----*/
#define CSL_GPIO_SET_DATA6_SET11_SET (0x00000001u)

#define CSL_GPIO_SET_DATA6_SET10_MASK (0x00000400u)
#define CSL_GPIO_SET_DATA6_SET10_SHIFT (0x0000000Au)
#define CSL_GPIO_SET_DATA6_SET10_RESETVAL (0x00000000u)
/*----SET10 Tokens----*/
#define CSL_GPIO_SET_DATA6_SET10_SET (0x00000001u)

#define CSL_GPIO_SET_DATA6_SET9_MASK (0x00000200u)
#define CSL_GPIO_SET_DATA6_SET9_SHIFT (0x00000009u)
#define CSL_GPIO_SET_DATA6_SET9_RESETVAL (0x00000000u)
/*----SET9 Tokens----*/
#define CSL_GPIO_SET_DATA6_SET9_SET (0x00000001u)

#define CSL_GPIO_SET_DATA6_SET8_MASK (0x00000100u)
#define CSL_GPIO_SET_DATA6_SET8_SHIFT (0x00000008u)
#define CSL_GPIO_SET_DATA6_SET8_RESETVAL (0x00000000u)
/*----SET8 Tokens----*/
#define CSL_GPIO_SET_DATA6_SET8_SET (0x00000001u)

#define CSL_GPIO_SET_DATA6_SET7_MASK (0x00000080u)
#define CSL_GPIO_SET_DATA6_SET7_SHIFT (0x00000007u)
#define CSL_GPIO_SET_DATA6_SET7_RESETVAL (0x00000000u)
/*----SET7 Tokens----*/
#define CSL_GPIO_SET_DATA6_SET7_SET (0x00000001u)

#define CSL_GPIO_SET_DATA6_SET6_MASK (0x00000040u)
#define CSL_GPIO_SET_DATA6_SET6_SHIFT (0x00000006u)
#define CSL_GPIO_SET_DATA6_SET6_RESETVAL (0x00000000u)
/*----SET6 Tokens----*/
#define CSL_GPIO_SET_DATA6_SET6_SET (0x00000001u)

#define CSL_GPIO_SET_DATA6_SET5_MASK (0x00000020u)
#define CSL_GPIO_SET_DATA6_SET5_SHIFT (0x00000005u)
#define CSL_GPIO_SET_DATA6_SET5_RESETVAL (0x00000000u)
/*----SET5 Tokens----*/
#define CSL_GPIO_SET_DATA6_SET5_SET (0x00000001u)

#define CSL_GPIO_SET_DATA6_SET4_MASK (0x00000010u)
#define CSL_GPIO_SET_DATA6_SET4_SHIFT (0x00000004u)
#define CSL_GPIO_SET_DATA6_SET4_RESETVAL (0x00000000u)
/*----SET4 Tokens----*/
#define CSL_GPIO_SET_DATA6_SET4_SET (0x00000001u)

#define CSL_GPIO_SET_DATA6_SET3_MASK (0x00000008u)
#define CSL_GPIO_SET_DATA6_SET3_SHIFT (0x00000003u)
#define CSL_GPIO_SET_DATA6_SET3_RESETVAL (0x00000000u)
/*----SET3 Tokens----*/
#define CSL_GPIO_SET_DATA6_SET3_SET (0x00000001u)

#define CSL_GPIO_SET_DATA6_SET2_MASK (0x00000004u)
#define CSL_GPIO_SET_DATA6_SET2_SHIFT (0x00000002u)
#define CSL_GPIO_SET_DATA6_SET2_RESETVAL (0x00000000u)
/*----SET2 Tokens----*/
#define CSL_GPIO_SET_DATA6_SET2_SET (0x00000001u)

#define CSL_GPIO_SET_DATA6_SET1_MASK (0x00000002u)
#define CSL_GPIO_SET_DATA6_SET1_SHIFT (0x00000001u)
#define CSL_GPIO_SET_DATA6_SET1_RESETVAL (0x00000000u)
/*----SET1 Tokens----*/
#define CSL_GPIO_SET_DATA6_SET1_SET (0x00000001u)

#define CSL_GPIO_SET_DATA6_SET0_MASK (0x00000001u)
#define CSL_GPIO_SET_DATA6_SET0_SHIFT (0x00000000u)
#define CSL_GPIO_SET_DATA6_SET0_RESETVAL (0x00000000u)
/*----SET0 Tokens----*/
#define CSL_GPIO_SET_DATA6_SET0_SET (0x00000001u)

#define CSL_GPIO_SET_DATA6_RESETVAL (0x00000000u)

/* CLR_DATA6 */


#define CSL_GPIO_CLR_DATA6_CLR14_MASK (0x00004000u)
#define CSL_GPIO_CLR_DATA6_CLR14_SHIFT (0x0000000Eu)
#define CSL_GPIO_CLR_DATA6_CLR14_RESETVAL (0x00000000u)
/*----CLR14 Tokens----*/
#define CSL_GPIO_CLR_DATA6_CLR14_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA6_CLR13_MASK (0x00002000u)
#define CSL_GPIO_CLR_DATA6_CLR13_SHIFT (0x0000000Du)
#define CSL_GPIO_CLR_DATA6_CLR13_RESETVAL (0x00000000u)
/*----CLR13 Tokens----*/
#define CSL_GPIO_CLR_DATA6_CLR13_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA6_CLR12_MASK (0x00001000u)
#define CSL_GPIO_CLR_DATA6_CLR12_SHIFT (0x0000000Cu)
#define CSL_GPIO_CLR_DATA6_CLR12_RESETVAL (0x00000000u)
/*----CLR12 Tokens----*/
#define CSL_GPIO_CLR_DATA6_CLR12_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA6_CLR11_MASK (0x00000800u)
#define CSL_GPIO_CLR_DATA6_CLR11_SHIFT (0x0000000Bu)
#define CSL_GPIO_CLR_DATA6_CLR11_RESETVAL (0x00000000u)
/*----CLR11 Tokens----*/
#define CSL_GPIO_CLR_DATA6_CLR11_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA6_CLR10_MASK (0x00000400u)
#define CSL_GPIO_CLR_DATA6_CLR10_SHIFT (0x0000000Au)
#define CSL_GPIO_CLR_DATA6_CLR10_RESETVAL (0x00000000u)
/*----CLR10 Tokens----*/
#define CSL_GPIO_CLR_DATA6_CLR10_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA6_CLR9_MASK (0x00000200u)
#define CSL_GPIO_CLR_DATA6_CLR9_SHIFT (0x00000009u)
#define CSL_GPIO_CLR_DATA6_CLR9_RESETVAL (0x00000000u)
/*----CLR9 Tokens----*/
#define CSL_GPIO_CLR_DATA6_CLR9_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA6_CLR8_MASK (0x00000100u)
#define CSL_GPIO_CLR_DATA6_CLR8_SHIFT (0x00000008u)
#define CSL_GPIO_CLR_DATA6_CLR8_RESETVAL (0x00000000u)
/*----CLR8 Tokens----*/
#define CSL_GPIO_CLR_DATA6_CLR8_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA6_CLR7_MASK (0x00000080u)
#define CSL_GPIO_CLR_DATA6_CLR7_SHIFT (0x00000007u)
#define CSL_GPIO_CLR_DATA6_CLR7_RESETVAL (0x00000000u)
/*----CLR7 Tokens----*/
#define CSL_GPIO_CLR_DATA6_CLR7_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA6_CLR6_MASK (0x00000040u)
#define CSL_GPIO_CLR_DATA6_CLR6_SHIFT (0x00000006u)
#define CSL_GPIO_CLR_DATA6_CLR6_RESETVAL (0x00000000u)
/*----CLR6 Tokens----*/
#define CSL_GPIO_CLR_DATA6_CLR6_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA6_CLR5_MASK (0x00000020u)
#define CSL_GPIO_CLR_DATA6_CLR5_SHIFT (0x00000005u)
#define CSL_GPIO_CLR_DATA6_CLR5_RESETVAL (0x00000000u)
/*----CLR5 Tokens----*/
#define CSL_GPIO_CLR_DATA6_CLR5_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA6_CLR4_MASK (0x00000010u)
#define CSL_GPIO_CLR_DATA6_CLR4_SHIFT (0x00000004u)
#define CSL_GPIO_CLR_DATA6_CLR4_RESETVAL (0x00000000u)
/*----CLR4 Tokens----*/
#define CSL_GPIO_CLR_DATA6_CLR4_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA6_CLR3_MASK (0x00000008u)
#define CSL_GPIO_CLR_DATA6_CLR3_SHIFT (0x00000003u)
#define CSL_GPIO_CLR_DATA6_CLR3_RESETVAL (0x00000000u)
/*----CLR3 Tokens----*/
#define CSL_GPIO_CLR_DATA6_CLR3_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA6_CLR2_MASK (0x00000004u)
#define CSL_GPIO_CLR_DATA6_CLR2_SHIFT (0x00000002u)
#define CSL_GPIO_CLR_DATA6_CLR2_RESETVAL (0x00000000u)
/*----CLR2 Tokens----*/
#define CSL_GPIO_CLR_DATA6_CLR2_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA6_CLR1_MASK (0x00000002u)
#define CSL_GPIO_CLR_DATA6_CLR1_SHIFT (0x00000001u)
#define CSL_GPIO_CLR_DATA6_CLR1_RESETVAL (0x00000000u)
/*----CLR1 Tokens----*/
#define CSL_GPIO_CLR_DATA6_CLR1_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA6_CLR0_MASK (0x00000001u)
#define CSL_GPIO_CLR_DATA6_CLR0_SHIFT (0x00000000u)
#define CSL_GPIO_CLR_DATA6_CLR0_RESETVAL (0x00000000u)
/*----CLR0 Tokens----*/
#define CSL_GPIO_CLR_DATA6_CLR0_CLR (0x00000001u)

#define CSL_GPIO_CLR_DATA6_RESETVAL (0x00000000u)

/* IN_DATA6 */


#define CSL_GPIO_IN_DATA6_IN14_MASK (0x00004000u)
#define CSL_GPIO_IN_DATA6_IN14_SHIFT (0x0000000Eu)
#define CSL_GPIO_IN_DATA6_IN14_RESETVAL (0x00000000u)
/*----IN14 Tokens----*/
#define CSL_GPIO_IN_DATA6_IN14_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA6_IN14_SET (0x00000001u)

#define CSL_GPIO_IN_DATA6_IN13_MASK (0x00002000u)
#define CSL_GPIO_IN_DATA6_IN13_SHIFT (0x0000000Du)
#define CSL_GPIO_IN_DATA6_IN13_RESETVAL (0x00000000u)
/*----IN13 Tokens----*/
#define CSL_GPIO_IN_DATA6_IN13_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA6_IN13_SET (0x00000001u)

#define CSL_GPIO_IN_DATA6_IN12_MASK (0x00001000u)
#define CSL_GPIO_IN_DATA6_IN12_SHIFT (0x0000000Cu)
#define CSL_GPIO_IN_DATA6_IN12_RESETVAL (0x00000000u)
/*----IN12 Tokens----*/
#define CSL_GPIO_IN_DATA6_IN12_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA6_IN12_SET (0x00000001u)

#define CSL_GPIO_IN_DATA6_IN11_MASK (0x00000800u)
#define CSL_GPIO_IN_DATA6_IN11_SHIFT (0x0000000Bu)
#define CSL_GPIO_IN_DATA6_IN11_RESETVAL (0x00000000u)
/*----IN11 Tokens----*/
#define CSL_GPIO_IN_DATA6_IN11_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA6_IN11_SET (0x00000001u)

#define CSL_GPIO_IN_DATA6_IN10_MASK (0x00000400u)
#define CSL_GPIO_IN_DATA6_IN10_SHIFT (0x0000000Au)
#define CSL_GPIO_IN_DATA6_IN10_RESETVAL (0x00000000u)
/*----IN10 Tokens----*/
#define CSL_GPIO_IN_DATA6_IN10_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA6_IN10_SET (0x00000001u)

#define CSL_GPIO_IN_DATA6_IN9_MASK (0x00000200u)
#define CSL_GPIO_IN_DATA6_IN9_SHIFT (0x00000009u)
#define CSL_GPIO_IN_DATA6_IN9_RESETVAL (0x00000000u)
/*----IN9 Tokens----*/
#define CSL_GPIO_IN_DATA6_IN9_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA6_IN9_SET (0x00000001u)

#define CSL_GPIO_IN_DATA6_IN8_MASK (0x00000100u)
#define CSL_GPIO_IN_DATA6_IN8_SHIFT (0x00000008u)
#define CSL_GPIO_IN_DATA6_IN8_RESETVAL (0x00000000u)
/*----IN8 Tokens----*/
#define CSL_GPIO_IN_DATA6_IN8_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA6_IN8_SET (0x00000001u)

#define CSL_GPIO_IN_DATA6_IN7_MASK (0x00000080u)
#define CSL_GPIO_IN_DATA6_IN7_SHIFT (0x00000007u)
#define CSL_GPIO_IN_DATA6_IN7_RESETVAL (0x00000000u)
/*----IN7 Tokens----*/
#define CSL_GPIO_IN_DATA6_IN7_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA6_IN7_SET (0x00000001u)

#define CSL_GPIO_IN_DATA6_IN6_MASK (0x00000040u)
#define CSL_GPIO_IN_DATA6_IN6_SHIFT (0x00000006u)
#define CSL_GPIO_IN_DATA6_IN6_RESETVAL (0x00000000u)
/*----IN6 Tokens----*/
#define CSL_GPIO_IN_DATA6_IN6_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA6_IN6_SET (0x00000001u)

#define CSL_GPIO_IN_DATA6_IN5_MASK (0x00000020u)
#define CSL_GPIO_IN_DATA6_IN5_SHIFT (0x00000005u)
#define CSL_GPIO_IN_DATA6_IN5_RESETVAL (0x00000000u)
/*----IN5 Tokens----*/
#define CSL_GPIO_IN_DATA6_IN5_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA6_IN5_SET (0x00000001u)

#define CSL_GPIO_IN_DATA6_IN4_MASK (0x00000010u)
#define CSL_GPIO_IN_DATA6_IN4_SHIFT (0x00000004u)
#define CSL_GPIO_IN_DATA6_IN4_RESETVAL (0x00000000u)
/*----IN4 Tokens----*/
#define CSL_GPIO_IN_DATA6_IN4_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA6_IN4_SET (0x00000001u)

#define CSL_GPIO_IN_DATA6_IN3_MASK (0x00000008u)
#define CSL_GPIO_IN_DATA6_IN3_SHIFT (0x00000003u)
#define CSL_GPIO_IN_DATA6_IN3_RESETVAL (0x00000000u)
/*----IN3 Tokens----*/
#define CSL_GPIO_IN_DATA6_IN3_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA6_IN3_SET (0x00000001u)

#define CSL_GPIO_IN_DATA6_IN2_MASK (0x00000004u)
#define CSL_GPIO_IN_DATA6_IN2_SHIFT (0x00000002u)
#define CSL_GPIO_IN_DATA6_IN2_RESETVAL (0x00000000u)
/*----IN2 Tokens----*/
#define CSL_GPIO_IN_DATA6_IN2_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA6_IN2_SET (0x00000001u)

#define CSL_GPIO_IN_DATA6_IN1_MASK (0x00000002u)
#define CSL_GPIO_IN_DATA6_IN1_SHIFT (0x00000001u)
#define CSL_GPIO_IN_DATA6_IN1_RESETVAL (0x00000000u)
/*----IN1 Tokens----*/
#define CSL_GPIO_IN_DATA6_IN1_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA6_IN1_SET (0x00000001u)

#define CSL_GPIO_IN_DATA6_IN0_MASK (0x00000001u)
#define CSL_GPIO_IN_DATA6_IN0_SHIFT (0x00000000u)
#define CSL_GPIO_IN_DATA6_IN0_RESETVAL (0x00000000u)
/*----IN0 Tokens----*/
#define CSL_GPIO_IN_DATA6_IN0_CLR (0x00000000u)
#define CSL_GPIO_IN_DATA6_IN0_SET (0x00000001u)

#define CSL_GPIO_IN_DATA6_RESETVAL (0x00000000u)

/* SET_RIS_TRIG6 */


#define CSL_GPIO_SET_RIS_TRIG6_SETRIS14_MASK (0x00004000u)
#define CSL_GPIO_SET_RIS_TRIG6_SETRIS14_SHIFT (0x0000000Eu)
#define CSL_GPIO_SET_RIS_TRIG6_SETRIS14_RESETVAL (0x00000000u)
/*----SETRIS14 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG6_SETRIS14_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG6_SETRIS13_MASK (0x00002000u)
#define CSL_GPIO_SET_RIS_TRIG6_SETRIS13_SHIFT (0x0000000Du)
#define CSL_GPIO_SET_RIS_TRIG6_SETRIS13_RESETVAL (0x00000000u)
/*----SETRIS13 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG6_SETRIS13_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG6_SETRIS12_MASK (0x00001000u)
#define CSL_GPIO_SET_RIS_TRIG6_SETRIS12_SHIFT (0x0000000Cu)
#define CSL_GPIO_SET_RIS_TRIG6_SETRIS12_RESETVAL (0x00000000u)
/*----SETRIS12 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG6_SETRIS12_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG6_SETRIS11_MASK (0x00000800u)
#define CSL_GPIO_SET_RIS_TRIG6_SETRIS11_SHIFT (0x0000000Bu)
#define CSL_GPIO_SET_RIS_TRIG6_SETRIS11_RESETVAL (0x00000000u)
/*----SETRIS11 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG6_SETRIS11_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG6_SETRIS10_MASK (0x00000400u)
#define CSL_GPIO_SET_RIS_TRIG6_SETRIS10_SHIFT (0x0000000Au)
#define CSL_GPIO_SET_RIS_TRIG6_SETRIS10_RESETVAL (0x00000000u)
/*----SETRIS10 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG6_SETRIS10_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG6_SETRIS9_MASK (0x00000200u)
#define CSL_GPIO_SET_RIS_TRIG6_SETRIS9_SHIFT (0x00000009u)
#define CSL_GPIO_SET_RIS_TRIG6_SETRIS9_RESETVAL (0x00000000u)
/*----SETRIS9 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG6_SETRIS9_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG6_SETRIS8_MASK (0x00000100u)
#define CSL_GPIO_SET_RIS_TRIG6_SETRIS8_SHIFT (0x00000008u)
#define CSL_GPIO_SET_RIS_TRIG6_SETRIS8_RESETVAL (0x00000000u)
/*----SETRIS8 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG6_SETRIS8_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG6_SETRIS7_MASK (0x00000080u)
#define CSL_GPIO_SET_RIS_TRIG6_SETRIS7_SHIFT (0x00000007u)
#define CSL_GPIO_SET_RIS_TRIG6_SETRIS7_RESETVAL (0x00000000u)
/*----SETRIS7 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG6_SETRIS7_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG6_SETRIS6_MASK (0x00000040u)
#define CSL_GPIO_SET_RIS_TRIG6_SETRIS6_SHIFT (0x00000006u)
#define CSL_GPIO_SET_RIS_TRIG6_SETRIS6_RESETVAL (0x00000000u)
/*----SETRIS6 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG6_SETRIS6_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG6_SETRIS5_MASK (0x00000020u)
#define CSL_GPIO_SET_RIS_TRIG6_SETRIS5_SHIFT (0x00000005u)
#define CSL_GPIO_SET_RIS_TRIG6_SETRIS5_RESETVAL (0x00000000u)
/*----SETRIS5 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG6_SETRIS5_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG6_SETRIS4_MASK (0x00000010u)
#define CSL_GPIO_SET_RIS_TRIG6_SETRIS4_SHIFT (0x00000004u)
#define CSL_GPIO_SET_RIS_TRIG6_SETRIS4_RESETVAL (0x00000000u)
/*----SETRIS4 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG6_SETRIS4_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG6_SETRIS3_MASK (0x00000008u)
#define CSL_GPIO_SET_RIS_TRIG6_SETRIS3_SHIFT (0x00000003u)
#define CSL_GPIO_SET_RIS_TRIG6_SETRIS3_RESETVAL (0x00000000u)
/*----SETRIS3 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG6_SETRIS3_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG6_SETRIS2_MASK (0x00000004u)
#define CSL_GPIO_SET_RIS_TRIG6_SETRIS2_SHIFT (0x00000002u)
#define CSL_GPIO_SET_RIS_TRIG6_SETRIS2_RESETVAL (0x00000000u)
/*----SETRIS2 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG6_SETRIS2_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG6_SETRIS1_MASK (0x00000002u)
#define CSL_GPIO_SET_RIS_TRIG6_SETRIS1_SHIFT (0x00000001u)
#define CSL_GPIO_SET_RIS_TRIG6_SETRIS1_RESETVAL (0x00000000u)
/*----SETRIS1 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG6_SETRIS1_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG6_SETRIS0_MASK (0x00000001u)
#define CSL_GPIO_SET_RIS_TRIG6_SETRIS0_SHIFT (0x00000000u)
#define CSL_GPIO_SET_RIS_TRIG6_SETRIS0_RESETVAL (0x00000000u)
/*----SETRIS0 Tokens----*/
#define CSL_GPIO_SET_RIS_TRIG6_SETRIS0_ENABLE (0x00000001u)

#define CSL_GPIO_SET_RIS_TRIG6_RESETVAL (0x00000000u)

/* CLR_RIS_TRIG6 */


#define CSL_GPIO_CLR_RIS_TRIG6_CLRRIS14_MASK (0x00004000u)
#define CSL_GPIO_CLR_RIS_TRIG6_CLRRIS14_SHIFT (0x0000000Eu)
#define CSL_GPIO_CLR_RIS_TRIG6_CLRRIS14_RESETVAL (0x00000000u)
/*----CLRRIS14 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG6_CLRRIS14_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_RIS_TRIG6_CLRRIS13_MASK (0x00002000u)
#define CSL_GPIO_CLR_RIS_TRIG6_CLRRIS13_SHIFT (0x0000000Du)
#define CSL_GPIO_CLR_RIS_TRIG6_CLRRIS13_RESETVAL (0x00000000u)
/*----CLRRIS13 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG6_CLRRIS13_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_RIS_TRIG6_CLRRIS12_MASK (0x00001000u)
#define CSL_GPIO_CLR_RIS_TRIG6_CLRRIS12_SHIFT (0x0000000Cu)
#define CSL_GPIO_CLR_RIS_TRIG6_CLRRIS12_RESETVAL (0x00000000u)
/*----CLRRIS12 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG6_CLRRIS12_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_RIS_TRIG6_CLRRIS11_MASK (0x00000800u)
#define CSL_GPIO_CLR_RIS_TRIG6_CLRRIS11_SHIFT (0x0000000Bu)
#define CSL_GPIO_CLR_RIS_TRIG6_CLRRIS11_RESETVAL (0x00000000u)
/*----CLRRIS11 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG6_CLRRIS11_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_RIS_TRIG6_CLRRIS10_MASK (0x00000400u)
#define CSL_GPIO_CLR_RIS_TRIG6_CLRRIS10_SHIFT (0x0000000Au)
#define CSL_GPIO_CLR_RIS_TRIG6_CLRRIS10_RESETVAL (0x00000000u)
/*----CLRRIS10 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG6_CLRRIS10_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_RIS_TRIG6_CLRRIS9_MASK (0x00000200u)
#define CSL_GPIO_CLR_RIS_TRIG6_CLRRIS9_SHIFT (0x00000009u)
#define CSL_GPIO_CLR_RIS_TRIG6_CLRRIS9_RESETVAL (0x00000000u)
/*----CLRRIS9 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG6_CLRRIS9_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_RIS_TRIG6_CLRRIS8_MASK (0x00000100u)
#define CSL_GPIO_CLR_RIS_TRIG6_CLRRIS8_SHIFT (0x00000008u)
#define CSL_GPIO_CLR_RIS_TRIG6_CLRRIS8_RESETVAL (0x00000000u)
/*----CLRRIS8 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG6_CLRRIS8_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_RIS_TRIG6_CLRRIS7_MASK (0x00000080u)
#define CSL_GPIO_CLR_RIS_TRIG6_CLRRIS7_SHIFT (0x00000007u)
#define CSL_GPIO_CLR_RIS_TRIG6_CLRRIS7_RESETVAL (0x00000000u)
/*----CLRRIS7 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG6_CLRRIS7_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_RIS_TRIG6_CLRRIS6_MASK (0x00000040u)
#define CSL_GPIO_CLR_RIS_TRIG6_CLRRIS6_SHIFT (0x00000006u)
#define CSL_GPIO_CLR_RIS_TRIG6_CLRRIS6_RESETVAL (0x00000000u)
/*----CLRRIS6 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG6_CLRRIS6_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_RIS_TRIG6_CLRRIS5_MASK (0x00000020u)
#define CSL_GPIO_CLR_RIS_TRIG6_CLRRIS5_SHIFT (0x00000005u)
#define CSL_GPIO_CLR_RIS_TRIG6_CLRRIS5_RESETVAL (0x00000000u)
/*----CLRRIS5 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG6_CLRRIS5_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_RIS_TRIG6_CLRRIS4_MASK (0x00000010u)
#define CSL_GPIO_CLR_RIS_TRIG6_CLRRIS4_SHIFT (0x00000004u)
#define CSL_GPIO_CLR_RIS_TRIG6_CLRRIS4_RESETVAL (0x00000000u)
/*----CLRRIS4 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG6_CLRRIS4_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_RIS_TRIG6_CLRRIS3_MASK (0x00000008u)
#define CSL_GPIO_CLR_RIS_TRIG6_CLRRIS3_SHIFT (0x00000003u)
#define CSL_GPIO_CLR_RIS_TRIG6_CLRRIS3_RESETVAL (0x00000000u)
/*----CLRRIS3 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG6_CLRRIS3_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_RIS_TRIG6_CLRRIS2_MASK (0x00000004u)
#define CSL_GPIO_CLR_RIS_TRIG6_CLRRIS2_SHIFT (0x00000002u)
#define CSL_GPIO_CLR_RIS_TRIG6_CLRRIS2_RESETVAL (0x00000000u)
/*----CLRRIS2 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG6_CLRRIS2_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_RIS_TRIG6_CLRRIS1_MASK (0x00000002u)
#define CSL_GPIO_CLR_RIS_TRIG6_CLRRIS1_SHIFT (0x00000001u)
#define CSL_GPIO_CLR_RIS_TRIG6_CLRRIS1_RESETVAL (0x00000000u)
/*----CLRRIS1 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG6_CLRRIS1_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_RIS_TRIG6_CLRRIS0_MASK (0x00000001u)
#define CSL_GPIO_CLR_RIS_TRIG6_CLRRIS0_SHIFT (0x00000000u)
#define CSL_GPIO_CLR_RIS_TRIG6_CLRRIS0_RESETVAL (0x00000000u)
/*----CLRRIS0 Tokens----*/
#define CSL_GPIO_CLR_RIS_TRIG6_CLRRIS0_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_RIS_TRIG6_RESETVAL (0x00000000u)

/* SET_FAL_TRIG6 */


#define CSL_GPIO_SET_FAL_TRIG6_SETFAL14_MASK (0x00004000u)
#define CSL_GPIO_SET_FAL_TRIG6_SETFAL14_SHIFT (0x0000000Eu)
#define CSL_GPIO_SET_FAL_TRIG6_SETFAL14_RESETVAL (0x00000000u)
/*----SETFAL14 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG6_SETFAL14_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG6_SETFAL13_MASK (0x00002000u)
#define CSL_GPIO_SET_FAL_TRIG6_SETFAL13_SHIFT (0x0000000Du)
#define CSL_GPIO_SET_FAL_TRIG6_SETFAL13_RESETVAL (0x00000000u)
/*----SETFAL13 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG6_SETFAL13_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG6_SETFAL12_MASK (0x00001000u)
#define CSL_GPIO_SET_FAL_TRIG6_SETFAL12_SHIFT (0x0000000Cu)
#define CSL_GPIO_SET_FAL_TRIG6_SETFAL12_RESETVAL (0x00000000u)
/*----SETFAL12 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG6_SETFAL12_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG6_SETFAL11_MASK (0x00000800u)
#define CSL_GPIO_SET_FAL_TRIG6_SETFAL11_SHIFT (0x0000000Bu)
#define CSL_GPIO_SET_FAL_TRIG6_SETFAL11_RESETVAL (0x00000000u)
/*----SETFAL11 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG6_SETFAL11_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG6_SETFAL10_MASK (0x00000400u)
#define CSL_GPIO_SET_FAL_TRIG6_SETFAL10_SHIFT (0x0000000Au)
#define CSL_GPIO_SET_FAL_TRIG6_SETFAL10_RESETVAL (0x00000000u)
/*----SETFAL10 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG6_SETFAL10_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG6_SETFAL9_MASK (0x00000200u)
#define CSL_GPIO_SET_FAL_TRIG6_SETFAL9_SHIFT (0x00000009u)
#define CSL_GPIO_SET_FAL_TRIG6_SETFAL9_RESETVAL (0x00000000u)
/*----SETFAL9 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG6_SETFAL9_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG6_SETFAL8_MASK (0x00000100u)
#define CSL_GPIO_SET_FAL_TRIG6_SETFAL8_SHIFT (0x00000008u)
#define CSL_GPIO_SET_FAL_TRIG6_SETFAL8_RESETVAL (0x00000000u)
/*----SETFAL8 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG6_SETFAL8_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG6_SETFAL7_MASK (0x00000080u)
#define CSL_GPIO_SET_FAL_TRIG6_SETFAL7_SHIFT (0x00000007u)
#define CSL_GPIO_SET_FAL_TRIG6_SETFAL7_RESETVAL (0x00000000u)
/*----SETFAL7 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG6_SETFAL7_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG6_SETFAL6_MASK (0x00000040u)
#define CSL_GPIO_SET_FAL_TRIG6_SETFAL6_SHIFT (0x00000006u)
#define CSL_GPIO_SET_FAL_TRIG6_SETFAL6_RESETVAL (0x00000000u)
/*----SETFAL6 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG6_SETFAL6_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG6_SETFAL5_MASK (0x00000020u)
#define CSL_GPIO_SET_FAL_TRIG6_SETFAL5_SHIFT (0x00000005u)
#define CSL_GPIO_SET_FAL_TRIG6_SETFAL5_RESETVAL (0x00000000u)
/*----SETFAL5 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG6_SETFAL5_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG6_SETFAL4_MASK (0x00000010u)
#define CSL_GPIO_SET_FAL_TRIG6_SETFAL4_SHIFT (0x00000004u)
#define CSL_GPIO_SET_FAL_TRIG6_SETFAL4_RESETVAL (0x00000000u)
/*----SETFAL4 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG6_SETFAL4_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG6_SETFAL3_MASK (0x00000008u)
#define CSL_GPIO_SET_FAL_TRIG6_SETFAL3_SHIFT (0x00000003u)
#define CSL_GPIO_SET_FAL_TRIG6_SETFAL3_RESETVAL (0x00000000u)
/*----SETFAL3 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG6_SETFAL3_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG6_SETFAL2_MASK (0x00000004u)
#define CSL_GPIO_SET_FAL_TRIG6_SETFAL2_SHIFT (0x00000002u)
#define CSL_GPIO_SET_FAL_TRIG6_SETFAL2_RESETVAL (0x00000000u)
/*----SETFAL2 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG6_SETFAL2_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG6_SETFAL1_MASK (0x00000002u)
#define CSL_GPIO_SET_FAL_TRIG6_SETFAL1_SHIFT (0x00000001u)
#define CSL_GPIO_SET_FAL_TRIG6_SETFAL1_RESETVAL (0x00000000u)
/*----SETFAL1 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG6_SETFAL1_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG6_SETFAL0_MASK (0x00000001u)
#define CSL_GPIO_SET_FAL_TRIG6_SETFAL0_SHIFT (0x00000000u)
#define CSL_GPIO_SET_FAL_TRIG6_SETFAL0_RESETVAL (0x00000000u)
/*----SETFAL0 Tokens----*/
#define CSL_GPIO_SET_FAL_TRIG6_SETFAL0_ENABLE (0x00000001u)

#define CSL_GPIO_SET_FAL_TRIG6_RESETVAL (0x00000000u)

/* CLR_FAL_TRIG6 */


#define CSL_GPIO_CLR_FAL_TRIG6_CLRFAL14_MASK (0x00004000u)
#define CSL_GPIO_CLR_FAL_TRIG6_CLRFAL14_SHIFT (0x0000000Eu)
#define CSL_GPIO_CLR_FAL_TRIG6_CLRFAL14_RESETVAL (0x00000000u)
/*----CLRFAL14 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG6_CLRFAL14_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_FAL_TRIG6_CLRFAL13_MASK (0x00002000u)
#define CSL_GPIO_CLR_FAL_TRIG6_CLRFAL13_SHIFT (0x0000000Du)
#define CSL_GPIO_CLR_FAL_TRIG6_CLRFAL13_RESETVAL (0x00000000u)
/*----CLRFAL13 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG6_CLRFAL13_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_FAL_TRIG6_CLRFAL12_MASK (0x00001000u)
#define CSL_GPIO_CLR_FAL_TRIG6_CLRFAL12_SHIFT (0x0000000Cu)
#define CSL_GPIO_CLR_FAL_TRIG6_CLRFAL12_RESETVAL (0x00000000u)
/*----CLRFAL12 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG6_CLRFAL12_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_FAL_TRIG6_CLRFAL11_MASK (0x00000800u)
#define CSL_GPIO_CLR_FAL_TRIG6_CLRFAL11_SHIFT (0x0000000Bu)
#define CSL_GPIO_CLR_FAL_TRIG6_CLRFAL11_RESETVAL (0x00000000u)
/*----CLRFAL11 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG6_CLRFAL11_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_FAL_TRIG6_CLRFAL10_MASK (0x00000400u)
#define CSL_GPIO_CLR_FAL_TRIG6_CLRFAL10_SHIFT (0x0000000Au)
#define CSL_GPIO_CLR_FAL_TRIG6_CLRFAL10_RESETVAL (0x00000000u)
/*----CLRFAL10 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG6_CLRFAL10_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_FAL_TRIG6_CLRFAL9_MASK (0x00000200u)
#define CSL_GPIO_CLR_FAL_TRIG6_CLRFAL9_SHIFT (0x00000009u)
#define CSL_GPIO_CLR_FAL_TRIG6_CLRFAL9_RESETVAL (0x00000000u)
/*----CLRFAL9 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG6_CLRFAL9_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_FAL_TRIG6_CLRFAL8_MASK (0x00000100u)
#define CSL_GPIO_CLR_FAL_TRIG6_CLRFAL8_SHIFT (0x00000008u)
#define CSL_GPIO_CLR_FAL_TRIG6_CLRFAL8_RESETVAL (0x00000000u)
/*----CLRFAL8 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG6_CLRFAL8_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_FAL_TRIG6_CLRFAL7_MASK (0x00000080u)
#define CSL_GPIO_CLR_FAL_TRIG6_CLRFAL7_SHIFT (0x00000007u)
#define CSL_GPIO_CLR_FAL_TRIG6_CLRFAL7_RESETVAL (0x00000000u)
/*----CLRFAL7 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG6_CLRFAL7_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_FAL_TRIG6_CLRFAL6_MASK (0x00000040u)
#define CSL_GPIO_CLR_FAL_TRIG6_CLRFAL6_SHIFT (0x00000006u)
#define CSL_GPIO_CLR_FAL_TRIG6_CLRFAL6_RESETVAL (0x00000000u)
/*----CLRFAL6 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG6_CLRFAL6_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_FAL_TRIG6_CLRFAL5_MASK (0x00000020u)
#define CSL_GPIO_CLR_FAL_TRIG6_CLRFAL5_SHIFT (0x00000005u)
#define CSL_GPIO_CLR_FAL_TRIG6_CLRFAL5_RESETVAL (0x00000000u)
/*----CLRFAL5 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG6_CLRFAL5_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_FAL_TRIG6_CLRFAL4_MASK (0x00000010u)
#define CSL_GPIO_CLR_FAL_TRIG6_CLRFAL4_SHIFT (0x00000004u)
#define CSL_GPIO_CLR_FAL_TRIG6_CLRFAL4_RESETVAL (0x00000000u)
/*----CLRFAL4 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG6_CLRFAL4_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_FAL_TRIG6_CLRFAL3_MASK (0x00000008u)
#define CSL_GPIO_CLR_FAL_TRIG6_CLRFAL3_SHIFT (0x00000003u)
#define CSL_GPIO_CLR_FAL_TRIG6_CLRFAL3_RESETVAL (0x00000000u)
/*----CLRFAL3 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG6_CLRFAL3_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_FAL_TRIG6_CLRFAL2_MASK (0x00000004u)
#define CSL_GPIO_CLR_FAL_TRIG6_CLRFAL2_SHIFT (0x00000002u)
#define CSL_GPIO_CLR_FAL_TRIG6_CLRFAL2_RESETVAL (0x00000000u)
/*----CLRFAL2 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG6_CLRFAL2_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_FAL_TRIG6_CLRFAL1_MASK (0x00000002u)
#define CSL_GPIO_CLR_FAL_TRIG6_CLRFAL1_SHIFT (0x00000001u)
#define CSL_GPIO_CLR_FAL_TRIG6_CLRFAL1_RESETVAL (0x00000000u)
/*----CLRFAL1 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG6_CLRFAL1_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_FAL_TRIG6_CLRFAL0_MASK (0x00000001u)
#define CSL_GPIO_CLR_FAL_TRIG6_CLRFAL0_SHIFT (0x00000000u)
#define CSL_GPIO_CLR_FAL_TRIG6_CLRFAL0_RESETVAL (0x00000000u)
/*----CLRFAL0 Tokens----*/
#define CSL_GPIO_CLR_FAL_TRIG6_CLRFAL0_DISABLE (0x00000000u)

#define CSL_GPIO_CLR_FAL_TRIG6_RESETVAL (0x00000000u)

/* INTSTAT6 */


#define CSL_GPIO_INTSTAT6_STAT14_MASK (0x00004000u)
#define CSL_GPIO_INTSTAT6_STAT14_SHIFT (0x0000000Eu)
#define CSL_GPIO_INTSTAT6_STAT14_RESETVAL (0x00000000u)
/*----STAT14 Tokens----*/
#define CSL_GPIO_INTSTAT6_STAT14_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT6_STAT14_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT6_STAT13_MASK (0x00002000u)
#define CSL_GPIO_INTSTAT6_STAT13_SHIFT (0x0000000Du)
#define CSL_GPIO_INTSTAT6_STAT13_RESETVAL (0x00000000u)
/*----STAT13 Tokens----*/
#define CSL_GPIO_INTSTAT6_STAT13_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT6_STAT13_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT6_STAT12_MASK (0x00001000u)
#define CSL_GPIO_INTSTAT6_STAT12_SHIFT (0x0000000Cu)
#define CSL_GPIO_INTSTAT6_STAT12_RESETVAL (0x00000000u)
/*----STAT12 Tokens----*/
#define CSL_GPIO_INTSTAT6_STAT12_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT6_STAT12_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT6_STAT11_MASK (0x00000800u)
#define CSL_GPIO_INTSTAT6_STAT11_SHIFT (0x0000000Bu)
#define CSL_GPIO_INTSTAT6_STAT11_RESETVAL (0x00000000u)
/*----STAT11 Tokens----*/
#define CSL_GPIO_INTSTAT6_STAT11_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT6_STAT11_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT6_STAT10_MASK (0x00000400u)
#define CSL_GPIO_INTSTAT6_STAT10_SHIFT (0x0000000Au)
#define CSL_GPIO_INTSTAT6_STAT10_RESETVAL (0x00000000u)
/*----STAT10 Tokens----*/
#define CSL_GPIO_INTSTAT6_STAT10_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT6_STAT10_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT6_STAT9_MASK (0x00000200u)
#define CSL_GPIO_INTSTAT6_STAT9_SHIFT (0x00000009u)
#define CSL_GPIO_INTSTAT6_STAT9_RESETVAL (0x00000000u)
/*----STAT9 Tokens----*/
#define CSL_GPIO_INTSTAT6_STAT9_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT6_STAT9_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT6_STAT8_MASK (0x00000100u)
#define CSL_GPIO_INTSTAT6_STAT8_SHIFT (0x00000008u)
#define CSL_GPIO_INTSTAT6_STAT8_RESETVAL (0x00000000u)
/*----STAT8 Tokens----*/
#define CSL_GPIO_INTSTAT6_STAT8_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT6_STAT8_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT6_STAT7_MASK (0x00000080u)
#define CSL_GPIO_INTSTAT6_STAT7_SHIFT (0x00000007u)
#define CSL_GPIO_INTSTAT6_STAT7_RESETVAL (0x00000000u)
/*----STAT7 Tokens----*/
#define CSL_GPIO_INTSTAT6_STAT7_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT6_STAT7_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT6_STAT6_MASK (0x00000040u)
#define CSL_GPIO_INTSTAT6_STAT6_SHIFT (0x00000006u)
#define CSL_GPIO_INTSTAT6_STAT6_RESETVAL (0x00000000u)
/*----STAT6 Tokens----*/
#define CSL_GPIO_INTSTAT6_STAT6_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT6_STAT6_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT6_STAT5_MASK (0x00000020u)
#define CSL_GPIO_INTSTAT6_STAT5_SHIFT (0x00000005u)
#define CSL_GPIO_INTSTAT6_STAT5_RESETVAL (0x00000000u)
/*----STAT5 Tokens----*/
#define CSL_GPIO_INTSTAT6_STAT5_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT6_STAT5_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT6_STAT4_MASK (0x00000010u)
#define CSL_GPIO_INTSTAT6_STAT4_SHIFT (0x00000004u)
#define CSL_GPIO_INTSTAT6_STAT4_RESETVAL (0x00000000u)
/*----STAT4 Tokens----*/
#define CSL_GPIO_INTSTAT6_STAT4_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT6_STAT4_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT6_STAT3_MASK (0x00000008u)
#define CSL_GPIO_INTSTAT6_STAT3_SHIFT (0x00000003u)
#define CSL_GPIO_INTSTAT6_STAT3_RESETVAL (0x00000000u)
/*----STAT3 Tokens----*/
#define CSL_GPIO_INTSTAT6_STAT3_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT6_STAT3_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT6_STAT2_MASK (0x00000004u)
#define CSL_GPIO_INTSTAT6_STAT2_SHIFT (0x00000002u)
#define CSL_GPIO_INTSTAT6_STAT2_RESETVAL (0x00000000u)
/*----STAT2 Tokens----*/
#define CSL_GPIO_INTSTAT6_STAT2_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT6_STAT2_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT6_STAT1_MASK (0x00000002u)
#define CSL_GPIO_INTSTAT6_STAT1_SHIFT (0x00000001u)
#define CSL_GPIO_INTSTAT6_STAT1_RESETVAL (0x00000000u)
/*----STAT1 Tokens----*/
#define CSL_GPIO_INTSTAT6_STAT1_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT6_STAT1_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT6_STAT0_MASK (0x00000001u)
#define CSL_GPIO_INTSTAT6_STAT0_SHIFT (0x00000000u)
#define CSL_GPIO_INTSTAT6_STAT0_RESETVAL (0x00000000u)
/*----STAT0 Tokens----*/
#define CSL_GPIO_INTSTAT6_STAT0_NOPEND (0x00000000u)
#define CSL_GPIO_INTSTAT6_STAT0_PEND (0x00000001u)

#define CSL_GPIO_INTSTAT6_RESETVAL (0x00000000u)

#ifdef __cplusplus
}
#endif

#endif

