/*  ============================================================================
 *   Copyright (c) Texas Instruments Inc 2002, 2003, 2004, 2005, 2006
 *
 *   Use of this software is controlled by the terms and conditions found in the
 *   license agreement under which this software has been supplied.
 *   ===========================================================================
 */
/** ============================================================================
 *   @file  cslr_hecc.h
 *
 *   @path  $(CSLPATH)\inc
 *
 *   @desc  This file contains the Register Descriptions for HECC
 *          Reference: User Guide SPRU981
 *  ============================================================================
 */
#ifndef _CSLR_HECC_H_
#define _CSLR_HECC_H_

#ifdef __cplusplus
extern "C" {
#endif

#include <ti/sdo/pspdrivers/soc/c6424/dsp/cslr.h>
#include <ti/sdo/pspdrivers/soc/c6424/dsp/tistdtypes.h>

/* Minimum unit = 1 byte */

/**************************************************************************\
* Register Overlay Structure for MBX
\**************************************************************************/
typedef struct  {
    volatile Uint32 MID;
    volatile Uint32 MCF;
    volatile Uint32 MDL;
    volatile Uint32 MDH;
} CSL_HeccMbxRegs;

/**************************************************************************\
* Register Overlay Structure
\**************************************************************************/
typedef struct  {
    volatile Uint32 CANME;
    volatile Uint32 CANMD;
    volatile Uint32 CANTRS;
    volatile Uint32 CANTRR;
    volatile Uint32 CANTA;
    volatile Uint32 CANAA;
    volatile Uint32 CANRMP;
    volatile Uint32 CANRML;
    volatile Uint32 CANRFP;
    volatile Uint8 RSVD0[4];
    volatile Uint32 CANMC;
    volatile Uint32 CANBTC;
    volatile Uint32 CANES;
    volatile Uint32 CANTEC;
    volatile Uint32 CANREC;
    volatile Uint32 CANGIF0;
    volatile Uint32 CANGIM;
    volatile Uint32 CANGIF1;
    volatile Uint32 CANMIM;
    volatile Uint32 CANMIL;
    volatile Uint32 CANOPC;
    volatile Uint32 CANTIOC;
    volatile Uint32 CANRIOC;
    volatile Uint32 CANLNT;
    volatile Uint32 CANTOC;
    volatile Uint32 CANTOS;
    volatile Uint32 CANTIOCE;
    volatile Uint32 CANRIOCE;
    volatile Uint32 CANETC;
    volatile Uint8 RSVD1[3980];
    CSL_HeccMbxRegs MBX[32];
    volatile Uint8 RSVD2[3584];
    volatile Uint32 LAM[32];
    volatile Uint32 MOTS[32];
    volatile Uint32 MOTO[32];
} CSL_HeccRegs;

/**************************************************************************\
* Overlay structure typedef definition
\**************************************************************************/
typedef volatile CSL_HeccRegs         *CSL_HeccRegsOvly;

/**************************************************************************\
* Field Definition Macros
\**************************************************************************/

/* MID */

#define CSL_HECC_MID_IDE_MASK (0x80000000u)
#define CSL_HECC_MID_IDE_SHIFT (0x0000001Fu)
#define CSL_HECC_MID_IDE_RESETVAL (0x00000000u)
/*----IDE Tokens----*/
#define CSL_HECC_MID_IDE_STANDARD (0x00000000u)
#define CSL_HECC_MID_IDE_EXTEMDED (0x00000001u)

#define CSL_HECC_MID_AME_MASK (0x40000000u)
#define CSL_HECC_MID_AME_SHIFT (0x0000001Eu)
#define CSL_HECC_MID_AME_RESETVAL (0x00000000u)
/*----AME Tokens----*/
#define CSL_HECC_MID_AME_DISABLE (0x00000000u)
#define CSL_HECC_MID_AME_ENABLE (0x00000001u)

#define CSL_HECC_MID_AAM_MASK (0x20000000u)
#define CSL_HECC_MID_AAM_SHIFT (0x0000001Du)
#define CSL_HECC_MID_AAM_RESETVAL (0x00000000u)
/*----AAM Tokens----*/
#define CSL_HECC_MID_AAM_DISABLE (0x00000000u)
#define CSL_HECC_MID_AAM_ENABLE (0x00000001u)

#define CSL_HECC_MID_ID_MASK (0x1FFFFFFFu)
#define CSL_HECC_MID_ID_SHIFT (0x00000000u)
#define CSL_HECC_MID_ID_RESETVAL (0x00000000u)

#define CSL_HECC_MID_RESETVAL (0x00000000u)

/* MCF */



#define CSL_HECC_MCF_TPL_MASK (0x00003F00u)
#define CSL_HECC_MCF_TPL_SHIFT (0x00000008u)
#define CSL_HECC_MCF_TPL_RESETVAL (0x00000000u)


#define CSL_HECC_MCF_RTR_MASK (0x00000010u)
#define CSL_HECC_MCF_RTR_SHIFT (0x00000004u)
#define CSL_HECC_MCF_RTR_RESETVAL (0x00000000u)
/*----RTR Tokens----*/
#define CSL_HECC_MCF_RTR_DISABLE (0x00000000u)
#define CSL_HECC_MCF_RTR_ENABLE (0x00000001u)

#define CSL_HECC_MCF_DLC_MASK (0x0000000Fu)
#define CSL_HECC_MCF_DLC_SHIFT (0x00000000u)
#define CSL_HECC_MCF_DLC_RESETVAL (0x00000000u)

#define CSL_HECC_MCF_RESETVAL (0x00000000u)

/* MDL */

#define CSL_HECC_MDL_MDL_MASK (0xFFFFFFFFu)
#define CSL_HECC_MDL_MDL_SHIFT (0x00000000u)
#define CSL_HECC_MDL_MDL_RESETVAL (0x00000000u)

#define CSL_HECC_MDL_RESETVAL (0x00000000u)

/* MDH */

#define CSL_HECC_MDH_MDH_MASK (0xFFFFFFFFu)
#define CSL_HECC_MDH_MDH_SHIFT (0x00000000u)
#define CSL_HECC_MDH_MDH_RESETVAL (0x00000000u)

#define CSL_HECC_MDH_RESETVAL (0x00000000u)

/* CANME */

#define CSL_HECC_CANME_ME31_MASK (0x80000000u)
#define CSL_HECC_CANME_ME31_SHIFT (0x0000001Fu)
#define CSL_HECC_CANME_ME31_RESETVAL (0x00000000u)
/*----ME31 Tokens----*/
#define CSL_HECC_CANME_ME31_DISABLE (0x00000000u)
#define CSL_HECC_CANME_ME31_ENABLE (0x00000001u)

#define CSL_HECC_CANME_ME30_MASK (0x40000000u)
#define CSL_HECC_CANME_ME30_SHIFT (0x0000001Eu)
#define CSL_HECC_CANME_ME30_RESETVAL (0x00000000u)
/*----ME30 Tokens----*/
#define CSL_HECC_CANME_ME30_DISABLE (0x00000000u)
#define CSL_HECC_CANME_ME30_ENABLE (0x00000001u)

#define CSL_HECC_CANME_ME29_MASK (0x20000000u)
#define CSL_HECC_CANME_ME29_SHIFT (0x0000001Du)
#define CSL_HECC_CANME_ME29_RESETVAL (0x00000000u)
/*----ME29 Tokens----*/
#define CSL_HECC_CANME_ME29_DISABLE (0x00000000u)
#define CSL_HECC_CANME_ME29_ENABLE (0x00000001u)

#define CSL_HECC_CANME_ME28_MASK (0x10000000u)
#define CSL_HECC_CANME_ME28_SHIFT (0x0000001Cu)
#define CSL_HECC_CANME_ME28_RESETVAL (0x00000000u)
/*----ME28 Tokens----*/
#define CSL_HECC_CANME_ME28_DISABLE (0x00000000u)
#define CSL_HECC_CANME_ME28_ENABLE (0x00000001u)

#define CSL_HECC_CANME_ME27_MASK (0x08000000u)
#define CSL_HECC_CANME_ME27_SHIFT (0x0000001Bu)
#define CSL_HECC_CANME_ME27_RESETVAL (0x00000000u)
/*----ME27 Tokens----*/
#define CSL_HECC_CANME_ME27_DISABLE (0x00000000u)
#define CSL_HECC_CANME_ME27_ENABLE (0x00000001u)

#define CSL_HECC_CANME_ME26_MASK (0x04000000u)
#define CSL_HECC_CANME_ME26_SHIFT (0x0000001Au)
#define CSL_HECC_CANME_ME26_RESETVAL (0x00000000u)
/*----ME26 Tokens----*/
#define CSL_HECC_CANME_ME26_DISABLE (0x00000000u)
#define CSL_HECC_CANME_ME26_ENABLE (0x00000001u)

#define CSL_HECC_CANME_ME25_MASK (0x02000000u)
#define CSL_HECC_CANME_ME25_SHIFT (0x00000019u)
#define CSL_HECC_CANME_ME25_RESETVAL (0x00000000u)
/*----ME25 Tokens----*/
#define CSL_HECC_CANME_ME25_DISABLE (0x00000000u)
#define CSL_HECC_CANME_ME25_ENABLE (0x00000001u)

#define CSL_HECC_CANME_ME24_MASK (0x01000000u)
#define CSL_HECC_CANME_ME24_SHIFT (0x00000018u)
#define CSL_HECC_CANME_ME24_RESETVAL (0x00000000u)
/*----ME24 Tokens----*/
#define CSL_HECC_CANME_ME24_DISABLE (0x00000000u)
#define CSL_HECC_CANME_ME24_ENABLE (0x00000001u)

#define CSL_HECC_CANME_ME23_MASK (0x00800000u)
#define CSL_HECC_CANME_ME23_SHIFT (0x00000017u)
#define CSL_HECC_CANME_ME23_RESETVAL (0x00000000u)
/*----ME23 Tokens----*/
#define CSL_HECC_CANME_ME23_DISABLE (0x00000000u)
#define CSL_HECC_CANME_ME23_ENABLE (0x00000001u)

#define CSL_HECC_CANME_ME22_MASK (0x00400000u)
#define CSL_HECC_CANME_ME22_SHIFT (0x00000016u)
#define CSL_HECC_CANME_ME22_RESETVAL (0x00000000u)
/*----ME22 Tokens----*/
#define CSL_HECC_CANME_ME22_DISABLE (0x00000000u)
#define CSL_HECC_CANME_ME22_ENABLE (0x00000001u)

#define CSL_HECC_CANME_ME21_MASK (0x00200000u)
#define CSL_HECC_CANME_ME21_SHIFT (0x00000015u)
#define CSL_HECC_CANME_ME21_RESETVAL (0x00000000u)
/*----ME21 Tokens----*/
#define CSL_HECC_CANME_ME21_DISABLE (0x00000000u)
#define CSL_HECC_CANME_ME21_ENABLE (0x00000001u)

#define CSL_HECC_CANME_ME20_MASK (0x00100000u)
#define CSL_HECC_CANME_ME20_SHIFT (0x00000014u)
#define CSL_HECC_CANME_ME20_RESETVAL (0x00000000u)
/*----ME20 Tokens----*/
#define CSL_HECC_CANME_ME20_DISABLE (0x00000000u)
#define CSL_HECC_CANME_ME20_ENABLE (0x00000001u)

#define CSL_HECC_CANME_ME19_MASK (0x00080000u)
#define CSL_HECC_CANME_ME19_SHIFT (0x00000013u)
#define CSL_HECC_CANME_ME19_RESETVAL (0x00000000u)
/*----ME19 Tokens----*/
#define CSL_HECC_CANME_ME19_DISABLE (0x00000000u)
#define CSL_HECC_CANME_ME19_ENABLE (0x00000001u)

#define CSL_HECC_CANME_ME18_MASK (0x00040000u)
#define CSL_HECC_CANME_ME18_SHIFT (0x00000012u)
#define CSL_HECC_CANME_ME18_RESETVAL (0x00000000u)
/*----ME18 Tokens----*/
#define CSL_HECC_CANME_ME18_DISABLE (0x00000000u)
#define CSL_HECC_CANME_ME18_ENABLE (0x00000001u)

#define CSL_HECC_CANME_ME17_MASK (0x00020000u)
#define CSL_HECC_CANME_ME17_SHIFT (0x00000011u)
#define CSL_HECC_CANME_ME17_RESETVAL (0x00000000u)
/*----ME17 Tokens----*/
#define CSL_HECC_CANME_ME17_DISABLE (0x00000000u)
#define CSL_HECC_CANME_ME17_ENABLE (0x00000001u)

#define CSL_HECC_CANME_ME16_MASK (0x00010000u)
#define CSL_HECC_CANME_ME16_SHIFT (0x00000010u)
#define CSL_HECC_CANME_ME16_RESETVAL (0x00000000u)
/*----ME16 Tokens----*/
#define CSL_HECC_CANME_ME16_DISABLE (0x00000000u)
#define CSL_HECC_CANME_ME16_ENABLE (0x00000001u)

#define CSL_HECC_CANME_ME15_MASK (0x00008000u)
#define CSL_HECC_CANME_ME15_SHIFT (0x0000000Fu)
#define CSL_HECC_CANME_ME15_RESETVAL (0x00000000u)
/*----ME15 Tokens----*/
#define CSL_HECC_CANME_ME15_DISABLE (0x00000000u)
#define CSL_HECC_CANME_ME15_ENABLE (0x00000001u)

#define CSL_HECC_CANME_ME14_MASK (0x00004000u)
#define CSL_HECC_CANME_ME14_SHIFT (0x0000000Eu)
#define CSL_HECC_CANME_ME14_RESETVAL (0x00000000u)
/*----ME14 Tokens----*/
#define CSL_HECC_CANME_ME14_DISABLE (0x00000000u)
#define CSL_HECC_CANME_ME14_ENABLE (0x00000001u)

#define CSL_HECC_CANME_ME13_MASK (0x00002000u)
#define CSL_HECC_CANME_ME13_SHIFT (0x0000000Du)
#define CSL_HECC_CANME_ME13_RESETVAL (0x00000000u)
/*----ME13 Tokens----*/
#define CSL_HECC_CANME_ME13_DISABLE (0x00000000u)
#define CSL_HECC_CANME_ME13_ENABLE (0x00000001u)

#define CSL_HECC_CANME_ME12_MASK (0x00001000u)
#define CSL_HECC_CANME_ME12_SHIFT (0x0000000Cu)
#define CSL_HECC_CANME_ME12_RESETVAL (0x00000000u)
/*----ME12 Tokens----*/
#define CSL_HECC_CANME_ME12_DISABLE (0x00000000u)
#define CSL_HECC_CANME_ME12_ENABLE (0x00000001u)

#define CSL_HECC_CANME_ME11_MASK (0x00000800u)
#define CSL_HECC_CANME_ME11_SHIFT (0x0000000Bu)
#define CSL_HECC_CANME_ME11_RESETVAL (0x00000000u)
/*----ME11 Tokens----*/
#define CSL_HECC_CANME_ME11_DISABLE (0x00000000u)
#define CSL_HECC_CANME_ME11_ENABLE (0x00000001u)

#define CSL_HECC_CANME_ME10_MASK (0x00000400u)
#define CSL_HECC_CANME_ME10_SHIFT (0x0000000Au)
#define CSL_HECC_CANME_ME10_RESETVAL (0x00000000u)
/*----ME10 Tokens----*/
#define CSL_HECC_CANME_ME10_DISABLE (0x00000000u)
#define CSL_HECC_CANME_ME10_ENABLE (0x00000001u)

#define CSL_HECC_CANME_ME9_MASK (0x00000200u)
#define CSL_HECC_CANME_ME9_SHIFT (0x00000009u)
#define CSL_HECC_CANME_ME9_RESETVAL (0x00000000u)
/*----ME9 Tokens----*/
#define CSL_HECC_CANME_ME9_DISABLE (0x00000000u)
#define CSL_HECC_CANME_ME9_ENABLE (0x00000001u)

#define CSL_HECC_CANME_ME8_MASK (0x00000100u)
#define CSL_HECC_CANME_ME8_SHIFT (0x00000008u)
#define CSL_HECC_CANME_ME8_RESETVAL (0x00000000u)
/*----ME8 Tokens----*/
#define CSL_HECC_CANME_ME8_DISABLE (0x00000000u)
#define CSL_HECC_CANME_ME8_ENABLE (0x00000001u)

#define CSL_HECC_CANME_ME7_MASK (0x00000080u)
#define CSL_HECC_CANME_ME7_SHIFT (0x00000007u)
#define CSL_HECC_CANME_ME7_RESETVAL (0x00000000u)
/*----ME7 Tokens----*/
#define CSL_HECC_CANME_ME7_DISABLE (0x00000000u)
#define CSL_HECC_CANME_ME7_ENABLE (0x00000001u)

#define CSL_HECC_CANME_ME6_MASK (0x00000040u)
#define CSL_HECC_CANME_ME6_SHIFT (0x00000006u)
#define CSL_HECC_CANME_ME6_RESETVAL (0x00000000u)
/*----ME6 Tokens----*/
#define CSL_HECC_CANME_ME6_DISABLE (0x00000000u)
#define CSL_HECC_CANME_ME6_ENABLE (0x00000001u)

#define CSL_HECC_CANME_ME5_MASK (0x00000020u)
#define CSL_HECC_CANME_ME5_SHIFT (0x00000005u)
#define CSL_HECC_CANME_ME5_RESETVAL (0x00000000u)
/*----ME5 Tokens----*/
#define CSL_HECC_CANME_ME5_DISABLE (0x00000000u)
#define CSL_HECC_CANME_ME5_ENABLE (0x00000001u)

#define CSL_HECC_CANME_ME4_MASK (0x00000010u)
#define CSL_HECC_CANME_ME4_SHIFT (0x00000004u)
#define CSL_HECC_CANME_ME4_RESETVAL (0x00000000u)
/*----ME4 Tokens----*/
#define CSL_HECC_CANME_ME4_DISABLE (0x00000000u)
#define CSL_HECC_CANME_ME4_ENABLE (0x00000001u)

#define CSL_HECC_CANME_ME3_MASK (0x00000008u)
#define CSL_HECC_CANME_ME3_SHIFT (0x00000003u)
#define CSL_HECC_CANME_ME3_RESETVAL (0x00000000u)
/*----ME3 Tokens----*/
#define CSL_HECC_CANME_ME3_DISABLE (0x00000000u)
#define CSL_HECC_CANME_ME3_ENABLE (0x00000001u)

#define CSL_HECC_CANME_ME2_MASK (0x00000004u)
#define CSL_HECC_CANME_ME2_SHIFT (0x00000002u)
#define CSL_HECC_CANME_ME2_RESETVAL (0x00000000u)
/*----ME2 Tokens----*/
#define CSL_HECC_CANME_ME2_DISABLE (0x00000000u)
#define CSL_HECC_CANME_ME2_ENABLE (0x00000001u)

#define CSL_HECC_CANME_ME1_MASK (0x00000002u)
#define CSL_HECC_CANME_ME1_SHIFT (0x00000001u)
#define CSL_HECC_CANME_ME1_RESETVAL (0x00000000u)
/*----ME1 Tokens----*/
#define CSL_HECC_CANME_ME1_DISABLE (0x00000000u)
#define CSL_HECC_CANME_ME1_ENABLE (0x00000001u)

#define CSL_HECC_CANME_ME0_MASK (0x00000001u)
#define CSL_HECC_CANME_ME0_SHIFT (0x00000000u)
#define CSL_HECC_CANME_ME0_RESETVAL (0x00000000u)
/*----ME0 Tokens----*/
#define CSL_HECC_CANME_ME0_DISABLE (0x00000000u)
#define CSL_HECC_CANME_ME0_ENABLE (0x00000001u)

#define CSL_HECC_CANME_RESETVAL (0x00000000u)

/* CANMD */

#define CSL_HECC_CANMD_MD31_MASK (0x80000000u)
#define CSL_HECC_CANMD_MD31_SHIFT (0x0000001Fu)
#define CSL_HECC_CANMD_MD31_RESETVAL (0x00000000u)
/*----MD31 Tokens----*/
#define CSL_HECC_CANMD_MD31_TX (0x00000000u)
#define CSL_HECC_CANMD_MD31_RX (0x00000001u)

#define CSL_HECC_CANMD_MD30_MASK (0x40000000u)
#define CSL_HECC_CANMD_MD30_SHIFT (0x0000001Eu)
#define CSL_HECC_CANMD_MD30_RESETVAL (0x00000000u)
/*----MD30 Tokens----*/
#define CSL_HECC_CANMD_MD30_TX (0x00000000u)
#define CSL_HECC_CANMD_MD30_RX (0x00000001u)

#define CSL_HECC_CANMD_MD29_MASK (0x20000000u)
#define CSL_HECC_CANMD_MD29_SHIFT (0x0000001Du)
#define CSL_HECC_CANMD_MD29_RESETVAL (0x00000000u)
/*----MD29 Tokens----*/
#define CSL_HECC_CANMD_MD29_TX (0x00000000u)
#define CSL_HECC_CANMD_MD29_RX (0x00000001u)

#define CSL_HECC_CANMD_MD28_MASK (0x10000000u)
#define CSL_HECC_CANMD_MD28_SHIFT (0x0000001Cu)
#define CSL_HECC_CANMD_MD28_RESETVAL (0x00000000u)
/*----MD28 Tokens----*/
#define CSL_HECC_CANMD_MD28_TX (0x00000000u)
#define CSL_HECC_CANMD_MD28_RX (0x00000001u)

#define CSL_HECC_CANMD_MD27_MASK (0x08000000u)
#define CSL_HECC_CANMD_MD27_SHIFT (0x0000001Bu)
#define CSL_HECC_CANMD_MD27_RESETVAL (0x00000000u)
/*----MD27 Tokens----*/
#define CSL_HECC_CANMD_MD27_TX (0x00000000u)
#define CSL_HECC_CANMD_MD27_RX (0x00000001u)

#define CSL_HECC_CANMD_MD26_MASK (0x04000000u)
#define CSL_HECC_CANMD_MD26_SHIFT (0x0000001Au)
#define CSL_HECC_CANMD_MD26_RESETVAL (0x00000000u)
/*----MD26 Tokens----*/
#define CSL_HECC_CANMD_MD26_TX (0x00000000u)
#define CSL_HECC_CANMD_MD26_RX (0x00000001u)

#define CSL_HECC_CANMD_MD25_MASK (0x02000000u)
#define CSL_HECC_CANMD_MD25_SHIFT (0x00000019u)
#define CSL_HECC_CANMD_MD25_RESETVAL (0x00000000u)
/*----MD25 Tokens----*/
#define CSL_HECC_CANMD_MD25_TX (0x00000000u)
#define CSL_HECC_CANMD_MD25_RX (0x00000001u)

#define CSL_HECC_CANMD_MD24_MASK (0x01000000u)
#define CSL_HECC_CANMD_MD24_SHIFT (0x00000018u)
#define CSL_HECC_CANMD_MD24_RESETVAL (0x00000000u)
/*----MD24 Tokens----*/
#define CSL_HECC_CANMD_MD24_TX (0x00000000u)
#define CSL_HECC_CANMD_MD24_RX (0x00000001u)

#define CSL_HECC_CANMD_MD23_MASK (0x00800000u)
#define CSL_HECC_CANMD_MD23_SHIFT (0x00000017u)
#define CSL_HECC_CANMD_MD23_RESETVAL (0x00000000u)
/*----MD23 Tokens----*/
#define CSL_HECC_CANMD_MD23_TX (0x00000000u)
#define CSL_HECC_CANMD_MD23_RX (0x00000001u)

#define CSL_HECC_CANMD_MD22_MASK (0x00400000u)
#define CSL_HECC_CANMD_MD22_SHIFT (0x00000016u)
#define CSL_HECC_CANMD_MD22_RESETVAL (0x00000000u)
/*----MD22 Tokens----*/
#define CSL_HECC_CANMD_MD22_TX (0x00000000u)
#define CSL_HECC_CANMD_MD22_RX (0x00000001u)

#define CSL_HECC_CANMD_MD21_MASK (0x00200000u)
#define CSL_HECC_CANMD_MD21_SHIFT (0x00000015u)
#define CSL_HECC_CANMD_MD21_RESETVAL (0x00000000u)
/*----MD21 Tokens----*/
#define CSL_HECC_CANMD_MD21_TX (0x00000000u)
#define CSL_HECC_CANMD_MD21_RX (0x00000001u)

#define CSL_HECC_CANMD_MD20_MASK (0x00100000u)
#define CSL_HECC_CANMD_MD20_SHIFT (0x00000014u)
#define CSL_HECC_CANMD_MD20_RESETVAL (0x00000000u)
/*----MD20 Tokens----*/
#define CSL_HECC_CANMD_MD20_TX (0x00000000u)
#define CSL_HECC_CANMD_MD20_RX (0x00000001u)

#define CSL_HECC_CANMD_MD19_MASK (0x00080000u)
#define CSL_HECC_CANMD_MD19_SHIFT (0x00000013u)
#define CSL_HECC_CANMD_MD19_RESETVAL (0x00000000u)
/*----MD19 Tokens----*/
#define CSL_HECC_CANMD_MD19_TX (0x00000000u)
#define CSL_HECC_CANMD_MD19_RX (0x00000001u)

#define CSL_HECC_CANMD_MD18_MASK (0x00040000u)
#define CSL_HECC_CANMD_MD18_SHIFT (0x00000012u)
#define CSL_HECC_CANMD_MD18_RESETVAL (0x00000000u)
/*----MD18 Tokens----*/
#define CSL_HECC_CANMD_MD18_TX (0x00000000u)
#define CSL_HECC_CANMD_MD18_RX (0x00000001u)

#define CSL_HECC_CANMD_MD17_MASK (0x00020000u)
#define CSL_HECC_CANMD_MD17_SHIFT (0x00000011u)
#define CSL_HECC_CANMD_MD17_RESETVAL (0x00000000u)
/*----MD17 Tokens----*/
#define CSL_HECC_CANMD_MD17_TX (0x00000000u)
#define CSL_HECC_CANMD_MD17_RX (0x00000001u)

#define CSL_HECC_CANMD_MD16_MASK (0x00010000u)
#define CSL_HECC_CANMD_MD16_SHIFT (0x00000010u)
#define CSL_HECC_CANMD_MD16_RESETVAL (0x00000000u)
/*----MD16 Tokens----*/
#define CSL_HECC_CANMD_MD16_TX (0x00000000u)
#define CSL_HECC_CANMD_MD16_RX (0x00000001u)

#define CSL_HECC_CANMD_MD15_MASK (0x00008000u)
#define CSL_HECC_CANMD_MD15_SHIFT (0x0000000Fu)
#define CSL_HECC_CANMD_MD15_RESETVAL (0x00000000u)
/*----MD15 Tokens----*/
#define CSL_HECC_CANMD_MD15_TX (0x00000000u)
#define CSL_HECC_CANMD_MD15_RX (0x00000001u)

#define CSL_HECC_CANMD_MD14_MASK (0x00004000u)
#define CSL_HECC_CANMD_MD14_SHIFT (0x0000000Eu)
#define CSL_HECC_CANMD_MD14_RESETVAL (0x00000000u)
/*----MD14 Tokens----*/
#define CSL_HECC_CANMD_MD14_TX (0x00000000u)
#define CSL_HECC_CANMD_MD14_RX (0x00000001u)

#define CSL_HECC_CANMD_MD13_MASK (0x00002000u)
#define CSL_HECC_CANMD_MD13_SHIFT (0x0000000Du)
#define CSL_HECC_CANMD_MD13_RESETVAL (0x00000000u)
/*----MD13 Tokens----*/
#define CSL_HECC_CANMD_MD13_TX (0x00000000u)
#define CSL_HECC_CANMD_MD13_RX (0x00000001u)

#define CSL_HECC_CANMD_MD12_MASK (0x00001000u)
#define CSL_HECC_CANMD_MD12_SHIFT (0x0000000Cu)
#define CSL_HECC_CANMD_MD12_RESETVAL (0x00000000u)
/*----MD12 Tokens----*/
#define CSL_HECC_CANMD_MD12_TX (0x00000000u)
#define CSL_HECC_CANMD_MD12_RX (0x00000001u)

#define CSL_HECC_CANMD_MD11_MASK (0x00000800u)
#define CSL_HECC_CANMD_MD11_SHIFT (0x0000000Bu)
#define CSL_HECC_CANMD_MD11_RESETVAL (0x00000000u)
/*----MD11 Tokens----*/
#define CSL_HECC_CANMD_MD11_TX (0x00000000u)
#define CSL_HECC_CANMD_MD11_RX (0x00000001u)

#define CSL_HECC_CANMD_MD10_MASK (0x00000400u)
#define CSL_HECC_CANMD_MD10_SHIFT (0x0000000Au)
#define CSL_HECC_CANMD_MD10_RESETVAL (0x00000000u)
/*----MD10 Tokens----*/
#define CSL_HECC_CANMD_MD10_TX (0x00000000u)
#define CSL_HECC_CANMD_MD10_RX (0x00000001u)

#define CSL_HECC_CANMD_MD9_MASK (0x00000200u)
#define CSL_HECC_CANMD_MD9_SHIFT (0x00000009u)
#define CSL_HECC_CANMD_MD9_RESETVAL (0x00000000u)
/*----MD9 Tokens----*/
#define CSL_HECC_CANMD_MD9_TX (0x00000000u)
#define CSL_HECC_CANMD_MD9_RX (0x00000001u)

#define CSL_HECC_CANMD_MD8_MASK (0x00000100u)
#define CSL_HECC_CANMD_MD8_SHIFT (0x00000008u)
#define CSL_HECC_CANMD_MD8_RESETVAL (0x00000000u)
/*----MD8 Tokens----*/
#define CSL_HECC_CANMD_MD8_TX (0x00000000u)
#define CSL_HECC_CANMD_MD8_RX (0x00000001u)

#define CSL_HECC_CANMD_MD7_MASK (0x00000080u)
#define CSL_HECC_CANMD_MD7_SHIFT (0x00000007u)
#define CSL_HECC_CANMD_MD7_RESETVAL (0x00000000u)
/*----MD7 Tokens----*/
#define CSL_HECC_CANMD_MD7_TX (0x00000000u)
#define CSL_HECC_CANMD_MD7_RX (0x00000001u)

#define CSL_HECC_CANMD_MD6_MASK (0x00000040u)
#define CSL_HECC_CANMD_MD6_SHIFT (0x00000006u)
#define CSL_HECC_CANMD_MD6_RESETVAL (0x00000000u)
/*----MD6 Tokens----*/
#define CSL_HECC_CANMD_MD6_TX (0x00000000u)
#define CSL_HECC_CANMD_MD6_RX (0x00000001u)

#define CSL_HECC_CANMD_MD5_MASK (0x00000020u)
#define CSL_HECC_CANMD_MD5_SHIFT (0x00000005u)
#define CSL_HECC_CANMD_MD5_RESETVAL (0x00000000u)
/*----MD5 Tokens----*/
#define CSL_HECC_CANMD_MD5_TX (0x00000000u)
#define CSL_HECC_CANMD_MD5_RX (0x00000001u)

#define CSL_HECC_CANMD_MD4_MASK (0x00000010u)
#define CSL_HECC_CANMD_MD4_SHIFT (0x00000004u)
#define CSL_HECC_CANMD_MD4_RESETVAL (0x00000000u)
/*----MD4 Tokens----*/
#define CSL_HECC_CANMD_MD4_TX (0x00000000u)
#define CSL_HECC_CANMD_MD4_RX (0x00000001u)

#define CSL_HECC_CANMD_MD3_MASK (0x00000008u)
#define CSL_HECC_CANMD_MD3_SHIFT (0x00000003u)
#define CSL_HECC_CANMD_MD3_RESETVAL (0x00000000u)
/*----MD3 Tokens----*/
#define CSL_HECC_CANMD_MD3_TX (0x00000000u)
#define CSL_HECC_CANMD_MD3_RX (0x00000001u)

#define CSL_HECC_CANMD_MD2_MASK (0x00000004u)
#define CSL_HECC_CANMD_MD2_SHIFT (0x00000002u)
#define CSL_HECC_CANMD_MD2_RESETVAL (0x00000000u)
/*----MD2 Tokens----*/
#define CSL_HECC_CANMD_MD2_TX (0x00000000u)
#define CSL_HECC_CANMD_MD2_RX (0x00000001u)

#define CSL_HECC_CANMD_MD1_MASK (0x00000002u)
#define CSL_HECC_CANMD_MD1_SHIFT (0x00000001u)
#define CSL_HECC_CANMD_MD1_RESETVAL (0x00000000u)
/*----MD1 Tokens----*/
#define CSL_HECC_CANMD_MD1_TX (0x00000000u)
#define CSL_HECC_CANMD_MD1_RX (0x00000001u)

#define CSL_HECC_CANMD_MD0_MASK (0x00000001u)
#define CSL_HECC_CANMD_MD0_SHIFT (0x00000000u)
#define CSL_HECC_CANMD_MD0_RESETVAL (0x00000000u)
/*----MD0 Tokens----*/
#define CSL_HECC_CANMD_MD0_TX (0x00000000u)
#define CSL_HECC_CANMD_MD0_RX (0x00000001u)

#define CSL_HECC_CANMD_RESETVAL (0x00000000u)

/* CANTRS */

#define CSL_HECC_CANTRS_TRS31_MASK (0x80000000u)
#define CSL_HECC_CANTRS_TRS31_SHIFT (0x0000001Fu)
#define CSL_HECC_CANTRS_TRS31_RESETVAL (0x00000000u)
/*----TRS31 Tokens----*/
#define CSL_HECC_CANTRS_TRS31_NOP (0x00000000u)
#define CSL_HECC_CANTRS_TRS31_TRANSMIT (0x00000001u)

#define CSL_HECC_CANTRS_TRS30_MASK (0x40000000u)
#define CSL_HECC_CANTRS_TRS30_SHIFT (0x0000001Eu)
#define CSL_HECC_CANTRS_TRS30_RESETVAL (0x00000000u)
/*----TRS30 Tokens----*/
#define CSL_HECC_CANTRS_TRS30_NOP (0x00000000u)
#define CSL_HECC_CANTRS_TRS30_TRANSMIT (0x00000001u)

#define CSL_HECC_CANTRS_TRS29_MASK (0x20000000u)
#define CSL_HECC_CANTRS_TRS29_SHIFT (0x0000001Du)
#define CSL_HECC_CANTRS_TRS29_RESETVAL (0x00000000u)
/*----TRS29 Tokens----*/
#define CSL_HECC_CANTRS_TRS29_NOP (0x00000000u)
#define CSL_HECC_CANTRS_TRS29_TRANSMIT (0x00000001u)

#define CSL_HECC_CANTRS_TRS28_MASK (0x10000000u)
#define CSL_HECC_CANTRS_TRS28_SHIFT (0x0000001Cu)
#define CSL_HECC_CANTRS_TRS28_RESETVAL (0x00000000u)
/*----TRS28 Tokens----*/
#define CSL_HECC_CANTRS_TRS28_NOP (0x00000000u)
#define CSL_HECC_CANTRS_TRS28_TRANSMIT (0x00000001u)

#define CSL_HECC_CANTRS_TRS27_MASK (0x08000000u)
#define CSL_HECC_CANTRS_TRS27_SHIFT (0x0000001Bu)
#define CSL_HECC_CANTRS_TRS27_RESETVAL (0x00000000u)
/*----TRS27 Tokens----*/
#define CSL_HECC_CANTRS_TRS27_NOP (0x00000000u)
#define CSL_HECC_CANTRS_TRS27_TRANSMIT (0x00000001u)

#define CSL_HECC_CANTRS_TRS26_MASK (0x04000000u)
#define CSL_HECC_CANTRS_TRS26_SHIFT (0x0000001Au)
#define CSL_HECC_CANTRS_TRS26_RESETVAL (0x00000000u)
/*----TRS26 Tokens----*/
#define CSL_HECC_CANTRS_TRS26_NOP (0x00000000u)
#define CSL_HECC_CANTRS_TRS26_TRANSMIT (0x00000001u)

#define CSL_HECC_CANTRS_TRS25_MASK (0x02000000u)
#define CSL_HECC_CANTRS_TRS25_SHIFT (0x00000019u)
#define CSL_HECC_CANTRS_TRS25_RESETVAL (0x00000000u)
/*----TRS25 Tokens----*/
#define CSL_HECC_CANTRS_TRS25_NOP (0x00000000u)
#define CSL_HECC_CANTRS_TRS25_TRANSMIT (0x00000001u)

#define CSL_HECC_CANTRS_TRS24_MASK (0x01000000u)
#define CSL_HECC_CANTRS_TRS24_SHIFT (0x00000018u)
#define CSL_HECC_CANTRS_TRS24_RESETVAL (0x00000000u)
/*----TRS24 Tokens----*/
#define CSL_HECC_CANTRS_TRS24_NOP (0x00000000u)
#define CSL_HECC_CANTRS_TRS24_TRANSMIT (0x00000001u)

#define CSL_HECC_CANTRS_TRS23_MASK (0x00800000u)
#define CSL_HECC_CANTRS_TRS23_SHIFT (0x00000017u)
#define CSL_HECC_CANTRS_TRS23_RESETVAL (0x00000000u)
/*----TRS23 Tokens----*/
#define CSL_HECC_CANTRS_TRS23_NOP (0x00000000u)
#define CSL_HECC_CANTRS_TRS23_TRANSMIT (0x00000001u)

#define CSL_HECC_CANTRS_TRS22_MASK (0x00400000u)
#define CSL_HECC_CANTRS_TRS22_SHIFT (0x00000016u)
#define CSL_HECC_CANTRS_TRS22_RESETVAL (0x00000000u)
/*----TRS22 Tokens----*/
#define CSL_HECC_CANTRS_TRS22_NOP (0x00000000u)
#define CSL_HECC_CANTRS_TRS22_TRANSMIT (0x00000001u)

#define CSL_HECC_CANTRS_TRS21_MASK (0x00200000u)
#define CSL_HECC_CANTRS_TRS21_SHIFT (0x00000015u)
#define CSL_HECC_CANTRS_TRS21_RESETVAL (0x00000000u)
/*----TRS21 Tokens----*/
#define CSL_HECC_CANTRS_TRS21_NOP (0x00000000u)
#define CSL_HECC_CANTRS_TRS21_TRANSMIT (0x00000001u)

#define CSL_HECC_CANTRS_TRS20_MASK (0x00100000u)
#define CSL_HECC_CANTRS_TRS20_SHIFT (0x00000014u)
#define CSL_HECC_CANTRS_TRS20_RESETVAL (0x00000000u)
/*----TRS20 Tokens----*/
#define CSL_HECC_CANTRS_TRS20_NOP (0x00000000u)
#define CSL_HECC_CANTRS_TRS20_TRANSMIT (0x00000001u)

#define CSL_HECC_CANTRS_TRS19_MASK (0x00080000u)
#define CSL_HECC_CANTRS_TRS19_SHIFT (0x00000013u)
#define CSL_HECC_CANTRS_TRS19_RESETVAL (0x00000000u)
/*----TRS19 Tokens----*/
#define CSL_HECC_CANTRS_TRS19_NOP (0x00000000u)
#define CSL_HECC_CANTRS_TRS19_TRANSMIT (0x00000001u)

#define CSL_HECC_CANTRS_TRS18_MASK (0x00040000u)
#define CSL_HECC_CANTRS_TRS18_SHIFT (0x00000012u)
#define CSL_HECC_CANTRS_TRS18_RESETVAL (0x00000000u)
/*----TRS18 Tokens----*/
#define CSL_HECC_CANTRS_TRS18_NOP (0x00000000u)
#define CSL_HECC_CANTRS_TRS18_TRANSMIT (0x00000001u)

#define CSL_HECC_CANTRS_TRS17_MASK (0x00020000u)
#define CSL_HECC_CANTRS_TRS17_SHIFT (0x00000011u)
#define CSL_HECC_CANTRS_TRS17_RESETVAL (0x00000000u)
/*----TRS17 Tokens----*/
#define CSL_HECC_CANTRS_TRS17_NOP (0x00000000u)
#define CSL_HECC_CANTRS_TRS17_TRANSMIT (0x00000001u)

#define CSL_HECC_CANTRS_TRS16_MASK (0x00010000u)
#define CSL_HECC_CANTRS_TRS16_SHIFT (0x00000010u)
#define CSL_HECC_CANTRS_TRS16_RESETVAL (0x00000000u)
/*----TRS16 Tokens----*/
#define CSL_HECC_CANTRS_TRS16_NOP (0x00000000u)
#define CSL_HECC_CANTRS_TRS16_TRANSMIT (0x00000001u)

#define CSL_HECC_CANTRS_TRS15_MASK (0x00008000u)
#define CSL_HECC_CANTRS_TRS15_SHIFT (0x0000000Fu)
#define CSL_HECC_CANTRS_TRS15_RESETVAL (0x00000000u)
/*----TRS15 Tokens----*/
#define CSL_HECC_CANTRS_TRS15_NOP (0x00000000u)
#define CSL_HECC_CANTRS_TRS15_TRANSMIT (0x00000001u)

#define CSL_HECC_CANTRS_TRS14_MASK (0x00004000u)
#define CSL_HECC_CANTRS_TRS14_SHIFT (0x0000000Eu)
#define CSL_HECC_CANTRS_TRS14_RESETVAL (0x00000000u)
/*----TRS14 Tokens----*/
#define CSL_HECC_CANTRS_TRS14_NOP (0x00000000u)
#define CSL_HECC_CANTRS_TRS14_TRANSMIT (0x00000001u)

#define CSL_HECC_CANTRS_TRS13_MASK (0x00002000u)
#define CSL_HECC_CANTRS_TRS13_SHIFT (0x0000000Du)
#define CSL_HECC_CANTRS_TRS13_RESETVAL (0x00000000u)
/*----TRS13 Tokens----*/
#define CSL_HECC_CANTRS_TRS13_NOP (0x00000000u)
#define CSL_HECC_CANTRS_TRS13_TRANSMIT (0x00000001u)

#define CSL_HECC_CANTRS_TRS12_MASK (0x00001000u)
#define CSL_HECC_CANTRS_TRS12_SHIFT (0x0000000Cu)
#define CSL_HECC_CANTRS_TRS12_RESETVAL (0x00000000u)
/*----TRS12 Tokens----*/
#define CSL_HECC_CANTRS_TRS12_NOP (0x00000000u)
#define CSL_HECC_CANTRS_TRS12_TRANSMIT (0x00000001u)

#define CSL_HECC_CANTRS_TRS11_MASK (0x00000800u)
#define CSL_HECC_CANTRS_TRS11_SHIFT (0x0000000Bu)
#define CSL_HECC_CANTRS_TRS11_RESETVAL (0x00000000u)
/*----TRS11 Tokens----*/
#define CSL_HECC_CANTRS_TRS11_NOP (0x00000000u)
#define CSL_HECC_CANTRS_TRS11_TRANSMIT (0x00000001u)

#define CSL_HECC_CANTRS_TRS10_MASK (0x00000400u)
#define CSL_HECC_CANTRS_TRS10_SHIFT (0x0000000Au)
#define CSL_HECC_CANTRS_TRS10_RESETVAL (0x00000000u)
/*----TRS10 Tokens----*/
#define CSL_HECC_CANTRS_TRS10_NOP (0x00000000u)
#define CSL_HECC_CANTRS_TRS10_TRANSMIT (0x00000001u)

#define CSL_HECC_CANTRS_TRS9_MASK (0x00000200u)
#define CSL_HECC_CANTRS_TRS9_SHIFT (0x00000009u)
#define CSL_HECC_CANTRS_TRS9_RESETVAL (0x00000000u)
/*----TRS9 Tokens----*/
#define CSL_HECC_CANTRS_TRS9_NOP (0x00000000u)
#define CSL_HECC_CANTRS_TRS9_TRANSMIT (0x00000001u)

#define CSL_HECC_CANTRS_TRS8_MASK (0x00000100u)
#define CSL_HECC_CANTRS_TRS8_SHIFT (0x00000008u)
#define CSL_HECC_CANTRS_TRS8_RESETVAL (0x00000000u)
/*----TRS8 Tokens----*/
#define CSL_HECC_CANTRS_TRS8_NOP (0x00000000u)
#define CSL_HECC_CANTRS_TRS8_TRANSMIT (0x00000001u)

#define CSL_HECC_CANTRS_TRS7_MASK (0x00000080u)
#define CSL_HECC_CANTRS_TRS7_SHIFT (0x00000007u)
#define CSL_HECC_CANTRS_TRS7_RESETVAL (0x00000000u)
/*----TRS7 Tokens----*/
#define CSL_HECC_CANTRS_TRS7_NOP (0x00000000u)
#define CSL_HECC_CANTRS_TRS7_TRANSMIT (0x00000001u)

#define CSL_HECC_CANTRS_TRS6_MASK (0x00000040u)
#define CSL_HECC_CANTRS_TRS6_SHIFT (0x00000006u)
#define CSL_HECC_CANTRS_TRS6_RESETVAL (0x00000000u)
/*----TRS6 Tokens----*/
#define CSL_HECC_CANTRS_TRS6_NOP (0x00000000u)
#define CSL_HECC_CANTRS_TRS6_TRANSMIT (0x00000001u)

#define CSL_HECC_CANTRS_TRS5_MASK (0x00000020u)
#define CSL_HECC_CANTRS_TRS5_SHIFT (0x00000005u)
#define CSL_HECC_CANTRS_TRS5_RESETVAL (0x00000000u)
/*----TRS5 Tokens----*/
#define CSL_HECC_CANTRS_TRS5_NOP (0x00000000u)
#define CSL_HECC_CANTRS_TRS5_TRANSMIT (0x00000001u)

#define CSL_HECC_CANTRS_TRS4_MASK (0x00000010u)
#define CSL_HECC_CANTRS_TRS4_SHIFT (0x00000004u)
#define CSL_HECC_CANTRS_TRS4_RESETVAL (0x00000000u)
/*----TRS4 Tokens----*/
#define CSL_HECC_CANTRS_TRS4_NOP (0x00000000u)
#define CSL_HECC_CANTRS_TRS4_TRANSMIT (0x00000001u)

#define CSL_HECC_CANTRS_TRS3_MASK (0x00000008u)
#define CSL_HECC_CANTRS_TRS3_SHIFT (0x00000003u)
#define CSL_HECC_CANTRS_TRS3_RESETVAL (0x00000000u)
/*----TRS3 Tokens----*/
#define CSL_HECC_CANTRS_TRS3_NOP (0x00000000u)
#define CSL_HECC_CANTRS_TRS3_TRANSMIT (0x00000001u)

#define CSL_HECC_CANTRS_TRS2_MASK (0x00000004u)
#define CSL_HECC_CANTRS_TRS2_SHIFT (0x00000002u)
#define CSL_HECC_CANTRS_TRS2_RESETVAL (0x00000000u)
/*----TRS2 Tokens----*/
#define CSL_HECC_CANTRS_TRS2_NOP (0x00000000u)
#define CSL_HECC_CANTRS_TRS2_TRANSMIT (0x00000001u)

#define CSL_HECC_CANTRS_TRS1_MASK (0x00000002u)
#define CSL_HECC_CANTRS_TRS1_SHIFT (0x00000001u)
#define CSL_HECC_CANTRS_TRS1_RESETVAL (0x00000000u)
/*----TRS1 Tokens----*/
#define CSL_HECC_CANTRS_TRS1_NOP (0x00000000u)
#define CSL_HECC_CANTRS_TRS1_TRANSMIT (0x00000001u)

#define CSL_HECC_CANTRS_TRS0_MASK (0x00000001u)
#define CSL_HECC_CANTRS_TRS0_SHIFT (0x00000000u)
#define CSL_HECC_CANTRS_TRS0_RESETVAL (0x00000000u)
/*----TRS0 Tokens----*/
#define CSL_HECC_CANTRS_TRS0_NOP (0x00000000u)
#define CSL_HECC_CANTRS_TRS0_TRANSMIT (0x00000001u)

#define CSL_HECC_CANTRS_RESETVAL (0x00000000u)

/* CANTRR */

#define CSL_HECC_CANTRR_TRR31_MASK (0x80000000u)
#define CSL_HECC_CANTRR_TRR31_SHIFT (0x0000001Fu)
#define CSL_HECC_CANTRR_TRR31_RESETVAL (0x00000000u)
/*----TRR31 Tokens----*/
#define CSL_HECC_CANTRR_TRR31_NOP (0x00000000u)
#define CSL_HECC_CANTRR_TRR31_CANCEL (0x00000001u)

#define CSL_HECC_CANTRR_TRR30_MASK (0x40000000u)
#define CSL_HECC_CANTRR_TRR30_SHIFT (0x0000001Eu)
#define CSL_HECC_CANTRR_TRR30_RESETVAL (0x00000000u)
/*----TRR30 Tokens----*/
#define CSL_HECC_CANTRR_TRR30_NOP (0x00000000u)
#define CSL_HECC_CANTRR_TRR30_CANCEL (0x00000001u)

#define CSL_HECC_CANTRR_TRR29_MASK (0x20000000u)
#define CSL_HECC_CANTRR_TRR29_SHIFT (0x0000001Du)
#define CSL_HECC_CANTRR_TRR29_RESETVAL (0x00000000u)
/*----TRR29 Tokens----*/
#define CSL_HECC_CANTRR_TRR29_NOP (0x00000000u)
#define CSL_HECC_CANTRR_TRR29_CANCEL (0x00000001u)

#define CSL_HECC_CANTRR_TRR28_MASK (0x10000000u)
#define CSL_HECC_CANTRR_TRR28_SHIFT (0x0000001Cu)
#define CSL_HECC_CANTRR_TRR28_RESETVAL (0x00000000u)
/*----TRR28 Tokens----*/
#define CSL_HECC_CANTRR_TRR28_NOP (0x00000000u)
#define CSL_HECC_CANTRR_TRR28_CANCEL (0x00000001u)

#define CSL_HECC_CANTRR_TRR27_MASK (0x08000000u)
#define CSL_HECC_CANTRR_TRR27_SHIFT (0x0000001Bu)
#define CSL_HECC_CANTRR_TRR27_RESETVAL (0x00000000u)
/*----TRR27 Tokens----*/
#define CSL_HECC_CANTRR_TRR27_NOP (0x00000000u)
#define CSL_HECC_CANTRR_TRR27_CANCEL (0x00000001u)

#define CSL_HECC_CANTRR_TRR26_MASK (0x04000000u)
#define CSL_HECC_CANTRR_TRR26_SHIFT (0x0000001Au)
#define CSL_HECC_CANTRR_TRR26_RESETVAL (0x00000000u)
/*----TRR26 Tokens----*/
#define CSL_HECC_CANTRR_TRR26_NOP (0x00000000u)
#define CSL_HECC_CANTRR_TRR26_CANCEL (0x00000001u)

#define CSL_HECC_CANTRR_TRR25_MASK (0x02000000u)
#define CSL_HECC_CANTRR_TRR25_SHIFT (0x00000019u)
#define CSL_HECC_CANTRR_TRR25_RESETVAL (0x00000000u)
/*----TRR25 Tokens----*/
#define CSL_HECC_CANTRR_TRR25_NOP (0x00000000u)
#define CSL_HECC_CANTRR_TRR25_CANCEL (0x00000001u)

#define CSL_HECC_CANTRR_TRR24_MASK (0x01000000u)
#define CSL_HECC_CANTRR_TRR24_SHIFT (0x00000018u)
#define CSL_HECC_CANTRR_TRR24_RESETVAL (0x00000000u)
/*----TRR24 Tokens----*/
#define CSL_HECC_CANTRR_TRR24_NOP (0x00000000u)
#define CSL_HECC_CANTRR_TRR24_CANCEL (0x00000001u)

#define CSL_HECC_CANTRR_TRR23_MASK (0x00800000u)
#define CSL_HECC_CANTRR_TRR23_SHIFT (0x00000017u)
#define CSL_HECC_CANTRR_TRR23_RESETVAL (0x00000000u)
/*----TRR23 Tokens----*/
#define CSL_HECC_CANTRR_TRR23_NOP (0x00000000u)
#define CSL_HECC_CANTRR_TRR23_CANCEL (0x00000001u)

#define CSL_HECC_CANTRR_TRR22_MASK (0x00400000u)
#define CSL_HECC_CANTRR_TRR22_SHIFT (0x00000016u)
#define CSL_HECC_CANTRR_TRR22_RESETVAL (0x00000000u)
/*----TRR22 Tokens----*/
#define CSL_HECC_CANTRR_TRR22_NOP (0x00000000u)
#define CSL_HECC_CANTRR_TRR22_CANCEL (0x00000001u)

#define CSL_HECC_CANTRR_TRR21_MASK (0x00200000u)
#define CSL_HECC_CANTRR_TRR21_SHIFT (0x00000015u)
#define CSL_HECC_CANTRR_TRR21_RESETVAL (0x00000000u)
/*----TRR21 Tokens----*/
#define CSL_HECC_CANTRR_TRR21_NOP (0x00000000u)
#define CSL_HECC_CANTRR_TRR21_CANCEL (0x00000001u)

#define CSL_HECC_CANTRR_TRR20_MASK (0x00100000u)
#define CSL_HECC_CANTRR_TRR20_SHIFT (0x00000014u)
#define CSL_HECC_CANTRR_TRR20_RESETVAL (0x00000000u)
/*----TRR20 Tokens----*/
#define CSL_HECC_CANTRR_TRR20_NOP (0x00000000u)
#define CSL_HECC_CANTRR_TRR20_CANCEL (0x00000001u)

#define CSL_HECC_CANTRR_TRR19_MASK (0x00080000u)
#define CSL_HECC_CANTRR_TRR19_SHIFT (0x00000013u)
#define CSL_HECC_CANTRR_TRR19_RESETVAL (0x00000000u)
/*----TRR19 Tokens----*/
#define CSL_HECC_CANTRR_TRR19_NOP (0x00000000u)
#define CSL_HECC_CANTRR_TRR19_CANCEL (0x00000001u)

#define CSL_HECC_CANTRR_TRR18_MASK (0x00040000u)
#define CSL_HECC_CANTRR_TRR18_SHIFT (0x00000012u)
#define CSL_HECC_CANTRR_TRR18_RESETVAL (0x00000000u)
/*----TRR18 Tokens----*/
#define CSL_HECC_CANTRR_TRR18_NOP (0x00000000u)
#define CSL_HECC_CANTRR_TRR18_CANCEL (0x00000001u)

#define CSL_HECC_CANTRR_TRR17_MASK (0x00020000u)
#define CSL_HECC_CANTRR_TRR17_SHIFT (0x00000011u)
#define CSL_HECC_CANTRR_TRR17_RESETVAL (0x00000000u)
/*----TRR17 Tokens----*/
#define CSL_HECC_CANTRR_TRR17_NOP (0x00000000u)
#define CSL_HECC_CANTRR_TRR17_CANCEL (0x00000001u)

#define CSL_HECC_CANTRR_TRR16_MASK (0x00010000u)
#define CSL_HECC_CANTRR_TRR16_SHIFT (0x00000010u)
#define CSL_HECC_CANTRR_TRR16_RESETVAL (0x00000000u)
/*----TRR16 Tokens----*/
#define CSL_HECC_CANTRR_TRR16_NOP (0x00000000u)
#define CSL_HECC_CANTRR_TRR16_CANCEL (0x00000001u)

#define CSL_HECC_CANTRR_TRR15_MASK (0x00008000u)
#define CSL_HECC_CANTRR_TRR15_SHIFT (0x0000000Fu)
#define CSL_HECC_CANTRR_TRR15_RESETVAL (0x00000000u)
/*----TRR15 Tokens----*/
#define CSL_HECC_CANTRR_TRR15_NOP (0x00000000u)
#define CSL_HECC_CANTRR_TRR15_CANCEL (0x00000001u)

#define CSL_HECC_CANTRR_TRR14_MASK (0x00004000u)
#define CSL_HECC_CANTRR_TRR14_SHIFT (0x0000000Eu)
#define CSL_HECC_CANTRR_TRR14_RESETVAL (0x00000000u)
/*----TRR14 Tokens----*/
#define CSL_HECC_CANTRR_TRR14_NOP (0x00000000u)
#define CSL_HECC_CANTRR_TRR14_CANCEL (0x00000001u)

#define CSL_HECC_CANTRR_TRR13_MASK (0x00002000u)
#define CSL_HECC_CANTRR_TRR13_SHIFT (0x0000000Du)
#define CSL_HECC_CANTRR_TRR13_RESETVAL (0x00000000u)
/*----TRR13 Tokens----*/
#define CSL_HECC_CANTRR_TRR13_NOP (0x00000000u)
#define CSL_HECC_CANTRR_TRR13_CANCEL (0x00000001u)

#define CSL_HECC_CANTRR_TRR12_MASK (0x00001000u)
#define CSL_HECC_CANTRR_TRR12_SHIFT (0x0000000Cu)
#define CSL_HECC_CANTRR_TRR12_RESETVAL (0x00000000u)
/*----TRR12 Tokens----*/
#define CSL_HECC_CANTRR_TRR12_NOP (0x00000000u)
#define CSL_HECC_CANTRR_TRR12_CANCEL (0x00000001u)

#define CSL_HECC_CANTRR_TRR11_MASK (0x00000800u)
#define CSL_HECC_CANTRR_TRR11_SHIFT (0x0000000Bu)
#define CSL_HECC_CANTRR_TRR11_RESETVAL (0x00000000u)
/*----TRR11 Tokens----*/
#define CSL_HECC_CANTRR_TRR11_NOP (0x00000000u)
#define CSL_HECC_CANTRR_TRR11_CANCEL (0x00000001u)

#define CSL_HECC_CANTRR_TRR10_MASK (0x00000400u)
#define CSL_HECC_CANTRR_TRR10_SHIFT (0x0000000Au)
#define CSL_HECC_CANTRR_TRR10_RESETVAL (0x00000000u)
/*----TRR10 Tokens----*/
#define CSL_HECC_CANTRR_TRR10_NOP (0x00000000u)
#define CSL_HECC_CANTRR_TRR10_CANCEL (0x00000001u)

#define CSL_HECC_CANTRR_TRR9_MASK (0x00000200u)
#define CSL_HECC_CANTRR_TRR9_SHIFT (0x00000009u)
#define CSL_HECC_CANTRR_TRR9_RESETVAL (0x00000000u)
/*----TRR9 Tokens----*/
#define CSL_HECC_CANTRR_TRR9_NOP (0x00000000u)
#define CSL_HECC_CANTRR_TRR9_CANCEL (0x00000001u)

#define CSL_HECC_CANTRR_TRR8_MASK (0x00000100u)
#define CSL_HECC_CANTRR_TRR8_SHIFT (0x00000008u)
#define CSL_HECC_CANTRR_TRR8_RESETVAL (0x00000000u)
/*----TRR8 Tokens----*/
#define CSL_HECC_CANTRR_TRR8_NOP (0x00000000u)
#define CSL_HECC_CANTRR_TRR8_CANCEL (0x00000001u)

#define CSL_HECC_CANTRR_TRR7_MASK (0x00000080u)
#define CSL_HECC_CANTRR_TRR7_SHIFT (0x00000007u)
#define CSL_HECC_CANTRR_TRR7_RESETVAL (0x00000000u)
/*----TRR7 Tokens----*/
#define CSL_HECC_CANTRR_TRR7_NOP (0x00000000u)
#define CSL_HECC_CANTRR_TRR7_CANCEL (0x00000001u)

#define CSL_HECC_CANTRR_TRR6_MASK (0x00000040u)
#define CSL_HECC_CANTRR_TRR6_SHIFT (0x00000006u)
#define CSL_HECC_CANTRR_TRR6_RESETVAL (0x00000000u)
/*----TRR6 Tokens----*/
#define CSL_HECC_CANTRR_TRR6_NOP (0x00000000u)
#define CSL_HECC_CANTRR_TRR6_CANCEL (0x00000001u)

#define CSL_HECC_CANTRR_TRR5_MASK (0x00000020u)
#define CSL_HECC_CANTRR_TRR5_SHIFT (0x00000005u)
#define CSL_HECC_CANTRR_TRR5_RESETVAL (0x00000000u)
/*----TRR5 Tokens----*/
#define CSL_HECC_CANTRR_TRR5_NOP (0x00000000u)
#define CSL_HECC_CANTRR_TRR5_CANCEL (0x00000001u)

#define CSL_HECC_CANTRR_TRR4_MASK (0x00000010u)
#define CSL_HECC_CANTRR_TRR4_SHIFT (0x00000004u)
#define CSL_HECC_CANTRR_TRR4_RESETVAL (0x00000000u)
/*----TRR4 Tokens----*/
#define CSL_HECC_CANTRR_TRR4_NOP (0x00000000u)
#define CSL_HECC_CANTRR_TRR4_CANCEL (0x00000001u)

#define CSL_HECC_CANTRR_TRR3_MASK (0x00000008u)
#define CSL_HECC_CANTRR_TRR3_SHIFT (0x00000003u)
#define CSL_HECC_CANTRR_TRR3_RESETVAL (0x00000000u)
/*----TRR3 Tokens----*/
#define CSL_HECC_CANTRR_TRR3_NOP (0x00000000u)
#define CSL_HECC_CANTRR_TRR3_CANCEL (0x00000001u)

#define CSL_HECC_CANTRR_TRR2_MASK (0x00000004u)
#define CSL_HECC_CANTRR_TRR2_SHIFT (0x00000002u)
#define CSL_HECC_CANTRR_TRR2_RESETVAL (0x00000000u)
/*----TRR2 Tokens----*/
#define CSL_HECC_CANTRR_TRR2_NOP (0x00000000u)
#define CSL_HECC_CANTRR_TRR2_CANCEL (0x00000001u)

#define CSL_HECC_CANTRR_TRR1_MASK (0x00000002u)
#define CSL_HECC_CANTRR_TRR1_SHIFT (0x00000001u)
#define CSL_HECC_CANTRR_TRR1_RESETVAL (0x00000000u)
/*----TRR1 Tokens----*/
#define CSL_HECC_CANTRR_TRR1_NOP (0x00000000u)
#define CSL_HECC_CANTRR_TRR1_CANCEL (0x00000001u)

#define CSL_HECC_CANTRR_TRR0_MASK (0x00000001u)
#define CSL_HECC_CANTRR_TRR0_SHIFT (0x00000000u)
#define CSL_HECC_CANTRR_TRR0_RESETVAL (0x00000000u)
/*----TRR0 Tokens----*/
#define CSL_HECC_CANTRR_TRR0_NOP (0x00000000u)
#define CSL_HECC_CANTRR_TRR0_CANCEL (0x00000001u)

#define CSL_HECC_CANTRR_RESETVAL (0x00000000u)

/* CANTA */

#define CSL_HECC_CANTA_TA31_MASK (0x80000000u)
#define CSL_HECC_CANTA_TA31_SHIFT (0x0000001Fu)
#define CSL_HECC_CANTA_TA31_RESETVAL (0x00000000u)
/*----TA31 Tokens----*/
#define CSL_HECC_CANTA_TA31_NOTSENT (0x00000000u)
#define CSL_HECC_CANTA_TA31_SENT (0x00000001u)

#define CSL_HECC_CANTA_TA30_MASK (0x40000000u)
#define CSL_HECC_CANTA_TA30_SHIFT (0x0000001Eu)
#define CSL_HECC_CANTA_TA30_RESETVAL (0x00000000u)
/*----TA30 Tokens----*/
#define CSL_HECC_CANTA_TA30_NOTSENT (0x00000000u)
#define CSL_HECC_CANTA_TA30_SENT (0x00000001u)

#define CSL_HECC_CANTA_TA29_MASK (0x20000000u)
#define CSL_HECC_CANTA_TA29_SHIFT (0x0000001Du)
#define CSL_HECC_CANTA_TA29_RESETVAL (0x00000000u)
/*----TA29 Tokens----*/
#define CSL_HECC_CANTA_TA29_NOTSENT (0x00000000u)
#define CSL_HECC_CANTA_TA29_SENT (0x00000001u)

#define CSL_HECC_CANTA_TA28_MASK (0x10000000u)
#define CSL_HECC_CANTA_TA28_SHIFT (0x0000001Cu)
#define CSL_HECC_CANTA_TA28_RESETVAL (0x00000000u)
/*----TA28 Tokens----*/
#define CSL_HECC_CANTA_TA28_NOTSENT (0x00000000u)
#define CSL_HECC_CANTA_TA28_SENT (0x00000001u)

#define CSL_HECC_CANTA_TA27_MASK (0x08000000u)
#define CSL_HECC_CANTA_TA27_SHIFT (0x0000001Bu)
#define CSL_HECC_CANTA_TA27_RESETVAL (0x00000000u)
/*----TA27 Tokens----*/
#define CSL_HECC_CANTA_TA27_NOTSENT (0x00000000u)
#define CSL_HECC_CANTA_TA27_SENT (0x00000001u)

#define CSL_HECC_CANTA_TA26_MASK (0x04000000u)
#define CSL_HECC_CANTA_TA26_SHIFT (0x0000001Au)
#define CSL_HECC_CANTA_TA26_RESETVAL (0x00000000u)
/*----TA26 Tokens----*/
#define CSL_HECC_CANTA_TA26_NOTSENT (0x00000000u)
#define CSL_HECC_CANTA_TA26_SENT (0x00000001u)

#define CSL_HECC_CANTA_TA25_MASK (0x02000000u)
#define CSL_HECC_CANTA_TA25_SHIFT (0x00000019u)
#define CSL_HECC_CANTA_TA25_RESETVAL (0x00000000u)
/*----TA25 Tokens----*/
#define CSL_HECC_CANTA_TA25_NOTSENT (0x00000000u)
#define CSL_HECC_CANTA_TA25_SENT (0x00000001u)

#define CSL_HECC_CANTA_TA24_MASK (0x01000000u)
#define CSL_HECC_CANTA_TA24_SHIFT (0x00000018u)
#define CSL_HECC_CANTA_TA24_RESETVAL (0x00000000u)
/*----TA24 Tokens----*/
#define CSL_HECC_CANTA_TA24_NOTSENT (0x00000000u)
#define CSL_HECC_CANTA_TA24_SENT (0x00000001u)

#define CSL_HECC_CANTA_TA23_MASK (0x00800000u)
#define CSL_HECC_CANTA_TA23_SHIFT (0x00000017u)
#define CSL_HECC_CANTA_TA23_RESETVAL (0x00000000u)
/*----TA23 Tokens----*/
#define CSL_HECC_CANTA_TA23_NOTSENT (0x00000000u)
#define CSL_HECC_CANTA_TA23_SENT (0x00000001u)

#define CSL_HECC_CANTA_TA22_MASK (0x00400000u)
#define CSL_HECC_CANTA_TA22_SHIFT (0x00000016u)
#define CSL_HECC_CANTA_TA22_RESETVAL (0x00000000u)
/*----TA22 Tokens----*/
#define CSL_HECC_CANTA_TA22_NOTSENT (0x00000000u)
#define CSL_HECC_CANTA_TA22_SENT (0x00000001u)

#define CSL_HECC_CANTA_TA21_MASK (0x00200000u)
#define CSL_HECC_CANTA_TA21_SHIFT (0x00000015u)
#define CSL_HECC_CANTA_TA21_RESETVAL (0x00000000u)
/*----TA21 Tokens----*/
#define CSL_HECC_CANTA_TA21_NOTSENT (0x00000000u)
#define CSL_HECC_CANTA_TA21_SENT (0x00000001u)

#define CSL_HECC_CANTA_TA20_MASK (0x00100000u)
#define CSL_HECC_CANTA_TA20_SHIFT (0x00000014u)
#define CSL_HECC_CANTA_TA20_RESETVAL (0x00000000u)
/*----TA20 Tokens----*/
#define CSL_HECC_CANTA_TA20_NOTSENT (0x00000000u)
#define CSL_HECC_CANTA_TA20_SENT (0x00000001u)

#define CSL_HECC_CANTA_TA19_MASK (0x00080000u)
#define CSL_HECC_CANTA_TA19_SHIFT (0x00000013u)
#define CSL_HECC_CANTA_TA19_RESETVAL (0x00000000u)
/*----TA19 Tokens----*/
#define CSL_HECC_CANTA_TA19_NOTSENT (0x00000000u)
#define CSL_HECC_CANTA_TA19_SENT (0x00000001u)

#define CSL_HECC_CANTA_TA18_MASK (0x00040000u)
#define CSL_HECC_CANTA_TA18_SHIFT (0x00000012u)
#define CSL_HECC_CANTA_TA18_RESETVAL (0x00000000u)
/*----TA18 Tokens----*/
#define CSL_HECC_CANTA_TA18_NOTSENT (0x00000000u)
#define CSL_HECC_CANTA_TA18_SENT (0x00000001u)

#define CSL_HECC_CANTA_TA17_MASK (0x00020000u)
#define CSL_HECC_CANTA_TA17_SHIFT (0x00000011u)
#define CSL_HECC_CANTA_TA17_RESETVAL (0x00000000u)
/*----TA17 Tokens----*/
#define CSL_HECC_CANTA_TA17_NOTSENT (0x00000000u)
#define CSL_HECC_CANTA_TA17_SENT (0x00000001u)

#define CSL_HECC_CANTA_TA16_MASK (0x00010000u)
#define CSL_HECC_CANTA_TA16_SHIFT (0x00000010u)
#define CSL_HECC_CANTA_TA16_RESETVAL (0x00000000u)
/*----TA16 Tokens----*/
#define CSL_HECC_CANTA_TA16_NOTSENT (0x00000000u)
#define CSL_HECC_CANTA_TA16_SENT (0x00000001u)

#define CSL_HECC_CANTA_TA15_MASK (0x00008000u)
#define CSL_HECC_CANTA_TA15_SHIFT (0x0000000Fu)
#define CSL_HECC_CANTA_TA15_RESETVAL (0x00000000u)
/*----TA15 Tokens----*/
#define CSL_HECC_CANTA_TA15_NOTSENT (0x00000000u)
#define CSL_HECC_CANTA_TA15_SENT (0x00000001u)

#define CSL_HECC_CANTA_TA14_MASK (0x00004000u)
#define CSL_HECC_CANTA_TA14_SHIFT (0x0000000Eu)
#define CSL_HECC_CANTA_TA14_RESETVAL (0x00000000u)
/*----TA14 Tokens----*/
#define CSL_HECC_CANTA_TA14_NOTSENT (0x00000000u)
#define CSL_HECC_CANTA_TA14_SENT (0x00000001u)

#define CSL_HECC_CANTA_TA13_MASK (0x00002000u)
#define CSL_HECC_CANTA_TA13_SHIFT (0x0000000Du)
#define CSL_HECC_CANTA_TA13_RESETVAL (0x00000000u)
/*----TA13 Tokens----*/
#define CSL_HECC_CANTA_TA13_NOTSENT (0x00000000u)
#define CSL_HECC_CANTA_TA13_SENT (0x00000001u)

#define CSL_HECC_CANTA_TA12_MASK (0x00001000u)
#define CSL_HECC_CANTA_TA12_SHIFT (0x0000000Cu)
#define CSL_HECC_CANTA_TA12_RESETVAL (0x00000000u)
/*----TA12 Tokens----*/
#define CSL_HECC_CANTA_TA12_NOTSENT (0x00000000u)
#define CSL_HECC_CANTA_TA12_SENT (0x00000001u)

#define CSL_HECC_CANTA_TA11_MASK (0x00000800u)
#define CSL_HECC_CANTA_TA11_SHIFT (0x0000000Bu)
#define CSL_HECC_CANTA_TA11_RESETVAL (0x00000000u)
/*----TA11 Tokens----*/
#define CSL_HECC_CANTA_TA11_NOTSENT (0x00000000u)
#define CSL_HECC_CANTA_TA11_SENT (0x00000001u)

#define CSL_HECC_CANTA_TA10_MASK (0x00000400u)
#define CSL_HECC_CANTA_TA10_SHIFT (0x0000000Au)
#define CSL_HECC_CANTA_TA10_RESETVAL (0x00000000u)
/*----TA10 Tokens----*/
#define CSL_HECC_CANTA_TA10_NOTSENT (0x00000000u)
#define CSL_HECC_CANTA_TA10_SENT (0x00000001u)

#define CSL_HECC_CANTA_TA9_MASK (0x00000200u)
#define CSL_HECC_CANTA_TA9_SHIFT (0x00000009u)
#define CSL_HECC_CANTA_TA9_RESETVAL (0x00000000u)
/*----TA9 Tokens----*/
#define CSL_HECC_CANTA_TA9_NOTSENT (0x00000000u)
#define CSL_HECC_CANTA_TA9_SENT (0x00000001u)

#define CSL_HECC_CANTA_TA8_MASK (0x00000100u)
#define CSL_HECC_CANTA_TA8_SHIFT (0x00000008u)
#define CSL_HECC_CANTA_TA8_RESETVAL (0x00000000u)
/*----TA8 Tokens----*/
#define CSL_HECC_CANTA_TA8_NOTSENT (0x00000000u)
#define CSL_HECC_CANTA_TA8_SENT (0x00000001u)

#define CSL_HECC_CANTA_TA7_MASK (0x00000080u)
#define CSL_HECC_CANTA_TA7_SHIFT (0x00000007u)
#define CSL_HECC_CANTA_TA7_RESETVAL (0x00000000u)
/*----TA7 Tokens----*/
#define CSL_HECC_CANTA_TA7_NOTSENT (0x00000000u)
#define CSL_HECC_CANTA_TA7_SENT (0x00000001u)

#define CSL_HECC_CANTA_TA6_MASK (0x00000040u)
#define CSL_HECC_CANTA_TA6_SHIFT (0x00000006u)
#define CSL_HECC_CANTA_TA6_RESETVAL (0x00000000u)
/*----TA6 Tokens----*/
#define CSL_HECC_CANTA_TA6_NOTSENT (0x00000000u)
#define CSL_HECC_CANTA_TA6_SENT (0x00000001u)

#define CSL_HECC_CANTA_TA5_MASK (0x00000020u)
#define CSL_HECC_CANTA_TA5_SHIFT (0x00000005u)
#define CSL_HECC_CANTA_TA5_RESETVAL (0x00000000u)
/*----TA5 Tokens----*/
#define CSL_HECC_CANTA_TA5_NOTSENT (0x00000000u)
#define CSL_HECC_CANTA_TA5_SENT (0x00000001u)

#define CSL_HECC_CANTA_TA4_MASK (0x00000010u)
#define CSL_HECC_CANTA_TA4_SHIFT (0x00000004u)
#define CSL_HECC_CANTA_TA4_RESETVAL (0x00000000u)
/*----TA4 Tokens----*/
#define CSL_HECC_CANTA_TA4_NOTSENT (0x00000000u)
#define CSL_HECC_CANTA_TA4_SENT (0x00000001u)

#define CSL_HECC_CANTA_TA3_MASK (0x00000008u)
#define CSL_HECC_CANTA_TA3_SHIFT (0x00000003u)
#define CSL_HECC_CANTA_TA3_RESETVAL (0x00000000u)
/*----TA3 Tokens----*/
#define CSL_HECC_CANTA_TA3_NOTSENT (0x00000000u)
#define CSL_HECC_CANTA_TA3_SENT (0x00000001u)

#define CSL_HECC_CANTA_TA2_MASK (0x00000004u)
#define CSL_HECC_CANTA_TA2_SHIFT (0x00000002u)
#define CSL_HECC_CANTA_TA2_RESETVAL (0x00000000u)
/*----TA2 Tokens----*/
#define CSL_HECC_CANTA_TA2_NOTSENT (0x00000000u)
#define CSL_HECC_CANTA_TA2_SENT (0x00000001u)

#define CSL_HECC_CANTA_TA1_MASK (0x00000002u)
#define CSL_HECC_CANTA_TA1_SHIFT (0x00000001u)
#define CSL_HECC_CANTA_TA1_RESETVAL (0x00000000u)
/*----TA1 Tokens----*/
#define CSL_HECC_CANTA_TA1_NOTSENT (0x00000000u)
#define CSL_HECC_CANTA_TA1_SENT (0x00000001u)

#define CSL_HECC_CANTA_TA0_MASK (0x00000001u)
#define CSL_HECC_CANTA_TA0_SHIFT (0x00000000u)
#define CSL_HECC_CANTA_TA0_RESETVAL (0x00000000u)
/*----TA0 Tokens----*/
#define CSL_HECC_CANTA_TA0_NOTSENT (0x00000000u)
#define CSL_HECC_CANTA_TA0_SENT (0x00000001u)

#define CSL_HECC_CANTA_RESETVAL (0x00000000u)

/* CANAA */

#define CSL_HECC_CANAA_AA31_MASK (0x80000000u)
#define CSL_HECC_CANAA_AA31_SHIFT (0x0000001Fu)
#define CSL_HECC_CANAA_AA31_RESETVAL (0x00000000u)
/*----AA31 Tokens----*/
#define CSL_HECC_CANAA_AA31_NOTABORTED (0x00000000u)
#define CSL_HECC_CANAA_AA31_ABORTED (0x00000001u)

#define CSL_HECC_CANAA_AA30_MASK (0x40000000u)
#define CSL_HECC_CANAA_AA30_SHIFT (0x0000001Eu)
#define CSL_HECC_CANAA_AA30_RESETVAL (0x00000000u)
/*----AA30 Tokens----*/
#define CSL_HECC_CANAA_AA30_NOTABORTED (0x00000000u)
#define CSL_HECC_CANAA_AA30_ABORTED (0x00000001u)

#define CSL_HECC_CANAA_AA29_MASK (0x20000000u)
#define CSL_HECC_CANAA_AA29_SHIFT (0x0000001Du)
#define CSL_HECC_CANAA_AA29_RESETVAL (0x00000000u)
/*----AA29 Tokens----*/
#define CSL_HECC_CANAA_AA29_NOTABORTED (0x00000000u)
#define CSL_HECC_CANAA_AA29_ABORTED (0x00000001u)

#define CSL_HECC_CANAA_AA28_MASK (0x10000000u)
#define CSL_HECC_CANAA_AA28_SHIFT (0x0000001Cu)
#define CSL_HECC_CANAA_AA28_RESETVAL (0x00000000u)
/*----AA28 Tokens----*/
#define CSL_HECC_CANAA_AA28_NOTABORTED (0x00000000u)
#define CSL_HECC_CANAA_AA28_ABORTED (0x00000001u)

#define CSL_HECC_CANAA_AA27_MASK (0x08000000u)
#define CSL_HECC_CANAA_AA27_SHIFT (0x0000001Bu)
#define CSL_HECC_CANAA_AA27_RESETVAL (0x00000000u)
/*----AA27 Tokens----*/
#define CSL_HECC_CANAA_AA27_NOTABORTED (0x00000000u)
#define CSL_HECC_CANAA_AA27_ABORTED (0x00000001u)

#define CSL_HECC_CANAA_AA26_MASK (0x04000000u)
#define CSL_HECC_CANAA_AA26_SHIFT (0x0000001Au)
#define CSL_HECC_CANAA_AA26_RESETVAL (0x00000000u)
/*----AA26 Tokens----*/
#define CSL_HECC_CANAA_AA26_NOTABORTED (0x00000000u)
#define CSL_HECC_CANAA_AA26_ABORTED (0x00000001u)

#define CSL_HECC_CANAA_AA25_MASK (0x02000000u)
#define CSL_HECC_CANAA_AA25_SHIFT (0x00000019u)
#define CSL_HECC_CANAA_AA25_RESETVAL (0x00000000u)
/*----AA25 Tokens----*/
#define CSL_HECC_CANAA_AA25_NOTABORTED (0x00000000u)
#define CSL_HECC_CANAA_AA25_ABORTED (0x00000001u)

#define CSL_HECC_CANAA_AA24_MASK (0x01000000u)
#define CSL_HECC_CANAA_AA24_SHIFT (0x00000018u)
#define CSL_HECC_CANAA_AA24_RESETVAL (0x00000000u)
/*----AA24 Tokens----*/
#define CSL_HECC_CANAA_AA24_NOTABORTED (0x00000000u)
#define CSL_HECC_CANAA_AA24_ABORTED (0x00000001u)

#define CSL_HECC_CANAA_AA23_MASK (0x00800000u)
#define CSL_HECC_CANAA_AA23_SHIFT (0x00000017u)
#define CSL_HECC_CANAA_AA23_RESETVAL (0x00000000u)
/*----AA23 Tokens----*/
#define CSL_HECC_CANAA_AA23_NOTABORTED (0x00000000u)
#define CSL_HECC_CANAA_AA23_ABORTED (0x00000001u)

#define CSL_HECC_CANAA_AA22_MASK (0x00400000u)
#define CSL_HECC_CANAA_AA22_SHIFT (0x00000016u)
#define CSL_HECC_CANAA_AA22_RESETVAL (0x00000000u)
/*----AA22 Tokens----*/
#define CSL_HECC_CANAA_AA22_NOTABORTED (0x00000000u)
#define CSL_HECC_CANAA_AA22_ABORTED (0x00000001u)

#define CSL_HECC_CANAA_AA21_MASK (0x00200000u)
#define CSL_HECC_CANAA_AA21_SHIFT (0x00000015u)
#define CSL_HECC_CANAA_AA21_RESETVAL (0x00000000u)
/*----AA21 Tokens----*/
#define CSL_HECC_CANAA_AA21_NOTABORTED (0x00000000u)
#define CSL_HECC_CANAA_AA21_ABORTED (0x00000001u)

#define CSL_HECC_CANAA_AA20_MASK (0x00100000u)
#define CSL_HECC_CANAA_AA20_SHIFT (0x00000014u)
#define CSL_HECC_CANAA_AA20_RESETVAL (0x00000000u)
/*----AA20 Tokens----*/
#define CSL_HECC_CANAA_AA20_NOTABORTED (0x00000000u)
#define CSL_HECC_CANAA_AA20_ABORTED (0x00000001u)

#define CSL_HECC_CANAA_AA19_MASK (0x00080000u)
#define CSL_HECC_CANAA_AA19_SHIFT (0x00000013u)
#define CSL_HECC_CANAA_AA19_RESETVAL (0x00000000u)
/*----AA19 Tokens----*/
#define CSL_HECC_CANAA_AA19_NOTABORTED (0x00000000u)
#define CSL_HECC_CANAA_AA19_ABORTED (0x00000001u)

#define CSL_HECC_CANAA_AA18_MASK (0x00040000u)
#define CSL_HECC_CANAA_AA18_SHIFT (0x00000012u)
#define CSL_HECC_CANAA_AA18_RESETVAL (0x00000000u)
/*----AA18 Tokens----*/
#define CSL_HECC_CANAA_AA18_NOTABORTED (0x00000000u)
#define CSL_HECC_CANAA_AA18_ABORTED (0x00000001u)

#define CSL_HECC_CANAA_AA17_MASK (0x00020000u)
#define CSL_HECC_CANAA_AA17_SHIFT (0x00000011u)
#define CSL_HECC_CANAA_AA17_RESETVAL (0x00000000u)
/*----AA17 Tokens----*/
#define CSL_HECC_CANAA_AA17_NOTABORTED (0x00000000u)
#define CSL_HECC_CANAA_AA17_ABORTED (0x00000001u)

#define CSL_HECC_CANAA_AA16_MASK (0x00010000u)
#define CSL_HECC_CANAA_AA16_SHIFT (0x00000010u)
#define CSL_HECC_CANAA_AA16_RESETVAL (0x00000000u)
/*----AA16 Tokens----*/
#define CSL_HECC_CANAA_AA16_NOTABORTED (0x00000000u)
#define CSL_HECC_CANAA_AA16_ABORTED (0x00000001u)

#define CSL_HECC_CANAA_AA15_MASK (0x00008000u)
#define CSL_HECC_CANAA_AA15_SHIFT (0x0000000Fu)
#define CSL_HECC_CANAA_AA15_RESETVAL (0x00000000u)
/*----AA15 Tokens----*/
#define CSL_HECC_CANAA_AA15_NOTABORTED (0x00000000u)
#define CSL_HECC_CANAA_AA15_ABORTED (0x00000001u)

#define CSL_HECC_CANAA_AA14_MASK (0x00004000u)
#define CSL_HECC_CANAA_AA14_SHIFT (0x0000000Eu)
#define CSL_HECC_CANAA_AA14_RESETVAL (0x00000000u)
/*----AA14 Tokens----*/
#define CSL_HECC_CANAA_AA14_NOTABORTED (0x00000000u)
#define CSL_HECC_CANAA_AA14_ABORTED (0x00000001u)

#define CSL_HECC_CANAA_AA13_MASK (0x00002000u)
#define CSL_HECC_CANAA_AA13_SHIFT (0x0000000Du)
#define CSL_HECC_CANAA_AA13_RESETVAL (0x00000000u)
/*----AA13 Tokens----*/
#define CSL_HECC_CANAA_AA13_NOTABORTED (0x00000000u)
#define CSL_HECC_CANAA_AA13_ABORTED (0x00000001u)

#define CSL_HECC_CANAA_AA12_MASK (0x00001000u)
#define CSL_HECC_CANAA_AA12_SHIFT (0x0000000Cu)
#define CSL_HECC_CANAA_AA12_RESETVAL (0x00000000u)
/*----AA12 Tokens----*/
#define CSL_HECC_CANAA_AA12_NOTABORTED (0x00000000u)
#define CSL_HECC_CANAA_AA12_ABORTED (0x00000001u)

#define CSL_HECC_CANAA_AA11_MASK (0x00000800u)
#define CSL_HECC_CANAA_AA11_SHIFT (0x0000000Bu)
#define CSL_HECC_CANAA_AA11_RESETVAL (0x00000000u)
/*----AA11 Tokens----*/
#define CSL_HECC_CANAA_AA11_NOTABORTED (0x00000000u)
#define CSL_HECC_CANAA_AA11_ABORTED (0x00000001u)

#define CSL_HECC_CANAA_AA10_MASK (0x00000400u)
#define CSL_HECC_CANAA_AA10_SHIFT (0x0000000Au)
#define CSL_HECC_CANAA_AA10_RESETVAL (0x00000000u)
/*----AA10 Tokens----*/
#define CSL_HECC_CANAA_AA10_NOTABORTED (0x00000000u)
#define CSL_HECC_CANAA_AA10_ABORTED (0x00000001u)

#define CSL_HECC_CANAA_AA9_MASK (0x00000200u)
#define CSL_HECC_CANAA_AA9_SHIFT (0x00000009u)
#define CSL_HECC_CANAA_AA9_RESETVAL (0x00000000u)
/*----AA9 Tokens----*/
#define CSL_HECC_CANAA_AA9_NOTABORTED (0x00000000u)
#define CSL_HECC_CANAA_AA9_ABORTED (0x00000001u)

#define CSL_HECC_CANAA_AA8_MASK (0x00000100u)
#define CSL_HECC_CANAA_AA8_SHIFT (0x00000008u)
#define CSL_HECC_CANAA_AA8_RESETVAL (0x00000000u)
/*----AA8 Tokens----*/
#define CSL_HECC_CANAA_AA8_NOTABORTED (0x00000000u)
#define CSL_HECC_CANAA_AA8_ABORTED (0x00000001u)

#define CSL_HECC_CANAA_AA7_MASK (0x00000080u)
#define CSL_HECC_CANAA_AA7_SHIFT (0x00000007u)
#define CSL_HECC_CANAA_AA7_RESETVAL (0x00000000u)
/*----AA7 Tokens----*/
#define CSL_HECC_CANAA_AA7_NOTABORTED (0x00000000u)
#define CSL_HECC_CANAA_AA7_ABORTED (0x00000001u)

#define CSL_HECC_CANAA_AA6_MASK (0x00000040u)
#define CSL_HECC_CANAA_AA6_SHIFT (0x00000006u)
#define CSL_HECC_CANAA_AA6_RESETVAL (0x00000000u)
/*----AA6 Tokens----*/
#define CSL_HECC_CANAA_AA6_NOTABORTED (0x00000000u)
#define CSL_HECC_CANAA_AA6_ABORTED (0x00000001u)

#define CSL_HECC_CANAA_AA5_MASK (0x00000020u)
#define CSL_HECC_CANAA_AA5_SHIFT (0x00000005u)
#define CSL_HECC_CANAA_AA5_RESETVAL (0x00000000u)
/*----AA5 Tokens----*/
#define CSL_HECC_CANAA_AA5_NOTABORTED (0x00000000u)
#define CSL_HECC_CANAA_AA5_ABORTED (0x00000001u)

#define CSL_HECC_CANAA_AA4_MASK (0x00000010u)
#define CSL_HECC_CANAA_AA4_SHIFT (0x00000004u)
#define CSL_HECC_CANAA_AA4_RESETVAL (0x00000000u)
/*----AA4 Tokens----*/
#define CSL_HECC_CANAA_AA4_NOTABORTED (0x00000000u)
#define CSL_HECC_CANAA_AA4_ABORTED (0x00000001u)

#define CSL_HECC_CANAA_AA3_MASK (0x00000008u)
#define CSL_HECC_CANAA_AA3_SHIFT (0x00000003u)
#define CSL_HECC_CANAA_AA3_RESETVAL (0x00000000u)
/*----AA3 Tokens----*/
#define CSL_HECC_CANAA_AA3_NOTABORTED (0x00000000u)
#define CSL_HECC_CANAA_AA3_ABORTED (0x00000001u)

#define CSL_HECC_CANAA_AA2_MASK (0x00000004u)
#define CSL_HECC_CANAA_AA2_SHIFT (0x00000002u)
#define CSL_HECC_CANAA_AA2_RESETVAL (0x00000000u)
/*----AA2 Tokens----*/
#define CSL_HECC_CANAA_AA2_NOTABORTED (0x00000000u)
#define CSL_HECC_CANAA_AA2_ABORTED (0x00000001u)

#define CSL_HECC_CANAA_AA1_MASK (0x00000002u)
#define CSL_HECC_CANAA_AA1_SHIFT (0x00000001u)
#define CSL_HECC_CANAA_AA1_RESETVAL (0x00000000u)
/*----AA1 Tokens----*/
#define CSL_HECC_CANAA_AA1_NOTABORTED (0x00000000u)
#define CSL_HECC_CANAA_AA1_ABORTED (0x00000001u)

#define CSL_HECC_CANAA_AA0_MASK (0x00000001u)
#define CSL_HECC_CANAA_AA0_SHIFT (0x00000000u)
#define CSL_HECC_CANAA_AA0_RESETVAL (0x00000000u)
/*----AA0 Tokens----*/
#define CSL_HECC_CANAA_AA0_NOTABORTED (0x00000000u)
#define CSL_HECC_CANAA_AA0_ABORTED (0x00000001u)

#define CSL_HECC_CANAA_RESETVAL (0x00000000u)

/* CANRMP */

#define CSL_HECC_CANRMP_RMP31_MASK (0x80000000u)
#define CSL_HECC_CANRMP_RMP31_SHIFT (0x0000001Fu)
#define CSL_HECC_CANRMP_RMP31_RESETVAL (0x00000000u)
/*----RMP31 Tokens----*/
#define CSL_HECC_CANRMP_RMP31_NOMESG (0x00000000u)
#define CSL_HECC_CANRMP_RMP31_MESG (0x00000001u)

#define CSL_HECC_CANRMP_RMP30_MASK (0x40000000u)
#define CSL_HECC_CANRMP_RMP30_SHIFT (0x0000001Eu)
#define CSL_HECC_CANRMP_RMP30_RESETVAL (0x00000000u)
/*----RMP30 Tokens----*/
#define CSL_HECC_CANRMP_RMP30_NOMESG (0x00000000u)
#define CSL_HECC_CANRMP_RMP30_MESG (0x00000001u)

#define CSL_HECC_CANRMP_RMP29_MASK (0x20000000u)
#define CSL_HECC_CANRMP_RMP29_SHIFT (0x0000001Du)
#define CSL_HECC_CANRMP_RMP29_RESETVAL (0x00000000u)
/*----RMP29 Tokens----*/
#define CSL_HECC_CANRMP_RMP29_NOMESG (0x00000000u)
#define CSL_HECC_CANRMP_RMP29_MESG (0x00000001u)

#define CSL_HECC_CANRMP_RMP28_MASK (0x10000000u)
#define CSL_HECC_CANRMP_RMP28_SHIFT (0x0000001Cu)
#define CSL_HECC_CANRMP_RMP28_RESETVAL (0x00000000u)
/*----RMP28 Tokens----*/
#define CSL_HECC_CANRMP_RMP28_NOMESG (0x00000000u)
#define CSL_HECC_CANRMP_RMP28_MESG (0x00000001u)

#define CSL_HECC_CANRMP_RMP27_MASK (0x08000000u)
#define CSL_HECC_CANRMP_RMP27_SHIFT (0x0000001Bu)
#define CSL_HECC_CANRMP_RMP27_RESETVAL (0x00000000u)
/*----RMP27 Tokens----*/
#define CSL_HECC_CANRMP_RMP27_NOMESG (0x00000000u)
#define CSL_HECC_CANRMP_RMP27_MESG (0x00000001u)

#define CSL_HECC_CANRMP_RMP26_MASK (0x04000000u)
#define CSL_HECC_CANRMP_RMP26_SHIFT (0x0000001Au)
#define CSL_HECC_CANRMP_RMP26_RESETVAL (0x00000000u)
/*----RMP26 Tokens----*/
#define CSL_HECC_CANRMP_RMP26_NOMESG (0x00000000u)
#define CSL_HECC_CANRMP_RMP26_MESG (0x00000001u)

#define CSL_HECC_CANRMP_RMP25_MASK (0x02000000u)
#define CSL_HECC_CANRMP_RMP25_SHIFT (0x00000019u)
#define CSL_HECC_CANRMP_RMP25_RESETVAL (0x00000000u)
/*----RMP25 Tokens----*/
#define CSL_HECC_CANRMP_RMP25_NOMESG (0x00000000u)
#define CSL_HECC_CANRMP_RMP25_MESG (0x00000001u)

#define CSL_HECC_CANRMP_RMP24_MASK (0x01000000u)
#define CSL_HECC_CANRMP_RMP24_SHIFT (0x00000018u)
#define CSL_HECC_CANRMP_RMP24_RESETVAL (0x00000000u)
/*----RMP24 Tokens----*/
#define CSL_HECC_CANRMP_RMP24_NOMESG (0x00000000u)
#define CSL_HECC_CANRMP_RMP24_MESG (0x00000001u)

#define CSL_HECC_CANRMP_RMP23_MASK (0x00800000u)
#define CSL_HECC_CANRMP_RMP23_SHIFT (0x00000017u)
#define CSL_HECC_CANRMP_RMP23_RESETVAL (0x00000000u)
/*----RMP23 Tokens----*/
#define CSL_HECC_CANRMP_RMP23_NOMESG (0x00000000u)
#define CSL_HECC_CANRMP_RMP23_MESG (0x00000001u)

#define CSL_HECC_CANRMP_RMP22_MASK (0x00400000u)
#define CSL_HECC_CANRMP_RMP22_SHIFT (0x00000016u)
#define CSL_HECC_CANRMP_RMP22_RESETVAL (0x00000000u)
/*----RMP22 Tokens----*/
#define CSL_HECC_CANRMP_RMP22_NOMESG (0x00000000u)
#define CSL_HECC_CANRMP_RMP22_MESG (0x00000001u)

#define CSL_HECC_CANRMP_RMP21_MASK (0x00200000u)
#define CSL_HECC_CANRMP_RMP21_SHIFT (0x00000015u)
#define CSL_HECC_CANRMP_RMP21_RESETVAL (0x00000000u)
/*----RMP21 Tokens----*/
#define CSL_HECC_CANRMP_RMP21_NOMESG (0x00000000u)
#define CSL_HECC_CANRMP_RMP21_MESG (0x00000001u)

#define CSL_HECC_CANRMP_RMP20_MASK (0x00100000u)
#define CSL_HECC_CANRMP_RMP20_SHIFT (0x00000014u)
#define CSL_HECC_CANRMP_RMP20_RESETVAL (0x00000000u)
/*----RMP20 Tokens----*/
#define CSL_HECC_CANRMP_RMP20_NOMESG (0x00000000u)
#define CSL_HECC_CANRMP_RMP20_MESG (0x00000001u)

#define CSL_HECC_CANRMP_RMP19_MASK (0x00080000u)
#define CSL_HECC_CANRMP_RMP19_SHIFT (0x00000013u)
#define CSL_HECC_CANRMP_RMP19_RESETVAL (0x00000000u)
/*----RMP19 Tokens----*/
#define CSL_HECC_CANRMP_RMP19_NOMESG (0x00000000u)
#define CSL_HECC_CANRMP_RMP19_MESG (0x00000001u)

#define CSL_HECC_CANRMP_RMP18_MASK (0x00040000u)
#define CSL_HECC_CANRMP_RMP18_SHIFT (0x00000012u)
#define CSL_HECC_CANRMP_RMP18_RESETVAL (0x00000000u)
/*----RMP18 Tokens----*/
#define CSL_HECC_CANRMP_RMP18_NOMESG (0x00000000u)
#define CSL_HECC_CANRMP_RMP18_MESG (0x00000001u)

#define CSL_HECC_CANRMP_RMP17_MASK (0x00020000u)
#define CSL_HECC_CANRMP_RMP17_SHIFT (0x00000011u)
#define CSL_HECC_CANRMP_RMP17_RESETVAL (0x00000000u)
/*----RMP17 Tokens----*/
#define CSL_HECC_CANRMP_RMP17_NOMESG (0x00000000u)
#define CSL_HECC_CANRMP_RMP17_MESG (0x00000001u)

#define CSL_HECC_CANRMP_RMP16_MASK (0x00010000u)
#define CSL_HECC_CANRMP_RMP16_SHIFT (0x00000010u)
#define CSL_HECC_CANRMP_RMP16_RESETVAL (0x00000000u)
/*----RMP16 Tokens----*/
#define CSL_HECC_CANRMP_RMP16_NOMESG (0x00000000u)
#define CSL_HECC_CANRMP_RMP16_MESG (0x00000001u)

#define CSL_HECC_CANRMP_RMP15_MASK (0x00008000u)
#define CSL_HECC_CANRMP_RMP15_SHIFT (0x0000000Fu)
#define CSL_HECC_CANRMP_RMP15_RESETVAL (0x00000000u)
/*----RMP15 Tokens----*/
#define CSL_HECC_CANRMP_RMP15_NOMESG (0x00000000u)
#define CSL_HECC_CANRMP_RMP15_MESG (0x00000001u)

#define CSL_HECC_CANRMP_RMP14_MASK (0x00004000u)
#define CSL_HECC_CANRMP_RMP14_SHIFT (0x0000000Eu)
#define CSL_HECC_CANRMP_RMP14_RESETVAL (0x00000000u)
/*----RMP14 Tokens----*/
#define CSL_HECC_CANRMP_RMP14_NOMESG (0x00000000u)
#define CSL_HECC_CANRMP_RMP14_MESG (0x00000001u)

#define CSL_HECC_CANRMP_RMP13_MASK (0x00002000u)
#define CSL_HECC_CANRMP_RMP13_SHIFT (0x0000000Du)
#define CSL_HECC_CANRMP_RMP13_RESETVAL (0x00000000u)
/*----RMP13 Tokens----*/
#define CSL_HECC_CANRMP_RMP13_NOMESG (0x00000000u)
#define CSL_HECC_CANRMP_RMP13_MESG (0x00000001u)

#define CSL_HECC_CANRMP_RMP12_MASK (0x00001000u)
#define CSL_HECC_CANRMP_RMP12_SHIFT (0x0000000Cu)
#define CSL_HECC_CANRMP_RMP12_RESETVAL (0x00000000u)
/*----RMP12 Tokens----*/
#define CSL_HECC_CANRMP_RMP12_NOMESG (0x00000000u)
#define CSL_HECC_CANRMP_RMP12_MESG (0x00000001u)

#define CSL_HECC_CANRMP_RMP11_MASK (0x00000800u)
#define CSL_HECC_CANRMP_RMP11_SHIFT (0x0000000Bu)
#define CSL_HECC_CANRMP_RMP11_RESETVAL (0x00000000u)
/*----RMP11 Tokens----*/
#define CSL_HECC_CANRMP_RMP11_NOMESG (0x00000000u)
#define CSL_HECC_CANRMP_RMP11_MESG (0x00000001u)

#define CSL_HECC_CANRMP_RMP10_MASK (0x00000400u)
#define CSL_HECC_CANRMP_RMP10_SHIFT (0x0000000Au)
#define CSL_HECC_CANRMP_RMP10_RESETVAL (0x00000000u)
/*----RMP10 Tokens----*/
#define CSL_HECC_CANRMP_RMP10_NOMESG (0x00000000u)
#define CSL_HECC_CANRMP_RMP10_MESG (0x00000001u)

#define CSL_HECC_CANRMP_RMP9_MASK (0x00000200u)
#define CSL_HECC_CANRMP_RMP9_SHIFT (0x00000009u)
#define CSL_HECC_CANRMP_RMP9_RESETVAL (0x00000000u)
/*----RMP9 Tokens----*/
#define CSL_HECC_CANRMP_RMP9_NOMESG (0x00000000u)
#define CSL_HECC_CANRMP_RMP9_MESG (0x00000001u)

#define CSL_HECC_CANRMP_RMP8_MASK (0x00000100u)
#define CSL_HECC_CANRMP_RMP8_SHIFT (0x00000008u)
#define CSL_HECC_CANRMP_RMP8_RESETVAL (0x00000000u)
/*----RMP8 Tokens----*/
#define CSL_HECC_CANRMP_RMP8_NOMESG (0x00000000u)
#define CSL_HECC_CANRMP_RMP8_MESG (0x00000001u)

#define CSL_HECC_CANRMP_RMP7_MASK (0x00000080u)
#define CSL_HECC_CANRMP_RMP7_SHIFT (0x00000007u)
#define CSL_HECC_CANRMP_RMP7_RESETVAL (0x00000000u)
/*----RMP7 Tokens----*/
#define CSL_HECC_CANRMP_RMP7_NOMESG (0x00000000u)
#define CSL_HECC_CANRMP_RMP7_MESG (0x00000001u)

#define CSL_HECC_CANRMP_RMP6_MASK (0x00000040u)
#define CSL_HECC_CANRMP_RMP6_SHIFT (0x00000006u)
#define CSL_HECC_CANRMP_RMP6_RESETVAL (0x00000000u)
/*----RMP6 Tokens----*/
#define CSL_HECC_CANRMP_RMP6_NOMESG (0x00000000u)
#define CSL_HECC_CANRMP_RMP6_MESG (0x00000001u)

#define CSL_HECC_CANRMP_RMP5_MASK (0x00000020u)
#define CSL_HECC_CANRMP_RMP5_SHIFT (0x00000005u)
#define CSL_HECC_CANRMP_RMP5_RESETVAL (0x00000000u)
/*----RMP5 Tokens----*/
#define CSL_HECC_CANRMP_RMP5_NOMESG (0x00000000u)
#define CSL_HECC_CANRMP_RMP5_MESG (0x00000001u)

#define CSL_HECC_CANRMP_RMP4_MASK (0x00000010u)
#define CSL_HECC_CANRMP_RMP4_SHIFT (0x00000004u)
#define CSL_HECC_CANRMP_RMP4_RESETVAL (0x00000000u)
/*----RMP4 Tokens----*/
#define CSL_HECC_CANRMP_RMP4_NOMESG (0x00000000u)
#define CSL_HECC_CANRMP_RMP4_MESG (0x00000001u)

#define CSL_HECC_CANRMP_RMP3_MASK (0x00000008u)
#define CSL_HECC_CANRMP_RMP3_SHIFT (0x00000003u)
#define CSL_HECC_CANRMP_RMP3_RESETVAL (0x00000000u)
/*----RMP3 Tokens----*/
#define CSL_HECC_CANRMP_RMP3_NOMESG (0x00000000u)
#define CSL_HECC_CANRMP_RMP3_MESG (0x00000001u)

#define CSL_HECC_CANRMP_RMP2_MASK (0x00000004u)
#define CSL_HECC_CANRMP_RMP2_SHIFT (0x00000002u)
#define CSL_HECC_CANRMP_RMP2_RESETVAL (0x00000000u)
/*----RMP2 Tokens----*/
#define CSL_HECC_CANRMP_RMP2_NOMESG (0x00000000u)
#define CSL_HECC_CANRMP_RMP2_MESG (0x00000001u)

#define CSL_HECC_CANRMP_RMP1_MASK (0x00000002u)
#define CSL_HECC_CANRMP_RMP1_SHIFT (0x00000001u)
#define CSL_HECC_CANRMP_RMP1_RESETVAL (0x00000000u)
/*----RMP1 Tokens----*/
#define CSL_HECC_CANRMP_RMP1_NOMESG (0x00000000u)
#define CSL_HECC_CANRMP_RMP1_MESG (0x00000001u)

#define CSL_HECC_CANRMP_RMP0_MASK (0x00000001u)
#define CSL_HECC_CANRMP_RMP0_SHIFT (0x00000000u)
#define CSL_HECC_CANRMP_RMP0_RESETVAL (0x00000000u)
/*----RMP0 Tokens----*/
#define CSL_HECC_CANRMP_RMP0_NOMESG (0x00000000u)
#define CSL_HECC_CANRMP_RMP0_MESG (0x00000001u)

#define CSL_HECC_CANRMP_RESETVAL (0x00000000u)

/* CANRML */

#define CSL_HECC_CANRML_RML31_MASK (0x80000000u)
#define CSL_HECC_CANRML_RML31_SHIFT (0x0000001Fu)
#define CSL_HECC_CANRML_RML31_RESETVAL (0x00000000u)
/*----RML31 Tokens----*/
#define CSL_HECC_CANRML_RML31_NOTLOST (0x00000000u)
#define CSL_HECC_CANRML_RML31_LOST (0x00000001u)

#define CSL_HECC_CANRML_RML30_MASK (0x40000000u)
#define CSL_HECC_CANRML_RML30_SHIFT (0x0000001Eu)
#define CSL_HECC_CANRML_RML30_RESETVAL (0x00000000u)
/*----RML30 Tokens----*/
#define CSL_HECC_CANRML_RML30_NOTLOST (0x00000000u)
#define CSL_HECC_CANRML_RML30_LOST (0x00000001u)

#define CSL_HECC_CANRML_RML29_MASK (0x20000000u)
#define CSL_HECC_CANRML_RML29_SHIFT (0x0000001Du)
#define CSL_HECC_CANRML_RML29_RESETVAL (0x00000000u)
/*----RML29 Tokens----*/
#define CSL_HECC_CANRML_RML29_NOTLOST (0x00000000u)
#define CSL_HECC_CANRML_RML29_LOST (0x00000001u)

#define CSL_HECC_CANRML_RML28_MASK (0x10000000u)
#define CSL_HECC_CANRML_RML28_SHIFT (0x0000001Cu)
#define CSL_HECC_CANRML_RML28_RESETVAL (0x00000000u)
/*----RML28 Tokens----*/
#define CSL_HECC_CANRML_RML28_NOTLOST (0x00000000u)
#define CSL_HECC_CANRML_RML28_LOST (0x00000001u)

#define CSL_HECC_CANRML_RML27_MASK (0x08000000u)
#define CSL_HECC_CANRML_RML27_SHIFT (0x0000001Bu)
#define CSL_HECC_CANRML_RML27_RESETVAL (0x00000000u)
/*----RML27 Tokens----*/
#define CSL_HECC_CANRML_RML27_NOTLOST (0x00000000u)
#define CSL_HECC_CANRML_RML27_LOST (0x00000001u)

#define CSL_HECC_CANRML_RML26_MASK (0x04000000u)
#define CSL_HECC_CANRML_RML26_SHIFT (0x0000001Au)
#define CSL_HECC_CANRML_RML26_RESETVAL (0x00000000u)
/*----RML26 Tokens----*/
#define CSL_HECC_CANRML_RML26_NOTLOST (0x00000000u)
#define CSL_HECC_CANRML_RML26_LOST (0x00000001u)

#define CSL_HECC_CANRML_RML25_MASK (0x02000000u)
#define CSL_HECC_CANRML_RML25_SHIFT (0x00000019u)
#define CSL_HECC_CANRML_RML25_RESETVAL (0x00000000u)
/*----RML25 Tokens----*/
#define CSL_HECC_CANRML_RML25_NOTLOST (0x00000000u)
#define CSL_HECC_CANRML_RML25_LOST (0x00000001u)

#define CSL_HECC_CANRML_RML24_MASK (0x01000000u)
#define CSL_HECC_CANRML_RML24_SHIFT (0x00000018u)
#define CSL_HECC_CANRML_RML24_RESETVAL (0x00000000u)
/*----RML24 Tokens----*/
#define CSL_HECC_CANRML_RML24_NOTLOST (0x00000000u)
#define CSL_HECC_CANRML_RML24_LOST (0x00000001u)

#define CSL_HECC_CANRML_RML23_MASK (0x00800000u)
#define CSL_HECC_CANRML_RML23_SHIFT (0x00000017u)
#define CSL_HECC_CANRML_RML23_RESETVAL (0x00000000u)
/*----RML23 Tokens----*/
#define CSL_HECC_CANRML_RML23_NOTLOST (0x00000000u)
#define CSL_HECC_CANRML_RML23_LOST (0x00000001u)

#define CSL_HECC_CANRML_RML22_MASK (0x00400000u)
#define CSL_HECC_CANRML_RML22_SHIFT (0x00000016u)
#define CSL_HECC_CANRML_RML22_RESETVAL (0x00000000u)
/*----RML22 Tokens----*/
#define CSL_HECC_CANRML_RML22_NOTLOST (0x00000000u)
#define CSL_HECC_CANRML_RML22_LOST (0x00000001u)

#define CSL_HECC_CANRML_RML21_MASK (0x00200000u)
#define CSL_HECC_CANRML_RML21_SHIFT (0x00000015u)
#define CSL_HECC_CANRML_RML21_RESETVAL (0x00000000u)
/*----RML21 Tokens----*/
#define CSL_HECC_CANRML_RML21_NOTLOST (0x00000000u)
#define CSL_HECC_CANRML_RML21_LOST (0x00000001u)

#define CSL_HECC_CANRML_RML20_MASK (0x00100000u)
#define CSL_HECC_CANRML_RML20_SHIFT (0x00000014u)
#define CSL_HECC_CANRML_RML20_RESETVAL (0x00000000u)
/*----RML20 Tokens----*/
#define CSL_HECC_CANRML_RML20_NOTLOST (0x00000000u)
#define CSL_HECC_CANRML_RML20_LOST (0x00000001u)

#define CSL_HECC_CANRML_RML19_MASK (0x00080000u)
#define CSL_HECC_CANRML_RML19_SHIFT (0x00000013u)
#define CSL_HECC_CANRML_RML19_RESETVAL (0x00000000u)
/*----RML19 Tokens----*/
#define CSL_HECC_CANRML_RML19_NOTLOST (0x00000000u)
#define CSL_HECC_CANRML_RML19_LOST (0x00000001u)

#define CSL_HECC_CANRML_RML18_MASK (0x00040000u)
#define CSL_HECC_CANRML_RML18_SHIFT (0x00000012u)
#define CSL_HECC_CANRML_RML18_RESETVAL (0x00000000u)
/*----RML18 Tokens----*/
#define CSL_HECC_CANRML_RML18_NOTLOST (0x00000000u)
#define CSL_HECC_CANRML_RML18_LOST (0x00000001u)

#define CSL_HECC_CANRML_RML17_MASK (0x00020000u)
#define CSL_HECC_CANRML_RML17_SHIFT (0x00000011u)
#define CSL_HECC_CANRML_RML17_RESETVAL (0x00000000u)
/*----RML17 Tokens----*/
#define CSL_HECC_CANRML_RML17_NOTLOST (0x00000000u)
#define CSL_HECC_CANRML_RML17_LOST (0x00000001u)

#define CSL_HECC_CANRML_RML16_MASK (0x00010000u)
#define CSL_HECC_CANRML_RML16_SHIFT (0x00000010u)
#define CSL_HECC_CANRML_RML16_RESETVAL (0x00000000u)
/*----RML16 Tokens----*/
#define CSL_HECC_CANRML_RML16_NOTLOST (0x00000000u)
#define CSL_HECC_CANRML_RML16_LOST (0x00000001u)

#define CSL_HECC_CANRML_RML15_MASK (0x00008000u)
#define CSL_HECC_CANRML_RML15_SHIFT (0x0000000Fu)
#define CSL_HECC_CANRML_RML15_RESETVAL (0x00000000u)
/*----RML15 Tokens----*/
#define CSL_HECC_CANRML_RML15_NOTLOST (0x00000000u)
#define CSL_HECC_CANRML_RML15_LOST (0x00000001u)

#define CSL_HECC_CANRML_RML14_MASK (0x00004000u)
#define CSL_HECC_CANRML_RML14_SHIFT (0x0000000Eu)
#define CSL_HECC_CANRML_RML14_RESETVAL (0x00000000u)
/*----RML14 Tokens----*/
#define CSL_HECC_CANRML_RML14_NOTLOST (0x00000000u)
#define CSL_HECC_CANRML_RML14_LOST (0x00000001u)

#define CSL_HECC_CANRML_RML13_MASK (0x00002000u)
#define CSL_HECC_CANRML_RML13_SHIFT (0x0000000Du)
#define CSL_HECC_CANRML_RML13_RESETVAL (0x00000000u)
/*----RML13 Tokens----*/
#define CSL_HECC_CANRML_RML13_NOTLOST (0x00000000u)
#define CSL_HECC_CANRML_RML13_LOST (0x00000001u)

#define CSL_HECC_CANRML_RML12_MASK (0x00001000u)
#define CSL_HECC_CANRML_RML12_SHIFT (0x0000000Cu)
#define CSL_HECC_CANRML_RML12_RESETVAL (0x00000000u)
/*----RML12 Tokens----*/
#define CSL_HECC_CANRML_RML12_NOTLOST (0x00000000u)
#define CSL_HECC_CANRML_RML12_LOST (0x00000001u)

#define CSL_HECC_CANRML_RML11_MASK (0x00000800u)
#define CSL_HECC_CANRML_RML11_SHIFT (0x0000000Bu)
#define CSL_HECC_CANRML_RML11_RESETVAL (0x00000000u)
/*----RML11 Tokens----*/
#define CSL_HECC_CANRML_RML11_NOTLOST (0x00000000u)
#define CSL_HECC_CANRML_RML11_LOST (0x00000001u)

#define CSL_HECC_CANRML_RML10_MASK (0x00000400u)
#define CSL_HECC_CANRML_RML10_SHIFT (0x0000000Au)
#define CSL_HECC_CANRML_RML10_RESETVAL (0x00000000u)
/*----RML10 Tokens----*/
#define CSL_HECC_CANRML_RML10_NOTLOST (0x00000000u)
#define CSL_HECC_CANRML_RML10_LOST (0x00000001u)

#define CSL_HECC_CANRML_RML9_MASK (0x00000200u)
#define CSL_HECC_CANRML_RML9_SHIFT (0x00000009u)
#define CSL_HECC_CANRML_RML9_RESETVAL (0x00000000u)
/*----RML9 Tokens----*/
#define CSL_HECC_CANRML_RML9_NOTLOST (0x00000000u)
#define CSL_HECC_CANRML_RML9_LOST (0x00000001u)

#define CSL_HECC_CANRML_RML8_MASK (0x00000100u)
#define CSL_HECC_CANRML_RML8_SHIFT (0x00000008u)
#define CSL_HECC_CANRML_RML8_RESETVAL (0x00000000u)
/*----RML8 Tokens----*/
#define CSL_HECC_CANRML_RML8_NOTLOST (0x00000000u)
#define CSL_HECC_CANRML_RML8_LOST (0x00000001u)

#define CSL_HECC_CANRML_RML7_MASK (0x00000080u)
#define CSL_HECC_CANRML_RML7_SHIFT (0x00000007u)
#define CSL_HECC_CANRML_RML7_RESETVAL (0x00000000u)
/*----RML7 Tokens----*/
#define CSL_HECC_CANRML_RML7_NOTLOST (0x00000000u)
#define CSL_HECC_CANRML_RML7_LOST (0x00000001u)

#define CSL_HECC_CANRML_RML6_MASK (0x00000040u)
#define CSL_HECC_CANRML_RML6_SHIFT (0x00000006u)
#define CSL_HECC_CANRML_RML6_RESETVAL (0x00000000u)
/*----RML6 Tokens----*/
#define CSL_HECC_CANRML_RML6_NOTLOST (0x00000000u)
#define CSL_HECC_CANRML_RML6_LOST (0x00000001u)

#define CSL_HECC_CANRML_RML5_MASK (0x00000020u)
#define CSL_HECC_CANRML_RML5_SHIFT (0x00000005u)
#define CSL_HECC_CANRML_RML5_RESETVAL (0x00000000u)
/*----RML5 Tokens----*/
#define CSL_HECC_CANRML_RML5_NOTLOST (0x00000000u)
#define CSL_HECC_CANRML_RML5_LOST (0x00000001u)

#define CSL_HECC_CANRML_RML4_MASK (0x00000010u)
#define CSL_HECC_CANRML_RML4_SHIFT (0x00000004u)
#define CSL_HECC_CANRML_RML4_RESETVAL (0x00000000u)
/*----RML4 Tokens----*/
#define CSL_HECC_CANRML_RML4_NOTLOST (0x00000000u)
#define CSL_HECC_CANRML_RML4_LOST (0x00000001u)

#define CSL_HECC_CANRML_RML3_MASK (0x00000008u)
#define CSL_HECC_CANRML_RML3_SHIFT (0x00000003u)
#define CSL_HECC_CANRML_RML3_RESETVAL (0x00000000u)
/*----RML3 Tokens----*/
#define CSL_HECC_CANRML_RML3_NOTLOST (0x00000000u)
#define CSL_HECC_CANRML_RML3_LOST (0x00000001u)

#define CSL_HECC_CANRML_RML2_MASK (0x00000004u)
#define CSL_HECC_CANRML_RML2_SHIFT (0x00000002u)
#define CSL_HECC_CANRML_RML2_RESETVAL (0x00000000u)
/*----RML2 Tokens----*/
#define CSL_HECC_CANRML_RML2_NOTLOST (0x00000000u)
#define CSL_HECC_CANRML_RML2_LOST (0x00000001u)

#define CSL_HECC_CANRML_RML1_MASK (0x00000002u)
#define CSL_HECC_CANRML_RML1_SHIFT (0x00000001u)
#define CSL_HECC_CANRML_RML1_RESETVAL (0x00000000u)
/*----RML1 Tokens----*/
#define CSL_HECC_CANRML_RML1_NOTLOST (0x00000000u)
#define CSL_HECC_CANRML_RML1_LOST (0x00000001u)

#define CSL_HECC_CANRML_RML0_MASK (0x00000001u)
#define CSL_HECC_CANRML_RML0_SHIFT (0x00000000u)
#define CSL_HECC_CANRML_RML0_RESETVAL (0x00000000u)
/*----RML0 Tokens----*/
#define CSL_HECC_CANRML_RML0_NOTLOST (0x00000000u)
#define CSL_HECC_CANRML_RML0_LOST (0x00000001u)

#define CSL_HECC_CANRML_RESETVAL (0x00000000u)

/* CANRFP */

#define CSL_HECC_CANRFP_RFP31_MASK (0x80000000u)
#define CSL_HECC_CANRFP_RFP31_SHIFT (0x0000001Fu)
#define CSL_HECC_CANRFP_RFP31_RESETVAL (0x00000000u)
/*----RFP31 Tokens----*/
#define CSL_HECC_CANRFP_RFP31_NO_RX_REQ (0x00000000u)
#define CSL_HECC_CANRFP_RFP31_RX_REQ (0x00000001u)

#define CSL_HECC_CANRFP_RFP30_MASK (0x40000000u)
#define CSL_HECC_CANRFP_RFP30_SHIFT (0x0000001Eu)
#define CSL_HECC_CANRFP_RFP30_RESETVAL (0x00000000u)
/*----RFP30 Tokens----*/
#define CSL_HECC_CANRFP_RFP30_NO_RX_REQ (0x00000000u)
#define CSL_HECC_CANRFP_RFP30_RX_REQ (0x00000001u)

#define CSL_HECC_CANRFP_RFP29_MASK (0x20000000u)
#define CSL_HECC_CANRFP_RFP29_SHIFT (0x0000001Du)
#define CSL_HECC_CANRFP_RFP29_RESETVAL (0x00000000u)
/*----RFP29 Tokens----*/
#define CSL_HECC_CANRFP_RFP29_NO_RX_REQ (0x00000000u)
#define CSL_HECC_CANRFP_RFP29_RX_REQ (0x00000001u)

#define CSL_HECC_CANRFP_RFP28_MASK (0x10000000u)
#define CSL_HECC_CANRFP_RFP28_SHIFT (0x0000001Cu)
#define CSL_HECC_CANRFP_RFP28_RESETVAL (0x00000000u)
/*----RFP28 Tokens----*/
#define CSL_HECC_CANRFP_RFP28_NO_RX_REQ (0x00000000u)
#define CSL_HECC_CANRFP_RFP28_RX_REQ (0x00000001u)

#define CSL_HECC_CANRFP_RFP27_MASK (0x08000000u)
#define CSL_HECC_CANRFP_RFP27_SHIFT (0x0000001Bu)
#define CSL_HECC_CANRFP_RFP27_RESETVAL (0x00000000u)
/*----RFP27 Tokens----*/
#define CSL_HECC_CANRFP_RFP27_NO_RX_REQ (0x00000000u)
#define CSL_HECC_CANRFP_RFP27_RX_REQ (0x00000001u)

#define CSL_HECC_CANRFP_RFP26_MASK (0x04000000u)
#define CSL_HECC_CANRFP_RFP26_SHIFT (0x0000001Au)
#define CSL_HECC_CANRFP_RFP26_RESETVAL (0x00000000u)
/*----RFP26 Tokens----*/
#define CSL_HECC_CANRFP_RFP26_NO_RX_REQ (0x00000000u)
#define CSL_HECC_CANRFP_RFP26_RX_REQ (0x00000001u)

#define CSL_HECC_CANRFP_RFP25_MASK (0x02000000u)
#define CSL_HECC_CANRFP_RFP25_SHIFT (0x00000019u)
#define CSL_HECC_CANRFP_RFP25_RESETVAL (0x00000000u)
/*----RFP25 Tokens----*/
#define CSL_HECC_CANRFP_RFP25_NO_RX_REQ (0x00000000u)
#define CSL_HECC_CANRFP_RFP25_RX_REQ (0x00000001u)

#define CSL_HECC_CANRFP_RFP24_MASK (0x01000000u)
#define CSL_HECC_CANRFP_RFP24_SHIFT (0x00000018u)
#define CSL_HECC_CANRFP_RFP24_RESETVAL (0x00000000u)
/*----RFP24 Tokens----*/
#define CSL_HECC_CANRFP_RFP24_NO_RX_REQ (0x00000000u)
#define CSL_HECC_CANRFP_RFP24_RX_REQ (0x00000001u)

#define CSL_HECC_CANRFP_RFP23_MASK (0x00800000u)
#define CSL_HECC_CANRFP_RFP23_SHIFT (0x00000017u)
#define CSL_HECC_CANRFP_RFP23_RESETVAL (0x00000000u)
/*----RFP23 Tokens----*/
#define CSL_HECC_CANRFP_RFP23_NO_RX_REQ (0x00000000u)
#define CSL_HECC_CANRFP_RFP23_RX_REQ (0x00000001u)

#define CSL_HECC_CANRFP_RFP22_MASK (0x00400000u)
#define CSL_HECC_CANRFP_RFP22_SHIFT (0x00000016u)
#define CSL_HECC_CANRFP_RFP22_RESETVAL (0x00000000u)
/*----RFP22 Tokens----*/
#define CSL_HECC_CANRFP_RFP22_NO_RX_REQ (0x00000000u)
#define CSL_HECC_CANRFP_RFP22_RX_REQ (0x00000001u)

#define CSL_HECC_CANRFP_RFP21_MASK (0x00200000u)
#define CSL_HECC_CANRFP_RFP21_SHIFT (0x00000015u)
#define CSL_HECC_CANRFP_RFP21_RESETVAL (0x00000000u)
/*----RFP21 Tokens----*/
#define CSL_HECC_CANRFP_RFP21_NO_RX_REQ (0x00000000u)
#define CSL_HECC_CANRFP_RFP21_RX_REQ (0x00000001u)

#define CSL_HECC_CANRFP_RFP20_MASK (0x00100000u)
#define CSL_HECC_CANRFP_RFP20_SHIFT (0x00000014u)
#define CSL_HECC_CANRFP_RFP20_RESETVAL (0x00000000u)
/*----RFP20 Tokens----*/
#define CSL_HECC_CANRFP_RFP20_NO_RX_REQ (0x00000000u)
#define CSL_HECC_CANRFP_RFP20_RX_REQ (0x00000001u)

#define CSL_HECC_CANRFP_RFP19_MASK (0x00080000u)
#define CSL_HECC_CANRFP_RFP19_SHIFT (0x00000013u)
#define CSL_HECC_CANRFP_RFP19_RESETVAL (0x00000000u)
/*----RFP19 Tokens----*/
#define CSL_HECC_CANRFP_RFP19_NO_RX_REQ (0x00000000u)
#define CSL_HECC_CANRFP_RFP19_RX_REQ (0x00000001u)

#define CSL_HECC_CANRFP_RFP18_MASK (0x00040000u)
#define CSL_HECC_CANRFP_RFP18_SHIFT (0x00000012u)
#define CSL_HECC_CANRFP_RFP18_RESETVAL (0x00000000u)
/*----RFP18 Tokens----*/
#define CSL_HECC_CANRFP_RFP18_NO_RX_REQ (0x00000000u)
#define CSL_HECC_CANRFP_RFP18_RX_REQ (0x00000001u)

#define CSL_HECC_CANRFP_RFP17_MASK (0x00020000u)
#define CSL_HECC_CANRFP_RFP17_SHIFT (0x00000011u)
#define CSL_HECC_CANRFP_RFP17_RESETVAL (0x00000000u)
/*----RFP17 Tokens----*/
#define CSL_HECC_CANRFP_RFP17_NO_RX_REQ (0x00000000u)
#define CSL_HECC_CANRFP_RFP17_RX_REQ (0x00000001u)

#define CSL_HECC_CANRFP_RFP16_MASK (0x00010000u)
#define CSL_HECC_CANRFP_RFP16_SHIFT (0x00000010u)
#define CSL_HECC_CANRFP_RFP16_RESETVAL (0x00000000u)
/*----RFP16 Tokens----*/
#define CSL_HECC_CANRFP_RFP16_NO_RX_REQ (0x00000000u)
#define CSL_HECC_CANRFP_RFP16_RX_REQ (0x00000001u)

#define CSL_HECC_CANRFP_RFP15_MASK (0x00008000u)
#define CSL_HECC_CANRFP_RFP15_SHIFT (0x0000000Fu)
#define CSL_HECC_CANRFP_RFP15_RESETVAL (0x00000000u)
/*----RFP15 Tokens----*/
#define CSL_HECC_CANRFP_RFP15_NO_RX_REQ (0x00000000u)
#define CSL_HECC_CANRFP_RFP15_RX_REQ (0x00000001u)

#define CSL_HECC_CANRFP_RFP14_MASK (0x00004000u)
#define CSL_HECC_CANRFP_RFP14_SHIFT (0x0000000Eu)
#define CSL_HECC_CANRFP_RFP14_RESETVAL (0x00000000u)
/*----RFP14 Tokens----*/
#define CSL_HECC_CANRFP_RFP14_NO_RX_REQ (0x00000000u)
#define CSL_HECC_CANRFP_RFP14_RX_REQ (0x00000001u)

#define CSL_HECC_CANRFP_RFP13_MASK (0x00002000u)
#define CSL_HECC_CANRFP_RFP13_SHIFT (0x0000000Du)
#define CSL_HECC_CANRFP_RFP13_RESETVAL (0x00000000u)
/*----RFP13 Tokens----*/
#define CSL_HECC_CANRFP_RFP13_NO_RX_REQ (0x00000000u)
#define CSL_HECC_CANRFP_RFP13_RX_REQ (0x00000001u)

#define CSL_HECC_CANRFP_RFP12_MASK (0x00001000u)
#define CSL_HECC_CANRFP_RFP12_SHIFT (0x0000000Cu)
#define CSL_HECC_CANRFP_RFP12_RESETVAL (0x00000000u)
/*----RFP12 Tokens----*/
#define CSL_HECC_CANRFP_RFP12_NO_RX_REQ (0x00000000u)
#define CSL_HECC_CANRFP_RFP12_RX_REQ (0x00000001u)

#define CSL_HECC_CANRFP_RFP11_MASK (0x00000800u)
#define CSL_HECC_CANRFP_RFP11_SHIFT (0x0000000Bu)
#define CSL_HECC_CANRFP_RFP11_RESETVAL (0x00000000u)
/*----RFP11 Tokens----*/
#define CSL_HECC_CANRFP_RFP11_NO_RX_REQ (0x00000000u)
#define CSL_HECC_CANRFP_RFP11_RX_REQ (0x00000001u)

#define CSL_HECC_CANRFP_RFP10_MASK (0x00000400u)
#define CSL_HECC_CANRFP_RFP10_SHIFT (0x0000000Au)
#define CSL_HECC_CANRFP_RFP10_RESETVAL (0x00000000u)
/*----RFP10 Tokens----*/
#define CSL_HECC_CANRFP_RFP10_NO_RX_REQ (0x00000000u)
#define CSL_HECC_CANRFP_RFP10_RX_REQ (0x00000001u)

#define CSL_HECC_CANRFP_RFP9_MASK (0x00000200u)
#define CSL_HECC_CANRFP_RFP9_SHIFT (0x00000009u)
#define CSL_HECC_CANRFP_RFP9_RESETVAL (0x00000000u)
/*----RFP9 Tokens----*/
#define CSL_HECC_CANRFP_RFP9_NO_RX_REQ (0x00000000u)
#define CSL_HECC_CANRFP_RFP9_RX_REQ (0x00000001u)

#define CSL_HECC_CANRFP_RFP8_MASK (0x00000100u)
#define CSL_HECC_CANRFP_RFP8_SHIFT (0x00000008u)
#define CSL_HECC_CANRFP_RFP8_RESETVAL (0x00000000u)
/*----RFP8 Tokens----*/
#define CSL_HECC_CANRFP_RFP8_NO_RX_REQ (0x00000000u)
#define CSL_HECC_CANRFP_RFP8_RX_REQ (0x00000001u)

#define CSL_HECC_CANRFP_RFP7_MASK (0x00000080u)
#define CSL_HECC_CANRFP_RFP7_SHIFT (0x00000007u)
#define CSL_HECC_CANRFP_RFP7_RESETVAL (0x00000000u)
/*----RFP7 Tokens----*/
#define CSL_HECC_CANRFP_RFP7_NO_RX_REQ (0x00000000u)
#define CSL_HECC_CANRFP_RFP7_RX_REQ (0x00000001u)

#define CSL_HECC_CANRFP_RFP6_MASK (0x00000040u)
#define CSL_HECC_CANRFP_RFP6_SHIFT (0x00000006u)
#define CSL_HECC_CANRFP_RFP6_RESETVAL (0x00000000u)
/*----RFP6 Tokens----*/
#define CSL_HECC_CANRFP_RFP6_NO_RX_REQ (0x00000000u)
#define CSL_HECC_CANRFP_RFP6_RX_REQ (0x00000001u)

#define CSL_HECC_CANRFP_RFP5_MASK (0x00000020u)
#define CSL_HECC_CANRFP_RFP5_SHIFT (0x00000005u)
#define CSL_HECC_CANRFP_RFP5_RESETVAL (0x00000000u)
/*----RFP5 Tokens----*/
#define CSL_HECC_CANRFP_RFP5_NO_RX_REQ (0x00000000u)
#define CSL_HECC_CANRFP_RFP5_RX_REQ (0x00000001u)

#define CSL_HECC_CANRFP_RFP4_MASK (0x00000010u)
#define CSL_HECC_CANRFP_RFP4_SHIFT (0x00000004u)
#define CSL_HECC_CANRFP_RFP4_RESETVAL (0x00000000u)
/*----RFP4 Tokens----*/
#define CSL_HECC_CANRFP_RFP4_NO_RX_REQ (0x00000000u)
#define CSL_HECC_CANRFP_RFP4_RX_REQ (0x00000001u)

#define CSL_HECC_CANRFP_RFP3_MASK (0x00000008u)
#define CSL_HECC_CANRFP_RFP3_SHIFT (0x00000003u)
#define CSL_HECC_CANRFP_RFP3_RESETVAL (0x00000000u)
/*----RFP3 Tokens----*/
#define CSL_HECC_CANRFP_RFP3_NO_RX_REQ (0x00000000u)
#define CSL_HECC_CANRFP_RFP3_RX_REQ (0x00000001u)

#define CSL_HECC_CANRFP_RFP2_MASK (0x00000004u)
#define CSL_HECC_CANRFP_RFP2_SHIFT (0x00000002u)
#define CSL_HECC_CANRFP_RFP2_RESETVAL (0x00000000u)
/*----RFP2 Tokens----*/
#define CSL_HECC_CANRFP_RFP2_NO_RX_REQ (0x00000000u)
#define CSL_HECC_CANRFP_RFP2_RX_REQ (0x00000001u)

#define CSL_HECC_CANRFP_RFP1_MASK (0x00000002u)
#define CSL_HECC_CANRFP_RFP1_SHIFT (0x00000001u)
#define CSL_HECC_CANRFP_RFP1_RESETVAL (0x00000000u)
/*----RFP1 Tokens----*/
#define CSL_HECC_CANRFP_RFP1_NO_RX_REQ (0x00000000u)
#define CSL_HECC_CANRFP_RFP1_RX_REQ (0x00000001u)

#define CSL_HECC_CANRFP_RFP0_MASK (0x00000001u)
#define CSL_HECC_CANRFP_RFP0_SHIFT (0x00000000u)
#define CSL_HECC_CANRFP_RFP0_RESETVAL (0x00000000u)
/*----RFP0 Tokens----*/
#define CSL_HECC_CANRFP_RFP0_NO_RX_REQ (0x00000000u)
#define CSL_HECC_CANRFP_RFP0_RX_REQ (0x00000001u)

#define CSL_HECC_CANRFP_RESETVAL (0x00000000u)

/* CANMC */


#define CSL_HECC_CANMC_LNTC_MASK (0x00008000u)
#define CSL_HECC_CANMC_LNTC_SHIFT (0x0000000Fu)
#define CSL_HECC_CANMC_LNTC_RESETVAL (0x00000000u)
/*----LNTC Tokens----*/
#define CSL_HECC_CANMC_LNTC_NO_RESET (0x00000000u)
#define CSL_HECC_CANMC_LNTC_RESET (0x00000001u)

#define CSL_HECC_CANMC_LNTM_MASK (0x00004000u)
#define CSL_HECC_CANMC_LNTM_SHIFT (0x0000000Eu)
#define CSL_HECC_CANMC_LNTM_RESETVAL (0x00000000u)
/*----LNTM Tokens----*/
#define CSL_HECC_CANMC_LNTM_NOT_CLEARED (0x00000000u)
#define CSL_HECC_CANMC_LNTM_CLEARED (0x00000001u)

#define CSL_HECC_CANMC_SCM_MASK (0x00002000u)
#define CSL_HECC_CANMC_SCM_SHIFT (0x0000000Du)
#define CSL_HECC_CANMC_SCM_RESETVAL (0x00000000u)
/*----SCM Tokens----*/
#define CSL_HECC_CANMC_SCM_SCC (0x00000000u)
#define CSL_HECC_CANMC_SCM_NORMAL (0x00000001u)

#define CSL_HECC_CANMC_CCR_MASK (0x00001000u)
#define CSL_HECC_CANMC_CCR_SHIFT (0x0000000Cu)
#define CSL_HECC_CANMC_CCR_RESETVAL (0x00000001u)
/*----CCR Tokens----*/
#define CSL_HECC_CANMC_CCR_NORMAL (0x00000000u)
#define CSL_HECC_CANMC_CCR_WRT_ACCESS (0x00000001u)

#define CSL_HECC_CANMC_PDR_MASK (0x00000800u)
#define CSL_HECC_CANMC_PDR_SHIFT (0x0000000Bu)
#define CSL_HECC_CANMC_PDR_RESETVAL (0x00000000u)
/*----PDR Tokens----*/
#define CSL_HECC_CANMC_PDR_NORMAL (0x00000000u)
#define CSL_HECC_CANMC_PDR_PWRDWN (0x00000001u)

#define CSL_HECC_CANMC_DBO_MASK (0x00000400u)
#define CSL_HECC_CANMC_DBO_SHIFT (0x0000000Au)
#define CSL_HECC_CANMC_DBO_RESETVAL (0x00000000u)
/*----DBO Tokens----*/
#define CSL_HECC_CANMC_DBO_MSBFIRST (0x00000000u)
#define CSL_HECC_CANMC_DBO_LSBFIRST (0x00000001u)

#define CSL_HECC_CANMC_WUBA_MASK (0x00000200u)
#define CSL_HECC_CANMC_WUBA_SHIFT (0x00000009u)
#define CSL_HECC_CANMC_WUBA_RESETVAL (0x00000000u)
/*----WUBA Tokens----*/
#define CSL_HECC_CANMC_WUBA_RESET (0x00000000u)
#define CSL_HECC_CANMC_WUBA_SET (0x00000001u)

#define CSL_HECC_CANMC_CDR_MASK (0x00000100u)
#define CSL_HECC_CANMC_CDR_SHIFT (0x00000008u)
#define CSL_HECC_CANMC_CDR_RESETVAL (0x00000000u)
/*----CDR Tokens----*/
#define CSL_HECC_CANMC_CDR_NORMAL (0x00000000u)
#define CSL_HECC_CANMC_CDR_WRT_ACCESS (0x00000001u)

#define CSL_HECC_CANMC_ABO_MASK (0x00000080u)
#define CSL_HECC_CANMC_ABO_SHIFT (0x00000007u)
#define CSL_HECC_CANMC_ABO_RESETVAL (0x00000000u)
/*----ABO Tokens----*/
#define CSL_HECC_CANMC_ABO_BUSOFF (0x00000000u)
#define CSL_HECC_CANMC_ABO_BUSON (0x00000001u)

#define CSL_HECC_CANMC_STM_MASK (0x00000040u)
#define CSL_HECC_CANMC_STM_SHIFT (0x00000006u)
#define CSL_HECC_CANMC_STM_RESETVAL (0x00000000u)
/*----STM Tokens----*/
#define CSL_HECC_CANMC_STM_NORMAL (0x00000000u)
#define CSL_HECC_CANMC_STM_SELFTEST (0x00000001u)

#define CSL_HECC_CANMC_SRES_MASK (0x00000020u)
#define CSL_HECC_CANMC_SRES_SHIFT (0x00000005u)
#define CSL_HECC_CANMC_SRES_RESETVAL (0x00000000u)
/*----SRES Tokens----*/
#define CSL_HECC_CANMC_SRES_SWRESET (0x00000001u)

#define CSL_HECC_CANMC_MNBR_MASK (0x0000001Fu)
#define CSL_HECC_CANMC_MNBR_SHIFT (0x00000000u)
#define CSL_HECC_CANMC_MNBR_RESETVAL (0x00000000u)

#define CSL_HECC_CANMC_RESETVAL (0x00001000u)

/* CANBTC */


#define CSL_HECC_CANBTC_BRP_MASK (0x00FF0000u)
#define CSL_HECC_CANBTC_BRP_SHIFT (0x00000010u)
#define CSL_HECC_CANBTC_BRP_RESETVAL (0x00000000u)


#define CSL_HECC_CANBTC_ERM_MASK (0x00000400u)
#define CSL_HECC_CANBTC_ERM_SHIFT (0x0000000Au)
#define CSL_HECC_CANBTC_ERM_RESETVAL (0x00000000u)
/*----ERM Tokens----*/
#define CSL_HECC_CANBTC_ERM_FALLING (0x00000000u)
#define CSL_HECC_CANBTC_ERM_BOTH (0x00000001u)

#define CSL_HECC_CANBTC_SJW_MASK (0x00000300u)
#define CSL_HECC_CANBTC_SJW_SHIFT (0x00000008u)
#define CSL_HECC_CANBTC_SJW_RESETVAL (0x00000000u)

#define CSL_HECC_CANBTC_SAM_MASK (0x00000080u)
#define CSL_HECC_CANBTC_SAM_SHIFT (0x00000007u)
#define CSL_HECC_CANBTC_SAM_RESETVAL (0x00000000u)
/*----SAM Tokens----*/
#define CSL_HECC_CANBTC_SAM_ONE (0x00000000u)
#define CSL_HECC_CANBTC_SAM_THREE (0x00000001u)

#define CSL_HECC_CANBTC_TSEG1_MASK (0x00000078u)
#define CSL_HECC_CANBTC_TSEG1_SHIFT (0x00000003u)
#define CSL_HECC_CANBTC_TSEG1_RESETVAL (0x00000000u)

#define CSL_HECC_CANBTC_TSEG2_MASK (0x00000007u)
#define CSL_HECC_CANBTC_TSEG2_SHIFT (0x00000000u)
#define CSL_HECC_CANBTC_TSEG2_RESETVAL (0x00000000u)

#define CSL_HECC_CANBTC_RESETVAL (0x00000000u)

/* CANES */


#define CSL_HECC_CANES_FE_MASK (0x01000000u)
#define CSL_HECC_CANES_FE_SHIFT (0x00000018u)
#define CSL_HECC_CANES_FE_RESETVAL (0x00000000u)
/*----FE Tokens----*/
#define CSL_HECC_CANES_FE_NOERR (0x00000000u)
#define CSL_HECC_CANES_FE_ERR (0x00000001u)

#define CSL_HECC_CANES_BE_MASK (0x00800000u)
#define CSL_HECC_CANES_BE_SHIFT (0x00000017u)
#define CSL_HECC_CANES_BE_RESETVAL (0x00000000u)
/*----BE Tokens----*/
#define CSL_HECC_CANES_BE_NOERR (0x00000000u)
#define CSL_HECC_CANES_BE_ERR (0x00000001u)

#define CSL_HECC_CANES_SA1_MASK (0x00400000u)
#define CSL_HECC_CANES_SA1_SHIFT (0x00000016u)
#define CSL_HECC_CANES_SA1_RESETVAL (0x00000001u)
/*----SA1 Tokens----*/
#define CSL_HECC_CANES_SA1_NOERR (0x00000000u)
#define CSL_HECC_CANES_SA1_ERR (0x00000001u)

#define CSL_HECC_CANES_CRCE_MASK (0x00200000u)
#define CSL_HECC_CANES_CRCE_SHIFT (0x00000015u)
#define CSL_HECC_CANES_CRCE_RESETVAL (0x00000000u)
/*----CRCE Tokens----*/
#define CSL_HECC_CANES_CRCE_NOERR (0x00000000u)
#define CSL_HECC_CANES_CRCE_ERR (0x00000001u)

#define CSL_HECC_CANES_SE_MASK (0x00100000u)
#define CSL_HECC_CANES_SE_SHIFT (0x00000014u)
#define CSL_HECC_CANES_SE_RESETVAL (0x00000000u)
/*----SE Tokens----*/
#define CSL_HECC_CANES_SE_NOERR (0x00000000u)
#define CSL_HECC_CANES_SE_ERR (0x00000001u)

#define CSL_HECC_CANES_ACKE_MASK (0x00080000u)
#define CSL_HECC_CANES_ACKE_SHIFT (0x00000013u)
#define CSL_HECC_CANES_ACKE_RESETVAL (0x00000000u)
/*----ACKE Tokens----*/
#define CSL_HECC_CANES_ACKE_NOERR (0x00000000u)
#define CSL_HECC_CANES_ACKE_ERR (0x00000001u)

#define CSL_HECC_CANES_BO_MASK (0x00040000u)
#define CSL_HECC_CANES_BO_SHIFT (0x00000012u)
#define CSL_HECC_CANES_BO_RESETVAL (0x00000000u)
/*----BO Tokens----*/
#define CSL_HECC_CANES_BO_NOERR (0x00000000u)
#define CSL_HECC_CANES_BO_ERR (0x00000001u)

#define CSL_HECC_CANES_EP_MASK (0x00020000u)
#define CSL_HECC_CANES_EP_SHIFT (0x00000011u)
#define CSL_HECC_CANES_EP_RESETVAL (0x00000000u)
/*----EP Tokens----*/
#define CSL_HECC_CANES_EP_ACTIVE (0x00000000u)
#define CSL_HECC_CANES_EP_PASSIVE (0x00000001u)

#define CSL_HECC_CANES_EW_MASK (0x00010000u)
#define CSL_HECC_CANES_EW_SHIFT (0x00000010u)
#define CSL_HECC_CANES_EW_RESETVAL (0x00000000u)
/*----EW Tokens----*/
#define CSL_HECC_CANES_EW_NOERR (0x00000000u)
#define CSL_HECC_CANES_EW_ERR (0x00000001u)


#define CSL_HECC_CANES_SMA_MASK (0x00000020u)
#define CSL_HECC_CANES_SMA_SHIFT (0x00000005u)
#define CSL_HECC_CANES_SMA_RESETVAL (0x00000000u)
/*----SMA Tokens----*/
#define CSL_HECC_CANES_SMA_NOSUSPEND (0x00000000u)
#define CSL_HECC_CANES_SMA_SUSPEND (0x00000001u)

#define CSL_HECC_CANES_CCE_MASK (0x00000010u)
#define CSL_HECC_CANES_CCE_SHIFT (0x00000004u)
#define CSL_HECC_CANES_CCE_RESETVAL (0x00000001u)
/*----CCE Tokens----*/
#define CSL_HECC_CANES_CCE_NOWRITE (0x00000000u)
#define CSL_HECC_CANES_CCE_WRITE (0x00000001u)

#define CSL_HECC_CANES_PDA_MASK (0x00000008u)
#define CSL_HECC_CANES_PDA_SHIFT (0x00000003u)
#define CSL_HECC_CANES_PDA_RESETVAL (0x00000000u)
/*----PDA Tokens----*/
#define CSL_HECC_CANES_PDA_NORMAL (0x00000000u)
#define CSL_HECC_CANES_PDA_PWRDWN (0x00000001u)


#define CSL_HECC_CANES_RM_MASK (0x00000002u)
#define CSL_HECC_CANES_RM_SHIFT (0x00000001u)
#define CSL_HECC_CANES_RM_RESETVAL (0x00000000u)
/*----RM Tokens----*/
#define CSL_HECC_CANES_RM_NORECV (0x00000000u)
#define CSL_HECC_CANES_RM_RECV (0x00000001u)

#define CSL_HECC_CANES_TM_MASK (0x00000001u)
#define CSL_HECC_CANES_TM_SHIFT (0x00000000u)
#define CSL_HECC_CANES_TM_RESETVAL (0x00000000u)
/*----TM Tokens----*/
#define CSL_HECC_CANES_TM_NO_TX (0x00000000u)
#define CSL_HECC_CANES_TM_TX (0x00000001u)

#define CSL_HECC_CANES_RESETVAL (0x00400010u)

/* CANTEC */


#define CSL_HECC_CANTEC_TEC_MASK (0x000000FFu)
#define CSL_HECC_CANTEC_TEC_SHIFT (0x00000000u)
#define CSL_HECC_CANTEC_TEC_RESETVAL (0x00000000u)

#define CSL_HECC_CANTEC_RESETVAL (0x00000000u)

/* CANREC */


#define CSL_HECC_CANREC_REC_MASK (0x000000FFu)
#define CSL_HECC_CANREC_REC_SHIFT (0x00000000u)
#define CSL_HECC_CANREC_REC_RESETVAL (0x00000000u)

#define CSL_HECC_CANREC_RESETVAL (0x00000000u)

/* CANGIF0 */


#define CSL_HECC_CANGIF0_MAIF0_MASK (0x00020000u)
#define CSL_HECC_CANGIF0_MAIF0_SHIFT (0x00000011u)
#define CSL_HECC_CANGIF0_MAIF0_RESETVAL (0x00000000u)
/*----MAIF0 Tokens----*/
#define CSL_HECC_CANGIF0_MAIF0_NOTIMEOUT (0x00000000u)
#define CSL_HECC_CANGIF0_MAIF0_TIMEOUT (0x00000001u)

#define CSL_HECC_CANGIF0_TCOIF0_MASK (0x00010000u)
#define CSL_HECC_CANGIF0_TCOIF0_SHIFT (0x00000010u)
#define CSL_HECC_CANGIF0_TCOIF0_RESETVAL (0x00000000u)
/*----TCOIF0 Tokens----*/
#define CSL_HECC_CANGIF0_TCOIF0_RESET (0x00000000u)
#define CSL_HECC_CANGIF0_TCOIF0_SET (0x00000001u)

#define CSL_HECC_CANGIF0_GMIF0_MASK (0x00008000u)
#define CSL_HECC_CANGIF0_GMIF0_SHIFT (0x0000000Fu)
#define CSL_HECC_CANGIF0_GMIF0_RESETVAL (0x00000000u)
/*----GMIF0 Tokens----*/
#define CSL_HECC_CANGIF0_GMIF0_RESET (0x00000000u)
#define CSL_HECC_CANGIF0_GMIF0_SET (0x00000001u)

#define CSL_HECC_CANGIF0_AAIF0_MASK (0x00004000u)
#define CSL_HECC_CANGIF0_AAIF0_SHIFT (0x0000000Eu)
#define CSL_HECC_CANGIF0_AAIF0_RESETVAL (0x00000000u)
/*----AAIF0 Tokens----*/
#define CSL_HECC_CANGIF0_AAIF0_NOABORT (0x00000000u)
#define CSL_HECC_CANGIF0_AAIF0_ABORTED (0x00000001u)

#define CSL_HECC_CANGIF0_WDIF0_MASK (0x00002000u)
#define CSL_HECC_CANGIF0_WDIF0_SHIFT (0x0000000Du)
#define CSL_HECC_CANGIF0_WDIF0_RESETVAL (0x00000000u)
/*----WDIF0 Tokens----*/
#define CSL_HECC_CANGIF0_WDIF0_RESET (0x00000000u)
#define CSL_HECC_CANGIF0_WDIF0_SET (0x00000001u)

#define CSL_HECC_CANGIF0_WUIF0_MASK (0x00001000u)
#define CSL_HECC_CANGIF0_WUIF0_SHIFT (0x0000000Cu)
#define CSL_HECC_CANGIF0_WUIF0_RESETVAL (0x00000000u)
/*----WUIF0 Tokens----*/
#define CSL_HECC_CANGIF0_WUIF0_NORMAL (0x00000000u)
#define CSL_HECC_CANGIF0_WUIF0_PWRDWN (0x00000001u)

#define CSL_HECC_CANGIF0_RMLIF0_MASK (0x00000800u)
#define CSL_HECC_CANGIF0_RMLIF0_SHIFT (0x0000000Bu)
#define CSL_HECC_CANGIF0_RMLIF0_RESETVAL (0x00000000u)
/*----RMLIF0 Tokens----*/
#define CSL_HECC_CANGIF0_RMLIF0_NOLOST (0x00000000u)
#define CSL_HECC_CANGIF0_RMLIF0_LOST (0x00000001u)

#define CSL_HECC_CANGIF0_BOIF0_MASK (0x00000400u)
#define CSL_HECC_CANGIF0_BOIF0_SHIFT (0x0000000Au)
#define CSL_HECC_CANGIF0_BOIF0_RESETVAL (0x00000000u)
/*----BOIF0 Tokens----*/
#define CSL_HECC_CANGIF0_BOIF0_BUSONMODE (0x00000000u)
#define CSL_HECC_CANGIF0_BOIF0_BUSOFFMODE (0x00000001u)

#define CSL_HECC_CANGIF0_EPIF0_MASK (0x00000200u)
#define CSL_HECC_CANGIF0_EPIF0_SHIFT (0x00000009u)
#define CSL_HECC_CANGIF0_EPIF0_RESETVAL (0x00000000u)
/*----EPIF0 Tokens----*/
#define CSL_HECC_CANGIF0_EPIF0_NOTERRPASSIVE (0x00000000u)
#define CSL_HECC_CANGIF0_EPIF0_ERRPASSIVE (0x00000001u)

#define CSL_HECC_CANGIF0_WLIF0_MASK (0x00000100u)
#define CSL_HECC_CANGIF0_WLIF0_SHIFT (0x00000008u)
#define CSL_HECC_CANGIF0_WLIF0_RESETVAL (0x00000000u)
/*----WLIF0 Tokens----*/
#define CSL_HECC_CANGIF0_WLIF0_NOTREACHED (0x00000000u)
#define CSL_HECC_CANGIF0_WLIF0_REACHED (0x00000001u)


#define CSL_HECC_CANGIF0_MIV0_MASK (0x0000001Fu)
#define CSL_HECC_CANGIF0_MIV0_SHIFT (0x00000000u)
#define CSL_HECC_CANGIF0_MIV0_RESETVAL (0x00000000u)

#define CSL_HECC_CANGIF0_RESETVAL (0x00000000u)

/* CANGIM */


#define CSL_HECC_CANGIM_MAIM_MASK (0x00020000u)
#define CSL_HECC_CANGIM_MAIM_SHIFT (0x00000011u)
#define CSL_HECC_CANGIM_MAIM_RESETVAL (0x00000000u)
/*----MAIM Tokens----*/
#define CSL_HECC_CANGIM_MAIM_DISABLE (0x00000000u)
#define CSL_HECC_CANGIM_MAIM_ENABLE (0x00000001u)

#define CSL_HECC_CANGIM_TCOIM_MASK (0x00010000u)
#define CSL_HECC_CANGIM_TCOIM_SHIFT (0x00000010u)
#define CSL_HECC_CANGIM_TCOIM_RESETVAL (0x00000000u)
/*----TCOIM Tokens----*/
#define CSL_HECC_CANGIM_TCOIM_DISABLE (0x00000000u)
#define CSL_HECC_CANGIM_TCOIM_ENABLE (0x00000001u)


#define CSL_HECC_CANGIM_AAIM_MASK (0x00004000u)
#define CSL_HECC_CANGIM_AAIM_SHIFT (0x0000000Eu)
#define CSL_HECC_CANGIM_AAIM_RESETVAL (0x00000000u)
/*----AAIM Tokens----*/
#define CSL_HECC_CANGIM_AAIM_DISABLE (0x00000000u)
#define CSL_HECC_CANGIM_AAIM_ENABLE (0x00000001u)

#define CSL_HECC_CANGIM_WDIM_MASK (0x00002000u)
#define CSL_HECC_CANGIM_WDIM_SHIFT (0x0000000Du)
#define CSL_HECC_CANGIM_WDIM_RESETVAL (0x00000000u)
/*----WDIM Tokens----*/
#define CSL_HECC_CANGIM_WDIM_DISABLE (0x00000000u)
#define CSL_HECC_CANGIM_WDIM_ENABLE (0x00000001u)

#define CSL_HECC_CANGIM_WUIM_MASK (0x00001000u)
#define CSL_HECC_CANGIM_WUIM_SHIFT (0x0000000Cu)
#define CSL_HECC_CANGIM_WUIM_RESETVAL (0x00000000u)
/*----WUIM Tokens----*/
#define CSL_HECC_CANGIM_WUIM_DISABLE (0x00000000u)
#define CSL_HECC_CANGIM_WUIM_ENABLE (0x00000001u)

#define CSL_HECC_CANGIM_RMLIM_MASK (0x00000800u)
#define CSL_HECC_CANGIM_RMLIM_SHIFT (0x0000000Bu)
#define CSL_HECC_CANGIM_RMLIM_RESETVAL (0x00000000u)
/*----RMLIM Tokens----*/
#define CSL_HECC_CANGIM_RMLIM_DISABLE (0x00000000u)
#define CSL_HECC_CANGIM_RMLIM_ENABLE (0x00000001u)

#define CSL_HECC_CANGIM_BOIM_MASK (0x00000400u)
#define CSL_HECC_CANGIM_BOIM_SHIFT (0x0000000Au)
#define CSL_HECC_CANGIM_BOIM_RESETVAL (0x00000000u)
/*----BOIM Tokens----*/
#define CSL_HECC_CANGIM_BOIM_DISABLE (0x00000000u)
#define CSL_HECC_CANGIM_BOIM_ENABLE (0x00000001u)

#define CSL_HECC_CANGIM_EPIM_MASK (0x00000200u)
#define CSL_HECC_CANGIM_EPIM_SHIFT (0x00000009u)
#define CSL_HECC_CANGIM_EPIM_RESETVAL (0x00000000u)
/*----EPIM Tokens----*/
#define CSL_HECC_CANGIM_EPIM_DISABLE (0x00000000u)
#define CSL_HECC_CANGIM_EPIM_ENABLE (0x00000001u)

#define CSL_HECC_CANGIM_WLIM_MASK (0x00000100u)
#define CSL_HECC_CANGIM_WLIM_SHIFT (0x00000008u)
#define CSL_HECC_CANGIM_WLIM_RESETVAL (0x00000000u)
/*----WLIM Tokens----*/
#define CSL_HECC_CANGIM_WLIM_DISABLE (0x00000000u)
#define CSL_HECC_CANGIM_WLIM_ENABLE (0x00000001u)


#define CSL_HECC_CANGIM_SIL_MASK (0x00000004u)
#define CSL_HECC_CANGIM_SIL_SHIFT (0x00000002u)
#define CSL_HECC_CANGIM_SIL_RESETVAL (0x00000000u)
/*----SIL Tokens----*/
#define CSL_HECC_CANGIM_SIL_GLINT (0x00000000u)
#define CSL_HECC_CANGIM_SIL_SYSINT (0x00000001u)

#define CSL_HECC_CANGIM_L1EN_MASK (0x00000002u)
#define CSL_HECC_CANGIM_L1EN_SHIFT (0x00000001u)
#define CSL_HECC_CANGIM_L1EN_RESETVAL (0x00000000u)
/*----L1EN Tokens----*/
#define CSL_HECC_CANGIM_L1EN_DISABLE (0x00000000u)
#define CSL_HECC_CANGIM_L1EN_ENABLE (0x00000001u)

#define CSL_HECC_CANGIM_L0EN_MASK (0x00000001u)
#define CSL_HECC_CANGIM_L0EN_SHIFT (0x00000000u)
#define CSL_HECC_CANGIM_L0EN_RESETVAL (0x00000000u)
/*----L0EN Tokens----*/
#define CSL_HECC_CANGIM_L0EN_DISABLE (0x00000000u)
#define CSL_HECC_CANGIM_L0EN_ENABLE (0x00000001u)

#define CSL_HECC_CANGIM_RESETVAL (0x00000000u)

/* CANGIF1 */


#define CSL_HECC_CANGIF1_MAIF1_MASK (0x00020000u)
#define CSL_HECC_CANGIF1_MAIF1_SHIFT (0x00000011u)
#define CSL_HECC_CANGIF1_MAIF1_RESETVAL (0x00000000u)
/*----MAIF1 Tokens----*/
#define CSL_HECC_CANGIF1_MAIF1_NOTIMEOUT (0x00000000u)
#define CSL_HECC_CANGIF1_MAIF1_TIMEOUT (0x00000001u)

#define CSL_HECC_CANGIF1_TCOIF1_MASK (0x00010000u)
#define CSL_HECC_CANGIF1_TCOIF1_SHIFT (0x00000010u)
#define CSL_HECC_CANGIF1_TCOIF1_RESETVAL (0x00000000u)
/*----TCOIF1 Tokens----*/
#define CSL_HECC_CANGIF1_TCOIF1_RESET (0x00000000u)
#define CSL_HECC_CANGIF1_TCOIF1_SET (0x00000001u)

#define CSL_HECC_CANGIF1_GMIF1_MASK (0x00008000u)
#define CSL_HECC_CANGIF1_GMIF1_SHIFT (0x0000000Fu)
#define CSL_HECC_CANGIF1_GMIF1_RESETVAL (0x00000000u)
/*----GMIF1 Tokens----*/
#define CSL_HECC_CANGIF1_GMIF1_RESET (0x00000000u)
#define CSL_HECC_CANGIF1_GMIF1_SET (0x00000001u)

#define CSL_HECC_CANGIF1_AAIF1_MASK (0x00004000u)
#define CSL_HECC_CANGIF1_AAIF1_SHIFT (0x0000000Eu)
#define CSL_HECC_CANGIF1_AAIF1_RESETVAL (0x00000000u)
/*----AAIF1 Tokens----*/
#define CSL_HECC_CANGIF1_AAIF1_NOABORT (0x00000000u)
#define CSL_HECC_CANGIF1_AAIF1_ABORTED (0x00000001u)

#define CSL_HECC_CANGIF1_WDIF1_MASK (0x00002000u)
#define CSL_HECC_CANGIF1_WDIF1_SHIFT (0x0000000Du)
#define CSL_HECC_CANGIF1_WDIF1_RESETVAL (0x00000000u)
/*----WDIF1 Tokens----*/
#define CSL_HECC_CANGIF1_WDIF1_RESET (0x00000000u)
#define CSL_HECC_CANGIF1_WDIF1_SET (0x00000001u)

#define CSL_HECC_CANGIF1_WUIF1_MASK (0x00001000u)
#define CSL_HECC_CANGIF1_WUIF1_SHIFT (0x0000000Cu)
#define CSL_HECC_CANGIF1_WUIF1_RESETVAL (0x00000000u)
/*----WUIF1 Tokens----*/
#define CSL_HECC_CANGIF1_WUIF1_NORMAL (0x00000000u)
#define CSL_HECC_CANGIF1_WUIF1_PWRDWN (0x00000001u)

#define CSL_HECC_CANGIF1_RMLIF1_MASK (0x00000800u)
#define CSL_HECC_CANGIF1_RMLIF1_SHIFT (0x0000000Bu)
#define CSL_HECC_CANGIF1_RMLIF1_RESETVAL (0x00000000u)
/*----RMLIF1 Tokens----*/
#define CSL_HECC_CANGIF1_RMLIF1_NOLOST (0x00000000u)
#define CSL_HECC_CANGIF1_RMLIF1_LOST (0x00000001u)

#define CSL_HECC_CANGIF1_BOIF1_MASK (0x00000400u)
#define CSL_HECC_CANGIF1_BOIF1_SHIFT (0x0000000Au)
#define CSL_HECC_CANGIF1_BOIF1_RESETVAL (0x00000000u)
/*----BOIF1 Tokens----*/
#define CSL_HECC_CANGIF1_BOIF1_BUSONMODE (0x00000000u)
#define CSL_HECC_CANGIF1_BOIF1_BUSOFFMODE (0x00000001u)

#define CSL_HECC_CANGIF1_EPIF1_MASK (0x00000200u)
#define CSL_HECC_CANGIF1_EPIF1_SHIFT (0x00000009u)
#define CSL_HECC_CANGIF1_EPIF1_RESETVAL (0x00000000u)
/*----EPIF1 Tokens----*/
#define CSL_HECC_CANGIF1_EPIF1_NOTERRPASSIVE (0x00000000u)
#define CSL_HECC_CANGIF1_EPIF1_ERRPASSIVE (0x00000001u)

#define CSL_HECC_CANGIF1_WLIF1_MASK (0x00000100u)
#define CSL_HECC_CANGIF1_WLIF1_SHIFT (0x00000008u)
#define CSL_HECC_CANGIF1_WLIF1_RESETVAL (0x00000000u)
/*----WLIF1 Tokens----*/
#define CSL_HECC_CANGIF1_WLIF1_NOTREACHED (0x00000000u)
#define CSL_HECC_CANGIF1_WLIF1_REACHED (0x00000001u)


#define CSL_HECC_CANGIF1_MIV1_MASK (0x0000001Fu)
#define CSL_HECC_CANGIF1_MIV1_SHIFT (0x00000000u)
#define CSL_HECC_CANGIF1_MIV1_RESETVAL (0x00000000u)

#define CSL_HECC_CANGIF1_RESETVAL (0x00000000u)

/* CANMIM */

#define CSL_HECC_CANMIM_MIM31_MASK (0x80000000u)
#define CSL_HECC_CANMIM_MIM31_SHIFT (0x0000001Fu)
#define CSL_HECC_CANMIM_MIM31_RESETVAL (0x00000000u)
/*----MIM31 Tokens----*/
#define CSL_HECC_CANMIM_MIM31_DISABLE (0x00000000u)
#define CSL_HECC_CANMIM_MIM31_ENABLE (0x00000001u)

#define CSL_HECC_CANMIM_MIM30_MASK (0x40000000u)
#define CSL_HECC_CANMIM_MIM30_SHIFT (0x0000001Eu)
#define CSL_HECC_CANMIM_MIM30_RESETVAL (0x00000000u)
/*----MIM30 Tokens----*/
#define CSL_HECC_CANMIM_MIM30_DISABLE (0x00000000u)
#define CSL_HECC_CANMIM_MIM30_ENABLE (0x00000001u)

#define CSL_HECC_CANMIM_MIM29_MASK (0x20000000u)
#define CSL_HECC_CANMIM_MIM29_SHIFT (0x0000001Du)
#define CSL_HECC_CANMIM_MIM29_RESETVAL (0x00000000u)
/*----MIM29 Tokens----*/
#define CSL_HECC_CANMIM_MIM29_DISABLE (0x00000000u)
#define CSL_HECC_CANMIM_MIM29_ENABLE (0x00000001u)

#define CSL_HECC_CANMIM_MIM28_MASK (0x10000000u)
#define CSL_HECC_CANMIM_MIM28_SHIFT (0x0000001Cu)
#define CSL_HECC_CANMIM_MIM28_RESETVAL (0x00000000u)
/*----MIM28 Tokens----*/
#define CSL_HECC_CANMIM_MIM28_DISABLE (0x00000000u)
#define CSL_HECC_CANMIM_MIM28_ENABLE (0x00000001u)

#define CSL_HECC_CANMIM_MIM27_MASK (0x08000000u)
#define CSL_HECC_CANMIM_MIM27_SHIFT (0x0000001Bu)
#define CSL_HECC_CANMIM_MIM27_RESETVAL (0x00000000u)
/*----MIM27 Tokens----*/
#define CSL_HECC_CANMIM_MIM27_DISABLE (0x00000000u)
#define CSL_HECC_CANMIM_MIM27_ENABLE (0x00000001u)

#define CSL_HECC_CANMIM_MIM26_MASK (0x04000000u)
#define CSL_HECC_CANMIM_MIM26_SHIFT (0x0000001Au)
#define CSL_HECC_CANMIM_MIM26_RESETVAL (0x00000000u)
/*----MIM26 Tokens----*/
#define CSL_HECC_CANMIM_MIM26_DISABLE (0x00000000u)
#define CSL_HECC_CANMIM_MIM26_ENABLE (0x00000001u)

#define CSL_HECC_CANMIM_MIM25_MASK (0x02000000u)
#define CSL_HECC_CANMIM_MIM25_SHIFT (0x00000019u)
#define CSL_HECC_CANMIM_MIM25_RESETVAL (0x00000000u)
/*----MIM25 Tokens----*/
#define CSL_HECC_CANMIM_MIM25_DISABLE (0x00000000u)
#define CSL_HECC_CANMIM_MIM25_ENABLE (0x00000001u)

#define CSL_HECC_CANMIM_MIM24_MASK (0x01000000u)
#define CSL_HECC_CANMIM_MIM24_SHIFT (0x00000018u)
#define CSL_HECC_CANMIM_MIM24_RESETVAL (0x00000000u)
/*----MIM24 Tokens----*/
#define CSL_HECC_CANMIM_MIM24_DISABLE (0x00000000u)
#define CSL_HECC_CANMIM_MIM24_ENABLE (0x00000001u)

#define CSL_HECC_CANMIM_MIM23_MASK (0x00800000u)
#define CSL_HECC_CANMIM_MIM23_SHIFT (0x00000017u)
#define CSL_HECC_CANMIM_MIM23_RESETVAL (0x00000000u)
/*----MIM23 Tokens----*/
#define CSL_HECC_CANMIM_MIM23_DISABLE (0x00000000u)
#define CSL_HECC_CANMIM_MIM23_ENABLE (0x00000001u)

#define CSL_HECC_CANMIM_MIM22_MASK (0x00400000u)
#define CSL_HECC_CANMIM_MIM22_SHIFT (0x00000016u)
#define CSL_HECC_CANMIM_MIM22_RESETVAL (0x00000000u)
/*----MIM22 Tokens----*/
#define CSL_HECC_CANMIM_MIM22_DISABLE (0x00000000u)
#define CSL_HECC_CANMIM_MIM22_ENABLE (0x00000001u)

#define CSL_HECC_CANMIM_MIM21_MASK (0x00200000u)
#define CSL_HECC_CANMIM_MIM21_SHIFT (0x00000015u)
#define CSL_HECC_CANMIM_MIM21_RESETVAL (0x00000000u)
/*----MIM21 Tokens----*/
#define CSL_HECC_CANMIM_MIM21_DISABLE (0x00000000u)
#define CSL_HECC_CANMIM_MIM21_ENABLE (0x00000001u)

#define CSL_HECC_CANMIM_MIM20_MASK (0x00100000u)
#define CSL_HECC_CANMIM_MIM20_SHIFT (0x00000014u)
#define CSL_HECC_CANMIM_MIM20_RESETVAL (0x00000000u)
/*----MIM20 Tokens----*/
#define CSL_HECC_CANMIM_MIM20_DISABLE (0x00000000u)
#define CSL_HECC_CANMIM_MIM20_ENABLE (0x00000001u)

#define CSL_HECC_CANMIM_MIM19_MASK (0x00080000u)
#define CSL_HECC_CANMIM_MIM19_SHIFT (0x00000013u)
#define CSL_HECC_CANMIM_MIM19_RESETVAL (0x00000000u)
/*----MIM19 Tokens----*/
#define CSL_HECC_CANMIM_MIM19_DISABLE (0x00000000u)
#define CSL_HECC_CANMIM_MIM19_ENABLE (0x00000001u)

#define CSL_HECC_CANMIM_MIM18_MASK (0x00040000u)
#define CSL_HECC_CANMIM_MIM18_SHIFT (0x00000012u)
#define CSL_HECC_CANMIM_MIM18_RESETVAL (0x00000000u)
/*----MIM18 Tokens----*/
#define CSL_HECC_CANMIM_MIM18_DISABLE (0x00000000u)
#define CSL_HECC_CANMIM_MIM18_ENABLE (0x00000001u)

#define CSL_HECC_CANMIM_MIM17_MASK (0x00020000u)
#define CSL_HECC_CANMIM_MIM17_SHIFT (0x00000011u)
#define CSL_HECC_CANMIM_MIM17_RESETVAL (0x00000000u)
/*----MIM17 Tokens----*/
#define CSL_HECC_CANMIM_MIM17_DISABLE (0x00000000u)
#define CSL_HECC_CANMIM_MIM17_ENABLE (0x00000001u)

#define CSL_HECC_CANMIM_MIM16_MASK (0x00010000u)
#define CSL_HECC_CANMIM_MIM16_SHIFT (0x00000010u)
#define CSL_HECC_CANMIM_MIM16_RESETVAL (0x00000000u)
/*----MIM16 Tokens----*/
#define CSL_HECC_CANMIM_MIM16_DISABLE (0x00000000u)
#define CSL_HECC_CANMIM_MIM16_ENABLE (0x00000001u)

#define CSL_HECC_CANMIM_MIM15_MASK (0x00008000u)
#define CSL_HECC_CANMIM_MIM15_SHIFT (0x0000000Fu)
#define CSL_HECC_CANMIM_MIM15_RESETVAL (0x00000000u)
/*----MIM15 Tokens----*/
#define CSL_HECC_CANMIM_MIM15_DISABLE (0x00000000u)
#define CSL_HECC_CANMIM_MIM15_ENABLE (0x00000001u)

#define CSL_HECC_CANMIM_MIM14_MASK (0x00004000u)
#define CSL_HECC_CANMIM_MIM14_SHIFT (0x0000000Eu)
#define CSL_HECC_CANMIM_MIM14_RESETVAL (0x00000000u)
/*----MIM14 Tokens----*/
#define CSL_HECC_CANMIM_MIM14_DISABLE (0x00000000u)
#define CSL_HECC_CANMIM_MIM14_ENABLE (0x00000001u)

#define CSL_HECC_CANMIM_MIM13_MASK (0x00002000u)
#define CSL_HECC_CANMIM_MIM13_SHIFT (0x0000000Du)
#define CSL_HECC_CANMIM_MIM13_RESETVAL (0x00000000u)
/*----MIM13 Tokens----*/
#define CSL_HECC_CANMIM_MIM13_DISABLE (0x00000000u)
#define CSL_HECC_CANMIM_MIM13_ENABLE (0x00000001u)

#define CSL_HECC_CANMIM_MIM12_MASK (0x00001000u)
#define CSL_HECC_CANMIM_MIM12_SHIFT (0x0000000Cu)
#define CSL_HECC_CANMIM_MIM12_RESETVAL (0x00000000u)
/*----MIM12 Tokens----*/
#define CSL_HECC_CANMIM_MIM12_DISABLE (0x00000000u)
#define CSL_HECC_CANMIM_MIM12_ENABLE (0x00000001u)

#define CSL_HECC_CANMIM_MIM11_MASK (0x00000800u)
#define CSL_HECC_CANMIM_MIM11_SHIFT (0x0000000Bu)
#define CSL_HECC_CANMIM_MIM11_RESETVAL (0x00000000u)
/*----MIM11 Tokens----*/
#define CSL_HECC_CANMIM_MIM11_DISABLE (0x00000000u)
#define CSL_HECC_CANMIM_MIM11_ENABLE (0x00000001u)

#define CSL_HECC_CANMIM_MIM10_MASK (0x00000400u)
#define CSL_HECC_CANMIM_MIM10_SHIFT (0x0000000Au)
#define CSL_HECC_CANMIM_MIM10_RESETVAL (0x00000000u)
/*----MIM10 Tokens----*/
#define CSL_HECC_CANMIM_MIM10_DISABLE (0x00000000u)
#define CSL_HECC_CANMIM_MIM10_ENABLE (0x00000001u)

#define CSL_HECC_CANMIM_MIM9_MASK (0x00000200u)
#define CSL_HECC_CANMIM_MIM9_SHIFT (0x00000009u)
#define CSL_HECC_CANMIM_MIM9_RESETVAL (0x00000000u)
/*----MIM9 Tokens----*/
#define CSL_HECC_CANMIM_MIM9_DISABLE (0x00000000u)
#define CSL_HECC_CANMIM_MIM9_ENABLE (0x00000001u)

#define CSL_HECC_CANMIM_MIM8_MASK (0x00000100u)
#define CSL_HECC_CANMIM_MIM8_SHIFT (0x00000008u)
#define CSL_HECC_CANMIM_MIM8_RESETVAL (0x00000000u)
/*----MIM8 Tokens----*/
#define CSL_HECC_CANMIM_MIM8_DISABLE (0x00000000u)
#define CSL_HECC_CANMIM_MIM8_ENABLE (0x00000001u)

#define CSL_HECC_CANMIM_MIM7_MASK (0x00000080u)
#define CSL_HECC_CANMIM_MIM7_SHIFT (0x00000007u)
#define CSL_HECC_CANMIM_MIM7_RESETVAL (0x00000000u)
/*----MIM7 Tokens----*/
#define CSL_HECC_CANMIM_MIM7_DISABLE (0x00000000u)
#define CSL_HECC_CANMIM_MIM7_ENABLE (0x00000001u)

#define CSL_HECC_CANMIM_MIM6_MASK (0x00000040u)
#define CSL_HECC_CANMIM_MIM6_SHIFT (0x00000006u)
#define CSL_HECC_CANMIM_MIM6_RESETVAL (0x00000000u)
/*----MIM6 Tokens----*/
#define CSL_HECC_CANMIM_MIM6_DISABLE (0x00000000u)
#define CSL_HECC_CANMIM_MIM6_ENABLE (0x00000001u)

#define CSL_HECC_CANMIM_MIM5_MASK (0x00000020u)
#define CSL_HECC_CANMIM_MIM5_SHIFT (0x00000005u)
#define CSL_HECC_CANMIM_MIM5_RESETVAL (0x00000000u)
/*----MIM5 Tokens----*/
#define CSL_HECC_CANMIM_MIM5_DISABLE (0x00000000u)
#define CSL_HECC_CANMIM_MIM5_ENABLE (0x00000001u)

#define CSL_HECC_CANMIM_MIM4_MASK (0x00000010u)
#define CSL_HECC_CANMIM_MIM4_SHIFT (0x00000004u)
#define CSL_HECC_CANMIM_MIM4_RESETVAL (0x00000000u)
/*----MIM4 Tokens----*/
#define CSL_HECC_CANMIM_MIM4_DISABLE (0x00000000u)
#define CSL_HECC_CANMIM_MIM4_ENABLE (0x00000001u)

#define CSL_HECC_CANMIM_MIM3_MASK (0x00000008u)
#define CSL_HECC_CANMIM_MIM3_SHIFT (0x00000003u)
#define CSL_HECC_CANMIM_MIM3_RESETVAL (0x00000000u)
/*----MIM3 Tokens----*/
#define CSL_HECC_CANMIM_MIM3_DISABLE (0x00000000u)
#define CSL_HECC_CANMIM_MIM3_ENABLE (0x00000001u)

#define CSL_HECC_CANMIM_MIM2_MASK (0x00000004u)
#define CSL_HECC_CANMIM_MIM2_SHIFT (0x00000002u)
#define CSL_HECC_CANMIM_MIM2_RESETVAL (0x00000000u)
/*----MIM2 Tokens----*/
#define CSL_HECC_CANMIM_MIM2_DISABLE (0x00000000u)
#define CSL_HECC_CANMIM_MIM2_ENABLE (0x00000001u)

#define CSL_HECC_CANMIM_MIM1_MASK (0x00000002u)
#define CSL_HECC_CANMIM_MIM1_SHIFT (0x00000001u)
#define CSL_HECC_CANMIM_MIM1_RESETVAL (0x00000000u)
/*----MIM1 Tokens----*/
#define CSL_HECC_CANMIM_MIM1_DISABLE (0x00000000u)
#define CSL_HECC_CANMIM_MIM1_ENABLE (0x00000001u)

#define CSL_HECC_CANMIM_MIM0_MASK (0x00000001u)
#define CSL_HECC_CANMIM_MIM0_SHIFT (0x00000000u)
#define CSL_HECC_CANMIM_MIM0_RESETVAL (0x00000000u)
/*----MIM0 Tokens----*/
#define CSL_HECC_CANMIM_MIM0_DISABLE (0x00000000u)
#define CSL_HECC_CANMIM_MIM0_ENABLE (0x00000001u)

#define CSL_HECC_CANMIM_RESETVAL (0x00000000u)

/* CANMIL */

#define CSL_HECC_CANMIL_MIL31_MASK (0x80000000u)
#define CSL_HECC_CANMIL_MIL31_SHIFT (0x0000001Fu)
#define CSL_HECC_CANMIL_MIL31_RESETVAL (0x00000000u)
/*----MIL31 Tokens----*/
#define CSL_HECC_CANMIL_MIL31_LINE0 (0x00000000u)
#define CSL_HECC_CANMIL_MIL31_LINE1 (0x00000001u)

#define CSL_HECC_CANMIL_MIL30_MASK (0x40000000u)
#define CSL_HECC_CANMIL_MIL30_SHIFT (0x0000001Eu)
#define CSL_HECC_CANMIL_MIL30_RESETVAL (0x00000000u)
/*----MIL30 Tokens----*/
#define CSL_HECC_CANMIL_MIL30_LINE0 (0x00000000u)
#define CSL_HECC_CANMIL_MIL30_LINE1 (0x00000001u)

#define CSL_HECC_CANMIL_MIL29_MASK (0x20000000u)
#define CSL_HECC_CANMIL_MIL29_SHIFT (0x0000001Du)
#define CSL_HECC_CANMIL_MIL29_RESETVAL (0x00000000u)
/*----MIL29 Tokens----*/
#define CSL_HECC_CANMIL_MIL29_LINE0 (0x00000000u)
#define CSL_HECC_CANMIL_MIL29_LINE1 (0x00000001u)

#define CSL_HECC_CANMIL_MIL28_MASK (0x10000000u)
#define CSL_HECC_CANMIL_MIL28_SHIFT (0x0000001Cu)
#define CSL_HECC_CANMIL_MIL28_RESETVAL (0x00000000u)
/*----MIL28 Tokens----*/
#define CSL_HECC_CANMIL_MIL28_LINE0 (0x00000000u)
#define CSL_HECC_CANMIL_MIL28_LINE1 (0x00000001u)

#define CSL_HECC_CANMIL_MIL27_MASK (0x08000000u)
#define CSL_HECC_CANMIL_MIL27_SHIFT (0x0000001Bu)
#define CSL_HECC_CANMIL_MIL27_RESETVAL (0x00000000u)
/*----MIL27 Tokens----*/
#define CSL_HECC_CANMIL_MIL27_LINE0 (0x00000000u)
#define CSL_HECC_CANMIL_MIL27_LINE1 (0x00000001u)

#define CSL_HECC_CANMIL_MIL26_MASK (0x04000000u)
#define CSL_HECC_CANMIL_MIL26_SHIFT (0x0000001Au)
#define CSL_HECC_CANMIL_MIL26_RESETVAL (0x00000000u)
/*----MIL26 Tokens----*/
#define CSL_HECC_CANMIL_MIL26_LINE0 (0x00000000u)
#define CSL_HECC_CANMIL_MIL26_LINE1 (0x00000001u)

#define CSL_HECC_CANMIL_MIL25_MASK (0x02000000u)
#define CSL_HECC_CANMIL_MIL25_SHIFT (0x00000019u)
#define CSL_HECC_CANMIL_MIL25_RESETVAL (0x00000000u)
/*----MIL25 Tokens----*/
#define CSL_HECC_CANMIL_MIL25_LINE0 (0x00000000u)
#define CSL_HECC_CANMIL_MIL25_LINE1 (0x00000001u)

#define CSL_HECC_CANMIL_MIL24_MASK (0x01000000u)
#define CSL_HECC_CANMIL_MIL24_SHIFT (0x00000018u)
#define CSL_HECC_CANMIL_MIL24_RESETVAL (0x00000000u)
/*----MIL24 Tokens----*/
#define CSL_HECC_CANMIL_MIL24_LINE0 (0x00000000u)
#define CSL_HECC_CANMIL_MIL24_LINE1 (0x00000001u)

#define CSL_HECC_CANMIL_MIL23_MASK (0x00800000u)
#define CSL_HECC_CANMIL_MIL23_SHIFT (0x00000017u)
#define CSL_HECC_CANMIL_MIL23_RESETVAL (0x00000000u)
/*----MIL23 Tokens----*/
#define CSL_HECC_CANMIL_MIL23_LINE0 (0x00000000u)
#define CSL_HECC_CANMIL_MIL23_LINE1 (0x00000001u)

#define CSL_HECC_CANMIL_MIL22_MASK (0x00400000u)
#define CSL_HECC_CANMIL_MIL22_SHIFT (0x00000016u)
#define CSL_HECC_CANMIL_MIL22_RESETVAL (0x00000000u)
/*----MIL22 Tokens----*/
#define CSL_HECC_CANMIL_MIL22_LINE0 (0x00000000u)
#define CSL_HECC_CANMIL_MIL22_LINE1 (0x00000001u)

#define CSL_HECC_CANMIL_MIL21_MASK (0x00200000u)
#define CSL_HECC_CANMIL_MIL21_SHIFT (0x00000015u)
#define CSL_HECC_CANMIL_MIL21_RESETVAL (0x00000000u)
/*----MIL21 Tokens----*/
#define CSL_HECC_CANMIL_MIL21_LINE0 (0x00000000u)
#define CSL_HECC_CANMIL_MIL21_LINE1 (0x00000001u)

#define CSL_HECC_CANMIL_MIL20_MASK (0x00100000u)
#define CSL_HECC_CANMIL_MIL20_SHIFT (0x00000014u)
#define CSL_HECC_CANMIL_MIL20_RESETVAL (0x00000000u)
/*----MIL20 Tokens----*/
#define CSL_HECC_CANMIL_MIL20_LINE0 (0x00000000u)
#define CSL_HECC_CANMIL_MIL20_LINE1 (0x00000001u)

#define CSL_HECC_CANMIL_MIL19_MASK (0x00080000u)
#define CSL_HECC_CANMIL_MIL19_SHIFT (0x00000013u)
#define CSL_HECC_CANMIL_MIL19_RESETVAL (0x00000000u)
/*----MIL19 Tokens----*/
#define CSL_HECC_CANMIL_MIL19_LINE0 (0x00000000u)
#define CSL_HECC_CANMIL_MIL19_LINE1 (0x00000001u)

#define CSL_HECC_CANMIL_MIL18_MASK (0x00040000u)
#define CSL_HECC_CANMIL_MIL18_SHIFT (0x00000012u)
#define CSL_HECC_CANMIL_MIL18_RESETVAL (0x00000000u)
/*----MIL18 Tokens----*/
#define CSL_HECC_CANMIL_MIL18_LINE0 (0x00000000u)
#define CSL_HECC_CANMIL_MIL18_LINE1 (0x00000001u)

#define CSL_HECC_CANMIL_MIL17_MASK (0x00020000u)
#define CSL_HECC_CANMIL_MIL17_SHIFT (0x00000011u)
#define CSL_HECC_CANMIL_MIL17_RESETVAL (0x00000000u)
/*----MIL17 Tokens----*/
#define CSL_HECC_CANMIL_MIL17_LINE0 (0x00000000u)
#define CSL_HECC_CANMIL_MIL17_LINE1 (0x00000001u)

#define CSL_HECC_CANMIL_MIL16_MASK (0x00010000u)
#define CSL_HECC_CANMIL_MIL16_SHIFT (0x00000010u)
#define CSL_HECC_CANMIL_MIL16_RESETVAL (0x00000000u)
/*----MIL16 Tokens----*/
#define CSL_HECC_CANMIL_MIL16_LINE0 (0x00000000u)
#define CSL_HECC_CANMIL_MIL16_LINE1 (0x00000001u)

#define CSL_HECC_CANMIL_MIL15_MASK (0x00008000u)
#define CSL_HECC_CANMIL_MIL15_SHIFT (0x0000000Fu)
#define CSL_HECC_CANMIL_MIL15_RESETVAL (0x00000000u)
/*----MIL15 Tokens----*/
#define CSL_HECC_CANMIL_MIL15_LINE0 (0x00000000u)
#define CSL_HECC_CANMIL_MIL15_LINE1 (0x00000001u)

#define CSL_HECC_CANMIL_MIL14_MASK (0x00004000u)
#define CSL_HECC_CANMIL_MIL14_SHIFT (0x0000000Eu)
#define CSL_HECC_CANMIL_MIL14_RESETVAL (0x00000000u)
/*----MIL14 Tokens----*/
#define CSL_HECC_CANMIL_MIL14_LINE0 (0x00000000u)
#define CSL_HECC_CANMIL_MIL14_LINE1 (0x00000001u)

#define CSL_HECC_CANMIL_MIL13_MASK (0x00002000u)
#define CSL_HECC_CANMIL_MIL13_SHIFT (0x0000000Du)
#define CSL_HECC_CANMIL_MIL13_RESETVAL (0x00000000u)
/*----MIL13 Tokens----*/
#define CSL_HECC_CANMIL_MIL13_LINE0 (0x00000000u)
#define CSL_HECC_CANMIL_MIL13_LINE1 (0x00000001u)

#define CSL_HECC_CANMIL_MIL12_MASK (0x00001000u)
#define CSL_HECC_CANMIL_MIL12_SHIFT (0x0000000Cu)
#define CSL_HECC_CANMIL_MIL12_RESETVAL (0x00000000u)
/*----MIL12 Tokens----*/
#define CSL_HECC_CANMIL_MIL12_LINE0 (0x00000000u)
#define CSL_HECC_CANMIL_MIL12_LINE1 (0x00000001u)

#define CSL_HECC_CANMIL_MIL11_MASK (0x00000800u)
#define CSL_HECC_CANMIL_MIL11_SHIFT (0x0000000Bu)
#define CSL_HECC_CANMIL_MIL11_RESETVAL (0x00000000u)
/*----MIL11 Tokens----*/
#define CSL_HECC_CANMIL_MIL11_LINE0 (0x00000000u)
#define CSL_HECC_CANMIL_MIL11_LINE1 (0x00000001u)

#define CSL_HECC_CANMIL_MIL10_MASK (0x00000400u)
#define CSL_HECC_CANMIL_MIL10_SHIFT (0x0000000Au)
#define CSL_HECC_CANMIL_MIL10_RESETVAL (0x00000000u)
/*----MIL10 Tokens----*/
#define CSL_HECC_CANMIL_MIL10_LINE0 (0x00000000u)
#define CSL_HECC_CANMIL_MIL10_LINE1 (0x00000001u)

#define CSL_HECC_CANMIL_MIL9_MASK (0x00000200u)
#define CSL_HECC_CANMIL_MIL9_SHIFT (0x00000009u)
#define CSL_HECC_CANMIL_MIL9_RESETVAL (0x00000000u)
/*----MIL9 Tokens----*/
#define CSL_HECC_CANMIL_MIL9_LINE0 (0x00000000u)
#define CSL_HECC_CANMIL_MIL9_LINE1 (0x00000001u)

#define CSL_HECC_CANMIL_MIL8_MASK (0x00000100u)
#define CSL_HECC_CANMIL_MIL8_SHIFT (0x00000008u)
#define CSL_HECC_CANMIL_MIL8_RESETVAL (0x00000000u)
/*----MIL8 Tokens----*/
#define CSL_HECC_CANMIL_MIL8_LINE0 (0x00000000u)
#define CSL_HECC_CANMIL_MIL8_LINE1 (0x00000001u)

#define CSL_HECC_CANMIL_MIL7_MASK (0x00000080u)
#define CSL_HECC_CANMIL_MIL7_SHIFT (0x00000007u)
#define CSL_HECC_CANMIL_MIL7_RESETVAL (0x00000000u)
/*----MIL7 Tokens----*/
#define CSL_HECC_CANMIL_MIL7_LINE0 (0x00000000u)
#define CSL_HECC_CANMIL_MIL7_LINE1 (0x00000001u)

#define CSL_HECC_CANMIL_MIL6_MASK (0x00000040u)
#define CSL_HECC_CANMIL_MIL6_SHIFT (0x00000006u)
#define CSL_HECC_CANMIL_MIL6_RESETVAL (0x00000000u)
/*----MIL6 Tokens----*/
#define CSL_HECC_CANMIL_MIL6_LINE0 (0x00000000u)
#define CSL_HECC_CANMIL_MIL6_LINE1 (0x00000001u)

#define CSL_HECC_CANMIL_MIL5_MASK (0x00000020u)
#define CSL_HECC_CANMIL_MIL5_SHIFT (0x00000005u)
#define CSL_HECC_CANMIL_MIL5_RESETVAL (0x00000000u)
/*----MIL5 Tokens----*/
#define CSL_HECC_CANMIL_MIL5_LINE0 (0x00000000u)
#define CSL_HECC_CANMIL_MIL5_LINE1 (0x00000001u)

#define CSL_HECC_CANMIL_MIL4_MASK (0x00000010u)
#define CSL_HECC_CANMIL_MIL4_SHIFT (0x00000004u)
#define CSL_HECC_CANMIL_MIL4_RESETVAL (0x00000000u)
/*----MIL4 Tokens----*/
#define CSL_HECC_CANMIL_MIL4_LINE0 (0x00000000u)
#define CSL_HECC_CANMIL_MIL4_LINE1 (0x00000001u)

#define CSL_HECC_CANMIL_MIL3_MASK (0x00000008u)
#define CSL_HECC_CANMIL_MIL3_SHIFT (0x00000003u)
#define CSL_HECC_CANMIL_MIL3_RESETVAL (0x00000000u)
/*----MIL3 Tokens----*/
#define CSL_HECC_CANMIL_MIL3_LINE0 (0x00000000u)
#define CSL_HECC_CANMIL_MIL3_LINE1 (0x00000001u)

#define CSL_HECC_CANMIL_MIL2_MASK (0x00000004u)
#define CSL_HECC_CANMIL_MIL2_SHIFT (0x00000002u)
#define CSL_HECC_CANMIL_MIL2_RESETVAL (0x00000000u)
/*----MIL2 Tokens----*/
#define CSL_HECC_CANMIL_MIL2_LINE0 (0x00000000u)
#define CSL_HECC_CANMIL_MIL2_LINE1 (0x00000001u)

#define CSL_HECC_CANMIL_MIL1_MASK (0x00000002u)
#define CSL_HECC_CANMIL_MIL1_SHIFT (0x00000001u)
#define CSL_HECC_CANMIL_MIL1_RESETVAL (0x00000000u)
/*----MIL1 Tokens----*/
#define CSL_HECC_CANMIL_MIL1_LINE0 (0x00000000u)
#define CSL_HECC_CANMIL_MIL1_LINE1 (0x00000001u)

#define CSL_HECC_CANMIL_MIL0_MASK (0x00000001u)
#define CSL_HECC_CANMIL_MIL0_SHIFT (0x00000000u)
#define CSL_HECC_CANMIL_MIL0_RESETVAL (0x00000000u)
/*----MIL0 Tokens----*/
#define CSL_HECC_CANMIL_MIL0_LINE0 (0x00000000u)
#define CSL_HECC_CANMIL_MIL0_LINE1 (0x00000001u)

#define CSL_HECC_CANMIL_RESETVAL (0x00000000u)

/* CANOPC */

#define CSL_HECC_CANOPC_OPC31_MASK (0x80000000u)
#define CSL_HECC_CANOPC_OPC31_SHIFT (0x0000001Fu)
#define CSL_HECC_CANOPC_OPC31_RESETVAL (0x00000000u)
/*----OPC31 Tokens----*/
#define CSL_HECC_CANOPC_OPC31_OVERWRITE (0x00000000u)
#define CSL_HECC_CANOPC_OPC31_NOOVERWRITE (0x00000001u)

#define CSL_HECC_CANOPC_OPC30_MASK (0x40000000u)
#define CSL_HECC_CANOPC_OPC30_SHIFT (0x0000001Eu)
#define CSL_HECC_CANOPC_OPC30_RESETVAL (0x00000000u)
/*----OPC30 Tokens----*/
#define CSL_HECC_CANOPC_OPC30_OVERWRITE (0x00000000u)
#define CSL_HECC_CANOPC_OPC30_NOOVERWRITE (0x00000001u)

#define CSL_HECC_CANOPC_OPC29_MASK (0x20000000u)
#define CSL_HECC_CANOPC_OPC29_SHIFT (0x0000001Du)
#define CSL_HECC_CANOPC_OPC29_RESETVAL (0x00000000u)
/*----OPC29 Tokens----*/
#define CSL_HECC_CANOPC_OPC29_OVERWRITE (0x00000000u)
#define CSL_HECC_CANOPC_OPC29_NOOVERWRITE (0x00000001u)

#define CSL_HECC_CANOPC_OPC28_MASK (0x10000000u)
#define CSL_HECC_CANOPC_OPC28_SHIFT (0x0000001Cu)
#define CSL_HECC_CANOPC_OPC28_RESETVAL (0x00000000u)
/*----OPC28 Tokens----*/
#define CSL_HECC_CANOPC_OPC28_OVERWRITE (0x00000000u)
#define CSL_HECC_CANOPC_OPC28_NOOVERWRITE (0x00000001u)

#define CSL_HECC_CANOPC_OPC27_MASK (0x08000000u)
#define CSL_HECC_CANOPC_OPC27_SHIFT (0x0000001Bu)
#define CSL_HECC_CANOPC_OPC27_RESETVAL (0x00000000u)
/*----OPC27 Tokens----*/
#define CSL_HECC_CANOPC_OPC27_OVERWRITE (0x00000000u)
#define CSL_HECC_CANOPC_OPC27_NOOVERWRITE (0x00000001u)

#define CSL_HECC_CANOPC_OPC26_MASK (0x04000000u)
#define CSL_HECC_CANOPC_OPC26_SHIFT (0x0000001Au)
#define CSL_HECC_CANOPC_OPC26_RESETVAL (0x00000000u)
/*----OPC26 Tokens----*/
#define CSL_HECC_CANOPC_OPC26_OVERWRITE (0x00000000u)
#define CSL_HECC_CANOPC_OPC26_NOOVERWRITE (0x00000001u)

#define CSL_HECC_CANOPC_OPC25_MASK (0x02000000u)
#define CSL_HECC_CANOPC_OPC25_SHIFT (0x00000019u)
#define CSL_HECC_CANOPC_OPC25_RESETVAL (0x00000000u)
/*----OPC25 Tokens----*/
#define CSL_HECC_CANOPC_OPC25_OVERWRITE (0x00000000u)
#define CSL_HECC_CANOPC_OPC25_NOOVERWRITE (0x00000001u)

#define CSL_HECC_CANOPC_OPC24_MASK (0x01000000u)
#define CSL_HECC_CANOPC_OPC24_SHIFT (0x00000018u)
#define CSL_HECC_CANOPC_OPC24_RESETVAL (0x00000000u)
/*----OPC24 Tokens----*/
#define CSL_HECC_CANOPC_OPC24_OVERWRITE (0x00000000u)
#define CSL_HECC_CANOPC_OPC24_NOOVERWRITE (0x00000001u)

#define CSL_HECC_CANOPC_OPC23_MASK (0x00800000u)
#define CSL_HECC_CANOPC_OPC23_SHIFT (0x00000017u)
#define CSL_HECC_CANOPC_OPC23_RESETVAL (0x00000000u)
/*----OPC23 Tokens----*/
#define CSL_HECC_CANOPC_OPC23_OVERWRITE (0x00000000u)
#define CSL_HECC_CANOPC_OPC23_NOOVERWRITE (0x00000001u)

#define CSL_HECC_CANOPC_OPC22_MASK (0x00400000u)
#define CSL_HECC_CANOPC_OPC22_SHIFT (0x00000016u)
#define CSL_HECC_CANOPC_OPC22_RESETVAL (0x00000000u)
/*----OPC22 Tokens----*/
#define CSL_HECC_CANOPC_OPC22_OVERWRITE (0x00000000u)
#define CSL_HECC_CANOPC_OPC22_NOOVERWRITE (0x00000001u)

#define CSL_HECC_CANOPC_OPC21_MASK (0x00200000u)
#define CSL_HECC_CANOPC_OPC21_SHIFT (0x00000015u)
#define CSL_HECC_CANOPC_OPC21_RESETVAL (0x00000000u)
/*----OPC21 Tokens----*/
#define CSL_HECC_CANOPC_OPC21_OVERWRITE (0x00000000u)
#define CSL_HECC_CANOPC_OPC21_NOOVERWRITE (0x00000001u)

#define CSL_HECC_CANOPC_OPC20_MASK (0x00100000u)
#define CSL_HECC_CANOPC_OPC20_SHIFT (0x00000014u)
#define CSL_HECC_CANOPC_OPC20_RESETVAL (0x00000000u)
/*----OPC20 Tokens----*/
#define CSL_HECC_CANOPC_OPC20_OVERWRITE (0x00000000u)
#define CSL_HECC_CANOPC_OPC20_NOOVERWRITE (0x00000001u)

#define CSL_HECC_CANOPC_OPC19_MASK (0x00080000u)
#define CSL_HECC_CANOPC_OPC19_SHIFT (0x00000013u)
#define CSL_HECC_CANOPC_OPC19_RESETVAL (0x00000000u)
/*----OPC19 Tokens----*/
#define CSL_HECC_CANOPC_OPC19_OVERWRITE (0x00000000u)
#define CSL_HECC_CANOPC_OPC19_NOOVERWRITE (0x00000001u)

#define CSL_HECC_CANOPC_OPC18_MASK (0x00040000u)
#define CSL_HECC_CANOPC_OPC18_SHIFT (0x00000012u)
#define CSL_HECC_CANOPC_OPC18_RESETVAL (0x00000000u)
/*----OPC18 Tokens----*/
#define CSL_HECC_CANOPC_OPC18_OVERWRITE (0x00000000u)
#define CSL_HECC_CANOPC_OPC18_NOOVERWRITE (0x00000001u)

#define CSL_HECC_CANOPC_OPC17_MASK (0x00020000u)
#define CSL_HECC_CANOPC_OPC17_SHIFT (0x00000011u)
#define CSL_HECC_CANOPC_OPC17_RESETVAL (0x00000000u)
/*----OPC17 Tokens----*/
#define CSL_HECC_CANOPC_OPC17_OVERWRITE (0x00000000u)
#define CSL_HECC_CANOPC_OPC17_NOOVERWRITE (0x00000001u)

#define CSL_HECC_CANOPC_OPC16_MASK (0x00010000u)
#define CSL_HECC_CANOPC_OPC16_SHIFT (0x00000010u)
#define CSL_HECC_CANOPC_OPC16_RESETVAL (0x00000000u)
/*----OPC16 Tokens----*/
#define CSL_HECC_CANOPC_OPC16_OVERWRITE (0x00000000u)
#define CSL_HECC_CANOPC_OPC16_NOOVERWRITE (0x00000001u)

#define CSL_HECC_CANOPC_OPC15_MASK (0x00008000u)
#define CSL_HECC_CANOPC_OPC15_SHIFT (0x0000000Fu)
#define CSL_HECC_CANOPC_OPC15_RESETVAL (0x00000000u)
/*----OPC15 Tokens----*/
#define CSL_HECC_CANOPC_OPC15_OVERWRITE (0x00000000u)
#define CSL_HECC_CANOPC_OPC15_NOOVERWRITE (0x00000001u)

#define CSL_HECC_CANOPC_OPC14_MASK (0x00004000u)
#define CSL_HECC_CANOPC_OPC14_SHIFT (0x0000000Eu)
#define CSL_HECC_CANOPC_OPC14_RESETVAL (0x00000000u)
/*----OPC14 Tokens----*/
#define CSL_HECC_CANOPC_OPC14_OVERWRITE (0x00000000u)
#define CSL_HECC_CANOPC_OPC14_NOOVERWRITE (0x00000001u)

#define CSL_HECC_CANOPC_OPC13_MASK (0x00002000u)
#define CSL_HECC_CANOPC_OPC13_SHIFT (0x0000000Du)
#define CSL_HECC_CANOPC_OPC13_RESETVAL (0x00000000u)
/*----OPC13 Tokens----*/
#define CSL_HECC_CANOPC_OPC13_OVERWRITE (0x00000000u)
#define CSL_HECC_CANOPC_OPC13_NOOVERWRITE (0x00000001u)

#define CSL_HECC_CANOPC_OPC12_MASK (0x00001000u)
#define CSL_HECC_CANOPC_OPC12_SHIFT (0x0000000Cu)
#define CSL_HECC_CANOPC_OPC12_RESETVAL (0x00000000u)
/*----OPC12 Tokens----*/
#define CSL_HECC_CANOPC_OPC12_OVERWRITE (0x00000000u)
#define CSL_HECC_CANOPC_OPC12_NOOVERWRITE (0x00000001u)

#define CSL_HECC_CANOPC_OPC11_MASK (0x00000800u)
#define CSL_HECC_CANOPC_OPC11_SHIFT (0x0000000Bu)
#define CSL_HECC_CANOPC_OPC11_RESETVAL (0x00000000u)
/*----OPC11 Tokens----*/
#define CSL_HECC_CANOPC_OPC11_OVERWRITE (0x00000000u)
#define CSL_HECC_CANOPC_OPC11_NOOVERWRITE (0x00000001u)

#define CSL_HECC_CANOPC_OPC10_MASK (0x00000400u)
#define CSL_HECC_CANOPC_OPC10_SHIFT (0x0000000Au)
#define CSL_HECC_CANOPC_OPC10_RESETVAL (0x00000000u)
/*----OPC10 Tokens----*/
#define CSL_HECC_CANOPC_OPC10_OVERWRITE (0x00000000u)
#define CSL_HECC_CANOPC_OPC10_NOOVERWRITE (0x00000001u)

#define CSL_HECC_CANOPC_OPC9_MASK (0x00000200u)
#define CSL_HECC_CANOPC_OPC9_SHIFT (0x00000009u)
#define CSL_HECC_CANOPC_OPC9_RESETVAL (0x00000000u)
/*----OPC9 Tokens----*/
#define CSL_HECC_CANOPC_OPC9_OVERWRITE (0x00000000u)
#define CSL_HECC_CANOPC_OPC9_NOOVERWRITE (0x00000001u)

#define CSL_HECC_CANOPC_OPC8_MASK (0x00000100u)
#define CSL_HECC_CANOPC_OPC8_SHIFT (0x00000008u)
#define CSL_HECC_CANOPC_OPC8_RESETVAL (0x00000000u)
/*----OPC8 Tokens----*/
#define CSL_HECC_CANOPC_OPC8_OVERWRITE (0x00000000u)
#define CSL_HECC_CANOPC_OPC8_NOOVERWRITE (0x00000001u)

#define CSL_HECC_CANOPC_OPC7_MASK (0x00000080u)
#define CSL_HECC_CANOPC_OPC7_SHIFT (0x00000007u)
#define CSL_HECC_CANOPC_OPC7_RESETVAL (0x00000000u)
/*----OPC7 Tokens----*/
#define CSL_HECC_CANOPC_OPC7_OVERWRITE (0x00000000u)
#define CSL_HECC_CANOPC_OPC7_NOOVERWRITE (0x00000001u)

#define CSL_HECC_CANOPC_OPC6_MASK (0x00000040u)
#define CSL_HECC_CANOPC_OPC6_SHIFT (0x00000006u)
#define CSL_HECC_CANOPC_OPC6_RESETVAL (0x00000000u)
/*----OPC6 Tokens----*/
#define CSL_HECC_CANOPC_OPC6_OVERWRITE (0x00000000u)
#define CSL_HECC_CANOPC_OPC6_NOOVERWRITE (0x00000001u)

#define CSL_HECC_CANOPC_OPC5_MASK (0x00000020u)
#define CSL_HECC_CANOPC_OPC5_SHIFT (0x00000005u)
#define CSL_HECC_CANOPC_OPC5_RESETVAL (0x00000000u)
/*----OPC5 Tokens----*/
#define CSL_HECC_CANOPC_OPC5_OVERWRITE (0x00000000u)
#define CSL_HECC_CANOPC_OPC5_NOOVERWRITE (0x00000001u)

#define CSL_HECC_CANOPC_OPC4_MASK (0x00000010u)
#define CSL_HECC_CANOPC_OPC4_SHIFT (0x00000004u)
#define CSL_HECC_CANOPC_OPC4_RESETVAL (0x00000000u)
/*----OPC4 Tokens----*/
#define CSL_HECC_CANOPC_OPC4_OVERWRITE (0x00000000u)
#define CSL_HECC_CANOPC_OPC4_NOOVERWRITE (0x00000001u)

#define CSL_HECC_CANOPC_OPC3_MASK (0x00000008u)
#define CSL_HECC_CANOPC_OPC3_SHIFT (0x00000003u)
#define CSL_HECC_CANOPC_OPC3_RESETVAL (0x00000000u)
/*----OPC3 Tokens----*/
#define CSL_HECC_CANOPC_OPC3_OVERWRITE (0x00000000u)
#define CSL_HECC_CANOPC_OPC3_NOOVERWRITE (0x00000001u)

#define CSL_HECC_CANOPC_OPC2_MASK (0x00000004u)
#define CSL_HECC_CANOPC_OPC2_SHIFT (0x00000002u)
#define CSL_HECC_CANOPC_OPC2_RESETVAL (0x00000000u)
/*----OPC2 Tokens----*/
#define CSL_HECC_CANOPC_OPC2_OVERWRITE (0x00000000u)
#define CSL_HECC_CANOPC_OPC2_NOOVERWRITE (0x00000001u)

#define CSL_HECC_CANOPC_OPC1_MASK (0x00000002u)
#define CSL_HECC_CANOPC_OPC1_SHIFT (0x00000001u)
#define CSL_HECC_CANOPC_OPC1_RESETVAL (0x00000000u)
/*----OPC1 Tokens----*/
#define CSL_HECC_CANOPC_OPC1_OVERWRITE (0x00000000u)
#define CSL_HECC_CANOPC_OPC1_NOOVERWRITE (0x00000001u)

#define CSL_HECC_CANOPC_OPC0_MASK (0x00000001u)
#define CSL_HECC_CANOPC_OPC0_SHIFT (0x00000000u)
#define CSL_HECC_CANOPC_OPC0_RESETVAL (0x00000000u)
/*----OPC0 Tokens----*/
#define CSL_HECC_CANOPC_OPC0_OVERWRITE (0x00000000u)
#define CSL_HECC_CANOPC_OPC0_NOOVERWRITE (0x00000001u)

#define CSL_HECC_CANOPC_RESETVAL (0x00000000u)

/* CANTIOC */


#define CSL_HECC_CANTIOC_TXFUNC_MASK (0x00000008u)
#define CSL_HECC_CANTIOC_TXFUNC_SHIFT (0x00000003u)
#define CSL_HECC_CANTIOC_TXFUNC_RESETVAL (0x00000000u)
/*----TXFUNC Tokens----*/
#define CSL_HECC_CANTIOC_TXFUNC_NORMAL (0x00000000u)
#define CSL_HECC_CANTIOC_TXFUNC_CANTX (0x00000001u)

#define CSL_HECC_CANTIOC_TXDIR_MASK (0x00000004u)
#define CSL_HECC_CANTIOC_TXDIR_SHIFT (0x00000002u)
#define CSL_HECC_CANTIOC_TXDIR_RESETVAL (0x00000000u)
/*----TXDIR Tokens----*/
#define CSL_HECC_CANTIOC_TXDIR_INPUT (0x00000000u)
#define CSL_HECC_CANTIOC_TXDIR_OUTPUT (0x00000001u)

#define CSL_HECC_CANTIOC_TXOUT_MASK (0x00000002u)
#define CSL_HECC_CANTIOC_TXOUT_SHIFT (0x00000001u)
#define CSL_HECC_CANTIOC_TXOUT_RESETVAL (0x00000000u)

#define CSL_HECC_CANTIOC_TXIN_MASK (0x00000001u)
#define CSL_HECC_CANTIOC_TXIN_SHIFT (0x00000000u)
#define CSL_HECC_CANTIOC_TXIN_RESETVAL (0x00000000u)
/*----TXIN Tokens----*/
#define CSL_HECC_CANTIOC_TXIN_LOW (0x00000000u)
#define CSL_HECC_CANTIOC_TXIN_HIGH (0x00000001u)

#define CSL_HECC_CANTIOC_RESETVAL (0x00000000u)

/* CANRIOC */


#define CSL_HECC_CANRIOC_RXFUNC_MASK (0x00000008u)
#define CSL_HECC_CANRIOC_RXFUNC_SHIFT (0x00000003u)
#define CSL_HECC_CANRIOC_RXFUNC_RESETVAL (0x00000000u)
/*----RXFUNC Tokens----*/
#define CSL_HECC_CANRIOC_RXFUNC_NORMAL (0x00000000u)
#define CSL_HECC_CANRIOC_RXFUNC_CANRX (0x00000001u)

#define CSL_HECC_CANRIOC_RXDIR_MASK (0x00000004u)
#define CSL_HECC_CANRIOC_RXDIR_SHIFT (0x00000002u)
#define CSL_HECC_CANRIOC_RXDIR_RESETVAL (0x00000000u)
/*----RXDIR Tokens----*/
#define CSL_HECC_CANRIOC_RXDIR_INPUT (0x00000000u)
#define CSL_HECC_CANRIOC_RXDIR_OUTPUT (0x00000001u)

#define CSL_HECC_CANRIOC_RXOUT_MASK (0x00000002u)
#define CSL_HECC_CANRIOC_RXOUT_SHIFT (0x00000001u)
#define CSL_HECC_CANRIOC_RXOUT_RESETVAL (0x00000000u)

#define CSL_HECC_CANRIOC_RXIN_MASK (0x00000001u)
#define CSL_HECC_CANRIOC_RXIN_SHIFT (0x00000000u)
#define CSL_HECC_CANRIOC_RXIN_RESETVAL (0x00000000u)
/*----RXIN Tokens----*/
#define CSL_HECC_CANRIOC_RXIN_LOW (0x00000000u)
#define CSL_HECC_CANRIOC_RXIN_HIGH (0x00000001u)

#define CSL_HECC_CANRIOC_RESETVAL (0x00000000u)

/* CANLNT */

#define CSL_HECC_CANLNT_LNT_MASK (0xFFFFFFFFu)
#define CSL_HECC_CANLNT_LNT_SHIFT (0x00000000u)
#define CSL_HECC_CANLNT_LNT_RESETVAL (0x00000000u)

#define CSL_HECC_CANLNT_RESETVAL (0x00000000u)

/* CANTOC */

#define CSL_HECC_CANTOC_TOC31_MASK (0x80000000u)
#define CSL_HECC_CANTOC_TOC31_SHIFT (0x0000001Fu)
#define CSL_HECC_CANTOC_TOC31_RESETVAL (0x00000000u)
/*----TOC31 Tokens----*/
#define CSL_HECC_CANTOC_TOC31_DISABLE (0x00000000u)
#define CSL_HECC_CANTOC_TOC31_ENABLE (0x00000001u)

#define CSL_HECC_CANTOC_TOC30_MASK (0x40000000u)
#define CSL_HECC_CANTOC_TOC30_SHIFT (0x0000001Eu)
#define CSL_HECC_CANTOC_TOC30_RESETVAL (0x00000000u)
/*----TOC30 Tokens----*/
#define CSL_HECC_CANTOC_TOC30_DISABLE (0x00000000u)
#define CSL_HECC_CANTOC_TOC30_ENABLE (0x00000001u)

#define CSL_HECC_CANTOC_TOC29_MASK (0x20000000u)
#define CSL_HECC_CANTOC_TOC29_SHIFT (0x0000001Du)
#define CSL_HECC_CANTOC_TOC29_RESETVAL (0x00000000u)
/*----TOC29 Tokens----*/
#define CSL_HECC_CANTOC_TOC29_DISABLE (0x00000000u)
#define CSL_HECC_CANTOC_TOC29_ENABLE (0x00000001u)

#define CSL_HECC_CANTOC_TOC28_MASK (0x10000000u)
#define CSL_HECC_CANTOC_TOC28_SHIFT (0x0000001Cu)
#define CSL_HECC_CANTOC_TOC28_RESETVAL (0x00000000u)
/*----TOC28 Tokens----*/
#define CSL_HECC_CANTOC_TOC28_DISABLE (0x00000000u)
#define CSL_HECC_CANTOC_TOC28_ENABLE (0x00000001u)

#define CSL_HECC_CANTOC_TOC27_MASK (0x08000000u)
#define CSL_HECC_CANTOC_TOC27_SHIFT (0x0000001Bu)
#define CSL_HECC_CANTOC_TOC27_RESETVAL (0x00000000u)
/*----TOC27 Tokens----*/
#define CSL_HECC_CANTOC_TOC27_DISABLE (0x00000000u)
#define CSL_HECC_CANTOC_TOC27_ENABLE (0x00000001u)

#define CSL_HECC_CANTOC_TOC26_MASK (0x04000000u)
#define CSL_HECC_CANTOC_TOC26_SHIFT (0x0000001Au)
#define CSL_HECC_CANTOC_TOC26_RESETVAL (0x00000000u)
/*----TOC26 Tokens----*/
#define CSL_HECC_CANTOC_TOC26_DISABLE (0x00000000u)
#define CSL_HECC_CANTOC_TOC26_ENABLE (0x00000001u)

#define CSL_HECC_CANTOC_TOC25_MASK (0x02000000u)
#define CSL_HECC_CANTOC_TOC25_SHIFT (0x00000019u)
#define CSL_HECC_CANTOC_TOC25_RESETVAL (0x00000000u)
/*----TOC25 Tokens----*/
#define CSL_HECC_CANTOC_TOC25_DISABLE (0x00000000u)
#define CSL_HECC_CANTOC_TOC25_ENABLE (0x00000001u)

#define CSL_HECC_CANTOC_TOC24_MASK (0x01000000u)
#define CSL_HECC_CANTOC_TOC24_SHIFT (0x00000018u)
#define CSL_HECC_CANTOC_TOC24_RESETVAL (0x00000000u)
/*----TOC24 Tokens----*/
#define CSL_HECC_CANTOC_TOC24_DISABLE (0x00000000u)
#define CSL_HECC_CANTOC_TOC24_ENABLE (0x00000001u)

#define CSL_HECC_CANTOC_TOC23_MASK (0x00800000u)
#define CSL_HECC_CANTOC_TOC23_SHIFT (0x00000017u)
#define CSL_HECC_CANTOC_TOC23_RESETVAL (0x00000000u)
/*----TOC23 Tokens----*/
#define CSL_HECC_CANTOC_TOC23_DISABLE (0x00000000u)
#define CSL_HECC_CANTOC_TOC23_ENABLE (0x00000001u)

#define CSL_HECC_CANTOC_TOC22_MASK (0x00400000u)
#define CSL_HECC_CANTOC_TOC22_SHIFT (0x00000016u)
#define CSL_HECC_CANTOC_TOC22_RESETVAL (0x00000000u)
/*----TOC22 Tokens----*/
#define CSL_HECC_CANTOC_TOC22_DISABLE (0x00000000u)
#define CSL_HECC_CANTOC_TOC22_ENABLE (0x00000001u)

#define CSL_HECC_CANTOC_TOC21_MASK (0x00200000u)
#define CSL_HECC_CANTOC_TOC21_SHIFT (0x00000015u)
#define CSL_HECC_CANTOC_TOC21_RESETVAL (0x00000000u)
/*----TOC21 Tokens----*/
#define CSL_HECC_CANTOC_TOC21_DISABLE (0x00000000u)
#define CSL_HECC_CANTOC_TOC21_ENABLE (0x00000001u)

#define CSL_HECC_CANTOC_TOC20_MASK (0x00100000u)
#define CSL_HECC_CANTOC_TOC20_SHIFT (0x00000014u)
#define CSL_HECC_CANTOC_TOC20_RESETVAL (0x00000000u)
/*----TOC20 Tokens----*/
#define CSL_HECC_CANTOC_TOC20_DISABLE (0x00000000u)
#define CSL_HECC_CANTOC_TOC20_ENABLE (0x00000001u)

#define CSL_HECC_CANTOC_TOC19_MASK (0x00080000u)
#define CSL_HECC_CANTOC_TOC19_SHIFT (0x00000013u)
#define CSL_HECC_CANTOC_TOC19_RESETVAL (0x00000000u)
/*----TOC19 Tokens----*/
#define CSL_HECC_CANTOC_TOC19_DISABLE (0x00000000u)
#define CSL_HECC_CANTOC_TOC19_ENABLE (0x00000001u)

#define CSL_HECC_CANTOC_TOC18_MASK (0x00040000u)
#define CSL_HECC_CANTOC_TOC18_SHIFT (0x00000012u)
#define CSL_HECC_CANTOC_TOC18_RESETVAL (0x00000000u)
/*----TOC18 Tokens----*/
#define CSL_HECC_CANTOC_TOC18_DISABLE (0x00000000u)
#define CSL_HECC_CANTOC_TOC18_ENABLE (0x00000001u)

#define CSL_HECC_CANTOC_TOC17_MASK (0x00020000u)
#define CSL_HECC_CANTOC_TOC17_SHIFT (0x00000011u)
#define CSL_HECC_CANTOC_TOC17_RESETVAL (0x00000000u)
/*----TOC17 Tokens----*/
#define CSL_HECC_CANTOC_TOC17_DISABLE (0x00000000u)
#define CSL_HECC_CANTOC_TOC17_ENABLE (0x00000001u)

#define CSL_HECC_CANTOC_TOC16_MASK (0x00010000u)
#define CSL_HECC_CANTOC_TOC16_SHIFT (0x00000010u)
#define CSL_HECC_CANTOC_TOC16_RESETVAL (0x00000000u)
/*----TOC16 Tokens----*/
#define CSL_HECC_CANTOC_TOC16_DISABLE (0x00000000u)
#define CSL_HECC_CANTOC_TOC16_ENABLE (0x00000001u)

#define CSL_HECC_CANTOC_TOC15_MASK (0x00008000u)
#define CSL_HECC_CANTOC_TOC15_SHIFT (0x0000000Fu)
#define CSL_HECC_CANTOC_TOC15_RESETVAL (0x00000000u)
/*----TOC15 Tokens----*/
#define CSL_HECC_CANTOC_TOC15_DISABLE (0x00000000u)
#define CSL_HECC_CANTOC_TOC15_ENABLE (0x00000001u)

#define CSL_HECC_CANTOC_TOC14_MASK (0x00004000u)
#define CSL_HECC_CANTOC_TOC14_SHIFT (0x0000000Eu)
#define CSL_HECC_CANTOC_TOC14_RESETVAL (0x00000000u)
/*----TOC14 Tokens----*/
#define CSL_HECC_CANTOC_TOC14_DISABLE (0x00000000u)
#define CSL_HECC_CANTOC_TOC14_ENABLE (0x00000001u)

#define CSL_HECC_CANTOC_TOC13_MASK (0x00002000u)
#define CSL_HECC_CANTOC_TOC13_SHIFT (0x0000000Du)
#define CSL_HECC_CANTOC_TOC13_RESETVAL (0x00000000u)
/*----TOC13 Tokens----*/
#define CSL_HECC_CANTOC_TOC13_DISABLE (0x00000000u)
#define CSL_HECC_CANTOC_TOC13_ENABLE (0x00000001u)

#define CSL_HECC_CANTOC_TOC12_MASK (0x00001000u)
#define CSL_HECC_CANTOC_TOC12_SHIFT (0x0000000Cu)
#define CSL_HECC_CANTOC_TOC12_RESETVAL (0x00000000u)
/*----TOC12 Tokens----*/
#define CSL_HECC_CANTOC_TOC12_DISABLE (0x00000000u)
#define CSL_HECC_CANTOC_TOC12_ENABLE (0x00000001u)

#define CSL_HECC_CANTOC_TOC11_MASK (0x00000800u)
#define CSL_HECC_CANTOC_TOC11_SHIFT (0x0000000Bu)
#define CSL_HECC_CANTOC_TOC11_RESETVAL (0x00000000u)
/*----TOC11 Tokens----*/
#define CSL_HECC_CANTOC_TOC11_DISABLE (0x00000000u)
#define CSL_HECC_CANTOC_TOC11_ENABLE (0x00000001u)

#define CSL_HECC_CANTOC_TOC10_MASK (0x00000400u)
#define CSL_HECC_CANTOC_TOC10_SHIFT (0x0000000Au)
#define CSL_HECC_CANTOC_TOC10_RESETVAL (0x00000000u)
/*----TOC10 Tokens----*/
#define CSL_HECC_CANTOC_TOC10_DISABLE (0x00000000u)
#define CSL_HECC_CANTOC_TOC10_ENABLE (0x00000001u)

#define CSL_HECC_CANTOC_TOC9_MASK (0x00000200u)
#define CSL_HECC_CANTOC_TOC9_SHIFT (0x00000009u)
#define CSL_HECC_CANTOC_TOC9_RESETVAL (0x00000000u)
/*----TOC9 Tokens----*/
#define CSL_HECC_CANTOC_TOC9_DISABLE (0x00000000u)
#define CSL_HECC_CANTOC_TOC9_ENABLE (0x00000001u)

#define CSL_HECC_CANTOC_TOC8_MASK (0x00000100u)
#define CSL_HECC_CANTOC_TOC8_SHIFT (0x00000008u)
#define CSL_HECC_CANTOC_TOC8_RESETVAL (0x00000000u)
/*----TOC8 Tokens----*/
#define CSL_HECC_CANTOC_TOC8_DISABLE (0x00000000u)
#define CSL_HECC_CANTOC_TOC8_ENABLE (0x00000001u)

#define CSL_HECC_CANTOC_TOC7_MASK (0x00000080u)
#define CSL_HECC_CANTOC_TOC7_SHIFT (0x00000007u)
#define CSL_HECC_CANTOC_TOC7_RESETVAL (0x00000000u)
/*----TOC7 Tokens----*/
#define CSL_HECC_CANTOC_TOC7_DISABLE (0x00000000u)
#define CSL_HECC_CANTOC_TOC7_ENABLE (0x00000001u)

#define CSL_HECC_CANTOC_TOC6_MASK (0x00000040u)
#define CSL_HECC_CANTOC_TOC6_SHIFT (0x00000006u)
#define CSL_HECC_CANTOC_TOC6_RESETVAL (0x00000000u)
/*----TOC6 Tokens----*/
#define CSL_HECC_CANTOC_TOC6_DISABLE (0x00000000u)
#define CSL_HECC_CANTOC_TOC6_ENABLE (0x00000001u)

#define CSL_HECC_CANTOC_TOC5_MASK (0x00000020u)
#define CSL_HECC_CANTOC_TOC5_SHIFT (0x00000005u)
#define CSL_HECC_CANTOC_TOC5_RESETVAL (0x00000000u)
/*----TOC5 Tokens----*/
#define CSL_HECC_CANTOC_TOC5_DISABLE (0x00000000u)
#define CSL_HECC_CANTOC_TOC5_ENABLE (0x00000001u)

#define CSL_HECC_CANTOC_TOC4_MASK (0x00000010u)
#define CSL_HECC_CANTOC_TOC4_SHIFT (0x00000004u)
#define CSL_HECC_CANTOC_TOC4_RESETVAL (0x00000000u)
/*----TOC4 Tokens----*/
#define CSL_HECC_CANTOC_TOC4_DISABLE (0x00000000u)
#define CSL_HECC_CANTOC_TOC4_ENABLE (0x00000001u)

#define CSL_HECC_CANTOC_TOC3_MASK (0x00000008u)
#define CSL_HECC_CANTOC_TOC3_SHIFT (0x00000003u)
#define CSL_HECC_CANTOC_TOC3_RESETVAL (0x00000000u)
/*----TOC3 Tokens----*/
#define CSL_HECC_CANTOC_TOC3_DISABLE (0x00000000u)
#define CSL_HECC_CANTOC_TOC3_ENABLE (0x00000001u)

#define CSL_HECC_CANTOC_TOC2_MASK (0x00000004u)
#define CSL_HECC_CANTOC_TOC2_SHIFT (0x00000002u)
#define CSL_HECC_CANTOC_TOC2_RESETVAL (0x00000000u)
/*----TOC2 Tokens----*/
#define CSL_HECC_CANTOC_TOC2_DISABLE (0x00000000u)
#define CSL_HECC_CANTOC_TOC2_ENABLE (0x00000001u)

#define CSL_HECC_CANTOC_TOC1_MASK (0x00000002u)
#define CSL_HECC_CANTOC_TOC1_SHIFT (0x00000001u)
#define CSL_HECC_CANTOC_TOC1_RESETVAL (0x00000000u)
/*----TOC1 Tokens----*/
#define CSL_HECC_CANTOC_TOC1_DISABLE (0x00000000u)
#define CSL_HECC_CANTOC_TOC1_ENABLE (0x00000001u)

#define CSL_HECC_CANTOC_TOC0_MASK (0x00000001u)
#define CSL_HECC_CANTOC_TOC0_SHIFT (0x00000000u)
#define CSL_HECC_CANTOC_TOC0_RESETVAL (0x00000000u)
/*----TOC0 Tokens----*/
#define CSL_HECC_CANTOC_TOC0_DISABLE (0x00000000u)
#define CSL_HECC_CANTOC_TOC0_ENABLE (0x00000001u)

#define CSL_HECC_CANTOC_RESETVAL (0x00000000u)

/* CANTOS */

#define CSL_HECC_CANTOS_TOS31_MASK (0x80000000u)
#define CSL_HECC_CANTOS_TOS31_SHIFT (0x0000001Fu)
#define CSL_HECC_CANTOS_TOS31_RESETVAL (0x00000000u)
/*----TOS31 Tokens----*/
#define CSL_HECC_CANTOS_TOS31_DISABLE (0x00000000u)
#define CSL_HECC_CANTOS_TOS31_ENABLE (0x00000001u)

#define CSL_HECC_CANTOS_TOS30_MASK (0x40000000u)
#define CSL_HECC_CANTOS_TOS30_SHIFT (0x0000001Eu)
#define CSL_HECC_CANTOS_TOS30_RESETVAL (0x00000000u)
/*----TOS30 Tokens----*/
#define CSL_HECC_CANTOS_TOS30_DISABLE (0x00000000u)
#define CSL_HECC_CANTOS_TOS30_ENABLE (0x00000001u)

#define CSL_HECC_CANTOS_TOS29_MASK (0x20000000u)
#define CSL_HECC_CANTOS_TOS29_SHIFT (0x0000001Du)
#define CSL_HECC_CANTOS_TOS29_RESETVAL (0x00000000u)
/*----TOS29 Tokens----*/
#define CSL_HECC_CANTOS_TOS29_DISABLE (0x00000000u)
#define CSL_HECC_CANTOS_TOS29_ENABLE (0x00000001u)

#define CSL_HECC_CANTOS_TOS28_MASK (0x10000000u)
#define CSL_HECC_CANTOS_TOS28_SHIFT (0x0000001Cu)
#define CSL_HECC_CANTOS_TOS28_RESETVAL (0x00000000u)
/*----TOS28 Tokens----*/
#define CSL_HECC_CANTOS_TOS28_DISABLE (0x00000000u)
#define CSL_HECC_CANTOS_TOS28_ENABLE (0x00000001u)

#define CSL_HECC_CANTOS_TOS27_MASK (0x08000000u)
#define CSL_HECC_CANTOS_TOS27_SHIFT (0x0000001Bu)
#define CSL_HECC_CANTOS_TOS27_RESETVAL (0x00000000u)
/*----TOS27 Tokens----*/
#define CSL_HECC_CANTOS_TOS27_DISABLE (0x00000000u)
#define CSL_HECC_CANTOS_TOS27_ENABLE (0x00000001u)

#define CSL_HECC_CANTOS_TOS26_MASK (0x04000000u)
#define CSL_HECC_CANTOS_TOS26_SHIFT (0x0000001Au)
#define CSL_HECC_CANTOS_TOS26_RESETVAL (0x00000000u)
/*----TOS26 Tokens----*/
#define CSL_HECC_CANTOS_TOS26_DISABLE (0x00000000u)
#define CSL_HECC_CANTOS_TOS26_ENABLE (0x00000001u)

#define CSL_HECC_CANTOS_TOS25_MASK (0x02000000u)
#define CSL_HECC_CANTOS_TOS25_SHIFT (0x00000019u)
#define CSL_HECC_CANTOS_TOS25_RESETVAL (0x00000000u)
/*----TOS25 Tokens----*/
#define CSL_HECC_CANTOS_TOS25_DISABLE (0x00000000u)
#define CSL_HECC_CANTOS_TOS25_ENABLE (0x00000001u)

#define CSL_HECC_CANTOS_TOS24_MASK (0x01000000u)
#define CSL_HECC_CANTOS_TOS24_SHIFT (0x00000018u)
#define CSL_HECC_CANTOS_TOS24_RESETVAL (0x00000000u)
/*----TOS24 Tokens----*/
#define CSL_HECC_CANTOS_TOS24_DISABLE (0x00000000u)
#define CSL_HECC_CANTOS_TOS24_ENABLE (0x00000001u)

#define CSL_HECC_CANTOS_TOS23_MASK (0x00800000u)
#define CSL_HECC_CANTOS_TOS23_SHIFT (0x00000017u)
#define CSL_HECC_CANTOS_TOS23_RESETVAL (0x00000000u)
/*----TOS23 Tokens----*/
#define CSL_HECC_CANTOS_TOS23_DISABLE (0x00000000u)
#define CSL_HECC_CANTOS_TOS23_ENABLE (0x00000001u)

#define CSL_HECC_CANTOS_TOS22_MASK (0x00400000u)
#define CSL_HECC_CANTOS_TOS22_SHIFT (0x00000016u)
#define CSL_HECC_CANTOS_TOS22_RESETVAL (0x00000000u)
/*----TOS22 Tokens----*/
#define CSL_HECC_CANTOS_TOS22_DISABLE (0x00000000u)
#define CSL_HECC_CANTOS_TOS22_ENABLE (0x00000001u)

#define CSL_HECC_CANTOS_TOS21_MASK (0x00200000u)
#define CSL_HECC_CANTOS_TOS21_SHIFT (0x00000015u)
#define CSL_HECC_CANTOS_TOS21_RESETVAL (0x00000000u)
/*----TOS21 Tokens----*/
#define CSL_HECC_CANTOS_TOS21_DISABLE (0x00000000u)
#define CSL_HECC_CANTOS_TOS21_ENABLE (0x00000001u)

#define CSL_HECC_CANTOS_TOS20_MASK (0x00100000u)
#define CSL_HECC_CANTOS_TOS20_SHIFT (0x00000014u)
#define CSL_HECC_CANTOS_TOS20_RESETVAL (0x00000000u)
/*----TOS20 Tokens----*/
#define CSL_HECC_CANTOS_TOS20_DISABLE (0x00000000u)
#define CSL_HECC_CANTOS_TOS20_ENABLE (0x00000001u)

#define CSL_HECC_CANTOS_TOS19_MASK (0x00080000u)
#define CSL_HECC_CANTOS_TOS19_SHIFT (0x00000013u)
#define CSL_HECC_CANTOS_TOS19_RESETVAL (0x00000000u)
/*----TOS19 Tokens----*/
#define CSL_HECC_CANTOS_TOS19_DISABLE (0x00000000u)
#define CSL_HECC_CANTOS_TOS19_ENABLE (0x00000001u)

#define CSL_HECC_CANTOS_TOS18_MASK (0x00040000u)
#define CSL_HECC_CANTOS_TOS18_SHIFT (0x00000012u)
#define CSL_HECC_CANTOS_TOS18_RESETVAL (0x00000000u)
/*----TOS18 Tokens----*/
#define CSL_HECC_CANTOS_TOS18_DISABLE (0x00000000u)
#define CSL_HECC_CANTOS_TOS18_ENABLE (0x00000001u)

#define CSL_HECC_CANTOS_TOS17_MASK (0x00020000u)
#define CSL_HECC_CANTOS_TOS17_SHIFT (0x00000011u)
#define CSL_HECC_CANTOS_TOS17_RESETVAL (0x00000000u)
/*----TOS17 Tokens----*/
#define CSL_HECC_CANTOS_TOS17_DISABLE (0x00000000u)
#define CSL_HECC_CANTOS_TOS17_ENABLE (0x00000001u)

#define CSL_HECC_CANTOS_TOS16_MASK (0x00010000u)
#define CSL_HECC_CANTOS_TOS16_SHIFT (0x00000010u)
#define CSL_HECC_CANTOS_TOS16_RESETVAL (0x00000000u)
/*----TOS16 Tokens----*/
#define CSL_HECC_CANTOS_TOS16_DISABLE (0x00000000u)
#define CSL_HECC_CANTOS_TOS16_ENABLE (0x00000001u)

#define CSL_HECC_CANTOS_TOS15_MASK (0x00008000u)
#define CSL_HECC_CANTOS_TOS15_SHIFT (0x0000000Fu)
#define CSL_HECC_CANTOS_TOS15_RESETVAL (0x00000000u)
/*----TOS15 Tokens----*/
#define CSL_HECC_CANTOS_TOS15_DISABLE (0x00000000u)
#define CSL_HECC_CANTOS_TOS15_ENABLE (0x00000001u)

#define CSL_HECC_CANTOS_TOS14_MASK (0x00004000u)
#define CSL_HECC_CANTOS_TOS14_SHIFT (0x0000000Eu)
#define CSL_HECC_CANTOS_TOS14_RESETVAL (0x00000000u)
/*----TOS14 Tokens----*/
#define CSL_HECC_CANTOS_TOS14_DISABLE (0x00000000u)
#define CSL_HECC_CANTOS_TOS14_ENABLE (0x00000001u)

#define CSL_HECC_CANTOS_TOS13_MASK (0x00002000u)
#define CSL_HECC_CANTOS_TOS13_SHIFT (0x0000000Du)
#define CSL_HECC_CANTOS_TOS13_RESETVAL (0x00000000u)
/*----TOS13 Tokens----*/
#define CSL_HECC_CANTOS_TOS13_DISABLE (0x00000000u)
#define CSL_HECC_CANTOS_TOS13_ENABLE (0x00000001u)

#define CSL_HECC_CANTOS_TOS12_MASK (0x00001000u)
#define CSL_HECC_CANTOS_TOS12_SHIFT (0x0000000Cu)
#define CSL_HECC_CANTOS_TOS12_RESETVAL (0x00000000u)
/*----TOS12 Tokens----*/
#define CSL_HECC_CANTOS_TOS12_DISABLE (0x00000000u)
#define CSL_HECC_CANTOS_TOS12_ENABLE (0x00000001u)

#define CSL_HECC_CANTOS_TOS11_MASK (0x00000800u)
#define CSL_HECC_CANTOS_TOS11_SHIFT (0x0000000Bu)
#define CSL_HECC_CANTOS_TOS11_RESETVAL (0x00000000u)
/*----TOS11 Tokens----*/
#define CSL_HECC_CANTOS_TOS11_DISABLE (0x00000000u)
#define CSL_HECC_CANTOS_TOS11_ENABLE (0x00000001u)

#define CSL_HECC_CANTOS_TOS10_MASK (0x00000400u)
#define CSL_HECC_CANTOS_TOS10_SHIFT (0x0000000Au)
#define CSL_HECC_CANTOS_TOS10_RESETVAL (0x00000000u)
/*----TOS10 Tokens----*/
#define CSL_HECC_CANTOS_TOS10_DISABLE (0x00000000u)
#define CSL_HECC_CANTOS_TOS10_ENABLE (0x00000001u)

#define CSL_HECC_CANTOS_TOS9_MASK (0x00000200u)
#define CSL_HECC_CANTOS_TOS9_SHIFT (0x00000009u)
#define CSL_HECC_CANTOS_TOS9_RESETVAL (0x00000000u)
/*----TOS9 Tokens----*/
#define CSL_HECC_CANTOS_TOS9_DISABLE (0x00000000u)
#define CSL_HECC_CANTOS_TOS9_ENABLE (0x00000001u)

#define CSL_HECC_CANTOS_TOS8_MASK (0x00000100u)
#define CSL_HECC_CANTOS_TOS8_SHIFT (0x00000008u)
#define CSL_HECC_CANTOS_TOS8_RESETVAL (0x00000000u)
/*----TOS8 Tokens----*/
#define CSL_HECC_CANTOS_TOS8_DISABLE (0x00000000u)
#define CSL_HECC_CANTOS_TOS8_ENABLE (0x00000001u)

#define CSL_HECC_CANTOS_TOS7_MASK (0x00000080u)
#define CSL_HECC_CANTOS_TOS7_SHIFT (0x00000007u)
#define CSL_HECC_CANTOS_TOS7_RESETVAL (0x00000000u)
/*----TOS7 Tokens----*/
#define CSL_HECC_CANTOS_TOS7_DISABLE (0x00000000u)
#define CSL_HECC_CANTOS_TOS7_ENABLE (0x00000001u)

#define CSL_HECC_CANTOS_TOS6_MASK (0x00000040u)
#define CSL_HECC_CANTOS_TOS6_SHIFT (0x00000006u)
#define CSL_HECC_CANTOS_TOS6_RESETVAL (0x00000000u)
/*----TOS6 Tokens----*/
#define CSL_HECC_CANTOS_TOS6_DISABLE (0x00000000u)
#define CSL_HECC_CANTOS_TOS6_ENABLE (0x00000001u)

#define CSL_HECC_CANTOS_TOS5_MASK (0x00000020u)
#define CSL_HECC_CANTOS_TOS5_SHIFT (0x00000005u)
#define CSL_HECC_CANTOS_TOS5_RESETVAL (0x00000000u)
/*----TOS5 Tokens----*/
#define CSL_HECC_CANTOS_TOS5_DISABLE (0x00000000u)
#define CSL_HECC_CANTOS_TOS5_ENABLE (0x00000001u)

#define CSL_HECC_CANTOS_TOS4_MASK (0x00000010u)
#define CSL_HECC_CANTOS_TOS4_SHIFT (0x00000004u)
#define CSL_HECC_CANTOS_TOS4_RESETVAL (0x00000000u)
/*----TOS4 Tokens----*/
#define CSL_HECC_CANTOS_TOS4_DISABLE (0x00000000u)
#define CSL_HECC_CANTOS_TOS4_ENABLE (0x00000001u)

#define CSL_HECC_CANTOS_TOS3_MASK (0x00000008u)
#define CSL_HECC_CANTOS_TOS3_SHIFT (0x00000003u)
#define CSL_HECC_CANTOS_TOS3_RESETVAL (0x00000000u)
/*----TOS3 Tokens----*/
#define CSL_HECC_CANTOS_TOS3_DISABLE (0x00000000u)
#define CSL_HECC_CANTOS_TOS3_ENABLE (0x00000001u)

#define CSL_HECC_CANTOS_TOS2_MASK (0x00000004u)
#define CSL_HECC_CANTOS_TOS2_SHIFT (0x00000002u)
#define CSL_HECC_CANTOS_TOS2_RESETVAL (0x00000000u)
/*----TOS2 Tokens----*/
#define CSL_HECC_CANTOS_TOS2_DISABLE (0x00000000u)
#define CSL_HECC_CANTOS_TOS2_ENABLE (0x00000001u)

#define CSL_HECC_CANTOS_TOS1_MASK (0x00000002u)
#define CSL_HECC_CANTOS_TOS1_SHIFT (0x00000001u)
#define CSL_HECC_CANTOS_TOS1_RESETVAL (0x00000000u)
/*----TOS1 Tokens----*/
#define CSL_HECC_CANTOS_TOS1_DISABLE (0x00000000u)
#define CSL_HECC_CANTOS_TOS1_ENABLE (0x00000001u)

#define CSL_HECC_CANTOS_TOS0_MASK (0x00000001u)
#define CSL_HECC_CANTOS_TOS0_SHIFT (0x00000000u)
#define CSL_HECC_CANTOS_TOS0_RESETVAL (0x00000000u)
/*----TOS0 Tokens----*/
#define CSL_HECC_CANTOS_TOS0_DISABLE (0x00000000u)
#define CSL_HECC_CANTOS_TOS0_ENABLE (0x00000001u)

#define CSL_HECC_CANTOS_RESETVAL (0x00000000u)

/* CANTIOCE */


#define CSL_HECC_CANTIOCE_TXSRS_MASK (0x00080000u)
#define CSL_HECC_CANTIOCE_TXSRS_SHIFT (0x00000013u)
#define CSL_HECC_CANTIOCE_TXSRS_RESETVAL (0x00000000u)
/*----TXSRS Tokens----*/
#define CSL_HECC_CANTIOCE_TXSRS_LOW (0x00000000u)
#define CSL_HECC_CANTIOCE_TXSRS_HIGH (0x00000001u)

#define CSL_HECC_CANTIOCE_TXPSL_MASK (0x00040000u)
#define CSL_HECC_CANTIOCE_TXPSL_SHIFT (0x00000012u)
#define CSL_HECC_CANTIOCE_TXPSL_RESETVAL (0x00000000u)
/*----TXPSL Tokens----*/
#define CSL_HECC_CANTIOCE_TXPSL_PULLDOWN (0x00000000u)
#define CSL_HECC_CANTIOCE_TXPSL_PULLUP (0x00000001u)

#define CSL_HECC_CANTIOCE_TXPULDIS_MASK (0x00020000u)
#define CSL_HECC_CANTIOCE_TXPULDIS_SHIFT (0x00000011u)
#define CSL_HECC_CANTIOCE_TXPULDIS_RESETVAL (0x00000000u)
/*----TXPULDIS Tokens----*/
#define CSL_HECC_CANTIOCE_TXPULDIS_ENABLE (0x00000000u)
#define CSL_HECC_CANTIOCE_TXPULDIS_DISABLE (0x00000001u)

#define CSL_HECC_CANTIOCE_TXOPDR_MASK (0x00010000u)
#define CSL_HECC_CANTIOCE_TXOPDR_SHIFT (0x00000010u)
#define CSL_HECC_CANTIOCE_TXOPDR_RESETVAL (0x00000000u)
/*----TXOPDR Tokens----*/
#define CSL_HECC_CANTIOCE_TXOPDR_DISABLE (0x00000000u)
#define CSL_HECC_CANTIOCE_TXOPDR_ENABLE (0x00000001u)


#define CSL_HECC_CANTIOCE_TXFUNC_MASK (0x00000008u)
#define CSL_HECC_CANTIOCE_TXFUNC_SHIFT (0x00000003u)
#define CSL_HECC_CANTIOCE_TXFUNC_RESETVAL (0x00000000u)
/*----TXFUNC Tokens----*/
#define CSL_HECC_CANTIOCE_TXFUNC_NORMAL (0x00000000u)
#define CSL_HECC_CANTIOCE_TXFUNC_CANTX (0x00000001u)

#define CSL_HECC_CANTIOCE_TXDIR_MASK (0x00000004u)
#define CSL_HECC_CANTIOCE_TXDIR_SHIFT (0x00000002u)
#define CSL_HECC_CANTIOCE_TXDIR_RESETVAL (0x00000000u)
/*----TXDIR Tokens----*/
#define CSL_HECC_CANTIOCE_TXDIR_INPUT (0x00000000u)
#define CSL_HECC_CANTIOCE_TXDIR_OUTPUT (0x00000001u)

#define CSL_HECC_CANTIOCE_TXOUT_MASK (0x00000002u)
#define CSL_HECC_CANTIOCE_TXOUT_SHIFT (0x00000001u)
#define CSL_HECC_CANTIOCE_TXOUT_RESETVAL (0x00000000u)

#define CSL_HECC_CANTIOCE_TXIN_MASK (0x00000001u)
#define CSL_HECC_CANTIOCE_TXIN_SHIFT (0x00000000u)
#define CSL_HECC_CANTIOCE_TXIN_RESETVAL (0x00000000u)
/*----TXIN Tokens----*/
#define CSL_HECC_CANTIOCE_TXIN_LOW (0x00000000u)
#define CSL_HECC_CANTIOCE_TXIN_HIGH (0x00000001u)

#define CSL_HECC_CANTIOCE_RESETVAL (0x00000000u)

/* CANRIOCE */


#define CSL_HECC_CANRIOCE_RXSRS_MASK (0x00080000u)
#define CSL_HECC_CANRIOCE_RXSRS_SHIFT (0x00000013u)
#define CSL_HECC_CANRIOCE_RXSRS_RESETVAL (0x00000000u)
/*----RXSRS Tokens----*/
#define CSL_HECC_CANRIOCE_RXSRS_LOW (0x00000000u)
#define CSL_HECC_CANRIOCE_RXSRS_HIGH (0x00000001u)

#define CSL_HECC_CANRIOCE_RXPSL_MASK (0x00040000u)
#define CSL_HECC_CANRIOCE_RXPSL_SHIFT (0x00000012u)
#define CSL_HECC_CANRIOCE_RXPSL_RESETVAL (0x00000000u)
/*----RXPSL Tokens----*/
#define CSL_HECC_CANRIOCE_RXPSL_PULLDOWN (0x00000000u)
#define CSL_HECC_CANRIOCE_RXPSL_PULLUP (0x00000001u)

#define CSL_HECC_CANRIOCE_RXPULDIS_MASK (0x00020000u)
#define CSL_HECC_CANRIOCE_RXPULDIS_SHIFT (0x00000011u)
#define CSL_HECC_CANRIOCE_RXPULDIS_RESETVAL (0x00000000u)
/*----RXPULDIS Tokens----*/
#define CSL_HECC_CANRIOCE_RXPULDIS_ENABLE (0x00000000u)
#define CSL_HECC_CANRIOCE_RXPULDIS_DISABLE (0x00000001u)

#define CSL_HECC_CANRIOCE_RXOPDR_MASK (0x00010000u)
#define CSL_HECC_CANRIOCE_RXOPDR_SHIFT (0x00000010u)
#define CSL_HECC_CANRIOCE_RXOPDR_RESETVAL (0x00000000u)
/*----RXOPDR Tokens----*/
#define CSL_HECC_CANRIOCE_RXOPDR_DISABLE (0x00000000u)
#define CSL_HECC_CANRIOCE_RXOPDR_ENABLE (0x00000001u)


#define CSL_HECC_CANRIOCE_RXFUNC_MASK (0x00000008u)
#define CSL_HECC_CANRIOCE_RXFUNC_SHIFT (0x00000003u)
#define CSL_HECC_CANRIOCE_RXFUNC_RESETVAL (0x00000000u)
/*----RXFUNC Tokens----*/
#define CSL_HECC_CANRIOCE_RXFUNC_NORMAL (0x00000000u)
#define CSL_HECC_CANRIOCE_RXFUNC_CANTX (0x00000001u)

#define CSL_HECC_CANRIOCE_RXDIR_MASK (0x00000004u)
#define CSL_HECC_CANRIOCE_RXDIR_SHIFT (0x00000002u)
#define CSL_HECC_CANRIOCE_RXDIR_RESETVAL (0x00000000u)
/*----RXDIR Tokens----*/
#define CSL_HECC_CANRIOCE_RXDIR_INPUT (0x00000000u)
#define CSL_HECC_CANRIOCE_RXDIR_OUTPUT (0x00000001u)

#define CSL_HECC_CANRIOCE_RXOUT_MASK (0x00000002u)
#define CSL_HECC_CANRIOCE_RXOUT_SHIFT (0x00000001u)
#define CSL_HECC_CANRIOCE_RXOUT_RESETVAL (0x00000000u)

#define CSL_HECC_CANRIOCE_RXIN_MASK (0x00000001u)
#define CSL_HECC_CANRIOCE_RXIN_SHIFT (0x00000000u)
#define CSL_HECC_CANRIOCE_RXIN_RESETVAL (0x00000000u)
/*----RXIN Tokens----*/
#define CSL_HECC_CANRIOCE_RXIN_LOW (0x00000000u)
#define CSL_HECC_CANRIOCE_RXIN_HIGH (0x00000001u)

#define CSL_HECC_CANRIOCE_RESETVAL (0x00000000u)

/* CANETC */


#define CSL_HECC_CANETC_FEN_MASK (0x01000000u)
#define CSL_HECC_CANETC_FEN_SHIFT (0x00000018u)
#define CSL_HECC_CANETC_FEN_RESETVAL (0x00000000u)
/*----FEN Tokens----*/
#define CSL_HECC_CANETC_FEN_NOERRORGEN (0x00000000u)
#define CSL_HECC_CANETC_FEN_ERRORGEN (0x00000001u)

#define CSL_HECC_CANETC_BEN_MASK (0x00800000u)
#define CSL_HECC_CANETC_BEN_SHIFT (0x00000017u)
#define CSL_HECC_CANETC_BEN_RESETVAL (0x00000000u)
/*----BEN Tokens----*/
#define CSL_HECC_CANETC_BEN_NOERRORGEN (0x00000000u)
#define CSL_HECC_CANETC_BEN_ERRORGEN (0x00000001u)

#define CSL_HECC_CANETC_SA1E_MASK (0x00400000u)
#define CSL_HECC_CANETC_SA1E_SHIFT (0x00000016u)
#define CSL_HECC_CANETC_SA1E_RESETVAL (0x00000000u)
/*----SA1E Tokens----*/
#define CSL_HECC_CANETC_SA1E_NOERRORGEN (0x00000000u)
#define CSL_HECC_CANETC_SA1E_ERRORGEN (0x00000001u)

#define CSL_HECC_CANETC_CRCEN_MASK (0x00200000u)
#define CSL_HECC_CANETC_CRCEN_SHIFT (0x00000015u)
#define CSL_HECC_CANETC_CRCEN_RESETVAL (0x00000000u)
/*----CRCEN Tokens----*/
#define CSL_HECC_CANETC_CRCEN_NOERRORGEN (0x00000000u)
#define CSL_HECC_CANETC_CRCEN_ERRORGEN (0x00000001u)

#define CSL_HECC_CANETC_SEN_MASK (0x00100000u)
#define CSL_HECC_CANETC_SEN_SHIFT (0x00000014u)
#define CSL_HECC_CANETC_SEN_RESETVAL (0x00000000u)
/*----SEN Tokens----*/
#define CSL_HECC_CANETC_SEN_NOERRORGEN (0x00000000u)
#define CSL_HECC_CANETC_SEN_ERRORGEN (0x00000001u)


#define CSL_HECC_CANETC_CANETCEN_MASK (0x00000F00u)
#define CSL_HECC_CANETC_CANETCEN_SHIFT (0x00000008u)
#define CSL_HECC_CANETC_CANETCEN_RESETVAL (0x00000005u)
#define CSL_HECC_CANETC_CANETCEN_ENABLE (0x0000000Cu)

#define CSL_HECC_CANETC_FIELD_SEL_MASK (0x000000F0u)
#define CSL_HECC_CANETC_FIELD_SEL_SHIFT (0x00000004u)
#define CSL_HECC_CANETC_FIELD_SEL_RESETVAL (0x00000000u)
#define CSL_HECC_CANETC_FIELD_SEL_NOFIELD (0x00000000u)
#define CSL_HECC_CANETC_FIELD_SEL_STDID (0x00000001u)
#define CSL_HECC_CANETC_FIELD_SEL_DLENCODE (0x00000002u)
#define CSL_HECC_CANETC_FIELD_SEL_DATA (0x00000003u)
#define CSL_HECC_CANETC_FIELD_SEL_CRC (0x00000004u)
#define CSL_HECC_CANETC_FIELD_SEL_CRCD (0x00000005u)
#define CSL_HECC_CANETC_FIELD_SEL_ACKSLOT (0x00000006u)
#define CSL_HECC_CANETC_FIELD_SEL_ACKDEL (0x00000007u)
#define CSL_HECC_CANETC_FIELD_SEL_ENDOFFRAME (0x00000008u)
#define CSL_HECC_CANETC_FIELD_SEL_EXTID (0x00000009u)

#define CSL_HECC_CANETC_RESETVAL (0x00000500u)

/* LAM */

#define CSL_HECC_LAM_LAMI_MASK (0x80000000u)
#define CSL_HECC_LAM_LAMI_SHIFT (0x0000001Fu)
#define CSL_HECC_LAM_LAMI_RESETVAL (0x00000000u)
/*----LAMI Tokens----*/
#define CSL_HECC_LAM_LAMI_DISABLE (0x00000000u)
#define CSL_HECC_LAM_LAMI_ENABLE (0x00000001u)


#define CSL_HECC_LAM_LAM28_MASK (0x10000000u)
#define CSL_HECC_LAM_LAM28_SHIFT (0x0000001Cu)
#define CSL_HECC_LAM_LAM28_RESETVAL (0x00000000u)

#define CSL_HECC_LAM_LAM27_MASK (0x08000000u)
#define CSL_HECC_LAM_LAM27_SHIFT (0x0000001Bu)
#define CSL_HECC_LAM_LAM27_RESETVAL (0x00000000u)

#define CSL_HECC_LAM_LAM26_MASK (0x04000000u)
#define CSL_HECC_LAM_LAM26_SHIFT (0x0000001Au)
#define CSL_HECC_LAM_LAM26_RESETVAL (0x00000000u)

#define CSL_HECC_LAM_LAM25_MASK (0x02000000u)
#define CSL_HECC_LAM_LAM25_SHIFT (0x00000019u)
#define CSL_HECC_LAM_LAM25_RESETVAL (0x00000000u)

#define CSL_HECC_LAM_LAM24_MASK (0x01000000u)
#define CSL_HECC_LAM_LAM24_SHIFT (0x00000018u)
#define CSL_HECC_LAM_LAM24_RESETVAL (0x00000000u)

#define CSL_HECC_LAM_LAM23_MASK (0x00800000u)
#define CSL_HECC_LAM_LAM23_SHIFT (0x00000017u)
#define CSL_HECC_LAM_LAM23_RESETVAL (0x00000000u)

#define CSL_HECC_LAM_LAM22_MASK (0x00400000u)
#define CSL_HECC_LAM_LAM22_SHIFT (0x00000016u)
#define CSL_HECC_LAM_LAM22_RESETVAL (0x00000000u)

#define CSL_HECC_LAM_LAM21_MASK (0x00200000u)
#define CSL_HECC_LAM_LAM21_SHIFT (0x00000015u)
#define CSL_HECC_LAM_LAM21_RESETVAL (0x00000000u)

#define CSL_HECC_LAM_LAM20_MASK (0x00100000u)
#define CSL_HECC_LAM_LAM20_SHIFT (0x00000014u)
#define CSL_HECC_LAM_LAM20_RESETVAL (0x00000000u)

#define CSL_HECC_LAM_LAM19_MASK (0x00080000u)
#define CSL_HECC_LAM_LAM19_SHIFT (0x00000013u)
#define CSL_HECC_LAM_LAM19_RESETVAL (0x00000000u)

#define CSL_HECC_LAM_LAM18_MASK (0x00040000u)
#define CSL_HECC_LAM_LAM18_SHIFT (0x00000012u)
#define CSL_HECC_LAM_LAM18_RESETVAL (0x00000000u)

#define CSL_HECC_LAM_LAM17_MASK (0x00020000u)
#define CSL_HECC_LAM_LAM17_SHIFT (0x00000011u)
#define CSL_HECC_LAM_LAM17_RESETVAL (0x00000000u)

#define CSL_HECC_LAM_LAM16_MASK (0x00010000u)
#define CSL_HECC_LAM_LAM16_SHIFT (0x00000010u)
#define CSL_HECC_LAM_LAM16_RESETVAL (0x00000000u)

#define CSL_HECC_LAM_LAM15_MASK (0x00008000u)
#define CSL_HECC_LAM_LAM15_SHIFT (0x0000000Fu)
#define CSL_HECC_LAM_LAM15_RESETVAL (0x00000000u)

#define CSL_HECC_LAM_LAM14_MASK (0x00004000u)
#define CSL_HECC_LAM_LAM14_SHIFT (0x0000000Eu)
#define CSL_HECC_LAM_LAM14_RESETVAL (0x00000000u)

#define CSL_HECC_LAM_LAM13_MASK (0x00002000u)
#define CSL_HECC_LAM_LAM13_SHIFT (0x0000000Du)
#define CSL_HECC_LAM_LAM13_RESETVAL (0x00000000u)

#define CSL_HECC_LAM_LAM12_MASK (0x00001000u)
#define CSL_HECC_LAM_LAM12_SHIFT (0x0000000Cu)
#define CSL_HECC_LAM_LAM12_RESETVAL (0x00000000u)

#define CSL_HECC_LAM_LAM11_MASK (0x00000800u)
#define CSL_HECC_LAM_LAM11_SHIFT (0x0000000Bu)
#define CSL_HECC_LAM_LAM11_RESETVAL (0x00000000u)

#define CSL_HECC_LAM_LAM10_MASK (0x00000400u)
#define CSL_HECC_LAM_LAM10_SHIFT (0x0000000Au)
#define CSL_HECC_LAM_LAM10_RESETVAL (0x00000000u)

#define CSL_HECC_LAM_LAM9_MASK (0x00000200u)
#define CSL_HECC_LAM_LAM9_SHIFT (0x00000009u)
#define CSL_HECC_LAM_LAM9_RESETVAL (0x00000000u)

#define CSL_HECC_LAM_LAM8_MASK (0x00000100u)
#define CSL_HECC_LAM_LAM8_SHIFT (0x00000008u)
#define CSL_HECC_LAM_LAM8_RESETVAL (0x00000000u)

#define CSL_HECC_LAM_LAM7_MASK (0x00000080u)
#define CSL_HECC_LAM_LAM7_SHIFT (0x00000007u)
#define CSL_HECC_LAM_LAM7_RESETVAL (0x00000000u)

#define CSL_HECC_LAM_LAM6_MASK (0x00000040u)
#define CSL_HECC_LAM_LAM6_SHIFT (0x00000006u)
#define CSL_HECC_LAM_LAM6_RESETVAL (0x00000000u)

#define CSL_HECC_LAM_LAM5_MASK (0x00000020u)
#define CSL_HECC_LAM_LAM5_SHIFT (0x00000005u)
#define CSL_HECC_LAM_LAM5_RESETVAL (0x00000000u)

#define CSL_HECC_LAM_LAM4_MASK (0x00000010u)
#define CSL_HECC_LAM_LAM4_SHIFT (0x00000004u)
#define CSL_HECC_LAM_LAM4_RESETVAL (0x00000000u)

#define CSL_HECC_LAM_LAM3_MASK (0x00000008u)
#define CSL_HECC_LAM_LAM3_SHIFT (0x00000003u)
#define CSL_HECC_LAM_LAM3_RESETVAL (0x00000000u)

#define CSL_HECC_LAM_LAM2_MASK (0x00000004u)
#define CSL_HECC_LAM_LAM2_SHIFT (0x00000002u)
#define CSL_HECC_LAM_LAM2_RESETVAL (0x00000000u)

#define CSL_HECC_LAM_LAM1_MASK (0x00000002u)
#define CSL_HECC_LAM_LAM1_SHIFT (0x00000001u)
#define CSL_HECC_LAM_LAM1_RESETVAL (0x00000000u)

#define CSL_HECC_LAM_LAM0_MASK (0x00000001u)
#define CSL_HECC_LAM_LAM0_SHIFT (0x00000000u)
#define CSL_HECC_LAM_LAM0_RESETVAL (0x00000000u)

/*----LAM Tokens----*/
#define CSL_HECC_LAM_LAM_RESET (0x00000000u)
#define CSL_HECC_LAM_LAM_SET (0x00000001u)

#define CSL_HECC_LAM_RESETVAL (0x00000000u)

/* MOTS */

#define CSL_HECC_MOTS_MOTS_MASK (0xFFFFFFFFu)
#define CSL_HECC_MOTS_MOTS_SHIFT (0x00000000u)
#define CSL_HECC_MOTS_MOTS_RESETVAL (0x00000000u)

#define CSL_HECC_MOTS_RESETVAL (0x00000000u)

/* MOTO */

#define CSL_HECC_MOTO_MOTO_MASK (0xFFFFFFFFu)
#define CSL_HECC_MOTO_MOTO_SHIFT (0x00000000u)
#define CSL_HECC_MOTO_MOTO_RESETVAL (0x00000000u)

#define CSL_HECC_MOTO_RESETVAL (0x00000000u)

#ifdef __cplusplus
}
#endif

#endif

