/*******************************************************************************
**+--------------------------------------------------------------------------+**
**|                            ****                                          |**
**|                            ****                                          |**
**|                            ******o***                                    |**
**|                      ********_///_****                                   |**
**|                      ***** /_//_/ ****                                   |**
**|                       ** ** (__/ ****                                    |**
**|                           *********                                      |**
**|                            ****                                          |**
**|                            ***                                           |**
**|                                                                          |**
**|         Copyright (c) 2006-2010 Texas Instruments Incorporated           |**
**|                        ALL RIGHTS RESERVED                               |**
**|                                                                          |**
**| Permission is hereby granted to licensees of Texas Instruments           |**
**| Incorporated (TI) products to use this computer program for the sole     |**
**| purpose of implementing a licensee product based on TI products.         |**
**| No other rights to reproduce, use, or disseminate this computer          |**
**| program, whether in part or in whole, are granted.                       |**
**|                                                                          |**
**| TI makes no representation or warranties with respect to the             |**
**| performance of this computer program, and specifically disclaims         |**
**| any responsibility for any damages, special or consequential,            |**
**| connected with the use of this program.                                  |**
**|                                                                          |**
**+--------------------------------------------------------------------------+**
*******************************************************************************/
/**
 *  \file  psp_bios_previewer_st_basic_input.c
 *
 *  \brief Input of Basic Previewer Application
 *
 *  (C) Copyright 2010, Texas Instruments, Inc
 *
 *
 *  \author     PSP Team
 *
 *  \version    1.0     Created
 */
/******************************************************************************
  Header File Inclusion
 ******************************************************************************/

#include<ti/sdo/pspdrivers/soc/dm6437/dsp/tistdtypes.h>
/******************************************************************************
  Macros
 ******************************************************************************/
/* height and width of input image */
#define PREV_IMAGE_HEIGHT 480u
#define PREV_IMAGE_WIDTH 640u
/******************************************************************************
  Data-Structures
 ******************************************************************************/

#pragma DATA_ALIGN (prevInImage,32);

Uint8 prevInImage[PREV_IMAGE_HEIGHT][PREV_IMAGE_WIDTH] =
{
    {
        0x4B, 0x1B, 0x4B, 0x1A, 0x4C, 0x1B, 0x4C, 0x1B, 0x4D, 0x1B, 0x4C, 0x1B, 0x4B, 0x1B, 0x4C, 0x1A, 0x4D, 0x1B, 0x4C, 0x1B, 0x4D, 0x1B, 0x4C, 0x1A, 0x4B, 0x1B, 0x4D, 0x1B, 0x4D, 0x1C, 0x4E, 0x1C, 0x4F, 0x1C, 0x4F, 0x1C, 0x50, 0x1D, 0x50, 0x1C, 0x51, 0x1C, 0x4F, 0x1C, 0x4F, 0x1D, 0x4F, 0x1C, 0x50, 0x1D, 0x50, 0x1C, 0x50, 0x1C, 0x50, 0x1C, 0x4F, 0x1C, 0x51, 0x1C, 0x52, 0x1C, 0x51, 0x1D, 0x52, 0x1D, 0x53, 0x1E, 0x52, 0x1F, 0x53, 0x1E, 0x52, 0x1E, 0x53, 0x1E, 0x53, 0x1E, 0x53, 0x1E, 0x54, 0x1F, 0x53, 0x1E, 0x54, 0x1F, 0x53, 0x1E, 0x53, 0x1F, 0x54, 0x1E, 0x55, 0x1E, 0x55, 0x1F, 0x56, 0x20, 0x58, 0x20, 0x57, 0x20, 0x58, 0x20, 0x57, 0x20, 0x55, 0x1F, 0x57, 0x20, 0x57, 0x20, 0x56, 0x20, 0x57, 0x20, 0x55, 0x20, 0x52, 0x1F, 0x4C, 0x1E, 0x43, 0x1C, 0x3D, 0x1B, 0x42, 0x1C, 0x4A, 0x1E, 0x4A, 0x1D, 0x42, 0x1B, 0x33, 0x17, 0x26, 0x14, 0x20, 0x12, 0x1D, 0x12, 0x1C, 0x12, 0x1C, 0x12, 0x1D, 0x13, 0x20, 0x14, 0x2C, 0x18, 0x41, 0x1D, 0x4D, 0x20, 0x52, 0x20, 0x4D, 0x1E, 0x3D, 0x1B, 0x3B, 0x1C, 0x49, 0x1F, 0x54, 0x21, 0x5A, 0x22, 0x5C, 0x22, 0x5A, 0x21, 0x5D, 0x22, 0x5D, 0x21, 0x5C, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x5E, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x5E, 0x23, 0x5E, 0x23, 0x61, 0x24, 0x61, 0x23, 0x60, 0x23, 0x5F, 0x22, 0x60, 0x23, 0x60, 0x23, 0x60, 0x23, 0x61, 0x23, 0x61, 0x24, 0x61, 0x24, 0x60, 0x23, 0x5F, 0x22, 0x5F, 0x22, 0x5E, 0x22, 0x60, 0x22, 0x5F, 0x22, 0x60, 0x22, 0x5F, 0x21, 0x5D, 0x21, 0x60, 0x22, 0x61, 0x22, 0x61, 0x22, 0x60, 0x22, 0x61, 0x22, 0x61, 0x22, 0x5F, 0x22, 0x60, 0x22, 0x5F, 0x22, 0x5F, 0x21, 0x5F, 0x21, 0x60, 0x22, 0x5F, 0x21, 0x61, 0x21, 0x60, 0x22, 0x5E, 0x21, 0x5E, 0x22, 0x5C, 0x21, 0x5E, 0x21, 0x5E, 0x22, 0x5E, 0x21, 0x61, 0x22, 0x5F, 0x21, 0x5E, 0x21, 0x61, 0x21, 0x5E, 0x21, 0x60, 0x21, 0x60, 0x21, 0x5F, 0x21, 0x5F, 0x22, 0x5F, 0x21, 0x5D, 0x21, 0x5E, 0x21, 0x5E, 0x21, 0x5F, 0x21, 0x60, 0x21, 0x5E, 0x21, 0x5F, 0x20, 0x5F, 0x21, 0x5D, 0x20, 0x5D, 0x20, 0x5D, 0x21, 0x5D, 0x20, 0x5E, 0x21, 0x5C, 0x20, 0x5C, 0x21, 0x5C, 0x21, 0x5C, 0x20, 0x5B, 0x20, 0x5C, 0x20, 0x5B, 0x20, 0x5B, 0x20, 0x5D, 0x20, 0x5C, 0x21, 0x5C, 0x20, 0x5B, 0x20, 0x5C, 0x20, 0x5C, 0x21, 0x5F, 0x21, 0x5C, 0x20, 0x5D, 0x20, 0x5B, 0x20, 0x5A, 0x1F, 0x5B, 0x20, 0x5D, 0x20, 0x5B, 0x20, 0x5C, 0x20, 0x5A, 0x1F, 0x5A, 0x20, 0x5A, 0x20, 0x5B, 0x20, 0x5B, 0x20, 0x5C, 0x20, 0x5A, 0x20, 0x57, 0x1F, 0x5A, 0x20, 0x5A, 0x20, 0x5A, 0x20, 0x59, 0x20, 0x58, 0x20, 0x54, 0x20, 0x4D, 0x21, 0x49, 0x22, 0x48, 0x21, 0x48, 0x21, 0x47, 0x22, 0x46, 0x20, 0x49, 0x1E, 0x4E, 0x1E, 0x53, 0x1F, 0x57, 0x1F, 0x56, 0x1F, 0x58, 0x20, 0x5A, 0x20, 0x58, 0x20, 0x58, 0x1F, 0x58, 0x20, 0x58, 0x20, 0x58, 0x20, 0x59, 0x20, 0x56, 0x1F, 0x57, 0x1F, 0x59, 0x20, 0x58, 0x20, 0x5B, 0x21, 0x5A, 0x21, 0x58, 0x20, 0x59, 0x20, 0x57, 0x1F, 0x58, 0x20, 0x58, 0x1F, 0x5A, 0x20, 0x59, 0x20, 0x59, 0x20, 0x58, 0x1F, 0x57, 0x1F, 0x56, 0x1F, 0x59, 0x20, 0x58, 0x20, 0x56, 0x1F, 0x55, 0x1E, 0x56, 0x20, 0x59, 0x21, 0x56, 0x1F, 0x55, 0x1F, 0x54, 0x1E, 0x54, 0x1E, 0x53, 0x1E, 0x54, 0x1E, 0x54, 0x1E, 0x56, 0x1E, 0x55, 0x1F, 0x56, 0x1F, 0x57, 0x1F, 0x56, 0x1E, 0x56, 0x1E, 0x55, 0x1F, 0x57, 0x20, 0x54, 0x1F, 0x56, 0x1F, 0x56, 0x20, 0x56, 0x1F, 0x54, 0x1E, 0x54, 0x1E, 0x55, 0x1F, 0x56, 0x1F, 0x54, 0x1E, 0x55, 0x1E, 0x54, 0x1E, 0x52, 0x1E, 0x53, 0x1E, 0x56, 0x1E, 0x53, 0x1E, 0x53, 0x1E, 0x54, 0x1D, 0x54, 0x1E, 0x53, 0x1E, 0x50, 0x1D, 0x51, 0x1D, 0x50, 0x1D, 0x43, 0x19, 0x2A, 0x15, 0x27, 0x16, 0x25, 0x15, 0x22, 0x14, 0x20, 0x14, 0x25, 0x15, 0x24, 0x15, 0x23, 0x15, 0x23, 0x14, 0x23, 0x15, 0x26, 0x16, 0x23, 0x15, 0x26, 0x16, 0x22, 0x14, 0x27, 0x18, 0x28, 0x16, 0x23, 0x15, 0x28, 0x17, 0x26, 0x16, 0x26, 0x15, 0x20, 0x14, 0x25, 0x15, 0x22, 0x14, 0x23, 0x16, 0x24, 0x15, 0x27, 0x17, 0x21, 0x14, 0x21, 0x14, 0x26, 0x16, 0x1F, 0x15, 0x28, 0x16, 0x20, 0x13, 0x26, 0x16, 0x1E, 0x13, 0x21, 0x14, 0x20, 0x13, 0x23, 0x15, 0x1F, 0x13, 0x23, 0x15, 0x23, 0x15, 0x22, 0x14, 0x25, 0x15
    },

    {
        0x50, 0x48, 0x51, 0x48, 0x52, 0x4A, 0x52, 0x4A, 0x51, 0x48, 0x52, 0x48, 0x52, 0x48, 0x52, 0x49, 0x53, 0x49, 0x53, 0x49, 0x52, 0x49, 0x52, 0x48, 0x52, 0x48, 0x53, 0x49, 0x52, 0x4A, 0x54, 0x4A, 0x54, 0x4B, 0x54, 0x4B, 0x55, 0x4C, 0x55, 0x4C, 0x56, 0x4D, 0x55, 0x4C, 0x55, 0x4B, 0x55, 0x4C, 0x57, 0x4D, 0x56, 0x4B, 0x57, 0x4C, 0x57, 0x4D, 0x56, 0x4D, 0x58, 0x4D, 0x57, 0x4D, 0x57, 0x4D, 0x58, 0x4E, 0x58, 0x4F, 0x58, 0x4F, 0x57, 0x4F, 0x57, 0x4E, 0x58, 0x4F, 0x59, 0x50, 0x58, 0x4F, 0x5A, 0x50, 0x58, 0x50, 0x59, 0x50, 0x58, 0x4F, 0x59, 0x4F, 0x5A, 0x51, 0x5A, 0x50, 0x59, 0x51, 0x5B, 0x52, 0x5C, 0x53, 0x5C, 0x53, 0x5D, 0x54, 0x5C, 0x53, 0x5B, 0x52, 0x5B, 0x52, 0x5C, 0x53, 0x5B, 0x53, 0x59, 0x52, 0x56, 0x4F, 0x52, 0x4C, 0x4B, 0x45, 0x43, 0x3E, 0x3C, 0x3B, 0x42, 0x41, 0x4A, 0x47, 0x48, 0x43, 0x3F, 0x39, 0x2E, 0x2B, 0x21, 0x21, 0x1A, 0x1C, 0x18, 0x1B, 0x16, 0x19, 0x16, 0x19, 0x17, 0x19, 0x19, 0x1C, 0x21, 0x27, 0x36, 0x3A, 0x47, 0x48, 0x4F, 0x4E, 0x4E, 0x4A, 0x3F, 0x3A, 0x38, 0x37, 0x44, 0x44, 0x51, 0x4E, 0x58, 0x54, 0x5C, 0x56, 0x5C, 0x55, 0x5E, 0x58, 0x5F, 0x58, 0x60, 0x57, 0x63, 0x5A, 0x63, 0x59, 0x63, 0x5A, 0x63, 0x58, 0x62, 0x5A, 0x63, 0x58, 0x62, 0x5A, 0x63, 0x5A, 0x64, 0x5B, 0x64, 0x5B, 0x63, 0x5A, 0x62, 0x59, 0x62, 0x5A, 0x63, 0x5A, 0x63, 0x5A, 0x63, 0x5B, 0x64, 0x5C, 0x65, 0x5C, 0x65, 0x5A, 0x63, 0x5A, 0x64, 0x59, 0x63, 0x59, 0x65, 0x5A, 0x64, 0x5A, 0x64, 0x5A, 0x64, 0x59, 0x62, 0x57, 0x63, 0x5A, 0x64, 0x5A, 0x65, 0x5B, 0x65, 0x5C, 0x65, 0x5C, 0x66, 0x5C, 0x62, 0x58, 0x63, 0x5A, 0x62, 0x5B, 0x63, 0x59, 0x63, 0x59, 0x63, 0x59, 0x62, 0x58, 0x64, 0x5A, 0x63, 0x5A, 0x62, 0x57, 0x60, 0x58, 0x61, 0x57, 0x62, 0x59, 0x62, 0x58, 0x62, 0x58, 0x64, 0x5A, 0x63, 0x59, 0x63, 0x5A, 0x64, 0x5A, 0x63, 0x57, 0x63, 0x58, 0x64, 0x58, 0x64, 0x58, 0x64, 0x59, 0x63, 0x58, 0x5F, 0x57, 0x62, 0x58, 0x61, 0x57, 0x61, 0x58, 0x63, 0x58, 0x63, 0x57, 0x63, 0x57, 0x63, 0x58, 0x62, 0x56, 0x63, 0x57, 0x61, 0x56, 0x60, 0x56, 0x60, 0x56, 0x60, 0x56, 0x60, 0x56, 0x60, 0x56, 0x60, 0x57, 0x5F, 0x54, 0x60, 0x56, 0x5E, 0x54, 0x5F, 0x55, 0x61, 0x56, 0x61, 0x58, 0x5F, 0x55, 0x5F, 0x56, 0x5F, 0x55, 0x60, 0x56, 0x61, 0x58, 0x61, 0x56, 0x61, 0x56, 0x61, 0x56, 0x5E, 0x55, 0x60, 0x56, 0x61, 0x57, 0x5F, 0x56, 0x5F, 0x55, 0x5C, 0x54, 0x5D, 0x53, 0x5F, 0x55, 0x5E, 0x54, 0x5F, 0x55, 0x60, 0x56, 0x5D, 0x54, 0x5C, 0x52, 0x5C, 0x54, 0x5D, 0x54, 0x5D, 0x54, 0x5D, 0x53, 0x5A, 0x51, 0x53, 0x4C, 0x49, 0x46, 0x43, 0x44, 0x42, 0x43, 0x40, 0x41, 0x40, 0x42, 0x40, 0x41, 0x43, 0x43, 0x4D, 0x48, 0x55, 0x4F, 0x5A, 0x51, 0x59, 0x51, 0x5C, 0x53, 0x5F, 0x55, 0x5C, 0x53, 0x5D, 0x52, 0x5D, 0x55, 0x5C, 0x54, 0x5D, 0x53, 0x5D, 0x54, 0x5A, 0x51, 0x5B, 0x52, 0x5C, 0x53, 0x5B, 0x53, 0x5D, 0x55, 0x5D, 0x55, 0x5B, 0x52, 0x5D, 0x53, 0x5C, 0x52, 0x5B, 0x52, 0x5D, 0x54, 0x5D, 0x55, 0x5C, 0x53, 0x5C, 0x54, 0x5C, 0x52, 0x5B, 0x53, 0x5B, 0x51, 0x5C, 0x55, 0x5C, 0x52, 0x5A, 0x51, 0x5A, 0x50, 0x5A, 0x52, 0x5B, 0x54, 0x5A, 0x50, 0x58, 0x50, 0x57, 0x4E, 0x58, 0x4F, 0x57, 0x4F, 0x59, 0x50, 0x58, 0x50, 0x5A, 0x51, 0x59, 0x50, 0x5A, 0x51, 0x5B, 0x52, 0x5B, 0x52, 0x5A, 0x52, 0x59, 0x51, 0x59, 0x51, 0x58, 0x50, 0x59, 0x51, 0x5A, 0x51, 0x5B, 0x51, 0x5A, 0x51, 0x5A, 0x51, 0x59, 0x51, 0x5A, 0x51, 0x58, 0x4F, 0x59, 0x50, 0x59, 0x4F, 0x57, 0x4E, 0x59, 0x4F, 0x5B, 0x50, 0x57, 0x4E, 0x59, 0x4F, 0x58, 0x4E, 0x58, 0x4F, 0x58, 0x4F, 0x54, 0x4C, 0x55, 0x4C, 0x53, 0x4B, 0x43, 0x39, 0x2A, 0x27, 0x23, 0x25, 0x20, 0x21, 0x1E, 0x20, 0x1D, 0x1F, 0x20, 0x23, 0x20, 0x23, 0x20, 0x24, 0x1F, 0x20, 0x20, 0x24, 0x21, 0x23, 0x1F, 0x21, 0x21, 0x24, 0x1D, 0x1F, 0x22, 0x29, 0x22, 0x24, 0x1F, 0x22, 0x24, 0x29, 0x20, 0x21, 0x21, 0x23, 0x1C, 0x1F, 0x21, 0x24, 0x1F, 0x1F, 0x20, 0x24, 0x1F, 0x21, 0x21, 0x25, 0x1E, 0x1F, 0x1D, 0x20, 0x20, 0x23, 0x1C, 0x21, 0x23, 0x25, 0x1C, 0x1D, 0x21, 0x24, 0x1B, 0x1C, 0x1E, 0x21, 0x1D, 0x1D, 0x1E, 0x21, 0x1C, 0x1E, 0x1E, 0x22, 0x1E, 0x20, 0x1F, 0x23, 0x20, 0x22
    },

    {
        0x4C, 0x1B, 0x4C, 0x1B, 0x4C, 0x1B, 0x4D, 0x1B, 0x4D, 0x1B, 0x4C, 0x1A, 0x4B, 0x1A, 0x4D, 0x1A, 0x4D, 0x1B, 0x4D, 0x1B, 0x4D, 0x1B, 0x4D, 0x1B, 0x4C, 0x1B, 0x4C, 0x1B, 0x4D, 0x1B, 0x4E, 0x1C, 0x4E, 0x1C, 0x4E, 0x1C, 0x4F, 0x1C, 0x50, 0x1C, 0x50, 0x1C, 0x4F, 0x1C, 0x50, 0x1C, 0x50, 0x1C, 0x50, 0x1C, 0x50, 0x1C, 0x50, 0x1C, 0x4F, 0x1C, 0x50, 0x1C, 0x51, 0x1C, 0x51, 0x1D, 0x51, 0x1C, 0x52, 0x1D, 0x52, 0x1E, 0x53, 0x1E, 0x53, 0x1E, 0x52, 0x1E, 0x53, 0x1F, 0x53, 0x1E, 0x53, 0x1E, 0x54, 0x1E, 0x53, 0x1E, 0x54, 0x1F, 0x54, 0x1E, 0x55, 0x1E, 0x56, 0x1F, 0x56, 0x1F, 0x55, 0x1F, 0x55, 0x1F, 0x56, 0x20, 0x58, 0x20, 0x58, 0x1F, 0x57, 0x20, 0x56, 0x1F, 0x55, 0x20, 0x57, 0x20, 0x57, 0x20, 0x55, 0x1F, 0x51, 0x1F, 0x4B, 0x1E, 0x44, 0x1C, 0x3E, 0x1B, 0x41, 0x1C, 0x4A, 0x1D, 0x48, 0x1C, 0x42, 0x1B, 0x36, 0x18, 0x27, 0x15, 0x1F, 0x13, 0x1C, 0x11, 0x1B, 0x11, 0x1A, 0x11, 0x1A, 0x11, 0x1A, 0x11, 0x1C, 0x12, 0x1E, 0x13, 0x29, 0x17, 0x3F, 0x1C, 0x4D, 0x1F, 0x52, 0x20, 0x4E, 0x1E, 0x3D, 0x1B, 0x3A, 0x1C, 0x49, 0x1F, 0x55, 0x21, 0x5A, 0x22, 0x59, 0x21, 0x5A, 0x21, 0x5D, 0x22, 0x5C, 0x21, 0x5E, 0x22, 0x5E, 0x22, 0x5D, 0x21, 0x5E, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x5F, 0x23, 0x5D, 0x23, 0x60, 0x22, 0x5E, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x5E, 0x22, 0x60, 0x23, 0x62, 0x23, 0x62, 0x24, 0x60, 0x23, 0x5F, 0x22, 0x5E, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x5D, 0x21, 0x5F, 0x22, 0x5F, 0x22, 0x5E, 0x21, 0x5E, 0x22, 0x60, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x61, 0x22, 0x62, 0x22, 0x60, 0x21, 0x5F, 0x21, 0x5F, 0x21, 0x5F, 0x21, 0x60, 0x22, 0x60, 0x22, 0x5F, 0x21, 0x60, 0x23, 0x60, 0x22, 0x60, 0x22, 0x5F, 0x21, 0x5D, 0x20, 0x5E, 0x20, 0x5E, 0x21, 0x5E, 0x21, 0x5F, 0x22, 0x5E, 0x21, 0x5D, 0x21, 0x5F, 0x20, 0x5D, 0x20, 0x5E, 0x21, 0x60, 0x21, 0x5F, 0x21, 0x5F, 0x22, 0x60, 0x21, 0x5E, 0x21, 0x5E, 0x20, 0x5D, 0x20, 0x5D, 0x20, 0x5E, 0x21, 0x5D, 0x20, 0x5E, 0x21, 0x5D, 0x20, 0x5D, 0x20, 0x5C, 0x21, 0x5D, 0x21, 0x5D, 0x20, 0x5E, 0x21, 0x5E, 0x21, 0x5C, 0x20, 0x5E, 0x21, 0x5D, 0x20, 0x5B, 0x1F, 0x5B, 0x20, 0x5B, 0x1F, 0x5A, 0x1F, 0x5C, 0x20, 0x5B, 0x20, 0x5C, 0x20, 0x5B, 0x20, 0x5B, 0x20, 0x5B, 0x20, 0x5D, 0x20, 0x5D, 0x20, 0x5B, 0x20, 0x5A, 0x20, 0x5B, 0x20, 0x5C, 0x20, 0x5C, 0x21, 0x5D, 0x20, 0x5C, 0x20, 0x5B, 0x20, 0x5A, 0x1F, 0x5A, 0x20, 0x5C, 0x20, 0x5B, 0x20, 0x5C, 0x20, 0x59, 0x20, 0x59, 0x20, 0x5B, 0x20, 0x59, 0x20, 0x58, 0x20, 0x58, 0x20, 0x59, 0x20, 0x50, 0x20, 0x4A, 0x21, 0x48, 0x22, 0x46, 0x22, 0x46, 0x22, 0x47, 0x22, 0x45, 0x21, 0x43, 0x1C, 0x46, 0x1C, 0x4F, 0x1D, 0x57, 0x1F, 0x57, 0x1F, 0x58, 0x1F, 0x59, 0x20, 0x58, 0x20, 0x58, 0x1F, 0x5A, 0x20, 0x58, 0x1F, 0x56, 0x1F, 0x57, 0x1F, 0x57, 0x1F, 0x58, 0x20, 0x56, 0x1F, 0x59, 0x20, 0x59, 0x21, 0x5A, 0x21, 0x58, 0x20, 0x59, 0x20, 0x58, 0x20, 0x56, 0x1F, 0x58, 0x1F, 0x58, 0x1F, 0x57, 0x20, 0x58, 0x20, 0x57, 0x1F, 0x58, 0x1F, 0x58, 0x1F, 0x59, 0x1F, 0x57, 0x1F, 0x55, 0x1F, 0x56, 0x1F, 0x57, 0x1F, 0x58, 0x20, 0x57, 0x1F, 0x56, 0x1F, 0x54, 0x1E, 0x52, 0x1E, 0x53, 0x1E, 0x53, 0x1E, 0x53, 0x1D, 0x56, 0x1E, 0x58, 0x20, 0x59, 0x20, 0x56, 0x1F, 0x57, 0x1F, 0x56, 0x1E, 0x55, 0x1F, 0x55, 0x20, 0x55, 0x1F, 0x55, 0x1F, 0x56, 0x1F, 0x55, 0x1F, 0x55, 0x1F, 0x56, 0x1F, 0x56, 0x1E, 0x55, 0x1F, 0x53, 0x1E, 0x55, 0x1E, 0x54, 0x1E, 0x53, 0x1D, 0x53, 0x1D, 0x54, 0x1E, 0x52, 0x1E, 0x54, 0x1E, 0x52, 0x1E, 0x53, 0x1D, 0x51, 0x1E, 0x50, 0x1D, 0x50, 0x1D, 0x50, 0x1D, 0x42, 0x19, 0x2D, 0x16, 0x28, 0x16, 0x23, 0x15, 0x28, 0x16, 0x23, 0x15, 0x2B, 0x17, 0x23, 0x15, 0x28, 0x16, 0x21, 0x14, 0x26, 0x16, 0x22, 0x14, 0x25, 0x16, 0x23, 0x15, 0x1F, 0x14, 0x28, 0x17, 0x22, 0x14, 0x22, 0x15, 0x2A, 0x17, 0x20, 0x14, 0x23, 0x14, 0x20, 0x14, 0x24, 0x14, 0x20, 0x13, 0x24, 0x15, 0x1F, 0x13, 0x24, 0x15, 0x1E, 0x13, 0x20, 0x14, 0x20, 0x14, 0x21, 0x15, 0x26, 0x14, 0x21, 0x15, 0x24, 0x15, 0x1F, 0x13, 0x23, 0x15, 0x25, 0x15, 0x24, 0x15, 0x25, 0x15, 0x22, 0x15, 0x26, 0x16, 0x25, 0x15, 0x1D, 0x12
    },

    {
        0x50, 0x48, 0x51, 0x48, 0x51, 0x4A, 0x52, 0x4A, 0x52, 0x49, 0x51, 0x49, 0x51, 0x48, 0x52, 0x49, 0x53, 0x49, 0x53, 0x4A, 0x53, 0x49, 0x53, 0x49, 0x52, 0x49, 0x52, 0x49, 0x52, 0x4A, 0x53, 0x4A, 0x53, 0x4A, 0x54, 0x4A, 0x55, 0x4B, 0x55, 0x4B, 0x55, 0x4C, 0x55, 0x4D, 0x57, 0x4D, 0x57, 0x4D, 0x57, 0x4D, 0x56, 0x4C, 0x56, 0x4D, 0x56, 0x4C, 0x57, 0x4C, 0x58, 0x4E, 0x57, 0x4C, 0x58, 0x4D, 0x57, 0x4E, 0x58, 0x4E, 0x58, 0x4F, 0x58, 0x4E, 0x58, 0x4E, 0x59, 0x4F, 0x58, 0x4F, 0x59, 0x50, 0x59, 0x50, 0x59, 0x50, 0x5A, 0x52, 0x5B, 0x51, 0x5A, 0x51, 0x5B, 0x50, 0x5B, 0x51, 0x5A, 0x51, 0x5B, 0x51, 0x5C, 0x52, 0x5C, 0x53, 0x5E, 0x53, 0x5D, 0x52, 0x5A, 0x50, 0x59, 0x51, 0x5A, 0x52, 0x5A, 0x52, 0x56, 0x51, 0x53, 0x4C, 0x4C, 0x45, 0x43, 0x3E, 0x3D, 0x3B, 0x41, 0x42, 0x4A, 0x47, 0x46, 0x42, 0x3E, 0x3A, 0x30, 0x2D, 0x21, 0x21, 0x1A, 0x1C, 0x17, 0x1A, 0x15, 0x19, 0x15, 0x18, 0x14, 0x17, 0x15, 0x18, 0x16, 0x19, 0x18, 0x1C, 0x20, 0x25, 0x34, 0x39, 0x45, 0x47, 0x4F, 0x4D, 0x4E, 0x4A, 0x3F, 0x3A, 0x37, 0x37, 0x44, 0x44, 0x51, 0x50, 0x59, 0x53, 0x5A, 0x53, 0x5B, 0x55, 0x5F, 0x58, 0x5F, 0x58, 0x60, 0x58, 0x62, 0x58, 0x61, 0x58, 0x62, 0x58, 0x61, 0x58, 0x62, 0x5A, 0x64, 0x59, 0x64, 0x5A, 0x61, 0x5A, 0x62, 0x5A, 0x64, 0x5A, 0x63, 0x58, 0x62, 0x5A, 0x64, 0x59, 0x62, 0x58, 0x62, 0x59, 0x64, 0x5D, 0x64, 0x5C, 0x64, 0x5A, 0x64, 0x59, 0x64, 0x5A, 0x62, 0x58, 0x63, 0x59, 0x63, 0x58, 0x64, 0x5A, 0x64, 0x59, 0x64, 0x59, 0x62, 0x59, 0x63, 0x5A, 0x62, 0x59, 0x62, 0x5A, 0x66, 0x5B, 0x64, 0x5B, 0x64, 0x5A, 0x62, 0x58, 0x63, 0x58, 0x64, 0x5A, 0x65, 0x5A, 0x64, 0x5A, 0x63, 0x59, 0x65, 0x5B, 0x65, 0x5A, 0x64, 0x59, 0x62, 0x58, 0x60, 0x57, 0x60, 0x57, 0x62, 0x58, 0x62, 0x57, 0x63, 0x58, 0x62, 0x57, 0x63, 0x58, 0x63, 0x58, 0x61, 0x57, 0x63, 0x58, 0x65, 0x59, 0x65, 0x59, 0x64, 0x59, 0x63, 0x59, 0x62, 0x57, 0x63, 0x58, 0x61, 0x57, 0x60, 0x58, 0x62, 0x58, 0x60, 0x56, 0x63, 0x57, 0x61, 0x58, 0x62, 0x56, 0x62, 0x56, 0x62, 0x56, 0x61, 0x57, 0x62, 0x58, 0x63, 0x57, 0x61, 0x58, 0x62, 0x58, 0x5F, 0x55, 0x5F, 0x56, 0x5F, 0x55, 0x5F, 0x55, 0x5F, 0x53, 0x5E, 0x55, 0x60, 0x54, 0x5F, 0x56, 0x5F, 0x55, 0x5F, 0x55, 0x60, 0x55, 0x62, 0x57, 0x61, 0x56, 0x60, 0x55, 0x60, 0x55, 0x5F, 0x55, 0x5E, 0x55, 0x5F, 0x56, 0x61, 0x57, 0x61, 0x55, 0x60, 0x55, 0x5F, 0x54, 0x5C, 0x55, 0x60, 0x56, 0x60, 0x55, 0x60, 0x54, 0x5D, 0x54, 0x5D, 0x54, 0x60, 0x55, 0x5C, 0x53, 0x5B, 0x53, 0x5C, 0x53, 0x5B, 0x51, 0x4F, 0x48, 0x45, 0x44, 0x42, 0x44, 0x40, 0x42, 0x3F, 0x42, 0x3E, 0x41, 0x3E, 0x41, 0x3C, 0x3C, 0x44, 0x41, 0x4F, 0x49, 0x59, 0x51, 0x5B, 0x53, 0x5C, 0x53, 0x5C, 0x54, 0x5C, 0x53, 0x5D, 0x54, 0x5E, 0x53, 0x5C, 0x52, 0x5A, 0x52, 0x5A, 0x51, 0x5C, 0x52, 0x5B, 0x53, 0x5A, 0x52, 0x5C, 0x53, 0x5D, 0x55, 0x5D, 0x56, 0x5C, 0x53, 0x5C, 0x54, 0x5D, 0x53, 0x5B, 0x51, 0x5D, 0x54, 0x5D, 0x54, 0x5B, 0x52, 0x5B, 0x53, 0x5B, 0x52, 0x5C, 0x53, 0x5C, 0x54, 0x5C, 0x53, 0x5B, 0x52, 0x5A, 0x50, 0x5B, 0x51, 0x5C, 0x53, 0x5C, 0x52, 0x5B, 0x51, 0x5A, 0x51, 0x57, 0x4E, 0x56, 0x4F, 0x56, 0x4D, 0x56, 0x4E, 0x57, 0x4F, 0x5A, 0x52, 0x5B, 0x53, 0x5B, 0x52, 0x5B, 0x52, 0x5C, 0x53, 0x5A, 0x51, 0x59, 0x51, 0x59, 0x51, 0x58, 0x50, 0x58, 0x51, 0x5A, 0x51, 0x5B, 0x51, 0x5A, 0x50, 0x5A, 0x51, 0x58, 0x50, 0x58, 0x4F, 0x58, 0x50, 0x5A, 0x50, 0x59, 0x50, 0x59, 0x50, 0x58, 0x50, 0x5A, 0x4F, 0x58, 0x4F, 0x59, 0x4F, 0x59, 0x4F, 0x57, 0x4E, 0x56, 0x4D, 0x56, 0x4D, 0x55, 0x4C, 0x52, 0x4A, 0x42, 0x3A, 0x2C, 0x29, 0x26, 0x25, 0x21, 0x23, 0x24, 0x25, 0x1F, 0x23, 0x24, 0x27, 0x1F, 0x21, 0x22, 0x25, 0x1D, 0x1E, 0x21, 0x25, 0x1E, 0x20, 0x20, 0x23, 0x1E, 0x20, 0x1C, 0x1F, 0x22, 0x26, 0x1E, 0x1F, 0x1F, 0x23, 0x23, 0x25, 0x1D, 0x1F, 0x1E, 0x1F, 0x1E, 0x20, 0x1E, 0x20, 0x1C, 0x1D, 0x20, 0x23, 0x1C, 0x1D, 0x1E, 0x21, 0x1B, 0x1E, 0x1C, 0x1F, 0x1E, 0x20, 0x1F, 0x22, 0x21, 0x23, 0x1E, 0x22, 0x21, 0x22, 0x1C, 0x1F, 0x21, 0x24, 0x20, 0x22, 0x1F, 0x22, 0x1F, 0x22, 0x1E, 0x22, 0x22, 0x25, 0x1F, 0x22, 0x1A, 0x1B
    },

    {
        0x4C, 0x1A, 0x4B, 0x1B, 0x4D, 0x1B, 0x4D, 0x1B, 0x4D, 0x1B, 0x4B, 0x1A, 0x4A, 0x1B, 0x4B, 0x1A, 0x4D, 0x1A, 0x4D, 0x1A, 0x4D, 0x1B, 0x4C, 0x1A, 0x4D, 0x1B, 0x4D, 0x1B, 0x4D, 0x1B, 0x4E, 0x1B, 0x4F, 0x1C, 0x4F, 0x1C, 0x4F, 0x1C, 0x50, 0x1C, 0x4F, 0x1C, 0x4F, 0x1D, 0x50, 0x1D, 0x51, 0x1C, 0x50, 0x1C, 0x4F, 0x1C, 0x50, 0x1D, 0x4F, 0x1C, 0x50, 0x1C, 0x50, 0x1C, 0x50, 0x1C, 0x51, 0x1C, 0x51, 0x1D, 0x52, 0x1E, 0x52, 0x1E, 0x51, 0x1E, 0x52, 0x1E, 0x52, 0x1E, 0x54, 0x1F, 0x53, 0x1E, 0x54, 0x1E, 0x55, 0x1E, 0x55, 0x1F, 0x55, 0x1F, 0x56, 0x1F, 0x56, 0x1F, 0x55, 0x1F, 0x54, 0x1F, 0x55, 0x1F, 0x57, 0x20, 0x58, 0x20, 0x56, 0x1F, 0x56, 0x1F, 0x54, 0x1F, 0x54, 0x20, 0x54, 0x1F, 0x54, 0x1F, 0x50, 0x1F, 0x4D, 0x1E, 0x45, 0x1C, 0x3E, 0x1B, 0x40, 0x1C, 0x48, 0x1D, 0x4A, 0x1E, 0x42, 0x1B, 0x34, 0x17, 0x27, 0x14, 0x1F, 0x12, 0x1C, 0x11, 0x1B, 0x11, 0x19, 0x11, 0x18, 0x11, 0x18, 0x11, 0x19, 0x11, 0x19, 0x11, 0x1B, 0x12, 0x1E, 0x12, 0x28, 0x17, 0x3E, 0x1C, 0x4A, 0x1E, 0x51, 0x20, 0x4D, 0x1E, 0x3E, 0x1B, 0x3A, 0x1B, 0x49, 0x1F, 0x55, 0x22, 0x5B, 0x22, 0x59, 0x22, 0x5B, 0x22, 0x5C, 0x21, 0x5D, 0x22, 0x5F, 0x22, 0x5D, 0x22, 0x5C, 0x22, 0x5E, 0x22, 0x5E, 0x22, 0x5F, 0x23, 0x60, 0x23, 0x5F, 0x22, 0x5E, 0x22, 0x5E, 0x22, 0x5F, 0x23, 0x5F, 0x22, 0x60, 0x23, 0x60, 0x23, 0x5E, 0x22, 0x61, 0x23, 0x60, 0x23, 0x60, 0x23, 0x60, 0x23, 0x5E, 0x22, 0x5D, 0x22, 0x5F, 0x22, 0x5F, 0x21, 0x5F, 0x22, 0x5F, 0x21, 0x5E, 0x21, 0x5E, 0x21, 0x5E, 0x21, 0x5F, 0x22, 0x5F, 0x22, 0x61, 0x22, 0x61, 0x22, 0x60, 0x22, 0x60, 0x22, 0x5F, 0x22, 0x60, 0x21, 0x60, 0x22, 0x5F, 0x21, 0x5E, 0x21, 0x60, 0x22, 0x61, 0x22, 0x60, 0x22, 0x5F, 0x21, 0x5D, 0x21, 0x5B, 0x21, 0x5C, 0x21, 0x5D, 0x21, 0x5E, 0x21, 0x5D, 0x21, 0x5D, 0x20, 0x5D, 0x20, 0x5D, 0x20, 0x5C, 0x20, 0x5F, 0x21, 0x60, 0x22, 0x60, 0x21, 0x5F, 0x21, 0x5D, 0x20, 0x5D, 0x20, 0x5F, 0x20, 0x60, 0x21, 0x60, 0x21, 0x5E, 0x21, 0x5F, 0x21, 0x5E, 0x21, 0x5C, 0x20, 0x5D, 0x20, 0x5D, 0x20, 0x5D, 0x20, 0x5F, 0x21, 0x5D, 0x21, 0x5B, 0x21, 0x5D, 0x21, 0x5D, 0x20, 0x5C, 0x21, 0x5B, 0x20, 0x5A, 0x1F, 0x5B, 0x1F, 0x5B, 0x20, 0x59, 0x1F, 0x5A, 0x20, 0x5B, 0x20, 0x5C, 0x20, 0x5A, 0x1F, 0x5D, 0x20, 0x5C, 0x20, 0x5B, 0x1F, 0x5B, 0x20, 0x5B, 0x20, 0x5A, 0x1F, 0x5A, 0x20, 0x5D, 0x21, 0x5C, 0x20, 0x5B, 0x20, 0x59, 0x20, 0x5A, 0x20, 0x5C, 0x21, 0x5A, 0x20, 0x5A, 0x1F, 0x5A, 0x1F, 0x59, 0x20, 0x5B, 0x20, 0x5A, 0x20, 0x59, 0x1F, 0x59, 0x20, 0x55, 0x1F, 0x4C, 0x1F, 0x47, 0x21, 0x46, 0x21, 0x47, 0x22, 0x46, 0x22, 0x46, 0x22, 0x47, 0x21, 0x3D, 0x1B, 0x3D, 0x1A, 0x4B, 0x1D, 0x57, 0x1F, 0x55, 0x1E, 0x58, 0x1F, 0x57, 0x20, 0x59, 0x1F, 0x57, 0x20, 0x58, 0x1F, 0x57, 0x1F, 0x58, 0x20, 0x57, 0x1F, 0x57, 0x1F, 0x57, 0x1F, 0x56, 0x1F, 0x59, 0x20, 0x5A, 0x22, 0x5A, 0x21, 0x59, 0x21, 0x5A, 0x21, 0x59, 0x20, 0x57, 0x1F, 0x57, 0x1F, 0x59, 0x20, 0x59, 0x1F, 0x57, 0x20, 0x57, 0x1F, 0x57, 0x1F, 0x58, 0x20, 0x58, 0x20, 0x57, 0x20, 0x58, 0x20, 0x56, 0x1F, 0x56, 0x1F, 0x58, 0x20, 0x56, 0x1F, 0x57, 0x1F, 0x55, 0x1F, 0x54, 0x1F, 0x54, 0x1F, 0x53, 0x1E, 0x54, 0x1E, 0x54, 0x1E, 0x57, 0x1F, 0x56, 0x20, 0x57, 0x1F, 0x54, 0x1F, 0x55, 0x1E, 0x57, 0x20, 0x54, 0x1F, 0x53, 0x1F, 0x54, 0x1F, 0x56, 0x1F, 0x54, 0x1F, 0x54, 0x1E, 0x54, 0x1E, 0x54, 0x1E, 0x51, 0x1D, 0x54, 0x1E, 0x52, 0x1D, 0x52, 0x1D, 0x55, 0x1E, 0x55, 0x1E, 0x54, 0x1E, 0x55, 0x1E, 0x53, 0x1E, 0x54, 0x1E, 0x53, 0x1E, 0x53, 0x1E, 0x50, 0x1D, 0x51, 0x1D, 0x4D, 0x1C, 0x41, 0x19, 0x2E, 0x16, 0x26, 0x15, 0x27, 0x16, 0x23, 0x14, 0x24, 0x16, 0x23, 0x14, 0x20, 0x14, 0x26, 0x16, 0x22, 0x14, 0x27, 0x16, 0x23, 0x15, 0x26, 0x16, 0x24, 0x16, 0x25, 0x16, 0x27, 0x17, 0x25, 0x15, 0x25, 0x17, 0x28, 0x16, 0x20, 0x13, 0x23, 0x14, 0x20, 0x14, 0x26, 0x16, 0x25, 0x15, 0x25, 0x16, 0x23, 0x14, 0x25, 0x15, 0x26, 0x16, 0x22, 0x14, 0x25, 0x15, 0x22, 0x15, 0x28, 0x16, 0x22, 0x14, 0x26, 0x16, 0x21, 0x13, 0x27, 0x17, 0x20, 0x13, 0x23, 0x15, 0x20, 0x13, 0x20, 0x14, 0x22, 0x14, 0x1F, 0x13, 0x1E, 0x13
    },

    {
        0x51, 0x48, 0x51, 0x48, 0x51, 0x49, 0x52, 0x4A, 0x51, 0x4A, 0x51, 0x48, 0x50, 0x47, 0x52, 0x48, 0x53, 0x49, 0x54, 0x49, 0x54, 0x49, 0x53, 0x49, 0x53, 0x49, 0x53, 0x4A, 0x52, 0x49, 0x54, 0x4A, 0x55, 0x4B, 0x55, 0x4B, 0x55, 0x4C, 0x57, 0x4D, 0x56, 0x4C, 0x56, 0x4C, 0x57, 0x4E, 0x57, 0x4D, 0x57, 0x4D, 0x55, 0x4C, 0x57, 0x4C, 0x56, 0x4C, 0x55, 0x4C, 0x56, 0x4D, 0x58, 0x4E, 0x58, 0x4E, 0x58, 0x4E, 0x58, 0x4F, 0x58, 0x4E, 0x56, 0x4F, 0x59, 0x4F, 0x59, 0x4F, 0x59, 0x4F, 0x59, 0x4F, 0x5A, 0x50, 0x5A, 0x51, 0x5B, 0x51, 0x5C, 0x52, 0x5C, 0x52, 0x5C, 0x51, 0x5C, 0x52, 0x5A, 0x50, 0x5A, 0x51, 0x5C, 0x52, 0x5D, 0x52, 0x5B, 0x52, 0x5A, 0x50, 0x59, 0x50, 0x59, 0x50, 0x59, 0x51, 0x57, 0x4F, 0x52, 0x4A, 0x4D, 0x45, 0x44, 0x3F, 0x3C, 0x3A, 0x40, 0x3F, 0x48, 0x46, 0x48, 0x45, 0x3F, 0x3B, 0x2F, 0x2C, 0x22, 0x22, 0x1A, 0x1C, 0x17, 0x19, 0x16, 0x19, 0x15, 0x18, 0x14, 0x17, 0x14, 0x16, 0x13, 0x17, 0x15, 0x18, 0x15, 0x19, 0x18, 0x1B, 0x20, 0x24, 0x32, 0x37, 0x45, 0x46, 0x4D, 0x4C, 0x4E, 0x4A, 0x41, 0x3C, 0x38, 0x36, 0x43, 0x44, 0x53, 0x50, 0x5A, 0x53, 0x5A, 0x53, 0x5C, 0x55, 0x5D, 0x56, 0x60, 0x58, 0x62, 0x59, 0x61, 0x59, 0x62, 0x58, 0x61, 0x59, 0x61, 0x58, 0x63, 0x59, 0x64, 0x5A, 0x62, 0x5A, 0x62, 0x59, 0x62, 0x58, 0x62, 0x5A, 0x64, 0x5B, 0x65, 0x5B, 0x63, 0x5A, 0x62, 0x59, 0x63, 0x5A, 0x64, 0x5A, 0x63, 0x5A, 0x63, 0x5A, 0x63, 0x58, 0x62, 0x59, 0x63, 0x5A, 0x64, 0x59, 0x63, 0x5A, 0x64, 0x58, 0x62, 0x58, 0x62, 0x57, 0x60, 0x57, 0x61, 0x58, 0x62, 0x59, 0x64, 0x5A, 0x65, 0x5A, 0x63, 0x5A, 0x64, 0x59, 0x64, 0x5A, 0x64, 0x5A, 0x66, 0x5B, 0x63, 0x5A, 0x63, 0x59, 0x64, 0x59, 0x64, 0x5A, 0x64, 0x59, 0x63, 0x58, 0x62, 0x57, 0x61, 0x56, 0x60, 0x56, 0x61, 0x57, 0x63, 0x58, 0x61, 0x57, 0x61, 0x58, 0x62, 0x58, 0x61, 0x56, 0x62, 0x56, 0x64, 0x58, 0x65, 0x5A, 0x64, 0x58, 0x62, 0x59, 0x62, 0x57, 0x62, 0x57, 0x63, 0x59, 0x63, 0x5A, 0x64, 0x59, 0x63, 0x58, 0x63, 0x59, 0x63, 0x57, 0x62, 0x57, 0x62, 0x56, 0x62, 0x57, 0x62, 0x58, 0x63, 0x58, 0x62, 0x57, 0x60, 0x56, 0x60, 0x58, 0x60, 0x58, 0x61, 0x56, 0x5F, 0x56, 0x5E, 0x54, 0x5F, 0x56, 0x5F, 0x54, 0x5F, 0x54, 0x5F, 0x55, 0x60, 0x56, 0x60, 0x56, 0x5E, 0x55, 0x61, 0x56, 0x5F, 0x54, 0x60, 0x53, 0x5F, 0x54, 0x5F, 0x54, 0x5F, 0x54, 0x5E, 0x54, 0x60, 0x56, 0x5E, 0x54, 0x5F, 0x54, 0x5D, 0x54, 0x5D, 0x55, 0x5F, 0x55, 0x5F, 0x55, 0x5F, 0x55, 0x5D, 0x54, 0x5D, 0x54, 0x5F, 0x54, 0x5D, 0x54, 0x5D, 0x54, 0x5C, 0x52, 0x58, 0x4E, 0x4C, 0x46, 0x43, 0x43, 0x41, 0x41, 0x40, 0x42, 0x3F, 0x41, 0x3F, 0x42, 0x3E, 0x41, 0x39, 0x36, 0x3C, 0x39, 0x4D, 0x48, 0x59, 0x51, 0x59, 0x51, 0x5C, 0x51, 0x5B, 0x53, 0x5E, 0x53, 0x5C, 0x53, 0x5D, 0x53, 0x5C, 0x52, 0x5C, 0x53, 0x5C, 0x52, 0x5B, 0x52, 0x5B, 0x51, 0x59, 0x51, 0x5E, 0x56, 0x5C, 0x54, 0x5C, 0x54, 0x5C, 0x54, 0x5C, 0x55, 0x5D, 0x54, 0x5D, 0x52, 0x5C, 0x54, 0x5D, 0x54, 0x5C, 0x54, 0x5A, 0x51, 0x5C, 0x52, 0x5A, 0x51, 0x5B, 0x52, 0x5B, 0x53, 0x5B, 0x52, 0x5C, 0x54, 0x5B, 0x51, 0x5A, 0x51, 0x5A, 0x52, 0x5A, 0x50, 0x5C, 0x52, 0x5A, 0x52, 0x58, 0x50, 0x58, 0x50, 0x57, 0x50, 0x58, 0x50, 0x59, 0x50, 0x5A, 0x52, 0x5B, 0x52, 0x5A, 0x50, 0x57, 0x50, 0x59, 0x51, 0x5A, 0x52, 0x58, 0x4F, 0x56, 0x4E, 0x57, 0x50, 0x5A, 0x51, 0x59, 0x4F, 0x58, 0x50, 0x57, 0x4F, 0x59, 0x4F, 0x56, 0x4D, 0x58, 0x50, 0x58, 0x4F, 0x58, 0x4D, 0x5A, 0x51, 0x5B, 0x50, 0x5A, 0x50, 0x5A, 0x50, 0x5A, 0x4F, 0x59, 0x50, 0x59, 0x4F, 0x58, 0x4E, 0x55, 0x4D, 0x57, 0x4F, 0x51, 0x47, 0x42, 0x3A, 0x2D, 0x28, 0x23, 0x23, 0x23, 0x25, 0x1F, 0x20, 0x20, 0x24, 0x1E, 0x1F, 0x1D, 0x20, 0x23, 0x25, 0x1F, 0x22, 0x22, 0x25, 0x1F, 0x22, 0x22, 0x26, 0x22, 0x25, 0x21, 0x24, 0x22, 0x26, 0x21, 0x22, 0x22, 0x26, 0x23, 0x24, 0x1D, 0x1E, 0x1F, 0x21, 0x1D, 0x21, 0x23, 0x26, 0x21, 0x22, 0x20, 0x23, 0x1E, 0x20, 0x20, 0x24, 0x21, 0x24, 0x1E, 0x20, 0x20, 0x22, 0x1E, 0x22, 0x22, 0x23, 0x1E, 0x20, 0x20, 0x23, 0x1C, 0x1E, 0x21, 0x24, 0x1D, 0x1E, 0x1F, 0x22, 0x1C, 0x1D, 0x1D, 0x22, 0x1F, 0x20, 0x1D, 0x1F, 0x1C, 0x1E
    },

    {
        0x4C, 0x1B, 0x4C, 0x1A, 0x4C, 0x1C, 0x4D, 0x1B, 0x4D, 0x1B, 0x4B, 0x1B, 0x4A, 0x1A, 0x4C, 0x1B, 0x4D, 0x1B, 0x4D, 0x1B, 0x4D, 0x1B, 0x4C, 0x1B, 0x4D, 0x1B, 0x4D, 0x1B, 0x4E, 0x1B, 0x4E, 0x1C, 0x4E, 0x1C, 0x4F, 0x1C, 0x4F, 0x1C, 0x4F, 0x1C, 0x51, 0x1D, 0x51, 0x1D, 0x51, 0x1D, 0x51, 0x1D, 0x51, 0x1D, 0x4F, 0x1C, 0x4F, 0x1D, 0x50, 0x1C, 0x4F, 0x1C, 0x51, 0x1D, 0x51, 0x1C, 0x51, 0x1D, 0x4F, 0x1D, 0x52, 0x1E, 0x53, 0x1E, 0x52, 0x1E, 0x53, 0x1E, 0x51, 0x1D, 0x52, 0x1E, 0x52, 0x1E, 0x54, 0x1E, 0x55, 0x1F, 0x55, 0x1F, 0x56, 0x1F, 0x56, 0x1F, 0x56, 0x1F, 0x58, 0x1F, 0x56, 0x1F, 0x55, 0x1F, 0x56, 0x1F, 0x57, 0x20, 0x56, 0x1F, 0x55, 0x20, 0x55, 0x1F, 0x55, 0x20, 0x55, 0x1F, 0x51, 0x1F, 0x4B, 0x1D, 0x44, 0x1C, 0x3D, 0x1B, 0x40, 0x1B, 0x47, 0x1D, 0x49, 0x1D, 0x44, 0x1B, 0x38, 0x19, 0x27, 0x14, 0x1F, 0x13, 0x1B, 0x11, 0x19, 0x11, 0x1A, 0x13, 0x1A, 0x14, 0x1A, 0x14, 0x19, 0x12, 0x19, 0x12, 0x19, 0x12, 0x19, 0x12, 0x1B, 0x12, 0x1E, 0x13, 0x26, 0x16, 0x3B, 0x1B, 0x4A, 0x1E, 0x4F, 0x1F, 0x4F, 0x1E, 0x40, 0x1C, 0x3A, 0x1C, 0x49, 0x1F, 0x53, 0x21, 0x58, 0x21, 0x59, 0x21, 0x5A, 0x21, 0x5B, 0x22, 0x5E, 0x22, 0x5E, 0x22, 0x5E, 0x22, 0x5E, 0x22, 0x5F, 0x22, 0x5D, 0x22, 0x5E, 0x22, 0x5E, 0x22, 0x5D, 0x22, 0x5D, 0x22, 0x5F, 0x22, 0x5F, 0x23, 0x5F, 0x22, 0x5E, 0x23, 0x5E, 0x22, 0x5F, 0x22, 0x60, 0x22, 0x60, 0x23, 0x60, 0x23, 0x5E, 0x22, 0x5E, 0x22, 0x60, 0x23, 0x5F, 0x21, 0x5E, 0x22, 0x5F, 0x21, 0x5E, 0x21, 0x5D, 0x22, 0x5D, 0x22, 0x5D, 0x22, 0x5E, 0x22, 0x5F, 0x22, 0x60, 0x22, 0x5F, 0x22, 0x5F, 0x21, 0x5E, 0x21, 0x5E, 0x21, 0x5F, 0x21, 0x60, 0x21, 0x60, 0x21, 0x60, 0x22, 0x60, 0x22, 0x60, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x5D, 0x21, 0x5C, 0x21, 0x5E, 0x21, 0x5D, 0x20, 0x5C, 0x20, 0x5D, 0x20, 0x5B, 0x20, 0x5D, 0x20, 0x5D, 0x21, 0x5F, 0x22, 0x5E, 0x21, 0x5D, 0x20, 0x5D, 0x20, 0x5E, 0x21, 0x5F, 0x21, 0x60, 0x22, 0x60, 0x22, 0x60, 0x20, 0x5F, 0x21, 0x5E, 0x21, 0x5C, 0x20, 0x5C, 0x20, 0x5C, 0x20, 0x5E, 0x21, 0x5D, 0x20, 0x5D, 0x21, 0x5D, 0x21, 0x5C, 0x20, 0x5B, 0x20, 0x5B, 0x20, 0x5D, 0x20, 0x5C, 0x20, 0x5D, 0x20, 0x5B, 0x20, 0x5A, 0x20, 0x5A, 0x20, 0x5D, 0x21, 0x5C, 0x20, 0x5B, 0x20, 0x5C, 0x1F, 0x59, 0x1F, 0x59, 0x20, 0x5B, 0x20, 0x59, 0x1F, 0x5B, 0x1F, 0x5A, 0x20, 0x5A, 0x21, 0x5B, 0x21, 0x59, 0x21, 0x58, 0x20, 0x5A, 0x21, 0x5B, 0x20, 0x5B, 0x20, 0x5B, 0x20, 0x5B, 0x20, 0x5C, 0x20, 0x5B, 0x20, 0x59, 0x20, 0x58, 0x1F, 0x58, 0x20, 0x54, 0x1F, 0x4A, 0x1E, 0x46, 0x1F, 0x44, 0x20, 0x45, 0x21, 0x46, 0x22, 0x45, 0x21, 0x43, 0x1F, 0x38, 0x19, 0x37, 0x18, 0x49, 0x1D, 0x56, 0x20, 0x58, 0x1F, 0x58, 0x1F, 0x57, 0x20, 0x59, 0x20, 0x59, 0x1F, 0x58, 0x1F, 0x57, 0x1F, 0x57, 0x1F, 0x58, 0x1F, 0x57, 0x1F, 0x55, 0x20, 0x56, 0x20, 0x59, 0x21, 0x57, 0x20, 0x59, 0x21, 0x59, 0x21, 0x5C, 0x21, 0x58, 0x20, 0x58, 0x20, 0x58, 0x1F, 0x59, 0x20, 0x58, 0x20, 0x56, 0x1F, 0x55, 0x1F, 0x56, 0x1F, 0x56, 0x1F, 0x57, 0x1F, 0x58, 0x20, 0x59, 0x1F, 0x57, 0x1F, 0x56, 0x1F, 0x55, 0x1F, 0x56, 0x1F, 0x56, 0x1F, 0x55, 0x1F, 0x55, 0x1F, 0x56, 0x1F, 0x53, 0x1F, 0x54, 0x1E, 0x55, 0x1E, 0x56, 0x1F, 0x55, 0x1F, 0x55, 0x1F, 0x54, 0x1E, 0x56, 0x1F, 0x57, 0x1F, 0x54, 0x1F, 0x53, 0x1F, 0x53, 0x1E, 0x53, 0x1F, 0x55, 0x1F, 0x56, 0x1F, 0x54, 0x1E, 0x53, 0x1E, 0x51, 0x1E, 0x54, 0x1F, 0x53, 0x1E, 0x51, 0x1D, 0x54, 0x1E, 0x52, 0x1E, 0x54, 0x1D, 0x52, 0x1D, 0x53, 0x1E, 0x54, 0x1E, 0x53, 0x1D, 0x55, 0x1F, 0x53, 0x1E, 0x51, 0x1E, 0x4E, 0x1D, 0x41, 0x19, 0x2C, 0x17, 0x25, 0x15, 0x29, 0x16, 0x25, 0x15, 0x25, 0x16, 0x23, 0x14, 0x25, 0x16, 0x29, 0x17, 0x23, 0x14, 0x25, 0x16, 0x21, 0x14, 0x2A, 0x17, 0x26, 0x16, 0x22, 0x15, 0x25, 0x16, 0x22, 0x15, 0x27, 0x17, 0x22, 0x14, 0x1E, 0x13, 0x23, 0x14, 0x21, 0x14, 0x25, 0x16, 0x20, 0x14, 0x27, 0x16, 0x20, 0x13, 0x26, 0x16, 0x22, 0x14, 0x20, 0x14, 0x22, 0x14, 0x22, 0x15, 0x22, 0x13, 0x1E, 0x14, 0x21, 0x14, 0x1F, 0x13, 0x24, 0x15, 0x22, 0x14, 0x24, 0x16, 0x24, 0x15, 0x25, 0x15, 0x28, 0x17, 0x26, 0x16, 0x23, 0x14
    },

    {
        0x51, 0x49, 0x50, 0x49, 0x51, 0x4A, 0x51, 0x49, 0x51, 0x49, 0x50, 0x48, 0x51, 0x48, 0x51, 0x48, 0x52, 0x49, 0x53, 0x49, 0x54, 0x4A, 0x54, 0x49, 0x54, 0x4A, 0x54, 0x4B, 0x54, 0x4A, 0x54, 0x4A, 0x54, 0x4B, 0x55, 0x4B, 0x54, 0x4B, 0x56, 0x4C, 0x57, 0x4E, 0x58, 0x4E, 0x58, 0x4E, 0x58, 0x4E, 0x57, 0x4C, 0x57, 0x4D, 0x56, 0x4C, 0x56, 0x4C, 0x56, 0x4C, 0x57, 0x4C, 0x57, 0x4D, 0x57, 0x4C, 0x57, 0x4E, 0x58, 0x4D, 0x58, 0x4E, 0x58, 0x4E, 0x58, 0x4E, 0x57, 0x4E, 0x58, 0x4E, 0x58, 0x4E, 0x58, 0x50, 0x5A, 0x51, 0x5B, 0x51, 0x5C, 0x52, 0x5D, 0x52, 0x5C, 0x52, 0x5D, 0x51, 0x5C, 0x52, 0x5C, 0x51, 0x5C, 0x51, 0x5B, 0x53, 0x5C, 0x51, 0x5B, 0x51, 0x59, 0x51, 0x58, 0x50, 0x56, 0x4F, 0x52, 0x4C, 0x4C, 0x45, 0x44, 0x3D, 0x3D, 0x3B, 0x40, 0x40, 0x48, 0x46, 0x48, 0x43, 0x41, 0x3C, 0x32, 0x2E, 0x22, 0x22, 0x1B, 0x1C, 0x17, 0x1A, 0x15, 0x18, 0x15, 0x19, 0x16, 0x1A, 0x15, 0x1A, 0x15, 0x18, 0x14, 0x18, 0x15, 0x18, 0x15, 0x18, 0x16, 0x18, 0x18, 0x1B, 0x1E, 0x22, 0x30, 0x35, 0x44, 0x45, 0x4D, 0x4A, 0x4E, 0x4A, 0x43, 0x3E, 0x38, 0x37, 0x43, 0x42, 0x50, 0x4E, 0x57, 0x52, 0x5B, 0x54, 0x5D, 0x55, 0x5D, 0x57, 0x60, 0x58, 0x60, 0x59, 0x62, 0x59, 0x61, 0x59, 0x63, 0x59, 0x61, 0x57, 0x62, 0x58, 0x63, 0x58, 0x62, 0x58, 0x62, 0x57, 0x62, 0x59, 0x63, 0x5A, 0x65, 0x5A, 0x63, 0x58, 0x62, 0x58, 0x63, 0x59, 0x62, 0x59, 0x63, 0x5A, 0x63, 0x59, 0x63, 0x58, 0x63, 0x58, 0x65, 0x5A, 0x65, 0x59, 0x63, 0x58, 0x62, 0x58, 0x62, 0x58, 0x62, 0x57, 0x61, 0x57, 0x61, 0x58, 0x61, 0x57, 0x62, 0x58, 0x63, 0x59, 0x63, 0x5A, 0x63, 0x59, 0x63, 0x58, 0x64, 0x58, 0x64, 0x5B, 0x65, 0x59, 0x64, 0x5A, 0x65, 0x5A, 0x64, 0x5A, 0x64, 0x59, 0x64, 0x5A, 0x64, 0x5A, 0x64, 0x59, 0x62, 0x56, 0x61, 0x57, 0x63, 0x57, 0x61, 0x56, 0x62, 0x55, 0x62, 0x56, 0x62, 0x55, 0x61, 0x56, 0x62, 0x57, 0x64, 0x57, 0x62, 0x57, 0x62, 0x58, 0x63, 0x57, 0x64, 0x59, 0x64, 0x59, 0x65, 0x5B, 0x64, 0x5A, 0x64, 0x59, 0x63, 0x59, 0x62, 0x58, 0x61, 0x56, 0x63, 0x57, 0x60, 0x55, 0x61, 0x56, 0x62, 0x57, 0x61, 0x57, 0x62, 0x56, 0x5F, 0x55, 0x5F, 0x55, 0x5F, 0x55, 0x61, 0x57, 0x61, 0x56, 0x61, 0x55, 0x5F, 0x56, 0x5E, 0x54, 0x60, 0x55, 0x61, 0x56, 0x61, 0x56, 0x60, 0x55, 0x60, 0x56, 0x5F, 0x54, 0x5F, 0x54, 0x60, 0x54, 0x5E, 0x52, 0x5F, 0x54, 0x5D, 0x54, 0x5D, 0x55, 0x5C, 0x55, 0x5C, 0x52, 0x5B, 0x52, 0x5D, 0x54, 0x5D, 0x54, 0x5F, 0x56, 0x60, 0x55, 0x5E, 0x54, 0x5F, 0x56, 0x5F, 0x55, 0x5C, 0x53, 0x5C, 0x53, 0x5D, 0x53, 0x58, 0x4E, 0x4B, 0x44, 0x43, 0x42, 0x3F, 0x40, 0x3E, 0x42, 0x3D, 0x41, 0x3D, 0x40, 0x3A, 0x3D, 0x34, 0x31, 0x37, 0x36, 0x4C, 0x48, 0x57, 0x51, 0x5A, 0x52, 0x5C, 0x52, 0x5C, 0x54, 0x5D, 0x54, 0x5E, 0x53, 0x5C, 0x52, 0x5C, 0x52, 0x5D, 0x53, 0x5C, 0x52, 0x5B, 0x52, 0x5B, 0x51, 0x5A, 0x52, 0x5D, 0x55, 0x5C, 0x52, 0x5D, 0x54, 0x5D, 0x55, 0x5F, 0x54, 0x5D, 0x54, 0x5E, 0x54, 0x5C, 0x53, 0x5D, 0x53, 0x5A, 0x52, 0x5A, 0x50, 0x59, 0x50, 0x5A, 0x51, 0x5A, 0x51, 0x5B, 0x53, 0x5D, 0x53, 0x5C, 0x54, 0x5C, 0x52, 0x5B, 0x51, 0x58, 0x50, 0x5A, 0x51, 0x5B, 0x51, 0x5A, 0x52, 0x57, 0x50, 0x59, 0x51, 0x59, 0x4F, 0x58, 0x4F, 0x58, 0x4F, 0x5A, 0x51, 0x5A, 0x50, 0x59, 0x50, 0x59, 0x52, 0x5A, 0x51, 0x5B, 0x51, 0x59, 0x50, 0x57, 0x4E, 0x57, 0x4E, 0x59, 0x4F, 0x59, 0x51, 0x59, 0x50, 0x57, 0x4F, 0x57, 0x4F, 0x57, 0x4E, 0x58, 0x4F, 0x57, 0x4D, 0x56, 0x4D, 0x5A, 0x50, 0x58, 0x4F, 0x58, 0x4E, 0x59, 0x4F, 0x5A, 0x50, 0x59, 0x4F, 0x57, 0x4D, 0x59, 0x51, 0x58, 0x4F, 0x57, 0x4C, 0x53, 0x4A, 0x42, 0x3A, 0x2C, 0x29, 0x24, 0x25, 0x24, 0x26, 0x20, 0x23, 0x20, 0x22, 0x1F, 0x21, 0x21, 0x25, 0x23, 0x25, 0x1D, 0x1F, 0x20, 0x22, 0x1D, 0x1F, 0x24, 0x28, 0x20, 0x21, 0x1D, 0x20, 0x20, 0x24, 0x1E, 0x1F, 0x22, 0x25, 0x1E, 0x1E, 0x1B, 0x1E, 0x1F, 0x20, 0x1E, 0x21, 0x20, 0x21, 0x1B, 0x1D, 0x22, 0x24, 0x1D, 0x1E, 0x21, 0x24, 0x1D, 0x1E, 0x1D, 0x21, 0x1E, 0x1F, 0x1F, 0x21, 0x1D, 0x1E, 0x1D, 0x1F, 0x1D, 0x1E, 0x1D, 0x1F, 0x20, 0x23, 0x1E, 0x21, 0x20, 0x24, 0x22, 0x25, 0x20, 0x23, 0x23, 0x26, 0x21, 0x24, 0x1F, 0x21
    },

    {
        0x4D, 0x1B, 0x4C, 0x1B, 0x4D, 0x1B, 0x4D, 0x1B, 0x4C, 0x1B, 0x4C, 0x1B, 0x4A, 0x1B, 0x4B, 0x1B, 0x4B, 0x1B, 0x4D, 0x1B, 0x4D, 0x1B, 0x4E, 0x1B, 0x4D, 0x1B, 0x4E, 0x1B, 0x4F, 0x1C, 0x4E, 0x1B, 0x4E, 0x1C, 0x4E, 0x1C, 0x4F, 0x1C, 0x4F, 0x1B, 0x4F, 0x1C, 0x51, 0x1C, 0x50, 0x1D, 0x51, 0x1D, 0x50, 0x1D, 0x50, 0x1D, 0x50, 0x1D, 0x50, 0x1D, 0x50, 0x1D, 0x52, 0x1D, 0x51, 0x1D, 0x51, 0x1D, 0x50, 0x1D, 0x51, 0x1D, 0x52, 0x1E, 0x53, 0x1E, 0x53, 0x1E, 0x53, 0x1E, 0x53, 0x1F, 0x53, 0x1F, 0x54, 0x1F, 0x54, 0x1E, 0x57, 0x1F, 0x55, 0x1F, 0x55, 0x1F, 0x56, 0x1F, 0x56, 0x20, 0x56, 0x1F, 0x56, 0x20, 0x55, 0x20, 0x57, 0x20, 0x56, 0x20, 0x56, 0x1F, 0x56, 0x20, 0x55, 0x20, 0x53, 0x1F, 0x4D, 0x1E, 0x45, 0x1C, 0x3E, 0x1B, 0x3F, 0x1B, 0x48, 0x1D, 0x4A, 0x1D, 0x44, 0x1B, 0x37, 0x18, 0x29, 0x15, 0x20, 0x13, 0x1C, 0x12, 0x1A, 0x11, 0x19, 0x13, 0x1C, 0x17, 0x21, 0x1E, 0x22, 0x1D, 0x1E, 0x19, 0x1B, 0x15, 0x1A, 0x13, 0x1A, 0x12, 0x1A, 0x13, 0x1B, 0x12, 0x1D, 0x13, 0x25, 0x15, 0x38, 0x1B, 0x49, 0x1D, 0x50, 0x1F, 0x50, 0x1E, 0x42, 0x1B, 0x3A, 0x1B, 0x45, 0x1E, 0x51, 0x20, 0x57, 0x20, 0x59, 0x20, 0x5B, 0x22, 0x5C, 0x22, 0x5D, 0x22, 0x5E, 0x22, 0x5E, 0x22, 0x5D, 0x22, 0x5D, 0x22, 0x5C, 0x22, 0x5E, 0x22, 0x5E, 0x22, 0x5D, 0x22, 0x5E, 0x22, 0x5F, 0x23, 0x5E, 0x22, 0x5D, 0x22, 0x5E, 0x22, 0x5F, 0x22, 0x60, 0x22, 0x60, 0x23, 0x5E, 0x23, 0x5D, 0x22, 0x5E, 0x22, 0x5E, 0x22, 0x5E, 0x21, 0x60, 0x21, 0x5F, 0x21, 0x5E, 0x21, 0x5D, 0x21, 0x5D, 0x21, 0x5E, 0x22, 0x5F, 0x22, 0x5E, 0x22, 0x5F, 0x22, 0x60, 0x22, 0x5F, 0x21, 0x5E, 0x22, 0x5E, 0x21, 0x5E, 0x21, 0x60, 0x22, 0x60, 0x22, 0x60, 0x22, 0x61, 0x22, 0x60, 0x22, 0x5E, 0x21, 0x5F, 0x22, 0x60, 0x22, 0x61, 0x22, 0x5F, 0x22, 0x5F, 0x21, 0x5D, 0x20, 0x5D, 0x20, 0x5D, 0x21, 0x5B, 0x20, 0x5B, 0x20, 0x5D, 0x20, 0x5B, 0x21, 0x5D, 0x21, 0x5D, 0x20, 0x5E, 0x21, 0x5D, 0x20, 0x5F, 0x21, 0x63, 0x21, 0x60, 0x21, 0x61, 0x21, 0x5F, 0x21, 0x5F, 0x22, 0x5E, 0x21, 0x5E, 0x21, 0x5D, 0x20, 0x5C, 0x20, 0x5D, 0x21, 0x5E, 0x21, 0x5F, 0x21, 0x5D, 0x21, 0x5C, 0x21, 0x5A, 0x20, 0x5C, 0x20, 0x5C, 0x20, 0x5B, 0x20, 0x5B, 0x20, 0x5A, 0x21, 0x5B, 0x20, 0x5C, 0x21, 0x5C, 0x20, 0x5B, 0x20, 0x5C, 0x20, 0x5A, 0x1F, 0x5C, 0x20, 0x5C, 0x20, 0x5B, 0x20, 0x5B, 0x20, 0x5B, 0x22, 0x5E, 0x25, 0x5B, 0x25, 0x59, 0x23, 0x56, 0x21, 0x57, 0x20, 0x5A, 0x20, 0x5A, 0x20, 0x5B, 0x20, 0x5A, 0x20, 0x5A, 0x20, 0x5B, 0x21, 0x5B, 0x20, 0x5A, 0x20, 0x59, 0x20, 0x58, 0x1F, 0x4C, 0x1D, 0x45, 0x1F, 0x44, 0x20, 0x43, 0x21, 0x44, 0x20, 0x42, 0x1F, 0x3B, 0x1B, 0x30, 0x16, 0x37, 0x18, 0x4B, 0x1D, 0x57, 0x20, 0x58, 0x1F, 0x57, 0x1F, 0x58, 0x20, 0x5A, 0x20, 0x58, 0x1F, 0x58, 0x1F, 0x5A, 0x20, 0x58, 0x1F, 0x57, 0x1F, 0x56, 0x1F, 0x57, 0x21, 0x59, 0x22, 0x59, 0x22, 0x57, 0x20, 0x5A, 0x20, 0x59, 0x21, 0x5A, 0x20, 0x59, 0x20, 0x5A, 0x20, 0x59, 0x1F, 0x59, 0x1F, 0x57, 0x1F, 0x55, 0x1F, 0x55, 0x1E, 0x56, 0x1E, 0x57, 0x1F, 0x57, 0x1F, 0x58, 0x20, 0x59, 0x20, 0x56, 0x1F, 0x55, 0x1F, 0x55, 0x1F, 0x56, 0x20, 0x57, 0x1F, 0x57, 0x20, 0x56, 0x1F, 0x55, 0x1F, 0x54, 0x1E, 0x54, 0x1E, 0x53, 0x1F, 0x57, 0x1F, 0x56, 0x1F, 0x55, 0x1F, 0x56, 0x1F, 0x57, 0x1F, 0x57, 0x1F, 0x55, 0x1E, 0x52, 0x1F, 0x54, 0x1F, 0x55, 0x1F, 0x54, 0x1F, 0x52, 0x1E, 0x52, 0x1E, 0x53, 0x1E, 0x52, 0x1E, 0x52, 0x1E, 0x52, 0x1D, 0x51, 0x1D, 0x54, 0x1E, 0x52, 0x1D, 0x51, 0x1D, 0x53, 0x1D, 0x52, 0x1D, 0x53, 0x1D, 0x52, 0x1C, 0x52, 0x1E, 0x54, 0x1E, 0x51, 0x1D, 0x50, 0x1D, 0x43, 0x1B, 0x2F, 0x17, 0x27, 0x17, 0x26, 0x16, 0x21, 0x14, 0x22, 0x15, 0x23, 0x15, 0x25, 0x15, 0x23, 0x14, 0x20, 0x14, 0x26, 0x16, 0x25, 0x16, 0x26, 0x16, 0x23, 0x15, 0x26, 0x16, 0x29, 0x17, 0x25, 0x16, 0x27, 0x16, 0x23, 0x15, 0x26, 0x16, 0x27, 0x15, 0x24, 0x15, 0x25, 0x15, 0x23, 0x15, 0x25, 0x16, 0x25, 0x16, 0x23, 0x15, 0x23, 0x14, 0x27, 0x16, 0x23, 0x15, 0x23, 0x14, 0x25, 0x16, 0x25, 0x16, 0x24, 0x15, 0x27, 0x16, 0x24, 0x15, 0x25, 0x16, 0x2B, 0x18, 0x26, 0x15, 0x23, 0x14, 0x20, 0x14, 0x25, 0x15, 0x23, 0x15
    },

    {
        0x52, 0x4A, 0x52, 0x49, 0x51, 0x4A, 0x51, 0x49, 0x51, 0x49, 0x51, 0x49, 0x50, 0x48, 0x51, 0x48, 0x51, 0x48, 0x52, 0x49, 0x54, 0x4A, 0x55, 0x4A, 0x53, 0x49, 0x54, 0x4B, 0x54, 0x4B, 0x54, 0x4B, 0x54, 0x4A, 0x55, 0x4B, 0x55, 0x4B, 0x54, 0x4A, 0x56, 0x4C, 0x56, 0x4C, 0x57, 0x4D, 0x57, 0x4D, 0x57, 0x4C, 0x56, 0x4B, 0x56, 0x4C, 0x56, 0x4D, 0x57, 0x4C, 0x58, 0x4D, 0x58, 0x4D, 0x58, 0x4D, 0x57, 0x4E, 0x58, 0x4E, 0x58, 0x4E, 0x58, 0x4E, 0x59, 0x4E, 0x58, 0x4F, 0x58, 0x4E, 0x58, 0x4F, 0x59, 0x51, 0x5A, 0x51, 0x5C, 0x51, 0x5C, 0x51, 0x5B, 0x51, 0x5C, 0x53, 0x5C, 0x53, 0x5D, 0x52, 0x5C, 0x53, 0x5B, 0x52, 0x5C, 0x53, 0x5C, 0x52, 0x5B, 0x51, 0x5A, 0x51, 0x57, 0x50, 0x53, 0x4B, 0x4E, 0x47, 0x45, 0x3F, 0x3E, 0x3A, 0x3F, 0x3F, 0x49, 0x46, 0x4A, 0x44, 0x41, 0x3D, 0x33, 0x2F, 0x23, 0x23, 0x1B, 0x1C, 0x18, 0x1A, 0x15, 0x18, 0x15, 0x19, 0x17, 0x1D, 0x1B, 0x22, 0x1C, 0x23, 0x1B, 0x1F, 0x18, 0x1B, 0x16, 0x19, 0x16, 0x19, 0x16, 0x19, 0x16, 0x19, 0x18, 0x1A, 0x1C, 0x20, 0x2E, 0x33, 0x42, 0x43, 0x4D, 0x4C, 0x50, 0x4C, 0x43, 0x3F, 0x38, 0x36, 0x40, 0x40, 0x4E, 0x4C, 0x57, 0x52, 0x5B, 0x53, 0x5D, 0x55, 0x5D, 0x56, 0x60, 0x58, 0x61, 0x59, 0x61, 0x58, 0x61, 0x57, 0x60, 0x57, 0x61, 0x58, 0x63, 0x5A, 0x63, 0x58, 0x64, 0x59, 0x63, 0x59, 0x65, 0x5A, 0x63, 0x58, 0x61, 0x57, 0x61, 0x58, 0x62, 0x58, 0x63, 0x59, 0x63, 0x59, 0x61, 0x58, 0x60, 0x57, 0x62, 0x58, 0x63, 0x58, 0x63, 0x58, 0x64, 0x59, 0x63, 0x59, 0x61, 0x57, 0x61, 0x56, 0x62, 0x57, 0x60, 0x57, 0x61, 0x57, 0x60, 0x58, 0x62, 0x59, 0x63, 0x5A, 0x63, 0x59, 0x63, 0x59, 0x64, 0x58, 0x64, 0x58, 0x65, 0x59, 0x65, 0x5A, 0x66, 0x5A, 0x65, 0x5B, 0x65, 0x59, 0x63, 0x59, 0x64, 0x58, 0x64, 0x59, 0x66, 0x5A, 0x64, 0x58, 0x62, 0x58, 0x62, 0x57, 0x63, 0x57, 0x63, 0x57, 0x61, 0x55, 0x60, 0x55, 0x62, 0x57, 0x61, 0x56, 0x62, 0x56, 0x62, 0x58, 0x62, 0x56, 0x61, 0x57, 0x64, 0x59, 0x67, 0x5B, 0x65, 0x5A, 0x65, 0x5A, 0x64, 0x59, 0x64, 0x5A, 0x63, 0x58, 0x64, 0x58, 0x62, 0x57, 0x61, 0x57, 0x62, 0x56, 0x62, 0x59, 0x62, 0x58, 0x62, 0x57, 0x60, 0x55, 0x5F, 0x55, 0x61, 0x55, 0x60, 0x55, 0x5F, 0x55, 0x5F, 0x54, 0x60, 0x55, 0x5F, 0x56, 0x60, 0x55, 0x60, 0x56, 0x5F, 0x54, 0x5F, 0x56, 0x5F, 0x55, 0x60, 0x55, 0x5F, 0x54, 0x5F, 0x54, 0x60, 0x55, 0x5D, 0x55, 0x5D, 0x58, 0x59, 0x53, 0x56, 0x50, 0x55, 0x4E, 0x59, 0x51, 0x5C, 0x53, 0x5C, 0x53, 0x5F, 0x55, 0x5D, 0x54, 0x5D, 0x54, 0x5E, 0x55, 0x5D, 0x55, 0x5E, 0x54, 0x5F, 0x55, 0x5A, 0x51, 0x4D, 0x45, 0x42, 0x40, 0x3E, 0x3F, 0x3C, 0x3F, 0x3B, 0x3E, 0x3A, 0x3C, 0x34, 0x34, 0x2E, 0x2A, 0x38, 0x37, 0x4C, 0x49, 0x59, 0x53, 0x5B, 0x52, 0x5B, 0x52, 0x5B, 0x53, 0x5D, 0x54, 0x5C, 0x54, 0x5C, 0x53, 0x5E, 0x54, 0x5C, 0x52, 0x5C, 0x51, 0x5B, 0x51, 0x5A, 0x51, 0x5B, 0x54, 0x5C, 0x53, 0x5B, 0x52, 0x5E, 0x54, 0x5E, 0x54, 0x5F, 0x54, 0x5D, 0x54, 0x5D, 0x54, 0x5C, 0x54, 0x5C, 0x54, 0x5B, 0x52, 0x5B, 0x51, 0x5A, 0x51, 0x5C, 0x51, 0x5A, 0x51, 0x5A, 0x51, 0x5D, 0x53, 0x5C, 0x53, 0x5C, 0x51, 0x5A, 0x50, 0x58, 0x50, 0x5A, 0x52, 0x5B, 0x52, 0x5A, 0x52, 0x59, 0x50, 0x59, 0x51, 0x59, 0x50, 0x5A, 0x4F, 0x58, 0x50, 0x5A, 0x52, 0x59, 0x51, 0x5B, 0x52, 0x5B, 0x52, 0x5B, 0x52, 0x5C, 0x53, 0x58, 0x4F, 0x56, 0x4F, 0x59, 0x50, 0x59, 0x50, 0x59, 0x50, 0x57, 0x4D, 0x56, 0x4E, 0x56, 0x4E, 0x56, 0x4E, 0x56, 0x4E, 0x57, 0x4F, 0x57, 0x4D, 0x5A, 0x50, 0x58, 0x4F, 0x59, 0x4E, 0x58, 0x4E, 0x57, 0x4D, 0x57, 0x4E, 0x56, 0x4E, 0x56, 0x4F, 0x58, 0x4E, 0x57, 0x4D, 0x55, 0x4C, 0x43, 0x3C, 0x2C, 0x29, 0x25, 0x26, 0x22, 0x22, 0x1D, 0x1E, 0x1F, 0x23, 0x1E, 0x23, 0x20, 0x22, 0x1E, 0x20, 0x1E, 0x20, 0x22, 0x26, 0x21, 0x24, 0x20, 0x22, 0x20, 0x23, 0x23, 0x28, 0x23, 0x27, 0x22, 0x27, 0x22, 0x23, 0x21, 0x24, 0x23, 0x26, 0x22, 0x25, 0x20, 0x21, 0x21, 0x23, 0x20, 0x22, 0x21, 0x24, 0x20, 0x25, 0x1F, 0x21, 0x21, 0x23, 0x22, 0x26, 0x20, 0x22, 0x1E, 0x21, 0x21, 0x25, 0x22, 0x24, 0x20, 0x23, 0x22, 0x25, 0x1F, 0x21, 0x22, 0x25, 0x24, 0x27, 0x20, 0x22, 0x1E, 0x20, 0x1D, 0x20, 0x20, 0x22, 0x1F, 0x22
    },

    {
        0x4D, 0x1B, 0x4C, 0x1B, 0x4C, 0x1B, 0x4C, 0x1B, 0x4C, 0x1B, 0x4C, 0x1C, 0x4A, 0x1B, 0x4B, 0x1A, 0x4B, 0x1A, 0x4C, 0x1B, 0x4D, 0x1C, 0x4D, 0x1C, 0x4D, 0x1B, 0x4E, 0x1B, 0x4E, 0x1C, 0x4D, 0x1B, 0x4E, 0x1B, 0x4E, 0x1C, 0x4F, 0x1C, 0x4F, 0x1C, 0x4F, 0x1C, 0x4F, 0x1D, 0x4F, 0x1C, 0x4F, 0x1C, 0x4F, 0x1C, 0x4F, 0x1C, 0x4F, 0x1D, 0x4F, 0x1D, 0x51, 0x1D, 0x51, 0x1D, 0x51, 0x1D, 0x52, 0x1D, 0x51, 0x1D, 0x52, 0x1E, 0x52, 0x1E, 0x52, 0x1E, 0x52, 0x1E, 0x53, 0x1E, 0x52, 0x1E, 0x52, 0x1E, 0x54, 0x1E, 0x55, 0x1F, 0x54, 0x1F, 0x55, 0x1F, 0x56, 0x1F, 0x56, 0x1F, 0x57, 0x20, 0x56, 0x20, 0x56, 0x20, 0x56, 0x20, 0x57, 0x20, 0x56, 0x20, 0x56, 0x20, 0x56, 0x20, 0x52, 0x1F, 0x4E, 0x1E, 0x46, 0x1D, 0x3E, 0x1B, 0x3D, 0x1B, 0x47, 0x1D, 0x4A, 0x1D, 0x45, 0x1C, 0x38, 0x18, 0x2A, 0x15, 0x20, 0x12, 0x1C, 0x11, 0x1A, 0x11, 0x19, 0x12, 0x1B, 0x17, 0x22, 0x20, 0x2B, 0x2B, 0x33, 0x32, 0x2E, 0x29, 0x23, 0x1D, 0x1D, 0x17, 0x1B, 0x14, 0x1A, 0x13, 0x1A, 0x12, 0x1B, 0x12, 0x1D, 0x12, 0x23, 0x15, 0x38, 0x1A, 0x48, 0x1D, 0x50, 0x1F, 0x51, 0x1F, 0x43, 0x1C, 0x38, 0x1B, 0x43, 0x1E, 0x51, 0x20, 0x55, 0x20, 0x58, 0x21, 0x5B, 0x21, 0x5C, 0x21, 0x5B, 0x22, 0x5D, 0x21, 0x5D, 0x22, 0x5C, 0x23, 0x5D, 0x22, 0x5F, 0x23, 0x5E, 0x22, 0x5E, 0x22, 0x5E, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x5E, 0x23, 0x5E, 0x22, 0x5D, 0x22, 0x5F, 0x22, 0x5F, 0x23, 0x5E, 0x22, 0x5C, 0x21, 0x5D, 0x21, 0x5E, 0x22, 0x5E, 0x21, 0x5E, 0x21, 0x5E, 0x22, 0x5C, 0x21, 0x5D, 0x21, 0x5C, 0x22, 0x5F, 0x22, 0x5F, 0x23, 0x5D, 0x22, 0x5D, 0x22, 0x5E, 0x22, 0x61, 0x22, 0x5F, 0x22, 0x5F, 0x21, 0x5F, 0x22, 0x61, 0x22, 0x61, 0x22, 0x61, 0x22, 0x61, 0x23, 0x60, 0x22, 0x5F, 0x22, 0x5E, 0x22, 0x5F, 0x22, 0x60, 0x23, 0x61, 0x22, 0x5E, 0x22, 0x5E, 0x21, 0x5E, 0x20, 0x5C, 0x20, 0x5C, 0x20, 0x5B, 0x20, 0x5C, 0x20, 0x5C, 0x21, 0x5D, 0x21, 0x5E, 0x20, 0x5D, 0x20, 0x5D, 0x20, 0x5D, 0x21, 0x5E, 0x21, 0x60, 0x22, 0x60, 0x21, 0x60, 0x22, 0x60, 0x22, 0x60, 0x21, 0x5E, 0x22, 0x5D, 0x20, 0x5C, 0x20, 0x5D, 0x21, 0x5C, 0x21, 0x5E, 0x21, 0x5D, 0x21, 0x5C, 0x21, 0x5B, 0x21, 0x5A, 0x20, 0x5C, 0x20, 0x5A, 0x20, 0x5A, 0x21, 0x5C, 0x21, 0x5C, 0x21, 0x5B, 0x20, 0x5A, 0x20, 0x59, 0x1F, 0x5A, 0x20, 0x5A, 0x20, 0x5A, 0x1F, 0x5A, 0x20, 0x5B, 0x20, 0x5C, 0x22, 0x5F, 0x28, 0x60, 0x2D, 0x5C, 0x2B, 0x52, 0x27, 0x4B, 0x20, 0x4D, 0x1F, 0x55, 0x1F, 0x57, 0x20, 0x59, 0x20, 0x5B, 0x20, 0x5C, 0x20, 0x5B, 0x20, 0x5B, 0x21, 0x5B, 0x21, 0x5A, 0x20, 0x57, 0x1F, 0x4D, 0x1D, 0x43, 0x1C, 0x40, 0x1D, 0x3F, 0x1D, 0x3E, 0x1D, 0x3A, 0x1B, 0x2F, 0x15, 0x2B, 0x15, 0x3C, 0x1A, 0x4F, 0x1E, 0x57, 0x20, 0x59, 0x20, 0x59, 0x20, 0x59, 0x20, 0x58, 0x1F, 0x59, 0x20, 0x57, 0x20, 0x58, 0x1F, 0x58, 0x20, 0x56, 0x1F, 0x56, 0x1F, 0x58, 0x21, 0x5B, 0x22, 0x5C, 0x21, 0x58, 0x21, 0x58, 0x20, 0x58, 0x20, 0x57, 0x20, 0x59, 0x20, 0x5A, 0x21, 0x59, 0x21, 0x5B, 0x21, 0x58, 0x20, 0x57, 0x20, 0x57, 0x20, 0x57, 0x1F, 0x58, 0x1F, 0x56, 0x1F, 0x55, 0x1F, 0x56, 0x1E, 0x56, 0x1F, 0x56, 0x1F, 0x54, 0x1F, 0x54, 0x1F, 0x56, 0x1F, 0x56, 0x20, 0x55, 0x1F, 0x55, 0x1F, 0x56, 0x1F, 0x56, 0x1F, 0x57, 0x20, 0x58, 0x20, 0x57, 0x20, 0x55, 0x1F, 0x57, 0x1F, 0x57, 0x1F, 0x57, 0x1F, 0x56, 0x1F, 0x54, 0x1E, 0x54, 0x1F, 0x54, 0x1F, 0x54, 0x1F, 0x52, 0x1E, 0x52, 0x1E, 0x52, 0x1E, 0x53, 0x1E, 0x52, 0x1E, 0x55, 0x1E, 0x54, 0x1E, 0x55, 0x1E, 0x53, 0x1E, 0x54, 0x1E, 0x54, 0x1E, 0x52, 0x1E, 0x52, 0x1D, 0x52, 0x1E, 0x52, 0x1E, 0x52, 0x1E, 0x52, 0x1E, 0x52, 0x1D, 0x40, 0x1A, 0x2F, 0x19, 0x29, 0x16, 0x23, 0x15, 0x26, 0x17, 0x2B, 0x18, 0x29, 0x17, 0x25, 0x15, 0x24, 0x15, 0x27, 0x17, 0x27, 0x17, 0x27, 0x16, 0x22, 0x16, 0x29, 0x18, 0x28, 0x17, 0x23, 0x15, 0x26, 0x17, 0x23, 0x14, 0x28, 0x16, 0x26, 0x16, 0x24, 0x15, 0x23, 0x15, 0x22, 0x15, 0x28, 0x17, 0x25, 0x15, 0x29, 0x15, 0x20, 0x14, 0x2A, 0x17, 0x25, 0x15, 0x22, 0x16, 0x25, 0x15, 0x26, 0x16, 0x24, 0x15, 0x22, 0x15, 0x26, 0x15, 0x24, 0x15, 0x29, 0x17, 0x22, 0x14, 0x21, 0x14, 0x21, 0x13, 0x23, 0x15, 0x22, 0x14, 0x1F, 0x13
    },

    {
        0x52, 0x49, 0x51, 0x48, 0x52, 0x4A, 0x52, 0x48, 0x52, 0x49, 0x51, 0x48, 0x52, 0x47, 0x51, 0x48, 0x51, 0x47, 0x52, 0x48, 0x53, 0x49, 0x54, 0x49, 0x54, 0x4A, 0x54, 0x4A, 0x55, 0x4A, 0x54, 0x49, 0x55, 0x4A, 0x55, 0x4B, 0x56, 0x4B, 0x55, 0x4B, 0x55, 0x4B, 0x55, 0x4B, 0x56, 0x4C, 0x56, 0x4C, 0x55, 0x4B, 0x56, 0x4B, 0x56, 0x4B, 0x55, 0x4B, 0x56, 0x4C, 0x57, 0x4D, 0x57, 0x4D, 0x59, 0x4E, 0x59, 0x4E, 0x57, 0x4F, 0x58, 0x4E, 0x57, 0x4E, 0x58, 0x4E, 0x58, 0x4E, 0x59, 0x4E, 0x58, 0x4D, 0x5A, 0x50, 0x5A, 0x50, 0x5A, 0x50, 0x5B, 0x50, 0x5B, 0x50, 0x5C, 0x52, 0x5C, 0x53, 0x5C, 0x51, 0x5C, 0x52, 0x5B, 0x51, 0x5C, 0x52, 0x5B, 0x52, 0x5A, 0x52, 0x59, 0x51, 0x54, 0x4D, 0x4E, 0x47, 0x46, 0x3F, 0x3E, 0x3A, 0x3F, 0x3E, 0x48, 0x46, 0x4A, 0x46, 0x43, 0x3D, 0x35, 0x30, 0x25, 0x23, 0x1C, 0x1C, 0x17, 0x19, 0x16, 0x18, 0x15, 0x18, 0x16, 0x1B, 0x1C, 0x23, 0x24, 0x2E, 0x2A, 0x35, 0x27, 0x2D, 0x20, 0x22, 0x19, 0x1C, 0x16, 0x19, 0x16, 0x19, 0x15, 0x18, 0x16, 0x19, 0x17, 0x1A, 0x1B, 0x1F, 0x2D, 0x32, 0x41, 0x43, 0x4C, 0x4A, 0x51, 0x4C, 0x47, 0x41, 0x38, 0x35, 0x3E, 0x3D, 0x4E, 0x4A, 0x56, 0x50, 0x59, 0x53, 0x5C, 0x55, 0x5F, 0x56, 0x60, 0x56, 0x60, 0x57, 0x61, 0x58, 0x60, 0x57, 0x61, 0x58, 0x62, 0x59, 0x63, 0x59, 0x64, 0x59, 0x64, 0x59, 0x64, 0x59, 0x64, 0x59, 0x63, 0x5A, 0x62, 0x59, 0x61, 0x58, 0x62, 0x58, 0x63, 0x5A, 0x62, 0x59, 0x60, 0x58, 0x62, 0x57, 0x62, 0x58, 0x63, 0x58, 0x63, 0x58, 0x63, 0x58, 0x62, 0x57, 0x61, 0x56, 0x61, 0x56, 0x62, 0x58, 0x62, 0x58, 0x60, 0x57, 0x60, 0x56, 0x62, 0x59, 0x64, 0x59, 0x65, 0x59, 0x63, 0x59, 0x65, 0x59, 0x65, 0x5A, 0x67, 0x5A, 0x66, 0x59, 0x65, 0x5B, 0x65, 0x5C, 0x63, 0x58, 0x63, 0x58, 0x64, 0x5A, 0x65, 0x5B, 0x65, 0x5B, 0x64, 0x58, 0x63, 0x58, 0x63, 0x57, 0x62, 0x56, 0x61, 0x55, 0x60, 0x55, 0x61, 0x56, 0x62, 0x56, 0x62, 0x57, 0x64, 0x58, 0x62, 0x57, 0x61, 0x56, 0x62, 0x57, 0x63, 0x5A, 0x64, 0x5A, 0x65, 0x59, 0x64, 0x5A, 0x65, 0x5A, 0x65, 0x59, 0x63, 0x58, 0x61, 0x56, 0x61, 0x55, 0x62, 0x57, 0x61, 0x56, 0x63, 0x59, 0x63, 0x58, 0x61, 0x56, 0x5F, 0x56, 0x5F, 0x55, 0x5F, 0x54, 0x5F, 0x54, 0x5F, 0x55, 0x60, 0x56, 0x5F, 0x54, 0x60, 0x55, 0x5F, 0x55, 0x60, 0x55, 0x5E, 0x54, 0x5D, 0x53, 0x5E, 0x53, 0x5F, 0x53, 0x5F, 0x54, 0x60, 0x57, 0x5F, 0x5A, 0x5A, 0x5A, 0x53, 0x51, 0x4B, 0x48, 0x46, 0x41, 0x4B, 0x45, 0x54, 0x4D, 0x59, 0x51, 0x5B, 0x53, 0x5E, 0x55, 0x5E, 0x55, 0x5E, 0x55, 0x60, 0x55, 0x60, 0x56, 0x5F, 0x54, 0x5A, 0x52, 0x50, 0x48, 0x41, 0x3D, 0x3B, 0x39, 0x3A, 0x39, 0x36, 0x37, 0x34, 0x32, 0x2D, 0x29, 0x2D, 0x2C, 0x3F, 0x3E, 0x51, 0x4C, 0x5A, 0x52, 0x5D, 0x53, 0x5D, 0x54, 0x5C, 0x53, 0x5C, 0x52, 0x5D, 0x53, 0x5C, 0x52, 0x5D, 0x52, 0x5D, 0x52, 0x5B, 0x52, 0x5C, 0x53, 0x5D, 0x54, 0x5E, 0x55, 0x5E, 0x55, 0x5D, 0x54, 0x5D, 0x54, 0x5D, 0x53, 0x5D, 0x52, 0x5F, 0x54, 0x5D, 0x55, 0x5D, 0x54, 0x5E, 0x55, 0x5C, 0x53, 0x5D, 0x54, 0x5C, 0x53, 0x5C, 0x52, 0x5D, 0x52, 0x59, 0x50, 0x5A, 0x51, 0x5B, 0x50, 0x5A, 0x50, 0x5B, 0x50, 0x59, 0x50, 0x59, 0x50, 0x5B, 0x52, 0x5A, 0x52, 0x5A, 0x50, 0x59, 0x50, 0x5A, 0x52, 0x5A, 0x50, 0x5B, 0x54, 0x5C, 0x53, 0x5B, 0x52, 0x5A, 0x50, 0x5C, 0x53, 0x5B, 0x51, 0x5C, 0x54, 0x5A, 0x51, 0x58, 0x4E, 0x59, 0x50, 0x5A, 0x50, 0x5A, 0x51, 0x56, 0x4D, 0x58, 0x4F, 0x58, 0x4E, 0x58, 0x4E, 0x57, 0x4D, 0x59, 0x51, 0x5A, 0x50, 0x5B, 0x51, 0x59, 0x4F, 0x59, 0x50, 0x59, 0x51, 0x57, 0x4E, 0x56, 0x4E, 0x55, 0x4D, 0x57, 0x4F, 0x57, 0x4E, 0x56, 0x4D, 0x55, 0x4C, 0x41, 0x39, 0x2F, 0x2D, 0x26, 0x23, 0x20, 0x23, 0x22, 0x25, 0x25, 0x28, 0x23, 0x26, 0x20, 0x21, 0x1F, 0x24, 0x23, 0x24, 0x21, 0x24, 0x22, 0x23, 0x1F, 0x22, 0x25, 0x27, 0x21, 0x24, 0x1E, 0x1F, 0x21, 0x24, 0x1F, 0x20, 0x22, 0x25, 0x20, 0x21, 0x1E, 0x20, 0x1E, 0x1E, 0x1E, 0x22, 0x22, 0x25, 0x20, 0x21, 0x22, 0x23, 0x1C, 0x20, 0x26, 0x28, 0x1F, 0x20, 0x1F, 0x23, 0x20, 0x23, 0x22, 0x24, 0x1E, 0x1F, 0x1F, 0x22, 0x20, 0x21, 0x20, 0x24, 0x21, 0x23, 0x1D, 0x1E, 0x1D, 0x20, 0x1D, 0x1E, 0x1F, 0x22, 0x1F, 0x20, 0x1C, 0x1E
    },

    {
        0x4C, 0x1B, 0x4C, 0x1B, 0x4C, 0x1B, 0x4C, 0x1B, 0x4B, 0x1B, 0x4B, 0x1B, 0x4A, 0x1A, 0x4A, 0x1B, 0x4B, 0x1A, 0x4C, 0x1B, 0x4D, 0x1C, 0x4D, 0x1B, 0x4D, 0x1C, 0x4D, 0x1B, 0x4E, 0x1B, 0x4D, 0x1C, 0x4E, 0x1B, 0x4E, 0x1C, 0x4F, 0x1D, 0x4F, 0x1C, 0x50, 0x1D, 0x4F, 0x1C, 0x4F, 0x1C, 0x4F, 0x1D, 0x50, 0x1C, 0x4F, 0x1C, 0x4F, 0x1D, 0x4E, 0x1D, 0x4F, 0x1D, 0x51, 0x1D, 0x4F, 0x1D, 0x51, 0x1E, 0x53, 0x1E, 0x53, 0x1E, 0x53, 0x1F, 0x53, 0x1F, 0x53, 0x1E, 0x52, 0x1E, 0x52, 0x1E, 0x53, 0x1E, 0x56, 0x1E, 0x55, 0x1F, 0x53, 0x1F, 0x54, 0x1F, 0x54, 0x1F, 0x54, 0x1F, 0x57, 0x1F, 0x55, 0x1F, 0x56, 0x20, 0x56, 0x21, 0x57, 0x20, 0x57, 0x20, 0x55, 0x1F, 0x52, 0x20, 0x4E, 0x1F, 0x47, 0x1D, 0x3F, 0x1B, 0x3D, 0x1A, 0x45, 0x1C, 0x4B, 0x1D, 0x46, 0x1B, 0x3A, 0x18, 0x2A, 0x15, 0x20, 0x13, 0x1C, 0x11, 0x1A, 0x11, 0x19, 0x12, 0x1B, 0x16, 0x1F, 0x1E, 0x2A, 0x2B, 0x38, 0x3A, 0x40, 0x40, 0x3F, 0x3D, 0x32, 0x2C, 0x26, 0x20, 0x1E, 0x18, 0x1B, 0x14, 0x1B, 0x14, 0x1A, 0x12, 0x1A, 0x12, 0x1C, 0x12, 0x22, 0x15, 0x35, 0x1A, 0x47, 0x1E, 0x4F, 0x1F, 0x51, 0x1F, 0x44, 0x1C, 0x37, 0x1A, 0x42, 0x1D, 0x4E, 0x1F, 0x56, 0x20, 0x59, 0x21, 0x5B, 0x21, 0x5C, 0x23, 0x5C, 0x22, 0x5C, 0x22, 0x5C, 0x23, 0x5C, 0x22, 0x5E, 0x23, 0x5E, 0x22, 0x5F, 0x23, 0x5F, 0x22, 0x5D, 0x22, 0x5E, 0x22, 0x5E, 0x22, 0x5F, 0x23, 0x60, 0x22, 0x5E, 0x22, 0x5E, 0x22, 0x5F, 0x22, 0x5E, 0x22, 0x5E, 0x21, 0x5E, 0x22, 0x5F, 0x22, 0x5E, 0x21, 0x5E, 0x22, 0x5C, 0x21, 0x5C, 0x21, 0x5D, 0x22, 0x5D, 0x22, 0x5F, 0x23, 0x5F, 0x23, 0x5D, 0x22, 0x5C, 0x22, 0x5F, 0x21, 0x61, 0x23, 0x60, 0x22, 0x60, 0x22, 0x61, 0x22, 0x61, 0x22, 0x62, 0x23, 0x60, 0x23, 0x61, 0x23, 0x61, 0x23, 0x60, 0x22, 0x61, 0x22, 0x60, 0x23, 0x5F, 0x22, 0x60, 0x22, 0x5E, 0x21, 0x5D, 0x21, 0x5F, 0x21, 0x5D, 0x21, 0x5C, 0x21, 0x5B, 0x20, 0x5C, 0x20, 0x5E, 0x21, 0x5D, 0x21, 0x5E, 0x21, 0x5D, 0x21, 0x5D, 0x21, 0x60, 0x21, 0x5F, 0x21, 0x5F, 0x21, 0x5F, 0x22, 0x60, 0x22, 0x61, 0x22, 0x5E, 0x21, 0x5D, 0x21, 0x5D, 0x21, 0x5E, 0x21, 0x5E, 0x21, 0x5F, 0x22, 0x5E, 0x22, 0x5E, 0x21, 0x5E, 0x21, 0x5C, 0x21, 0x5C, 0x20, 0x5A, 0x1F, 0x5B, 0x21, 0x5C, 0x22, 0x5C, 0x21, 0x5B, 0x20, 0x5C, 0x20, 0x5B, 0x21, 0x5C, 0x20, 0x5A, 0x20, 0x5A, 0x20, 0x5A, 0x20, 0x59, 0x20, 0x5B, 0x25, 0x60, 0x2D, 0x5C, 0x2F, 0x50, 0x29, 0x42, 0x21, 0x39, 0x1C, 0x38, 0x1A, 0x49, 0x1D, 0x53, 0x1F, 0x57, 0x20, 0x58, 0x1F, 0x5A, 0x20, 0x5A, 0x20, 0x5C, 0x22, 0x5D, 0x21, 0x5B, 0x20, 0x58, 0x20, 0x50, 0x1E, 0x44, 0x1A, 0x38, 0x18, 0x34, 0x17, 0x31, 0x16, 0x2C, 0x15, 0x2A, 0x14, 0x34, 0x17, 0x47, 0x1C, 0x53, 0x1F, 0x57, 0x1F, 0x59, 0x20, 0x59, 0x20, 0x59, 0x20, 0x57, 0x20, 0x59, 0x20, 0x58, 0x20, 0x58, 0x20, 0x57, 0x1F, 0x58, 0x20, 0x58, 0x1F, 0x59, 0x21, 0x5B, 0x21, 0x5B, 0x22, 0x59, 0x21, 0x59, 0x20, 0x57, 0x20, 0x5A, 0x20, 0x59, 0x21, 0x5A, 0x22, 0x5A, 0x21, 0x5A, 0x21, 0x5B, 0x21, 0x59, 0x20, 0x59, 0x20, 0x58, 0x1F, 0x56, 0x1F, 0x57, 0x1F, 0x54, 0x1E, 0x55, 0x1E, 0x55, 0x1F, 0x55, 0x1F, 0x56, 0x1F, 0x56, 0x20, 0x57, 0x20, 0x55, 0x1F, 0x55, 0x1F, 0x55, 0x1F, 0x57, 0x20, 0x56, 0x1F, 0x57, 0x20, 0x57, 0x20, 0x55, 0x20, 0x57, 0x20, 0x57, 0x20, 0x55, 0x1F, 0x56, 0x1F, 0x56, 0x1F, 0x54, 0x1F, 0x54, 0x1E, 0x55, 0x1F, 0x53, 0x1F, 0x53, 0x1F, 0x53, 0x1F, 0x54, 0x1E, 0x54, 0x1F, 0x53, 0x1E, 0x53, 0x1E, 0x55, 0x1F, 0x57, 0x20, 0x56, 0x1F, 0x54, 0x1E, 0x52, 0x1E, 0x52, 0x1F, 0x51, 0x1D, 0x50, 0x1E, 0x51, 0x1E, 0x52, 0x1E, 0x52, 0x1E, 0x51, 0x1E, 0x3E, 0x19, 0x30, 0x18, 0x24, 0x14, 0x26, 0x17, 0x25, 0x16, 0x22, 0x14, 0x22, 0x15, 0x22, 0x15, 0x24, 0x16, 0x24, 0x15, 0x21, 0x16, 0x24, 0x15, 0x23, 0x16, 0x28, 0x17, 0x22, 0x14, 0x1E, 0x13, 0x25, 0x16, 0x21, 0x14, 0x23, 0x15, 0x1E, 0x13, 0x21, 0x14, 0x20, 0x13, 0x24, 0x16, 0x23, 0x14, 0x21, 0x14, 0x22, 0x14, 0x1F, 0x14, 0x28, 0x16, 0x21, 0x14, 0x26, 0x17, 0x22, 0x14, 0x22, 0x14, 0x21, 0x14, 0x23, 0x16, 0x23, 0x15, 0x24, 0x15, 0x1F, 0x13, 0x20, 0x14, 0x22, 0x15, 0x24, 0x15, 0x27, 0x16, 0x22, 0x15, 0x28, 0x17
    },

    {
        0x52, 0x49, 0x51, 0x49, 0x52, 0x48, 0x51, 0x48, 0x51, 0x48, 0x51, 0x48, 0x50, 0x46, 0x50, 0x47, 0x50, 0x48, 0x51, 0x48, 0x53, 0x4A, 0x53, 0x4A, 0x53, 0x4A, 0x53, 0x4A, 0x54, 0x49, 0x54, 0x4A, 0x54, 0x49, 0x55, 0x4B, 0x56, 0x4C, 0x56, 0x4C, 0x56, 0x4C, 0x57, 0x4C, 0x56, 0x4D, 0x56, 0x4C, 0x57, 0x4C, 0x56, 0x4B, 0x56, 0x4C, 0x55, 0x4B, 0x55, 0x4C, 0x57, 0x4D, 0x57, 0x4C, 0x57, 0x4D, 0x59, 0x4D, 0x59, 0x4E, 0x5A, 0x51, 0x5A, 0x50, 0x59, 0x4D, 0x58, 0x4F, 0x59, 0x4F, 0x5A, 0x4F, 0x5B, 0x51, 0x5A, 0x51, 0x59, 0x4F, 0x59, 0x4F, 0x5A, 0x4F, 0x5B, 0x51, 0x5C, 0x52, 0x5B, 0x51, 0x5B, 0x52, 0x5C, 0x53, 0x5C, 0x53, 0x5B, 0x52, 0x58, 0x51, 0x55, 0x4D, 0x4F, 0x47, 0x47, 0x40, 0x3E, 0x3A, 0x3D, 0x3B, 0x47, 0x44, 0x4A, 0x45, 0x44, 0x3D, 0x35, 0x30, 0x25, 0x23, 0x1C, 0x1C, 0x18, 0x19, 0x16, 0x18, 0x15, 0x18, 0x17, 0x1B, 0x1A, 0x20, 0x22, 0x2B, 0x2D, 0x38, 0x34, 0x3E, 0x34, 0x3E, 0x2C, 0x31, 0x22, 0x25, 0x1A, 0x1E, 0x17, 0x1A, 0x16, 0x19, 0x15, 0x18, 0x16, 0x18, 0x17, 0x19, 0x1B, 0x1E, 0x2B, 0x30, 0x40, 0x42, 0x4C, 0x4B, 0x50, 0x4D, 0x47, 0x42, 0x38, 0x35, 0x3C, 0x3D, 0x4D, 0x49, 0x57, 0x51, 0x5B, 0x54, 0x5C, 0x55, 0x5E, 0x56, 0x5F, 0x57, 0x61, 0x57, 0x61, 0x57, 0x60, 0x58, 0x61, 0x59, 0x63, 0x59, 0x64, 0x5A, 0x63, 0x58, 0x63, 0x58, 0x64, 0x5A, 0x63, 0x5A, 0x63, 0x5A, 0x63, 0x59, 0x63, 0x59, 0x63, 0x58, 0x63, 0x59, 0x63, 0x59, 0x63, 0x58, 0x64, 0x58, 0x65, 0x59, 0x63, 0x58, 0x63, 0x58, 0x62, 0x57, 0x61, 0x56, 0x62, 0x57, 0x61, 0x57, 0x62, 0x5A, 0x63, 0x5A, 0x61, 0x58, 0x61, 0x58, 0x62, 0x59, 0x65, 0x5A, 0x64, 0x5A, 0x66, 0x5A, 0x66, 0x5B, 0x67, 0x5C, 0x68, 0x5C, 0x66, 0x5B, 0x66, 0x5B, 0x65, 0x5B, 0x65, 0x5A, 0x65, 0x59, 0x65, 0x59, 0x64, 0x5A, 0x66, 0x59, 0x64, 0x59, 0x64, 0x58, 0x64, 0x57, 0x64, 0x58, 0x63, 0x57, 0x63, 0x57, 0x62, 0x57, 0x63, 0x57, 0x64, 0x58, 0x62, 0x56, 0x63, 0x57, 0x61, 0x57, 0x65, 0x59, 0x63, 0x58, 0x64, 0x59, 0x64, 0x5A, 0x62, 0x59, 0x64, 0x58, 0x63, 0x58, 0x62, 0x56, 0x61, 0x56, 0x62, 0x57, 0x62, 0x56, 0x62, 0x58, 0x63, 0x5A, 0x63, 0x57, 0x62, 0x57, 0x5E, 0x56, 0x60, 0x55, 0x5E, 0x53, 0x5F, 0x56, 0x60, 0x56, 0x60, 0x55, 0x60, 0x56, 0x60, 0x55, 0x60, 0x56, 0x61, 0x56, 0x5F, 0x54, 0x5D, 0x53, 0x5E, 0x53, 0x5E, 0x53, 0x5B, 0x56, 0x58, 0x57, 0x50, 0x51, 0x45, 0x43, 0x3C, 0x38, 0x35, 0x30, 0x36, 0x32, 0x47, 0x42, 0x53, 0x4E, 0x5B, 0x52, 0x5C, 0x52, 0x5E, 0x54, 0x5E, 0x55, 0x5F, 0x56, 0x5F, 0x56, 0x5F, 0x54, 0x5C, 0x53, 0x54, 0x4B, 0x46, 0x3F, 0x39, 0x33, 0x32, 0x2E, 0x2F, 0x2A, 0x2C, 0x28, 0x2D, 0x2B, 0x39, 0x38, 0x4A, 0x46, 0x56, 0x50, 0x5A, 0x51, 0x5D, 0x54, 0x5C, 0x53, 0x5C, 0x53, 0x5D, 0x53, 0x5E, 0x54, 0x5C, 0x54, 0x5D, 0x53, 0x5C, 0x50, 0x5D, 0x52, 0x5C, 0x53, 0x5D, 0x55, 0x5E, 0x54, 0x5E, 0x55, 0x5D, 0x54, 0x5C, 0x53, 0x5C, 0x52, 0x5E, 0x54, 0x5D, 0x54, 0x5F, 0x56, 0x5E, 0x54, 0x5E, 0x56, 0x5F, 0x55, 0x5C, 0x53, 0x5D, 0x53, 0x5D, 0x53, 0x5B, 0x51, 0x5C, 0x52, 0x59, 0x4F, 0x5A, 0x50, 0x5A, 0x51, 0x5B, 0x51, 0x5A, 0x50, 0x59, 0x50, 0x5B, 0x51, 0x59, 0x50, 0x59, 0x4F, 0x5A, 0x50, 0x5B, 0x52, 0x5A, 0x51, 0x5A, 0x51, 0x5A, 0x51, 0x5C, 0x52, 0x5E, 0x53, 0x5C, 0x53, 0x59, 0x50, 0x5A, 0x51, 0x5A, 0x51, 0x5A, 0x51, 0x59, 0x50, 0x59, 0x4F, 0x59, 0x50, 0x59, 0x4F, 0x59, 0x50, 0x59, 0x4F, 0x59, 0x4F, 0x58, 0x4E, 0x58, 0x4F, 0x5A, 0x50, 0x5B, 0x52, 0x5C, 0x52, 0x5A, 0x4E, 0x57, 0x4D, 0x57, 0x4E, 0x57, 0x4D, 0x57, 0x4E, 0x56, 0x4F, 0x58, 0x4F, 0x59, 0x50, 0x56, 0x4C, 0x3E, 0x38, 0x2D, 0x2A, 0x22, 0x21, 0x22, 0x25, 0x20, 0x21, 0x1E, 0x1F, 0x1D, 0x21, 0x1E, 0x1F, 0x20, 0x23, 0x20, 0x20, 0x1E, 0x22, 0x1F, 0x20, 0x1F, 0x23, 0x23, 0x24, 0x1D, 0x1E, 0x1C, 0x1D, 0x21, 0x24, 0x1E, 0x20, 0x1F, 0x20, 0x1C, 0x1D, 0x1C, 0x20, 0x1C, 0x1E, 0x20, 0x24, 0x1E, 0x20, 0x1C, 0x20, 0x1E, 0x1F, 0x1D, 0x21, 0x21, 0x23, 0x1D, 0x1E, 0x21, 0x24, 0x1D, 0x20, 0x1F, 0x21, 0x1D, 0x1F, 0x1F, 0x23, 0x1E, 0x21, 0x20, 0x22, 0x1D, 0x1E, 0x1D, 0x20, 0x1E, 0x23, 0x21, 0x25, 0x22, 0x25, 0x20, 0x23, 0x22, 0x24
    },

    {
        0x4C, 0x1B, 0x4D, 0x1B, 0x4C, 0x1B, 0x4B, 0x1A, 0x4A, 0x1A, 0x4A, 0x1A, 0x4B, 0x1A, 0x4B, 0x1A, 0x4C, 0x1A, 0x4C, 0x1B, 0x4D, 0x1B, 0x4E, 0x1C, 0x4E, 0x1B, 0x4C, 0x1B, 0x4D, 0x1B, 0x4D, 0x1B, 0x4D, 0x1B, 0x4E, 0x1B, 0x4F, 0x1C, 0x51, 0x1C, 0x50, 0x1C, 0x50, 0x1C, 0x4F, 0x1D, 0x4F, 0x1C, 0x50, 0x1C, 0x4F, 0x1C, 0x50, 0x1D, 0x50, 0x1C, 0x4F, 0x1C, 0x51, 0x1C, 0x51, 0x1D, 0x51, 0x1D, 0x50, 0x1D, 0x51, 0x1D, 0x55, 0x1E, 0x54, 0x1D, 0x54, 0x1E, 0x53, 0x1E, 0x53, 0x1E, 0x53, 0x1D, 0x54, 0x1E, 0x55, 0x1F, 0x55, 0x20, 0x54, 0x1E, 0x55, 0x1E, 0x54, 0x1E, 0x55, 0x1F, 0x55, 0x1F, 0x55, 0x1F, 0x57, 0x20, 0x57, 0x20, 0x56, 0x1F, 0x53, 0x1F, 0x4E, 0x1E, 0x47, 0x1C, 0x40, 0x1B, 0x3D, 0x1A, 0x43, 0x1B, 0x48, 0x1C, 0x45, 0x1B, 0x3B, 0x18, 0x2C, 0x15, 0x21, 0x12, 0x1D, 0x11, 0x1A, 0x10, 0x18, 0x11, 0x19, 0x15, 0x1F, 0x1D, 0x27, 0x28, 0x34, 0x36, 0x40, 0x41, 0x44, 0x46, 0x46, 0x45, 0x42, 0x40, 0x35, 0x30, 0x27, 0x21, 0x1F, 0x18, 0x1C, 0x14, 0x1A, 0x13, 0x1A, 0x12, 0x1A, 0x11, 0x1C, 0x11, 0x21, 0x15, 0x34, 0x1A, 0x47, 0x1E, 0x4F, 0x1F, 0x51, 0x1F, 0x46, 0x1C, 0x39, 0x1A, 0x42, 0x1C, 0x4F, 0x20, 0x57, 0x20, 0x5A, 0x21, 0x5C, 0x22, 0x5D, 0x22, 0x5C, 0x22, 0x5D, 0x22, 0x5C, 0x22, 0x5D, 0x22, 0x5D, 0x22, 0x5F, 0x22, 0x60, 0x23, 0x5E, 0x22, 0x5E, 0x22, 0x5E, 0x22, 0x5F, 0x22, 0x5E, 0x23, 0x5D, 0x23, 0x5F, 0x22, 0x5F, 0x22, 0x60, 0x22, 0x5E, 0x21, 0x5F, 0x22, 0x5E, 0x22, 0x60, 0x22, 0x5D, 0x21, 0x5C, 0x20, 0x5C, 0x21, 0x5E, 0x22, 0x5E, 0x22, 0x5F, 0x22, 0x61, 0x22, 0x60, 0x23, 0x5F, 0x22, 0x5D, 0x22, 0x60, 0x22, 0x60, 0x21, 0x5F, 0x22, 0x5F, 0x21, 0x62, 0x22, 0x64, 0x23, 0x64, 0x23, 0x62, 0x23, 0x61, 0x23, 0x62, 0x23, 0x60, 0x22, 0x5E, 0x22, 0x61, 0x21, 0x5F, 0x21, 0x5E, 0x21, 0x5F, 0x21, 0x5E, 0x20, 0x5F, 0x21, 0x5F, 0x21, 0x5F, 0x20, 0x5E, 0x21, 0x5D, 0x21, 0x5E, 0x20, 0x5D, 0x20, 0x5C, 0x20, 0x5C, 0x20, 0x5E, 0x21, 0x5F, 0x21, 0x5E, 0x21, 0x60, 0x22, 0x5F, 0x21, 0x5F, 0x21, 0x5E, 0x21, 0x5D, 0x20, 0x5C, 0x20, 0x5C, 0x20, 0x5C, 0x20, 0x5F, 0x22, 0x5D, 0x20, 0x5E, 0x21, 0x5D, 0x20, 0x5D, 0x21, 0x5B, 0x20, 0x5A, 0x20, 0x5A, 0x20, 0x5D, 0x22, 0x5C, 0x21, 0x5B, 0x20, 0x5C, 0x20, 0x5C, 0x20, 0x5B, 0x20, 0x59, 0x1F, 0x5A, 0x1F, 0x58, 0x1F, 0x59, 0x20, 0x57, 0x24, 0x55, 0x29, 0x47, 0x24, 0x39, 0x1C, 0x31, 0x19, 0x2E, 0x17, 0x2A, 0x16, 0x38, 0x19, 0x51, 0x1E, 0x56, 0x1F, 0x59, 0x20, 0x5C, 0x22, 0x5C, 0x21, 0x5C, 0x21, 0x5B, 0x21, 0x5A, 0x20, 0x57, 0x1F, 0x56, 0x1F, 0x4D, 0x1C, 0x3F, 0x19, 0x34, 0x16, 0x30, 0x15, 0x31, 0x16, 0x37, 0x17, 0x45, 0x1B, 0x4F, 0x1E, 0x55, 0x1F, 0x59, 0x20, 0x58, 0x1F, 0x57, 0x1F, 0x56, 0x1F, 0x58, 0x1F, 0x59, 0x20, 0x58, 0x1F, 0x56, 0x1F, 0x57, 0x1F, 0x58, 0x1F, 0x59, 0x20, 0x5A, 0x20, 0x59, 0x20, 0x58, 0x20, 0x59, 0x20, 0x59, 0x20, 0x57, 0x1F, 0x58, 0x1F, 0x59, 0x20, 0x5B, 0x20, 0x59, 0x20, 0x5C, 0x20, 0x59, 0x20, 0x58, 0x1F, 0x58, 0x1F, 0x57, 0x1F, 0x56, 0x1F, 0x57, 0x1E, 0x53, 0x1D, 0x55, 0x1E, 0x55, 0x1E, 0x56, 0x1F, 0x55, 0x1F, 0x57, 0x1F, 0x58, 0x1F, 0x54, 0x1F, 0x54, 0x1E, 0x55, 0x1E, 0x57, 0x1F, 0x55, 0x1F, 0x57, 0x1F, 0x56, 0x1F, 0x56, 0x1F, 0x57, 0x1F, 0x57, 0x1F, 0x56, 0x1E, 0x54, 0x1E, 0x55, 0x1E, 0x55, 0x1F, 0x54, 0x1F, 0x52, 0x1E, 0x53, 0x1E, 0x53, 0x1E, 0x53, 0x1D, 0x54, 0x1E, 0x54, 0x1E, 0x54, 0x1E, 0x53, 0x1D, 0x52, 0x1D, 0x54, 0x1E, 0x53, 0x1E, 0x53, 0x1D, 0x51, 0x1D, 0x50, 0x1D, 0x52, 0x1D, 0x54, 0x1E, 0x53, 0x1E, 0x55, 0x1E, 0x55, 0x1E, 0x50, 0x1C, 0x40, 0x1A, 0x2D, 0x17, 0x26, 0x15, 0x26, 0x16, 0x26, 0x15, 0x22, 0x14, 0x25, 0x16, 0x22, 0x15, 0x25, 0x16, 0x23, 0x14, 0x22, 0x15, 0x26, 0x16, 0x27, 0x17, 0x28, 0x17, 0x24, 0x15, 0x22, 0x15, 0x28, 0x17, 0x25, 0x15, 0x27, 0x16, 0x24, 0x14, 0x24, 0x15, 0x23, 0x14, 0x24, 0x15, 0x27, 0x16, 0x23, 0x15, 0x27, 0x16, 0x24, 0x15, 0x29, 0x16, 0x24, 0x15, 0x25, 0x16, 0x25, 0x15, 0x26, 0x16, 0x25, 0x15, 0x27, 0x17, 0x27, 0x15, 0x23, 0x14, 0x25, 0x15, 0x26, 0x15, 0x28, 0x17, 0x28, 0x16, 0x25, 0x15, 0x24, 0x15, 0x22, 0x13
    },

    {
        0x52, 0x49, 0x51, 0x49, 0x51, 0x49, 0x4F, 0x47, 0x4E, 0x48, 0x51, 0x47, 0x51, 0x47, 0x50, 0x48, 0x51, 0x49, 0x52, 0x49, 0x53, 0x4A, 0x54, 0x4A, 0x54, 0x4A, 0x53, 0x4A, 0x53, 0x49, 0x53, 0x49, 0x53, 0x4A, 0x55, 0x4A, 0x55, 0x4B, 0x56, 0x4C, 0x56, 0x4C, 0x56, 0x4C, 0x56, 0x4C, 0x57, 0x4C, 0x57, 0x4C, 0x56, 0x4B, 0x56, 0x4C, 0x56, 0x4C, 0x55, 0x4D, 0x57, 0x4D, 0x57, 0x4D, 0x57, 0x4E, 0x57, 0x4D, 0x59, 0x4F, 0x5A, 0x4F, 0x5A, 0x50, 0x5A, 0x4F, 0x5A, 0x51, 0x5A, 0x50, 0x5A, 0x50, 0x5B, 0x51, 0x5C, 0x51, 0x5A, 0x51, 0x59, 0x50, 0x59, 0x50, 0x5A, 0x50, 0x5C, 0x51, 0x5A, 0x50, 0x5B, 0x52, 0x5C, 0x53, 0x5B, 0x53, 0x59, 0x50, 0x55, 0x4D, 0x4F, 0x48, 0x48, 0x40, 0x3F, 0x39, 0x3D, 0x3B, 0x44, 0x43, 0x49, 0x44, 0x44, 0x3E, 0x37, 0x32, 0x26, 0x24, 0x1C, 0x1D, 0x19, 0x1A, 0x16, 0x18, 0x15, 0x17, 0x16, 0x1A, 0x1A, 0x20, 0x21, 0x2A, 0x2B, 0x37, 0x34, 0x3F, 0x37, 0x42, 0x38, 0x42, 0x37, 0x40, 0x2F, 0x34, 0x23, 0x26, 0x1C, 0x1E, 0x18, 0x1A, 0x16, 0x19, 0x16, 0x19, 0x16, 0x18, 0x16, 0x1A, 0x1A, 0x1D, 0x29, 0x2E, 0x3E, 0x41, 0x4B, 0x4B, 0x50, 0x4D, 0x49, 0x44, 0x3A, 0x36, 0x3D, 0x3C, 0x4D, 0x4A, 0x57, 0x52, 0x5C, 0x55, 0x5D, 0x55, 0x5E, 0x56, 0x5F, 0x56, 0x63, 0x58, 0x60, 0x58, 0x60, 0x58, 0x62, 0x5A, 0x64, 0x59, 0x64, 0x59, 0x63, 0x58, 0x64, 0x58, 0x62, 0x58, 0x63, 0x59, 0x62, 0x58, 0x62, 0x59, 0x63, 0x5A, 0x63, 0x59, 0x63, 0x5A, 0x63, 0x58, 0x64, 0x5A, 0x64, 0x5B, 0x64, 0x58, 0x62, 0x57, 0x61, 0x56, 0x62, 0x56, 0x61, 0x57, 0x62, 0x57, 0x64, 0x5B, 0x65, 0x5C, 0x64, 0x5B, 0x62, 0x59, 0x62, 0x59, 0x64, 0x5A, 0x66, 0x5A, 0x65, 0x59, 0x65, 0x5A, 0x68, 0x5B, 0x69, 0x5D, 0x69, 0x5D, 0x66, 0x5B, 0x66, 0x5B, 0x66, 0x5B, 0x64, 0x5A, 0x64, 0x59, 0x65, 0x5A, 0x64, 0x58, 0x64, 0x59, 0x66, 0x59, 0x65, 0x59, 0x65, 0x59, 0x64, 0x58, 0x64, 0x58, 0x64, 0x58, 0x62, 0x57, 0x63, 0x58, 0x64, 0x57, 0x61, 0x56, 0x63, 0x56, 0x63, 0x58, 0x62, 0x58, 0x63, 0x58, 0x64, 0x59, 0x62, 0x59, 0x64, 0x59, 0x63, 0x56, 0x61, 0x57, 0x61, 0x56, 0x60, 0x56, 0x61, 0x57, 0x63, 0x59, 0x61, 0x57, 0x63, 0x57, 0x60, 0x58, 0x5F, 0x56, 0x5F, 0x54, 0x5E, 0x54, 0x5E, 0x54, 0x60, 0x57, 0x60, 0x57, 0x60, 0x56, 0x60, 0x54, 0x60, 0x56, 0x5F, 0x55, 0x5E, 0x53, 0x5E, 0x52, 0x5E, 0x53, 0x5D, 0x53, 0x55, 0x4F, 0x4B, 0x49, 0x3F, 0x3A, 0x35, 0x30, 0x2F, 0x2B, 0x2C, 0x29, 0x2A, 0x26, 0x37, 0x35, 0x51, 0x4C, 0x59, 0x51, 0x5E, 0x55, 0x61, 0x57, 0x5F, 0x56, 0x5F, 0x56, 0x5E, 0x55, 0x5F, 0x54, 0x5C, 0x53, 0x5A, 0x51, 0x52, 0x4A, 0x44, 0x3D, 0x3A, 0x35, 0x35, 0x31, 0x37, 0x33, 0x3D, 0x3A, 0x4A, 0x46, 0x55, 0x4F, 0x5A, 0x53, 0x5D, 0x55, 0x5D, 0x54, 0x5C, 0x52, 0x5B, 0x51, 0x5B, 0x52, 0x5D, 0x53, 0x5C, 0x51, 0x5C, 0x53, 0x5D, 0x52, 0x5D, 0x53, 0x5D, 0x55, 0x5F, 0x54, 0x5C, 0x53, 0x5C, 0x53, 0x5E, 0x55, 0x5D, 0x53, 0x5B, 0x52, 0x5C, 0x52, 0x5C, 0x55, 0x60, 0x55, 0x5D, 0x55, 0x5E, 0x54, 0x5D, 0x54, 0x5D, 0x53, 0x5E, 0x53, 0x5C, 0x52, 0x5B, 0x51, 0x5B, 0x52, 0x59, 0x4F, 0x59, 0x51, 0x5A, 0x50, 0x5B, 0x52, 0x58, 0x52, 0x5B, 0x53, 0x5C, 0x52, 0x5B, 0x50, 0x5A, 0x51, 0x5A, 0x51, 0x5B, 0x51, 0x59, 0x50, 0x5B, 0x52, 0x5B, 0x52, 0x5B, 0x51, 0x5C, 0x52, 0x5B, 0x51, 0x5A, 0x51, 0x58, 0x51, 0x59, 0x4F, 0x5B, 0x51, 0x58, 0x50, 0x56, 0x4D, 0x58, 0x50, 0x59, 0x50, 0x59, 0x4F, 0x59, 0x4F, 0x59, 0x50, 0x59, 0x4E, 0x58, 0x4E, 0x57, 0x4E, 0x5A, 0x50, 0x59, 0x50, 0x58, 0x4D, 0x57, 0x4D, 0x58, 0x4E, 0x58, 0x4D, 0x5B, 0x4F, 0x58, 0x50, 0x5A, 0x50, 0x5A, 0x51, 0x53, 0x4A, 0x3F, 0x38, 0x2C, 0x2A, 0x24, 0x24, 0x23, 0x26, 0x22, 0x24, 0x1D, 0x1F, 0x21, 0x25, 0x1F, 0x22, 0x20, 0x23, 0x1F, 0x21, 0x1F, 0x23, 0x22, 0x25, 0x22, 0x26, 0x24, 0x26, 0x21, 0x23, 0x1F, 0x21, 0x24, 0x28, 0x21, 0x24, 0x23, 0x26, 0x20, 0x22, 0x20, 0x23, 0x20, 0x22, 0x20, 0x25, 0x22, 0x24, 0x1F, 0x23, 0x23, 0x26, 0x20, 0x22, 0x23, 0x26, 0x20, 0x21, 0x21, 0x25, 0x20, 0x22, 0x21, 0x25, 0x20, 0x21, 0x23, 0x27, 0x22, 0x23, 0x1E, 0x1F, 0x22, 0x26, 0x20, 0x21, 0x24, 0x28, 0x20, 0x23, 0x20, 0x22, 0x1F, 0x21, 0x1C, 0x1D
    },

    {
        0x4D, 0x1C, 0x4D, 0x1B, 0x4D, 0x1C, 0x4B, 0x1B, 0x4A, 0x1A, 0x4B, 0x1A, 0x4B, 0x1A, 0x4A, 0x1A, 0x4D, 0x1B, 0x4D, 0x1B, 0x4E, 0x1C, 0x4F, 0x1B, 0x4F, 0x1C, 0x4E, 0x1C, 0x4D, 0x1B, 0x4E, 0x1B, 0x4D, 0x1B, 0x4D, 0x1B, 0x4F, 0x1C, 0x4F, 0x1C, 0x50, 0x1C, 0x50, 0x1D, 0x50, 0x1C, 0x4F, 0x1C, 0x4F, 0x1C, 0x4F, 0x1C, 0x4F, 0x1C, 0x50, 0x1C, 0x4F, 0x1D, 0x51, 0x1D, 0x51, 0x1D, 0x51, 0x1E, 0x52, 0x1E, 0x53, 0x1E, 0x53, 0x1E, 0x53, 0x1E, 0x54, 0x1E, 0x54, 0x1E, 0x54, 0x1E, 0x54, 0x1F, 0x55, 0x1E, 0x55, 0x1E, 0x54, 0x1F, 0x55, 0x1F, 0x55, 0x1F, 0x55, 0x1E, 0x55, 0x1F, 0x54, 0x1E, 0x55, 0x1E, 0x55, 0x20, 0x56, 0x20, 0x53, 0x1F, 0x4E, 0x1E, 0x47, 0x1C, 0x3F, 0x1B, 0x3C, 0x1A, 0x42, 0x1B, 0x47, 0x1C, 0x44, 0x1B, 0x3B, 0x18, 0x2C, 0x15, 0x22, 0x12, 0x1C, 0x11, 0x1A, 0x10, 0x19, 0x11, 0x19, 0x14, 0x1D, 0x1B, 0x26, 0x27, 0x33, 0x35, 0x3F, 0x41, 0x45, 0x47, 0x47, 0x48, 0x48, 0x49, 0x47, 0x48, 0x46, 0x43, 0x38, 0x32, 0x28, 0x23, 0x1F, 0x19, 0x1C, 0x15, 0x1A, 0x14, 0x1B, 0x13, 0x1A, 0x12, 0x1C, 0x12, 0x20, 0x14, 0x32, 0x19, 0x46, 0x1D, 0x4F, 0x1F, 0x4F, 0x1F, 0x48, 0x1C, 0x3A, 0x1B, 0x42, 0x1D, 0x50, 0x20, 0x58, 0x22, 0x5A, 0x22, 0x5B, 0x22, 0x5D, 0x22, 0x5D, 0x22, 0x5E, 0x22, 0x5F, 0x23, 0x5D, 0x23, 0x5F, 0x22, 0x5F, 0x22, 0x5D, 0x22, 0x5D, 0x22, 0x5F, 0x23, 0x60, 0x22, 0x5E, 0x22, 0x5F, 0x23, 0x5E, 0x22, 0x5F, 0x23, 0x5F, 0x23, 0x5E, 0x21, 0x5E, 0x22, 0x5F, 0x22, 0x60, 0x22, 0x5C, 0x22, 0x5D, 0x21, 0x5C, 0x21, 0x5D, 0x22, 0x60, 0x23, 0x60, 0x23, 0x62, 0x23, 0x61, 0x23, 0x61, 0x22, 0x60, 0x22, 0x60, 0x22, 0x61, 0x22, 0x61, 0x22, 0x60, 0x22, 0x62, 0x23, 0x64, 0x24, 0x61, 0x23, 0x63, 0x23, 0x61, 0x23, 0x62, 0x23, 0x61, 0x22, 0x60, 0x22, 0x61, 0x22, 0x60, 0x22, 0x5E, 0x21, 0x60, 0x21, 0x5F, 0x21, 0x5E, 0x21, 0x5D, 0x20, 0x5C, 0x20, 0x5E, 0x21, 0x5C, 0x20, 0x5D, 0x20, 0x5D, 0x20, 0x5B, 0x20, 0x5B, 0x20, 0x5C, 0x20, 0x60, 0x22, 0x5F, 0x21, 0x61, 0x22, 0x5E, 0x22, 0x5D, 0x21, 0x5B, 0x20, 0x5F, 0x21, 0x5E, 0x21, 0x5D, 0x21, 0x5C, 0x20, 0x5E, 0x21, 0x5D, 0x21, 0x5D, 0x21, 0x5C, 0x21, 0x5C, 0x21, 0x5A, 0x20, 0x5A, 0x20, 0x5A, 0x20, 0x5E, 0x21, 0x5D, 0x21, 0x5C, 0x20, 0x5A, 0x20, 0x5B, 0x21, 0x59, 0x20, 0x59, 0x1F, 0x5B, 0x20, 0x5A, 0x20, 0x5A, 0x20, 0x4D, 0x21, 0x42, 0x20, 0x35, 0x1B, 0x2E, 0x18, 0x2C, 0x16, 0x29, 0x16, 0x26, 0x15, 0x2D, 0x17, 0x4C, 0x1E, 0x56, 0x1F, 0x5A, 0x21, 0x5E, 0x22, 0x5B, 0x21, 0x5C, 0x21, 0x5B, 0x21, 0x5A, 0x20, 0x58, 0x20, 0x57, 0x1F, 0x56, 0x20, 0x4E, 0x1D, 0x46, 0x1B, 0x43, 0x1A, 0x45, 0x1B, 0x4B, 0x1C, 0x4F, 0x1D, 0x55, 0x1F, 0x57, 0x1F, 0x57, 0x20, 0x59, 0x20, 0x57, 0x1F, 0x57, 0x20, 0x58, 0x20, 0x58, 0x1F, 0x56, 0x1F, 0x56, 0x1F, 0x57, 0x20, 0x59, 0x21, 0x59, 0x20, 0x5A, 0x21, 0x58, 0x20, 0x5A, 0x20, 0x5B, 0x20, 0x59, 0x21, 0x59, 0x20, 0x57, 0x1F, 0x58, 0x1F, 0x59, 0x20, 0x59, 0x1F, 0x56, 0x1F, 0x58, 0x20, 0x58, 0x1F, 0x56, 0x1F, 0x56, 0x1F, 0x57, 0x1F, 0x56, 0x1F, 0x55, 0x1F, 0x56, 0x1E, 0x55, 0x1F, 0x57, 0x1F, 0x58, 0x1F, 0x58, 0x20, 0x57, 0x20, 0x57, 0x1F, 0x56, 0x1F, 0x56, 0x1F, 0x55, 0x1F, 0x56, 0x1F, 0x56, 0x1F, 0x56, 0x1F, 0x55, 0x1E, 0x54, 0x1F, 0x56, 0x1F, 0x54, 0x1F, 0x55, 0x1F, 0x54, 0x1F, 0x56, 0x1F, 0x56, 0x1F, 0x54, 0x1E, 0x52, 0x1E, 0x54, 0x1F, 0x54, 0x1F, 0x56, 0x1F, 0x55, 0x1F, 0x53, 0x1E, 0x52, 0x1E, 0x53, 0x1E, 0x55, 0x1E, 0x52, 0x1D, 0x50, 0x1D, 0x51, 0x1E, 0x53, 0x1E, 0x53, 0x1E, 0x55, 0x1F, 0x55, 0x1F, 0x55, 0x1E, 0x53, 0x1D, 0x4C, 0x1C, 0x3C, 0x1A, 0x34, 0x19, 0x28, 0x16, 0x28, 0x17, 0x26, 0x16, 0x22, 0x15, 0x2A, 0x19, 0x26, 0x15, 0x26, 0x15, 0x23, 0x14, 0x27, 0x18, 0x26, 0x16, 0x26, 0x16, 0x25, 0x16, 0x24, 0x15, 0x20, 0x14, 0x2C, 0x17, 0x20, 0x14, 0x24, 0x15, 0x1F, 0x13, 0x24, 0x15, 0x21, 0x14, 0x25, 0x16, 0x22, 0x14, 0x25, 0x16, 0x26, 0x15, 0x20, 0x14, 0x25, 0x15, 0x21, 0x14, 0x24, 0x16, 0x1F, 0x13, 0x21, 0x14, 0x1F, 0x13, 0x26, 0x17, 0x21, 0x14, 0x22, 0x14, 0x25, 0x16, 0x20, 0x14, 0x25, 0x16, 0x20, 0x13, 0x25, 0x16, 0x20, 0x14, 0x1E, 0x13
    },

    {
        0x53, 0x4A, 0x52, 0x49, 0x52, 0x49, 0x50, 0x48, 0x50, 0x47, 0x51, 0x47, 0x51, 0x47, 0x52, 0x48, 0x52, 0x48, 0x54, 0x4A, 0x56, 0x4C, 0x55, 0x4B, 0x55, 0x4C, 0x55, 0x4B, 0x54, 0x4A, 0x55, 0x4A, 0x54, 0x49, 0x54, 0x49, 0x55, 0x4B, 0x55, 0x4B, 0x57, 0x4C, 0x57, 0x4D, 0x57, 0x4B, 0x57, 0x4B, 0x57, 0x4B, 0x57, 0x4B, 0x57, 0x4B, 0x57, 0x4B, 0x57, 0x4D, 0x57, 0x4D, 0x57, 0x4C, 0x58, 0x4D, 0x59, 0x4E, 0x59, 0x4E, 0x5A, 0x4F, 0x5A, 0x50, 0x5B, 0x50, 0x5C, 0x50, 0x5C, 0x51, 0x5C, 0x52, 0x5B, 0x50, 0x5B, 0x50, 0x5B, 0x50, 0x5A, 0x4F, 0x5B, 0x50, 0x5B, 0x51, 0x5B, 0x51, 0x5A, 0x4F, 0x5B, 0x51, 0x5C, 0x51, 0x5A, 0x52, 0x56, 0x4D, 0x50, 0x47, 0x49, 0x41, 0x40, 0x3A, 0x3D, 0x3B, 0x43, 0x42, 0x47, 0x44, 0x44, 0x3F, 0x39, 0x32, 0x28, 0x25, 0x1D, 0x1D, 0x18, 0x19, 0x16, 0x18, 0x15, 0x18, 0x15, 0x19, 0x1A, 0x1F, 0x20, 0x28, 0x2A, 0x35, 0x34, 0x3F, 0x38, 0x42, 0x39, 0x44, 0x3B, 0x45, 0x3B, 0x44, 0x39, 0x42, 0x32, 0x37, 0x25, 0x27, 0x1B, 0x1E, 0x18, 0x1A, 0x17, 0x19, 0x16, 0x19, 0x16, 0x19, 0x17, 0x19, 0x1A, 0x1C, 0x27, 0x2C, 0x3C, 0x40, 0x4B, 0x4A, 0x4F, 0x4C, 0x4A, 0x46, 0x3B, 0x37, 0x3D, 0x3B, 0x4E, 0x4C, 0x59, 0x53, 0x5B, 0x55, 0x5C, 0x56, 0x5F, 0x56, 0x62, 0x58, 0x61, 0x59, 0x62, 0x59, 0x62, 0x59, 0x64, 0x59, 0x65, 0x58, 0x63, 0x59, 0x62, 0x58, 0x63, 0x59, 0x63, 0x5A, 0x64, 0x59, 0x64, 0x5A, 0x63, 0x59, 0x63, 0x59, 0x64, 0x59, 0x63, 0x58, 0x64, 0x58, 0x65, 0x5A, 0x65, 0x5A, 0x63, 0x57, 0x63, 0x57, 0x62, 0x57, 0x63, 0x59, 0x64, 0x5B, 0x66, 0x5B, 0x66, 0x5C, 0x66, 0x5B, 0x66, 0x5A, 0x65, 0x59, 0x65, 0x5B, 0x65, 0x5B, 0x67, 0x5A, 0x66, 0x59, 0x68, 0x5C, 0x6A, 0x5E, 0x68, 0x5C, 0x68, 0x5C, 0x68, 0x5A, 0x66, 0x5B, 0x67, 0x5B, 0x65, 0x59, 0x67, 0x5B, 0x66, 0x5A, 0x64, 0x58, 0x65, 0x59, 0x64, 0x58, 0x64, 0x59, 0x63, 0x58, 0x65, 0x57, 0x64, 0x57, 0x63, 0x57, 0x62, 0x57, 0x63, 0x57, 0x60, 0x55, 0x60, 0x55, 0x61, 0x57, 0x64, 0x59, 0x65, 0x5A, 0x65, 0x5B, 0x62, 0x59, 0x62, 0x57, 0x62, 0x56, 0x63, 0x58, 0x63, 0x58, 0x61, 0x57, 0x60, 0x55, 0x61, 0x57, 0x62, 0x56, 0x60, 0x57, 0x60, 0x57, 0x5E, 0x54, 0x5D, 0x53, 0x5E, 0x54, 0x5F, 0x55, 0x60, 0x57, 0x61, 0x56, 0x61, 0x56, 0x61, 0x56, 0x60, 0x55, 0x5F, 0x54, 0x5E, 0x54, 0x61, 0x56, 0x60, 0x55, 0x5C, 0x52, 0x4D, 0x43, 0x3E, 0x37, 0x34, 0x2E, 0x2D, 0x29, 0x2B, 0x27, 0x28, 0x25, 0x26, 0x22, 0x2F, 0x2E, 0x4D, 0x4A, 0x5B, 0x51, 0x5E, 0x55, 0x62, 0x58, 0x5E, 0x55, 0x5F, 0x55, 0x60, 0x56, 0x60, 0x54, 0x5F, 0x54, 0x5C, 0x52, 0x5C, 0x52, 0x55, 0x4B, 0x4E, 0x47, 0x4B, 0x44, 0x4C, 0x47, 0x51, 0x4B, 0x55, 0x4D, 0x5A, 0x52, 0x5B, 0x52, 0x5D, 0x53, 0x5E, 0x54, 0x5D, 0x53, 0x5D, 0x53, 0x5E, 0x54, 0x5D, 0x52, 0x5C, 0x51, 0x5D, 0x53, 0x5E, 0x53, 0x5E, 0x53, 0x5D, 0x54, 0x5E, 0x55, 0x5D, 0x52, 0x5F, 0x55, 0x60, 0x55, 0x5F, 0x54, 0x5D, 0x54, 0x5C, 0x52, 0x5B, 0x52, 0x5E, 0x54, 0x5D, 0x52, 0x5C, 0x51, 0x5B, 0x51, 0x5F, 0x53, 0x5C, 0x50, 0x5D, 0x52, 0x5C, 0x52, 0x5B, 0x51, 0x5B, 0x51, 0x5A, 0x51, 0x5A, 0x52, 0x5A, 0x52, 0x5C, 0x52, 0x5C, 0x52, 0x5C, 0x53, 0x5C, 0x51, 0x5A, 0x51, 0x5B, 0x51, 0x5A, 0x52, 0x59, 0x51, 0x5B, 0x51, 0x5C, 0x52, 0x5B, 0x51, 0x5A, 0x51, 0x5D, 0x51, 0x59, 0x51, 0x59, 0x50, 0x59, 0x50, 0x5B, 0x51, 0x5B, 0x51, 0x59, 0x4F, 0x56, 0x4F, 0x5A, 0x50, 0x58, 0x4F, 0x5D, 0x53, 0x5B, 0x52, 0x59, 0x4E, 0x59, 0x4F, 0x59, 0x4E, 0x59, 0x4F, 0x59, 0x4E, 0x55, 0x4D, 0x57, 0x4E, 0x5B, 0x4F, 0x57, 0x4F, 0x5B, 0x52, 0x5A, 0x50, 0x5A, 0x50, 0x58, 0x4D, 0x50, 0x48, 0x3D, 0x36, 0x31, 0x2E, 0x24, 0x22, 0x24, 0x26, 0x22, 0x23, 0x1E, 0x20, 0x25, 0x2A, 0x20, 0x22, 0x20, 0x22, 0x1F, 0x20, 0x22, 0x27, 0x20, 0x20, 0x21, 0x22, 0x20, 0x21, 0x1F, 0x1F, 0x1C, 0x20, 0x24, 0x26, 0x1D, 0x1E, 0x1F, 0x20, 0x1B, 0x1D, 0x1F, 0x22, 0x1C, 0x1D, 0x21, 0x23, 0x1E, 0x1F, 0x20, 0x25, 0x1F, 0x20, 0x1E, 0x21, 0x20, 0x21, 0x1D, 0x1F, 0x20, 0x22, 0x1C, 0x1D, 0x1E, 0x21, 0x1C, 0x1D, 0x21, 0x25, 0x1D, 0x1F, 0x1F, 0x21, 0x21, 0x22, 0x1D, 0x1F, 0x21, 0x23, 0x1D, 0x1E, 0x21, 0x23, 0x1C, 0x1E, 0x1C, 0x20
    },

    {
        0x4D, 0x1C, 0x4C, 0x1B, 0x4D, 0x1C, 0x4C, 0x1B, 0x4A, 0x1A, 0x4A, 0x1A, 0x4B, 0x1B, 0x4B, 0x1A, 0x4C, 0x1A, 0x4D, 0x1B, 0x4F, 0x1C, 0x4F, 0x1D, 0x50, 0x1C, 0x50, 0x1C, 0x4E, 0x1C, 0x4E, 0x1B, 0x4D, 0x1C, 0x4D, 0x1C, 0x4E, 0x1C, 0x4F, 0x1C, 0x50, 0x1C, 0x50, 0x1D, 0x50, 0x1D, 0x50, 0x1C, 0x4F, 0x1C, 0x4E, 0x1C, 0x4F, 0x1C, 0x50, 0x1C, 0x51, 0x1D, 0x51, 0x1D, 0x50, 0x1D, 0x50, 0x1D, 0x52, 0x1E, 0x52, 0x1E, 0x52, 0x1F, 0x53, 0x1E, 0x53, 0x1E, 0x54, 0x1E, 0x54, 0x1E, 0x54, 0x1E, 0x55, 0x1E, 0x54, 0x1E, 0x54, 0x1E, 0x54, 0x1F, 0x55, 0x1F, 0x54, 0x1F, 0x54, 0x1F, 0x53, 0x1E, 0x54, 0x1F, 0x54, 0x1F, 0x53, 0x1F, 0x4E, 0x1E, 0x47, 0x1D, 0x3F, 0x1A, 0x3B, 0x1A, 0x42, 0x1B, 0x48, 0x1C, 0x46, 0x1B, 0x3C, 0x19, 0x2D, 0x15, 0x21, 0x12, 0x1C, 0x11, 0x19, 0x10, 0x18, 0x10, 0x19, 0x14, 0x1C, 0x1A, 0x25, 0x26, 0x31, 0x32, 0x3D, 0x3F, 0x43, 0x45, 0x47, 0x49, 0x49, 0x4A, 0x4B, 0x4B, 0x4A, 0x4C, 0x49, 0x4A, 0x46, 0x45, 0x3B, 0x36, 0x29, 0x25, 0x20, 0x1A, 0x1C, 0x17, 0x1D, 0x14, 0x1A, 0x13, 0x1A, 0x12, 0x1B, 0x12, 0x1F, 0x13, 0x30, 0x18, 0x44, 0x1C, 0x4D, 0x1F, 0x51, 0x1F, 0x49, 0x1D, 0x3B, 0x1C, 0x3F, 0x1D, 0x50, 0x21, 0x57, 0x21, 0x58, 0x22, 0x5D, 0x22, 0x5D, 0x23, 0x5E, 0x23, 0x60, 0x23, 0x5F, 0x22, 0x5D, 0x22, 0x5E, 0x22, 0x5D, 0x22, 0x5E, 0x22, 0x5E, 0x22, 0x5F, 0x22, 0x5E, 0x23, 0x5E, 0x22, 0x5E, 0x22, 0x5F, 0x23, 0x5F, 0x23, 0x5F, 0x22, 0x5E, 0x22, 0x5D, 0x22, 0x60, 0x22, 0x5E, 0x21, 0x5F, 0x21, 0x5E, 0x22, 0x5F, 0x22, 0x61, 0x23, 0x61, 0x23, 0x61, 0x22, 0x60, 0x22, 0x61, 0x23, 0x60, 0x22, 0x60, 0x22, 0x61, 0x22, 0x60, 0x22, 0x60, 0x21, 0x60, 0x22, 0x62, 0x23, 0x63, 0x24, 0x63, 0x22, 0x61, 0x22, 0x60, 0x22, 0x60, 0x22, 0x61, 0x22, 0x61, 0x22, 0x5F, 0x21, 0x5E, 0x21, 0x5F, 0x21, 0x5F, 0x21, 0x5D, 0x21, 0x5C, 0x20, 0x5E, 0x20, 0x5B, 0x20, 0x5D, 0x20, 0x5D, 0x20, 0x5C, 0x20, 0x5D, 0x20, 0x5D, 0x21, 0x5E, 0x21, 0x5E, 0x21, 0x60, 0x22, 0x60, 0x22, 0x5D, 0x21, 0x5D, 0x21, 0x5E, 0x21, 0x5E, 0x21, 0x5D, 0x21, 0x5D, 0x21, 0x5C, 0x20, 0x5C, 0x21, 0x5C, 0x20, 0x5C, 0x21, 0x5C, 0x20, 0x5A, 0x20, 0x58, 0x1F, 0x58, 0x1F, 0x5B, 0x20, 0x5A, 0x21, 0x5C, 0x20, 0x5A, 0x20, 0x5D, 0x20, 0x5B, 0x20, 0x59, 0x20, 0x5A, 0x1F, 0x59, 0x1F, 0x59, 0x20, 0x58, 0x20, 0x45, 0x1C, 0x37, 0x1A, 0x2F, 0x17, 0x2B, 0x16, 0x29, 0x16, 0x25, 0x14, 0x23, 0x13, 0x2D, 0x16, 0x4D, 0x1E, 0x57, 0x21, 0x5B, 0x21, 0x5E, 0x22, 0x5C, 0x21, 0x5C, 0x22, 0x5B, 0x21, 0x58, 0x20, 0x58, 0x1F, 0x59, 0x20, 0x59, 0x20, 0x56, 0x1F, 0x54, 0x1E, 0x51, 0x1D, 0x53, 0x1E, 0x55, 0x1F, 0x55, 0x1E, 0x56, 0x1F, 0x56, 0x1F, 0x58, 0x20, 0x58, 0x1F, 0x58, 0x1F, 0x59, 0x20, 0x58, 0x20, 0x57, 0x1F, 0x58, 0x21, 0x5A, 0x20, 0x57, 0x20, 0x59, 0x20, 0x5A, 0x21, 0x59, 0x20, 0x57, 0x20, 0x5A, 0x20, 0x5A, 0x21, 0x5A, 0x20, 0x5A, 0x20, 0x57, 0x1F, 0x59, 0x1F, 0x57, 0x1F, 0x57, 0x1F, 0x56, 0x1F, 0x55, 0x1E, 0x58, 0x1F, 0x54, 0x1E, 0x56, 0x1F, 0x58, 0x1F, 0x57, 0x1F, 0x58, 0x1F, 0x55, 0x1E, 0x55, 0x1F, 0x55, 0x20, 0x56, 0x1F, 0x54, 0x1E, 0x56, 0x1F, 0x56, 0x1F, 0x56, 0x1E, 0x54, 0x1F, 0x55, 0x1F, 0x55, 0x1F, 0x55, 0x1E, 0x56, 0x22, 0x53, 0x1E, 0x53, 0x1F, 0x56, 0x1E, 0x54, 0x1E, 0x56, 0x1F, 0x52, 0x1E, 0x54, 0x1F, 0x54, 0x1F, 0x54, 0x1E, 0x53, 0x1F, 0x54, 0x1F, 0x55, 0x1E, 0x56, 0x20, 0x54, 0x1F, 0x53, 0x1E, 0x51, 0x1D, 0x53, 0x1E, 0x54, 0x1E, 0x50, 0x1D, 0x51, 0x1E, 0x51, 0x1D, 0x52, 0x1E, 0x52, 0x1E, 0x53, 0x1E, 0x53, 0x1E, 0x53, 0x1E, 0x53, 0x1E, 0x4E, 0x1D, 0x3F, 0x1A, 0x31, 0x18, 0x22, 0x14, 0x29, 0x17, 0x23, 0x15, 0x21, 0x14, 0x29, 0x17, 0x21, 0x14, 0x20, 0x14, 0x1F, 0x13, 0x25, 0x15, 0x20, 0x14, 0x23, 0x15, 0x21, 0x14, 0x20, 0x14, 0x23, 0x16, 0x21, 0x14, 0x20, 0x14, 0x21, 0x14, 0x21, 0x15, 0x22, 0x14, 0x20, 0x14, 0x23, 0x15, 0x20, 0x14, 0x24, 0x15, 0x1F, 0x12, 0x23, 0x16, 0x22, 0x14, 0x25, 0x16, 0x25, 0x15, 0x21, 0x14, 0x24, 0x16, 0x21, 0x14, 0x23, 0x15, 0x20, 0x13, 0x22, 0x15, 0x22, 0x15, 0x28, 0x18, 0x25, 0x16, 0x23, 0x15, 0x25, 0x17, 0x23, 0x15, 0x26, 0x16
    },

    {
        0x52, 0x49, 0x52, 0x49, 0x52, 0x4A, 0x51, 0x48, 0x52, 0x47, 0x50, 0x47, 0x50, 0x49, 0x52, 0x48, 0x52, 0x49, 0x54, 0x4A, 0x56, 0x4C, 0x56, 0x4C, 0x56, 0x4B, 0x56, 0x4B, 0x54, 0x4B, 0x54, 0x4A, 0x54, 0x4A, 0x54, 0x4A, 0x55, 0x4B, 0x55, 0x4A, 0x57, 0x4C, 0x57, 0x4D, 0x57, 0x4D, 0x56, 0x4C, 0x56, 0x4B, 0x56, 0x4B, 0x58, 0x4C, 0x58, 0x4C, 0x58, 0x4E, 0x58, 0x4E, 0x58, 0x4D, 0x57, 0x4E, 0x58, 0x4E, 0x58, 0x4F, 0x5A, 0x4F, 0x5A, 0x4F, 0x5A, 0x4F, 0x5B, 0x50, 0x5C, 0x50, 0x5C, 0x51, 0x5C, 0x52, 0x5C, 0x51, 0x5B, 0x50, 0x5A, 0x50, 0x5A, 0x51, 0x5A, 0x51, 0x5B, 0x51, 0x5A, 0x50, 0x5A, 0x50, 0x59, 0x4F, 0x56, 0x4D, 0x51, 0x48, 0x49, 0x40, 0x40, 0x39, 0x3C, 0x3A, 0x44, 0x42, 0x49, 0x45, 0x44, 0x3F, 0x3A, 0x33, 0x29, 0x26, 0x1D, 0x1E, 0x18, 0x1A, 0x16, 0x17, 0x15, 0x17, 0x16, 0x1A, 0x19, 0x1E, 0x1F, 0x27, 0x29, 0x33, 0x32, 0x3E, 0x38, 0x41, 0x3B, 0x44, 0x3B, 0x46, 0x3C, 0x47, 0x3D, 0x47, 0x3D, 0x46, 0x3A, 0x44, 0x33, 0x39, 0x25, 0x29, 0x1D, 0x1F, 0x19, 0x1C, 0x18, 0x1B, 0x16, 0x19, 0x16, 0x19, 0x17, 0x19, 0x19, 0x1C, 0x25, 0x2A, 0x3C, 0x3F, 0x49, 0x49, 0x50, 0x4E, 0x4C, 0x47, 0x3C, 0x38, 0x3B, 0x3B, 0x4C, 0x49, 0x58, 0x51, 0x5B, 0x54, 0x5F, 0x57, 0x61, 0x58, 0x61, 0x59, 0x64, 0x5B, 0x64, 0x58, 0x61, 0x57, 0x64, 0x59, 0x62, 0x58, 0x63, 0x59, 0x65, 0x59, 0x63, 0x5A, 0x64, 0x59, 0x63, 0x59, 0x63, 0x58, 0x64, 0x5A, 0x64, 0x5A, 0x64, 0x59, 0x63, 0x59, 0x63, 0x58, 0x65, 0x5A, 0x66, 0x59, 0x64, 0x59, 0x65, 0x5A, 0x66, 0x5A, 0x65, 0x5B, 0x66, 0x5A, 0x67, 0x5B, 0x66, 0x5A, 0x66, 0x59, 0x65, 0x59, 0x64, 0x5A, 0x66, 0x5A, 0x66, 0x5A, 0x64, 0x59, 0x66, 0x5B, 0x69, 0x5D, 0x69, 0x5C, 0x67, 0x5C, 0x66, 0x5A, 0x66, 0x59, 0x65, 0x5A, 0x66, 0x5B, 0x67, 0x5B, 0x66, 0x59, 0x64, 0x59, 0x65, 0x5A, 0x67, 0x5A, 0x65, 0x59, 0x63, 0x56, 0x65, 0x58, 0x63, 0x56, 0x64, 0x57, 0x64, 0x57, 0x62, 0x56, 0x62, 0x58, 0x63, 0x58, 0x64, 0x58, 0x64, 0x59, 0x65, 0x5A, 0x64, 0x59, 0x61, 0x58, 0x62, 0x58, 0x64, 0x59, 0x64, 0x59, 0x63, 0x58, 0x63, 0x56, 0x60, 0x56, 0x61, 0x57, 0x60, 0x56, 0x61, 0x56, 0x61, 0x56, 0x5F, 0x55, 0x5D, 0x54, 0x5C, 0x54, 0x61, 0x55, 0x60, 0x56, 0x62, 0x56, 0x60, 0x56, 0x62, 0x57, 0x60, 0x55, 0x5E, 0x53, 0x5E, 0x55, 0x5F, 0x54, 0x5F, 0x55, 0x5C, 0x50, 0x47, 0x3C, 0x38, 0x30, 0x2F, 0x29, 0x2A, 0x26, 0x28, 0x25, 0x25, 0x22, 0x25, 0x21, 0x30, 0x30, 0x4E, 0x4B, 0x5A, 0x54, 0x60, 0x57, 0x62, 0x56, 0x60, 0x55, 0x5E, 0x56, 0x60, 0x55, 0x5F, 0x54, 0x5F, 0x54, 0x5F, 0x54, 0x5E, 0x55, 0x5C, 0x53, 0x5A, 0x50, 0x59, 0x4E, 0x59, 0x4F, 0x59, 0x51, 0x5B, 0x50, 0x5B, 0x51, 0x5C, 0x52, 0x5F, 0x55, 0x5E, 0x54, 0x5D, 0x52, 0x5E, 0x53, 0x5D, 0x53, 0x5C, 0x50, 0x5E, 0x55, 0x5F, 0x54, 0x5C, 0x53, 0x5E, 0x53, 0x5E, 0x55, 0x5D, 0x53, 0x5C, 0x52, 0x5F, 0x55, 0x5F, 0x54, 0x5F, 0x56, 0x5F, 0x55, 0x5D, 0x52, 0x5F, 0x55, 0x5B, 0x52, 0x5C, 0x52, 0x5D, 0x52, 0x5C, 0x51, 0x5D, 0x52, 0x5C, 0x50, 0x5C, 0x50, 0x5D, 0x52, 0x5C, 0x51, 0x5C, 0x52, 0x59, 0x50, 0x59, 0x50, 0x5A, 0x51, 0x59, 0x51, 0x5A, 0x4F, 0x5B, 0x51, 0x5A, 0x51, 0x5C, 0x51, 0x5B, 0x51, 0x5A, 0x51, 0x5A, 0x51, 0x5A, 0x4F, 0x5A, 0x50, 0x58, 0x50, 0x59, 0x50, 0x5C, 0x52, 0x59, 0x4F, 0x5C, 0x51, 0x57, 0x4E, 0x59, 0x50, 0x59, 0x51, 0x5A, 0x50, 0x59, 0x50, 0x5A, 0x51, 0x5C, 0x52, 0x5B, 0x51, 0x5A, 0x50, 0x59, 0x4E, 0x57, 0x4E, 0x58, 0x4E, 0x59, 0x4F, 0x56, 0x4E, 0x57, 0x4F, 0x56, 0x4E, 0x57, 0x4E, 0x58, 0x4F, 0x59, 0x4F, 0x58, 0x4F, 0x58, 0x4F, 0x57, 0x4D, 0x53, 0x4A, 0x40, 0x39, 0x2F, 0x2B, 0x21, 0x21, 0x24, 0x26, 0x1F, 0x20, 0x1E, 0x1F, 0x22, 0x25, 0x1D, 0x1F, 0x1D, 0x1E, 0x1C, 0x1F, 0x21, 0x24, 0x1E, 0x1F, 0x1F, 0x22, 0x1E, 0x21, 0x1D, 0x20, 0x20, 0x24, 0x1D, 0x1E, 0x1E, 0x20, 0x1D, 0x1F, 0x1F, 0x22, 0x1E, 0x20, 0x1D, 0x1F, 0x20, 0x23, 0x1E, 0x21, 0x20, 0x22, 0x1D, 0x1F, 0x1F, 0x23, 0x1F, 0x20, 0x22, 0x26, 0x21, 0x22, 0x1E, 0x21, 0x21, 0x25, 0x1E, 0x22, 0x20, 0x21, 0x1C, 0x1E, 0x20, 0x23, 0x20, 0x22, 0x25, 0x2A, 0x21, 0x25, 0x20, 0x22, 0x21, 0x25, 0x20, 0x22, 0x21, 0x25
    },

    {
        0x4D, 0x1B, 0x4C, 0x1B, 0x4C, 0x1B, 0x4C, 0x1B, 0x4B, 0x1A, 0x4C, 0x1A, 0x4B, 0x1A, 0x4C, 0x1B, 0x4D, 0x1B, 0x4E, 0x1C, 0x4F, 0x1C, 0x4F, 0x1D, 0x50, 0x1D, 0x50, 0x1D, 0x4E, 0x1C, 0x4E, 0x1C, 0x4D, 0x1C, 0x4E, 0x1B, 0x4E, 0x1C, 0x4E, 0x1C, 0x4F, 0x1C, 0x4F, 0x1C, 0x4F, 0x1C, 0x50, 0x1C, 0x4F, 0x1C, 0x4F, 0x1C, 0x51, 0x1D, 0x51, 0x1D, 0x53, 0x1D, 0x52, 0x1D, 0x52, 0x1E, 0x52, 0x1D, 0x52, 0x1E, 0x52, 0x1E, 0x53, 0x1F, 0x52, 0x1E, 0x52, 0x1E, 0x53, 0x1E, 0x54, 0x1E, 0x54, 0x1F, 0x55, 0x1F, 0x55, 0x1E, 0x55, 0x1F, 0x54, 0x1F, 0x55, 0x1F, 0x55, 0x1F, 0x55, 0x1E, 0x54, 0x1F, 0x53, 0x1E, 0x51, 0x1E, 0x4E, 0x1D, 0x47, 0x1D, 0x40, 0x1B, 0x3A, 0x1A, 0x40, 0x1B, 0x49, 0x1C, 0x47, 0x1C, 0x3C, 0x19, 0x2E, 0x16, 0x22, 0x13, 0x1D, 0x11, 0x1A, 0x10, 0x18, 0x10, 0x18, 0x13, 0x1C, 0x19, 0x24, 0x25, 0x30, 0x33, 0x3D, 0x3F, 0x44, 0x45, 0x47, 0x48, 0x49, 0x4A, 0x4A, 0x4C, 0x4C, 0x4D, 0x4B, 0x4D, 0x4B, 0x4D, 0x4A, 0x4B, 0x48, 0x47, 0x3D, 0x37, 0x2B, 0x25, 0x21, 0x1B, 0x1F, 0x17, 0x1D, 0x15, 0x1A, 0x13, 0x19, 0x12, 0x1A, 0x11, 0x1E, 0x12, 0x2D, 0x17, 0x42, 0x1C, 0x4E, 0x1F, 0x54, 0x21, 0x4E, 0x1F, 0x3C, 0x1B, 0x3F, 0x1D, 0x4D, 0x20, 0x55, 0x21, 0x59, 0x21, 0x5C, 0x22, 0x5E, 0x23, 0x60, 0x23, 0x60, 0x22, 0x5F, 0x22, 0x5E, 0x22, 0x5F, 0x22, 0x5E, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x5F, 0x23, 0x61, 0x23, 0x61, 0x23, 0x5F, 0x23, 0x60, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x60, 0x22, 0x61, 0x22, 0x60, 0x22, 0x61, 0x22, 0x60, 0x22, 0x61, 0x23, 0x62, 0x23, 0x61, 0x23, 0x62, 0x23, 0x61, 0x22, 0x5F, 0x21, 0x60, 0x22, 0x60, 0x22, 0x62, 0x23, 0x5F, 0x22, 0x5F, 0x21, 0x62, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x60, 0x22, 0x5F, 0x21, 0x5F, 0x21, 0x60, 0x21, 0x61, 0x22, 0x60, 0x21, 0x5E, 0x20, 0x5E, 0x21, 0x5E, 0x20, 0x5F, 0x21, 0x5D, 0x20, 0x5D, 0x20, 0x5D, 0x20, 0x5E, 0x21, 0x5E, 0x20, 0x5B, 0x20, 0x5D, 0x20, 0x5D, 0x20, 0x5E, 0x20, 0x5F, 0x21, 0x5F, 0x22, 0x61, 0x23, 0x5F, 0x21, 0x5E, 0x21, 0x5F, 0x21, 0x5E, 0x21, 0x5E, 0x21, 0x5E, 0x20, 0x5D, 0x20, 0x5D, 0x21, 0x5F, 0x22, 0x5E, 0x21, 0x5D, 0x21, 0x5A, 0x20, 0x5A, 0x1F, 0x5A, 0x20, 0x5B, 0x20, 0x5D, 0x21, 0x5B, 0x20, 0x5B, 0x20, 0x5D, 0x20, 0x5A, 0x1F, 0x59, 0x1F, 0x58, 0x1F, 0x5A, 0x1F, 0x5A, 0x20, 0x58, 0x1F, 0x46, 0x1B, 0x33, 0x17, 0x2B, 0x16, 0x28, 0x15, 0x25, 0x14, 0x22, 0x12, 0x23, 0x13, 0x38, 0x1A, 0x52, 0x20, 0x58, 0x21, 0x5D, 0x22, 0x5E, 0x22, 0x5B, 0x21, 0x5D, 0x22, 0x5D, 0x21, 0x5C, 0x21, 0x5B, 0x20, 0x5A, 0x20, 0x5C, 0x21, 0x59, 0x20, 0x57, 0x1F, 0x55, 0x1E, 0x57, 0x1F, 0x55, 0x1E, 0x56, 0x1F, 0x57, 0x1F, 0x58, 0x1F, 0x5A, 0x1F, 0x59, 0x20, 0x59, 0x20, 0x5A, 0x20, 0x58, 0x1F, 0x58, 0x1F, 0x59, 0x21, 0x59, 0x20, 0x59, 0x20, 0x59, 0x20, 0x58, 0x1F, 0x58, 0x20, 0x5A, 0x20, 0x59, 0x20, 0x59, 0x21, 0x58, 0x20, 0x59, 0x20, 0x57, 0x1F, 0x58, 0x1F, 0x59, 0x20, 0x58, 0x20, 0x56, 0x1F, 0x56, 0x1F, 0x55, 0x1E, 0x56, 0x1E, 0x55, 0x1F, 0x56, 0x1F, 0x57, 0x1F, 0x57, 0x1F, 0x54, 0x1E, 0x55, 0x1E, 0x55, 0x1E, 0x54, 0x1E, 0x55, 0x1F, 0x55, 0x1F, 0x55, 0x1F, 0x56, 0x1E, 0x54, 0x1F, 0x57, 0x20, 0x56, 0x1F, 0x55, 0x1F, 0x54, 0x1E, 0x55, 0x1F, 0x55, 0x1F, 0x56, 0x1F, 0x54, 0x1E, 0x53, 0x1F, 0x54, 0x1E, 0x56, 0x1F, 0x55, 0x1F, 0x54, 0x1E, 0x55, 0x1F, 0x55, 0x1E, 0x55, 0x1F, 0x55, 0x1E, 0x55, 0x1E, 0x51, 0x1D, 0x51, 0x1D, 0x53, 0x1E, 0x52, 0x1E, 0x52, 0x1E, 0x52, 0x1E, 0x51, 0x1E, 0x51, 0x1D, 0x51, 0x1E, 0x53, 0x1E, 0x51, 0x1E, 0x52, 0x1E, 0x50, 0x1D, 0x4D, 0x1C, 0x3C, 0x19, 0x2B, 0x16, 0x23, 0x15, 0x26, 0x16, 0x23, 0x15, 0x2A, 0x18, 0x26, 0x15, 0x23, 0x14, 0x23, 0x15, 0x27, 0x16, 0x28, 0x17, 0x26, 0x15, 0x25, 0x17, 0x2A, 0x18, 0x2A, 0x17, 0x26, 0x15, 0x27, 0x17, 0x23, 0x15, 0x29, 0x18, 0x2B, 0x18, 0x27, 0x16, 0x24, 0x15, 0x29, 0x17, 0x28, 0x17, 0x26, 0x16, 0x26, 0x16, 0x26, 0x16, 0x27, 0x16, 0x2B, 0x17, 0x28, 0x16, 0x24, 0x15, 0x2B, 0x18, 0x22, 0x15, 0x26, 0x15, 0x20, 0x13, 0x26, 0x17, 0x26, 0x16, 0x28, 0x17, 0x26, 0x16, 0x21, 0x14, 0x29, 0x18, 0x26, 0x15, 0x21, 0x14
    },

    {
        0x52, 0x4A, 0x51, 0x48, 0x51, 0x48, 0x51, 0x49, 0x50, 0x48, 0x52, 0x48, 0x52, 0x48, 0x52, 0x48, 0x53, 0x4A, 0x54, 0x4A, 0x55, 0x4C, 0x57, 0x4C, 0x57, 0x4D, 0x56, 0x4C, 0x55, 0x4B, 0x54, 0x4A, 0x54, 0x4A, 0x56, 0x4A, 0x55, 0x4B, 0x55, 0x4B, 0x56, 0x4C, 0x57, 0x4D, 0x58, 0x4C, 0x57, 0x4C, 0x57, 0x4C, 0x57, 0x4C, 0x58, 0x4D, 0x59, 0x4E, 0x5A, 0x4E, 0x5B, 0x4F, 0x59, 0x4F, 0x59, 0x4E, 0x5A, 0x4E, 0x59, 0x4E, 0x5A, 0x4F, 0x59, 0x4F, 0x5B, 0x4E, 0x5A, 0x4F, 0x5A, 0x50, 0x5B, 0x50, 0x5B, 0x51, 0x5C, 0x51, 0x5C, 0x52, 0x5B, 0x50, 0x5B, 0x51, 0x5B, 0x50, 0x5B, 0x50, 0x5A, 0x4F, 0x59, 0x4E, 0x55, 0x4B, 0x51, 0x48, 0x49, 0x41, 0x40, 0x39, 0x3C, 0x39, 0x42, 0x40, 0x4A, 0x44, 0x46, 0x40, 0x39, 0x34, 0x2A, 0x27, 0x1D, 0x1D, 0x19, 0x1A, 0x16, 0x17, 0x15, 0x17, 0x15, 0x18, 0x19, 0x1E, 0x1F, 0x27, 0x28, 0x32, 0x32, 0x3E, 0x38, 0x42, 0x3A, 0x44, 0x3B, 0x45, 0x3C, 0x46, 0x3D, 0x48, 0x3D, 0x48, 0x3E, 0x48, 0x3D, 0x46, 0x3B, 0x45, 0x35, 0x3B, 0x27, 0x29, 0x1E, 0x20, 0x1A, 0x1E, 0x18, 0x1B, 0x16, 0x18, 0x15, 0x17, 0x16, 0x17, 0x18, 0x1A, 0x22, 0x27, 0x39, 0x3B, 0x49, 0x48, 0x52, 0x4F, 0x50, 0x4A, 0x3D, 0x39, 0x3C, 0x3A, 0x4A, 0x48, 0x55, 0x51, 0x5B, 0x54, 0x5D, 0x56, 0x60, 0x58, 0x63, 0x5B, 0x65, 0x5A, 0x63, 0x59, 0x64, 0x59, 0x65, 0x5A, 0x64, 0x59, 0x65, 0x5A, 0x65, 0x5A, 0x65, 0x5B, 0x66, 0x5B, 0x65, 0x5A, 0x64, 0x59, 0x65, 0x5B, 0x66, 0x59, 0x65, 0x59, 0x63, 0x59, 0x64, 0x59, 0x67, 0x5C, 0x66, 0x5B, 0x67, 0x5B, 0x65, 0x5A, 0x66, 0x5C, 0x66, 0x5D, 0x66, 0x5B, 0x68, 0x5C, 0x66, 0x5C, 0x65, 0x59, 0x65, 0x59, 0x65, 0x5A, 0x66, 0x5A, 0x65, 0x5A, 0x65, 0x59, 0x66, 0x5B, 0x65, 0x59, 0x66, 0x5A, 0x66, 0x5B, 0x66, 0x5A, 0x65, 0x58, 0x65, 0x5A, 0x69, 0x5C, 0x67, 0x5A, 0x65, 0x59, 0x63, 0x57, 0x65, 0x59, 0x65, 0x58, 0x64, 0x57, 0x63, 0x55, 0x64, 0x57, 0x64, 0x58, 0x64, 0x57, 0x63, 0x56, 0x64, 0x57, 0x63, 0x57, 0x64, 0x58, 0x64, 0x59, 0x64, 0x5A, 0x66, 0x5B, 0x63, 0x58, 0x64, 0x58, 0x63, 0x58, 0x64, 0x59, 0x64, 0x58, 0x64, 0x56, 0x62, 0x56, 0x61, 0x57, 0x65, 0x59, 0x63, 0x57, 0x62, 0x56, 0x60, 0x54, 0x5F, 0x54, 0x60, 0x55, 0x62, 0x56, 0x62, 0x56, 0x60, 0x56, 0x61, 0x56, 0x62, 0x55, 0x5F, 0x53, 0x5D, 0x53, 0x5C, 0x52, 0x5F, 0x54, 0x5F, 0x53, 0x5C, 0x51, 0x4C, 0x40, 0x36, 0x2E, 0x2D, 0x26, 0x29, 0x24, 0x26, 0x21, 0x23, 0x1F, 0x27, 0x25, 0x3B, 0x3C, 0x53, 0x4F, 0x5B, 0x54, 0x60, 0x57, 0x61, 0x56, 0x60, 0x56, 0x61, 0x57, 0x62, 0x57, 0x62, 0x57, 0x62, 0x57, 0x60, 0x56, 0x63, 0x57, 0x5F, 0x55, 0x5C, 0x53, 0x5C, 0x51, 0x5E, 0x54, 0x5B, 0x52, 0x5B, 0x52, 0x5D, 0x53, 0x5E, 0x53, 0x5E, 0x54, 0x5D, 0x53, 0x5E, 0x54, 0x5F, 0x54, 0x5E, 0x52, 0x5D, 0x53, 0x5E, 0x54, 0x5D, 0x52, 0x5E, 0x53, 0x5E, 0x53, 0x5F, 0x54, 0x5F, 0x53, 0x5F, 0x54, 0x60, 0x54, 0x5F, 0x55, 0x5F, 0x55, 0x5E, 0x54, 0x5E, 0x52, 0x5E, 0x54, 0x5F, 0x54, 0x5F, 0x53, 0x5E, 0x53, 0x5C, 0x51, 0x5C, 0x51, 0x5C, 0x4F, 0x5B, 0x50, 0x5D, 0x51, 0x5C, 0x52, 0x5C, 0x51, 0x58, 0x4F, 0x59, 0x4F, 0x5A, 0x50, 0x58, 0x4F, 0x5A, 0x50, 0x5B, 0x50, 0x5A, 0x4F, 0x5A, 0x50, 0x59, 0x4F, 0x5C, 0x54, 0x5B, 0x53, 0x59, 0x51, 0x59, 0x51, 0x5B, 0x51, 0x5C, 0x51, 0x5B, 0x51, 0x59, 0x50, 0x58, 0x4E, 0x59, 0x4E, 0x5B, 0x52, 0x59, 0x50, 0x5B, 0x50, 0x5A, 0x51, 0x5C, 0x52, 0x5D, 0x52, 0x5B, 0x52, 0x5C, 0x50, 0x58, 0x4C, 0x58, 0x4D, 0x59, 0x4F, 0x5A, 0x4E, 0x58, 0x4E, 0x57, 0x4D, 0x56, 0x4D, 0x57, 0x4D, 0x57, 0x4E, 0x59, 0x4C, 0x5A, 0x4F, 0x59, 0x4F, 0x56, 0x4C, 0x53, 0x49, 0x3D, 0x35, 0x2B, 0x28, 0x22, 0x22, 0x23, 0x25, 0x21, 0x25, 0x25, 0x2A, 0x20, 0x22, 0x1F, 0x21, 0x1F, 0x24, 0x23, 0x26, 0x22, 0x26, 0x21, 0x22, 0x21, 0x27, 0x26, 0x29, 0x25, 0x29, 0x20, 0x21, 0x24, 0x27, 0x21, 0x24, 0x25, 0x29, 0x25, 0x28, 0x22, 0x26, 0x20, 0x21, 0x24, 0x28, 0x23, 0x26, 0x20, 0x24, 0x22, 0x24, 0x21, 0x24, 0x24, 0x27, 0x24, 0x27, 0x23, 0x26, 0x20, 0x21, 0x26, 0x29, 0x1F, 0x21, 0x21, 0x23, 0x1D, 0x1E, 0x22, 0x27, 0x21, 0x23, 0x21, 0x23, 0x20, 0x22, 0x1C, 0x1E, 0x24, 0x29, 0x1F, 0x21, 0x1C, 0x1D
    },

    {
        0x4D, 0x1B, 0x4C, 0x1B, 0x4B, 0x1B, 0x4B, 0x1A, 0x4B, 0x1A, 0x4C, 0x1B, 0x4C, 0x1B, 0x4C, 0x1B, 0x4E, 0x1B, 0x4E, 0x1B, 0x4F, 0x1C, 0x50, 0x1C, 0x50, 0x1D, 0x51, 0x1D, 0x4F, 0x1C, 0x4E, 0x1B, 0x4E, 0x1C, 0x4F, 0x1C, 0x4F, 0x1C, 0x4F, 0x1C, 0x4F, 0x1D, 0x50, 0x1D, 0x50, 0x1D, 0x50, 0x1C, 0x4F, 0x1C, 0x4F, 0x1C, 0x50, 0x1C, 0x51, 0x1D, 0x52, 0x1D, 0x52, 0x1E, 0x52, 0x1E, 0x52, 0x1E, 0x52, 0x1F, 0x52, 0x1F, 0x52, 0x1E, 0x51, 0x1E, 0x52, 0x1E, 0x53, 0x1E, 0x54, 0x1E, 0x54, 0x1E, 0x55, 0x1F, 0x56, 0x1F, 0x55, 0x1F, 0x56, 0x1F, 0x55, 0x1F, 0x54, 0x1E, 0x54, 0x1F, 0x53, 0x1F, 0x52, 0x1E, 0x4F, 0x1E, 0x49, 0x1D, 0x40, 0x1B, 0x3B, 0x1A, 0x40, 0x1A, 0x47, 0x1C, 0x46, 0x1B, 0x3D, 0x19, 0x30, 0x17, 0x23, 0x13, 0x1D, 0x11, 0x1A, 0x10, 0x18, 0x11, 0x18, 0x13, 0x1B, 0x19, 0x22, 0x23, 0x2F, 0x31, 0x3D, 0x3E, 0x43, 0x45, 0x47, 0x49, 0x49, 0x4A, 0x4A, 0x4C, 0x4C, 0x4D, 0x4C, 0x4E, 0x4D, 0x4E, 0x4C, 0x4E, 0x4B, 0x4D, 0x4A, 0x4B, 0x49, 0x47, 0x3E, 0x38, 0x2C, 0x27, 0x22, 0x1C, 0x1D, 0x16, 0x1A, 0x14, 0x19, 0x12, 0x19, 0x11, 0x1A, 0x12, 0x1E, 0x12, 0x2B, 0x18, 0x41, 0x1C, 0x4E, 0x1F, 0x54, 0x21, 0x4F, 0x1F, 0x3E, 0x1B, 0x3E, 0x1D, 0x4D, 0x20, 0x58, 0x21, 0x59, 0x22, 0x5C, 0x23, 0x61, 0x24, 0x61, 0x23, 0x60, 0x23, 0x5E, 0x22, 0x5E, 0x23, 0x61, 0x23, 0x62, 0x23, 0x60, 0x23, 0x60, 0x24, 0x60, 0x23, 0x61, 0x23, 0x60, 0x23, 0x5F, 0x22, 0x60, 0x22, 0x5F, 0x22, 0x5E, 0x23, 0x5F, 0x22, 0x5E, 0x22, 0x60, 0x22, 0x62, 0x23, 0x61, 0x22, 0x61, 0x22, 0x61, 0x23, 0x61, 0x22, 0x60, 0x23, 0x62, 0x22, 0x60, 0x21, 0x5F, 0x21, 0x5F, 0x21, 0x5F, 0x22, 0x5F, 0x22, 0x60, 0x21, 0x60, 0x22, 0x60, 0x22, 0x5F, 0x22, 0x60, 0x22, 0x5F, 0x21, 0x5F, 0x21, 0x5F, 0x21, 0x60, 0x21, 0x5F, 0x21, 0x5E, 0x20, 0x5E, 0x21, 0x5D, 0x21, 0x5F, 0x21, 0x5E, 0x20, 0x5C, 0x20, 0x5B, 0x20, 0x5D, 0x20, 0x5C, 0x20, 0x5B, 0x20, 0x5C, 0x20, 0x5C, 0x20, 0x5F, 0x20, 0x5D, 0x20, 0x5E, 0x21, 0x5E, 0x22, 0x5E, 0x21, 0x5C, 0x21, 0x5D, 0x21, 0x5E, 0x21, 0x5F, 0x21, 0x60, 0x21, 0x5D, 0x21, 0x5B, 0x21, 0x60, 0x22, 0x5D, 0x21, 0x5B, 0x20, 0x5B, 0x20, 0x5B, 0x21, 0x5D, 0x22, 0x5E, 0x22, 0x5E, 0x22, 0x5E, 0x21, 0x5C, 0x20, 0x5C, 0x20, 0x5A, 0x1F, 0x58, 0x1F, 0x59, 0x1F, 0x5B, 0x20, 0x5A, 0x1F, 0x58, 0x1F, 0x50, 0x1D, 0x38, 0x17, 0x2A, 0x14, 0x25, 0x14, 0x23, 0x12, 0x24, 0x13, 0x2D, 0x16, 0x47, 0x1C, 0x54, 0x20, 0x59, 0x22, 0x5F, 0x23, 0x5F, 0x23, 0x5B, 0x22, 0x5B, 0x21, 0x5C, 0x21, 0x5C, 0x21, 0x5C, 0x21, 0x5D, 0x20, 0x5E, 0x21, 0x5A, 0x20, 0x57, 0x1F, 0x57, 0x1F, 0x59, 0x20, 0x57, 0x1F, 0x59, 0x1F, 0x59, 0x20, 0x5B, 0x20, 0x5B, 0x20, 0x5A, 0x21, 0x5A, 0x20, 0x5A, 0x20, 0x59, 0x20, 0x58, 0x1F, 0x59, 0x20, 0x58, 0x20, 0x58, 0x20, 0x59, 0x20, 0x58, 0x20, 0x5B, 0x21, 0x58, 0x20, 0x5B, 0x21, 0x58, 0x20, 0x59, 0x20, 0x5A, 0x20, 0x57, 0x1F, 0x59, 0x20, 0x5A, 0x21, 0x58, 0x1F, 0x57, 0x1F, 0x55, 0x1E, 0x55, 0x1E, 0x53, 0x1E, 0x55, 0x1F, 0x56, 0x1F, 0x58, 0x1F, 0x57, 0x1F, 0x55, 0x1E, 0x55, 0x1F, 0x54, 0x1E, 0x55, 0x1F, 0x54, 0x1F, 0x54, 0x1E, 0x55, 0x1F, 0x55, 0x1F, 0x55, 0x20, 0x57, 0x21, 0x58, 0x20, 0x55, 0x1E, 0x53, 0x1F, 0x56, 0x1F, 0x56, 0x1F, 0x55, 0x1F, 0x53, 0x1E, 0x54, 0x1F, 0x53, 0x1E, 0x56, 0x1F, 0x56, 0x1F, 0x56, 0x1F, 0x55, 0x1E, 0x55, 0x1E, 0x55, 0x1F, 0x55, 0x1E, 0x51, 0x1D, 0x51, 0x1E, 0x51, 0x1D, 0x51, 0x1E, 0x53, 0x1E, 0x52, 0x1E, 0x53, 0x1E, 0x50, 0x1D, 0x51, 0x1E, 0x52, 0x1D, 0x51, 0x1D, 0x52, 0x1D, 0x51, 0x1D, 0x51, 0x1D, 0x4F, 0x1D, 0x3A, 0x18, 0x2D, 0x17, 0x23, 0x15, 0x2B, 0x18, 0x2A, 0x17, 0x24, 0x14, 0x24, 0x15, 0x23, 0x15, 0x28, 0x17, 0x27, 0x16, 0x26, 0x16, 0x21, 0x14, 0x29, 0x18, 0x2A, 0x17, 0x23, 0x15, 0x20, 0x14, 0x29, 0x16, 0x24, 0x16, 0x2C, 0x18, 0x24, 0x15, 0x26, 0x16, 0x20, 0x15, 0x2A, 0x18, 0x24, 0x14, 0x25, 0x16, 0x23, 0x14, 0x26, 0x17, 0x28, 0x16, 0x20, 0x13, 0x28, 0x17, 0x23, 0x15, 0x28, 0x16, 0x1F, 0x13, 0x23, 0x14, 0x20, 0x14, 0x27, 0x16, 0x20, 0x14, 0x20, 0x14, 0x23, 0x14, 0x1F, 0x14, 0x26, 0x16, 0x1F, 0x13, 0x20, 0x13
    },

    {
        0x52, 0x49, 0x52, 0x49, 0x52, 0x49, 0x51, 0x47, 0x51, 0x48, 0x52, 0x48, 0x53, 0x4A, 0x54, 0x49, 0x54, 0x4A, 0x54, 0x4A, 0x56, 0x4B, 0x57, 0x4C, 0x56, 0x4D, 0x56, 0x4C, 0x55, 0x4A, 0x55, 0x4B, 0x56, 0x4C, 0x56, 0x4B, 0x56, 0x4B, 0x56, 0x4C, 0x57, 0x4C, 0x58, 0x4D, 0x59, 0x4D, 0x58, 0x4C, 0x58, 0x4C, 0x58, 0x4C, 0x59, 0x4C, 0x5A, 0x4E, 0x5A, 0x4E, 0x5A, 0x4F, 0x5A, 0x4F, 0x5A, 0x4E, 0x5A, 0x4F, 0x59, 0x4E, 0x5A, 0x4E, 0x59, 0x4E, 0x5B, 0x4F, 0x5A, 0x4F, 0x5A, 0x50, 0x5B, 0x50, 0x5C, 0x51, 0x5D, 0x52, 0x5C, 0x51, 0x5C, 0x51, 0x5C, 0x51, 0x5B, 0x50, 0x5A, 0x50, 0x58, 0x4F, 0x57, 0x4D, 0x52, 0x48, 0x4C, 0x43, 0x42, 0x3A, 0x3C, 0x39, 0x41, 0x3F, 0x49, 0x44, 0x46, 0x40, 0x3C, 0x36, 0x2C, 0x29, 0x1F, 0x1E, 0x1A, 0x1B, 0x16, 0x18, 0x15, 0x18, 0x15, 0x18, 0x18, 0x1C, 0x1D, 0x25, 0x27, 0x31, 0x32, 0x3C, 0x37, 0x41, 0x3A, 0x43, 0x3C, 0x46, 0x3D, 0x46, 0x3E, 0x48, 0x3E, 0x48, 0x3F, 0x49, 0x3F, 0x49, 0x3E, 0x48, 0x3E, 0x47, 0x3C, 0x45, 0x35, 0x3C, 0x28, 0x2C, 0x1F, 0x21, 0x1A, 0x1B, 0x17, 0x19, 0x16, 0x18, 0x15, 0x18, 0x16, 0x18, 0x18, 0x1A, 0x22, 0x27, 0x38, 0x3B, 0x49, 0x48, 0x54, 0x4E, 0x51, 0x4C, 0x41, 0x3C, 0x3B, 0x3A, 0x49, 0x48, 0x58, 0x52, 0x5B, 0x54, 0x5F, 0x57, 0x63, 0x5B, 0x66, 0x5B, 0x64, 0x5A, 0x64, 0x5A, 0x64, 0x5A, 0x67, 0x5B, 0x66, 0x5B, 0x65, 0x5B, 0x66, 0x5B, 0x67, 0x5A, 0x66, 0x5B, 0x66, 0x59, 0x65, 0x5A, 0x66, 0x5A, 0x65, 0x5A, 0x65, 0x5A, 0x63, 0x5B, 0x64, 0x58, 0x68, 0x5B, 0x69, 0x5B, 0x66, 0x5A, 0x67, 0x5C, 0x68, 0x5C, 0x66, 0x5A, 0x66, 0x5B, 0x69, 0x5C, 0x67, 0x5A, 0x66, 0x5A, 0x65, 0x59, 0x63, 0x59, 0x64, 0x5A, 0x65, 0x59, 0x65, 0x5A, 0x66, 0x5B, 0x66, 0x5A, 0x65, 0x5A, 0x65, 0x58, 0x65, 0x58, 0x64, 0x59, 0x67, 0x5A, 0x65, 0x59, 0x64, 0x57, 0x65, 0x59, 0x63, 0x58, 0x65, 0x59, 0x64, 0x57, 0x63, 0x57, 0x61, 0x55, 0x64, 0x58, 0x63, 0x57, 0x61, 0x56, 0x63, 0x56, 0x63, 0x57, 0x65, 0x58, 0x64, 0x58, 0x63, 0x57, 0x63, 0x59, 0x62, 0x58, 0x62, 0x58, 0x63, 0x58, 0x63, 0x57, 0x66, 0x5A, 0x65, 0x5A, 0x64, 0x57, 0x61, 0x57, 0x64, 0x59, 0x61, 0x56, 0x60, 0x56, 0x60, 0x55, 0x62, 0x57, 0x62, 0x57, 0x63, 0x58, 0x63, 0x58, 0x64, 0x59, 0x63, 0x56, 0x62, 0x56, 0x61, 0x54, 0x5F, 0x55, 0x5E, 0x53, 0x5F, 0x54, 0x60, 0x54, 0x5E, 0x52, 0x58, 0x4C, 0x3F, 0x34, 0x30, 0x28, 0x29, 0x23, 0x27, 0x21, 0x28, 0x25, 0x34, 0x33, 0x4C, 0x4A, 0x57, 0x51, 0x5D, 0x56, 0x63, 0x5A, 0x64, 0x58, 0x60, 0x56, 0x60, 0x57, 0x60, 0x57, 0x62, 0x56, 0x62, 0x57, 0x62, 0x58, 0x62, 0x58, 0x60, 0x55, 0x5D, 0x53, 0x5E, 0x53, 0x5F, 0x54, 0x5D, 0x52, 0x60, 0x53, 0x60, 0x54, 0x5F, 0x55, 0x60, 0x55, 0x5F, 0x54, 0x5F, 0x54, 0x5F, 0x54, 0x5F, 0x53, 0x5D, 0x52, 0x5E, 0x52, 0x5E, 0x52, 0x5E, 0x53, 0x5F, 0x54, 0x5F, 0x52, 0x60, 0x54, 0x5E, 0x54, 0x60, 0x56, 0x5E, 0x55, 0x5F, 0x53, 0x60, 0x54, 0x5E, 0x52, 0x5E, 0x54, 0x60, 0x55, 0x5F, 0x54, 0x5D, 0x52, 0x5D, 0x50, 0x5B, 0x51, 0x58, 0x4E, 0x5B, 0x51, 0x5D, 0x53, 0x5E, 0x54, 0x5D, 0x52, 0x59, 0x4F, 0x5B, 0x50, 0x5A, 0x50, 0x5B, 0x50, 0x5B, 0x50, 0x5A, 0x4F, 0x5C, 0x51, 0x5B, 0x52, 0x59, 0x51, 0x5C, 0x54, 0x5D, 0x53, 0x5B, 0x50, 0x59, 0x50, 0x5C, 0x51, 0x5B, 0x50, 0x59, 0x50, 0x5A, 0x4F, 0x59, 0x4F, 0x59, 0x4F, 0x5C, 0x51, 0x5C, 0x52, 0x5C, 0x51, 0x5B, 0x50, 0x5C, 0x51, 0x5B, 0x51, 0x5A, 0x50, 0x57, 0x4C, 0x56, 0x4C, 0x58, 0x4E, 0x58, 0x4D, 0x59, 0x4F, 0x59, 0x4F, 0x58, 0x4F, 0x56, 0x4B, 0x57, 0x4E, 0x58, 0x4E, 0x57, 0x4C, 0x58, 0x4D, 0x56, 0x4E, 0x56, 0x4C, 0x55, 0x4A, 0x3B, 0x32, 0x2C, 0x29, 0x21, 0x22, 0x26, 0x29, 0x24, 0x26, 0x1E, 0x1E, 0x21, 0x25, 0x1E, 0x20, 0x22, 0x28, 0x21, 0x21, 0x21, 0x23, 0x1D, 0x1E, 0x23, 0x29, 0x23, 0x24, 0x1F, 0x1F, 0x1D, 0x20, 0x23, 0x24, 0x20, 0x24, 0x26, 0x27, 0x1E, 0x1F, 0x20, 0x22, 0x1E, 0x21, 0x24, 0x25, 0x20, 0x20, 0x20, 0x24, 0x1F, 0x20, 0x21, 0x23, 0x21, 0x22, 0x1D, 0x1E, 0x25, 0x27, 0x1E, 0x22, 0x21, 0x22, 0x1C, 0x1C, 0x20, 0x22, 0x1D, 0x1F, 0x20, 0x22, 0x1E, 0x1F, 0x1D, 0x20, 0x20, 0x21, 0x1C, 0x20, 0x21, 0x23, 0x1C, 0x1F, 0x1E, 0x1F
    },

    {
        0x4C, 0x1B, 0x4B, 0x1B, 0x4C, 0x1B, 0x4C, 0x1B, 0x4B, 0x1A, 0x4B, 0x1B, 0x4C, 0x1B, 0x4D, 0x1B, 0x4E, 0x1B, 0x4E, 0x1B, 0x4F, 0x1C, 0x4F, 0x1C, 0x4F, 0x1C, 0x4F, 0x1D, 0x4E, 0x1C, 0x4E, 0x1C, 0x50, 0x1C, 0x4E, 0x1C, 0x4F, 0x1C, 0x4F, 0x1D, 0x50, 0x1D, 0x4F, 0x1C, 0x4F, 0x1D, 0x50, 0x1C, 0x50, 0x1C, 0x4F, 0x1D, 0x50, 0x1D, 0x51, 0x1D, 0x51, 0x1D, 0x52, 0x1E, 0x52, 0x1E, 0x52, 0x1E, 0x52, 0x1E, 0x53, 0x1E, 0x52, 0x1E, 0x52, 0x1E, 0x54, 0x1E, 0x53, 0x1E, 0x52, 0x1E, 0x53, 0x1F, 0x55, 0x1F, 0x56, 0x1F, 0x56, 0x20, 0x55, 0x1F, 0x55, 0x1F, 0x55, 0x1F, 0x54, 0x1F, 0x52, 0x1E, 0x4E, 0x1D, 0x49, 0x1C, 0x42, 0x1B, 0x3B, 0x1A, 0x3F, 0x1A, 0x48, 0x1C, 0x46, 0x1B, 0x3D, 0x19, 0x31, 0x16, 0x24, 0x14, 0x1E, 0x12, 0x1B, 0x11, 0x19, 0x11, 0x18, 0x13, 0x1B, 0x19, 0x22, 0x23, 0x2C, 0x2F, 0x3A, 0x3D, 0x43, 0x45, 0x45, 0x48, 0x48, 0x4A, 0x4B, 0x4C, 0x4B, 0x4E, 0x4C, 0x4E, 0x4D, 0x4F, 0x4E, 0x4F, 0x4E, 0x50, 0x4E, 0x4F, 0x4C, 0x4E, 0x4B, 0x4C, 0x48, 0x47, 0x3F, 0x3B, 0x2E, 0x28, 0x22, 0x1C, 0x1D, 0x17, 0x1A, 0x14, 0x19, 0x12, 0x19, 0x12, 0x1A, 0x12, 0x1D, 0x13, 0x2B, 0x18, 0x40, 0x1C, 0x4E, 0x1F, 0x53, 0x1F, 0x4E, 0x1F, 0x3E, 0x1B, 0x3D, 0x1C, 0x4E, 0x20, 0x57, 0x22, 0x5B, 0x22, 0x5E, 0x23, 0x5E, 0x23, 0x5F, 0x23, 0x5F, 0x23, 0x60, 0x23, 0x60, 0x23, 0x61, 0x23, 0x62, 0x23, 0x61, 0x24, 0x61, 0x23, 0x61, 0x23, 0x61, 0x23, 0x60, 0x23, 0x61, 0x22, 0x60, 0x22, 0x5F, 0x22, 0x5F, 0x23, 0x5F, 0x22, 0x60, 0x22, 0x61, 0x22, 0x62, 0x22, 0x61, 0x23, 0x61, 0x22, 0x60, 0x22, 0x60, 0x23, 0x60, 0x22, 0x60, 0x21, 0x5F, 0x22, 0x5F, 0x21, 0x5E, 0x21, 0x5F, 0x22, 0x60, 0x22, 0x60, 0x22, 0x61, 0x23, 0x61, 0x23, 0x61, 0x22, 0x61, 0x22, 0x61, 0x22, 0x5F, 0x22, 0x5E, 0x21, 0x5E, 0x21, 0x5D, 0x21, 0x5E, 0x21, 0x5E, 0x21, 0x5E, 0x21, 0x5F, 0x21, 0x5D, 0x21, 0x5C, 0x20, 0x5D, 0x21, 0x5F, 0x21, 0x5C, 0x20, 0x5D, 0x20, 0x5D, 0x21, 0x5E, 0x21, 0x5E, 0x21, 0x5C, 0x20, 0x5D, 0x21, 0x5E, 0x21, 0x5E, 0x21, 0x5D, 0x20, 0x5B, 0x20, 0x5E, 0x22, 0x5F, 0x22, 0x5E, 0x22, 0x5F, 0x22, 0x5C, 0x21, 0x5C, 0x21, 0x5D, 0x21, 0x5D, 0x21, 0x5E, 0x21, 0x5D, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x61, 0x23, 0x5F, 0x21, 0x5E, 0x21, 0x5A, 0x20, 0x5A, 0x20, 0x5B, 0x20, 0x5C, 0x20, 0x5A, 0x20, 0x59, 0x1F, 0x58, 0x1F, 0x4D, 0x1C, 0x38, 0x17, 0x2E, 0x15, 0x2D, 0x15, 0x34, 0x17, 0x46, 0x1C, 0x53, 0x1E, 0x55, 0x1F, 0x59, 0x21, 0x5E, 0x23, 0x5F, 0x22, 0x5C, 0x22, 0x5D, 0x21, 0x5B, 0x22, 0x5D, 0x21, 0x5C, 0x21, 0x5D, 0x21, 0x5C, 0x21, 0x5A, 0x20, 0x58, 0x20, 0x58, 0x20, 0x59, 0x20, 0x58, 0x20, 0x59, 0x20, 0x58, 0x20, 0x58, 0x20, 0x59, 0x20, 0x58, 0x20, 0x5A, 0x20, 0x59, 0x21, 0x59, 0x20, 0x59, 0x20, 0x57, 0x1F, 0x57, 0x20, 0x58, 0x20, 0x59, 0x20, 0x59, 0x20, 0x5A, 0x21, 0x5B, 0x21, 0x5A, 0x21, 0x5A, 0x21, 0x59, 0x21, 0x59, 0x21, 0x59, 0x20, 0x59, 0x1F, 0x58, 0x20, 0x5B, 0x20, 0x57, 0x1F, 0x58, 0x20, 0x57, 0x1F, 0x54, 0x1E, 0x56, 0x1F, 0x56, 0x1E, 0x56, 0x1F, 0x56, 0x1F, 0x55, 0x1F, 0x57, 0x20, 0x57, 0x20, 0x57, 0x1F, 0x56, 0x1F, 0x56, 0x1F, 0x57, 0x20, 0x55, 0x1F, 0x56, 0x1F, 0x58, 0x21, 0x56, 0x20, 0x57, 0x20, 0x57, 0x20, 0x57, 0x1F, 0x55, 0x1F, 0x53, 0x1F, 0x54, 0x1F, 0x53, 0x1F, 0x55, 0x1F, 0x56, 0x1F, 0x56, 0x20, 0x55, 0x1F, 0x53, 0x1F, 0x56, 0x1F, 0x55, 0x1F, 0x52, 0x1E, 0x51, 0x1E, 0x52, 0x1E, 0x53, 0x1E, 0x53, 0x1E, 0x53, 0x1F, 0x53, 0x1F, 0x53, 0x1F, 0x50, 0x1D, 0x52, 0x1F, 0x52, 0x1E, 0x52, 0x1D, 0x51, 0x1D, 0x51, 0x1E, 0x51, 0x1D, 0x4F, 0x1D, 0x38, 0x18, 0x2A, 0x16, 0x23, 0x15, 0x27, 0x16, 0x23, 0x15, 0x1F, 0x15, 0x27, 0x17, 0x22, 0x15, 0x26, 0x16, 0x22, 0x15, 0x24, 0x15, 0x20, 0x14, 0x27, 0x17, 0x23, 0x15, 0x20, 0x13, 0x22, 0x15, 0x24, 0x15, 0x26, 0x17, 0x25, 0x16, 0x20, 0x15, 0x24, 0x15, 0x23, 0x15, 0x23, 0x15, 0x24, 0x15, 0x25, 0x15, 0x22, 0x15, 0x25, 0x16, 0x26, 0x15, 0x21, 0x14, 0x26, 0x16, 0x25, 0x16, 0x23, 0x15, 0x20, 0x14, 0x29, 0x17, 0x24, 0x15, 0x23, 0x15, 0x26, 0x15, 0x26, 0x17, 0x25, 0x15, 0x26, 0x16, 0x26, 0x16, 0x26, 0x16, 0x23, 0x14
    },

    {
        0x52, 0x49, 0x51, 0x48, 0x52, 0x48, 0x52, 0x49, 0x51, 0x48, 0x52, 0x48, 0x53, 0x49, 0x54, 0x4A, 0x55, 0x4B, 0x54, 0x4B, 0x55, 0x4C, 0x56, 0x4B, 0x56, 0x4C, 0x55, 0x4C, 0x55, 0x4B, 0x55, 0x4A, 0x56, 0x4C, 0x57, 0x4C, 0x56, 0x4C, 0x57, 0x4C, 0x59, 0x4D, 0x58, 0x4D, 0x58, 0x4D, 0x57, 0x4C, 0x57, 0x4C, 0x57, 0x4C, 0x5A, 0x4D, 0x5A, 0x4E, 0x5A, 0x4E, 0x5A, 0x4F, 0x59, 0x4D, 0x5A, 0x4F, 0x5B, 0x50, 0x5A, 0x4F, 0x5B, 0x4F, 0x5A, 0x4F, 0x5B, 0x4F, 0x5A, 0x4F, 0x5B, 0x4F, 0x5B, 0x4F, 0x5B, 0x51, 0x5C, 0x51, 0x5C, 0x52, 0x5C, 0x51, 0x5C, 0x51, 0x5B, 0x50, 0x59, 0x50, 0x56, 0x4D, 0x51, 0x48, 0x4B, 0x42, 0x42, 0x3B, 0x3B, 0x38, 0x41, 0x3E, 0x49, 0x45, 0x46, 0x40, 0x3B, 0x36, 0x2D, 0x28, 0x1F, 0x1F, 0x1B, 0x1B, 0x17, 0x19, 0x15, 0x17, 0x15, 0x17, 0x17, 0x1C, 0x1D, 0x24, 0x25, 0x2F, 0x31, 0x3B, 0x37, 0x41, 0x3A, 0x44, 0x3B, 0x46, 0x3D, 0x47, 0x3F, 0x49, 0x3F, 0x49, 0x3F, 0x49, 0x40, 0x4A, 0x3F, 0x49, 0x40, 0x49, 0x3F, 0x48, 0x3E, 0x47, 0x3B, 0x45, 0x36, 0x3D, 0x2A, 0x2C, 0x1F, 0x21, 0x1A, 0x1C, 0x16, 0x19, 0x15, 0x18, 0x15, 0x17, 0x16, 0x18, 0x18, 0x1A, 0x21, 0x26, 0x38, 0x3B, 0x4A, 0x49, 0x52, 0x4E, 0x50, 0x4B, 0x41, 0x3B, 0x39, 0x37, 0x49, 0x47, 0x56, 0x52, 0x5D, 0x55, 0x61, 0x59, 0x62, 0x58, 0x63, 0x59, 0x65, 0x5A, 0x66, 0x5A, 0x66, 0x5A, 0x66, 0x5A, 0x65, 0x5B, 0x67, 0x5C, 0x66, 0x5B, 0x67, 0x5C, 0x67, 0x5C, 0x66, 0x5A, 0x67, 0x5A, 0x67, 0x59, 0x64, 0x58, 0x65, 0x5A, 0x65, 0x59, 0x66, 0x5A, 0x68, 0x5B, 0x68, 0x5B, 0x67, 0x5A, 0x66, 0x5C, 0x65, 0x5A, 0x66, 0x5B, 0x67, 0x5C, 0x66, 0x59, 0x65, 0x5A, 0x65, 0x59, 0x64, 0x5A, 0x64, 0x5A, 0x67, 0x5B, 0x67, 0x5C, 0x67, 0x5C, 0x68, 0x5C, 0x66, 0x5B, 0x67, 0x5B, 0x67, 0x5A, 0x66, 0x59, 0x64, 0x59, 0x65, 0x56, 0x64, 0x57, 0x64, 0x58, 0x65, 0x58, 0x63, 0x57, 0x63, 0x59, 0x64, 0x57, 0x63, 0x56, 0x64, 0x58, 0x64, 0x58, 0x64, 0x57, 0x65, 0x58, 0x64, 0x57, 0x64, 0x58, 0x65, 0x58, 0x63, 0x55, 0x64, 0x57, 0x63, 0x58, 0x64, 0x57, 0x63, 0x58, 0x61, 0x55, 0x63, 0x59, 0x66, 0x59, 0x64, 0x59, 0x64, 0x59, 0x64, 0x57, 0x63, 0x57, 0x62, 0x57, 0x62, 0x58, 0x62, 0x57, 0x62, 0x58, 0x63, 0x59, 0x63, 0x59, 0x66, 0x5B, 0x65, 0x59, 0x62, 0x56, 0x62, 0x55, 0x61, 0x55, 0x61, 0x55, 0x60, 0x55, 0x60, 0x54, 0x60, 0x54, 0x5F, 0x53, 0x55, 0x49, 0x41, 0x39, 0x37, 0x30, 0x36, 0x30, 0x3E, 0x3A, 0x4D, 0x48, 0x58, 0x50, 0x59, 0x52, 0x5E, 0x55, 0x63, 0x59, 0x63, 0x58, 0x60, 0x57, 0x62, 0x57, 0x60, 0x57, 0x62, 0x57, 0x61, 0x57, 0x62, 0x58, 0x62, 0x57, 0x5F, 0x54, 0x5D, 0x53, 0x5F, 0x54, 0x5F, 0x54, 0x5F, 0x54, 0x60, 0x55, 0x5F, 0x53, 0x5F, 0x54, 0x5F, 0x54, 0x5C, 0x52, 0x5E, 0x54, 0x61, 0x55, 0x5F, 0x54, 0x5E, 0x52, 0x5D, 0x52, 0x5D, 0x52, 0x5E, 0x52, 0x5F, 0x53, 0x5F, 0x54, 0x61, 0x56, 0x61, 0x55, 0x5E, 0x55, 0x60, 0x56, 0x5F, 0x54, 0x5F, 0x54, 0x60, 0x54, 0x5F, 0x54, 0x5F, 0x53, 0x61, 0x55, 0x5D, 0x52, 0x5E, 0x53, 0x5D, 0x53, 0x5A, 0x4F, 0x5B, 0x52, 0x5C, 0x50, 0x5C, 0x50, 0x5B, 0x50, 0x5A, 0x51, 0x5D, 0x52, 0x5D, 0x52, 0x5D, 0x51, 0x5D, 0x51, 0x5D, 0x52, 0x5D, 0x52, 0x5A, 0x50, 0x5B, 0x53, 0x5C, 0x53, 0x5B, 0x51, 0x5D, 0x52, 0x5D, 0x52, 0x5C, 0x52, 0x5B, 0x50, 0x5A, 0x50, 0x5A, 0x50, 0x59, 0x50, 0x5A, 0x51, 0x5B, 0x53, 0x5B, 0x53, 0x5B, 0x51, 0x5A, 0x50, 0x5C, 0x51, 0x5C, 0x50, 0x57, 0x4E, 0x58, 0x4E, 0x59, 0x4E, 0x59, 0x4E, 0x58, 0x4E, 0x58, 0x4E, 0x5A, 0x50, 0x59, 0x4F, 0x56, 0x4D, 0x59, 0x4F, 0x59, 0x4E, 0x5A, 0x4F, 0x57, 0x4C, 0x57, 0x4E, 0x56, 0x4D, 0x54, 0x4A, 0x39, 0x31, 0x29, 0x26, 0x21, 0x22, 0x21, 0x23, 0x20, 0x23, 0x1C, 0x20, 0x22, 0x25, 0x1F, 0x23, 0x21, 0x22, 0x1E, 0x20, 0x1F, 0x22, 0x1D, 0x21, 0x22, 0x24, 0x20, 0x22, 0x1D, 0x1F, 0x1F, 0x22, 0x21, 0x23, 0x21, 0x24, 0x21, 0x23, 0x1C, 0x1F, 0x21, 0x22, 0x20, 0x23, 0x21, 0x23, 0x20, 0x21, 0x20, 0x22, 0x1F, 0x22, 0x22, 0x25, 0x21, 0x23, 0x1E, 0x21, 0x21, 0x24, 0x21, 0x25, 0x1F, 0x21, 0x1E, 0x20, 0x25, 0x27, 0x1F, 0x20, 0x20, 0x22, 0x22, 0x24, 0x21, 0x25, 0x21, 0x22, 0x20, 0x22, 0x22, 0x24, 0x20, 0x23, 0x1D, 0x20
    },

    {
        0x4C, 0x1B, 0x4B, 0x1A, 0x4B, 0x1B, 0x4C, 0x1A, 0x4A, 0x1A, 0x4C, 0x1B, 0x4C, 0x1B, 0x4D, 0x1B, 0x4E, 0x1B, 0x4D, 0x1B, 0x4E, 0x1B, 0x4E, 0x1C, 0x4F, 0x1B, 0x4F, 0x1C, 0x4F, 0x1B, 0x4F, 0x1C, 0x4F, 0x1C, 0x4F, 0x1C, 0x51, 0x1C, 0x4F, 0x1C, 0x50, 0x1D, 0x51, 0x1D, 0x51, 0x1D, 0x50, 0x1C, 0x4F, 0x1C, 0x4F, 0x1C, 0x50, 0x1D, 0x52, 0x1D, 0x52, 0x1D, 0x53, 0x1E, 0x52, 0x1E, 0x53, 0x1D, 0x53, 0x1E, 0x53, 0x1E, 0x53, 0x1E, 0x54, 0x1E, 0x53, 0x1E, 0x52, 0x1E, 0x52, 0x1E, 0x53, 0x1E, 0x55, 0x1E, 0x55, 0x1F, 0x56, 0x1F, 0x56, 0x1F, 0x54, 0x1F, 0x54, 0x1E, 0x52, 0x1E, 0x4F, 0x1D, 0x49, 0x1C, 0x41, 0x1B, 0x3B, 0x19, 0x3E, 0x1A, 0x47, 0x1C, 0x46, 0x1B, 0x3E, 0x19, 0x31, 0x16, 0x24, 0x13, 0x1E, 0x11, 0x1B, 0x11, 0x19, 0x11, 0x19, 0x13, 0x1C, 0x18, 0x21, 0x22, 0x2C, 0x2E, 0x39, 0x3C, 0x41, 0x43, 0x46, 0x48, 0x48, 0x4A, 0x4A, 0x4C, 0x4B, 0x4D, 0x4C, 0x4F, 0x4C, 0x4E, 0x4D, 0x4E, 0x4D, 0x4E, 0x4D, 0x50, 0x4E, 0x4F, 0x4D, 0x4F, 0x4D, 0x4F, 0x4B, 0x4C, 0x49, 0x49, 0x42, 0x3E, 0x2F, 0x2A, 0x23, 0x1D, 0x1D, 0x17, 0x1A, 0x14, 0x19, 0x13, 0x1A, 0x11, 0x1B, 0x12, 0x1D, 0x12, 0x27, 0x16, 0x3D, 0x1B, 0x4D, 0x1E, 0x53, 0x20, 0x4F, 0x1E, 0x3E, 0x1B, 0x3C, 0x1D, 0x4C, 0x20, 0x58, 0x22, 0x5C, 0x22, 0x5D, 0x22, 0x5E, 0x22, 0x5F, 0x23, 0x60, 0x23, 0x5E, 0x22, 0x5E, 0x22, 0x5F, 0x22, 0x61, 0x23, 0x61, 0x23, 0x5F, 0x23, 0x61, 0x23, 0x62, 0x24, 0x61, 0x23, 0x60, 0x22, 0x5F, 0x22, 0x5F, 0x23, 0x61, 0x22, 0x61, 0x22, 0x5F, 0x21, 0x60, 0x22, 0x61, 0x22, 0x62, 0x22, 0x61, 0x22, 0x61, 0x23, 0x61, 0x22, 0x61, 0x22, 0x61, 0x22, 0x5F, 0x22, 0x5F, 0x21, 0x60, 0x22, 0x61, 0x22, 0x63, 0x23, 0x63, 0x23, 0x63, 0x22, 0x62, 0x22, 0x63, 0x22, 0x61, 0x22, 0x60, 0x21, 0x5E, 0x20, 0x5E, 0x20, 0x5B, 0x20, 0x5D, 0x21, 0x5E, 0x21, 0x5C, 0x21, 0x5E, 0x21, 0x5F, 0x21, 0x5E, 0x20, 0x5E, 0x21, 0x5E, 0x21, 0x5E, 0x20, 0x5D, 0x21, 0x5D, 0x20, 0x5E, 0x21, 0x5D, 0x20, 0x5C, 0x20, 0x5C, 0x20, 0x5D, 0x20, 0x5E, 0x20, 0x5D, 0x21, 0x5D, 0x21, 0x5E, 0x22, 0x61, 0x23, 0x5F, 0x22, 0x5D, 0x21, 0x5C, 0x21, 0x5C, 0x21, 0x5E, 0x22, 0x5E, 0x21, 0x5C, 0x21, 0x5E, 0x25, 0x5F, 0x23, 0x60, 0x23, 0x62, 0x22, 0x5F, 0x21, 0x5D, 0x20, 0x5B, 0x20, 0x5C, 0x20, 0x5B, 0x20, 0x5A, 0x20, 0x5A, 0x1F, 0x5B, 0x20, 0x58, 0x1F, 0x56, 0x1E, 0x51, 0x1D, 0x4A, 0x1B, 0x4A, 0x1B, 0x50, 0x1D, 0x53, 0x1F, 0x55, 0x1F, 0x57, 0x1F, 0x5A, 0x21, 0x5E, 0x22, 0x5E, 0x21, 0x5E, 0x22, 0x5D, 0x22, 0x5D, 0x22, 0x5E, 0x22, 0x5C, 0x20, 0x5D, 0x20, 0x5B, 0x20, 0x59, 0x1F, 0x59, 0x1F, 0x58, 0x1F, 0x59, 0x20, 0x58, 0x1F, 0x57, 0x1F, 0x58, 0x1F, 0x59, 0x1F, 0x57, 0x20, 0x59, 0x1F, 0x5B, 0x21, 0x5A, 0x20, 0x56, 0x1F, 0x56, 0x1F, 0x56, 0x1F, 0x57, 0x1F, 0x58, 0x20, 0x58, 0x1F, 0x58, 0x1F, 0x5A, 0x21, 0x5A, 0x1F, 0x5A, 0x20, 0x59, 0x20, 0x59, 0x20, 0x58, 0x20, 0x58, 0x1F, 0x58, 0x20, 0x58, 0x1F, 0x57, 0x1F, 0x5B, 0x22, 0x5B, 0x22, 0x56, 0x1F, 0x54, 0x1E, 0x52, 0x1D, 0x54, 0x1E, 0x55, 0x1E, 0x54, 0x1E, 0x56, 0x1E, 0x57, 0x1F, 0x56, 0x1F, 0x57, 0x1F, 0x56, 0x1F, 0x57, 0x1F, 0x58, 0x1F, 0x55, 0x1F, 0x56, 0x1F, 0x57, 0x20, 0x56, 0x1F, 0x58, 0x20, 0x58, 0x20, 0x58, 0x1F, 0x55, 0x1F, 0x55, 0x1E, 0x54, 0x1F, 0x56, 0x1F, 0x58, 0x20, 0x5A, 0x20, 0x57, 0x1F, 0x55, 0x1E, 0x53, 0x1E, 0x52, 0x1E, 0x55, 0x1E, 0x53, 0x1E, 0x53, 0x1E, 0x55, 0x1E, 0x51, 0x1D, 0x50, 0x1D, 0x52, 0x1E, 0x52, 0x1E, 0x53, 0x1E, 0x53, 0x1E, 0x54, 0x1E, 0x51, 0x1D, 0x53, 0x1D, 0x50, 0x1D, 0x52, 0x1E, 0x50, 0x1D, 0x4E, 0x1D, 0x38, 0x18, 0x2D, 0x18, 0x26, 0x16, 0x2B, 0x18, 0x2A, 0x17, 0x22, 0x15, 0x2A, 0x17, 0x28, 0x16, 0x26, 0x16, 0x25, 0x15, 0x27, 0x17, 0x25, 0x16, 0x28, 0x17, 0x2A, 0x18, 0x26, 0x15, 0x24, 0x16, 0x2C, 0x18, 0x26, 0x16, 0x27, 0x15, 0x20, 0x14, 0x2B, 0x18, 0x26, 0x16, 0x29, 0x17, 0x24, 0x14, 0x25, 0x17, 0x25, 0x15, 0x25, 0x16, 0x25, 0x16, 0x21, 0x13, 0x29, 0x17, 0x22, 0x14, 0x23, 0x14, 0x21, 0x14, 0x26, 0x15, 0x1D, 0x12, 0x26, 0x16, 0x22, 0x14, 0x22, 0x15, 0x21, 0x13, 0x1D, 0x13, 0x25, 0x15, 0x1F, 0x12, 0x1E, 0x13
    },

    {
        0x52, 0x48, 0x52, 0x48, 0x51, 0x48, 0x52, 0x47, 0x52, 0x48, 0x52, 0x48, 0x53, 0x48, 0x54, 0x4A, 0x56, 0x4B, 0x56, 0x4B, 0x56, 0x4B, 0x56, 0x4B, 0x55, 0x4B, 0x57, 0x4C, 0x56, 0x4B, 0x56, 0x4B, 0x56, 0x4B, 0x58, 0x4D, 0x58, 0x4D, 0x57, 0x4C, 0x58, 0x4D, 0x5A, 0x4E, 0x59, 0x4E, 0x59, 0x4D, 0x57, 0x4C, 0x57, 0x4D, 0x58, 0x4D, 0x59, 0x4E, 0x5A, 0x4E, 0x5A, 0x4F, 0x5A, 0x4F, 0x5A, 0x50, 0x5C, 0x50, 0x5B, 0x50, 0x5C, 0x4F, 0x5B, 0x4F, 0x5B, 0x4E, 0x5B, 0x4F, 0x5B, 0x4E, 0x5A, 0x4F, 0x5C, 0x50, 0x5C, 0x52, 0x5D, 0x53, 0x5E, 0x52, 0x5C, 0x51, 0x5B, 0x4F, 0x57, 0x4C, 0x52, 0x49, 0x4C, 0x42, 0x42, 0x3A, 0x3C, 0x39, 0x40, 0x3F, 0x49, 0x45, 0x48, 0x41, 0x3D, 0x36, 0x2D, 0x28, 0x20, 0x1F, 0x19, 0x1B, 0x17, 0x18, 0x15, 0x18, 0x15, 0x18, 0x18, 0x1C, 0x1C, 0x28, 0x26, 0x2E, 0x30, 0x3B, 0x37, 0x41, 0x3A, 0x43, 0x3A, 0x45, 0x3D, 0x47, 0x3D, 0x48, 0x3F, 0x48, 0x3F, 0x48, 0x3F, 0x48, 0x40, 0x4A, 0x3F, 0x49, 0x40, 0x4B, 0x40, 0x49, 0x3F, 0x4A, 0x3E, 0x48, 0x3C, 0x46, 0x38, 0x40, 0x2C, 0x2F, 0x21, 0x22, 0x1A, 0x1C, 0x17, 0x1A, 0x16, 0x19, 0x15, 0x17, 0x16, 0x18, 0x18, 0x1A, 0x1F, 0x23, 0x34, 0x38, 0x49, 0x48, 0x52, 0x4F, 0x51, 0x4B, 0x41, 0x3B, 0x39, 0x37, 0x48, 0x46, 0x58, 0x52, 0x5E, 0x56, 0x60, 0x57, 0x62, 0x59, 0x65, 0x59, 0x66, 0x5A, 0x64, 0x58, 0x63, 0x58, 0x65, 0x59, 0x67, 0x5B, 0x68, 0x5C, 0x66, 0x5B, 0x67, 0x5C, 0x67, 0x5D, 0x66, 0x5B, 0x67, 0x5A, 0x65, 0x5A, 0x65, 0x5B, 0x67, 0x5A, 0x68, 0x5B, 0x66, 0x59, 0x68, 0x5B, 0x67, 0x5C, 0x68, 0x5B, 0x66, 0x5C, 0x67, 0x5B, 0x68, 0x5C, 0x67, 0x5B, 0x67, 0x5A, 0x65, 0x58, 0x63, 0x59, 0x63, 0x59, 0x66, 0x5A, 0x69, 0x5E, 0x6A, 0x5E, 0x69, 0x5C, 0x68, 0x5C, 0x69, 0x5D, 0x68, 0x5B, 0x66, 0x5A, 0x66, 0x59, 0x65, 0x58, 0x63, 0x58, 0x63, 0x59, 0x64, 0x57, 0x62, 0x57, 0x64, 0x5A, 0x66, 0x5A, 0x65, 0x58, 0x63, 0x58, 0x65, 0x59, 0x65, 0x59, 0x65, 0x57, 0x64, 0x57, 0x64, 0x59, 0x64, 0x58, 0x63, 0x57, 0x64, 0x58, 0x64, 0x57, 0x65, 0x58, 0x65, 0x58, 0x64, 0x58, 0x65, 0x59, 0x67, 0x5B, 0x65, 0x59, 0x62, 0x57, 0x64, 0x57, 0x63, 0x58, 0x64, 0x59, 0x64, 0x58, 0x61, 0x57, 0x61, 0x57, 0x62, 0x59, 0x66, 0x5A, 0x66, 0x5A, 0x64, 0x58, 0x63, 0x57, 0x63, 0x56, 0x65, 0x58, 0x62, 0x56, 0x61, 0x54, 0x60, 0x55, 0x61, 0x55, 0x5F, 0x53, 0x5D, 0x52, 0x59, 0x4E, 0x56, 0x4C, 0x56, 0x4C, 0x5A, 0x4F, 0x5A, 0x50, 0x5C, 0x52, 0x5D, 0x54, 0x5F, 0x55, 0x63, 0x59, 0x64, 0x58, 0x62, 0x57, 0x62, 0x58, 0x60, 0x57, 0x62, 0x57, 0x63, 0x56, 0x62, 0x56, 0x60, 0x54, 0x5E, 0x54, 0x5F, 0x55, 0x5F, 0x53, 0x60, 0x54, 0x5F, 0x54, 0x5F, 0x52, 0x5F, 0x53, 0x5E, 0x54, 0x5F, 0x53, 0x5E, 0x53, 0x60, 0x56, 0x60, 0x55, 0x5C, 0x52, 0x5C, 0x51, 0x5A, 0x50, 0x5D, 0x52, 0x5E, 0x52, 0x5F, 0x53, 0x5E, 0x54, 0x61, 0x56, 0x60, 0x56, 0x61, 0x56, 0x5E, 0x54, 0x5F, 0x54, 0x5F, 0x55, 0x5E, 0x53, 0x60, 0x53, 0x5E, 0x52, 0x5D, 0x52, 0x5F, 0x57, 0x5F, 0x57, 0x5B, 0x50, 0x5A, 0x50, 0x59, 0x4E, 0x5A, 0x50, 0x5B, 0x50, 0x5B, 0x50, 0x5C, 0x50, 0x5C, 0x51, 0x5B, 0x51, 0x5D, 0x51, 0x5D, 0x51, 0x5D, 0x52, 0x5C, 0x51, 0x5C, 0x51, 0x5C, 0x51, 0x5E, 0x54, 0x5C, 0x52, 0x5E, 0x54, 0x5C, 0x53, 0x5E, 0x53, 0x5B, 0x51, 0x5B, 0x50, 0x5B, 0x51, 0x5C, 0x52, 0x5E, 0x54, 0x5E, 0x53, 0x5B, 0x53, 0x5C, 0x50, 0x5A, 0x50, 0x58, 0x4E, 0x5C, 0x51, 0x58, 0x4E, 0x59, 0x51, 0x5B, 0x4F, 0x58, 0x4E, 0x56, 0x4C, 0x57, 0x4E, 0x58, 0x4E, 0x59, 0x51, 0x5B, 0x4F, 0x5A, 0x4F, 0x59, 0x4F, 0x59, 0x4D, 0x57, 0x4C, 0x56, 0x4C, 0x56, 0x4C, 0x53, 0x48, 0x38, 0x31, 0x2C, 0x2D, 0x23, 0x24, 0x26, 0x2B, 0x24, 0x26, 0x1E, 0x20, 0x26, 0x29, 0x23, 0x24, 0x22, 0x26, 0x20, 0x20, 0x23, 0x27, 0x20, 0x21, 0x23, 0x28, 0x25, 0x27, 0x21, 0x21, 0x20, 0x26, 0x25, 0x27, 0x21, 0x23, 0x22, 0x23, 0x1D, 0x1F, 0x26, 0x29, 0x20, 0x21, 0x23, 0x26, 0x1F, 0x1E, 0x23, 0x28, 0x1F, 0x1F, 0x20, 0x23, 0x1F, 0x20, 0x1D, 0x1F, 0x23, 0x27, 0x1D, 0x1E, 0x1F, 0x20, 0x1E, 0x1F, 0x20, 0x20, 0x19, 0x1C, 0x21, 0x24, 0x1D, 0x1E, 0x1E, 0x20, 0x1D, 0x1D, 0x1B, 0x1F, 0x21, 0x21, 0x1C, 0x1D, 0x1C, 0x1F
    },

    {
        0x4C, 0x1B, 0x4A, 0x1A, 0x4A, 0x1A, 0x4B, 0x1A, 0x4B, 0x1B, 0x4C, 0x1B, 0x4B, 0x1B, 0x4D, 0x1B, 0x4E, 0x1B, 0x4F, 0x1B, 0x4E, 0x1B, 0x4D, 0x1B, 0x4D, 0x1B, 0x4E, 0x1B, 0x4F, 0x1C, 0x4F, 0x1C, 0x4F, 0x1C, 0x4F, 0x1D, 0x51, 0x1D, 0x51, 0x1C, 0x50, 0x1C, 0x50, 0x1D, 0x51, 0x1D, 0x52, 0x1C, 0x50, 0x1D, 0x4F, 0x1C, 0x51, 0x1D, 0x53, 0x1E, 0x53, 0x1E, 0x54, 0x1F, 0x52, 0x1E, 0x52, 0x1D, 0x52, 0x1D, 0x54, 0x1E, 0x53, 0x1E, 0x52, 0x1E, 0x51, 0x1D, 0x51, 0x1E, 0x53, 0x1F, 0x53, 0x1E, 0x54, 0x1E, 0x55, 0x1F, 0x57, 0x20, 0x56, 0x1F, 0x55, 0x1F, 0x53, 0x1E, 0x4F, 0x1D, 0x49, 0x1C, 0x42, 0x1A, 0x3B, 0x1A, 0x3E, 0x1A, 0x46, 0x1B, 0x48, 0x1C, 0x41, 0x1A, 0x32, 0x16, 0x24, 0x13, 0x1D, 0x11, 0x1B, 0x10, 0x18, 0x11, 0x18, 0x12, 0x1B, 0x17, 0x21, 0x20, 0x2B, 0x2D, 0x38, 0x3B, 0x42, 0x43, 0x46, 0x47, 0x49, 0x4B, 0x49, 0x4C, 0x4B, 0x4D, 0x4C, 0x4E, 0x4C, 0x4E, 0x4C, 0x4F, 0x4E, 0x4F, 0x4D, 0x4F, 0x4E, 0x50, 0x4E, 0x50, 0x4E, 0x50, 0x4F, 0x50, 0x4E, 0x4F, 0x4C, 0x4D, 0x4B, 0x4A, 0x43, 0x3F, 0x31, 0x2C, 0x24, 0x1E, 0x1D, 0x17, 0x1A, 0x14, 0x19, 0x12, 0x19, 0x11, 0x19, 0x11, 0x1C, 0x12, 0x26, 0x16, 0x3C, 0x1A, 0x4C, 0x1E, 0x53, 0x20, 0x50, 0x1E, 0x3F, 0x1B, 0x3A, 0x1C, 0x49, 0x1F, 0x56, 0x21, 0x5A, 0x22, 0x5D, 0x22, 0x5E, 0x22, 0x5F, 0x22, 0x5F, 0x23, 0x5D, 0x22, 0x5F, 0x23, 0x61, 0x23, 0x61, 0x23, 0x61, 0x24, 0x62, 0x23, 0x62, 0x24, 0x62, 0x23, 0x5F, 0x22, 0x61, 0x23, 0x61, 0x23, 0x5F, 0x22, 0x61, 0x22, 0x5E, 0x21, 0x5F, 0x22, 0x62, 0x23, 0x62, 0x23, 0x60, 0x23, 0x60, 0x22, 0x61, 0x22, 0x61, 0x22, 0x60, 0x22, 0x60, 0x22, 0x60, 0x22, 0x5E, 0x21, 0x5F, 0x21, 0x61, 0x23, 0x62, 0x23, 0x62, 0x22, 0x61, 0x22, 0x63, 0x23, 0x62, 0x22, 0x60, 0x22, 0x60, 0x22, 0x5E, 0x21, 0x5D, 0x21, 0x5E, 0x21, 0x5D, 0x21, 0x5C, 0x21, 0x5E, 0x21, 0x60, 0x22, 0x5F, 0x21, 0x5E, 0x21, 0x5F, 0x21, 0x5E, 0x21, 0x5D, 0x20, 0x5E, 0x21, 0x5D, 0x21, 0x5E, 0x21, 0x5D, 0x21, 0x5E, 0x21, 0x5F, 0x21, 0x60, 0x22, 0x60, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x5E, 0x21, 0x5C, 0x21, 0x5C, 0x21, 0x5E, 0x22, 0x60, 0x22, 0x5E, 0x22, 0x5D, 0x21, 0x5D, 0x21, 0x5E, 0x22, 0x60, 0x23, 0x5F, 0x22, 0x5D, 0x21, 0x5C, 0x20, 0x5C, 0x20, 0x5C, 0x20, 0x5D, 0x20, 0x5B, 0x20, 0x5A, 0x20, 0x5A, 0x20, 0x5A, 0x20, 0x5A, 0x20, 0x57, 0x1E, 0x57, 0x1E, 0x56, 0x1F, 0x58, 0x1F, 0x59, 0x20, 0x5A, 0x20, 0x5C, 0x21, 0x5B, 0x21, 0x5D, 0x22, 0x5E, 0x22, 0x5D, 0x21, 0x5D, 0x22, 0x5B, 0x21, 0x5B, 0x21, 0x5A, 0x21, 0x5A, 0x1F, 0x5A, 0x20, 0x5A, 0x20, 0x5B, 0x20, 0x58, 0x20, 0x58, 0x1F, 0x58, 0x1F, 0x58, 0x1F, 0x58, 0x20, 0x59, 0x20, 0x59, 0x20, 0x58, 0x20, 0x5A, 0x20, 0x59, 0x20, 0x58, 0x1F, 0x55, 0x1E, 0x54, 0x1F, 0x54, 0x1F, 0x57, 0x1F, 0x58, 0x20, 0x58, 0x20, 0x5B, 0x21, 0x5A, 0x20, 0x5B, 0x20, 0x58, 0x1F, 0x5B, 0x20, 0x5A, 0x20, 0x58, 0x1F, 0x58, 0x20, 0x59, 0x20, 0x59, 0x20, 0x5F, 0x26, 0x5E, 0x25, 0x55, 0x1F, 0x55, 0x1E, 0x53, 0x1E, 0x53, 0x1D, 0x55, 0x1E, 0x56, 0x1F, 0x55, 0x20, 0x55, 0x1F, 0x56, 0x20, 0x57, 0x1F, 0x54, 0x1F, 0x56, 0x1F, 0x56, 0x1F, 0x56, 0x1F, 0x57, 0x1F, 0x56, 0x1F, 0x55, 0x1F, 0x58, 0x20, 0x57, 0x20, 0x59, 0x21, 0x58, 0x21, 0x56, 0x21, 0x57, 0x20, 0x57, 0x20, 0x56, 0x20, 0x57, 0x1F, 0x52, 0x1E, 0x55, 0x1F, 0x54, 0x1E, 0x52, 0x1E, 0x53, 0x1F, 0x54, 0x1E, 0x54, 0x1F, 0x54, 0x1F, 0x54, 0x1E, 0x51, 0x1E, 0x54, 0x1E, 0x51, 0x1E, 0x53, 0x1F, 0x55, 0x1E, 0x54, 0x1E, 0x53, 0x1D, 0x51, 0x1D, 0x52, 0x1E, 0x51, 0x1D, 0x50, 0x1D, 0x4D, 0x1C, 0x37, 0x18, 0x36, 0x1B, 0x23, 0x15, 0x2A, 0x17, 0x22, 0x14, 0x1F, 0x14, 0x26, 0x16, 0x21, 0x14, 0x27, 0x16, 0x20, 0x14, 0x2A, 0x18, 0x20, 0x14, 0x28, 0x17, 0x22, 0x14, 0x1F, 0x13, 0x27, 0x17, 0x22, 0x14, 0x23, 0x15, 0x21, 0x14, 0x21, 0x15, 0x25, 0x15, 0x20, 0x14, 0x24, 0x15, 0x1F, 0x14, 0x28, 0x16, 0x1F, 0x13, 0x26, 0x17, 0x1F, 0x13, 0x1F, 0x15, 0x23, 0x15, 0x1E, 0x14, 0x21, 0x13, 0x20, 0x15, 0x20, 0x14, 0x21, 0x14, 0x25, 0x15, 0x21, 0x14, 0x22, 0x14, 0x1F, 0x13, 0x23, 0x15, 0x26, 0x16, 0x24, 0x15, 0x24, 0x14
    },

    {
        0x52, 0x48, 0x50, 0x48, 0x51, 0x47, 0x52, 0x48, 0x54, 0x49, 0x53, 0x49, 0x54, 0x49, 0x54, 0x49, 0x56, 0x4A, 0x56, 0x4B, 0x56, 0x4B, 0x55, 0x4A, 0x54, 0x49, 0x55, 0x4A, 0x56, 0x4B, 0x56, 0x4B, 0x57, 0x4B, 0x57, 0x4B, 0x59, 0x4D, 0x59, 0x4D, 0x5A, 0x4D, 0x59, 0x4D, 0x59, 0x4E, 0x5B, 0x4D, 0x5A, 0x4D, 0x58, 0x4B, 0x5A, 0x4E, 0x5A, 0x4E, 0x5C, 0x50, 0x5C, 0x50, 0x5B, 0x4F, 0x5A, 0x4F, 0x5A, 0x4E, 0x5C, 0x4F, 0x5B, 0x50, 0x59, 0x4F, 0x59, 0x4E, 0x59, 0x4E, 0x5A, 0x4F, 0x5A, 0x4E, 0x5B, 0x50, 0x5C, 0x51, 0x5D, 0x52, 0x5D, 0x52, 0x5B, 0x51, 0x58, 0x4E, 0x53, 0x49, 0x4B, 0x43, 0x43, 0x3C, 0x3C, 0x38, 0x41, 0x40, 0x49, 0x45, 0x49, 0x43, 0x40, 0x39, 0x2F, 0x2A, 0x21, 0x1F, 0x1A, 0x1B, 0x17, 0x18, 0x16, 0x17, 0x15, 0x17, 0x17, 0x1B, 0x1C, 0x22, 0x24, 0x2E, 0x30, 0x39, 0x37, 0x40, 0x3A, 0x44, 0x3C, 0x46, 0x3D, 0x46, 0x3E, 0x48, 0x3F, 0x49, 0x40, 0x49, 0x3F, 0x49, 0x3F, 0x49, 0x3F, 0x49, 0x40, 0x4A, 0x40, 0x4A, 0x40, 0x4A, 0x40, 0x4A, 0x40, 0x4A, 0x3F, 0x49, 0x3D, 0x47, 0x3A, 0x41, 0x2D, 0x31, 0x21, 0x23, 0x1A, 0x1C, 0x17, 0x19, 0x15, 0x17, 0x15, 0x17, 0x15, 0x17, 0x17, 0x19, 0x1E, 0x21, 0x33, 0x37, 0x46, 0x47, 0x51, 0x4E, 0x52, 0x4C, 0x43, 0x3C, 0x39, 0x36, 0x46, 0x44, 0x55, 0x50, 0x5D, 0x55, 0x61, 0x57, 0x63, 0x58, 0x65, 0x5A, 0x65, 0x59, 0x65, 0x59, 0x65, 0x5A, 0x66, 0x5A, 0x67, 0x5C, 0x68, 0x5B, 0x68, 0x5B, 0x67, 0x5C, 0x68, 0x5B, 0x66, 0x59, 0x66, 0x5B, 0x67, 0x5B, 0x66, 0x5B, 0x67, 0x5A, 0x66, 0x59, 0x64, 0x5A, 0x68, 0x5C, 0x6A, 0x5D, 0x66, 0x5B, 0x67, 0x5A, 0x66, 0x5A, 0x68, 0x5A, 0x68, 0x5C, 0x68, 0x5C, 0x67, 0x5A, 0x65, 0x5A, 0x65, 0x59, 0x67, 0x5B, 0x69, 0x5C, 0x69, 0x5B, 0x67, 0x5B, 0x69, 0x5C, 0x69, 0x5C, 0x68, 0x5B, 0x67, 0x5A, 0x65, 0x59, 0x63, 0x58, 0x64, 0x59, 0x64, 0x57, 0x63, 0x57, 0x66, 0x58, 0x67, 0x5A, 0x67, 0x59, 0x66, 0x59, 0x66, 0x59, 0x65, 0x58, 0x66, 0x58, 0x65, 0x59, 0x64, 0x57, 0x66, 0x59, 0x65, 0x58, 0x66, 0x5A, 0x68, 0x5C, 0x65, 0x59, 0x67, 0x5B, 0x64, 0x59, 0x65, 0x58, 0x65, 0x59, 0x65, 0x57, 0x64, 0x58, 0x64, 0x58, 0x66, 0x5A, 0x67, 0x5B, 0x64, 0x5A, 0x63, 0x58, 0x64, 0x59, 0x63, 0x58, 0x64, 0x5A, 0x64, 0x58, 0x65, 0x58, 0x63, 0x56, 0x65, 0x57, 0x65, 0x57, 0x65, 0x58, 0x62, 0x55, 0x62, 0x56, 0x61, 0x55, 0x61, 0x55, 0x61, 0x55, 0x60, 0x53, 0x60, 0x52, 0x5E, 0x52, 0x5F, 0x55, 0x5F, 0x54, 0x60, 0x56, 0x61, 0x57, 0x63, 0x57, 0x63, 0x59, 0x64, 0x57, 0x62, 0x56, 0x62, 0x57, 0x61, 0x56, 0x62, 0x55, 0x60, 0x53, 0x60, 0x53, 0x60, 0x54, 0x60, 0x56, 0x60, 0x54, 0x5F, 0x53, 0x60, 0x54, 0x60, 0x55, 0x61, 0x56, 0x60, 0x54, 0x60, 0x54, 0x61, 0x54, 0x5E, 0x54, 0x60, 0x56, 0x62, 0x56, 0x5E, 0x52, 0x5C, 0x51, 0x5B, 0x4E, 0x5B, 0x50, 0x5E, 0x51, 0x5F, 0x53, 0x5E, 0x52, 0x61, 0x56, 0x62, 0x56, 0x61, 0x56, 0x60, 0x53, 0x61, 0x56, 0x60, 0x55, 0x60, 0x54, 0x5F, 0x54, 0x60, 0x53, 0x5F, 0x54, 0x61, 0x59, 0x5E, 0x57, 0x5A, 0x4F, 0x5B, 0x50, 0x5B, 0x50, 0x5A, 0x4F, 0x5A, 0x4F, 0x5C, 0x52, 0x5B, 0x51, 0x5B, 0x51, 0x5C, 0x51, 0x5D, 0x51, 0x5C, 0x50, 0x5D, 0x52, 0x5C, 0x50, 0x5C, 0x51, 0x5C, 0x51, 0x5D, 0x52, 0x5B, 0x52, 0x5D, 0x53, 0x5B, 0x52, 0x5D, 0x54, 0x5C, 0x53, 0x5C, 0x53, 0x5D, 0x53, 0x5D, 0x53, 0x5E, 0x53, 0x5D, 0x51, 0x59, 0x4E, 0x5B, 0x50, 0x59, 0x4F, 0x5A, 0x4F, 0x5A, 0x50, 0x5A, 0x51, 0x5B, 0x52, 0x5A, 0x51, 0x5A, 0x4F, 0x59, 0x4E, 0x5B, 0x50, 0x58, 0x4E, 0x59, 0x4F, 0x5A, 0x4F, 0x5A, 0x4F, 0x5A, 0x4E, 0x58, 0x4D, 0x5A, 0x4F, 0x58, 0x4D, 0x56, 0x4C, 0x52, 0x47, 0x38, 0x32, 0x2F, 0x2D, 0x22, 0x23, 0x24, 0x26, 0x1F, 0x1F, 0x1D, 0x1F, 0x21, 0x22, 0x1E, 0x20, 0x22, 0x24, 0x1E, 0x1F, 0x23, 0x27, 0x1D, 0x1F, 0x23, 0x26, 0x1E, 0x1F, 0x1C, 0x1F, 0x23, 0x27, 0x1E, 0x1E, 0x20, 0x22, 0x1E, 0x1F, 0x1E, 0x22, 0x1F, 0x1F, 0x1F, 0x21, 0x1F, 0x21, 0x1D, 0x21, 0x22, 0x24, 0x1D, 0x1E, 0x22, 0x26, 0x1D, 0x1D, 0x1D, 0x20, 0x1F, 0x20, 0x1C, 0x20, 0x1E, 0x1F, 0x1F, 0x21, 0x1E, 0x21, 0x1F, 0x22, 0x21, 0x23, 0x1F, 0x22, 0x20, 0x23, 0x1E, 0x20, 0x21, 0x23, 0x24, 0x26, 0x23, 0x26, 0x1F, 0x20
    },

    {
        0x4C, 0x1B, 0x4B, 0x1A, 0x4B, 0x1A, 0x4B, 0x1B, 0x4C, 0x1A, 0x4D, 0x1A, 0x4C, 0x1B, 0x4D, 0x1B, 0x4D, 0x1B, 0x4E, 0x1B, 0x4E, 0x1B, 0x4E, 0x1B, 0x4D, 0x1B, 0x4E, 0x1C, 0x4D, 0x1C, 0x4E, 0x1C, 0x4E, 0x1C, 0x51, 0x1C, 0x50, 0x1D, 0x50, 0x1C, 0x51, 0x1C, 0x52, 0x1D, 0x52, 0x1D, 0x53, 0x1D, 0x52, 0x1C, 0x50, 0x1C, 0x52, 0x1D, 0x53, 0x1E, 0x53, 0x1E, 0x54, 0x1E, 0x53, 0x1E, 0x53, 0x1E, 0x53, 0x1D, 0x52, 0x1D, 0x53, 0x1E, 0x52, 0x1E, 0x52, 0x1E, 0x51, 0x1D, 0x51, 0x1E, 0x53, 0x1E, 0x54, 0x1E, 0x55, 0x1E, 0x56, 0x1F, 0x56, 0x1F, 0x54, 0x1F, 0x50, 0x1E, 0x49, 0x1C, 0x41, 0x1B, 0x3B, 0x19, 0x3D, 0x1A, 0x47, 0x1C, 0x49, 0x1C, 0x42, 0x1A, 0x34, 0x17, 0x26, 0x13, 0x1E, 0x10, 0x1A, 0x10, 0x19, 0x10, 0x18, 0x11, 0x1A, 0x16, 0x1F, 0x1F, 0x29, 0x2B, 0x37, 0x39, 0x3F, 0x41, 0x43, 0x46, 0x48, 0x49, 0x4B, 0x4D, 0x4C, 0x4F, 0x4C, 0x4F, 0x4E, 0x4F, 0x4D, 0x4E, 0x4D, 0x4E, 0x4D, 0x4E, 0x4D, 0x4E, 0x4E, 0x50, 0x4E, 0x4F, 0x4E, 0x4F, 0x4E, 0x4F, 0x50, 0x4F, 0x4D, 0x4E, 0x4E, 0x4E, 0x4B, 0x4B, 0x45, 0x42, 0x33, 0x2D, 0x25, 0x1F, 0x1D, 0x17, 0x19, 0x13, 0x19, 0x12, 0x19, 0x11, 0x19, 0x10, 0x1B, 0x12, 0x23, 0x14, 0x3B, 0x1B, 0x4C, 0x1E, 0x52, 0x1F, 0x50, 0x1F, 0x40, 0x1B, 0x39, 0x1B, 0x48, 0x1E, 0x56, 0x21, 0x5A, 0x21, 0x5C, 0x22, 0x5F, 0x21, 0x60, 0x23, 0x60, 0x23, 0x61, 0x22, 0x61, 0x23, 0x61, 0x23, 0x61, 0x22, 0x61, 0x23, 0x61, 0x23, 0x62, 0x23, 0x5F, 0x22, 0x5E, 0x22, 0x61, 0x23, 0x5F, 0x22, 0x5F, 0x21, 0x60, 0x21, 0x60, 0x22, 0x60, 0x22, 0x61, 0x22, 0x60, 0x22, 0x60, 0x22, 0x60, 0x21, 0x61, 0x22, 0x61, 0x22, 0x61, 0x21, 0x61, 0x22, 0x5F, 0x21, 0x5E, 0x20, 0x5E, 0x22, 0x5F, 0x21, 0x62, 0x23, 0x62, 0x23, 0x63, 0x23, 0x62, 0x22, 0x61, 0x23, 0x61, 0x22, 0x60, 0x22, 0x5D, 0x20, 0x5D, 0x21, 0x5E, 0x21, 0x5D, 0x21, 0x5F, 0x22, 0x5F, 0x21, 0x5F, 0x21, 0x5F, 0x21, 0x5F, 0x21, 0x5E, 0x21, 0x5E, 0x21, 0x5F, 0x22, 0x5F, 0x21, 0x5C, 0x21, 0x5D, 0x21, 0x60, 0x22, 0x61, 0x21, 0x5F, 0x22, 0x60, 0x22, 0x60, 0x21, 0x5F, 0x21, 0x5D, 0x20, 0x5F, 0x21, 0x5F, 0x22, 0x5F, 0x22, 0x62, 0x22, 0x60, 0x22, 0x61, 0x22, 0x5F, 0x21, 0x5E, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x5C, 0x21, 0x5E, 0x21, 0x5D, 0x1F, 0x5D, 0x20, 0x5B, 0x1F, 0x5D, 0x1F, 0x5C, 0x20, 0x5D, 0x20, 0x5B, 0x20, 0x5D, 0x20, 0x5A, 0x1F, 0x5B, 0x1F, 0x59, 0x1F, 0x58, 0x1F, 0x5C, 0x20, 0x5C, 0x21, 0x5C, 0x20, 0x5C, 0x21, 0x5E, 0x21, 0x5D, 0x21, 0x5D, 0x21, 0x5A, 0x20, 0x5B, 0x20, 0x5B, 0x20, 0x5A, 0x1F, 0x5A, 0x20, 0x59, 0x1F, 0x59, 0x1F, 0x59, 0x20, 0x58, 0x1F, 0x59, 0x1F, 0x5C, 0x20, 0x5B, 0x20, 0x5C, 0x21, 0x5C, 0x20, 0x5A, 0x1F, 0x5A, 0x20, 0x5A, 0x20, 0x5C, 0x20, 0x5A, 0x20, 0x59, 0x1F, 0x56, 0x1F, 0x55, 0x1F, 0x55, 0x1F, 0x56, 0x1F, 0x58, 0x1F, 0x57, 0x1F, 0x5A, 0x20, 0x5B, 0x20, 0x5A, 0x20, 0x5B, 0x20, 0x5A, 0x20, 0x59, 0x20, 0x5A, 0x20, 0x5A, 0x20, 0x58, 0x1F, 0x58, 0x20, 0x5A, 0x22, 0x59, 0x21, 0x54, 0x1F, 0x52, 0x1E, 0x54, 0x1E, 0x55, 0x1E, 0x54, 0x1E, 0x57, 0x20, 0x55, 0x1E, 0x55, 0x1E, 0x54, 0x1F, 0x56, 0x1F, 0x55, 0x1F, 0x57, 0x1F, 0x56, 0x1F, 0x54, 0x1F, 0x56, 0x1F, 0x56, 0x1F, 0x57, 0x1F, 0x57, 0x1E, 0x57, 0x20, 0x58, 0x20, 0x59, 0x22, 0x5A, 0x22, 0x57, 0x20, 0x56, 0x1F, 0x58, 0x1F, 0x54, 0x1F, 0x53, 0x1E, 0x54, 0x1E, 0x54, 0x1D, 0x51, 0x1D, 0x53, 0x1E, 0x53, 0x1E, 0x54, 0x1F, 0x56, 0x1F, 0x54, 0x1E, 0x51, 0x1E, 0x55, 0x1E, 0x53, 0x1E, 0x53, 0x1E, 0x54, 0x1E, 0x50, 0x1D, 0x52, 0x1D, 0x52, 0x1D, 0x52, 0x1D, 0x51, 0x1D, 0x4F, 0x1D, 0x4E, 0x1B, 0x36, 0x18, 0x2A, 0x16, 0x23, 0x15, 0x27, 0x16, 0x24, 0x15, 0x27, 0x16, 0x27, 0x16, 0x24, 0x15, 0x25, 0x15, 0x27, 0x16, 0x25, 0x16, 0x24, 0x15, 0x26, 0x16, 0x25, 0x15, 0x29, 0x17, 0x27, 0x16, 0x24, 0x16, 0x25, 0x16, 0x28, 0x17, 0x27, 0x17, 0x26, 0x16, 0x25, 0x16, 0x28, 0x17, 0x2A, 0x18, 0x26, 0x16, 0x24, 0x16, 0x28, 0x17, 0x21, 0x13, 0x28, 0x17, 0x26, 0x16, 0x24, 0x16, 0x2A, 0x18, 0x28, 0x16, 0x29, 0x17, 0x23, 0x15, 0x2A, 0x18, 0x29, 0x16, 0x26, 0x16, 0x26, 0x16, 0x26, 0x17, 0x2A, 0x16, 0x24, 0x14, 0x1D, 0x12
    },

    {
        0x52, 0x49, 0x52, 0x48, 0x51, 0x49, 0x52, 0x49, 0x52, 0x49, 0x53, 0x49, 0x54, 0x4A, 0x55, 0x4A, 0x55, 0x4A, 0x55, 0x4B, 0x56, 0x4A, 0x55, 0x4A, 0x55, 0x4A, 0x56, 0x4B, 0x56, 0x4A, 0x57, 0x4B, 0x57, 0x4B, 0x59, 0x4C, 0x59, 0x4E, 0x59, 0x4D, 0x59, 0x4D, 0x5A, 0x4F, 0x5B, 0x4F, 0x5C, 0x4E, 0x5A, 0x4E, 0x5A, 0x4D, 0x5A, 0x4F, 0x5C, 0x50, 0x5B, 0x50, 0x5B, 0x50, 0x5C, 0x4F, 0x5B, 0x50, 0x5A, 0x4F, 0x5B, 0x4F, 0x5C, 0x4E, 0x59, 0x4F, 0x59, 0x4E, 0x59, 0x4E, 0x59, 0x4F, 0x5B, 0x4F, 0x5A, 0x4F, 0x5B, 0x4F, 0x5B, 0x51, 0x5C, 0x51, 0x58, 0x4F, 0x53, 0x49, 0x4D, 0x43, 0x43, 0x3C, 0x3D, 0x38, 0x3F, 0x3D, 0x4A, 0x48, 0x4B, 0x44, 0x3F, 0x3A, 0x30, 0x2B, 0x21, 0x20, 0x1A, 0x1B, 0x17, 0x18, 0x15, 0x17, 0x15, 0x17, 0x17, 0x1A, 0x1B, 0x21, 0x23, 0x2C, 0x2E, 0x37, 0x35, 0x3E, 0x39, 0x42, 0x3B, 0x46, 0x3E, 0x49, 0x3F, 0x49, 0x40, 0x49, 0x40, 0x4A, 0x40, 0x49, 0x3F, 0x49, 0x3F, 0x49, 0x3F, 0x49, 0x40, 0x4A, 0x40, 0x4B, 0x41, 0x4A, 0x40, 0x4B, 0x41, 0x4B, 0x3F, 0x4A, 0x3F, 0x48, 0x3D, 0x46, 0x3A, 0x43, 0x2F, 0x33, 0x21, 0x23, 0x1B, 0x1C, 0x17, 0x19, 0x15, 0x17, 0x15, 0x17, 0x15, 0x17, 0x17, 0x19, 0x1D, 0x21, 0x31, 0x36, 0x47, 0x47, 0x51, 0x4D, 0x53, 0x4D, 0x46, 0x3F, 0x39, 0x35, 0x45, 0x43, 0x55, 0x4F, 0x5B, 0x53, 0x60, 0x56, 0x62, 0x58, 0x65, 0x5B, 0x66, 0x5C, 0x66, 0x5B, 0x68, 0x5C, 0x68, 0x5C, 0x66, 0x5A, 0x67, 0x5A, 0x67, 0x5B, 0x68, 0x5C, 0x65, 0x59, 0x64, 0x58, 0x67, 0x5A, 0x66, 0x59, 0x67, 0x59, 0x66, 0x59, 0x66, 0x5A, 0x66, 0x5A, 0x66, 0x59, 0x66, 0x5A, 0x68, 0x5A, 0x66, 0x5A, 0x69, 0x5B, 0x69, 0x5C, 0x69, 0x5B, 0x68, 0x5B, 0x66, 0x5A, 0x65, 0x58, 0x66, 0x59, 0x67, 0x5A, 0x68, 0x5C, 0x69, 0x5B, 0x6C, 0x5E, 0x6B, 0x5C, 0x68, 0x5C, 0x68, 0x5C, 0x66, 0x5A, 0x64, 0x57, 0x63, 0x58, 0x64, 0x59, 0x65, 0x58, 0x66, 0x59, 0x67, 0x59, 0x66, 0x58, 0x65, 0x59, 0x67, 0x59, 0x65, 0x59, 0x66, 0x59, 0x66, 0x5A, 0x66, 0x5A, 0x63, 0x57, 0x64, 0x58, 0x67, 0x5A, 0x67, 0x5B, 0x65, 0x5A, 0x67, 0x5B, 0x66, 0x5A, 0x66, 0x59, 0x66, 0x58, 0x66, 0x59, 0x67, 0x59, 0x66, 0x59, 0x67, 0x5B, 0x66, 0x5B, 0x67, 0x5C, 0x64, 0x58, 0x65, 0x59, 0x65, 0x59, 0x65, 0x59, 0x63, 0x57, 0x65, 0x59, 0x64, 0x57, 0x65, 0x57, 0x64, 0x57, 0x65, 0x58, 0x63, 0x57, 0x63, 0x57, 0x62, 0x56, 0x63, 0x57, 0x61, 0x55, 0x62, 0x56, 0x62, 0x55, 0x61, 0x54, 0x62, 0x57, 0x64, 0x56, 0x63, 0x57, 0x62, 0x57, 0x65, 0x58, 0x64, 0x58, 0x63, 0x58, 0x61, 0x55, 0x62, 0x56, 0x62, 0x56, 0x62, 0x55, 0x61, 0x55, 0x60, 0x54, 0x5F, 0x53, 0x60, 0x54, 0x5F, 0x53, 0x62, 0x54, 0x62, 0x56, 0x61, 0x55, 0x62, 0x57, 0x63, 0x57, 0x61, 0x54, 0x61, 0x56, 0x61, 0x55, 0x61, 0x56, 0x60, 0x55, 0x5F, 0x53, 0x5E, 0x52, 0x5B, 0x50, 0x5C, 0x51, 0x5D, 0x52, 0x5F, 0x54, 0x5E, 0x54, 0x5F, 0x54, 0x61, 0x56, 0x61, 0x56, 0x61, 0x56, 0x60, 0x54, 0x5F, 0x54, 0x61, 0x55, 0x61, 0x54, 0x5E, 0x52, 0x5F, 0x54, 0x5E, 0x55, 0x5D, 0x52, 0x5B, 0x51, 0x5A, 0x50, 0x5C, 0x51, 0x5B, 0x51, 0x5B, 0x51, 0x5D, 0x53, 0x5B, 0x50, 0x5B, 0x50, 0x5A, 0x4F, 0x59, 0x50, 0x5B, 0x51, 0x5D, 0x52, 0x5D, 0x51, 0x5C, 0x51, 0x5D, 0x52, 0x5D, 0x52, 0x5D, 0x52, 0x5C, 0x51, 0x5C, 0x52, 0x5D, 0x53, 0x5E, 0x56, 0x5D, 0x55, 0x5E, 0x53, 0x5C, 0x52, 0x5D, 0x52, 0x5B, 0x50, 0x5B, 0x50, 0x5A, 0x50, 0x5A, 0x50, 0x58, 0x4E, 0x59, 0x4F, 0x58, 0x4F, 0x5B, 0x50, 0x5B, 0x51, 0x59, 0x4F, 0x59, 0x4E, 0x5C, 0x51, 0x5A, 0x4F, 0x59, 0x4F, 0x5A, 0x4F, 0x57, 0x4B, 0x59, 0x4E, 0x59, 0x4E, 0x5B, 0x4D, 0x57, 0x4D, 0x55, 0x4A, 0x53, 0x49, 0x37, 0x30, 0x28, 0x25, 0x21, 0x22, 0x24, 0x26, 0x22, 0x25, 0x23, 0x26, 0x23, 0x27, 0x20, 0x21, 0x22, 0x26, 0x23, 0x26, 0x21, 0x24, 0x20, 0x22, 0x22, 0x25, 0x22, 0x24, 0x25, 0x29, 0x21, 0x24, 0x22, 0x24, 0x21, 0x23, 0x25, 0x28, 0x23, 0x26, 0x23, 0x27, 0x22, 0x25, 0x23, 0x28, 0x26, 0x28, 0x22, 0x23, 0x20, 0x23, 0x22, 0x26, 0x1E, 0x21, 0x24, 0x28, 0x23, 0x26, 0x1F, 0x23, 0x26, 0x2A, 0x22, 0x23, 0x24, 0x26, 0x1F, 0x23, 0x24, 0x29, 0x22, 0x23, 0x22, 0x23, 0x21, 0x24, 0x21, 0x27, 0x24, 0x25, 0x1E, 0x1F, 0x1B, 0x1D
    },

    {
        0x4B, 0x1B, 0x4B, 0x1A, 0x4C, 0x1A, 0x4C, 0x1A, 0x4C, 0x1B, 0x4D, 0x1B, 0x4D, 0x1B, 0x4E, 0x1B, 0x4E, 0x1A, 0x4E, 0x1B, 0x4E, 0x1B, 0x4D, 0x1B, 0x4D, 0x1C, 0x4D, 0x1B, 0x4F, 0x1B, 0x4E, 0x1C, 0x4F, 0x1C, 0x51, 0x1D, 0x52, 0x1D, 0x51, 0x1C, 0x4F, 0x1C, 0x50, 0x1D, 0x52, 0x1D, 0x52, 0x1D, 0x52, 0x1D, 0x51, 0x1D, 0x51, 0x1D, 0x53, 0x1E, 0x53, 0x1D, 0x54, 0x1D, 0x53, 0x1E, 0x52, 0x1E, 0x52, 0x1E, 0x53, 0x1E, 0x53, 0x1E, 0x53, 0x1E, 0x52, 0x1E, 0x52, 0x1E, 0x53, 0x1E, 0x54, 0x1F, 0x54, 0x1F, 0x53, 0x1F, 0x55, 0x1F, 0x55, 0x1F, 0x50, 0x1E, 0x4A, 0x1C, 0x42, 0x1B, 0x3B, 0x19, 0x3D, 0x1A, 0x45, 0x1C, 0x48, 0x1C, 0x42, 0x1A, 0x36, 0x17, 0x26, 0x13, 0x1D, 0x11, 0x1A, 0x10, 0x18, 0x10, 0x18, 0x11, 0x19, 0x16, 0x1E, 0x1E, 0x28, 0x2A, 0x35, 0x38, 0x3F, 0x41, 0x43, 0x45, 0x45, 0x48, 0x48, 0x4B, 0x4B, 0x4F, 0x4D, 0x50, 0x4F, 0x50, 0x4E, 0x50, 0x4D, 0x4F, 0x4C, 0x4F, 0x4D, 0x4F, 0x4D, 0x50, 0x4E, 0x50, 0x4E, 0x50, 0x4E, 0x50, 0x4E, 0x51, 0x50, 0x50, 0x4F, 0x51, 0x4E, 0x50, 0x4C, 0x4D, 0x4C, 0x4B, 0x47, 0x43, 0x34, 0x2E, 0x25, 0x1F, 0x1D, 0x17, 0x1A, 0x14, 0x19, 0x12, 0x18, 0x11, 0x19, 0x11, 0x1B, 0x11, 0x23, 0x15, 0x39, 0x1A, 0x4A, 0x1E, 0x53, 0x1F, 0x51, 0x1F, 0x42, 0x1C, 0x39, 0x1B, 0x47, 0x1E, 0x54, 0x20, 0x59, 0x21, 0x5C, 0x21, 0x5F, 0x23, 0x61, 0x23, 0x61, 0x23, 0x62, 0x23, 0x60, 0x23, 0x61, 0x23, 0x5F, 0x23, 0x60, 0x23, 0x61, 0x23, 0x60, 0x22, 0x5E, 0x22, 0x60, 0x22, 0x60, 0x22, 0x5F, 0x22, 0x60, 0x22, 0x60, 0x21, 0x60, 0x22, 0x5F, 0x21, 0x60, 0x21, 0x61, 0x22, 0x5F, 0x21, 0x60, 0x21, 0x61, 0x22, 0x60, 0x22, 0x60, 0x22, 0x5F, 0x21, 0x5E, 0x21, 0x5F, 0x21, 0x5F, 0x22, 0x5F, 0x22, 0x61, 0x22, 0x62, 0x23, 0x60, 0x22, 0x61, 0x22, 0x61, 0x22, 0x61, 0x22, 0x5F, 0x21, 0x5D, 0x21, 0x5F, 0x21, 0x5D, 0x21, 0x5E, 0x21, 0x5E, 0x21, 0x60, 0x21, 0x5F, 0x21, 0x5D, 0x20, 0x5C, 0x20, 0x5A, 0x1F, 0x5D, 0x21, 0x60, 0x22, 0x5D, 0x21, 0x5C, 0x20, 0x5E, 0x21, 0x5F, 0x22, 0x5F, 0x21, 0x60, 0x22, 0x5F, 0x21, 0x5E, 0x21, 0x5E, 0x21, 0x5F, 0x21, 0x5F, 0x21, 0x61, 0x22, 0x60, 0x22, 0x62, 0x23, 0x62, 0x22, 0x61, 0x21, 0x5E, 0x21, 0x5E, 0x22, 0x5E, 0x22, 0x5E, 0x21, 0x5D, 0x20, 0x5C, 0x20, 0x5E, 0x21, 0x5F, 0x20, 0x5D, 0x20, 0x5B, 0x1F, 0x5A, 0x20, 0x5A, 0x20, 0x5B, 0x20, 0x5B, 0x20, 0x5B, 0x21, 0x5A, 0x1F, 0x5B, 0x1F, 0x5A, 0x1F, 0x5B, 0x20, 0x5D, 0x20, 0x5E, 0x21, 0x5E, 0x22, 0x5F, 0x22, 0x5E, 0x22, 0x5C, 0x21, 0x5C, 0x21, 0x5B, 0x20, 0x5A, 0x20, 0x5A, 0x20, 0x5B, 0x20, 0x59, 0x1F, 0x57, 0x1F, 0x58, 0x1F, 0x5B, 0x1F, 0x5D, 0x21, 0x5B, 0x20, 0x5C, 0x21, 0x5B, 0x20, 0x5A, 0x20, 0x59, 0x20, 0x59, 0x20, 0x5B, 0x21, 0x59, 0x20, 0x59, 0x20, 0x58, 0x1F, 0x57, 0x20, 0x58, 0x1F, 0x59, 0x20, 0x59, 0x20, 0x59, 0x1F, 0x58, 0x1F, 0x58, 0x1F, 0x5A, 0x1F, 0x5A, 0x20, 0x5A, 0x1F, 0x59, 0x20, 0x5B, 0x20, 0x5B, 0x20, 0x59, 0x20, 0x59, 0x20, 0x56, 0x1F, 0x55, 0x1F, 0x57, 0x1F, 0x55, 0x1E, 0x55, 0x1E, 0x55, 0x1E, 0x58, 0x1F, 0x55, 0x1F, 0x54, 0x1E, 0x53, 0x1E, 0x54, 0x1D, 0x51, 0x1E, 0x54, 0x1E, 0x55, 0x1E, 0x54, 0x1E, 0x54, 0x1F, 0x55, 0x1F, 0x57, 0x20, 0x57, 0x1F, 0x56, 0x1F, 0x54, 0x1F, 0x56, 0x20, 0x59, 0x22, 0x59, 0x22, 0x57, 0x20, 0x57, 0x20, 0x55, 0x1F, 0x56, 0x1F, 0x56, 0x1E, 0x56, 0x1F, 0x55, 0x1F, 0x57, 0x1F, 0x55, 0x1E, 0x53, 0x1E, 0x53, 0x1E, 0x55, 0x1F, 0x55, 0x1F, 0x52, 0x1E, 0x55, 0x1F, 0x54, 0x1E, 0x52, 0x1E, 0x52, 0x1E, 0x50, 0x1D, 0x52, 0x1E, 0x52, 0x1D, 0x52, 0x1D, 0x4F, 0x1D, 0x4E, 0x1D, 0x4E, 0x1D, 0x35, 0x18, 0x2E, 0x18, 0x24, 0x15, 0x2C, 0x18, 0x26, 0x16, 0x22, 0x14, 0x27, 0x16, 0x20, 0x13, 0x2B, 0x18, 0x24, 0x15, 0x26, 0x16, 0x21, 0x14, 0x27, 0x17, 0x27, 0x17, 0x23, 0x15, 0x24, 0x16, 0x23, 0x14, 0x25, 0x16, 0x28, 0x16, 0x21, 0x15, 0x26, 0x16, 0x26, 0x17, 0x28, 0x18, 0x24, 0x15, 0x24, 0x15, 0x20, 0x14, 0x28, 0x17, 0x23, 0x15, 0x25, 0x16, 0x23, 0x15, 0x21, 0x15, 0x25, 0x15, 0x1F, 0x14, 0x27, 0x16, 0x22, 0x15, 0x23, 0x14, 0x21, 0x13, 0x22, 0x15, 0x20, 0x12, 0x22, 0x15, 0x22, 0x14, 0x21, 0x14, 0x20, 0x13
    },

    {
        0x52, 0x48, 0x52, 0x48, 0x52, 0x49, 0x53, 0x49, 0x54, 0x49, 0x55, 0x49, 0x55, 0x4A, 0x56, 0x4B, 0x56, 0x4A, 0x55, 0x4A, 0x55, 0x4A, 0x55, 0x4A, 0x54, 0x4A, 0x55, 0x4A, 0x57, 0x4A, 0x57, 0x4A, 0x58, 0x4C, 0x59, 0x4D, 0x5A, 0x4E, 0x5A, 0x4D, 0x59, 0x4D, 0x59, 0x4E, 0x5A, 0x4F, 0x5B, 0x4F, 0x5B, 0x4E, 0x5A, 0x4E, 0x5B, 0x4F, 0x5B, 0x4F, 0x5B, 0x50, 0x5C, 0x50, 0x5B, 0x50, 0x5C, 0x4F, 0x5A, 0x4E, 0x5A, 0x4F, 0x5C, 0x4F, 0x5B, 0x50, 0x5A, 0x4F, 0x5A, 0x4F, 0x5A, 0x4E, 0x5B, 0x50, 0x5C, 0x51, 0x5B, 0x51, 0x5A, 0x51, 0x59, 0x4F, 0x54, 0x4B, 0x4C, 0x45, 0x45, 0x3C, 0x3D, 0x38, 0x3E, 0x3C, 0x48, 0x44, 0x4A, 0x43, 0x42, 0x3B, 0x33, 0x2D, 0x23, 0x21, 0x1B, 0x1B, 0x17, 0x18, 0x15, 0x17, 0x15, 0x17, 0x17, 0x1A, 0x1B, 0x21, 0x22, 0x2A, 0x2D, 0x36, 0x34, 0x3D, 0x39, 0x42, 0x3A, 0x43, 0x3C, 0x45, 0x3F, 0x48, 0x3F, 0x4A, 0x40, 0x4A, 0x40, 0x4A, 0x40, 0x49, 0x40, 0x4A, 0x40, 0x4A, 0x40, 0x4A, 0x41, 0x4B, 0x40, 0x4A, 0x41, 0x4A, 0x41, 0x4B, 0x41, 0x4B, 0x42, 0x4B, 0x40, 0x4A, 0x3E, 0x48, 0x3F, 0x47, 0x3B, 0x43, 0x30, 0x33, 0x23, 0x24, 0x1A, 0x1D, 0x16, 0x19, 0x15, 0x17, 0x14, 0x17, 0x15, 0x17, 0x17, 0x19, 0x1C, 0x1F, 0x2F, 0x33, 0x45, 0x45, 0x51, 0x4C, 0x52, 0x4D, 0x46, 0x3F, 0x39, 0x36, 0x43, 0x41, 0x54, 0x4E, 0x5B, 0x53, 0x5F, 0x56, 0x65, 0x59, 0x66, 0x5B, 0x66, 0x5D, 0x68, 0x5C, 0x67, 0x5B, 0x66, 0x5B, 0x66, 0x5A, 0x66, 0x5B, 0x66, 0x5C, 0x66, 0x5A, 0x65, 0x5A, 0x66, 0x5A, 0x68, 0x5B, 0x68, 0x5C, 0x68, 0x5A, 0x67, 0x5A, 0x68, 0x5A, 0x67, 0x59, 0x67, 0x5B, 0x68, 0x5B, 0x67, 0x5B, 0x68, 0x5A, 0x6A, 0x5C, 0x67, 0x5B, 0x67, 0x5B, 0x66, 0x5A, 0x64, 0x59, 0x65, 0x58, 0x67, 0x5A, 0x68, 0x5A, 0x68, 0x5B, 0x69, 0x5C, 0x6A, 0x5C, 0x6B, 0x5C, 0x68, 0x5B, 0x68, 0x5B, 0x67, 0x59, 0x65, 0x58, 0x66, 0x5A, 0x65, 0x58, 0x65, 0x58, 0x65, 0x58, 0x66, 0x59, 0x65, 0x58, 0x64, 0x56, 0x64, 0x56, 0x62, 0x54, 0x64, 0x57, 0x66, 0x58, 0x63, 0x57, 0x65, 0x58, 0x66, 0x5A, 0x65, 0x58, 0x67, 0x5A, 0x66, 0x59, 0x65, 0x59, 0x64, 0x58, 0x65, 0x59, 0x66, 0x59, 0x65, 0x59, 0x69, 0x5B, 0x68, 0x5B, 0x69, 0x5C, 0x69, 0x5C, 0x69, 0x5A, 0x66, 0x59, 0x65, 0x58, 0x63, 0x58, 0x65, 0x57, 0x63, 0x57, 0x64, 0x58, 0x67, 0x5A, 0x67, 0x5A, 0x65, 0x58, 0x63, 0x56, 0x62, 0x56, 0x62, 0x54, 0x62, 0x57, 0x62, 0x56, 0x63, 0x56, 0x63, 0x56, 0x62, 0x55, 0x61, 0x55, 0x63, 0x55, 0x64, 0x57, 0x63, 0x59, 0x64, 0x58, 0x65, 0x5A, 0x67, 0x5A, 0x64, 0x57, 0x62, 0x56, 0x62, 0x56, 0x63, 0x54, 0x62, 0x56, 0x63, 0x56, 0x60, 0x54, 0x5F, 0x52, 0x60, 0x53, 0x62, 0x56, 0x64, 0x58, 0x63, 0x56, 0x63, 0x56, 0x63, 0x57, 0x60, 0x55, 0x60, 0x53, 0x60, 0x54, 0x61, 0x55, 0x61, 0x54, 0x60, 0x54, 0x5F, 0x52, 0x5E, 0x53, 0x5E, 0x53, 0x60, 0x53, 0x60, 0x53, 0x5F, 0x54, 0x5E, 0x51, 0x5F, 0x53, 0x61, 0x54, 0x5F, 0x53, 0x5F, 0x53, 0x5F, 0x55, 0x61, 0x57, 0x62, 0x55, 0x60, 0x53, 0x5F, 0x54, 0x5E, 0x51, 0x5C, 0x50, 0x5C, 0x52, 0x5C, 0x50, 0x5D, 0x50, 0x5B, 0x51, 0x5D, 0x52, 0x5A, 0x50, 0x59, 0x50, 0x58, 0x4F, 0x58, 0x4E, 0x59, 0x4F, 0x5B, 0x4F, 0x5C, 0x50, 0x5A, 0x4F, 0x5B, 0x50, 0x5C, 0x51, 0x5C, 0x52, 0x5D, 0x52, 0x5D, 0x50, 0x5B, 0x50, 0x5D, 0x54, 0x5E, 0x55, 0x5C, 0x54, 0x5D, 0x52, 0x5E, 0x53, 0x5B, 0x52, 0x5C, 0x51, 0x5C, 0x51, 0x5E, 0x51, 0x5D, 0x51, 0x5C, 0x50, 0x5A, 0x50, 0x5A, 0x51, 0x58, 0x4E, 0x59, 0x4F, 0x5B, 0x4F, 0x5B, 0x4F, 0x5C, 0x52, 0x5C, 0x4F, 0x59, 0x50, 0x59, 0x4E, 0x58, 0x4D, 0x59, 0x4E, 0x5B, 0x4F, 0x59, 0x4D, 0x56, 0x4C, 0x55, 0x4B, 0x53, 0x48, 0x35, 0x30, 0x2C, 0x2B, 0x22, 0x23, 0x26, 0x28, 0x20, 0x22, 0x1D, 0x1F, 0x22, 0x22, 0x1D, 0x1F, 0x24, 0x27, 0x1E, 0x20, 0x21, 0x23, 0x1D, 0x1E, 0x24, 0x27, 0x22, 0x24, 0x1E, 0x1E, 0x20, 0x22, 0x20, 0x20, 0x22, 0x26, 0x22, 0x22, 0x1D, 0x1E, 0x21, 0x22, 0x20, 0x22, 0x22, 0x23, 0x1E, 0x20, 0x20, 0x22, 0x1D, 0x1E, 0x24, 0x27, 0x1E, 0x23, 0x20, 0x21, 0x20, 0x21, 0x1E, 0x20, 0x1F, 0x20, 0x1D, 0x1F, 0x23, 0x25, 0x1E, 0x1F, 0x1D, 0x1F, 0x1D, 0x1F, 0x1F, 0x21, 0x1C, 0x1C, 0x1F, 0x22, 0x1F, 0x21, 0x1F, 0x21, 0x1E, 0x20
    },

    {
        0x4C, 0x1B, 0x4C, 0x1A, 0x4B, 0x1B, 0x4C, 0x1B, 0x4D, 0x1B, 0x4D, 0x1B, 0x4C, 0x1B, 0x4D, 0x1B, 0x4F, 0x1B, 0x4E, 0x1B, 0x4E, 0x1B, 0x4D, 0x1B, 0x4E, 0x1B, 0x4E, 0x1B, 0x4E, 0x1C, 0x4E, 0x1C, 0x50, 0x1C, 0x50, 0x1C, 0x50, 0x1D, 0x50, 0x1C, 0x50, 0x1D, 0x51, 0x1D, 0x50, 0x1D, 0x51, 0x1C, 0x52, 0x1D, 0x52, 0x1D, 0x53, 0x1E, 0x53, 0x1D, 0x53, 0x1D, 0x52, 0x1E, 0x53, 0x1D, 0x51, 0x1E, 0x52, 0x1E, 0x52, 0x1E, 0x52, 0x1E, 0x52, 0x1E, 0x52, 0x1E, 0x53, 0x1E, 0x53, 0x1E, 0x55, 0x1F, 0x55, 0x1F, 0x54, 0x1F, 0x54, 0x1F, 0x51, 0x1E, 0x4B, 0x1D, 0x43, 0x1B, 0x3B, 0x1A, 0x3B, 0x1A, 0x43, 0x1B, 0x48, 0x1C, 0x43, 0x1B, 0x37, 0x18, 0x27, 0x14, 0x1F, 0x12, 0x1B, 0x10, 0x19, 0x11, 0x18, 0x12, 0x19, 0x15, 0x1E, 0x1E, 0x27, 0x29, 0x33, 0x36, 0x3E, 0x41, 0x42, 0x45, 0x45, 0x49, 0x47, 0x4A, 0x4A, 0x4B, 0x4B, 0x4E, 0x4D, 0x4F, 0x4E, 0x51, 0x4F, 0x51, 0x4E, 0x51, 0x4E, 0x50, 0x4D, 0x50, 0x4E, 0x4F, 0x4F, 0x50, 0x4E, 0x50, 0x4E, 0x50, 0x4F, 0x51, 0x4F, 0x50, 0x50, 0x50, 0x50, 0x51, 0x4D, 0x4F, 0x4D, 0x4E, 0x4A, 0x4B, 0x46, 0x44, 0x36, 0x32, 0x26, 0x21, 0x1E, 0x18, 0x1B, 0x14, 0x18, 0x12, 0x19, 0x12, 0x19, 0x11, 0x1B, 0x12, 0x21, 0x14, 0x37, 0x1A, 0x49, 0x1E, 0x52, 0x1F, 0x51, 0x1F, 0x45, 0x1C, 0x39, 0x1B, 0x44, 0x1D, 0x54, 0x20, 0x59, 0x22, 0x5B, 0x21, 0x5C, 0x23, 0x61, 0x23, 0x61, 0x23, 0x61, 0x23, 0x61, 0x23, 0x60, 0x23, 0x5E, 0x22, 0x60, 0x23, 0x61, 0x23, 0x60, 0x23, 0x5E, 0x23, 0x5F, 0x22, 0x60, 0x22, 0x61, 0x22, 0x5F, 0x21, 0x61, 0x22, 0x60, 0x22, 0x60, 0x22, 0x61, 0x23, 0x60, 0x22, 0x60, 0x22, 0x62, 0x22, 0x61, 0x22, 0x60, 0x22, 0x5E, 0x22, 0x5E, 0x21, 0x5E, 0x22, 0x60, 0x21, 0x61, 0x21, 0x60, 0x22, 0x60, 0x22, 0x61, 0x23, 0x61, 0x22, 0x60, 0x22, 0x60, 0x22, 0x5E, 0x21, 0x5D, 0x21, 0x5D, 0x21, 0x5D, 0x21, 0x5D, 0x20, 0x5E, 0x20, 0x5C, 0x20, 0x5D, 0x21, 0x5B, 0x20, 0x5C, 0x20, 0x59, 0x1F, 0x5B, 0x20, 0x5C, 0x20, 0x5D, 0x20, 0x5C, 0x21, 0x5F, 0x21, 0x5D, 0x20, 0x5D, 0x21, 0x5F, 0x21, 0x5F, 0x21, 0x5E, 0x21, 0x5F, 0x21, 0x5E, 0x22, 0x5E, 0x22, 0x5E, 0x22, 0x5F, 0x22, 0x61, 0x23, 0x63, 0x23, 0x61, 0x22, 0x61, 0x22, 0x5F, 0x22, 0x5D, 0x21, 0x5F, 0x21, 0x5C, 0x21, 0x5D, 0x21, 0x5D, 0x21, 0x5D, 0x20, 0x5D, 0x20, 0x5B, 0x20, 0x5C, 0x20, 0x5C, 0x20, 0x5B, 0x20, 0x5D, 0x21, 0x5F, 0x23, 0x5C, 0x21, 0x5A, 0x1F, 0x59, 0x20, 0x5B, 0x20, 0x5D, 0x21, 0x5D, 0x21, 0x5F, 0x22, 0x5D, 0x21, 0x5D, 0x21, 0x5B, 0x21, 0x5C, 0x21, 0x5C, 0x21, 0x5A, 0x20, 0x5B, 0x21, 0x5B, 0x20, 0x5A, 0x1F, 0x59, 0x20, 0x5A, 0x20, 0x5B, 0x20, 0x5D, 0x20, 0x5A, 0x20, 0x5B, 0x20, 0x5A, 0x20, 0x5A, 0x20, 0x59, 0x20, 0x5B, 0x20, 0x5A, 0x20, 0x58, 0x20, 0x59, 0x20, 0x58, 0x20, 0x5B, 0x20, 0x57, 0x1F, 0x57, 0x20, 0x57, 0x1F, 0x57, 0x1F, 0x57, 0x20, 0x58, 0x1F, 0x57, 0x1F, 0x56, 0x1F, 0x57, 0x1F, 0x59, 0x20, 0x5C, 0x22, 0x5D, 0x21, 0x58, 0x20, 0x59, 0x20, 0x57, 0x1F, 0x56, 0x1F, 0x56, 0x1F, 0x54, 0x1E, 0x56, 0x1E, 0x54, 0x1F, 0x55, 0x1F, 0x54, 0x1E, 0x53, 0x1E, 0x54, 0x1E, 0x52, 0x1D, 0x53, 0x1E, 0x54, 0x1E, 0x54, 0x1E, 0x54, 0x1F, 0x54, 0x1E, 0x56, 0x1E, 0x56, 0x20, 0x55, 0x1F, 0x56, 0x1F, 0x55, 0x1F, 0x57, 0x20, 0x57, 0x20, 0x55, 0x1F, 0x55, 0x1F, 0x58, 0x1F, 0x56, 0x1F, 0x54, 0x1F, 0x55, 0x1F, 0x54, 0x1E, 0x55, 0x1F, 0x55, 0x1E, 0x52, 0x1D, 0x53, 0x1E, 0x53, 0x1E, 0x54, 0x1F, 0x54, 0x1F, 0x56, 0x1F, 0x56, 0x1F, 0x54, 0x1F, 0x54, 0x1F, 0x54, 0x1E, 0x52, 0x1E, 0x52, 0x1E, 0x51, 0x1E, 0x53, 0x1E, 0x52, 0x1E, 0x4D, 0x1C, 0x4D, 0x1C, 0x32, 0x17, 0x2A, 0x16, 0x23, 0x15, 0x28, 0x16, 0x22, 0x15, 0x20, 0x15, 0x23, 0x15, 0x24, 0x16, 0x26, 0x16, 0x21, 0x14, 0x24, 0x15, 0x20, 0x14, 0x28, 0x17, 0x27, 0x16, 0x20, 0x13, 0x25, 0x15, 0x22, 0x15, 0x26, 0x17, 0x23, 0x15, 0x22, 0x15, 0x24, 0x15, 0x24, 0x15, 0x26, 0x17, 0x22, 0x14, 0x20, 0x14, 0x21, 0x14, 0x26, 0x16, 0x20, 0x14, 0x21, 0x15, 0x21, 0x14, 0x26, 0x16, 0x24, 0x15, 0x23, 0x15, 0x2A, 0x16, 0x23, 0x15, 0x25, 0x16, 0x28, 0x16, 0x24, 0x15, 0x20, 0x13, 0x27, 0x16, 0x28, 0x17, 0x24, 0x14, 0x22, 0x14
    },

    {
        0x53, 0x48, 0x52, 0x47, 0x53, 0x48, 0x54, 0x4A, 0x56, 0x4A, 0x55, 0x4A, 0x56, 0x4A, 0x55, 0x4A, 0x57, 0x4B, 0x55, 0x4B, 0x55, 0x4A, 0x55, 0x4A, 0x55, 0x4A, 0x55, 0x4A, 0x56, 0x4B, 0x58, 0x4C, 0x59, 0x4D, 0x5A, 0x4C, 0x58, 0x4D, 0x59, 0x4D, 0x59, 0x4E, 0x59, 0x4D, 0x59, 0x4E, 0x58, 0x4E, 0x5A, 0x4F, 0x5B, 0x50, 0x5B, 0x4F, 0x5B, 0x50, 0x5A, 0x50, 0x5B, 0x4F, 0x5A, 0x4F, 0x5B, 0x4F, 0x5A, 0x4F, 0x5A, 0x4E, 0x5A, 0x4E, 0x5A, 0x4E, 0x5B, 0x4F, 0x5C, 0x51, 0x5D, 0x51, 0x5C, 0x4F, 0x5C, 0x50, 0x59, 0x50, 0x59, 0x4F, 0x55, 0x4A, 0x4D, 0x45, 0x45, 0x3D, 0x3D, 0x38, 0x3D, 0x3B, 0x46, 0x42, 0x4A, 0x43, 0x43, 0x3C, 0x35, 0x2F, 0x24, 0x22, 0x1B, 0x1B, 0x17, 0x18, 0x15, 0x17, 0x15, 0x17, 0x16, 0x19, 0x1A, 0x20, 0x22, 0x2A, 0x2B, 0x36, 0x34, 0x3D, 0x37, 0x40, 0x3A, 0x43, 0x3B, 0x45, 0x3D, 0x47, 0x3F, 0x48, 0x40, 0x4A, 0x41, 0x4B, 0x40, 0x4B, 0x41, 0x4A, 0x40, 0x4A, 0x40, 0x4A, 0x40, 0x4A, 0x41, 0x49, 0x40, 0x4A, 0x41, 0x4B, 0x41, 0x4B, 0x41, 0x4C, 0x41, 0x4B, 0x41, 0x4B, 0x41, 0x4A, 0x40, 0x49, 0x3E, 0x47, 0x3B, 0x44, 0x31, 0x35, 0x23, 0x26, 0x1B, 0x1D, 0x17, 0x19, 0x15, 0x17, 0x14, 0x16, 0x14, 0x17, 0x16, 0x18, 0x1B, 0x1E, 0x2C, 0x30, 0x43, 0x43, 0x50, 0x4D, 0x54, 0x4D, 0x4A, 0x42, 0x3A, 0x36, 0x41, 0x40, 0x52, 0x4E, 0x5B, 0x54, 0x5E, 0x56, 0x62, 0x58, 0x65, 0x5A, 0x67, 0x5C, 0x68, 0x5B, 0x68, 0x5B, 0x66, 0x5B, 0x64, 0x5A, 0x66, 0x5C, 0x67, 0x5C, 0x66, 0x5B, 0x65, 0x5A, 0x67, 0x5B, 0x68, 0x5B, 0x68, 0x5B, 0x67, 0x59, 0x68, 0x5C, 0x68, 0x5A, 0x68, 0x5B, 0x68, 0x5C, 0x68, 0x5A, 0x68, 0x5C, 0x68, 0x5B, 0x69, 0x5C, 0x68, 0x5A, 0x65, 0x59, 0x65, 0x58, 0x65, 0x59, 0x68, 0x5B, 0x69, 0x5C, 0x68, 0x5A, 0x69, 0x5B, 0x69, 0x5C, 0x69, 0x5B, 0x6A, 0x5B, 0x68, 0x5A, 0x66, 0x59, 0x65, 0x58, 0x65, 0x58, 0x65, 0x57, 0x63, 0x57, 0x65, 0x58, 0x65, 0x58, 0x64, 0x57, 0x63, 0x56, 0x64, 0x57, 0x62, 0x54, 0x63, 0x57, 0x64, 0x57, 0x64, 0x57, 0x64, 0x58, 0x68, 0x5A, 0x66, 0x58, 0x64, 0x58, 0x67, 0x5A, 0x67, 0x59, 0x65, 0x59, 0x66, 0x59, 0x65, 0x58, 0x64, 0x58, 0x65, 0x59, 0x65, 0x5A, 0x67, 0x5B, 0x6A, 0x5C, 0x68, 0x5A, 0x69, 0x5B, 0x64, 0x58, 0x63, 0x57, 0x66, 0x59, 0x64, 0x57, 0x62, 0x58, 0x65, 0x57, 0x65, 0x57, 0x64, 0x57, 0x63, 0x56, 0x63, 0x57, 0x63, 0x56, 0x64, 0x57, 0x64, 0x57, 0x65, 0x59, 0x64, 0x59, 0x62, 0x56, 0x61, 0x55, 0x62, 0x56, 0x64, 0x57, 0x63, 0x59, 0x65, 0x59, 0x64, 0x57, 0x63, 0x56, 0x63, 0x55, 0x63, 0x55, 0x61, 0x56, 0x62, 0x55, 0x64, 0x57, 0x65, 0x56, 0x60, 0x53, 0x5F, 0x54, 0x61, 0x55, 0x62, 0x56, 0x64, 0x57, 0x62, 0x55, 0x62, 0x55, 0x61, 0x53, 0x62, 0x54, 0x5F, 0x54, 0x61, 0x55, 0x61, 0x54, 0x60, 0x53, 0x61, 0x54, 0x5F, 0x55, 0x60, 0x54, 0x5E, 0x51, 0x5F, 0x51, 0x5E, 0x53, 0x5E, 0x52, 0x5F, 0x52, 0x5E, 0x53, 0x5E, 0x52, 0x5C, 0x51, 0x5E, 0x53, 0x60, 0x55, 0x61, 0x57, 0x61, 0x55, 0x5F, 0x54, 0x5F, 0x55, 0x5E, 0x51, 0x5D, 0x51, 0x5C, 0x50, 0x5C, 0x51, 0x5C, 0x51, 0x5C, 0x51, 0x5C, 0x52, 0x5C, 0x50, 0x5A, 0x4F, 0x5A, 0x4F, 0x5A, 0x4F, 0x59, 0x4F, 0x5B, 0x4F, 0x5A, 0x4F, 0x5B, 0x51, 0x5C, 0x50, 0x5C, 0x4F, 0x5D, 0x53, 0x5A, 0x50, 0x5B, 0x51, 0x5B, 0x51, 0x5D, 0x53, 0x5D, 0x51, 0x5A, 0x50, 0x5A, 0x51, 0x5E, 0x52, 0x5B, 0x52, 0x5A, 0x50, 0x5B, 0x52, 0x5B, 0x4F, 0x5B, 0x4F, 0x5B, 0x50, 0x59, 0x4E, 0x5A, 0x4F, 0x5A, 0x50, 0x5B, 0x51, 0x5C, 0x51, 0x5F, 0x52, 0x5B, 0x50, 0x5C, 0x51, 0x5C, 0x50, 0x5C, 0x50, 0x5B, 0x4E, 0x59, 0x4E, 0x58, 0x4E, 0x5A, 0x4F, 0x57, 0x4C, 0x55, 0x4B, 0x52, 0x46, 0x33, 0x2C, 0x28, 0x26, 0x21, 0x23, 0x22, 0x23, 0x20, 0x21, 0x1E, 0x20, 0x20, 0x23, 0x22, 0x26, 0x22, 0x26, 0x1F, 0x22, 0x21, 0x23, 0x1E, 0x21, 0x25, 0x28, 0x23, 0x25, 0x1D, 0x1D, 0x20, 0x24, 0x20, 0x23, 0x23, 0x25, 0x21, 0x24, 0x1F, 0x22, 0x20, 0x21, 0x20, 0x24, 0x23, 0x26, 0x1F, 0x20, 0x1E, 0x21, 0x1F, 0x22, 0x23, 0x24, 0x1E, 0x1F, 0x1F, 0x21, 0x1F, 0x21, 0x23, 0x26, 0x21, 0x23, 0x21, 0x24, 0x25, 0x28, 0x1F, 0x22, 0x23, 0x26, 0x23, 0x25, 0x22, 0x23, 0x1D, 0x1F, 0x23, 0x26, 0x22, 0x25, 0x1F, 0x1E, 0x20, 0x23
    },

    {
        0x4C, 0x1B, 0x4C, 0x1A, 0x4C, 0x1B, 0x4C, 0x1A, 0x4C, 0x1B, 0x4D, 0x1B, 0x4D, 0x1B, 0x4D, 0x1B, 0x4D, 0x1B, 0x4E, 0x1B, 0x4F, 0x1C, 0x4E, 0x1B, 0x4E, 0x1C, 0x4E, 0x1C, 0x4E, 0x1B, 0x4F, 0x1C, 0x50, 0x1C, 0x50, 0x1C, 0x50, 0x1C, 0x50, 0x1C, 0x51, 0x1D, 0x51, 0x1C, 0x51, 0x1D, 0x52, 0x1D, 0x51, 0x1C, 0x51, 0x1D, 0x51, 0x1D, 0x52, 0x1D, 0x52, 0x1D, 0x53, 0x1D, 0x51, 0x1D, 0x51, 0x1D, 0x52, 0x1D, 0x52, 0x1D, 0x51, 0x1E, 0x51, 0x1E, 0x51, 0x1E, 0x53, 0x1E, 0x54, 0x1E, 0x54, 0x1E, 0x54, 0x1E, 0x53, 0x1E, 0x50, 0x1D, 0x4B, 0x1C, 0x44, 0x1B, 0x3D, 0x1A, 0x3B, 0x1A, 0x42, 0x1B, 0x47, 0x1C, 0x42, 0x1A, 0x38, 0x18, 0x29, 0x14, 0x20, 0x12, 0x1C, 0x11, 0x19, 0x10, 0x18, 0x11, 0x19, 0x15, 0x1E, 0x1C, 0x26, 0x28, 0x33, 0x36, 0x3D, 0x41, 0x43, 0x45, 0x46, 0x47, 0x47, 0x49, 0x49, 0x4B, 0x4A, 0x4C, 0x4C, 0x4F, 0x4D, 0x4F, 0x4E, 0x50, 0x4F, 0x50, 0x4E, 0x50, 0x4F, 0x50, 0x4E, 0x50, 0x4F, 0x50, 0x4E, 0x51, 0x4D, 0x50, 0x4F, 0x51, 0x4F, 0x51, 0x4F, 0x51, 0x50, 0x51, 0x4F, 0x50, 0x4E, 0x4F, 0x4E, 0x50, 0x4C, 0x4D, 0x4B, 0x4C, 0x49, 0x47, 0x3A, 0x34, 0x28, 0x22, 0x1F, 0x18, 0x1B, 0x14, 0x19, 0x13, 0x18, 0x11, 0x19, 0x11, 0x1A, 0x11, 0x20, 0x14, 0x34, 0x18, 0x49, 0x1D, 0x50, 0x1F, 0x53, 0x1F, 0x47, 0x1C, 0x38, 0x1A, 0x43, 0x1E, 0x53, 0x20, 0x5A, 0x22, 0x5B, 0x21, 0x5D, 0x22, 0x5F, 0x22, 0x61, 0x23, 0x62, 0x22, 0x61, 0x23, 0x61, 0x23, 0x61, 0x23, 0x61, 0x23, 0x61, 0x23, 0x5F, 0x23, 0x60, 0x22, 0x60, 0x22, 0x61, 0x22, 0x60, 0x21, 0x61, 0x22, 0x61, 0x22, 0x60, 0x21, 0x60, 0x22, 0x61, 0x22, 0x60, 0x22, 0x62, 0x22, 0x61, 0x22, 0x62, 0x22, 0x5F, 0x21, 0x5C, 0x21, 0x5D, 0x21, 0x5F, 0x21, 0x61, 0x22, 0x60, 0x21, 0x60, 0x22, 0x5F, 0x21, 0x5F, 0x22, 0x60, 0x22, 0x60, 0x21, 0x5D, 0x20, 0x5E, 0x20, 0x5E, 0x21, 0x5D, 0x20, 0x5E, 0x20, 0x5D, 0x20, 0x5D, 0x20, 0x5E, 0x21, 0x5C, 0x20, 0x5B, 0x20, 0x5B, 0x20, 0x5C, 0x20, 0x5E, 0x20, 0x5E, 0x20, 0x5D, 0x21, 0x5F, 0x21, 0x5E, 0x20, 0x5C, 0x20, 0x5D, 0x21, 0x5D, 0x21, 0x5E, 0x21, 0x5E, 0x21, 0x5D, 0x21, 0x5F, 0x22, 0x5D, 0x22, 0x5D, 0x21, 0x5D, 0x21, 0x5F, 0x22, 0x60, 0x22, 0x61, 0x22, 0x5F, 0x22, 0x5D, 0x21, 0x5C, 0x20, 0x5C, 0x20, 0x5B, 0x20, 0x5B, 0x21, 0x5B, 0x1F, 0x5A, 0x1F, 0x5B, 0x1F, 0x5A, 0x20, 0x5C, 0x20, 0x5B, 0x20, 0x5C, 0x20, 0x5B, 0x20, 0x5B, 0x20, 0x5A, 0x20, 0x5B, 0x20, 0x5C, 0x20, 0x5B, 0x20, 0x5C, 0x21, 0x5F, 0x21, 0x5C, 0x21, 0x5B, 0x20, 0x5A, 0x20, 0x5B, 0x20, 0x5C, 0x21, 0x5B, 0x20, 0x5B, 0x21, 0x5A, 0x1F, 0x59, 0x20, 0x5A, 0x20, 0x5C, 0x20, 0x5A, 0x20, 0x5B, 0x20, 0x5B, 0x21, 0x5A, 0x20, 0x57, 0x1F, 0x59, 0x20, 0x59, 0x1F, 0x58, 0x1F, 0x58, 0x1F, 0x57, 0x1F, 0x58, 0x1F, 0x56, 0x1E, 0x59, 0x1F, 0x58, 0x20, 0x57, 0x1F, 0x58, 0x1F, 0x56, 0x1F, 0x56, 0x20, 0x57, 0x20, 0x58, 0x1F, 0x58, 0x1F, 0x59, 0x1F, 0x59, 0x20, 0x5C, 0x21, 0x5A, 0x20, 0x5B, 0x22, 0x5B, 0x20, 0x57, 0x1E, 0x56, 0x1F, 0x54, 0x1E, 0x54, 0x1F, 0x56, 0x1E, 0x54, 0x1E, 0x56, 0x1E, 0x54, 0x1E, 0x53, 0x1D, 0x54, 0x1E, 0x54, 0x1E, 0x54, 0x1E, 0x53, 0x1E, 0x54, 0x1E, 0x57, 0x1F, 0x54, 0x1F, 0x54, 0x1E, 0x58, 0x20, 0x56, 0x1F, 0x57, 0x20, 0x57, 0x20, 0x56, 0x1F, 0x56, 0x1F, 0x55, 0x1F, 0x53, 0x1E, 0x55, 0x1F, 0x55, 0x1E, 0x54, 0x1E, 0x54, 0x1F, 0x53, 0x1D, 0x52, 0x1E, 0x55, 0x1E, 0x53, 0x1E, 0x53, 0x1F, 0x52, 0x1E, 0x54, 0x1E, 0x55, 0x1F, 0x54, 0x1E, 0x52, 0x1F, 0x55, 0x1E, 0x55, 0x1E, 0x53, 0x1E, 0x55, 0x1E, 0x54, 0x1E, 0x50, 0x1E, 0x52, 0x1E, 0x52, 0x1E, 0x4F, 0x1D, 0x4C, 0x1C, 0x32, 0x17, 0x2D, 0x18, 0x2A, 0x17, 0x28, 0x18, 0x2A, 0x18, 0x23, 0x16, 0x2D, 0x18, 0x29, 0x17, 0x2B, 0x17, 0x22, 0x13, 0x28, 0x17, 0x27, 0x17, 0x2C, 0x18, 0x25, 0x16, 0x1F, 0x13, 0x29, 0x18, 0x27, 0x16, 0x28, 0x17, 0x27, 0x16, 0x24, 0x15, 0x2B, 0x18, 0x28, 0x17, 0x28, 0x16, 0x21, 0x14, 0x29, 0x17, 0x24, 0x15, 0x27, 0x15, 0x21, 0x13, 0x23, 0x15, 0x2A, 0x17, 0x25, 0x15, 0x25, 0x15, 0x25, 0x16, 0x27, 0x15, 0x20, 0x14, 0x28, 0x16, 0x20, 0x13, 0x21, 0x14, 0x1F, 0x12, 0x23, 0x14, 0x1D, 0x12, 0x20, 0x14, 0x29, 0x16
    },

    {
        0x53, 0x48, 0x53, 0x48, 0x53, 0x49, 0x54, 0x4A, 0x54, 0x4A, 0x55, 0x4A, 0x55, 0x4A, 0x55, 0x49, 0x55, 0x4A, 0x56, 0x4A, 0x56, 0x4B, 0x55, 0x4A, 0x56, 0x4B, 0x56, 0x4B, 0x56, 0x4B, 0x58, 0x4C, 0x58, 0x4C, 0x5A, 0x4C, 0x5A, 0x4C, 0x59, 0x4D, 0x5A, 0x4E, 0x59, 0x4E, 0x59, 0x4D, 0x5A, 0x4E, 0x5A, 0x4E, 0x58, 0x4D, 0x59, 0x4D, 0x59, 0x4E, 0x59, 0x4E, 0x5A, 0x4E, 0x59, 0x4E, 0x5A, 0x4E, 0x5A, 0x4D, 0x5A, 0x4D, 0x59, 0x4E, 0x59, 0x4E, 0x5A, 0x4E, 0x5B, 0x50, 0x5D, 0x51, 0x5D, 0x50, 0x5C, 0x50, 0x59, 0x4E, 0x54, 0x4B, 0x4E, 0x44, 0x46, 0x3D, 0x3E, 0x39, 0x3E, 0x3B, 0x46, 0x42, 0x49, 0x42, 0x42, 0x3C, 0x35, 0x30, 0x25, 0x23, 0x1C, 0x1C, 0x18, 0x19, 0x16, 0x17, 0x15, 0x17, 0x16, 0x19, 0x1A, 0x1F, 0x21, 0x29, 0x2B, 0x34, 0x34, 0x3C, 0x38, 0x41, 0x3B, 0x43, 0x3C, 0x44, 0x3C, 0x46, 0x3E, 0x47, 0x40, 0x48, 0x3F, 0x49, 0x41, 0x49, 0x41, 0x4A, 0x40, 0x4A, 0x40, 0x49, 0x40, 0x49, 0x41, 0x4A, 0x41, 0x4B, 0x40, 0x4A, 0x41, 0x4B, 0x41, 0x4C, 0x42, 0x4B, 0x41, 0x4C, 0x42, 0x4B, 0x41, 0x4A, 0x41, 0x4A, 0x3F, 0x48, 0x3D, 0x47, 0x3D, 0x47, 0x34, 0x37, 0x25, 0x27, 0x1C, 0x1D, 0x18, 0x19, 0x15, 0x17, 0x15, 0x17, 0x15, 0x17, 0x16, 0x18, 0x1A, 0x1C, 0x2A, 0x2E, 0x42, 0x43, 0x4F, 0x4B, 0x54, 0x4E, 0x4C, 0x45, 0x3A, 0x34, 0x3F, 0x3C, 0x50, 0x4D, 0x5C, 0x55, 0x60, 0x56, 0x61, 0x58, 0x64, 0x5A, 0x68, 0x5C, 0x67, 0x5B, 0x66, 0x5C, 0x66, 0x5B, 0x68, 0x5C, 0x67, 0x5B, 0x66, 0x5B, 0x67, 0x5B, 0x68, 0x5B, 0x69, 0x5C, 0x68, 0x5B, 0x68, 0x5B, 0x68, 0x5C, 0x69, 0x5B, 0x66, 0x5A, 0x69, 0x5B, 0x68, 0x5B, 0x68, 0x5A, 0x69, 0x5B, 0x68, 0x5C, 0x69, 0x5C, 0x67, 0x59, 0x64, 0x58, 0x66, 0x58, 0x67, 0x5A, 0x69, 0x5B, 0x67, 0x59, 0x69, 0x5A, 0x69, 0x59, 0x68, 0x5A, 0x69, 0x5C, 0x68, 0x5A, 0x64, 0x57, 0x66, 0x58, 0x67, 0x58, 0x64, 0x58, 0x65, 0x57, 0x66, 0x58, 0x66, 0x58, 0x66, 0x59, 0x64, 0x57, 0x63, 0x55, 0x62, 0x54, 0x65, 0x58, 0x67, 0x59, 0x65, 0x56, 0x65, 0x56, 0x66, 0x58, 0x66, 0x58, 0x63, 0x58, 0x66, 0x59, 0x64, 0x57, 0x64, 0x57, 0x65, 0x57, 0x63, 0x58, 0x63, 0x59, 0x63, 0x57, 0x62, 0x57, 0x63, 0x57, 0x65, 0x59, 0x68, 0x5B, 0x67, 0x5C, 0x64, 0x58, 0x65, 0x58, 0x63, 0x57, 0x63, 0x57, 0x63, 0x56, 0x64, 0x57, 0x64, 0x56, 0x63, 0x54, 0x63, 0x56, 0x62, 0x56, 0x64, 0x58, 0x64, 0x57, 0x63, 0x56, 0x63, 0x57, 0x61, 0x55, 0x60, 0x54, 0x61, 0x55, 0x63, 0x57, 0x63, 0x55, 0x63, 0x57, 0x64, 0x58, 0x64, 0x56, 0x62, 0x55, 0x61, 0x56, 0x62, 0x55, 0x62, 0x57, 0x63, 0x56, 0x62, 0x55, 0x62, 0x54, 0x61, 0x54, 0x61, 0x55, 0x61, 0x55, 0x62, 0x55, 0x63, 0x56, 0x62, 0x55, 0x61, 0x54, 0x5F, 0x53, 0x61, 0x55, 0x60, 0x54, 0x5F, 0x52, 0x5F, 0x52, 0x5F, 0x52, 0x60, 0x53, 0x5C, 0x51, 0x60, 0x54, 0x5F, 0x54, 0x5E, 0x52, 0x60, 0x54, 0x5D, 0x52, 0x5B, 0x51, 0x5E, 0x52, 0x5E, 0x53, 0x5E, 0x52, 0x62, 0x55, 0x61, 0x55, 0x64, 0x57, 0x62, 0x55, 0x62, 0x58, 0x60, 0x55, 0x5E, 0x51, 0x5D, 0x51, 0x5A, 0x4F, 0x5A, 0x50, 0x5D, 0x50, 0x5B, 0x50, 0x5D, 0x51, 0x5D, 0x50, 0x5A, 0x4F, 0x5B, 0x4F, 0x5B, 0x4F, 0x5A, 0x50, 0x5A, 0x4F, 0x5C, 0x51, 0x5B, 0x50, 0x5A, 0x4E, 0x5A, 0x4F, 0x5E, 0x52, 0x5C, 0x52, 0x5D, 0x52, 0x5D, 0x52, 0x5C, 0x51, 0x5D, 0x52, 0x5C, 0x51, 0x5B, 0x51, 0x5C, 0x52, 0x5C, 0x51, 0x5C, 0x50, 0x5B, 0x50, 0x5A, 0x4E, 0x5A, 0x4F, 0x5A, 0x50, 0x5A, 0x4F, 0x5C, 0x52, 0x5B, 0x50, 0x5A, 0x50, 0x5C, 0x51, 0x5B, 0x4E, 0x5A, 0x4F, 0x5B, 0x51, 0x5D, 0x51, 0x5C, 0x4F, 0x5D, 0x51, 0x5C, 0x51, 0x59, 0x4E, 0x5A, 0x4D, 0x58, 0x4F, 0x55, 0x4C, 0x4E, 0x45, 0x34, 0x2F, 0x2D, 0x2C, 0x26, 0x27, 0x25, 0x27, 0x24, 0x26, 0x21, 0x23, 0x29, 0x2C, 0x24, 0x26, 0x24, 0x26, 0x1E, 0x1E, 0x23, 0x27, 0x23, 0x25, 0x24, 0x26, 0x21, 0x22, 0x1C, 0x1D, 0x25, 0x29, 0x22, 0x23, 0x23, 0x24, 0x22, 0x22, 0x20, 0x23, 0x25, 0x26, 0x23, 0x26, 0x22, 0x23, 0x1E, 0x20, 0x24, 0x27, 0x20, 0x21, 0x22, 0x24, 0x1E, 0x1F, 0x21, 0x24, 0x26, 0x26, 0x20, 0x21, 0x1F, 0x20, 0x20, 0x24, 0x21, 0x20, 0x1C, 0x1E, 0x22, 0x23, 0x1C, 0x1D, 0x1E, 0x20, 0x1C, 0x1C, 0x1F, 0x21, 0x1B, 0x1C, 0x20, 0x23, 0x22, 0x23
    },

    {
        0x4C, 0x1B, 0x4D, 0x1A, 0x4C, 0x1B, 0x4C, 0x1A, 0x4C, 0x1A, 0x4C, 0x1B, 0x4D, 0x1B, 0x4D, 0x1B, 0x4D, 0x1B, 0x4E, 0x1B, 0x4F, 0x1C, 0x4F, 0x1B, 0x4F, 0x1C, 0x50, 0x1C, 0x4F, 0x1C, 0x4F, 0x1C, 0x50, 0x1C, 0x50, 0x1D, 0x50, 0x1D, 0x51, 0x1D, 0x52, 0x1D, 0x53, 0x1D, 0x51, 0x1D, 0x51, 0x1D, 0x51, 0x1D, 0x51, 0x1D, 0x50, 0x1D, 0x51, 0x1D, 0x51, 0x1D, 0x51, 0x1D, 0x52, 0x1D, 0x52, 0x1D, 0x51, 0x1D, 0x52, 0x1D, 0x51, 0x1E, 0x52, 0x1E, 0x52, 0x1E, 0x53, 0x1E, 0x53, 0x1E, 0x54, 0x1F, 0x53, 0x1F, 0x51, 0x1E, 0x4C, 0x1D, 0x45, 0x1C, 0x3C, 0x1A, 0x3C, 0x1A, 0x44, 0x1C, 0x48, 0x1C, 0x44, 0x1A, 0x38, 0x19, 0x2B, 0x15, 0x20, 0x12, 0x1C, 0x11, 0x19, 0x10, 0x18, 0x11, 0x19, 0x14, 0x1D, 0x1C, 0x25, 0x27, 0x31, 0x35, 0x3C, 0x3F, 0x41, 0x44, 0x44, 0x48, 0x49, 0x4A, 0x49, 0x4D, 0x4A, 0x4D, 0x4C, 0x4E, 0x4C, 0x4F, 0x4D, 0x4F, 0x4D, 0x50, 0x4E, 0x51, 0x4E, 0x50, 0x4E, 0x50, 0x4D, 0x51, 0x4E, 0x50, 0x4F, 0x51, 0x50, 0x51, 0x4F, 0x52, 0x50, 0x52, 0x51, 0x51, 0x51, 0x51, 0x4F, 0x51, 0x4E, 0x50, 0x4E, 0x51, 0x4E, 0x50, 0x4D, 0x4F, 0x4D, 0x4E, 0x48, 0x48, 0x3C, 0x36, 0x29, 0x23, 0x1F, 0x19, 0x1C, 0x15, 0x1A, 0x13, 0x18, 0x11, 0x19, 0x11, 0x1B, 0x11, 0x1F, 0x13, 0x32, 0x19, 0x47, 0x1E, 0x50, 0x1F, 0x52, 0x20, 0x46, 0x1C, 0x38, 0x1A, 0x42, 0x1D, 0x53, 0x20, 0x59, 0x22, 0x5B, 0x21, 0x5D, 0x22, 0x61, 0x22, 0x60, 0x23, 0x60, 0x23, 0x62, 0x24, 0x62, 0x23, 0x61, 0x23, 0x61, 0x23, 0x62, 0x24, 0x61, 0x22, 0x60, 0x22, 0x60, 0x22, 0x61, 0x23, 0x62, 0x23, 0x63, 0x23, 0x61, 0x22, 0x62, 0x23, 0x61, 0x22, 0x61, 0x22, 0x62, 0x23, 0x61, 0x22, 0x60, 0x22, 0x60, 0x22, 0x5F, 0x20, 0x5E, 0x21, 0x60, 0x21, 0x5F, 0x21, 0x61, 0x22, 0x60, 0x21, 0x5F, 0x22, 0x61, 0x21, 0x61, 0x22, 0x62, 0x22, 0x5F, 0x21, 0x5E, 0x20, 0x5E, 0x20, 0x5E, 0x20, 0x5E, 0x20, 0x5E, 0x20, 0x5F, 0x20, 0x5E, 0x21, 0x5F, 0x20, 0x5D, 0x20, 0x5B, 0x1F, 0x5D, 0x21, 0x5E, 0x21, 0x5C, 0x20, 0x5B, 0x20, 0x5D, 0x21, 0x5C, 0x20, 0x5D, 0x20, 0x5E, 0x21, 0x5D, 0x21, 0x5B, 0x20, 0x5E, 0x21, 0x5D, 0x22, 0x5E, 0x23, 0x5C, 0x21, 0x5C, 0x21, 0x5C, 0x20, 0x5E, 0x21, 0x60, 0x22, 0x60, 0x21, 0x5C, 0x20, 0x5C, 0x21, 0x5E, 0x21, 0x5D, 0x21, 0x5C, 0x21, 0x5C, 0x20, 0x5B, 0x20, 0x5A, 0x1F, 0x5A, 0x1F, 0x5B, 0x1F, 0x5C, 0x20, 0x5C, 0x20, 0x5C, 0x20, 0x5C, 0x20, 0x5A, 0x20, 0x5B, 0x20, 0x59, 0x1F, 0x5A, 0x20, 0x5B, 0x20, 0x5C, 0x21, 0x5D, 0x20, 0x5C, 0x20, 0x5C, 0x21, 0x5B, 0x20, 0x5C, 0x20, 0x5B, 0x21, 0x5B, 0x20, 0x5C, 0x20, 0x5A, 0x20, 0x5B, 0x20, 0x5B, 0x20, 0x5B, 0x20, 0x5B, 0x20, 0x5C, 0x21, 0x5B, 0x21, 0x5B, 0x20, 0x57, 0x20, 0x58, 0x1F, 0x58, 0x20, 0x57, 0x20, 0x5B, 0x20, 0x58, 0x20, 0x57, 0x1F, 0x57, 0x1F, 0x5A, 0x20, 0x58, 0x1F, 0x58, 0x1F, 0x57, 0x20, 0x58, 0x20, 0x58, 0x20, 0x58, 0x20, 0x59, 0x20, 0x58, 0x20, 0x5B, 0x20, 0x5A, 0x20, 0x5C, 0x21, 0x5A, 0x20, 0x5E, 0x24, 0x5D, 0x22, 0x55, 0x1F, 0x55, 0x1F, 0x55, 0x1F, 0x55, 0x1E, 0x54, 0x1E, 0x52, 0x1D, 0x55, 0x1E, 0x53, 0x1F, 0x54, 0x1E, 0x54, 0x1E, 0x51, 0x1E, 0x54, 0x1F, 0x52, 0x1E, 0x53, 0x1E, 0x53, 0x1F, 0x55, 0x20, 0x56, 0x1F, 0x54, 0x1F, 0x56, 0x1F, 0x55, 0x1F, 0x56, 0x1F, 0x55, 0x1E, 0x56, 0x1F, 0x56, 0x20, 0x57, 0x1F, 0x57, 0x1F, 0x55, 0x1E, 0x54, 0x1D, 0x52, 0x1D, 0x52, 0x1D, 0x53, 0x1E, 0x54, 0x1E, 0x54, 0x1F, 0x58, 0x21, 0x57, 0x1F, 0x53, 0x1F, 0x55, 0x1E, 0x53, 0x1E, 0x51, 0x1D, 0x53, 0x1E, 0x53, 0x1E, 0x53, 0x1E, 0x54, 0x1E, 0x55, 0x1E, 0x52, 0x1E, 0x51, 0x1D, 0x52, 0x1E, 0x4F, 0x1D, 0x4C, 0x1C, 0x36, 0x19, 0x31, 0x19, 0x24, 0x16, 0x29, 0x17, 0x23, 0x15, 0x25, 0x16, 0x29, 0x16, 0x22, 0x14, 0x23, 0x13, 0x1E, 0x14, 0x27, 0x16, 0x21, 0x14, 0x22, 0x14, 0x20, 0x13, 0x1F, 0x14, 0x28, 0x16, 0x1E, 0x13, 0x22, 0x14, 0x1F, 0x13, 0x25, 0x16, 0x22, 0x14, 0x23, 0x16, 0x22, 0x14, 0x23, 0x16, 0x29, 0x18, 0x20, 0x14, 0x25, 0x15, 0x1F, 0x13, 0x26, 0x15, 0x20, 0x13, 0x21, 0x14, 0x1C, 0x12, 0x21, 0x14, 0x1F, 0x13, 0x21, 0x14, 0x24, 0x14, 0x1E, 0x14, 0x26, 0x15, 0x23, 0x14, 0x24, 0x15, 0x24, 0x15, 0x29, 0x17, 0x21, 0x14
    },

    {
        0x53, 0x49, 0x54, 0x48, 0x54, 0x48, 0x54, 0x4A, 0x54, 0x4A, 0x54, 0x4A, 0x55, 0x4A, 0x55, 0x49, 0x54, 0x49, 0x56, 0x4B, 0x57, 0x4C, 0x57, 0x4B, 0x57, 0x4C, 0x58, 0x4C, 0x58, 0x4B, 0x59, 0x4C, 0x5A, 0x4C, 0x5B, 0x4D, 0x5A, 0x4D, 0x59, 0x4E, 0x5B, 0x4F, 0x5A, 0x50, 0x5A, 0x4F, 0x59, 0x4E, 0x59, 0x4D, 0x59, 0x4E, 0x59, 0x4D, 0x58, 0x4D, 0x58, 0x4D, 0x59, 0x4E, 0x5A, 0x4F, 0x59, 0x4E, 0x59, 0x4D, 0x59, 0x4D, 0x5A, 0x4E, 0x59, 0x4E, 0x59, 0x4F, 0x5B, 0x50, 0x5C, 0x50, 0x5C, 0x51, 0x5B, 0x50, 0x57, 0x4C, 0x50, 0x46, 0x48, 0x3F, 0x3E, 0x38, 0x3D, 0x3C, 0x46, 0x43, 0x4A, 0x43, 0x44, 0x3D, 0x37, 0x31, 0x27, 0x24, 0x1C, 0x1D, 0x18, 0x19, 0x17, 0x18, 0x15, 0x18, 0x16, 0x19, 0x1A, 0x1F, 0x21, 0x28, 0x2B, 0x33, 0x33, 0x3C, 0x37, 0x40, 0x39, 0x43, 0x3D, 0x45, 0x3D, 0x46, 0x3E, 0x48, 0x3F, 0x48, 0x40, 0x49, 0x3F, 0x49, 0x3F, 0x4A, 0x41, 0x4B, 0x41, 0x4A, 0x40, 0x49, 0x41, 0x4A, 0x41, 0x4A, 0x42, 0x4B, 0x41, 0x4B, 0x42, 0x4B, 0x43, 0x4C, 0x43, 0x4D, 0x42, 0x4B, 0x42, 0x4C, 0x42, 0x4B, 0x41, 0x4B, 0x41, 0x4B, 0x41, 0x4B, 0x40, 0x4A, 0x3E, 0x46, 0x35, 0x39, 0x25, 0x27, 0x1D, 0x1E, 0x18, 0x1A, 0x16, 0x18, 0x15, 0x17, 0x15, 0x17, 0x16, 0x18, 0x19, 0x1C, 0x29, 0x2C, 0x41, 0x41, 0x4E, 0x4A, 0x53, 0x4D, 0x4B, 0x44, 0x3B, 0x35, 0x3F, 0x3D, 0x52, 0x4D, 0x5A, 0x54, 0x5F, 0x55, 0x62, 0x58, 0x65, 0x5B, 0x68, 0x5B, 0x68, 0x5C, 0x69, 0x5D, 0x6A, 0x5D, 0x68, 0x5C, 0x67, 0x5D, 0x68, 0x5C, 0x68, 0x5C, 0x69, 0x5C, 0x68, 0x5A, 0x69, 0x5B, 0x6B, 0x5C, 0x6B, 0x5E, 0x68, 0x5B, 0x68, 0x5C, 0x69, 0x5C, 0x69, 0x5D, 0x6A, 0x5D, 0x6A, 0x5C, 0x69, 0x5B, 0x68, 0x5B, 0x68, 0x5A, 0x67, 0x59, 0x6A, 0x5B, 0x67, 0x59, 0x68, 0x5B, 0x68, 0x5A, 0x68, 0x5A, 0x6B, 0x5C, 0x69, 0x5B, 0x6A, 0x5C, 0x68, 0x5B, 0x67, 0x58, 0x67, 0x5A, 0x67, 0x59, 0x67, 0x59, 0x66, 0x57, 0x67, 0x5A, 0x67, 0x59, 0x66, 0x58, 0x66, 0x58, 0x64, 0x56, 0x65, 0x58, 0x67, 0x58, 0x64, 0x57, 0x63, 0x56, 0x65, 0x58, 0x65, 0x57, 0x66, 0x57, 0x66, 0x58, 0x66, 0x58, 0x64, 0x56, 0x64, 0x59, 0x65, 0x57, 0x65, 0x59, 0x63, 0x57, 0x63, 0x57, 0x64, 0x58, 0x65, 0x59, 0x68, 0x5A, 0x68, 0x57, 0x64, 0x56, 0x65, 0x59, 0x66, 0x59, 0x65, 0x57, 0x64, 0x57, 0x64, 0x56, 0x63, 0x55, 0x62, 0x55, 0x63, 0x55, 0x63, 0x55, 0x63, 0x56, 0x64, 0x55, 0x65, 0x56, 0x63, 0x56, 0x64, 0x56, 0x64, 0x56, 0x63, 0x56, 0x62, 0x57, 0x62, 0x56, 0x64, 0x57, 0x64, 0x58, 0x62, 0x57, 0x63, 0x56, 0x63, 0x56, 0x64, 0x58, 0x62, 0x56, 0x64, 0x56, 0x65, 0x57, 0x62, 0x56, 0x63, 0x56, 0x61, 0x55, 0x62, 0x56, 0x63, 0x56, 0x63, 0x55, 0x62, 0x57, 0x63, 0x58, 0x60, 0x54, 0x5F, 0x53, 0x60, 0x53, 0x60, 0x54, 0x63, 0x56, 0x61, 0x54, 0x5F, 0x52, 0x5F, 0x52, 0x62, 0x55, 0x62, 0x54, 0x60, 0x53, 0x5E, 0x51, 0x60, 0x54, 0x60, 0x53, 0x5F, 0x53, 0x60, 0x53, 0x5F, 0x53, 0x62, 0x57, 0x62, 0x56, 0x64, 0x57, 0x63, 0x56, 0x63, 0x59, 0x62, 0x55, 0x5B, 0x51, 0x5E, 0x50, 0x5A, 0x50, 0x5B, 0x4E, 0x5B, 0x50, 0x5C, 0x4F, 0x5B, 0x50, 0x5C, 0x4F, 0x59, 0x4F, 0x5A, 0x4F, 0x58, 0x4E, 0x5A, 0x4F, 0x59, 0x4D, 0x59, 0x4E, 0x5A, 0x4F, 0x5A, 0x52, 0x5C, 0x51, 0x5A, 0x50, 0x5C, 0x51, 0x5D, 0x53, 0x5E, 0x51, 0x5C, 0x51, 0x5C, 0x52, 0x5C, 0x51, 0x5C, 0x54, 0x5C, 0x52, 0x5D, 0x51, 0x5B, 0x4D, 0x58, 0x4D, 0x5A, 0x4E, 0x5B, 0x50, 0x5B, 0x4E, 0x5B, 0x51, 0x5F, 0x54, 0x5F, 0x51, 0x5C, 0x51, 0x5C, 0x50, 0x5B, 0x4E, 0x5A, 0x4D, 0x5B, 0x4F, 0x5C, 0x4E, 0x5B, 0x4F, 0x5C, 0x50, 0x5B, 0x4E, 0x5A, 0x4E, 0x5A, 0x4E, 0x59, 0x4F, 0x56, 0x4C, 0x51, 0x46, 0x36, 0x34, 0x2C, 0x29, 0x22, 0x24, 0x24, 0x25, 0x1F, 0x20, 0x22, 0x26, 0x22, 0x23, 0x1F, 0x20, 0x1F, 0x20, 0x1E, 0x21, 0x22, 0x24, 0x1E, 0x1F, 0x1E, 0x1F, 0x1E, 0x1D, 0x1E, 0x21, 0x23, 0x23, 0x1C, 0x1D, 0x20, 0x21, 0x1D, 0x1E, 0x22, 0x24, 0x1E, 0x1E, 0x20, 0x23, 0x1F, 0x1F, 0x1F, 0x23, 0x24, 0x27, 0x1D, 0x1F, 0x21, 0x22, 0x1D, 0x1D, 0x21, 0x23, 0x1D, 0x1E, 0x1E, 0x1F, 0x1B, 0x1D, 0x1F, 0x21, 0x1E, 0x1F, 0x1E, 0x21, 0x20, 0x21, 0x1F, 0x22, 0x22, 0x24, 0x20, 0x21, 0x20, 0x23, 0x24, 0x25, 0x25, 0x28, 0x21, 0x21
    },

    {
        0x4C, 0x1B, 0x4B, 0x1B, 0x4C, 0x1B, 0x4D, 0x1B, 0x4D, 0x1B, 0x4E, 0x1B, 0x4D, 0x1B, 0x4D, 0x1B, 0x4D, 0x1B, 0x4D, 0x1B, 0x50, 0x1C, 0x50, 0x1C, 0x50, 0x1C, 0x50, 0x1C, 0x50, 0x1C, 0x50, 0x1C, 0x51, 0x1C, 0x51, 0x1D, 0x52, 0x1D, 0x51, 0x1D, 0x53, 0x1E, 0x54, 0x1D, 0x53, 0x1D, 0x51, 0x1D, 0x50, 0x1D, 0x50, 0x1C, 0x51, 0x1D, 0x51, 0x1D, 0x50, 0x1D, 0x50, 0x1D, 0x51, 0x1D, 0x52, 0x1E, 0x51, 0x1E, 0x52, 0x1E, 0x52, 0x1E, 0x52, 0x1E, 0x53, 0x1F, 0x53, 0x1F, 0x54, 0x1E, 0x53, 0x1F, 0x52, 0x1E, 0x4D, 0x1D, 0x46, 0x1C, 0x3E, 0x1A, 0x39, 0x19, 0x41, 0x1B, 0x47, 0x1D, 0x45, 0x1B, 0x3A, 0x18, 0x2C, 0x15, 0x21, 0x12, 0x1C, 0x11, 0x1A, 0x10, 0x18, 0x10, 0x19, 0x14, 0x1D, 0x1B, 0x25, 0x26, 0x31, 0x33, 0x3C, 0x3F, 0x41, 0x43, 0x45, 0x47, 0x47, 0x49, 0x49, 0x4B, 0x4A, 0x4D, 0x4C, 0x4E, 0x4C, 0x4F, 0x4C, 0x4F, 0x4D, 0x50, 0x4C, 0x4F, 0x4D, 0x50, 0x4E, 0x50, 0x4E, 0x50, 0x4E, 0x51, 0x4F, 0x51, 0x4F, 0x51, 0x4E, 0x52, 0x4F, 0x51, 0x4F, 0x52, 0x50, 0x52, 0x50, 0x52, 0x50, 0x52, 0x4F, 0x51, 0x4F, 0x50, 0x4F, 0x51, 0x4F, 0x51, 0x4F, 0x50, 0x4C, 0x4E, 0x4A, 0x48, 0x3D, 0x37, 0x2A, 0x24, 0x20, 0x1B, 0x1C, 0x15, 0x19, 0x13, 0x18, 0x12, 0x18, 0x10, 0x1A, 0x12, 0x1F, 0x13, 0x30, 0x18, 0x44, 0x1C, 0x4E, 0x1F, 0x52, 0x20, 0x4B, 0x1D, 0x3A, 0x1B, 0x43, 0x1D, 0x51, 0x20, 0x58, 0x21, 0x5C, 0x22, 0x5E, 0x23, 0x5F, 0x22, 0x5F, 0x23, 0x61, 0x23, 0x62, 0x23, 0x61, 0x23, 0x63, 0x23, 0x62, 0x24, 0x62, 0x23, 0x60, 0x22, 0x60, 0x22, 0x60, 0x22, 0x62, 0x22, 0x62, 0x22, 0x61, 0x22, 0x63, 0x22, 0x61, 0x22, 0x61, 0x22, 0x62, 0x23, 0x61, 0x22, 0x61, 0x22, 0x60, 0x21, 0x5F, 0x20, 0x5F, 0x21, 0x61, 0x22, 0x61, 0x22, 0x61, 0x21, 0x5F, 0x22, 0x60, 0x21, 0x60, 0x21, 0x60, 0x21, 0x62, 0x22, 0x60, 0x22, 0x60, 0x21, 0x5E, 0x20, 0x5F, 0x20, 0x5E, 0x20, 0x5C, 0x1F, 0x5E, 0x20, 0x5E, 0x21, 0x5D, 0x20, 0x5E, 0x21, 0x5D, 0x21, 0x5F, 0x21, 0x5E, 0x20, 0x5C, 0x20, 0x5B, 0x1F, 0x5E, 0x21, 0x5E, 0x20, 0x5D, 0x20, 0x5D, 0x20, 0x5F, 0x21, 0x5F, 0x21, 0x5E, 0x22, 0x5F, 0x22, 0x5E, 0x21, 0x5D, 0x20, 0x5C, 0x20, 0x5D, 0x21, 0x5D, 0x21, 0x5E, 0x21, 0x5D, 0x21, 0x5C, 0x21, 0x5E, 0x21, 0x5D, 0x20, 0x5C, 0x20, 0x5D, 0x20, 0x5B, 0x1F, 0x5B, 0x20, 0x59, 0x1F, 0x5A, 0x1F, 0x5A, 0x20, 0x5A, 0x20, 0x59, 0x1F, 0x5C, 0x20, 0x5C, 0x21, 0x5C, 0x20, 0x5C, 0x20, 0x5D, 0x21, 0x5B, 0x21, 0x5C, 0x21, 0x59, 0x20, 0x5B, 0x21, 0x5C, 0x20, 0x5D, 0x21, 0x5C, 0x20, 0x5D, 0x20, 0x5D, 0x21, 0x5C, 0x20, 0x5C, 0x20, 0x5B, 0x21, 0x5D, 0x21, 0x5B, 0x20, 0x5B, 0x20, 0x59, 0x1F, 0x5A, 0x20, 0x5B, 0x21, 0x5D, 0x20, 0x5A, 0x20, 0x58, 0x1F, 0x5A, 0x20, 0x59, 0x20, 0x5A, 0x20, 0x58, 0x1F, 0x58, 0x20, 0x58, 0x1F, 0x59, 0x1F, 0x5B, 0x20, 0x57, 0x1F, 0x57, 0x1F, 0x56, 0x1F, 0x57, 0x20, 0x57, 0x1F, 0x59, 0x20, 0x59, 0x20, 0x59, 0x20, 0x5B, 0x20, 0x5B, 0x20, 0x5A, 0x20, 0x5D, 0x24, 0x59, 0x21, 0x56, 0x1F, 0x54, 0x1E, 0x53, 0x1E, 0x52, 0x1D, 0x52, 0x1D, 0x53, 0x1F, 0x54, 0x1E, 0x56, 0x1F, 0x55, 0x1F, 0x56, 0x1F, 0x52, 0x1E, 0x52, 0x1D, 0x51, 0x1E, 0x53, 0x1E, 0x54, 0x1F, 0x57, 0x20, 0x56, 0x1F, 0x53, 0x1F, 0x55, 0x1E, 0x55, 0x1E, 0x55, 0x1F, 0x55, 0x1F, 0x55, 0x1F, 0x54, 0x1F, 0x55, 0x1E, 0x53, 0x1E, 0x53, 0x1D, 0x52, 0x1D, 0x50, 0x1C, 0x52, 0x1E, 0x54, 0x1E, 0x53, 0x1E, 0x55, 0x1E, 0x55, 0x1F, 0x54, 0x1E, 0x53, 0x1E, 0x54, 0x1E, 0x53, 0x1E, 0x52, 0x1E, 0x50, 0x1D, 0x51, 0x1E, 0x53, 0x1E, 0x51, 0x1D, 0x51, 0x1D, 0x52, 0x1E, 0x51, 0x1D, 0x51, 0x1E, 0x50, 0x1D, 0x4A, 0x1C, 0x39, 0x1A, 0x29, 0x15, 0x27, 0x17, 0x25, 0x15, 0x21, 0x15, 0x2A, 0x18, 0x22, 0x14, 0x22, 0x15, 0x27, 0x16, 0x2B, 0x18, 0x25, 0x16, 0x24, 0x15, 0x27, 0x16, 0x24, 0x15, 0x2A, 0x17, 0x22, 0x14, 0x23, 0x15, 0x24, 0x16, 0x27, 0x17, 0x27, 0x16, 0x23, 0x14, 0x24, 0x16, 0x25, 0x15, 0x29, 0x18, 0x29, 0x18, 0x25, 0x16, 0x26, 0x16, 0x26, 0x16, 0x25, 0x16, 0x23, 0x15, 0x24, 0x15, 0x25, 0x15, 0x28, 0x16, 0x24, 0x14, 0x24, 0x15, 0x27, 0x15, 0x29, 0x17, 0x24, 0x16, 0x25, 0x15, 0x28, 0x18, 0x2A, 0x17, 0x23, 0x14, 0x23, 0x15
    },

    {
        0x53, 0x49, 0x52, 0x48, 0x53, 0x49, 0x54, 0x4A, 0x54, 0x4A, 0x54, 0x4B, 0x54, 0x49, 0x55, 0x4A, 0x54, 0x4A, 0x55, 0x4A, 0x57, 0x4B, 0x58, 0x4C, 0x58, 0x4D, 0x58, 0x4D, 0x58, 0x4D, 0x59, 0x4D, 0x59, 0x4D, 0x5B, 0x4E, 0x5B, 0x4F, 0x5A, 0x50, 0x5C, 0x4F, 0x5C, 0x50, 0x5A, 0x4E, 0x59, 0x4D, 0x59, 0x4D, 0x58, 0x4D, 0x59, 0x4E, 0x59, 0x4E, 0x59, 0x4C, 0x57, 0x4D, 0x59, 0x4E, 0x59, 0x4F, 0x5A, 0x4E, 0x5B, 0x4F, 0x5B, 0x4F, 0x5B, 0x50, 0x5C, 0x50, 0x5D, 0x51, 0x5D, 0x51, 0x5A, 0x50, 0x56, 0x4C, 0x50, 0x46, 0x49, 0x40, 0x3F, 0x39, 0x3C, 0x39, 0x44, 0x41, 0x4B, 0x44, 0x46, 0x3E, 0x39, 0x33, 0x28, 0x25, 0x1D, 0x1D, 0x18, 0x19, 0x16, 0x18, 0x15, 0x17, 0x15, 0x19, 0x19, 0x1E, 0x20, 0x28, 0x29, 0x33, 0x33, 0x3C, 0x36, 0x3F, 0x3A, 0x42, 0x3C, 0x44, 0x3E, 0x46, 0x3E, 0x47, 0x3F, 0x49, 0x3F, 0x49, 0x40, 0x49, 0x40, 0x4A, 0x40, 0x49, 0x40, 0x4A, 0x3F, 0x49, 0x40, 0x4A, 0x41, 0x4B, 0x41, 0x4B, 0x42, 0x4A, 0x42, 0x4B, 0x42, 0x4B, 0x42, 0x4C, 0x42, 0x4C, 0x42, 0x4C, 0x43, 0x4C, 0x42, 0x4C, 0x42, 0x4B, 0x42, 0x4B, 0x41, 0x4C, 0x40, 0x4B, 0x3F, 0x48, 0x3D, 0x45, 0x36, 0x3B, 0x27, 0x29, 0x1D, 0x1F, 0x18, 0x1A, 0x15, 0x18, 0x14, 0x17, 0x14, 0x16, 0x15, 0x18, 0x19, 0x1B, 0x27, 0x2A, 0x3D, 0x3E, 0x4B, 0x49, 0x53, 0x4F, 0x4D, 0x48, 0x3D, 0x38, 0x3F, 0x3D, 0x50, 0x4C, 0x5A, 0x53, 0x60, 0x57, 0x63, 0x5A, 0x64, 0x59, 0x66, 0x5B, 0x68, 0x5C, 0x68, 0x5C, 0x69, 0x5B, 0x6A, 0x5D, 0x69, 0x5D, 0x69, 0x5C, 0x68, 0x5B, 0x68, 0x5C, 0x68, 0x5B, 0x6A, 0x5C, 0x6B, 0x5D, 0x6A, 0x5C, 0x6B, 0x5D, 0x69, 0x5B, 0x68, 0x5B, 0x68, 0x5D, 0x6A, 0x5B, 0x68, 0x5B, 0x68, 0x59, 0x67, 0x59, 0x68, 0x5A, 0x68, 0x5B, 0x6A, 0x5C, 0x69, 0x5C, 0x68, 0x5A, 0x68, 0x5A, 0x68, 0x5B, 0x69, 0x5B, 0x69, 0x5B, 0x68, 0x5B, 0x68, 0x5A, 0x67, 0x58, 0x69, 0x5A, 0x67, 0x58, 0x64, 0x55, 0x67, 0x59, 0x67, 0x59, 0x65, 0x57, 0x66, 0x57, 0x65, 0x57, 0x66, 0x5A, 0x65, 0x57, 0x64, 0x57, 0x64, 0x56, 0x67, 0x59, 0x67, 0x5A, 0x66, 0x58, 0x66, 0x57, 0x66, 0x59, 0x66, 0x59, 0x64, 0x58, 0x66, 0x59, 0x65, 0x58, 0x64, 0x58, 0x64, 0x57, 0x66, 0x58, 0x65, 0x57, 0x67, 0x59, 0x65, 0x58, 0x65, 0x57, 0x66, 0x59, 0x65, 0x57, 0x65, 0x58, 0x64, 0x56, 0x61, 0x54, 0x63, 0x55, 0x62, 0x54, 0x62, 0x55, 0x63, 0x55, 0x61, 0x55, 0x61, 0x54, 0x64, 0x56, 0x66, 0x58, 0x64, 0x56, 0x63, 0x56, 0x65, 0x58, 0x64, 0x57, 0x63, 0x56, 0x61, 0x54, 0x63, 0x56, 0x63, 0x56, 0x62, 0x56, 0x62, 0x56, 0x65, 0x57, 0x65, 0x58, 0x65, 0x57, 0x64, 0x55, 0x64, 0x57, 0x62, 0x56, 0x62, 0x56, 0x63, 0x55, 0x61, 0x54, 0x62, 0x56, 0x61, 0x56, 0x64, 0x57, 0x62, 0x55, 0x60, 0x53, 0x61, 0x55, 0x61, 0x54, 0x62, 0x55, 0x60, 0x54, 0x61, 0x54, 0x60, 0x55, 0x60, 0x54, 0x62, 0x54, 0x5E, 0x52, 0x5D, 0x52, 0x5D, 0x52, 0x5E, 0x51, 0x5F, 0x53, 0x60, 0x54, 0x5F, 0x54, 0x60, 0x55, 0x62, 0x55, 0x62, 0x56, 0x61, 0x55, 0x63, 0x58, 0x5F, 0x53, 0x5D, 0x52, 0x5B, 0x50, 0x5A, 0x4F, 0x59, 0x4D, 0x59, 0x4E, 0x5B, 0x50, 0x5C, 0x50, 0x5D, 0x52, 0x5D, 0x52, 0x5D, 0x52, 0x59, 0x4E, 0x59, 0x4E, 0x58, 0x4E, 0x59, 0x4E, 0x59, 0x50, 0x5C, 0x53, 0x5C, 0x51, 0x5A, 0x4F, 0x5C, 0x50, 0x5D, 0x51, 0x5D, 0x51, 0x5C, 0x51, 0x5D, 0x50, 0x5B, 0x51, 0x5B, 0x50, 0x5A, 0x4F, 0x5A, 0x4F, 0x5A, 0x4E, 0x57, 0x4D, 0x5B, 0x4F, 0x5C, 0x51, 0x5B, 0x4F, 0x5D, 0x51, 0x5B, 0x50, 0x5B, 0x4F, 0x59, 0x4F, 0x5A, 0x4F, 0x5B, 0x4D, 0x59, 0x4D, 0x59, 0x4E, 0x5A, 0x4E, 0x5B, 0x4F, 0x59, 0x4E, 0x58, 0x4E, 0x59, 0x4D, 0x59, 0x4E, 0x59, 0x4F, 0x56, 0x4B, 0x4E, 0x43, 0x37, 0x33, 0x27, 0x25, 0x25, 0x26, 0x21, 0x22, 0x20, 0x23, 0x26, 0x29, 0x1F, 0x20, 0x20, 0x23, 0x23, 0x26, 0x27, 0x2A, 0x23, 0x24, 0x22, 0x24, 0x24, 0x27, 0x21, 0x24, 0x26, 0x27, 0x20, 0x21, 0x21, 0x22, 0x21, 0x23, 0x23, 0x28, 0x24, 0x24, 0x21, 0x24, 0x21, 0x24, 0x22, 0x23, 0x24, 0x29, 0x26, 0x29, 0x20, 0x23, 0x23, 0x26, 0x22, 0x26, 0x22, 0x24, 0x20, 0x22, 0x21, 0x25, 0x20, 0x25, 0x24, 0x26, 0x21, 0x21, 0x22, 0x24, 0x23, 0x25, 0x23, 0x25, 0x20, 0x24, 0x20, 0x21, 0x24, 0x2A, 0x23, 0x24, 0x1E, 0x1E, 0x1F, 0x20
    },

    {
        0x4C, 0x1B, 0x4B, 0x1A, 0x4C, 0x1B, 0x4C, 0x1A, 0x4C, 0x1B, 0x4D, 0x1B, 0x4E, 0x1B, 0x4D, 0x1B, 0x4E, 0x1B, 0x4E, 0x1C, 0x4F, 0x1C, 0x4E, 0x1C, 0x50, 0x1C, 0x51, 0x1D, 0x50, 0x1C, 0x50, 0x1C, 0x50, 0x1C, 0x51, 0x1D, 0x52, 0x1D, 0x53, 0x1D, 0x53, 0x1D, 0x52, 0x1D, 0x52, 0x1D, 0x51, 0x1D, 0x52, 0x1D, 0x52, 0x1E, 0x51, 0x1D, 0x51, 0x1D, 0x50, 0x1D, 0x51, 0x1D, 0x52, 0x1D, 0x52, 0x1E, 0x52, 0x1E, 0x54, 0x1E, 0x54, 0x1E, 0x53, 0x1E, 0x53, 0x1F, 0x56, 0x1F, 0x54, 0x1F, 0x51, 0x1E, 0x4E, 0x1D, 0x46, 0x1B, 0x3E, 0x1A, 0x3A, 0x1A, 0x41, 0x1B, 0x47, 0x1C, 0x45, 0x1B, 0x3A, 0x18, 0x2C, 0x15, 0x21, 0x12, 0x1C, 0x11, 0x19, 0x10, 0x18, 0x10, 0x19, 0x13, 0x1C, 0x1A, 0x23, 0x25, 0x2F, 0x32, 0x3A, 0x3E, 0x41, 0x44, 0x43, 0x46, 0x47, 0x4A, 0x48, 0x4B, 0x49, 0x4C, 0x4A, 0x4E, 0x4C, 0x4F, 0x4D, 0x4E, 0x4D, 0x50, 0x4D, 0x4F, 0x4D, 0x4F, 0x4D, 0x4F, 0x4D, 0x50, 0x4E, 0x51, 0x4E, 0x51, 0x4E, 0x51, 0x4F, 0x51, 0x4F, 0x51, 0x4F, 0x52, 0x50, 0x52, 0x51, 0x52, 0x51, 0x52, 0x4F, 0x52, 0x4F, 0x50, 0x4F, 0x51, 0x4F, 0x52, 0x51, 0x52, 0x50, 0x51, 0x4D, 0x50, 0x4B, 0x4D, 0x4A, 0x4C, 0x3F, 0x39, 0x2B, 0x26, 0x1F, 0x1A, 0x1B, 0x15, 0x19, 0x13, 0x18, 0x11, 0x18, 0x11, 0x1A, 0x11, 0x1E, 0x13, 0x2E, 0x18, 0x42, 0x1C, 0x50, 0x20, 0x54, 0x20, 0x4D, 0x1E, 0x3B, 0x1A, 0x3F, 0x1D, 0x51, 0x20, 0x58, 0x22, 0x5D, 0x22, 0x5D, 0x22, 0x60, 0x23, 0x61, 0x23, 0x62, 0x23, 0x61, 0x23, 0x62, 0x23, 0x62, 0x23, 0x61, 0x22, 0x62, 0x22, 0x62, 0x22, 0x61, 0x22, 0x60, 0x22, 0x61, 0x22, 0x60, 0x22, 0x62, 0x23, 0x62, 0x22, 0x60, 0x22, 0x60, 0x23, 0x61, 0x23, 0x61, 0x22, 0x60, 0x21, 0x5E, 0x20, 0x5F, 0x21, 0x5E, 0x21, 0x61, 0x22, 0x62, 0x22, 0x61, 0x22, 0x61, 0x22, 0x60, 0x21, 0x5F, 0x20, 0x5F, 0x22, 0x5F, 0x21, 0x5F, 0x20, 0x5D, 0x20, 0x5E, 0x20, 0x5D, 0x20, 0x5D, 0x20, 0x5D, 0x20, 0x5D, 0x21, 0x5D, 0x20, 0x5C, 0x20, 0x5D, 0x20, 0x5D, 0x21, 0x5D, 0x20, 0x5C, 0x20, 0x5D, 0x20, 0x5F, 0x21, 0x60, 0x21, 0x5D, 0x20, 0x5D, 0x20, 0x5E, 0x21, 0x60, 0x22, 0x5F, 0x22, 0x60, 0x22, 0x5F, 0x22, 0x5D, 0x21, 0x5C, 0x21, 0x5E, 0x20, 0x5C, 0x20, 0x5E, 0x20, 0x5C, 0x20, 0x5D, 0x21, 0x5D, 0x21, 0x5D, 0x21, 0x5D, 0x21, 0x5E, 0x20, 0x59, 0x1F, 0x59, 0x1F, 0x5A, 0x1F, 0x5A, 0x1F, 0x5A, 0x1F, 0x5A, 0x1F, 0x59, 0x1F, 0x5A, 0x1F, 0x5B, 0x20, 0x5C, 0x20, 0x5A, 0x20, 0x5C, 0x21, 0x5B, 0x21, 0x5C, 0x20, 0x58, 0x1F, 0x5C, 0x21, 0x5C, 0x20, 0x5D, 0x20, 0x5A, 0x20, 0x5B, 0x20, 0x5B, 0x20, 0x5D, 0x21, 0x5C, 0x20, 0x5A, 0x20, 0x59, 0x1F, 0x58, 0x1F, 0x59, 0x1F, 0x59, 0x1F, 0x5B, 0x21, 0x58, 0x1F, 0x59, 0x1F, 0x5A, 0x20, 0x59, 0x1E, 0x5A, 0x1F, 0x59, 0x1F, 0x58, 0x1F, 0x5A, 0x20, 0x59, 0x20, 0x5B, 0x21, 0x59, 0x20, 0x58, 0x20, 0x57, 0x1F, 0x57, 0x1F, 0x55, 0x1E, 0x58, 0x1F, 0x57, 0x1F, 0x58, 0x20, 0x57, 0x1F, 0x57, 0x20, 0x58, 0x20, 0x59, 0x20, 0x56, 0x20, 0x5C, 0x23, 0x59, 0x1F, 0x55, 0x1F, 0x56, 0x1E, 0x51, 0x1D, 0x52, 0x1D, 0x54, 0x1E, 0x53, 0x1E, 0x53, 0x1E, 0x54, 0x1E, 0x55, 0x1E, 0x54, 0x1F, 0x52, 0x1E, 0x53, 0x1E, 0x52, 0x1E, 0x53, 0x1E, 0x55, 0x1F, 0x56, 0x20, 0x55, 0x1F, 0x56, 0x1F, 0x55, 0x1E, 0x54, 0x1E, 0x54, 0x1E, 0x53, 0x1E, 0x53, 0x1F, 0x54, 0x1E, 0x55, 0x1E, 0x55, 0x1F, 0x53, 0x1D, 0x51, 0x1D, 0x51, 0x1D, 0x51, 0x1D, 0x52, 0x1E, 0x54, 0x1E, 0x54, 0x1E, 0x53, 0x1D, 0x53, 0x1E, 0x53, 0x1E, 0x51, 0x1D, 0x51, 0x1E, 0x51, 0x1E, 0x50, 0x1D, 0x53, 0x1E, 0x53, 0x1E, 0x54, 0x1F, 0x53, 0x1E, 0x52, 0x1E, 0x50, 0x1D, 0x52, 0x1E, 0x4F, 0x1D, 0x4A, 0x1B, 0x30, 0x17, 0x2A, 0x17, 0x26, 0x16, 0x29, 0x18, 0x2E, 0x1A, 0x29, 0x17, 0x24, 0x16, 0x26, 0x16, 0x2C, 0x18, 0x25, 0x15, 0x26, 0x16, 0x23, 0x15, 0x2C, 0x18, 0x26, 0x16, 0x24, 0x15, 0x26, 0x17, 0x25, 0x16, 0x28, 0x18, 0x29, 0x17, 0x24, 0x15, 0x2A, 0x17, 0x25, 0x17, 0x2D, 0x18, 0x29, 0x18, 0x2E, 0x19, 0x23, 0x15, 0x2C, 0x18, 0x24, 0x15, 0x26, 0x16, 0x23, 0x14, 0x26, 0x16, 0x24, 0x14, 0x23, 0x14, 0x20, 0x14, 0x23, 0x14, 0x23, 0x15, 0x21, 0x14, 0x25, 0x15, 0x20, 0x13, 0x27, 0x16, 0x20, 0x14, 0x1E, 0x13, 0x21, 0x15
    },

    {
        0x53, 0x49, 0x53, 0x49, 0x52, 0x49, 0x53, 0x49, 0x54, 0x49, 0x55, 0x4A, 0x54, 0x4B, 0x55, 0x4A, 0x55, 0x4B, 0x55, 0x4B, 0x57, 0x4B, 0x57, 0x4C, 0x58, 0x4D, 0x59, 0x4D, 0x5A, 0x4D, 0x5B, 0x4E, 0x5A, 0x4D, 0x5B, 0x4D, 0x5B, 0x4F, 0x5B, 0x4F, 0x5B, 0x4E, 0x5B, 0x4F, 0x5A, 0x4E, 0x5A, 0x4E, 0x5B, 0x4F, 0x5A, 0x50, 0x5A, 0x4E, 0x59, 0x4E, 0x58, 0x4C, 0x59, 0x4E, 0x59, 0x4F, 0x5B, 0x4F, 0x5B, 0x4E, 0x5B, 0x50, 0x5D, 0x51, 0x5C, 0x50, 0x5C, 0x50, 0x5D, 0x52, 0x5C, 0x50, 0x56, 0x4C, 0x53, 0x48, 0x4B, 0x40, 0x40, 0x3A, 0x3C, 0x3A, 0x44, 0x41, 0x4A, 0x45, 0x46, 0x3F, 0x39, 0x33, 0x28, 0x25, 0x1D, 0x1D, 0x19, 0x1A, 0x16, 0x18, 0x15, 0x18, 0x15, 0x18, 0x18, 0x1D, 0x1E, 0x26, 0x28, 0x32, 0x32, 0x3B, 0x37, 0x40, 0x39, 0x42, 0x3C, 0x44, 0x3D, 0x45, 0x3E, 0x47, 0x3E, 0x47, 0x3F, 0x47, 0x3F, 0x4A, 0x40, 0x4A, 0x3F, 0x4A, 0x40, 0x49, 0x41, 0x49, 0x40, 0x4A, 0x40, 0x4A, 0x41, 0x4A, 0x41, 0x4A, 0x41, 0x4B, 0x42, 0x4C, 0x42, 0x4C, 0x43, 0x4C, 0x42, 0x4D, 0x43, 0x4D, 0x42, 0x4B, 0x41, 0x4A, 0x41, 0x4A, 0x42, 0x4B, 0x43, 0x4C, 0x41, 0x4C, 0x41, 0x4A, 0x3F, 0x48, 0x3E, 0x47, 0x38, 0x3C, 0x28, 0x2A, 0x1D, 0x1F, 0x18, 0x1A, 0x15, 0x18, 0x14, 0x17, 0x15, 0x17, 0x15, 0x18, 0x18, 0x1B, 0x25, 0x29, 0x3B, 0x3D, 0x4C, 0x4A, 0x55, 0x50, 0x50, 0x4A, 0x3E, 0x38, 0x3C, 0x3A, 0x50, 0x4A, 0x59, 0x53, 0x62, 0x57, 0x63, 0x58, 0x66, 0x5A, 0x67, 0x5C, 0x68, 0x5D, 0x69, 0x5B, 0x69, 0x5C, 0x69, 0x5C, 0x6A, 0x5D, 0x69, 0x5C, 0x69, 0x5C, 0x69, 0x5B, 0x67, 0x5A, 0x69, 0x5B, 0x69, 0x5B, 0x6A, 0x5C, 0x6A, 0x5D, 0x68, 0x5A, 0x68, 0x5B, 0x6A, 0x5D, 0x69, 0x5C, 0x6A, 0x5B, 0x67, 0x59, 0x68, 0x59, 0x66, 0x5A, 0x69, 0x5B, 0x6A, 0x5C, 0x6A, 0x5C, 0x69, 0x5B, 0x68, 0x5B, 0x67, 0x5A, 0x68, 0x5B, 0x67, 0x59, 0x69, 0x5B, 0x67, 0x59, 0x68, 0x58, 0x67, 0x58, 0x67, 0x57, 0x65, 0x58, 0x66, 0x58, 0x65, 0x58, 0x63, 0x56, 0x64, 0x56, 0x63, 0x58, 0x65, 0x57, 0x64, 0x56, 0x66, 0x58, 0x67, 0x59, 0x68, 0x5B, 0x66, 0x58, 0x65, 0x57, 0x67, 0x5A, 0x69, 0x5A, 0x67, 0x59, 0x67, 0x5A, 0x65, 0x59, 0x64, 0x57, 0x64, 0x58, 0x66, 0x59, 0x65, 0x57, 0x67, 0x58, 0x65, 0x57, 0x65, 0x57, 0x64, 0x58, 0x66, 0x58, 0x66, 0x58, 0x67, 0x59, 0x63, 0x55, 0x63, 0x56, 0x64, 0x57, 0x62, 0x55, 0x61, 0x53, 0x61, 0x54, 0x60, 0x53, 0x61, 0x53, 0x63, 0x55, 0x64, 0x55, 0x61, 0x55, 0x63, 0x56, 0x64, 0x58, 0x64, 0x57, 0x62, 0x55, 0x64, 0x57, 0x65, 0x58, 0x63, 0x56, 0x62, 0x56, 0x63, 0x57, 0x63, 0x56, 0x65, 0x59, 0x64, 0x56, 0x62, 0x55, 0x61, 0x54, 0x61, 0x55, 0x62, 0x55, 0x63, 0x55, 0x62, 0x55, 0x60, 0x54, 0x62, 0x54, 0x62, 0x55, 0x61, 0x53, 0x62, 0x54, 0x60, 0x54, 0x60, 0x54, 0x62, 0x55, 0x61, 0x53, 0x60, 0x55, 0x60, 0x54, 0x5F, 0x52, 0x5D, 0x51, 0x5E, 0x52, 0x5E, 0x52, 0x60, 0x52, 0x5E, 0x51, 0x5E, 0x53, 0x5E, 0x52, 0x5F, 0x53, 0x5F, 0x53, 0x60, 0x54, 0x5D, 0x52, 0x61, 0x58, 0x5F, 0x52, 0x5D, 0x52, 0x5C, 0x50, 0x58, 0x4E, 0x5A, 0x4E, 0x59, 0x4F, 0x5A, 0x4E, 0x5A, 0x4F, 0x5C, 0x51, 0x5D, 0x51, 0x5D, 0x50, 0x5C, 0x50, 0x5A, 0x50, 0x58, 0x4E, 0x5B, 0x4F, 0x5C, 0x51, 0x5C, 0x52, 0x5C, 0x51, 0x5E, 0x51, 0x5B, 0x50, 0x5B, 0x4F, 0x5C, 0x52, 0x5B, 0x50, 0x5C, 0x4F, 0x5B, 0x4F, 0x5B, 0x50, 0x5C, 0x51, 0x5B, 0x50, 0x5A, 0x4E, 0x59, 0x4F, 0x5B, 0x4F, 0x5A, 0x4F, 0x5B, 0x50, 0x5C, 0x4F, 0x5A, 0x4E, 0x5B, 0x4F, 0x5B, 0x4E, 0x5A, 0x4E, 0x59, 0x4E, 0x5A, 0x4E, 0x58, 0x4D, 0x5A, 0x4E, 0x5B, 0x4F, 0x5B, 0x51, 0x5B, 0x4F, 0x5A, 0x4E, 0x59, 0x4C, 0x58, 0x4D, 0x58, 0x4D, 0x4F, 0x44, 0x32, 0x2C, 0x29, 0x28, 0x24, 0x25, 0x26, 0x29, 0x29, 0x2B, 0x23, 0x24, 0x22, 0x23, 0x23, 0x27, 0x27, 0x29, 0x20, 0x21, 0x23, 0x26, 0x1F, 0x21, 0x27, 0x29, 0x22, 0x22, 0x21, 0x22, 0x23, 0x26, 0x21, 0x21, 0x25, 0x29, 0x24, 0x26, 0x20, 0x22, 0x24, 0x27, 0x22, 0x26, 0x27, 0x28, 0x23, 0x26, 0x28, 0x2B, 0x1F, 0x21, 0x28, 0x29, 0x20, 0x20, 0x22, 0x24, 0x20, 0x21, 0x22, 0x24, 0x1F, 0x20, 0x20, 0x21, 0x1E, 0x1E, 0x1F, 0x22, 0x1F, 0x20, 0x1D, 0x1D, 0x21, 0x24, 0x1B, 0x1E, 0x23, 0x25, 0x1E, 0x1F, 0x1C, 0x1E, 0x1F, 0x23
    },

    {
        0x4D, 0x1B, 0x4C, 0x1B, 0x4C, 0x1B, 0x4C, 0x1A, 0x4C, 0x1B, 0x4D, 0x1B, 0x4E, 0x1C, 0x4E, 0x1C, 0x4D, 0x1B, 0x4D, 0x1B, 0x4E, 0x1D, 0x4F, 0x1C, 0x50, 0x1C, 0x51, 0x1C, 0x51, 0x1C, 0x50, 0x1C, 0x50, 0x1D, 0x51, 0x1D, 0x52, 0x1C, 0x52, 0x1D, 0x51, 0x1D, 0x51, 0x1D, 0x51, 0x1D, 0x52, 0x1D, 0x52, 0x1D, 0x52, 0x1E, 0x53, 0x1E, 0x52, 0x1E, 0x52, 0x1E, 0x52, 0x1E, 0x52, 0x1E, 0x53, 0x1E, 0x54, 0x1E, 0x54, 0x1E, 0x54, 0x1F, 0x53, 0x1E, 0x53, 0x1E, 0x53, 0x1F, 0x52, 0x1E, 0x4E, 0x1D, 0x48, 0x1C, 0x3F, 0x1A, 0x3B, 0x1A, 0x41, 0x1B, 0x48, 0x1D, 0x46, 0x1C, 0x3D, 0x18, 0x2D, 0x15, 0x21, 0x12, 0x1C, 0x11, 0x19, 0x11, 0x18, 0x10, 0x18, 0x13, 0x1B, 0x19, 0x22, 0x23, 0x2D, 0x31, 0x3A, 0x3C, 0x40, 0x43, 0x43, 0x47, 0x46, 0x49, 0x49, 0x4B, 0x49, 0x4D, 0x4A, 0x4D, 0x4B, 0x4E, 0x4B, 0x4E, 0x4E, 0x51, 0x4F, 0x51, 0x4E, 0x51, 0x4E, 0x50, 0x4E, 0x50, 0x4D, 0x51, 0x4D, 0x51, 0x4D, 0x51, 0x4E, 0x50, 0x50, 0x52, 0x4F, 0x51, 0x50, 0x53, 0x50, 0x52, 0x50, 0x52, 0x4F, 0x53, 0x4F, 0x52, 0x4E, 0x50, 0x4D, 0x51, 0x4F, 0x52, 0x51, 0x53, 0x51, 0x52, 0x4F, 0x51, 0x4E, 0x4F, 0x4D, 0x4F, 0x4B, 0x4B, 0x40, 0x3C, 0x2C, 0x26, 0x20, 0x1A, 0x1B, 0x15, 0x19, 0x12, 0x17, 0x11, 0x19, 0x11, 0x1A, 0x11, 0x1D, 0x13, 0x2B, 0x17, 0x43, 0x1C, 0x50, 0x20, 0x55, 0x20, 0x4C, 0x1D, 0x3A, 0x1B, 0x3D, 0x1C, 0x4E, 0x20, 0x59, 0x22, 0x5C, 0x23, 0x5E, 0x22, 0x60, 0x23, 0x62, 0x23, 0x5F, 0x23, 0x61, 0x23, 0x61, 0x23, 0x61, 0x22, 0x61, 0x22, 0x61, 0x22, 0x62, 0x23, 0x60, 0x21, 0x61, 0x22, 0x60, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x60, 0x22, 0x60, 0x23, 0x62, 0x23, 0x62, 0x23, 0x61, 0x22, 0x60, 0x21, 0x60, 0x22, 0x60, 0x22, 0x61, 0x22, 0x61, 0x22, 0x61, 0x22, 0x60, 0x22, 0x5F, 0x21, 0x5E, 0x21, 0x5F, 0x22, 0x60, 0x21, 0x5D, 0x21, 0x5D, 0x21, 0x5D, 0x20, 0x5D, 0x1F, 0x5D, 0x20, 0x5E, 0x20, 0x5D, 0x20, 0x5C, 0x20, 0x5C, 0x20, 0x5B, 0x1F, 0x5C, 0x20, 0x5C, 0x1F, 0x5D, 0x20, 0x5C, 0x1F, 0x5C, 0x20, 0x5C, 0x20, 0x5E, 0x21, 0x5B, 0x21, 0x5C, 0x20, 0x5F, 0x21, 0x5F, 0x21, 0x5E, 0x21, 0x5F, 0x21, 0x5D, 0x21, 0x5D, 0x21, 0x5D, 0x20, 0x5D, 0x21, 0x5F, 0x21, 0x5E, 0x21, 0x5E, 0x21, 0x5B, 0x1F, 0x5D, 0x20, 0x5E, 0x21, 0x5E, 0x21, 0x5C, 0x20, 0x5B, 0x20, 0x5B, 0x20, 0x5A, 0x1F, 0x58, 0x1F, 0x58, 0x1F, 0x59, 0x1F, 0x58, 0x1F, 0x57, 0x1F, 0x5A, 0x20, 0x59, 0x20, 0x5B, 0x20, 0x5A, 0x21, 0x5A, 0x20, 0x5B, 0x20, 0x5A, 0x20, 0x5B, 0x20, 0x59, 0x1F, 0x5A, 0x20, 0x5C, 0x20, 0x5C, 0x21, 0x5D, 0x21, 0x5C, 0x20, 0x5A, 0x1F, 0x5A, 0x20, 0x5A, 0x1F, 0x5A, 0x20, 0x5C, 0x20, 0x5B, 0x20, 0x59, 0x1F, 0x57, 0x1F, 0x59, 0x1F, 0x58, 0x1F, 0x59, 0x20, 0x59, 0x1F, 0x5A, 0x20, 0x5B, 0x20, 0x5B, 0x20, 0x5C, 0x22, 0x5A, 0x21, 0x5A, 0x21, 0x57, 0x1F, 0x56, 0x1F, 0x55, 0x1F, 0x58, 0x1F, 0x54, 0x1E, 0x56, 0x1F, 0x55, 0x1F, 0x55, 0x1F, 0x55, 0x1F, 0x56, 0x1F, 0x56, 0x1F, 0x5A, 0x23, 0x55, 0x1F, 0x55, 0x1E, 0x53, 0x1E, 0x53, 0x1E, 0x53, 0x1E, 0x54, 0x1E, 0x53, 0x1E, 0x51, 0x1E, 0x53, 0x1E, 0x56, 0x1E, 0x55, 0x1E, 0x55, 0x1F, 0x54, 0x1E, 0x53, 0x1D, 0x53, 0x1D, 0x54, 0x1E, 0x54, 0x1E, 0x55, 0x1E, 0x55, 0x1E, 0x52, 0x1D, 0x51, 0x1E, 0x54, 0x1E, 0x53, 0x1E, 0x55, 0x1F, 0x56, 0x1E, 0x53, 0x1E, 0x54, 0x1F, 0x54, 0x1E, 0x52, 0x1D, 0x51, 0x1D, 0x51, 0x1D, 0x53, 0x1E, 0x53, 0x1D, 0x53, 0x1E, 0x52, 0x1E, 0x52, 0x1E, 0x51, 0x1E, 0x53, 0x1E, 0x52, 0x1E, 0x55, 0x1F, 0x53, 0x1E, 0x52, 0x1E, 0x54, 0x1F, 0x54, 0x1F, 0x54, 0x1E, 0x52, 0x1E, 0x51, 0x1D, 0x51, 0x1D, 0x51, 0x1D, 0x4B, 0x1B, 0x32, 0x18, 0x2D, 0x18, 0x25, 0x16, 0x2C, 0x19, 0x2A, 0x17, 0x23, 0x15, 0x24, 0x15, 0x25, 0x16, 0x26, 0x15, 0x1F, 0x13, 0x26, 0x16, 0x23, 0x16, 0x27, 0x17, 0x23, 0x15, 0x20, 0x14, 0x26, 0x16, 0x21, 0x14, 0x2B, 0x19, 0x23, 0x14, 0x24, 0x16, 0x24, 0x14, 0x25, 0x17, 0x24, 0x15, 0x20, 0x14, 0x25, 0x15, 0x1F, 0x14, 0x25, 0x15, 0x1E, 0x13, 0x27, 0x16, 0x1F, 0x14, 0x25, 0x17, 0x22, 0x14, 0x1F, 0x14, 0x1F, 0x13, 0x1F, 0x14, 0x25, 0x15, 0x21, 0x14, 0x24, 0x15, 0x22, 0x14, 0x25, 0x16, 0x29, 0x17, 0x25, 0x15, 0x25, 0x15
    },

    {
        0x53, 0x4A, 0x53, 0x49, 0x53, 0x48, 0x53, 0x48, 0x54, 0x4A, 0x54, 0x4B, 0x56, 0x4B, 0x56, 0x4C, 0x56, 0x4B, 0x55, 0x4B, 0x56, 0x4D, 0x57, 0x4C, 0x57, 0x4D, 0x59, 0x4D, 0x59, 0x4D, 0x5A, 0x4D, 0x59, 0x4E, 0x5C, 0x4D, 0x5B, 0x4E, 0x5C, 0x4E, 0x5B, 0x4F, 0x5B, 0x4E, 0x5A, 0x4E, 0x5A, 0x4D, 0x5A, 0x4E, 0x5A, 0x50, 0x5B, 0x50, 0x5B, 0x50, 0x5A, 0x4F, 0x59, 0x4E, 0x59, 0x4E, 0x5C, 0x50, 0x5D, 0x50, 0x5C, 0x51, 0x5D, 0x50, 0x5B, 0x50, 0x5C, 0x50, 0x5B, 0x4F, 0x58, 0x4C, 0x53, 0x49, 0x4B, 0x41, 0x41, 0x39, 0x3C, 0x39, 0x44, 0x41, 0x4A, 0x45, 0x46, 0x40, 0x3C, 0x35, 0x2A, 0x27, 0x1E, 0x1D, 0x18, 0x19, 0x16, 0x18, 0x15, 0x17, 0x15, 0x18, 0x18, 0x1D, 0x1D, 0x24, 0x26, 0x2F, 0x31, 0x3A, 0x36, 0x3E, 0x39, 0x41, 0x3B, 0x43, 0x3D, 0x45, 0x3E, 0x47, 0x3F, 0x48, 0x40, 0x47, 0x3F, 0x48, 0x41, 0x4C, 0x43, 0x4D, 0x41, 0x4B, 0x41, 0x4A, 0x41, 0x4A, 0x41, 0x49, 0x41, 0x4A, 0x41, 0x4A, 0x40, 0x4A, 0x42, 0x4A, 0x42, 0x4C, 0x42, 0x4C, 0x42, 0x4D, 0x43, 0x4D, 0x42, 0x4C, 0x42, 0x4D, 0x41, 0x4B, 0x41, 0x4B, 0x42, 0x4C, 0x42, 0x4C, 0x42, 0x4C, 0x41, 0x4B, 0x40, 0x49, 0x40, 0x49, 0x3E, 0x47, 0x38, 0x3E, 0x28, 0x2B, 0x1D, 0x1F, 0x17, 0x19, 0x15, 0x17, 0x14, 0x17, 0x14, 0x17, 0x15, 0x18, 0x18, 0x1A, 0x21, 0x25, 0x3A, 0x3D, 0x4E, 0x4C, 0x55, 0x50, 0x51, 0x49, 0x3E, 0x38, 0x3B, 0x38, 0x4D, 0x4A, 0x5B, 0x54, 0x60, 0x57, 0x63, 0x58, 0x65, 0x5B, 0x6A, 0x5D, 0x68, 0x5B, 0x68, 0x5C, 0x68, 0x5C, 0x68, 0x5B, 0x6A, 0x5B, 0x69, 0x5C, 0x6A, 0x5C, 0x68, 0x5A, 0x68, 0x5D, 0x68, 0x5C, 0x68, 0x5B, 0x67, 0x5B, 0x68, 0x5C, 0x68, 0x5C, 0x69, 0x5C, 0x68, 0x5B, 0x69, 0x5C, 0x69, 0x5C, 0x68, 0x5A, 0x69, 0x5B, 0x6A, 0x5A, 0x6A, 0x5B, 0x6A, 0x5B, 0x68, 0x5B, 0x68, 0x5B, 0x66, 0x59, 0x67, 0x5A, 0x67, 0x59, 0x66, 0x59, 0x67, 0x59, 0x67, 0x57, 0x65, 0x55, 0x66, 0x58, 0x66, 0x59, 0x66, 0x59, 0x64, 0x57, 0x64, 0x57, 0x64, 0x56, 0x64, 0x56, 0x65, 0x57, 0x66, 0x57, 0x64, 0x56, 0x64, 0x55, 0x65, 0x57, 0x68, 0x59, 0x63, 0x56, 0x63, 0x56, 0x66, 0x59, 0x66, 0x58, 0x67, 0x59, 0x67, 0x59, 0x67, 0x5A, 0x66, 0x59, 0x67, 0x58, 0x66, 0x58, 0x68, 0x58, 0x68, 0x59, 0x67, 0x5A, 0x64, 0x57, 0x65, 0x58, 0x66, 0x59, 0x66, 0x58, 0x65, 0x56, 0x62, 0x55, 0x61, 0x55, 0x62, 0x53, 0x60, 0x53, 0x62, 0x54, 0x63, 0x56, 0x62, 0x53, 0x60, 0x54, 0x63, 0x55, 0x63, 0x55, 0x63, 0x56, 0x63, 0x56, 0x63, 0x56, 0x63, 0x55, 0x62, 0x55, 0x63, 0x55, 0x62, 0x54, 0x63, 0x56, 0x63, 0x56, 0x64, 0x57, 0x64, 0x58, 0x64, 0x56, 0x61, 0x54, 0x63, 0x56, 0x62, 0x55, 0x62, 0x55, 0x64, 0x57, 0x62, 0x55, 0x61, 0x53, 0x61, 0x53, 0x61, 0x54, 0x5E, 0x53, 0x62, 0x54, 0x60, 0x55, 0x63, 0x56, 0x63, 0x57, 0x61, 0x56, 0x62, 0x56, 0x60, 0x55, 0x60, 0x54, 0x5F, 0x53, 0x60, 0x52, 0x5E, 0x51, 0x61, 0x54, 0x5D, 0x4F, 0x5D, 0x51, 0x5C, 0x51, 0x5E, 0x51, 0x5E, 0x52, 0x5E, 0x52, 0x5D, 0x52, 0x5F, 0x57, 0x5C, 0x50, 0x5D, 0x50, 0x5C, 0x4F, 0x5A, 0x4E, 0x5A, 0x4E, 0x5B, 0x4F, 0x5A, 0x4F, 0x59, 0x4E, 0x5C, 0x51, 0x5D, 0x52, 0x5E, 0x51, 0x5D, 0x52, 0x5C, 0x50, 0x59, 0x4E, 0x5A, 0x50, 0x5C, 0x50, 0x5B, 0x4E, 0x5C, 0x51, 0x5D, 0x50, 0x59, 0x4E, 0x59, 0x4E, 0x5B, 0x51, 0x5B, 0x50, 0x5F, 0x51, 0x5C, 0x4F, 0x5A, 0x50, 0x5B, 0x50, 0x5C, 0x50, 0x5A, 0x4E, 0x59, 0x4F, 0x59, 0x4D, 0x5D, 0x50, 0x5C, 0x50, 0x5B, 0x50, 0x5A, 0x4F, 0x5A, 0x4E, 0x5B, 0x4E, 0x5C, 0x50, 0x5A, 0x4E, 0x5C, 0x51, 0x5C, 0x50, 0x5A, 0x4F, 0x5C, 0x50, 0x5C, 0x51, 0x5B, 0x4E, 0x5A, 0x4F, 0x5A, 0x4E, 0x59, 0x4D, 0x5A, 0x4D, 0x4F, 0x41, 0x34, 0x30, 0x2B, 0x29, 0x22, 0x24, 0x26, 0x27, 0x23, 0x24, 0x20, 0x21, 0x20, 0x21, 0x21, 0x24, 0x20, 0x21, 0x1E, 0x1F, 0x21, 0x23, 0x21, 0x24, 0x22, 0x22, 0x1F, 0x21, 0x1D, 0x1F, 0x23, 0x24, 0x1D, 0x1F, 0x24, 0x27, 0x1F, 0x20, 0x21, 0x24, 0x20, 0x20, 0x22, 0x25, 0x1F, 0x20, 0x1E, 0x1F, 0x20, 0x21, 0x1D, 0x20, 0x20, 0x20, 0x1D, 0x1E, 0x24, 0x26, 0x1E, 0x20, 0x21, 0x25, 0x1E, 0x1F, 0x1E, 0x20, 0x1E, 0x1F, 0x1F, 0x23, 0x22, 0x25, 0x1F, 0x20, 0x22, 0x22, 0x21, 0x24, 0x22, 0x26, 0x25, 0x29, 0x22, 0x23, 0x20, 0x23
    },

    {
        0x4E, 0x1C, 0x4E, 0x1B, 0x4D, 0x1B, 0x4D, 0x1B, 0x4C, 0x1B, 0x4E, 0x1B, 0x4E, 0x1C, 0x4E, 0x1C, 0x4F, 0x1C, 0x4E, 0x1C, 0x50, 0x1D, 0x52, 0x1D, 0x51, 0x1D, 0x52, 0x1C, 0x50, 0x1D, 0x50, 0x1C, 0x50, 0x1C, 0x51, 0x1D, 0x52, 0x1D, 0x51, 0x1D, 0x51, 0x1D, 0x52, 0x1D, 0x51, 0x1D, 0x52, 0x1D, 0x52, 0x1D, 0x52, 0x1D, 0x54, 0x1E, 0x54, 0x1E, 0x53, 0x1E, 0x53, 0x1E, 0x54, 0x1D, 0x54, 0x1E, 0x56, 0x1F, 0x56, 0x1F, 0x55, 0x1F, 0x54, 0x1E, 0x53, 0x1E, 0x52, 0x1E, 0x4F, 0x1E, 0x49, 0x1D, 0x41, 0x1B, 0x3A, 0x19, 0x3F, 0x1B, 0x48, 0x1D, 0x47, 0x1C, 0x3D, 0x19, 0x2E, 0x15, 0x23, 0x12, 0x1C, 0x11, 0x19, 0x10, 0x18, 0x11, 0x18, 0x12, 0x1B, 0x17, 0x22, 0x22, 0x2C, 0x2F, 0x39, 0x3C, 0x40, 0x43, 0x43, 0x46, 0x46, 0x48, 0x48, 0x4A, 0x4C, 0x4D, 0x4C, 0x4E, 0x4C, 0x4E, 0x4D, 0x4F, 0x4B, 0x4F, 0x4D, 0x50, 0x52, 0x51, 0x50, 0x50, 0x4E, 0x50, 0x4D, 0x50, 0x4E, 0x50, 0x4E, 0x50, 0x4E, 0x51, 0x4E, 0x51, 0x4E, 0x51, 0x4F, 0x51, 0x50, 0x53, 0x50, 0x53, 0x52, 0x53, 0x51, 0x53, 0x50, 0x52, 0x50, 0x52, 0x50, 0x52, 0x50, 0x52, 0x51, 0x52, 0x51, 0x53, 0x4F, 0x52, 0x4F, 0x51, 0x4F, 0x51, 0x4D, 0x50, 0x4C, 0x4C, 0x41, 0x3B, 0x2C, 0x24, 0x1F, 0x18, 0x1A, 0x13, 0x18, 0x12, 0x18, 0x11, 0x18, 0x11, 0x1A, 0x11, 0x1D, 0x12, 0x2A, 0x17, 0x42, 0x1D, 0x4F, 0x20, 0x53, 0x1F, 0x4D, 0x1E, 0x3C, 0x1B, 0x3E, 0x1D, 0x4F, 0x20, 0x59, 0x22, 0x5C, 0x22, 0x5F, 0x23, 0x64, 0x23, 0x64, 0x25, 0x61, 0x23, 0x63, 0x23, 0x60, 0x22, 0x5F, 0x21, 0x60, 0x22, 0x60, 0x22, 0x62, 0x22, 0x60, 0x22, 0x62, 0x22, 0x62, 0x22, 0x61, 0x22, 0x62, 0x22, 0x61, 0x23, 0x63, 0x23, 0x62, 0x23, 0x62, 0x22, 0x62, 0x22, 0x62, 0x22, 0x5F, 0x21, 0x60, 0x21, 0x5F, 0x21, 0x60, 0x22, 0x60, 0x21, 0x5E, 0x21, 0x5F, 0x21, 0x5E, 0x21, 0x5E, 0x21, 0x5C, 0x20, 0x5E, 0x20, 0x5E, 0x20, 0x5D, 0x20, 0x5E, 0x20, 0x5F, 0x21, 0x5E, 0x20, 0x5C, 0x20, 0x5C, 0x20, 0x5C, 0x21, 0x5C, 0x1F, 0x5E, 0x1F, 0x5C, 0x1F, 0x5B, 0x20, 0x5B, 0x20, 0x5D, 0x21, 0x5F, 0x21, 0x5E, 0x21, 0x5E, 0x21, 0x5E, 0x21, 0x5E, 0x21, 0x5F, 0x21, 0x5F, 0x21, 0x5E, 0x21, 0x5D, 0x21, 0x5C, 0x20, 0x5D, 0x21, 0x5E, 0x20, 0x5E, 0x20, 0x5E, 0x21, 0x5D, 0x21, 0x5D, 0x20, 0x5F, 0x21, 0x5D, 0x21, 0x5D, 0x20, 0x5B, 0x20, 0x58, 0x1F, 0x5A, 0x20, 0x59, 0x1F, 0x59, 0x1F, 0x5A, 0x20, 0x58, 0x1F, 0x58, 0x1F, 0x5A, 0x20, 0x5A, 0x20, 0x5C, 0x20, 0x5D, 0x21, 0x5B, 0x20, 0x5B, 0x20, 0x58, 0x1F, 0x5A, 0x1F, 0x58, 0x1F, 0x5B, 0x1F, 0x5C, 0x20, 0x5C, 0x20, 0x5D, 0x20, 0x5B, 0x20, 0x5A, 0x1F, 0x5A, 0x20, 0x5A, 0x1F, 0x5A, 0x1F, 0x5B, 0x20, 0x5A, 0x20, 0x59, 0x1F, 0x59, 0x20, 0x5A, 0x20, 0x56, 0x1F, 0x5A, 0x1F, 0x58, 0x1F, 0x5A, 0x1F, 0x58, 0x20, 0x5C, 0x21, 0x5A, 0x21, 0x58, 0x20, 0x59, 0x20, 0x59, 0x1F, 0x58, 0x1F, 0x56, 0x1F, 0x57, 0x1F, 0x57, 0x1F, 0x56, 0x1F, 0x55, 0x1F, 0x55, 0x1E, 0x57, 0x1F, 0x58, 0x1F, 0x57, 0x20, 0x5F, 0x25, 0x55, 0x1F, 0x54, 0x1E, 0x54, 0x1E, 0x53, 0x1E, 0x54, 0x1E, 0x55, 0x1E, 0x53, 0x1D, 0x51, 0x1E, 0x55, 0x1F, 0x54, 0x1E, 0x56, 0x20, 0x54, 0x1E, 0x54, 0x1E, 0x51, 0x1D, 0x51, 0x1D, 0x53, 0x1D, 0x52, 0x1E, 0x53, 0x1E, 0x54, 0x1D, 0x51, 0x1D, 0x51, 0x1E, 0x53, 0x1E, 0x53, 0x1E, 0x54, 0x1F, 0x53, 0x1D, 0x52, 0x1D, 0x54, 0x1F, 0x53, 0x1E, 0x53, 0x1E, 0x52, 0x1D, 0x51, 0x1D, 0x51, 0x1D, 0x52, 0x1D, 0x53, 0x1E, 0x55, 0x1F, 0x53, 0x1E, 0x52, 0x1D, 0x54, 0x1E, 0x53, 0x1E, 0x54, 0x1F, 0x54, 0x1E, 0x54, 0x1F, 0x54, 0x1F, 0x55, 0x1E, 0x53, 0x1D, 0x55, 0x1E, 0x50, 0x1E, 0x53, 0x1E, 0x52, 0x1E, 0x4C, 0x1B, 0x33, 0x19, 0x29, 0x16, 0x24, 0x16, 0x28, 0x18, 0x25, 0x16, 0x22, 0x15, 0x24, 0x16, 0x26, 0x16, 0x24, 0x16, 0x23, 0x14, 0x26, 0x16, 0x26, 0x16, 0x25, 0x15, 0x26, 0x16, 0x22, 0x14, 0x23, 0x15, 0x23, 0x16, 0x26, 0x15, 0x25, 0x16, 0x25, 0x16, 0x23, 0x15, 0x29, 0x17, 0x23, 0x15, 0x23, 0x15, 0x25, 0x16, 0x25, 0x16, 0x27, 0x17, 0x23, 0x15, 0x2B, 0x18, 0x24, 0x15, 0x25, 0x16, 0x21, 0x13, 0x25, 0x16, 0x25, 0x15, 0x26, 0x16, 0x29, 0x16, 0x20, 0x12, 0x29, 0x17, 0x24, 0x14, 0x29, 0x17, 0x24, 0x15, 0x22, 0x14, 0x23, 0x15
    },

    {
        0x54, 0x4C, 0x54, 0x4B, 0x54, 0x4B, 0x53, 0x4A, 0x54, 0x4A, 0x55, 0x4A, 0x55, 0x4B, 0x56, 0x4C, 0x57, 0x4B, 0x56, 0x4B, 0x58, 0x4D, 0x5A, 0x4D, 0x59, 0x4E, 0x59, 0x4D, 0x59, 0x4C, 0x5A, 0x4D, 0x5A, 0x4E, 0x5B, 0x4D, 0x5B, 0x4E, 0x5A, 0x4D, 0x5A, 0x4E, 0x5A, 0x4E, 0x5B, 0x4E, 0x5A, 0x4E, 0x5A, 0x4F, 0x5A, 0x4F, 0x5B, 0x51, 0x5B, 0x50, 0x5B, 0x50, 0x5C, 0x50, 0x5D, 0x50, 0x5D, 0x50, 0x5E, 0x52, 0x5F, 0x52, 0x5D, 0x51, 0x5C, 0x50, 0x5A, 0x50, 0x58, 0x4F, 0x55, 0x4A, 0x4D, 0x43, 0x44, 0x3E, 0x3C, 0x39, 0x42, 0x3F, 0x4B, 0x46, 0x48, 0x41, 0x3B, 0x35, 0x2C, 0x27, 0x1E, 0x1D, 0x19, 0x1A, 0x16, 0x17, 0x14, 0x17, 0x14, 0x18, 0x17, 0x1C, 0x1C, 0x24, 0x26, 0x2F, 0x30, 0x3A, 0x37, 0x3F, 0x38, 0x40, 0x39, 0x42, 0x3C, 0x45, 0x3E, 0x48, 0x3E, 0x48, 0x3F, 0x49, 0x40, 0x49, 0x40, 0x49, 0x40, 0x4A, 0x43, 0x4D, 0x42, 0x4C, 0x41, 0x4A, 0x41, 0x4A, 0x41, 0x49, 0x40, 0x4A, 0x41, 0x4A, 0x41, 0x4A, 0x41, 0x4B, 0x41, 0x4B, 0x43, 0x4D, 0x44, 0x4E, 0x44, 0x4F, 0x43, 0x4E, 0x43, 0x4D, 0x43, 0x4C, 0x42, 0x4B, 0x42, 0x4C, 0x43, 0x4C, 0x43, 0x4C, 0x42, 0x4D, 0x42, 0x4B, 0x42, 0x4B, 0x40, 0x4A, 0x3E, 0x47, 0x38, 0x3E, 0x27, 0x29, 0x1B, 0x1D, 0x17, 0x19, 0x14, 0x17, 0x13, 0x16, 0x14, 0x17, 0x15, 0x18, 0x18, 0x1A, 0x22, 0x25, 0x3B, 0x3D, 0x4C, 0x4B, 0x53, 0x4F, 0x52, 0x4A, 0x41, 0x3A, 0x3C, 0x39, 0x4D, 0x48, 0x5A, 0x53, 0x61, 0x57, 0x63, 0x5A, 0x67, 0x5C, 0x6A, 0x5E, 0x68, 0x5B, 0x6A, 0x5C, 0x69, 0x5A, 0x68, 0x5A, 0x69, 0x5B, 0x67, 0x5B, 0x69, 0x5B, 0x6A, 0x5A, 0x6B, 0x5D, 0x6B, 0x5D, 0x69, 0x5B, 0x6A, 0x5D, 0x6A, 0x5D, 0x6C, 0x5E, 0x6A, 0x5D, 0x6B, 0x5C, 0x6B, 0x5E, 0x6C, 0x5C, 0x67, 0x59, 0x68, 0x5A, 0x69, 0x5A, 0x69, 0x5B, 0x67, 0x5A, 0x68, 0x5A, 0x67, 0x59, 0x67, 0x5A, 0x66, 0x59, 0x66, 0x57, 0x68, 0x59, 0x68, 0x58, 0x67, 0x58, 0x67, 0x58, 0x67, 0x59, 0x68, 0x59, 0x66, 0x58, 0x65, 0x57, 0x64, 0x56, 0x63, 0x57, 0x66, 0x57, 0x65, 0x57, 0x64, 0x57, 0x64, 0x56, 0x66, 0x59, 0x67, 0x59, 0x66, 0x59, 0x67, 0x59, 0x66, 0x58, 0x65, 0x57, 0x66, 0x5A, 0x68, 0x5A, 0x68, 0x5A, 0x65, 0x56, 0x64, 0x57, 0x67, 0x58, 0x67, 0x57, 0x68, 0x58, 0x68, 0x59, 0x66, 0x57, 0x64, 0x58, 0x64, 0x57, 0x64, 0x58, 0x65, 0x57, 0x64, 0x56, 0x60, 0x54, 0x62, 0x55, 0x62, 0x53, 0x63, 0x55, 0x65, 0x56, 0x60, 0x52, 0x60, 0x53, 0x62, 0x55, 0x63, 0x55, 0x63, 0x57, 0x64, 0x57, 0x62, 0x56, 0x62, 0x55, 0x61, 0x53, 0x61, 0x53, 0x61, 0x54, 0x62, 0x56, 0x64, 0x57, 0x64, 0x56, 0x66, 0x57, 0x64, 0x56, 0x64, 0x55, 0x64, 0x55, 0x63, 0x55, 0x63, 0x56, 0x63, 0x57, 0x62, 0x54, 0x61, 0x53, 0x60, 0x53, 0x61, 0x53, 0x5F, 0x52, 0x61, 0x53, 0x60, 0x52, 0x62, 0x54, 0x60, 0x54, 0x62, 0x57, 0x60, 0x55, 0x5E, 0x52, 0x5D, 0x52, 0x5F, 0x53, 0x60, 0x52, 0x5F, 0x52, 0x5F, 0x52, 0x60, 0x53, 0x5C, 0x50, 0x5E, 0x52, 0x5F, 0x53, 0x5F, 0x52, 0x60, 0x54, 0x5E, 0x53, 0x62, 0x5A, 0x5C, 0x51, 0x5B, 0x50, 0x5B, 0x4F, 0x5A, 0x50, 0x5C, 0x50, 0x5C, 0x4F, 0x5C, 0x50, 0x5B, 0x4F, 0x5E, 0x53, 0x5D, 0x51, 0x5D, 0x52, 0x5B, 0x50, 0x5C, 0x51, 0x5A, 0x4D, 0x59, 0x4D, 0x5B, 0x4F, 0x5A, 0x4E, 0x5A, 0x4F, 0x59, 0x4E, 0x5A, 0x4F, 0x59, 0x4D, 0x5B, 0x50, 0x5D, 0x50, 0x5E, 0x51, 0x5A, 0x4E, 0x5A, 0x4E, 0x5A, 0x4F, 0x5A, 0x50, 0x59, 0x4F, 0x59, 0x4E, 0x58, 0x4D, 0x5A, 0x4E, 0x5A, 0x4E, 0x5B, 0x4F, 0x5B, 0x50, 0x5B, 0x4F, 0x5C, 0x4E, 0x5B, 0x4F, 0x5B, 0x4F, 0x5C, 0x50, 0x5B, 0x50, 0x5C, 0x51, 0x5D, 0x51, 0x5E, 0x51, 0x5B, 0x4F, 0x5C, 0x52, 0x59, 0x4E, 0x5A, 0x4F, 0x5A, 0x4E, 0x52, 0x44, 0x35, 0x30, 0x27, 0x25, 0x22, 0x23, 0x29, 0x28, 0x21, 0x22, 0x20, 0x23, 0x21, 0x24, 0x22, 0x25, 0x22, 0x25, 0x20, 0x21, 0x22, 0x25, 0x23, 0x25, 0x22, 0x25, 0x24, 0x25, 0x1F, 0x21, 0x21, 0x22, 0x21, 0x26, 0x22, 0x22, 0x21, 0x24, 0x22, 0x24, 0x1F, 0x21, 0x24, 0x27, 0x21, 0x24, 0x1E, 0x21, 0x23, 0x26, 0x23, 0x25, 0x26, 0x29, 0x20, 0x22, 0x26, 0x29, 0x20, 0x21, 0x21, 0x23, 0x1D, 0x1E, 0x22, 0x26, 0x20, 0x22, 0x21, 0x22, 0x22, 0x24, 0x1D, 0x1D, 0x25, 0x29, 0x1F, 0x20, 0x23, 0x26, 0x21, 0x22, 0x1F, 0x21, 0x20, 0x22
    },

    {
        0x4F, 0x1D, 0x4F, 0x1C, 0x4E, 0x1B, 0x4D, 0x1B, 0x4D, 0x1B, 0x4D, 0x1C, 0x4D, 0x1B, 0x4E, 0x1B, 0x4E, 0x1B, 0x4E, 0x1C, 0x4E, 0x1C, 0x50, 0x1C, 0x50, 0x1C, 0x4F, 0x1C, 0x50, 0x1C, 0x50, 0x1C, 0x51, 0x1C, 0x52, 0x1C, 0x52, 0x1D, 0x51, 0x1D, 0x52, 0x1D, 0x51, 0x1C, 0x50, 0x1D, 0x52, 0x1D, 0x52, 0x1E, 0x53, 0x1D, 0x54, 0x1F, 0x54, 0x1F, 0x54, 0x1E, 0x54, 0x1E, 0x53, 0x1E, 0x54, 0x1E, 0x54, 0x1F, 0x55, 0x1F, 0x55, 0x1F, 0x54, 0x1F, 0x52, 0x1E, 0x4E, 0x1E, 0x49, 0x1D, 0x42, 0x1B, 0x3D, 0x1B, 0x3F, 0x1A, 0x47, 0x1C, 0x46, 0x1C, 0x3F, 0x1A, 0x2F, 0x16, 0x22, 0x12, 0x1C, 0x10, 0x19, 0x10, 0x17, 0x10, 0x17, 0x11, 0x19, 0x16, 0x1F, 0x1F, 0x2B, 0x2D, 0x38, 0x3A, 0x40, 0x42, 0x44, 0x45, 0x45, 0x47, 0x47, 0x49, 0x49, 0x4B, 0x4C, 0x4F, 0x4F, 0x50, 0x4D, 0x4F, 0x4C, 0x4F, 0x4D, 0x4F, 0x4D, 0x4F, 0x4E, 0x51, 0x4F, 0x51, 0x4E, 0x50, 0x4E, 0x50, 0x4D, 0x50, 0x4D, 0x50, 0x4F, 0x52, 0x4E, 0x52, 0x4F, 0x52, 0x4F, 0x52, 0x50, 0x52, 0x52, 0x53, 0x52, 0x52, 0x51, 0x54, 0x52, 0x54, 0x50, 0x53, 0x50, 0x52, 0x4F, 0x53, 0x51, 0x53, 0x51, 0x52, 0x50, 0x52, 0x50, 0x53, 0x50, 0x52, 0x4F, 0x50, 0x4D, 0x4D, 0x46, 0x44, 0x38, 0x2F, 0x24, 0x1C, 0x1C, 0x15, 0x18, 0x12, 0x18, 0x11, 0x17, 0x10, 0x18, 0x11, 0x1A, 0x11, 0x1C, 0x12, 0x28, 0x17, 0x41, 0x1C, 0x4E, 0x1F, 0x52, 0x1F, 0x4F, 0x1E, 0x3E, 0x1B, 0x3B, 0x1C, 0x4C, 0x1F, 0x58, 0x21, 0x5A, 0x22, 0x5D, 0x22, 0x60, 0x23, 0x64, 0x24, 0x63, 0x23, 0x61, 0x22, 0x60, 0x22, 0x60, 0x22, 0x60, 0x22, 0x60, 0x22, 0x60, 0x21, 0x61, 0x22, 0x62, 0x22, 0x60, 0x21, 0x62, 0x22, 0x62, 0x23, 0x62, 0x22, 0x63, 0x22, 0x62, 0x23, 0x62, 0x22, 0x61, 0x22, 0x61, 0x22, 0x61, 0x22, 0x61, 0x21, 0x60, 0x21, 0x5E, 0x22, 0x5F, 0x20, 0x5D, 0x20, 0x5D, 0x21, 0x5D, 0x21, 0x5C, 0x20, 0x5E, 0x21, 0x5F, 0x20, 0x5D, 0x20, 0x5D, 0x20, 0x5D, 0x20, 0x5D, 0x20, 0x5C, 0x1F, 0x5D, 0x20, 0x5C, 0x20, 0x5D, 0x20, 0x5C, 0x20, 0x5D, 0x20, 0x5C, 0x20, 0x5D, 0x21, 0x5E, 0x21, 0x5F, 0x21, 0x5D, 0x21, 0x5E, 0x21, 0x5F, 0x21, 0x5C, 0x20, 0x5D, 0x21, 0x5F, 0x22, 0x5F, 0x21, 0x5D, 0x21, 0x5C, 0x20, 0x5B, 0x20, 0x5D, 0x20, 0x5E, 0x20, 0x5F, 0x21, 0x5E, 0x21, 0x5D, 0x21, 0x5C, 0x20, 0x5D, 0x21, 0x5D, 0x21, 0x5C, 0x20, 0x5B, 0x20, 0x59, 0x1F, 0x5B, 0x20, 0x59, 0x20, 0x5A, 0x1F, 0x59, 0x1F, 0x57, 0x1F, 0x59, 0x20, 0x5B, 0x20, 0x5C, 0x20, 0x5E, 0x21, 0x5D, 0x20, 0x5D, 0x21, 0x5B, 0x20, 0x59, 0x1F, 0x59, 0x20, 0x5C, 0x21, 0x5A, 0x20, 0x5D, 0x21, 0x5B, 0x20, 0x5A, 0x20, 0x5B, 0x20, 0x5B, 0x1F, 0x5A, 0x20, 0x5B, 0x20, 0x5B, 0x20, 0x5A, 0x20, 0x58, 0x1F, 0x57, 0x1F, 0x58, 0x1E, 0x57, 0x1E, 0x58, 0x1F, 0x57, 0x1F, 0x59, 0x1F, 0x59, 0x20, 0x5A, 0x20, 0x57, 0x20, 0x54, 0x1F, 0x54, 0x1F, 0x56, 0x1F, 0x57, 0x1F, 0x58, 0x20, 0x56, 0x20, 0x59, 0x20, 0x58, 0x1F, 0x55, 0x1F, 0x58, 0x20, 0x57, 0x1F, 0x57, 0x1F, 0x58, 0x22, 0x5B, 0x22, 0x56, 0x1F, 0x56, 0x1F, 0x55, 0x1E, 0x54, 0x1E, 0x55, 0x1E, 0x54, 0x1D, 0x53, 0x1E, 0x54, 0x1E, 0x57, 0x1F, 0x56, 0x1F, 0x57, 0x1F, 0x55, 0x1F, 0x53, 0x1D, 0x52, 0x1D, 0x52, 0x1D, 0x52, 0x1D, 0x51, 0x1D, 0x53, 0x1E, 0x54, 0x1F, 0x52, 0x1D, 0x51, 0x1D, 0x53, 0x1E, 0x54, 0x1E, 0x56, 0x1E, 0x52, 0x1E, 0x51, 0x1D, 0x52, 0x1E, 0x53, 0x1E, 0x51, 0x1D, 0x50, 0x1D, 0x52, 0x1E, 0x51, 0x1D, 0x51, 0x1D, 0x52, 0x1E, 0x54, 0x1F, 0x53, 0x1E, 0x54, 0x1F, 0x52, 0x1D, 0x51, 0x1D, 0x53, 0x1E, 0x52, 0x1E, 0x53, 0x1D, 0x53, 0x1E, 0x55, 0x1F, 0x56, 0x1F, 0x55, 0x1F, 0x54, 0x1F, 0x54, 0x1F, 0x54, 0x1E, 0x4B, 0x1C, 0x36, 0x1A, 0x27, 0x16, 0x26, 0x16, 0x28, 0x17, 0x26, 0x16, 0x24, 0x16, 0x2C, 0x19, 0x26, 0x17, 0x2D, 0x19, 0x22, 0x14, 0x2B, 0x18, 0x24, 0x16, 0x2B, 0x18, 0x26, 0x16, 0x20, 0x14, 0x29, 0x17, 0x27, 0x16, 0x25, 0x16, 0x28, 0x17, 0x26, 0x16, 0x27, 0x16, 0x25, 0x16, 0x25, 0x17, 0x20, 0x14, 0x29, 0x16, 0x22, 0x15, 0x29, 0x17, 0x20, 0x13, 0x28, 0x16, 0x20, 0x14, 0x24, 0x15, 0x20, 0x14, 0x25, 0x15, 0x1E, 0x13, 0x23, 0x15, 0x21, 0x13, 0x1E, 0x13, 0x26, 0x15, 0x20, 0x13, 0x25, 0x16, 0x21, 0x14, 0x25, 0x15, 0x1F, 0x14
    },

    {
        0x56, 0x4D, 0x55, 0x4C, 0x54, 0x4B, 0x54, 0x4B, 0x54, 0x49, 0x55, 0x4B, 0x54, 0x4A, 0x55, 0x4A, 0x56, 0x4B, 0x57, 0x4B, 0x58, 0x4D, 0x59, 0x4B, 0x59, 0x4C, 0x59, 0x4D, 0x59, 0x4D, 0x59, 0x4D, 0x5A, 0x4E, 0x5C, 0x4D, 0x5C, 0x4E, 0x5B, 0x4E, 0x5B, 0x4E, 0x5B, 0x4E, 0x5B, 0x4E, 0x5B, 0x4E, 0x5B, 0x50, 0x5C, 0x50, 0x5D, 0x51, 0x5B, 0x51, 0x5A, 0x50, 0x5C, 0x50, 0x5C, 0x4F, 0x5C, 0x50, 0x5D, 0x51, 0x5E, 0x51, 0x5E, 0x51, 0x5B, 0x50, 0x59, 0x4E, 0x53, 0x48, 0x4D, 0x43, 0x44, 0x3C, 0x3E, 0x3A, 0x43, 0x40, 0x4B, 0x45, 0x49, 0x41, 0x3F, 0x36, 0x2D, 0x28, 0x1F, 0x1E, 0x19, 0x1A, 0x16, 0x17, 0x14, 0x16, 0x13, 0x16, 0x15, 0x1A, 0x1B, 0x21, 0x24, 0x2D, 0x2F, 0x37, 0x35, 0x3E, 0x38, 0x41, 0x3A, 0x42, 0x3B, 0x45, 0x3D, 0x46, 0x3F, 0x48, 0x41, 0x4A, 0x40, 0x48, 0x3F, 0x48, 0x40, 0x49, 0x41, 0x49, 0x41, 0x49, 0x41, 0x49, 0x41, 0x49, 0x41, 0x49, 0x41, 0x4A, 0x41, 0x4A, 0x41, 0x4B, 0x41, 0x4B, 0x42, 0x4A, 0x42, 0x4B, 0x43, 0x4C, 0x44, 0x4D, 0x43, 0x4D, 0x44, 0x4E, 0x43, 0x4E, 0x44, 0x4D, 0x43, 0x4B, 0x43, 0x4D, 0x44, 0x4D, 0x43, 0x4C, 0x42, 0x4B, 0x41, 0x4A, 0x42, 0x4B, 0x40, 0x49, 0x3F, 0x48, 0x39, 0x41, 0x2E, 0x32, 0x1F, 0x1F, 0x17, 0x1A, 0x14, 0x17, 0x14, 0x16, 0x12, 0x16, 0x14, 0x17, 0x15, 0x17, 0x17, 0x19, 0x20, 0x24, 0x39, 0x3B, 0x4B, 0x48, 0x53, 0x4D, 0x53, 0x4B, 0x43, 0x3B, 0x3A, 0x36, 0x4B, 0x47, 0x5A, 0x52, 0x5F, 0x55, 0x61, 0x59, 0x65, 0x5A, 0x69, 0x5E, 0x6A, 0x5C, 0x6A, 0x5C, 0x69, 0x5B, 0x69, 0x5B, 0x68, 0x5B, 0x68, 0x5C, 0x6A, 0x5B, 0x6A, 0x5C, 0x6B, 0x5D, 0x6B, 0x5B, 0x6B, 0x5D, 0x6A, 0x5C, 0x6B, 0x5D, 0x6C, 0x5D, 0x6A, 0x5D, 0x6B, 0x5D, 0x6B, 0x5C, 0x6A, 0x5B, 0x6A, 0x5A, 0x69, 0x5B, 0x6A, 0x5B, 0x69, 0x5A, 0x69, 0x5A, 0x67, 0x58, 0x66, 0x58, 0x65, 0x58, 0x65, 0x56, 0x69, 0x59, 0x68, 0x5A, 0x66, 0x56, 0x66, 0x57, 0x66, 0x58, 0x65, 0x57, 0x63, 0x56, 0x64, 0x56, 0x66, 0x58, 0x66, 0x57, 0x64, 0x57, 0x66, 0x57, 0x65, 0x57, 0x67, 0x59, 0x68, 0x59, 0x67, 0x59, 0x66, 0x58, 0x66, 0x58, 0x67, 0x58, 0x64, 0x57, 0x65, 0x58, 0x65, 0x59, 0x67, 0x59, 0x67, 0x58, 0x65, 0x57, 0x65, 0x57, 0x67, 0x58, 0x67, 0x58, 0x69, 0x5A, 0x66, 0x59, 0x65, 0x57, 0x65, 0x57, 0x65, 0x57, 0x68, 0x59, 0x65, 0x57, 0x63, 0x56, 0x62, 0x55, 0x63, 0x55, 0x63, 0x54, 0x63, 0x54, 0x62, 0x53, 0x61, 0x53, 0x63, 0x57, 0x64, 0x56, 0x64, 0x57, 0x66, 0x58, 0x66, 0x59, 0x66, 0x58, 0x64, 0x55, 0x61, 0x55, 0x62, 0x55, 0x64, 0x55, 0x63, 0x57, 0x65, 0x59, 0x64, 0x55, 0x64, 0x56, 0x62, 0x55, 0x62, 0x56, 0x62, 0x56, 0x64, 0x56, 0x64, 0x55, 0x64, 0x54, 0x61, 0x52, 0x61, 0x52, 0x60, 0x52, 0x5E, 0x51, 0x5F, 0x52, 0x5F, 0x52, 0x60, 0x53, 0x5F, 0x54, 0x5E, 0x52, 0x5B, 0x50, 0x57, 0x4E, 0x59, 0x50, 0x5D, 0x53, 0x5F, 0x53, 0x60, 0x54, 0x5F, 0x53, 0x60, 0x53, 0x5F, 0x52, 0x5E, 0x52, 0x60, 0x53, 0x61, 0x53, 0x60, 0x53, 0x5F, 0x56, 0x60, 0x55, 0x5E, 0x51, 0x5F, 0x53, 0x5E, 0x51, 0x5C, 0x50, 0x5E, 0x51, 0x5D, 0x50, 0x5D, 0x4F, 0x5E, 0x51, 0x5F, 0x52, 0x5F, 0x52, 0x5E, 0x50, 0x5E, 0x51, 0x5C, 0x4F, 0x5A, 0x4D, 0x5B, 0x4E, 0x5A, 0x4E, 0x5B, 0x4E, 0x5A, 0x4F, 0x5C, 0x50, 0x5C, 0x50, 0x59, 0x4D, 0x5B, 0x50, 0x5D, 0x50, 0x5D, 0x50, 0x5A, 0x4D, 0x58, 0x4E, 0x57, 0x50, 0x5B, 0x4F, 0x59, 0x4C, 0x59, 0x4E, 0x5A, 0x4E, 0x5B, 0x4E, 0x59, 0x4E, 0x5B, 0x4F, 0x5C, 0x52, 0x5B, 0x4F, 0x5D, 0x4F, 0x5A, 0x4E, 0x5B, 0x4E, 0x5B, 0x4E, 0x5C, 0x50, 0x5B, 0x4E, 0x5C, 0x50, 0x5D, 0x52, 0x5C, 0x50, 0x5D, 0x51, 0x5D, 0x51, 0x5C, 0x51, 0x5B, 0x4F, 0x51, 0x45, 0x36, 0x33, 0x26, 0x24, 0x23, 0x24, 0x22, 0x24, 0x22, 0x24, 0x21, 0x24, 0x26, 0x28, 0x21, 0x23, 0x26, 0x28, 0x1F, 0x21, 0x26, 0x29, 0x20, 0x23, 0x26, 0x28, 0x21, 0x21, 0x1E, 0x20, 0x25, 0x28, 0x22, 0x22, 0x22, 0x26, 0x23, 0x24, 0x23, 0x26, 0x22, 0x23, 0x20, 0x21, 0x21, 0x23, 0x1D, 0x1F, 0x23, 0x25, 0x1E, 0x21, 0x24, 0x24, 0x1D, 0x1E, 0x25, 0x25, 0x1D, 0x1F, 0x20, 0x20, 0x1D, 0x1F, 0x21, 0x23, 0x1D, 0x1E, 0x20, 0x23, 0x1F, 0x1F, 0x1C, 0x1E, 0x22, 0x23, 0x1D, 0x1F, 0x21, 0x23, 0x20, 0x23, 0x22, 0x24, 0x1D, 0x1F
    },

    {
        0x4F, 0x1C, 0x4E, 0x1C, 0x4F, 0x1B, 0x4D, 0x1B, 0x4D, 0x1B, 0x4E, 0x1C, 0x4E, 0x1C, 0x4E, 0x1C, 0x4E, 0x1B, 0x4E, 0x1C, 0x4F, 0x1C, 0x4F, 0x1B, 0x4E, 0x1C, 0x4F, 0x1C, 0x50, 0x1C, 0x50, 0x1C, 0x51, 0x1D, 0x52, 0x1D, 0x52, 0x1D, 0x52, 0x1C, 0x51, 0x1D, 0x51, 0x1D, 0x51, 0x1D, 0x53, 0x1D, 0x53, 0x1D, 0x52, 0x1D, 0x53, 0x1E, 0x54, 0x1E, 0x54, 0x1E, 0x54, 0x1F, 0x52, 0x1E, 0x53, 0x1E, 0x55, 0x1F, 0x55, 0x1E, 0x56, 0x1F, 0x53, 0x1F, 0x4E, 0x1E, 0x49, 0x1C, 0x41, 0x1B, 0x3C, 0x19, 0x3F, 0x1A, 0x47, 0x1C, 0x49, 0x1C, 0x40, 0x1A, 0x32, 0x16, 0x23, 0x13, 0x1C, 0x11, 0x1A, 0x10, 0x18, 0x10, 0x16, 0x0F, 0x16, 0x11, 0x1B, 0x19, 0x26, 0x27, 0x34, 0x36, 0x3D, 0x40, 0x40, 0x44, 0x43, 0x47, 0x45, 0x47, 0x47, 0x4A, 0x4B, 0x4D, 0x4D, 0x4E, 0x4D, 0x4F, 0x4C, 0x4F, 0x4B, 0x4F, 0x4C, 0x4F, 0x4D, 0x4F, 0x4D, 0x50, 0x4D, 0x4F, 0x4D, 0x50, 0x4D, 0x51, 0x4D, 0x51, 0x4E, 0x51, 0x4F, 0x51, 0x4F, 0x51, 0x4F, 0x52, 0x4F, 0x52, 0x50, 0x53, 0x51, 0x53, 0x51, 0x53, 0x51, 0x54, 0x52, 0x54, 0x51, 0x53, 0x51, 0x54, 0x51, 0x53, 0x53, 0x53, 0x51, 0x54, 0x50, 0x53, 0x50, 0x53, 0x51, 0x53, 0x4F, 0x50, 0x4A, 0x49, 0x40, 0x3C, 0x32, 0x2B, 0x23, 0x1B, 0x1B, 0x14, 0x19, 0x12, 0x18, 0x11, 0x17, 0x11, 0x18, 0x10, 0x18, 0x11, 0x19, 0x11, 0x1C, 0x12, 0x26, 0x16, 0x3E, 0x1B, 0x4C, 0x1E, 0x54, 0x1F, 0x50, 0x1E, 0x3F, 0x1B, 0x3B, 0x1C, 0x4C, 0x1F, 0x54, 0x20, 0x5A, 0x21, 0x5D, 0x22, 0x60, 0x23, 0x61, 0x23, 0x61, 0x23, 0x61, 0x23, 0x62, 0x23, 0x62, 0x23, 0x60, 0x22, 0x61, 0x22, 0x61, 0x22, 0x60, 0x22, 0x60, 0x21, 0x62, 0x22, 0x62, 0x22, 0x63, 0x23, 0x63, 0x23, 0x60, 0x22, 0x62, 0x23, 0x60, 0x22, 0x61, 0x22, 0x61, 0x22, 0x61, 0x22, 0x5F, 0x21, 0x5E, 0x21, 0x5D, 0x21, 0x5E, 0x20, 0x5E, 0x21, 0x5E, 0x20, 0x5C, 0x20, 0x5D, 0x20, 0x5E, 0x20, 0x5D, 0x20, 0x5D, 0x20, 0x5C, 0x20, 0x5D, 0x20, 0x5B, 0x20, 0x5B, 0x20, 0x5B, 0x20, 0x5D, 0x20, 0x5D, 0x20, 0x5C, 0x20, 0x5D, 0x20, 0x5E, 0x21, 0x5E, 0x21, 0x5F, 0x21, 0x5C, 0x20, 0x5C, 0x20, 0x5E, 0x21, 0x5C, 0x20, 0x5E, 0x21, 0x5F, 0x22, 0x5D, 0x22, 0x5E, 0x21, 0x5C, 0x20, 0x5D, 0x20, 0x5F, 0x21, 0x5F, 0x21, 0x5E, 0x21, 0x5E, 0x21, 0x5C, 0x20, 0x5C, 0x20, 0x5F, 0x21, 0x5E, 0x21, 0x5B, 0x20, 0x5A, 0x1F, 0x5A, 0x20, 0x5C, 0x1F, 0x58, 0x20, 0x58, 0x1F, 0x5A, 0x20, 0x5B, 0x20, 0x5C, 0x20, 0x5C, 0x20, 0x5C, 0x20, 0x5E, 0x21, 0x5E, 0x21, 0x5D, 0x20, 0x5C, 0x20, 0x5B, 0x20, 0x5B, 0x20, 0x5E, 0x21, 0x5E, 0x22, 0x5E, 0x21, 0x5D, 0x20, 0x5B, 0x20, 0x5B, 0x20, 0x5A, 0x20, 0x5B, 0x20, 0x5D, 0x21, 0x5B, 0x21, 0x5C, 0x21, 0x5B, 0x20, 0x59, 0x1F, 0x59, 0x1F, 0x57, 0x1F, 0x56, 0x1E, 0x56, 0x1E, 0x58, 0x1F, 0x56, 0x21, 0x53, 0x21, 0x4F, 0x21, 0x4F, 0x20, 0x4F, 0x20, 0x55, 0x20, 0x57, 0x20, 0x57, 0x20, 0x59, 0x20, 0x58, 0x20, 0x56, 0x1F, 0x58, 0x1F, 0x57, 0x1F, 0x58, 0x1F, 0x58, 0x20, 0x59, 0x21, 0x5A, 0x20, 0x56, 0x1F, 0x57, 0x1F, 0x57, 0x1F, 0x58, 0x1F, 0x58, 0x1F, 0x56, 0x1F, 0x55, 0x1F, 0x57, 0x20, 0x56, 0x1F, 0x57, 0x20, 0x56, 0x1F, 0x56, 0x1F, 0x53, 0x1D, 0x52, 0x1D, 0x51, 0x1D, 0x52, 0x1D, 0x53, 0x1E, 0x55, 0x1F, 0x54, 0x1F, 0x54, 0x1E, 0x52, 0x1D, 0x51, 0x1E, 0x54, 0x1F, 0x53, 0x1F, 0x52, 0x1E, 0x55, 0x1E, 0x55, 0x1F, 0x54, 0x1E, 0x52, 0x1E, 0x52, 0x1D, 0x53, 0x1E, 0x53, 0x1E, 0x53, 0x1E, 0x53, 0x1F, 0x55, 0x1E, 0x53, 0x1E, 0x55, 0x1E, 0x51, 0x1D, 0x51, 0x1E, 0x52, 0x1E, 0x51, 0x1D, 0x51, 0x1D, 0x53, 0x1E, 0x53, 0x1E, 0x52, 0x1E, 0x54, 0x1F, 0x54, 0x1E, 0x53, 0x1E, 0x53, 0x1E, 0x4B, 0x1C, 0x39, 0x1A, 0x29, 0x17, 0x2A, 0x18, 0x28, 0x18, 0x26, 0x17, 0x25, 0x17, 0x25, 0x15, 0x23, 0x15, 0x27, 0x16, 0x21, 0x15, 0x26, 0x16, 0x26, 0x17, 0x25, 0x16, 0x21, 0x14, 0x22, 0x15, 0x23, 0x15, 0x1F, 0x13, 0x26, 0x16, 0x20, 0x14, 0x25, 0x16, 0x22, 0x14, 0x20, 0x13, 0x22, 0x14, 0x21, 0x14, 0x22, 0x14, 0x21, 0x15, 0x24, 0x15, 0x22, 0x15, 0x25, 0x15, 0x20, 0x14, 0x23, 0x15, 0x26, 0x16, 0x25, 0x15, 0x21, 0x14, 0x24, 0x15, 0x29, 0x17, 0x27, 0x16, 0x2C, 0x18, 0x23, 0x15, 0x2B, 0x17, 0x2B, 0x18, 0x23, 0x13, 0x22, 0x15
    },

    {
        0x56, 0x4C, 0x56, 0x4B, 0x56, 0x4B, 0x53, 0x4A, 0x55, 0x4A, 0x55, 0x4B, 0x55, 0x4B, 0x56, 0x4B, 0x56, 0x4A, 0x56, 0x4A, 0x57, 0x4C, 0x58, 0x4B, 0x57, 0x4B, 0x58, 0x4C, 0x59, 0x4C, 0x5A, 0x4D, 0x5B, 0x4E, 0x5C, 0x4E, 0x5C, 0x50, 0x5C, 0x4E, 0x5B, 0x4E, 0x5C, 0x4E, 0x5B, 0x4F, 0x5C, 0x50, 0x5B, 0x4F, 0x5B, 0x4E, 0x5B, 0x4F, 0x5C, 0x51, 0x5C, 0x51, 0x5D, 0x51, 0x5C, 0x4F, 0x5C, 0x50, 0x5E, 0x51, 0x5D, 0x52, 0x5E, 0x52, 0x59, 0x4F, 0x54, 0x4A, 0x4E, 0x43, 0x44, 0x3B, 0x3C, 0x38, 0x41, 0x3E, 0x4B, 0x46, 0x4B, 0x44, 0x41, 0x38, 0x2F, 0x29, 0x20, 0x1F, 0x19, 0x19, 0x16, 0x17, 0x14, 0x16, 0x12, 0x15, 0x13, 0x16, 0x16, 0x1B, 0x1F, 0x27, 0x2B, 0x35, 0x32, 0x3B, 0x36, 0x3F, 0x38, 0x40, 0x3A, 0x42, 0x3B, 0x44, 0x3E, 0x48, 0x40, 0x4A, 0x40, 0x48, 0x40, 0x48, 0x40, 0x47, 0x3F, 0x49, 0x40, 0x49, 0x41, 0x4B, 0x41, 0x49, 0x41, 0x49, 0x41, 0x4A, 0x41, 0x4B, 0x42, 0x4B, 0x41, 0x4A, 0x41, 0x4B, 0x42, 0x4B, 0x42, 0x4B, 0x43, 0x4C, 0x43, 0x4E, 0x43, 0x4D, 0x43, 0x4D, 0x44, 0x4E, 0x43, 0x4D, 0x44, 0x4D, 0x43, 0x4D, 0x44, 0x4E, 0x44, 0x4D, 0x43, 0x4C, 0x43, 0x4C, 0x43, 0x4C, 0x40, 0x4A, 0x3C, 0x44, 0x34, 0x38, 0x28, 0x2A, 0x1C, 0x1E, 0x16, 0x19, 0x15, 0x18, 0x14, 0x17, 0x13, 0x16, 0x13, 0x16, 0x13, 0x16, 0x15, 0x17, 0x17, 0x19, 0x1E, 0x21, 0x36, 0x39, 0x4A, 0x48, 0x54, 0x4E, 0x56, 0x4E, 0x45, 0x3D, 0x3B, 0x37, 0x49, 0x45, 0x57, 0x4F, 0x5E, 0x54, 0x62, 0x58, 0x66, 0x5A, 0x68, 0x5C, 0x6A, 0x5D, 0x6A, 0x5C, 0x6C, 0x5D, 0x6C, 0x5C, 0x6A, 0x5C, 0x6B, 0x5C, 0x6A, 0x5C, 0x6B, 0x5A, 0x69, 0x5B, 0x6B, 0x5D, 0x6C, 0x5B, 0x6C, 0x5D, 0x6D, 0x5E, 0x6A, 0x5B, 0x6B, 0x5D, 0x6A, 0x5A, 0x6B, 0x5C, 0x6A, 0x5B, 0x69, 0x5A, 0x69, 0x5A, 0x67, 0x58, 0x67, 0x59, 0x66, 0x58, 0x68, 0x5A, 0x67, 0x58, 0x65, 0x57, 0x65, 0x58, 0x65, 0x57, 0x66, 0x57, 0x66, 0x58, 0x65, 0x56, 0x65, 0x56, 0x62, 0x55, 0x63, 0x55, 0x64, 0x56, 0x66, 0x59, 0x66, 0x57, 0x67, 0x57, 0x67, 0x57, 0x67, 0x5A, 0x67, 0x59, 0x68, 0x59, 0x65, 0x57, 0x65, 0x57, 0x65, 0x57, 0x62, 0x57, 0x66, 0x58, 0x66, 0x5A, 0x66, 0x59, 0x66, 0x58, 0x65, 0x57, 0x65, 0x58, 0x68, 0x59, 0x69, 0x5A, 0x69, 0x59, 0x67, 0x57, 0x64, 0x56, 0x65, 0x56, 0x67, 0x5A, 0x67, 0x58, 0x63, 0x55, 0x63, 0x56, 0x63, 0x54, 0x62, 0x53, 0x62, 0x55, 0x60, 0x52, 0x63, 0x55, 0x63, 0x55, 0x64, 0x55, 0x64, 0x57, 0x64, 0x56, 0x67, 0x58, 0x67, 0x59, 0x65, 0x57, 0x65, 0x57, 0x64, 0x55, 0x64, 0x56, 0x66, 0x59, 0x65, 0x59, 0x66, 0x58, 0x65, 0x57, 0x64, 0x56, 0x63, 0x56, 0x63, 0x54, 0x64, 0x56, 0x64, 0x57, 0x65, 0x56, 0x64, 0x57, 0x64, 0x57, 0x62, 0x55, 0x62, 0x55, 0x60, 0x54, 0x5E, 0x50, 0x5D, 0x51, 0x5D, 0x51, 0x59, 0x50, 0x53, 0x4B, 0x4D, 0x48, 0x4C, 0x48, 0x4F, 0x49, 0x57, 0x4F, 0x5C, 0x52, 0x5F, 0x54, 0x61, 0x53, 0x60, 0x53, 0x5E, 0x52, 0x61, 0x54, 0x60, 0x53, 0x61, 0x54, 0x60, 0x54, 0x5F, 0x54, 0x60, 0x54, 0x5E, 0x53, 0x60, 0x54, 0x60, 0x52, 0x5F, 0x53, 0x5F, 0x52, 0x5E, 0x52, 0x5D, 0x52, 0x5F, 0x53, 0x5E, 0x50, 0x5E, 0x53, 0x5E, 0x51, 0x5E, 0x52, 0x5C, 0x50, 0x5A, 0x4D, 0x5C, 0x50, 0x5B, 0x4F, 0x5A, 0x50, 0x5C, 0x50, 0x5B, 0x4F, 0x5C, 0x4F, 0x59, 0x4E, 0x59, 0x4D, 0x5B, 0x50, 0x5B, 0x4F, 0x59, 0x4E, 0x5D, 0x51, 0x5C, 0x4F, 0x5C, 0x4F, 0x5A, 0x4E, 0x59, 0x4E, 0x5C, 0x4F, 0x5B, 0x4F, 0x5A, 0x4F, 0x5D, 0x51, 0x5D, 0x51, 0x5B, 0x50, 0x5D, 0x4F, 0x5B, 0x4E, 0x5B, 0x4E, 0x5B, 0x50, 0x5B, 0x4F, 0x5A, 0x4E, 0x5C, 0x4F, 0x5C, 0x4F, 0x59, 0x4F, 0x5C, 0x50, 0x5C, 0x50, 0x5A, 0x4F, 0x5A, 0x4E, 0x4F, 0x43, 0x37, 0x33, 0x28, 0x27, 0x27, 0x29, 0x24, 0x26, 0x22, 0x23, 0x21, 0x24, 0x1F, 0x1F, 0x20, 0x24, 0x22, 0x22, 0x1E, 0x22, 0x21, 0x22, 0x21, 0x25, 0x21, 0x24, 0x1F, 0x20, 0x20, 0x23, 0x1F, 0x21, 0x1D, 0x1F, 0x22, 0x23, 0x1D, 0x1F, 0x21, 0x26, 0x1E, 0x1F, 0x1D, 0x1F, 0x1F, 0x20, 0x1F, 0x21, 0x1F, 0x21, 0x20, 0x23, 0x21, 0x22, 0x20, 0x24, 0x21, 0x24, 0x1E, 0x1F, 0x22, 0x23, 0x23, 0x26, 0x22, 0x24, 0x20, 0x20, 0x22, 0x25, 0x26, 0x29, 0x23, 0x27, 0x26, 0x28, 0x1F, 0x23, 0x26, 0x29, 0x24, 0x26, 0x1F, 0x1E, 0x1F, 0x22
    },

    {
        0x4E, 0x1C, 0x4E, 0x1B, 0x4E, 0x1B, 0x4E, 0x1B, 0x4D, 0x1B, 0x4E, 0x1B, 0x4D, 0x1B, 0x4D, 0x1B, 0x4E, 0x1B, 0x4F, 0x1C, 0x4E, 0x1C, 0x4F, 0x1C, 0x4F, 0x1C, 0x4F, 0x1C, 0x50, 0x1C, 0x4F, 0x1C, 0x51, 0x1C, 0x51, 0x1D, 0x52, 0x1D, 0x51, 0x1C, 0x51, 0x1C, 0x51, 0x1C, 0x52, 0x1D, 0x53, 0x1D, 0x53, 0x1D, 0x52, 0x1D, 0x52, 0x1E, 0x53, 0x1E, 0x54, 0x1E, 0x54, 0x1F, 0x54, 0x1E, 0x54, 0x1E, 0x54, 0x1E, 0x55, 0x1F, 0x54, 0x1F, 0x50, 0x1E, 0x4A, 0x1D, 0x43, 0x1B, 0x3C, 0x1A, 0x3D, 0x1A, 0x45, 0x1C, 0x48, 0x1C, 0x42, 0x1A, 0x34, 0x17, 0x25, 0x13, 0x1E, 0x11, 0x1A, 0x10, 0x18, 0x0F, 0x16, 0x0F, 0x15, 0x0F, 0x15, 0x10, 0x18, 0x15, 0x25, 0x27, 0x35, 0x37, 0x3C, 0x3F, 0x41, 0x43, 0x43, 0x47, 0x45, 0x48, 0x47, 0x4A, 0x4A, 0x4C, 0x4D, 0x50, 0x4D, 0x4E, 0x4C, 0x4F, 0x4B, 0x50, 0x4C, 0x4F, 0x4D, 0x4F, 0x4E, 0x51, 0x4E, 0x50, 0x4D, 0x50, 0x4D, 0x51, 0x4E, 0x52, 0x4E, 0x51, 0x4E, 0x51, 0x4F, 0x50, 0x4F, 0x52, 0x4E, 0x51, 0x50, 0x54, 0x52, 0x53, 0x52, 0x54, 0x52, 0x55, 0x52, 0x56, 0x53, 0x55, 0x51, 0x54, 0x52, 0x54, 0x51, 0x54, 0x51, 0x53, 0x52, 0x53, 0x51, 0x53, 0x50, 0x51, 0x4C, 0x4C, 0x45, 0x40, 0x35, 0x2F, 0x26, 0x1F, 0x1E, 0x17, 0x1A, 0x14, 0x19, 0x12, 0x18, 0x12, 0x18, 0x11, 0x17, 0x11, 0x17, 0x10, 0x17, 0x10, 0x18, 0x10, 0x1C, 0x11, 0x25, 0x16, 0x3E, 0x1B, 0x4E, 0x1F, 0x54, 0x20, 0x52, 0x1F, 0x40, 0x1B, 0x3A, 0x1C, 0x4A, 0x1F, 0x57, 0x20, 0x5B, 0x22, 0x5D, 0x22, 0x5F, 0x23, 0x62, 0x23, 0x61, 0x22, 0x61, 0x22, 0x61, 0x22, 0x60, 0x22, 0x63, 0x21, 0x62, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x61, 0x22, 0x61, 0x22, 0x60, 0x22, 0x62, 0x22, 0x61, 0x22, 0x5E, 0x21, 0x61, 0x22, 0x5F, 0x21, 0x60, 0x21, 0x5E, 0x21, 0x5E, 0x21, 0x5E, 0x21, 0x5E, 0x20, 0x5E, 0x20, 0x5F, 0x21, 0x5D, 0x20, 0x5C, 0x20, 0x5B, 0x1F, 0x5C, 0x21, 0x5C, 0x20, 0x5D, 0x20, 0x5D, 0x20, 0x5D, 0x21, 0x5B, 0x20, 0x5B, 0x20, 0x5C, 0x20, 0x5E, 0x20, 0x5E, 0x20, 0x5C, 0x21, 0x5E, 0x20, 0x5E, 0x21, 0x5E, 0x20, 0x5C, 0x20, 0x5B, 0x20, 0x5C, 0x20, 0x5D, 0x20, 0x5D, 0x21, 0x5E, 0x21, 0x5E, 0x21, 0x5E, 0x21, 0x5D, 0x20, 0x5D, 0x21, 0x5B, 0x20, 0x5B, 0x20, 0x5D, 0x20, 0x5E, 0x21, 0x5D, 0x20, 0x5B, 0x1F, 0x5B, 0x20, 0x5F, 0x20, 0x5E, 0x21, 0x5A, 0x20, 0x5C, 0x1F, 0x59, 0x1F, 0x5A, 0x1F, 0x59, 0x20, 0x5A, 0x1F, 0x58, 0x1F, 0x58, 0x1F, 0x5B, 0x20, 0x5C, 0x20, 0x5B, 0x20, 0x5B, 0x20, 0x5E, 0x21, 0x5B, 0x20, 0x5A, 0x1F, 0x5D, 0x20, 0x5B, 0x20, 0x5C, 0x20, 0x5D, 0x21, 0x5D, 0x20, 0x5C, 0x20, 0x5A, 0x1F, 0x59, 0x1F, 0x5B, 0x20, 0x5A, 0x20, 0x5B, 0x1F, 0x5C, 0x21, 0x5D, 0x21, 0x5B, 0x20, 0x5B, 0x20, 0x59, 0x1F, 0x58, 0x1F, 0x57, 0x1F, 0x57, 0x1E, 0x53, 0x1F, 0x4E, 0x20, 0x49, 0x21, 0x48, 0x22, 0x48, 0x22, 0x49, 0x22, 0x4B, 0x1F, 0x52, 0x1F, 0x56, 0x1F, 0x57, 0x1F, 0x57, 0x1F, 0x56, 0x1F, 0x59, 0x20, 0x59, 0x20, 0x58, 0x20, 0x5A, 0x21, 0x58, 0x20, 0x59, 0x21, 0x59, 0x1F, 0x59, 0x20, 0x57, 0x1F, 0x58, 0x1F, 0x58, 0x1F, 0x5A, 0x20, 0x5A, 0x21, 0x57, 0x1F, 0x58, 0x1F, 0x56, 0x20, 0x56, 0x20, 0x55, 0x1E, 0x55, 0x1E, 0x52, 0x1E, 0x55, 0x1E, 0x54, 0x1E, 0x54, 0x1F, 0x56, 0x1F, 0x53, 0x1E, 0x53, 0x1E, 0x52, 0x1E, 0x52, 0x1E, 0x51, 0x1E, 0x53, 0x1E, 0x52, 0x1D, 0x53, 0x1E, 0x53, 0x1E, 0x53, 0x1D, 0x54, 0x1E, 0x53, 0x1E, 0x53, 0x1D, 0x53, 0x1E, 0x53, 0x1E, 0x51, 0x1D, 0x53, 0x1E, 0x51, 0x1E, 0x53, 0x1E, 0x53, 0x1E, 0x53, 0x1E, 0x55, 0x1F, 0x54, 0x1F, 0x53, 0x1E, 0x52, 0x1E, 0x55, 0x1F, 0x54, 0x1E, 0x52, 0x1E, 0x51, 0x1D, 0x51, 0x1D, 0x4E, 0x1D, 0x48, 0x1B, 0x32, 0x18, 0x27, 0x16, 0x25, 0x16, 0x24, 0x15, 0x24, 0x16, 0x24, 0x16, 0x23, 0x14, 0x27, 0x18, 0x2B, 0x19, 0x28, 0x17, 0x2C, 0x18, 0x27, 0x17, 0x2C, 0x18, 0x2B, 0x18, 0x23, 0x15, 0x28, 0x17, 0x23, 0x15, 0x29, 0x17, 0x27, 0x17, 0x26, 0x16, 0x23, 0x14, 0x22, 0x15, 0x29, 0x17, 0x23, 0x15, 0x2A, 0x17, 0x26, 0x15, 0x2C, 0x19, 0x23, 0x14, 0x2A, 0x17, 0x22, 0x14, 0x2D, 0x18, 0x23, 0x14, 0x26, 0x16, 0x22, 0x14, 0x2A, 0x17, 0x28, 0x16, 0x22, 0x15, 0x25, 0x15, 0x22, 0x14, 0x25, 0x15, 0x20, 0x13, 0x1D, 0x12, 0x22, 0x14
    },

    {
        0x55, 0x4C, 0x54, 0x4B, 0x55, 0x4B, 0x55, 0x4A, 0x54, 0x4B, 0x55, 0x4B, 0x55, 0x4A, 0x55, 0x4A, 0x56, 0x4C, 0x56, 0x4B, 0x57, 0x4C, 0x58, 0x4B, 0x57, 0x4C, 0x58, 0x4C, 0x5A, 0x4E, 0x5B, 0x4E, 0x5A, 0x4D, 0x5B, 0x4E, 0x5B, 0x4E, 0x5A, 0x4D, 0x5A, 0x4E, 0x5B, 0x4E, 0x5B, 0x4F, 0x5C, 0x4F, 0x5B, 0x4F, 0x5B, 0x4F, 0x5B, 0x4E, 0x5C, 0x50, 0x5D, 0x50, 0x5E, 0x51, 0x5D, 0x50, 0x5D, 0x50, 0x5D, 0x51, 0x5B, 0x51, 0x5A, 0x4F, 0x54, 0x4A, 0x4E, 0x45, 0x47, 0x3E, 0x3E, 0x38, 0x40, 0x3C, 0x48, 0x45, 0x4A, 0x43, 0x41, 0x3A, 0x31, 0x2B, 0x22, 0x20, 0x1A, 0x1A, 0x17, 0x18, 0x14, 0x16, 0x13, 0x16, 0x12, 0x14, 0x12, 0x15, 0x14, 0x18, 0x1D, 0x25, 0x2A, 0x33, 0x32, 0x3B, 0x36, 0x3E, 0x37, 0x41, 0x3A, 0x42, 0x3B, 0x44, 0x3D, 0x45, 0x3F, 0x4A, 0x40, 0x49, 0x3F, 0x49, 0x40, 0x48, 0x40, 0x49, 0x40, 0x49, 0x41, 0x4A, 0x40, 0x4A, 0x40, 0x49, 0x41, 0x49, 0x42, 0x4B, 0x42, 0x4A, 0x42, 0x4B, 0x42, 0x4B, 0x42, 0x4B, 0x42, 0x4B, 0x43, 0x4C, 0x43, 0x4E, 0x45, 0x4E, 0x43, 0x4E, 0x45, 0x4F, 0x44, 0x4E, 0x43, 0x4D, 0x44, 0x4D, 0x44, 0x4E, 0x44, 0x4D, 0x43, 0x4D, 0x42, 0x4C, 0x41, 0x4A, 0x3E, 0x46, 0x37, 0x3C, 0x2B, 0x2D, 0x1E, 0x21, 0x18, 0x1B, 0x15, 0x19, 0x14, 0x18, 0x14, 0x17, 0x13, 0x17, 0x13, 0x16, 0x12, 0x16, 0x13, 0x16, 0x14, 0x17, 0x17, 0x19, 0x1D, 0x20, 0x35, 0x37, 0x4B, 0x49, 0x56, 0x50, 0x57, 0x4F, 0x46, 0x3E, 0x3A, 0x36, 0x47, 0x44, 0x57, 0x51, 0x5F, 0x56, 0x62, 0x58, 0x66, 0x5A, 0x68, 0x5B, 0x68, 0x5A, 0x68, 0x5A, 0x6A, 0x5C, 0x69, 0x5B, 0x6B, 0x5C, 0x69, 0x5B, 0x68, 0x5A, 0x68, 0x5B, 0x69, 0x5C, 0x6B, 0x5E, 0x6A, 0x5A, 0x69, 0x5C, 0x6A, 0x5C, 0x68, 0x5A, 0x6A, 0x5A, 0x69, 0x5A, 0x6B, 0x5A, 0x68, 0x59, 0x67, 0x59, 0x68, 0x59, 0x68, 0x5A, 0x66, 0x58, 0x68, 0x5A, 0x66, 0x57, 0x65, 0x56, 0x64, 0x56, 0x66, 0x57, 0x65, 0x58, 0x67, 0x59, 0x67, 0x58, 0x65, 0x57, 0x64, 0x56, 0x64, 0x56, 0x63, 0x56, 0x67, 0x58, 0x67, 0x59, 0x66, 0x58, 0x67, 0x58, 0x66, 0x58, 0x66, 0x57, 0x66, 0x58, 0x66, 0x57, 0x65, 0x57, 0x64, 0x57, 0x65, 0x58, 0x65, 0x5A, 0x68, 0x59, 0x68, 0x5A, 0x67, 0x58, 0x67, 0x57, 0x64, 0x55, 0x66, 0x56, 0x66, 0x58, 0x67, 0x58, 0x67, 0x58, 0x66, 0x57, 0x66, 0x56, 0x68, 0x59, 0x67, 0x57, 0x62, 0x55, 0x65, 0x55, 0x64, 0x54, 0x63, 0x54, 0x62, 0x54, 0x62, 0x55, 0x63, 0x55, 0x62, 0x56, 0x65, 0x58, 0x64, 0x55, 0x63, 0x55, 0x64, 0x56, 0x65, 0x57, 0x64, 0x56, 0x64, 0x55, 0x65, 0x57, 0x64, 0x56, 0x64, 0x58, 0x66, 0x57, 0x65, 0x58, 0x66, 0x57, 0x63, 0x53, 0x61, 0x55, 0x62, 0x56, 0x62, 0x55, 0x61, 0x55, 0x64, 0x58, 0x65, 0x57, 0x62, 0x56, 0x63, 0x55, 0x61, 0x54, 0x61, 0x53, 0x60, 0x52, 0x5E, 0x52, 0x55, 0x4C, 0x4D, 0x47, 0x45, 0x43, 0x44, 0x44, 0x44, 0x44, 0x45, 0x45, 0x48, 0x46, 0x54, 0x4D, 0x5C, 0x52, 0x5E, 0x52, 0x60, 0x53, 0x5F, 0x53, 0x61, 0x54, 0x61, 0x54, 0x61, 0x54, 0x62, 0x55, 0x5E, 0x53, 0x61, 0x55, 0x60, 0x54, 0x61, 0x54, 0x61, 0x53, 0x61, 0x54, 0x62, 0x55, 0x62, 0x57, 0x62, 0x54, 0x5F, 0x52, 0x5F, 0x53, 0x5F, 0x52, 0x5F, 0x53, 0x5E, 0x51, 0x5E, 0x50, 0x5B, 0x4F, 0x5B, 0x50, 0x5C, 0x50, 0x5B, 0x50, 0x5C, 0x50, 0x5A, 0x4F, 0x5A, 0x4E, 0x5B, 0x50, 0x5A, 0x4E, 0x59, 0x4E, 0x5B, 0x4E, 0x5A, 0x4E, 0x5C, 0x51, 0x5B, 0x4F, 0x5B, 0x4F, 0x5D, 0x50, 0x5B, 0x4F, 0x5B, 0x4F, 0x5C, 0x4F, 0x59, 0x4E, 0x59, 0x4F, 0x5A, 0x4F, 0x59, 0x4E, 0x5B, 0x4F, 0x5B, 0x4F, 0x5D, 0x51, 0x5E, 0x52, 0x5C, 0x50, 0x5A, 0x50, 0x5A, 0x4E, 0x5D, 0x51, 0x5C, 0x4F, 0x5B, 0x4E, 0x5A, 0x4D, 0x59, 0x4C, 0x57, 0x4C, 0x4E, 0x41, 0x31, 0x2B, 0x26, 0x24, 0x22, 0x22, 0x20, 0x21, 0x21, 0x24, 0x22, 0x25, 0x21, 0x23, 0x24, 0x28, 0x28, 0x2B, 0x24, 0x26, 0x26, 0x28, 0x24, 0x27, 0x29, 0x2A, 0x25, 0x27, 0x20, 0x21, 0x24, 0x26, 0x1F, 0x22, 0x26, 0x28, 0x23, 0x24, 0x22, 0x25, 0x1F, 0x20, 0x20, 0x25, 0x25, 0x26, 0x20, 0x23, 0x25, 0x26, 0x20, 0x22, 0x26, 0x28, 0x1E, 0x1F, 0x26, 0x27, 0x20, 0x21, 0x27, 0x29, 0x1F, 0x1F, 0x22, 0x24, 0x1F, 0x20, 0x26, 0x29, 0x22, 0x22, 0x1F, 0x21, 0x21, 0x21, 0x1F, 0x21, 0x1F, 0x21, 0x1C, 0x1E, 0x1B, 0x1C, 0x20, 0x21
    },

    {
        0x4E, 0x1C, 0x4E, 0x1C, 0x4F, 0x1C, 0x4F, 0x1B, 0x4E, 0x1B, 0x4E, 0x1B, 0x4F, 0x1C, 0x4E, 0x1C, 0x50, 0x1C, 0x50, 0x1C, 0x50, 0x1C, 0x4F, 0x1C, 0x50, 0x1C, 0x4F, 0x1C, 0x50, 0x1C, 0x50, 0x1C, 0x51, 0x1C, 0x51, 0x1C, 0x51, 0x1D, 0x51, 0x1D, 0x51, 0x1D, 0x51, 0x1D, 0x53, 0x1D, 0x52, 0x1D, 0x53, 0x1E, 0x54, 0x1E, 0x53, 0x1E, 0x54, 0x1E, 0x54, 0x1E, 0x55, 0x1F, 0x54, 0x1F, 0x55, 0x1F, 0x54, 0x1F, 0x54, 0x1F, 0x50, 0x1F, 0x4A, 0x1D, 0x43, 0x1B, 0x3D, 0x1B, 0x3D, 0x1A, 0x45, 0x1C, 0x47, 0x1C, 0x41, 0x1A, 0x34, 0x17, 0x26, 0x13, 0x1D, 0x11, 0x1A, 0x10, 0x18, 0x0F, 0x16, 0x0F, 0x16, 0x0F, 0x14, 0x0F, 0x15, 0x0F, 0x15, 0x10, 0x1B, 0x19, 0x29, 0x2C, 0x38, 0x3B, 0x40, 0x43, 0x43, 0x47, 0x45, 0x49, 0x46, 0x4B, 0x48, 0x4C, 0x4A, 0x4D, 0x4C, 0x4E, 0x4D, 0x4E, 0x4C, 0x4F, 0x4C, 0x4F, 0x4B, 0x4F, 0x4D, 0x50, 0x4E, 0x50, 0x4D, 0x50, 0x4E, 0x51, 0x4E, 0x51, 0x4F, 0x51, 0x50, 0x52, 0x4F, 0x51, 0x4F, 0x52, 0x4F, 0x52, 0x50, 0x53, 0x51, 0x53, 0x51, 0x53, 0x52, 0x54, 0x53, 0x55, 0x52, 0x53, 0x51, 0x53, 0x51, 0x54, 0x51, 0x53, 0x52, 0x53, 0x51, 0x53, 0x50, 0x51, 0x4D, 0x4D, 0x45, 0x42, 0x38, 0x32, 0x29, 0x21, 0x20, 0x19, 0x1C, 0x16, 0x1A, 0x13, 0x19, 0x13, 0x19, 0x12, 0x19, 0x12, 0x19, 0x12, 0x17, 0x11, 0x16, 0x10, 0x18, 0x10, 0x18, 0x10, 0x1A, 0x11, 0x23, 0x15, 0x3C, 0x1C, 0x4F, 0x1F, 0x53, 0x1F, 0x53, 0x1F, 0x42, 0x1B, 0x38, 0x1B, 0x48, 0x1E, 0x56, 0x21, 0x5B, 0x21, 0x5E, 0x22, 0x5F, 0x24, 0x5F, 0x23, 0x5E, 0x22, 0x5F, 0x21, 0x61, 0x22, 0x61, 0x22, 0x61, 0x23, 0x62, 0x22, 0x5F, 0x22, 0x61, 0x22, 0x61, 0x22, 0x62, 0x21, 0x5F, 0x21, 0x60, 0x22, 0x61, 0x21, 0x60, 0x22, 0x60, 0x21, 0x60, 0x21, 0x5F, 0x21, 0x5D, 0x21, 0x5D, 0x21, 0x5D, 0x21, 0x5C, 0x20, 0x5C, 0x21, 0x5E, 0x20, 0x5C, 0x20, 0x5B, 0x1F, 0x5D, 0x20, 0x5B, 0x20, 0x5E, 0x21, 0x5C, 0x20, 0x5D, 0x21, 0x5C, 0x21, 0x5B, 0x21, 0x5C, 0x20, 0x5D, 0x20, 0x5E, 0x21, 0x5E, 0x21, 0x5E, 0x20, 0x5D, 0x20, 0x5D, 0x20, 0x5C, 0x20, 0x5D, 0x20, 0x5B, 0x1F, 0x5B, 0x20, 0x5D, 0x21, 0x5D, 0x21, 0x5F, 0x21, 0x5C, 0x20, 0x5E, 0x21, 0x5C, 0x21, 0x5C, 0x20, 0x5B, 0x20, 0x5C, 0x20, 0x5D, 0x20, 0x5D, 0x20, 0x5C, 0x21, 0x5D, 0x20, 0x5D, 0x21, 0x5C, 0x20, 0x5B, 0x20, 0x5B, 0x20, 0x59, 0x1F, 0x5A, 0x1F, 0x58, 0x1F, 0x5A, 0x20, 0x5A, 0x20, 0x5C, 0x20, 0x5D, 0x20, 0x59, 0x1F, 0x5A, 0x20, 0x5A, 0x20, 0x5C, 0x20, 0x5B, 0x20, 0x5B, 0x20, 0x5B, 0x20, 0x5A, 0x20, 0x59, 0x1F, 0x5D, 0x20, 0x5C, 0x20, 0x5D, 0x21, 0x5B, 0x20, 0x59, 0x20, 0x5D, 0x21, 0x5C, 0x22, 0x5C, 0x22, 0x5D, 0x22, 0x5A, 0x21, 0x58, 0x20, 0x57, 0x1F, 0x58, 0x1F, 0x57, 0x1F, 0x57, 0x1F, 0x56, 0x1E, 0x4D, 0x1F, 0x49, 0x22, 0x46, 0x22, 0x46, 0x22, 0x48, 0x23, 0x48, 0x22, 0x48, 0x21, 0x48, 0x1D, 0x51, 0x1E, 0x56, 0x1F, 0x58, 0x20, 0x57, 0x20, 0x59, 0x21, 0x5B, 0x21, 0x59, 0x20, 0x58, 0x20, 0x5B, 0x20, 0x59, 0x20, 0x59, 0x20, 0x5A, 0x20, 0x5A, 0x20, 0x59, 0x20, 0x5A, 0x20, 0x5C, 0x21, 0x58, 0x20, 0x57, 0x20, 0x59, 0x21, 0x59, 0x21, 0x58, 0x1F, 0x59, 0x20, 0x57, 0x1F, 0x54, 0x1E, 0x53, 0x1E, 0x53, 0x1E, 0x53, 0x1E, 0x51, 0x1D, 0x52, 0x1E, 0x55, 0x1F, 0x53, 0x1E, 0x54, 0x1F, 0x52, 0x1E, 0x54, 0x1E, 0x52, 0x1D, 0x54, 0x1E, 0x54, 0x1E, 0x52, 0x1E, 0x53, 0x1D, 0x53, 0x1D, 0x52, 0x1D, 0x52, 0x1E, 0x50, 0x1D, 0x51, 0x1D, 0x51, 0x1E, 0x52, 0x1E, 0x53, 0x1F, 0x53, 0x1E, 0x53, 0x1E, 0x54, 0x1F, 0x54, 0x1F, 0x53, 0x1E, 0x54, 0x1F, 0x53, 0x1E, 0x54, 0x1E, 0x52, 0x1D, 0x52, 0x1E, 0x51, 0x1D, 0x4E, 0x1C, 0x48, 0x1B, 0x2C, 0x17, 0x2D, 0x18, 0x25, 0x17, 0x2C, 0x18, 0x29, 0x17, 0x28, 0x18, 0x24, 0x15, 0x2C, 0x1A, 0x2C, 0x18, 0x21, 0x15, 0x27, 0x18, 0x29, 0x19, 0x2A, 0x17, 0x1F, 0x13, 0x22, 0x15, 0x25, 0x15, 0x21, 0x14, 0x26, 0x15, 0x1F, 0x13, 0x26, 0x16, 0x1F, 0x13, 0x26, 0x16, 0x25, 0x15, 0x23, 0x15, 0x25, 0x15, 0x21, 0x14, 0x24, 0x15, 0x1E, 0x13, 0x24, 0x14, 0x21, 0x15, 0x26, 0x16, 0x1F, 0x14, 0x23, 0x15, 0x20, 0x15, 0x23, 0x15, 0x21, 0x14, 0x21, 0x15, 0x23, 0x15, 0x26, 0x16, 0x21, 0x14, 0x26, 0x17, 0x23, 0x15, 0x22, 0x15
    },

    {
        0x54, 0x4B, 0x55, 0x4B, 0x57, 0x4C, 0x56, 0x4B, 0x56, 0x4B, 0x56, 0x4B, 0x57, 0x4B, 0x56, 0x4B, 0x57, 0x4C, 0x59, 0x4D, 0x58, 0x4D, 0x58, 0x4C, 0x58, 0x4C, 0x58, 0x4C, 0x59, 0x4D, 0x5A, 0x4D, 0x5A, 0x4D, 0x5A, 0x4F, 0x5B, 0x4E, 0x59, 0x4D, 0x59, 0x4E, 0x5A, 0x4F, 0x5B, 0x4E, 0x5A, 0x4F, 0x5C, 0x50, 0x5C, 0x51, 0x5E, 0x50, 0x5C, 0x50, 0x5D, 0x51, 0x5D, 0x52, 0x5D, 0x52, 0x5E, 0x51, 0x5B, 0x50, 0x5A, 0x4F, 0x55, 0x4B, 0x4E, 0x45, 0x46, 0x3C, 0x3E, 0x39, 0x40, 0x3D, 0x49, 0x43, 0x49, 0x42, 0x42, 0x3A, 0x32, 0x2D, 0x22, 0x20, 0x1A, 0x1A, 0x17, 0x18, 0x15, 0x17, 0x13, 0x15, 0x12, 0x15, 0x11, 0x14, 0x11, 0x14, 0x12, 0x15, 0x14, 0x19, 0x1F, 0x27, 0x2B, 0x35, 0x33, 0x3D, 0x38, 0x41, 0x3A, 0x43, 0x3B, 0x44, 0x3D, 0x46, 0x3F, 0x48, 0x3F, 0x48, 0x40, 0x49, 0x40, 0x49, 0x3F, 0x48, 0x40, 0x49, 0x41, 0x49, 0x41, 0x4A, 0x41, 0x4A, 0x41, 0x4A, 0x42, 0x4B, 0x42, 0x4B, 0x42, 0x4A, 0x42, 0x4B, 0x43, 0x4A, 0x42, 0x4B, 0x43, 0x4D, 0x45, 0x4D, 0x44, 0x4E, 0x45, 0x4F, 0x45, 0x4F, 0x45, 0x4E, 0x44, 0x4E, 0x43, 0x4D, 0x43, 0x4C, 0x43, 0x4D, 0x43, 0x4C, 0x40, 0x4A, 0x3D, 0x46, 0x38, 0x3D, 0x2D, 0x30, 0x20, 0x23, 0x1A, 0x1D, 0x17, 0x1A, 0x15, 0x18, 0x15, 0x18, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x13, 0x16, 0x12, 0x15, 0x13, 0x16, 0x14, 0x17, 0x17, 0x18, 0x1C, 0x1F, 0x32, 0x36, 0x4B, 0x4A, 0x55, 0x4F, 0x57, 0x4F, 0x49, 0x41, 0x3A, 0x35, 0x46, 0x42, 0x57, 0x50, 0x5F, 0x55, 0x64, 0x5A, 0x65, 0x5A, 0x67, 0x5A, 0x66, 0x5A, 0x68, 0x5B, 0x6A, 0x5B, 0x6B, 0x5B, 0x6A, 0x5C, 0x6A, 0x5C, 0x67, 0x5A, 0x67, 0x5C, 0x6A, 0x5D, 0x6C, 0x5B, 0x69, 0x5A, 0x68, 0x5B, 0x69, 0x5C, 0x69, 0x5B, 0x6A, 0x5B, 0x6A, 0x5A, 0x69, 0x59, 0x67, 0x59, 0x66, 0x57, 0x65, 0x57, 0x65, 0x57, 0x67, 0x57, 0x66, 0x58, 0x65, 0x57, 0x65, 0x57, 0x66, 0x58, 0x65, 0x56, 0x66, 0x57, 0x65, 0x55, 0x65, 0x56, 0x63, 0x57, 0x64, 0x57, 0x65, 0x56, 0x66, 0x58, 0x66, 0x59, 0x67, 0x58, 0x68, 0x59, 0x67, 0x58, 0x68, 0x59, 0x67, 0x56, 0x65, 0x56, 0x64, 0x55, 0x64, 0x56, 0x65, 0x58, 0x66, 0x58, 0x68, 0x59, 0x66, 0x58, 0x69, 0x59, 0x66, 0x57, 0x67, 0x57, 0x66, 0x57, 0x66, 0x57, 0x66, 0x56, 0x65, 0x57, 0x66, 0x57, 0x65, 0x56, 0x67, 0x59, 0x66, 0x57, 0x64, 0x56, 0x64, 0x56, 0x63, 0x56, 0x63, 0x54, 0x63, 0x55, 0x62, 0x54, 0x62, 0x55, 0x65, 0x57, 0x66, 0x57, 0x63, 0x55, 0x64, 0x56, 0x63, 0x56, 0x63, 0x56, 0x62, 0x56, 0x64, 0x56, 0x65, 0x57, 0x64, 0x55, 0x63, 0x54, 0x64, 0x58, 0x67, 0x58, 0x66, 0x57, 0x65, 0x56, 0x63, 0x55, 0x64, 0x58, 0x63, 0x58, 0x62, 0x57, 0x61, 0x56, 0x60, 0x54, 0x60, 0x53, 0x5F, 0x53, 0x61, 0x55, 0x61, 0x52, 0x5F, 0x51, 0x5D, 0x4F, 0x4F, 0x46, 0x46, 0x45, 0x44, 0x43, 0x43, 0x43, 0x42, 0x43, 0x43, 0x43, 0x43, 0x42, 0x48, 0x44, 0x56, 0x4D, 0x5D, 0x51, 0x60, 0x54, 0x5F, 0x52, 0x62, 0x55, 0x64, 0x56, 0x62, 0x54, 0x60, 0x55, 0x63, 0x56, 0x61, 0x55, 0x62, 0x56, 0x64, 0x57, 0x64, 0x57, 0x63, 0x55, 0x64, 0x57, 0x65, 0x57, 0x61, 0x55, 0x60, 0x54, 0x63, 0x56, 0x63, 0x55, 0x61, 0x53, 0x62, 0x54, 0x60, 0x52, 0x5E, 0x4F, 0x5C, 0x50, 0x5B, 0x4E, 0x59, 0x4E, 0x59, 0x4D, 0x5B, 0x4F, 0x5D, 0x50, 0x5A, 0x4F, 0x5C, 0x50, 0x5A, 0x4D, 0x5C, 0x4E, 0x5B, 0x4E, 0x5D, 0x4F, 0x5C, 0x4F, 0x5B, 0x4E, 0x5B, 0x4D, 0x59, 0x4E, 0x5B, 0x4E, 0x5A, 0x4E, 0x58, 0x4D, 0x58, 0x4D, 0x59, 0x4E, 0x5A, 0x4F, 0x5B, 0x4F, 0x5B, 0x4F, 0x5C, 0x50, 0x5C, 0x50, 0x5C, 0x50, 0x5B, 0x51, 0x5C, 0x50, 0x5C, 0x50, 0x5A, 0x4E, 0x5A, 0x4E, 0x5C, 0x4F, 0x5A, 0x4D, 0x55, 0x4A, 0x4C, 0x3E, 0x2E, 0x2B, 0x2C, 0x2B, 0x24, 0x27, 0x28, 0x2A, 0x23, 0x23, 0x24, 0x26, 0x20, 0x21, 0x28, 0x2C, 0x24, 0x24, 0x1F, 0x22, 0x22, 0x24, 0x26, 0x2B, 0x24, 0x25, 0x1E, 0x1E, 0x20, 0x22, 0x20, 0x21, 0x1F, 0x21, 0x21, 0x21, 0x1D, 0x1E, 0x21, 0x24, 0x1C, 0x1D, 0x22, 0x23, 0x20, 0x20, 0x20, 0x22, 0x1F, 0x20, 0x1F, 0x21, 0x21, 0x21, 0x1D, 0x1F, 0x21, 0x21, 0x1E, 0x21, 0x22, 0x22, 0x1C, 0x1F, 0x20, 0x22, 0x1E, 0x21, 0x20, 0x20, 0x1F, 0x21, 0x1F, 0x22, 0x21, 0x22, 0x21, 0x23, 0x1F, 0x22, 0x23, 0x27, 0x1D, 0x20, 0x1D, 0x1F
    },

    {
        0x4E, 0x1C, 0x4D, 0x1B, 0x4E, 0x1C, 0x50, 0x1C, 0x4F, 0x1C, 0x4E, 0x1C, 0x4D, 0x1B, 0x4E, 0x1C, 0x4F, 0x1C, 0x50, 0x1C, 0x51, 0x1D, 0x50, 0x1C, 0x4E, 0x1C, 0x4F, 0x1C, 0x50, 0x1C, 0x51, 0x1C, 0x50, 0x1C, 0x52, 0x1D, 0x51, 0x1D, 0x50, 0x1C, 0x50, 0x1C, 0x51, 0x1C, 0x52, 0x1D, 0x52, 0x1D, 0x52, 0x1D, 0x53, 0x1D, 0x54, 0x1F, 0x53, 0x1E, 0x54, 0x1F, 0x55, 0x1F, 0x55, 0x1F, 0x56, 0x1F, 0x55, 0x1F, 0x53, 0x1F, 0x4D, 0x1E, 0x45, 0x1C, 0x3C, 0x1A, 0x3C, 0x1A, 0x44, 0x1C, 0x48, 0x1C, 0x42, 0x1A, 0x36, 0x17, 0x27, 0x14, 0x1E, 0x11, 0x1A, 0x10, 0x18, 0x10, 0x16, 0x0F, 0x15, 0x0F, 0x16, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x14, 0x0F, 0x16, 0x12, 0x1C, 0x1A, 0x29, 0x2B, 0x39, 0x3C, 0x41, 0x44, 0x45, 0x49, 0x47, 0x4A, 0x49, 0x4C, 0x4C, 0x4E, 0x4C, 0x4D, 0x4C, 0x4F, 0x4C, 0x50, 0x4C, 0x4F, 0x4C, 0x50, 0x4C, 0x4F, 0x4D, 0x4F, 0x4E, 0x50, 0x4E, 0x50, 0x4F, 0x51, 0x4E, 0x51, 0x4F, 0x51, 0x4F, 0x52, 0x4F, 0x51, 0x4F, 0x52, 0x50, 0x53, 0x50, 0x53, 0x51, 0x54, 0x52, 0x54, 0x53, 0x55, 0x53, 0x55, 0x51, 0x54, 0x51, 0x54, 0x51, 0x52, 0x4F, 0x52, 0x4F, 0x51, 0x4C, 0x4D, 0x46, 0x42, 0x39, 0x33, 0x2A, 0x23, 0x21, 0x1A, 0x1D, 0x17, 0x1B, 0x15, 0x1A, 0x13, 0x19, 0x13, 0x19, 0x12, 0x1A, 0x13, 0x1A, 0x12, 0x18, 0x11, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x18, 0x11, 0x1B, 0x12, 0x23, 0x15, 0x3A, 0x1B, 0x4D, 0x1F, 0x54, 0x20, 0x54, 0x20, 0x44, 0x1C, 0x38, 0x1B, 0x48, 0x1E, 0x55, 0x21, 0x5B, 0x22, 0x5D, 0x22, 0x5F, 0x22, 0x60, 0x22, 0x60, 0x22, 0x60, 0x21, 0x61, 0x22, 0x61, 0x22, 0x61, 0x22, 0x61, 0x21, 0x61, 0x21, 0x62, 0x22, 0x61, 0x21, 0x60, 0x22, 0x5F, 0x21, 0x61, 0x22, 0x60, 0x21, 0x5F, 0x20, 0x61, 0x21, 0x5F, 0x21, 0x5E, 0x21, 0x5E, 0x20, 0x5D, 0x20, 0x5C, 0x20, 0x5C, 0x20, 0x5C, 0x20, 0x5C, 0x1F, 0x5B, 0x1F, 0x5B, 0x1F, 0x5C, 0x20, 0x5C, 0x20, 0x5A, 0x1F, 0x5B, 0x20, 0x5C, 0x20, 0x5C, 0x20, 0x5C, 0x20, 0x5B, 0x20, 0x5E, 0x21, 0x5F, 0x21, 0x5D, 0x21, 0x5D, 0x20, 0x5E, 0x20, 0x5D, 0x20, 0x5B, 0x20, 0x5B, 0x20, 0x5D, 0x21, 0x5D, 0x20, 0x5E, 0x21, 0x61, 0x21, 0x5D, 0x20, 0x5E, 0x20, 0x5C, 0x20, 0x5D, 0x20, 0x5C, 0x20, 0x5C, 0x20, 0x5A, 0x20, 0x5C, 0x20, 0x5D, 0x20, 0x5B, 0x20, 0x5C, 0x20, 0x5D, 0x20, 0x5C, 0x20, 0x5C, 0x20, 0x5B, 0x20, 0x5A, 0x20, 0x5A, 0x20, 0x59, 0x1F, 0x5A, 0x20, 0x5E, 0x21, 0x5C, 0x20, 0x5C, 0x20, 0x5C, 0x20, 0x5A, 0x20, 0x5A, 0x20, 0x5A, 0x1F, 0x59, 0x1F, 0x5B, 0x20, 0x5A, 0x20, 0x5A, 0x1F, 0x5D, 0x21, 0x5E, 0x21, 0x5D, 0x21, 0x5C, 0x21, 0x5C, 0x20, 0x5B, 0x22, 0x5F, 0x27, 0x5F, 0x29, 0x5B, 0x27, 0x56, 0x22, 0x55, 0x20, 0x58, 0x20, 0x59, 0x1F, 0x58, 0x20, 0x56, 0x1E, 0x54, 0x1E, 0x4B, 0x20, 0x47, 0x22, 0x46, 0x22, 0x48, 0x23, 0x47, 0x23, 0x46, 0x23, 0x45, 0x21, 0x3E, 0x1B, 0x48, 0x1C, 0x54, 0x1F, 0x56, 0x1F, 0x58, 0x20, 0x59, 0x21, 0x59, 0x20, 0x58, 0x20, 0x57, 0x1F, 0x58, 0x1F, 0x58, 0x1F, 0x59, 0x20, 0x5B, 0x20, 0x5B, 0x20, 0x5B, 0x21, 0x5B, 0x21, 0x5D, 0x21, 0x5B, 0x21, 0x5C, 0x21, 0x5C, 0x21, 0x5D, 0x21, 0x5B, 0x20, 0x5A, 0x20, 0x58, 0x1F, 0x57, 0x1F, 0x56, 0x1E, 0x54, 0x1E, 0x52, 0x1E, 0x4F, 0x1D, 0x54, 0x1E, 0x55, 0x1E, 0x54, 0x1E, 0x55, 0x1F, 0x53, 0x1D, 0x54, 0x1E, 0x4F, 0x1C, 0x52, 0x1D, 0x52, 0x1D, 0x52, 0x1E, 0x51, 0x1D, 0x52, 0x1E, 0x53, 0x1D, 0x51, 0x1D, 0x51, 0x1D, 0x52, 0x1D, 0x51, 0x1E, 0x52, 0x1D, 0x53, 0x1E, 0x54, 0x1E, 0x51, 0x1D, 0x52, 0x1E, 0x55, 0x1F, 0x54, 0x1E, 0x55, 0x1F, 0x53, 0x1E, 0x52, 0x1D, 0x54, 0x1E, 0x54, 0x1E, 0x51, 0x1D, 0x50, 0x1D, 0x46, 0x1A, 0x31, 0x18, 0x29, 0x16, 0x2B, 0x19, 0x27, 0x16, 0x22, 0x14, 0x25, 0x15, 0x22, 0x15, 0x2A, 0x19, 0x24, 0x16, 0x24, 0x18, 0x2C, 0x1A, 0x2D, 0x1A, 0x25, 0x18, 0x27, 0x17, 0x25, 0x17, 0x27, 0x17, 0x29, 0x17, 0x23, 0x16, 0x28, 0x18, 0x25, 0x18, 0x26, 0x18, 0x26, 0x19, 0x24, 0x17, 0x24, 0x18, 0x26, 0x18, 0x27, 0x17, 0x28, 0x17, 0x22, 0x15, 0x29, 0x19, 0x27, 0x1B, 0x2B, 0x1E, 0x26, 0x1B, 0x2C, 0x1D, 0x25, 0x1B, 0x27, 0x1C, 0x29, 0x1B, 0x22, 0x17, 0x28, 0x17, 0x20, 0x15, 0x26, 0x1A, 0x24, 0x1C, 0x1F, 0x1A, 0x24, 0x1D
    },

    {
        0x54, 0x4B, 0x55, 0x4A, 0x55, 0x4B, 0x56, 0x4C, 0x57, 0x4C, 0x56, 0x4B, 0x56, 0x4B, 0x56, 0x4C, 0x58, 0x4D, 0x57, 0x4D, 0x5A, 0x4F, 0x59, 0x4D, 0x59, 0x4D, 0x58, 0x4C, 0x58, 0x4E, 0x59, 0x4D, 0x5A, 0x4D, 0x5A, 0x4D, 0x5A, 0x4E, 0x58, 0x4D, 0x59, 0x4D, 0x59, 0x4E, 0x5A, 0x4E, 0x5B, 0x4F, 0x5B, 0x4F, 0x5C, 0x4F, 0x5D, 0x4F, 0x5C, 0x4F, 0x5C, 0x50, 0x5E, 0x52, 0x5D, 0x51, 0x5D, 0x52, 0x5C, 0x4F, 0x58, 0x4D, 0x52, 0x48, 0x49, 0x3F, 0x3E, 0x38, 0x3F, 0x3C, 0x49, 0x45, 0x4B, 0x43, 0x42, 0x3B, 0x34, 0x2E, 0x24, 0x21, 0x1B, 0x1A, 0x17, 0x18, 0x14, 0x16, 0x12, 0x15, 0x12, 0x14, 0x12, 0x14, 0x11, 0x14, 0x11, 0x14, 0x11, 0x14, 0x12, 0x15, 0x16, 0x1A, 0x1F, 0x26, 0x2C, 0x35, 0x35, 0x3F, 0x38, 0x42, 0x3A, 0x43, 0x3C, 0x45, 0x3E, 0x47, 0x3E, 0x47, 0x3F, 0x48, 0x40, 0x48, 0x40, 0x49, 0x3F, 0x49, 0x3F, 0x49, 0x41, 0x4A, 0x41, 0x4A, 0x41, 0x4A, 0x42, 0x4B, 0x42, 0x4B, 0x42, 0x4A, 0x42, 0x4B, 0x42, 0x4B, 0x42, 0x4C, 0x44, 0x4C, 0x43, 0x4D, 0x44, 0x4D, 0x45, 0x4F, 0x45, 0x50, 0x45, 0x4E, 0x43, 0x4D, 0x44, 0x4C, 0x43, 0x4C, 0x42, 0x4C, 0x41, 0x4B, 0x3F, 0x47, 0x38, 0x3F, 0x2E, 0x31, 0x22, 0x24, 0x1A, 0x1D, 0x18, 0x1C, 0x16, 0x1A, 0x15, 0x19, 0x15, 0x18, 0x15, 0x19, 0x15, 0x19, 0x15, 0x19, 0x14, 0x17, 0x13, 0x16, 0x12, 0x16, 0x13, 0x16, 0x14, 0x16, 0x16, 0x19, 0x1C, 0x1F, 0x30, 0x34, 0x49, 0x47, 0x55, 0x50, 0x59, 0x52, 0x4B, 0x42, 0x3A, 0x35, 0x47, 0x42, 0x55, 0x4F, 0x5E, 0x56, 0x62, 0x58, 0x66, 0x5A, 0x67, 0x5A, 0x6A, 0x5C, 0x68, 0x5B, 0x6B, 0x5D, 0x6B, 0x5C, 0x6A, 0x5C, 0x6A, 0x5C, 0x69, 0x5B, 0x69, 0x5C, 0x6A, 0x5C, 0x6A, 0x5B, 0x68, 0x59, 0x68, 0x5B, 0x67, 0x5A, 0x68, 0x5B, 0x6A, 0x5B, 0x69, 0x5A, 0x68, 0x5A, 0x67, 0x59, 0x66, 0x58, 0x66, 0x57, 0x68, 0x57, 0x66, 0x57, 0x65, 0x56, 0x64, 0x57, 0x65, 0x56, 0x65, 0x57, 0x65, 0x57, 0x64, 0x56, 0x65, 0x56, 0x65, 0x57, 0x64, 0x57, 0x65, 0x57, 0x66, 0x57, 0x67, 0x58, 0x67, 0x58, 0x66, 0x58, 0x66, 0x57, 0x67, 0x58, 0x68, 0x58, 0x65, 0x55, 0x64, 0x57, 0x66, 0x58, 0x66, 0x58, 0x66, 0x59, 0x69, 0x5A, 0x66, 0x58, 0x68, 0x59, 0x66, 0x57, 0x66, 0x57, 0x65, 0x55, 0x66, 0x55, 0x64, 0x55, 0x65, 0x57, 0x65, 0x56, 0x65, 0x56, 0x66, 0x58, 0x66, 0x57, 0x65, 0x56, 0x64, 0x56, 0x65, 0x56, 0x63, 0x55, 0x64, 0x56, 0x62, 0x54, 0x64, 0x56, 0x67, 0x59, 0x65, 0x57, 0x64, 0x57, 0x65, 0x58, 0x62, 0x54, 0x63, 0x55, 0x63, 0x55, 0x62, 0x54, 0x63, 0x56, 0x64, 0x55, 0x63, 0x56, 0x64, 0x57, 0x68, 0x5A, 0x67, 0x58, 0x65, 0x58, 0x65, 0x57, 0x62, 0x58, 0x61, 0x5B, 0x5E, 0x5A, 0x59, 0x54, 0x58, 0x4E, 0x59, 0x4D, 0x5E, 0x53, 0x5F, 0x54, 0x61, 0x54, 0x5F, 0x52, 0x5A, 0x4E, 0x4B, 0x46, 0x45, 0x44, 0x42, 0x42, 0x43, 0x44, 0x42, 0x44, 0x43, 0x43, 0x40, 0x41, 0x3C, 0x39, 0x4B, 0x45, 0x59, 0x51, 0x5E, 0x52, 0x60, 0x55, 0x63, 0x55, 0x62, 0x54, 0x62, 0x54, 0x61, 0x54, 0x61, 0x53, 0x5F, 0x54, 0x62, 0x56, 0x66, 0x57, 0x64, 0x57, 0x65, 0x58, 0x64, 0x57, 0x63, 0x57, 0x63, 0x56, 0x65, 0x58, 0x66, 0x58, 0x65, 0x58, 0x65, 0x57, 0x63, 0x55, 0x62, 0x54, 0x62, 0x53, 0x5E, 0x50, 0x5D, 0x50, 0x5C, 0x4F, 0x59, 0x4D, 0x5D, 0x50, 0x5D, 0x51, 0x5B, 0x50, 0x5D, 0x50, 0x5B, 0x4F, 0x5C, 0x4F, 0x58, 0x4B, 0x5B, 0x4E, 0x5B, 0x4F, 0x5C, 0x4E, 0x59, 0x4E, 0x5A, 0x4E, 0x5B, 0x4E, 0x5B, 0x4E, 0x58, 0x4C, 0x59, 0x4D, 0x5A, 0x4F, 0x5C, 0x4F, 0x5B, 0x4E, 0x5B, 0x4F, 0x5A, 0x4D, 0x5B, 0x4F, 0x5D, 0x50, 0x5D, 0x51, 0x5B, 0x50, 0x5C, 0x50, 0x59, 0x4E, 0x5B, 0x4F, 0x5C, 0x50, 0x5B, 0x4E, 0x58, 0x4D, 0x4B, 0x3E, 0x31, 0x2D, 0x27, 0x23, 0x27, 0x29, 0x22, 0x22, 0x20, 0x21, 0x22, 0x24, 0x20, 0x24, 0x23, 0x27, 0x20, 0x23, 0x21, 0x25, 0x27, 0x2A, 0x26, 0x28, 0x22, 0x26, 0x23, 0x24, 0x22, 0x26, 0x25, 0x28, 0x24, 0x26, 0x21, 0x24, 0x22, 0x24, 0x22, 0x25, 0x21, 0x25, 0x21, 0x26, 0x20, 0x22, 0x1F, 0x25, 0x24, 0x27, 0x22, 0x25, 0x25, 0x27, 0x1F, 0x22, 0x24, 0x28, 0x21, 0x27, 0x25, 0x2B, 0x1F, 0x24, 0x25, 0x29, 0x1E, 0x22, 0x21, 0x26, 0x22, 0x25, 0x1F, 0x23, 0x24, 0x24, 0x1D, 0x20, 0x1F, 0x22, 0x1D, 0x21, 0x19, 0x1E, 0x1D, 0x23
    },

    {
        0x4E, 0x1C, 0x4E, 0x1B, 0x4E, 0x1C, 0x4E, 0x1B, 0x4E, 0x1C, 0x4E, 0x1C, 0x4E, 0x1C, 0x4F, 0x1C, 0x50, 0x1C, 0x50, 0x1C, 0x51, 0x1D, 0x51, 0x1D, 0x51, 0x1D, 0x50, 0x1C, 0x4F, 0x1C, 0x51, 0x1C, 0x50, 0x1C, 0x50, 0x1C, 0x51, 0x1D, 0x51, 0x1C, 0x51, 0x1C, 0x50, 0x1D, 0x50, 0x1D, 0x51, 0x1D, 0x53, 0x1D, 0x53, 0x1D, 0x53, 0x1E, 0x53, 0x1D, 0x54, 0x1E, 0x54, 0x1E, 0x55, 0x1F, 0x54, 0x1F, 0x52, 0x1F, 0x4D, 0x1E, 0x47, 0x1D, 0x3F, 0x1B, 0x3B, 0x1A, 0x44, 0x1B, 0x49, 0x1C, 0x43, 0x1B, 0x38, 0x18, 0x28, 0x14, 0x1F, 0x12, 0x1A, 0x10, 0x18, 0x0F, 0x16, 0x0F, 0x15, 0x0F, 0x14, 0x0E, 0x15, 0x0F, 0x15, 0x0F, 0x16, 0x0F, 0x15, 0x0F, 0x16, 0x10, 0x17, 0x13, 0x1B, 0x19, 0x28, 0x2A, 0x39, 0x3A, 0x41, 0x44, 0x45, 0x48, 0x47, 0x4A, 0x4B, 0x4D, 0x4B, 0x4D, 0x4B, 0x4E, 0x4B, 0x4F, 0x4C, 0x4F, 0x4C, 0x4F, 0x4D, 0x50, 0x4D, 0x50, 0x4E, 0x50, 0x4F, 0x51, 0x50, 0x51, 0x4F, 0x51, 0x4E, 0x50, 0x4F, 0x51, 0x4F, 0x51, 0x4E, 0x51, 0x51, 0x52, 0x52, 0x54, 0x51, 0x54, 0x52, 0x54, 0x53, 0x55, 0x51, 0x53, 0x51, 0x53, 0x4F, 0x52, 0x4F, 0x53, 0x4F, 0x52, 0x4F, 0x4E, 0x47, 0x44, 0x3B, 0x34, 0x2B, 0x24, 0x21, 0x1B, 0x1F, 0x18, 0x1C, 0x15, 0x1C, 0x15, 0x1A, 0x13, 0x19, 0x12, 0x19, 0x12, 0x19, 0x12, 0x1A, 0x12, 0x1A, 0x12, 0x18, 0x11, 0x18, 0x10, 0x17, 0x10, 0x16, 0x10, 0x18, 0x11, 0x1B, 0x12, 0x21, 0x15, 0x39, 0x1B, 0x4D, 0x1F, 0x56, 0x20, 0x55, 0x20, 0x47, 0x1D, 0x39, 0x1B, 0x45, 0x1E, 0x56, 0x21, 0x5C, 0x22, 0x5D, 0x22, 0x5F, 0x21, 0x62, 0x22, 0x61, 0x22, 0x60, 0x22, 0x61, 0x22, 0x60, 0x22, 0x60, 0x22, 0x5F, 0x22, 0x60, 0x22, 0x60, 0x21, 0x5F, 0x21, 0x5F, 0x21, 0x5F, 0x21, 0x5E, 0x22, 0x5E, 0x21, 0x5F, 0x21, 0x5F, 0x21, 0x5F, 0x21, 0x5F, 0x21, 0x5D, 0x20, 0x5D, 0x20, 0x5C, 0x20, 0x5B, 0x1F, 0x5B, 0x1F, 0x5B, 0x20, 0x5B, 0x20, 0x5C, 0x20, 0x5B, 0x20, 0x5D, 0x21, 0x5E, 0x21, 0x5E, 0x20, 0x5C, 0x20, 0x5B, 0x20, 0x5C, 0x20, 0x5E, 0x21, 0x5C, 0x21, 0x5D, 0x20, 0x5B, 0x20, 0x5D, 0x20, 0x5D, 0x21, 0x5C, 0x20, 0x5D, 0x20, 0x5C, 0x20, 0x5B, 0x20, 0x5C, 0x21, 0x5E, 0x21, 0x5C, 0x21, 0x5E, 0x21, 0x5E, 0x21, 0x5B, 0x20, 0x5C, 0x20, 0x5C, 0x20, 0x5A, 0x20, 0x5C, 0x21, 0x5D, 0x21, 0x5C, 0x21, 0x5F, 0x22, 0x5C, 0x20, 0x59, 0x20, 0x5D, 0x20, 0x5A, 0x1F, 0x5D, 0x21, 0x59, 0x1F, 0x58, 0x1F, 0x59, 0x1F, 0x5D, 0x21, 0x5D, 0x20, 0x5C, 0x21, 0x5C, 0x21, 0x5C, 0x20, 0x59, 0x20, 0x5A, 0x20, 0x5B, 0x1F, 0x5A, 0x20, 0x5B, 0x20, 0x5B, 0x20, 0x5D, 0x21, 0x5D, 0x21, 0x5E, 0x21, 0x5C, 0x20, 0x5B, 0x21, 0x5E, 0x2A, 0x63, 0x32, 0x5E, 0x30, 0x52, 0x2A, 0x45, 0x20, 0x45, 0x1E, 0x53, 0x20, 0x58, 0x20, 0x5A, 0x1F, 0x59, 0x20, 0x53, 0x1F, 0x4A, 0x20, 0x46, 0x21, 0x46, 0x23, 0x47, 0x23, 0x47, 0x23, 0x46, 0x23, 0x44, 0x20, 0x37, 0x18, 0x42, 0x1B, 0x52, 0x1E, 0x55, 0x1F, 0x58, 0x20, 0x5B, 0x21, 0x5A, 0x20, 0x59, 0x20, 0x59, 0x21, 0x59, 0x20, 0x58, 0x20, 0x5A, 0x21, 0x5A, 0x20, 0x5A, 0x20, 0x5E, 0x21, 0x5E, 0x22, 0x5C, 0x21, 0x5A, 0x20, 0x5C, 0x21, 0x5D, 0x21, 0x5D, 0x21, 0x5C, 0x20, 0x5B, 0x20, 0x5A, 0x1F, 0x58, 0x20, 0x59, 0x1F, 0x58, 0x20, 0x57, 0x1F, 0x54, 0x1F, 0x56, 0x1F, 0x57, 0x20, 0x53, 0x1F, 0x56, 0x1F, 0x55, 0x1E, 0x54, 0x1E, 0x50, 0x1D, 0x53, 0x1E, 0x53, 0x1E, 0x52, 0x1E, 0x53, 0x1E, 0x51, 0x1D, 0x51, 0x1D, 0x52, 0x1E, 0x50, 0x1C, 0x4F, 0x1C, 0x52, 0x1E, 0x52, 0x1D, 0x52, 0x1D, 0x50, 0x1D, 0x52, 0x1E, 0x52, 0x1E, 0x54, 0x1E, 0x55, 0x1E, 0x54, 0x1F, 0x53, 0x1E, 0x51, 0x1E, 0x52, 0x1F, 0x52, 0x1D, 0x50, 0x1D, 0x51, 0x1D, 0x45, 0x1A, 0x30, 0x18, 0x25, 0x16, 0x2B, 0x18, 0x27, 0x17, 0x28, 0x17, 0x28, 0x17, 0x2D, 0x1B, 0x29, 0x1E, 0x2A, 0x1E, 0x26, 0x20, 0x2E, 0x21, 0x28, 0x20, 0x2C, 0x21, 0x24, 0x1B, 0x24, 0x18, 0x2B, 0x17, 0x21, 0x14, 0x27, 0x1B, 0x23, 0x1F, 0x29, 0x25, 0x26, 0x24, 0x28, 0x28, 0x29, 0x27, 0x28, 0x28, 0x29, 0x20, 0x25, 0x19, 0x26, 0x16, 0x20, 0x17, 0x29, 0x25, 0x27, 0x2C, 0x2B, 0x2F, 0x25, 0x2D, 0x29, 0x2F, 0x26, 0x2E, 0x28, 0x2E, 0x22, 0x1E, 0x21, 0x17, 0x21, 0x14, 0x21, 0x19, 0x25, 0x29, 0x25, 0x30, 0x24, 0x2F, 0x26, 0x34
    },

    {
        0x55, 0x4A, 0x56, 0x4B, 0x55, 0x4C, 0x55, 0x4B, 0x56, 0x4C, 0x57, 0x4C, 0x58, 0x4C, 0x58, 0x4D, 0x58, 0x4E, 0x59, 0x4D, 0x5A, 0x4E, 0x59, 0x4D, 0x5A, 0x4E, 0x58, 0x4D, 0x58, 0x4C, 0x5A, 0x4D, 0x59, 0x4C, 0x59, 0x4D, 0x5A, 0x4D, 0x59, 0x4D, 0x59, 0x4E, 0x59, 0x4E, 0x59, 0x4D, 0x5A, 0x4E, 0x5C, 0x50, 0x5C, 0x4F, 0x5C, 0x50, 0x5C, 0x4F, 0x5C, 0x51, 0x5C, 0x51, 0x5D, 0x51, 0x5B, 0x50, 0x58, 0x4D, 0x51, 0x48, 0x4A, 0x41, 0x40, 0x3B, 0x3E, 0x3B, 0x47, 0x44, 0x4D, 0x45, 0x44, 0x3C, 0x36, 0x2F, 0x25, 0x22, 0x1B, 0x1B, 0x17, 0x18, 0x15, 0x16, 0x13, 0x15, 0x11, 0x14, 0x10, 0x14, 0x11, 0x14, 0x11, 0x15, 0x12, 0x15, 0x11, 0x14, 0x12, 0x15, 0x13, 0x16, 0x15, 0x19, 0x1D, 0x25, 0x2B, 0x35, 0x34, 0x3E, 0x39, 0x42, 0x3B, 0x43, 0x3D, 0x46, 0x3E, 0x47, 0x3F, 0x48, 0x3F, 0x48, 0x40, 0x49, 0x3F, 0x49, 0x40, 0x49, 0x40, 0x49, 0x41, 0x4A, 0x42, 0x4C, 0x43, 0x4D, 0x42, 0x4B, 0x43, 0x4A, 0x42, 0x4B, 0x43, 0x4C, 0x42, 0x4C, 0x43, 0x4C, 0x45, 0x4E, 0x44, 0x4D, 0x44, 0x4E, 0x45, 0x4E, 0x45, 0x4E, 0x44, 0x4D, 0x43, 0x4C, 0x42, 0x4C, 0x40, 0x4B, 0x3E, 0x47, 0x39, 0x3F, 0x2F, 0x32, 0x23, 0x25, 0x1B, 0x1E, 0x18, 0x1C, 0x17, 0x1B, 0x16, 0x1A, 0x15, 0x19, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x15, 0x19, 0x15, 0x19, 0x14, 0x17, 0x14, 0x17, 0x12, 0x15, 0x13, 0x15, 0x13, 0x17, 0x16, 0x19, 0x1B, 0x1E, 0x2E, 0x33, 0x48, 0x47, 0x56, 0x51, 0x58, 0x52, 0x4D, 0x45, 0x3B, 0x37, 0x42, 0x40, 0x57, 0x51, 0x60, 0x56, 0x63, 0x58, 0x65, 0x5B, 0x6A, 0x5C, 0x69, 0x5C, 0x6A, 0x5C, 0x6B, 0x5B, 0x69, 0x5B, 0x69, 0x5B, 0x68, 0x5C, 0x6A, 0x5C, 0x68, 0x59, 0x6A, 0x5A, 0x67, 0x59, 0x68, 0x59, 0x67, 0x5A, 0x67, 0x58, 0x68, 0x59, 0x68, 0x59, 0x67, 0x5A, 0x68, 0x58, 0x67, 0x59, 0x66, 0x57, 0x66, 0x56, 0x64, 0x57, 0x64, 0x57, 0x64, 0x56, 0x65, 0x57, 0x66, 0x57, 0x64, 0x56, 0x65, 0x58, 0x67, 0x59, 0x66, 0x59, 0x65, 0x56, 0x66, 0x56, 0x66, 0x58, 0x67, 0x58, 0x66, 0x58, 0x65, 0x57, 0x64, 0x57, 0x67, 0x58, 0x67, 0x59, 0x65, 0x58, 0x65, 0x59, 0x64, 0x57, 0x65, 0x57, 0x65, 0x57, 0x66, 0x58, 0x65, 0x57, 0x68, 0x5A, 0x68, 0x59, 0x65, 0x57, 0x64, 0x57, 0x64, 0x57, 0x64, 0x56, 0x64, 0x57, 0x66, 0x59, 0x66, 0x59, 0x68, 0x5B, 0x66, 0x58, 0x64, 0x55, 0x66, 0x58, 0x64, 0x56, 0x67, 0x59, 0x64, 0x55, 0x62, 0x53, 0x64, 0x55, 0x65, 0x57, 0x65, 0x58, 0x65, 0x57, 0x67, 0x58, 0x66, 0x57, 0x62, 0x55, 0x63, 0x55, 0x63, 0x55, 0x63, 0x55, 0x64, 0x56, 0x63, 0x56, 0x63, 0x57, 0x65, 0x57, 0x66, 0x5A, 0x65, 0x57, 0x62, 0x57, 0x5F, 0x5C, 0x5B, 0x5D, 0x54, 0x56, 0x4A, 0x47, 0x42, 0x3B, 0x44, 0x3E, 0x56, 0x4E, 0x5F, 0x54, 0x63, 0x55, 0x60, 0x54, 0x5B, 0x4E, 0x4B, 0x45, 0x45, 0x43, 0x42, 0x43, 0x42, 0x43, 0x41, 0x44, 0x41, 0x43, 0x3F, 0x3E, 0x35, 0x32, 0x43, 0x40, 0x57, 0x4E, 0x5D, 0x52, 0x5F, 0x55, 0x62, 0x56, 0x63, 0x55, 0x61, 0x55, 0x61, 0x55, 0x62, 0x54, 0x61, 0x56, 0x61, 0x55, 0x63, 0x55, 0x64, 0x56, 0x65, 0x59, 0x68, 0x5A, 0x65, 0x58, 0x64, 0x57, 0x64, 0x58, 0x64, 0x58, 0x67, 0x5A, 0x67, 0x58, 0x65, 0x56, 0x65, 0x56, 0x63, 0x55, 0x63, 0x55, 0x61, 0x55, 0x61, 0x52, 0x5D, 0x51, 0x5D, 0x51, 0x5E, 0x52, 0x5B, 0x50, 0x5D, 0x51, 0x5B, 0x4E, 0x5B, 0x4F, 0x58, 0x4C, 0x5B, 0x4F, 0x5C, 0x4F, 0x5A, 0x4D, 0x5A, 0x4E, 0x5A, 0x4D, 0x5A, 0x4E, 0x5B, 0x4F, 0x5A, 0x4C, 0x59, 0x4B, 0x59, 0x4E, 0x5A, 0x4D, 0x5C, 0x4E, 0x59, 0x4D, 0x5A, 0x4F, 0x5B, 0x50, 0x5B, 0x4F, 0x5E, 0x52, 0x5A, 0x4F, 0x5B, 0x50, 0x59, 0x4E, 0x59, 0x4E, 0x5A, 0x4E, 0x5A, 0x4D, 0x59, 0x4C, 0x4A, 0x3D, 0x30, 0x2D, 0x25, 0x25, 0x28, 0x29, 0x25, 0x28, 0x23, 0x24, 0x24, 0x29, 0x26, 0x29, 0x22, 0x28, 0x22, 0x25, 0x1F, 0x27, 0x24, 0x28, 0x20, 0x27, 0x24, 0x29, 0x1E, 0x21, 0x21, 0x27, 0x24, 0x25, 0x1D, 0x1F, 0x21, 0x25, 0x1D, 0x22, 0x1F, 0x28, 0x1D, 0x22, 0x1F, 0x27, 0x1E, 0x25, 0x1F, 0x28, 0x1F, 0x23, 0x20, 0x23, 0x21, 0x21, 0x1B, 0x1D, 0x1E, 0x25, 0x1C, 0x25, 0x1D, 0x26, 0x1A, 0x25, 0x1C, 0x26, 0x1B, 0x25, 0x1B, 0x25, 0x1A, 0x1D, 0x1B, 0x1F, 0x1D, 0x1E, 0x1C, 0x21, 0x1A, 0x23, 0x19, 0x24, 0x19, 0x23, 0x19, 0x24
    },

    {
        0x4E, 0x1C, 0x4E, 0x1B, 0x50, 0x1C, 0x4F, 0x1C, 0x50, 0x1C, 0x50, 0x1C, 0x4E, 0x1C, 0x50, 0x1D, 0x50, 0x1C, 0x51, 0x1C, 0x50, 0x1D, 0x4F, 0x1C, 0x50, 0x1C, 0x50, 0x1D, 0x4F, 0x1D, 0x52, 0x1D, 0x52, 0x1D, 0x51, 0x1D, 0x51, 0x1C, 0x4F, 0x1C, 0x4F, 0x1C, 0x51, 0x1C, 0x51, 0x1D, 0x51, 0x1D, 0x52, 0x1E, 0x52, 0x1E, 0x52, 0x1E, 0x52, 0x1E, 0x53, 0x1E, 0x54, 0x1F, 0x52, 0x1E, 0x50, 0x1E, 0x4D, 0x1E, 0x45, 0x1C, 0x3F, 0x1C, 0x3C, 0x1B, 0x43, 0x1C, 0x49, 0x1D, 0x45, 0x1B, 0x3A, 0x18, 0x29, 0x14, 0x1F, 0x11, 0x1B, 0x10, 0x18, 0x10, 0x16, 0x0F, 0x15, 0x0F, 0x14, 0x0F, 0x14, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x10, 0x16, 0x10, 0x16, 0x11, 0x17, 0x11, 0x18, 0x13, 0x1C, 0x19, 0x27, 0x28, 0x36, 0x39, 0x41, 0x44, 0x45, 0x48, 0x48, 0x4B, 0x49, 0x4C, 0x4A, 0x4C, 0x4B, 0x4D, 0x4C, 0x4F, 0x4C, 0x4F, 0x4D, 0x4F, 0x4D, 0x50, 0x4E, 0x51, 0x4F, 0x52, 0x53, 0x53, 0x51, 0x52, 0x4F, 0x50, 0x4E, 0x51, 0x50, 0x52, 0x50, 0x53, 0x50, 0x52, 0x50, 0x55, 0x51, 0x53, 0x50, 0x54, 0x52, 0x55, 0x52, 0x54, 0x51, 0x53, 0x50, 0x52, 0x4E, 0x50, 0x4C, 0x4D, 0x47, 0x45, 0x3D, 0x36, 0x2D, 0x24, 0x21, 0x1B, 0x1E, 0x18, 0x1B, 0x16, 0x1A, 0x14, 0x1A, 0x13, 0x1A, 0x12, 0x18, 0x12, 0x19, 0x11, 0x18, 0x12, 0x18, 0x12, 0x18, 0x12, 0x18, 0x11, 0x17, 0x10, 0x16, 0x10, 0x16, 0x10, 0x17, 0x10, 0x18, 0x11, 0x1A, 0x12, 0x21, 0x15, 0x37, 0x1B, 0x4E, 0x1F, 0x53, 0x20, 0x56, 0x20, 0x4A, 0x1D, 0x38, 0x1B, 0x43, 0x1E, 0x56, 0x21, 0x5A, 0x21, 0x5C, 0x21, 0x60, 0x22, 0x60, 0x22, 0x61, 0x23, 0x61, 0x23, 0x60, 0x22, 0x5F, 0x22, 0x60, 0x22, 0x61, 0x23, 0x60, 0x22, 0x60, 0x21, 0x5E, 0x21, 0x61, 0x22, 0x5D, 0x21, 0x5C, 0x21, 0x5F, 0x21, 0x60, 0x21, 0x5E, 0x21, 0x5C, 0x21, 0x5D, 0x21, 0x5E, 0x20, 0x5B, 0x21, 0x5A, 0x20, 0x5B, 0x1F, 0x5A, 0x20, 0x5B, 0x20, 0x5B, 0x1F, 0x5B, 0x20, 0x5D, 0x20, 0x5E, 0x21, 0x5E, 0x21, 0x5D, 0x20, 0x5D, 0x21, 0x5E, 0x21, 0x5D, 0x20, 0x5D, 0x20, 0x5C, 0x20, 0x5C, 0x21, 0x5C, 0x20, 0x5D, 0x20, 0x5C, 0x21, 0x5D, 0x21, 0x5C, 0x20, 0x5D, 0x21, 0x5C, 0x21, 0x5D, 0x21, 0x5C, 0x20, 0x5E, 0x21, 0x5E, 0x20, 0x5D, 0x20, 0x5C, 0x21, 0x5D, 0x21, 0x5D, 0x21, 0x5D, 0x21, 0x5F, 0x22, 0x5F, 0x22, 0x5C, 0x22, 0x5C, 0x21, 0x5C, 0x21, 0x5D, 0x20, 0x5B, 0x1F, 0x5D, 0x21, 0x5D, 0x21, 0x5C, 0x20, 0x5B, 0x20, 0x5B, 0x20, 0x5B, 0x20, 0x5C, 0x21, 0x5D, 0x21, 0x5D, 0x21, 0x5A, 0x20, 0x5B, 0x20, 0x59, 0x1F, 0x5A, 0x20, 0x5C, 0x20, 0x5D, 0x21, 0x5B, 0x21, 0x5B, 0x21, 0x5C, 0x20, 0x5C, 0x20, 0x58, 0x23, 0x5E, 0x2E, 0x57, 0x2E, 0x4A, 0x26, 0x3D, 0x1F, 0x35, 0x1B, 0x31, 0x19, 0x46, 0x1D, 0x56, 0x20, 0x5A, 0x20, 0x58, 0x20, 0x55, 0x1F, 0x4B, 0x20, 0x47, 0x21, 0x47, 0x23, 0x48, 0x23, 0x47, 0x22, 0x46, 0x22, 0x40, 0x1E, 0x31, 0x16, 0x3C, 0x19, 0x4E, 0x1E, 0x55, 0x1F, 0x58, 0x20, 0x5B, 0x20, 0x5B, 0x21, 0x5B, 0x21, 0x5B, 0x21, 0x5C, 0x21, 0x5D, 0x21, 0x59, 0x20, 0x5A, 0x20, 0x5A, 0x20, 0x5B, 0x21, 0x5D, 0x22, 0x5E, 0x21, 0x5A, 0x20, 0x5C, 0x20, 0x5C, 0x20, 0x5D, 0x21, 0x5B, 0x20, 0x5A, 0x20, 0x5B, 0x21, 0x5C, 0x21, 0x5D, 0x21, 0x5E, 0x22, 0x5C, 0x21, 0x59, 0x21, 0x59, 0x21, 0x55, 0x1F, 0x53, 0x1F, 0x55, 0x1F, 0x52, 0x1E, 0x53, 0x1E, 0x54, 0x1E, 0x53, 0x1E, 0x52, 0x1E, 0x52, 0x1D, 0x4F, 0x1D, 0x53, 0x1D, 0x52, 0x1E, 0x52, 0x1E, 0x51, 0x1D, 0x50, 0x1D, 0x50, 0x1E, 0x51, 0x1E, 0x53, 0x1E, 0x52, 0x1D, 0x50, 0x1E, 0x52, 0x1E, 0x53, 0x1E, 0x52, 0x1E, 0x50, 0x1D, 0x52, 0x1F, 0x52, 0x1F, 0x52, 0x1E, 0x52, 0x1E, 0x52, 0x1E, 0x4F, 0x1D, 0x46, 0x1B, 0x37, 0x1B, 0x28, 0x16, 0x27, 0x17, 0x29, 0x18, 0x22, 0x15, 0x29, 0x19, 0x28, 0x27, 0x28, 0x30, 0x2A, 0x32, 0x29, 0x35, 0x29, 0x34, 0x2A, 0x35, 0x29, 0x35, 0x23, 0x1F, 0x27, 0x19, 0x24, 0x16, 0x21, 0x17, 0x29, 0x29, 0x27, 0x32, 0x28, 0x36, 0x27, 0x36, 0x29, 0x38, 0x28, 0x36, 0x27, 0x34, 0x21, 0x1F, 0x1E, 0x16, 0x20, 0x15, 0x1F, 0x19, 0x26, 0x2D, 0x28, 0x34, 0x27, 0x35, 0x27, 0x35, 0x27, 0x34, 0x27, 0x34, 0x26, 0x31, 0x1D, 0x1A, 0x20, 0x16, 0x24, 0x16, 0x23, 0x1B, 0x26, 0x2C, 0x26, 0x30, 0x24, 0x2F, 0x25, 0x2F
    },

    {
        0x55, 0x4C, 0x54, 0x4B, 0x56, 0x4B, 0x56, 0x4C, 0x57, 0x4C, 0x58, 0x4D, 0x58, 0x4C, 0x59, 0x4D, 0x58, 0x4E, 0x59, 0x4D, 0x5A, 0x4D, 0x59, 0x4C, 0x59, 0x4D, 0x58, 0x4D, 0x59, 0x4D, 0x5A, 0x4D, 0x5B, 0x4E, 0x5A, 0x4D, 0x5A, 0x4E, 0x59, 0x4C, 0x58, 0x4C, 0x59, 0x4D, 0x59, 0x4D, 0x59, 0x4D, 0x5B, 0x4F, 0x5C, 0x4E, 0x5B, 0x4E, 0x5B, 0x4F, 0x5D, 0x50, 0x5D, 0x50, 0x59, 0x4E, 0x56, 0x4A, 0x50, 0x46, 0x48, 0x3E, 0x40, 0x3A, 0x3E, 0x3C, 0x46, 0x43, 0x4C, 0x45, 0x46, 0x3E, 0x38, 0x31, 0x26, 0x23, 0x1B, 0x1B, 0x17, 0x19, 0x15, 0x16, 0x13, 0x14, 0x11, 0x14, 0x10, 0x13, 0x11, 0x13, 0x11, 0x14, 0x11, 0x14, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x12, 0x16, 0x13, 0x17, 0x15, 0x1A, 0x1D, 0x24, 0x29, 0x32, 0x33, 0x3C, 0x38, 0x41, 0x39, 0x44, 0x3C, 0x46, 0x3C, 0x46, 0x3E, 0x47, 0x3F, 0x48, 0x41, 0x49, 0x41, 0x4A, 0x41, 0x4A, 0x41, 0x4A, 0x42, 0x4C, 0x44, 0x4E, 0x44, 0x4C, 0x42, 0x4B, 0x41, 0x4B, 0x43, 0x4B, 0x42, 0x4C, 0x43, 0x4D, 0x44, 0x4E, 0x44, 0x4D, 0x43, 0x4D, 0x44, 0x4E, 0x44, 0x4D, 0x44, 0x4E, 0x42, 0x4B, 0x40, 0x49, 0x3D, 0x46, 0x38, 0x40, 0x30, 0x34, 0x23, 0x26, 0x1A, 0x1D, 0x18, 0x1C, 0x16, 0x19, 0x15, 0x18, 0x15, 0x18, 0x15, 0x18, 0x13, 0x17, 0x13, 0x17, 0x14, 0x17, 0x14, 0x17, 0x13, 0x17, 0x13, 0x16, 0x12, 0x16, 0x12, 0x15, 0x12, 0x15, 0x12, 0x16, 0x13, 0x16, 0x16, 0x19, 0x1A, 0x1D, 0x2C, 0x31, 0x48, 0x48, 0x54, 0x4F, 0x5A, 0x52, 0x52, 0x48, 0x3C, 0x36, 0x41, 0x3E, 0x56, 0x50, 0x5E, 0x53, 0x60, 0x57, 0x65, 0x5A, 0x69, 0x5C, 0x69, 0x5C, 0x6B, 0x5B, 0x6A, 0x5B, 0x68, 0x5A, 0x6A, 0x5C, 0x6C, 0x5D, 0x6A, 0x5C, 0x69, 0x59, 0x66, 0x5A, 0x69, 0x5C, 0x67, 0x59, 0x66, 0x59, 0x68, 0x59, 0x68, 0x5A, 0x67, 0x58, 0x65, 0x58, 0x65, 0x58, 0x68, 0x59, 0x64, 0x56, 0x63, 0x55, 0x64, 0x56, 0x63, 0x55, 0x64, 0x56, 0x65, 0x56, 0x64, 0x56, 0x67, 0x57, 0x66, 0x57, 0x65, 0x59, 0x65, 0x57, 0x65, 0x58, 0x65, 0x58, 0x66, 0x58, 0x67, 0x58, 0x66, 0x58, 0x66, 0x58, 0x64, 0x57, 0x66, 0x57, 0x65, 0x56, 0x65, 0x58, 0x64, 0x56, 0x64, 0x57, 0x64, 0x57, 0x67, 0x58, 0x65, 0x58, 0x67, 0x58, 0x68, 0x57, 0x67, 0x57, 0x65, 0x58, 0x66, 0x59, 0x65, 0x57, 0x66, 0x58, 0x66, 0x5A, 0x68, 0x59, 0x64, 0x58, 0x64, 0x56, 0x65, 0x58, 0x67, 0x56, 0x65, 0x56, 0x67, 0x58, 0x66, 0x58, 0x65, 0x58, 0x65, 0x57, 0x66, 0x57, 0x64, 0x56, 0x66, 0x59, 0x67, 0x58, 0x66, 0x58, 0x63, 0x55, 0x64, 0x56, 0x64, 0x55, 0x64, 0x57, 0x65, 0x58, 0x66, 0x58, 0x63, 0x56, 0x65, 0x58, 0x65, 0x57, 0x63, 0x57, 0x5D, 0x53, 0x57, 0x55, 0x4C, 0x4A, 0x40, 0x3C, 0x38, 0x32, 0x34, 0x2E, 0x30, 0x2C, 0x46, 0x42, 0x5A, 0x52, 0x60, 0x55, 0x5F, 0x54, 0x5C, 0x50, 0x4C, 0x46, 0x45, 0x43, 0x41, 0x43, 0x41, 0x43, 0x40, 0x43, 0x3F, 0x41, 0x3A, 0x38, 0x32, 0x2D, 0x3F, 0x3C, 0x55, 0x4C, 0x5D, 0x53, 0x60, 0x55, 0x63, 0x56, 0x65, 0x58, 0x64, 0x57, 0x65, 0x58, 0x64, 0x57, 0x65, 0x58, 0x62, 0x55, 0x64, 0x57, 0x64, 0x56, 0x64, 0x57, 0x68, 0x59, 0x68, 0x5A, 0x66, 0x56, 0x67, 0x58, 0x67, 0x56, 0x66, 0x58, 0x65, 0x57, 0x64, 0x56, 0x65, 0x57, 0x66, 0x58, 0x67, 0x58, 0x68, 0x5A, 0x65, 0x58, 0x63, 0x57, 0x62, 0x55, 0x5E, 0x51, 0x5B, 0x4F, 0x5D, 0x50, 0x5B, 0x4E, 0x5C, 0x4E, 0x5B, 0x50, 0x5B, 0x4E, 0x5B, 0x4E, 0x5C, 0x4E, 0x59, 0x4D, 0x5B, 0x4E, 0x5A, 0x4D, 0x5A, 0x4F, 0x5A, 0x4D, 0x58, 0x4B, 0x59, 0x4E, 0x59, 0x4D, 0x5C, 0x4F, 0x5B, 0x4E, 0x5A, 0x4E, 0x5C, 0x4F, 0x5B, 0x4F, 0x59, 0x4F, 0x58, 0x4D, 0x5A, 0x4F, 0x5A, 0x4E, 0x5B, 0x4E, 0x5A, 0x4F, 0x5B, 0x4F, 0x56, 0x4A, 0x4B, 0x41, 0x35, 0x33, 0x26, 0x24, 0x25, 0x26, 0x24, 0x26, 0x20, 0x20, 0x24, 0x27, 0x1E, 0x25, 0x1D, 0x27, 0x1C, 0x27, 0x1B, 0x27, 0x1B, 0x27, 0x1B, 0x27, 0x1B, 0x27, 0x1B, 0x20, 0x22, 0x25, 0x1F, 0x21, 0x1E, 0x23, 0x1F, 0x25, 0x1B, 0x26, 0x1A, 0x25, 0x1A, 0x25, 0x1A, 0x25, 0x1A, 0x24, 0x19, 0x24, 0x17, 0x1C, 0x1A, 0x1F, 0x1C, 0x1E, 0x1D, 0x20, 0x1B, 0x24, 0x1B, 0x25, 0x1A, 0x24, 0x19, 0x24, 0x19, 0x24, 0x19, 0x24, 0x18, 0x22, 0x16, 0x19, 0x1D, 0x22, 0x21, 0x22, 0x1D, 0x22, 0x1B, 0x24, 0x19, 0x22, 0x17, 0x21, 0x18, 0x20
    },

    {
        0x4F, 0x1C, 0x4F, 0x1C, 0x4F, 0x1C, 0x4F, 0x1C, 0x4E, 0x1C, 0x50, 0x1C, 0x50, 0x1D, 0x51, 0x1C, 0x51, 0x1C, 0x50, 0x1C, 0x51, 0x1D, 0x50, 0x1D, 0x50, 0x1D, 0x51, 0x1D, 0x50, 0x1C, 0x50, 0x1C, 0x4F, 0x1C, 0x50, 0x1C, 0x4F, 0x1C, 0x50, 0x1C, 0x4F, 0x1C, 0x50, 0x1C, 0x50, 0x1C, 0x4F, 0x1D, 0x51, 0x1D, 0x50, 0x1D, 0x51, 0x1D, 0x51, 0x1D, 0x54, 0x1E, 0x54, 0x1F, 0x51, 0x1E, 0x4C, 0x1D, 0x45, 0x1C, 0x3E, 0x1A, 0x3B, 0x1A, 0x43, 0x1B, 0x48, 0x1D, 0x45, 0x1B, 0x3A, 0x18, 0x2A, 0x14, 0x1F, 0x11, 0x1B, 0x10, 0x19, 0x0F, 0x16, 0x0F, 0x15, 0x0E, 0x14, 0x0E, 0x14, 0x0E, 0x14, 0x0E, 0x14, 0x0E, 0x14, 0x0F, 0x15, 0x10, 0x15, 0x0F, 0x16, 0x0F, 0x17, 0x10, 0x17, 0x11, 0x18, 0x13, 0x1B, 0x18, 0x25, 0x26, 0x35, 0x38, 0x40, 0x42, 0x45, 0x48, 0x48, 0x4A, 0x48, 0x4B, 0x4A, 0x4C, 0x4B, 0x4D, 0x4C, 0x4E, 0x4C, 0x4F, 0x4D, 0x50, 0x4D, 0x50, 0x4E, 0x51, 0x4F, 0x52, 0x4F, 0x52, 0x4F, 0x51, 0x4F, 0x52, 0x51, 0x53, 0x51, 0x52, 0x51, 0x53, 0x51, 0x53, 0x51, 0x53, 0x51, 0x54, 0x53, 0x54, 0x50, 0x53, 0x50, 0x53, 0x4E, 0x50, 0x4B, 0x4C, 0x46, 0x45, 0x3C, 0x38, 0x2F, 0x27, 0x22, 0x1C, 0x1D, 0x18, 0x1C, 0x16, 0x1B, 0x14, 0x19, 0x13, 0x19, 0x12, 0x18, 0x12, 0x19, 0x12, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x17, 0x10, 0x16, 0x0F, 0x16, 0x10, 0x17, 0x11, 0x19, 0x11, 0x1A, 0x12, 0x1F, 0x14, 0x34, 0x1A, 0x4D, 0x1F, 0x55, 0x20, 0x57, 0x20, 0x49, 0x1C, 0x37, 0x1A, 0x41, 0x1D, 0x53, 0x20, 0x5A, 0x20, 0x5C, 0x21, 0x60, 0x22, 0x61, 0x22, 0x61, 0x21, 0x60, 0x22, 0x5F, 0x22, 0x60, 0x22, 0x61, 0x23, 0x61, 0x22, 0x60, 0x22, 0x5F, 0x22, 0x60, 0x22, 0x60, 0x21, 0x5E, 0x21, 0x5D, 0x20, 0x5E, 0x20, 0x5B, 0x20, 0x5E, 0x21, 0x5D, 0x21, 0x5E, 0x21, 0x5C, 0x20, 0x58, 0x1F, 0x5A, 0x20, 0x5C, 0x20, 0x5B, 0x20, 0x5D, 0x1F, 0x5C, 0x20, 0x5B, 0x20, 0x5B, 0x21, 0x5E, 0x21, 0x5C, 0x20, 0x5D, 0x20, 0x5D, 0x20, 0x5B, 0x1F, 0x5C, 0x20, 0x5E, 0x20, 0x5D, 0x21, 0x5B, 0x20, 0x5C, 0x20, 0x5D, 0x20, 0x5C, 0x20, 0x5B, 0x21, 0x5B, 0x21, 0x5B, 0x21, 0x5B, 0x20, 0x5C, 0x20, 0x5F, 0x21, 0x5E, 0x21, 0x5D, 0x21, 0x5D, 0x21, 0x5D, 0x21, 0x5D, 0x21, 0x5E, 0x21, 0x5D, 0x20, 0x5E, 0x21, 0x5B, 0x21, 0x5C, 0x21, 0x5A, 0x20, 0x5B, 0x20, 0x5A, 0x1F, 0x5D, 0x22, 0x60, 0x22, 0x5F, 0x21, 0x5F, 0x21, 0x5E, 0x21, 0x5D, 0x21, 0x5E, 0x21, 0x5D, 0x21, 0x5C, 0x20, 0x5C, 0x21, 0x5B, 0x20, 0x5A, 0x1F, 0x5C, 0x21, 0x5E, 0x21, 0x5D, 0x21, 0x5A, 0x20, 0x5C, 0x20, 0x5A, 0x20, 0x59, 0x20, 0x53, 0x22, 0x4C, 0x26, 0x3C, 0x1E, 0x31, 0x1A, 0x2E, 0x18, 0x2B, 0x17, 0x26, 0x14, 0x32, 0x18, 0x50, 0x1F, 0x58, 0x20, 0x5C, 0x21, 0x56, 0x1F, 0x4B, 0x1E, 0x46, 0x1F, 0x45, 0x21, 0x44, 0x21, 0x44, 0x21, 0x41, 0x1E, 0x33, 0x17, 0x2A, 0x14, 0x3B, 0x19, 0x51, 0x1E, 0x57, 0x20, 0x59, 0x21, 0x5B, 0x21, 0x5E, 0x22, 0x5D, 0x21, 0x5E, 0x21, 0x5C, 0x21, 0x5E, 0x21, 0x5A, 0x20, 0x5D, 0x21, 0x5B, 0x20, 0x5B, 0x20, 0x5E, 0x21, 0x5F, 0x21, 0x5D, 0x20, 0x5D, 0x21, 0x5D, 0x21, 0x5E, 0x21, 0x5C, 0x21, 0x5D, 0x21, 0x5D, 0x21, 0x5C, 0x21, 0x5E, 0x22, 0x5F, 0x22, 0x5E, 0x21, 0x5D, 0x22, 0x5F, 0x22, 0x5A, 0x21, 0x57, 0x20, 0x56, 0x1F, 0x54, 0x1E, 0x53, 0x1E, 0x53, 0x1E, 0x51, 0x1E, 0x53, 0x1E, 0x52, 0x1E, 0x52, 0x1E, 0x54, 0x1E, 0x51, 0x1D, 0x52, 0x1E, 0x51, 0x1D, 0x4E, 0x1D, 0x50, 0x1D, 0x51, 0x1E, 0x53, 0x1E, 0x52, 0x1D, 0x51, 0x1D, 0x52, 0x1E, 0x53, 0x1F, 0x52, 0x1E, 0x51, 0x1E, 0x52, 0x1F, 0x53, 0x1E, 0x52, 0x1E, 0x51, 0x1E, 0x4F, 0x1C, 0x4F, 0x1D, 0x45, 0x1A, 0x2D, 0x16, 0x23, 0x15, 0x29, 0x18, 0x25, 0x16, 0x26, 0x17, 0x24, 0x17, 0x27, 0x2B, 0x29, 0x34, 0x29, 0x35, 0x28, 0x34, 0x27, 0x34, 0x27, 0x33, 0x27, 0x30, 0x1E, 0x1A, 0x21, 0x17, 0x26, 0x16, 0x29, 0x1A, 0x28, 0x26, 0x25, 0x2C, 0x23, 0x2B, 0x23, 0x2C, 0x24, 0x2B, 0x22, 0x29, 0x22, 0x26, 0x1A, 0x15, 0x22, 0x17, 0x2A, 0x19, 0x23, 0x19, 0x27, 0x23, 0x22, 0x23, 0x20, 0x22, 0x1E, 0x21, 0x1E, 0x20, 0x1E, 0x1E, 0x1D, 0x1C, 0x19, 0x13, 0x23, 0x17, 0x22, 0x14, 0x23, 0x17, 0x21, 0x1A, 0x1C, 0x19, 0x1A, 0x18, 0x1A, 0x18
    },

    {
        0x56, 0x4C, 0x56, 0x4C, 0x56, 0x4B, 0x56, 0x4B, 0x55, 0x4C, 0x57, 0x4D, 0x57, 0x4D, 0x59, 0x4D, 0x5A, 0x4D, 0x5A, 0x4E, 0x5B, 0x4E, 0x59, 0x4D, 0x59, 0x4D, 0x59, 0x4D, 0x58, 0x4C, 0x58, 0x4B, 0x58, 0x4C, 0x59, 0x4C, 0x5A, 0x4D, 0x59, 0x4D, 0x5A, 0x4C, 0x59, 0x4D, 0x59, 0x4C, 0x5A, 0x4B, 0x5A, 0x4D, 0x5B, 0x4E, 0x5B, 0x4E, 0x5C, 0x4F, 0x5D, 0x51, 0x5C, 0x50, 0x57, 0x4C, 0x51, 0x46, 0x49, 0x3F, 0x3F, 0x39, 0x3E, 0x3B, 0x45, 0x43, 0x4B, 0x44, 0x46, 0x3F, 0x39, 0x32, 0x28, 0x23, 0x1C, 0x1C, 0x17, 0x19, 0x15, 0x17, 0x13, 0x15, 0x11, 0x14, 0x10, 0x13, 0x10, 0x13, 0x10, 0x12, 0x10, 0x13, 0x10, 0x14, 0x11, 0x14, 0x11, 0x14, 0x11, 0x15, 0x12, 0x16, 0x12, 0x16, 0x13, 0x17, 0x15, 0x19, 0x1B, 0x22, 0x28, 0x32, 0x32, 0x3D, 0x38, 0x42, 0x3B, 0x44, 0x3C, 0x46, 0x3D, 0x47, 0x3E, 0x48, 0x3F, 0x48, 0x40, 0x49, 0x41, 0x4A, 0x41, 0x4A, 0x42, 0x4B, 0x42, 0x4B, 0x42, 0x4C, 0x42, 0x4B, 0x42, 0x4C, 0x43, 0x4D, 0x42, 0x4C, 0x42, 0x4C, 0x43, 0x4D, 0x44, 0x4D, 0x44, 0x4D, 0x44, 0x4D, 0x44, 0x4D, 0x43, 0x4D, 0x41, 0x4B, 0x3E, 0x46, 0x39, 0x40, 0x30, 0x34, 0x24, 0x27, 0x1B, 0x1F, 0x18, 0x1B, 0x17, 0x1A, 0x14, 0x19, 0x14, 0x18, 0x14, 0x17, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x13, 0x16, 0x13, 0x16, 0x13, 0x16, 0x12, 0x16, 0x12, 0x15, 0x12, 0x15, 0x13, 0x16, 0x14, 0x17, 0x15, 0x18, 0x1A, 0x1B, 0x2A, 0x2F, 0x47, 0x47, 0x56, 0x51, 0x5B, 0x54, 0x50, 0x47, 0x3C, 0x35, 0x3F, 0x3C, 0x53, 0x4C, 0x5C, 0x54, 0x62, 0x57, 0x67, 0x5B, 0x69, 0x5C, 0x69, 0x5B, 0x69, 0x5C, 0x68, 0x5A, 0x6A, 0x5C, 0x6B, 0x5C, 0x69, 0x5C, 0x69, 0x5A, 0x69, 0x5A, 0x69, 0x5C, 0x69, 0x5B, 0x65, 0x58, 0x66, 0x57, 0x66, 0x57, 0x64, 0x57, 0x66, 0x59, 0x66, 0x59, 0x66, 0x59, 0x66, 0x57, 0x63, 0x55, 0x64, 0x55, 0x65, 0x58, 0x66, 0x56, 0x67, 0x58, 0x66, 0x57, 0x65, 0x55, 0x65, 0x57, 0x67, 0x58, 0x64, 0x56, 0x65, 0x57, 0x64, 0x56, 0x63, 0x55, 0x64, 0x57, 0x67, 0x57, 0x65, 0x57, 0x64, 0x58, 0x65, 0x56, 0x65, 0x57, 0x64, 0x57, 0x64, 0x57, 0x64, 0x57, 0x63, 0x56, 0x66, 0x58, 0x64, 0x57, 0x68, 0x5B, 0x67, 0x58, 0x67, 0x59, 0x68, 0x59, 0x66, 0x58, 0x65, 0x58, 0x67, 0x58, 0x66, 0x57, 0x67, 0x58, 0x64, 0x57, 0x63, 0x57, 0x64, 0x57, 0x64, 0x55, 0x64, 0x56, 0x67, 0x5A, 0x69, 0x5B, 0x68, 0x5B, 0x68, 0x5A, 0x68, 0x59, 0x68, 0x59, 0x68, 0x5A, 0x67, 0x58, 0x65, 0x58, 0x65, 0x58, 0x65, 0x56, 0x64, 0x56, 0x66, 0x57, 0x67, 0x58, 0x67, 0x58, 0x64, 0x55, 0x64, 0x56, 0x63, 0x55, 0x61, 0x54, 0x56, 0x4B, 0x47, 0x42, 0x39, 0x32, 0x31, 0x2C, 0x2E, 0x29, 0x2B, 0x26, 0x26, 0x21, 0x33, 0x33, 0x55, 0x4D, 0x5E, 0x54, 0x61, 0x57, 0x5C, 0x50, 0x4F, 0x46, 0x45, 0x42, 0x40, 0x41, 0x3F, 0x40, 0x3E, 0x3E, 0x3A, 0x39, 0x2E, 0x29, 0x2E, 0x2B, 0x42, 0x3E, 0x57, 0x4F, 0x5E, 0x53, 0x62, 0x57, 0x65, 0x57, 0x68, 0x59, 0x66, 0x59, 0x68, 0x5A, 0x65, 0x57, 0x67, 0x5B, 0x63, 0x56, 0x67, 0x59, 0x64, 0x56, 0x65, 0x57, 0x68, 0x5B, 0x68, 0x59, 0x69, 0x59, 0x67, 0x59, 0x68, 0x59, 0x67, 0x5A, 0x68, 0x59, 0x6A, 0x5A, 0x66, 0x58, 0x66, 0x58, 0x68, 0x59, 0x67, 0x5A, 0x68, 0x59, 0x67, 0x58, 0x67, 0x5C, 0x62, 0x56, 0x60, 0x52, 0x5D, 0x51, 0x5E, 0x51, 0x5C, 0x4E, 0x5B, 0x4F, 0x5A, 0x4D, 0x5C, 0x4F, 0x5C, 0x4E, 0x5B, 0x4F, 0x5C, 0x4E, 0x58, 0x4D, 0x5B, 0x4E, 0x5A, 0x4E, 0x56, 0x4B, 0x58, 0x4C, 0x5B, 0x4E, 0x5B, 0x4D, 0x59, 0x4E, 0x5B, 0x4E, 0x5C, 0x4E, 0x5D, 0x51, 0x5A, 0x4F, 0x5B, 0x4E, 0x5A, 0x4F, 0x5B, 0x4F, 0x5C, 0x4F, 0x5A, 0x4E, 0x58, 0x4C, 0x58, 0x4B, 0x47, 0x3C, 0x2C, 0x27, 0x23, 0x22, 0x27, 0x28, 0x22, 0x24, 0x22, 0x28, 0x21, 0x24, 0x1E, 0x25, 0x1C, 0x26, 0x1C, 0x25, 0x1A, 0x24, 0x1A, 0x24, 0x19, 0x23, 0x19, 0x23, 0x16, 0x19, 0x1E, 0x23, 0x20, 0x21, 0x24, 0x2A, 0x20, 0x24, 0x1A, 0x21, 0x18, 0x20, 0x18, 0x20, 0x18, 0x1F, 0x18, 0x1F, 0x17, 0x1D, 0x15, 0x17, 0x1F, 0x26, 0x25, 0x28, 0x1E, 0x20, 0x1F, 0x24, 0x19, 0x1E, 0x17, 0x1C, 0x16, 0x1C, 0x16, 0x1B, 0x16, 0x1B, 0x16, 0x1A, 0x15, 0x18, 0x20, 0x24, 0x1D, 0x1D, 0x20, 0x22, 0x1C, 0x1E, 0x16, 0x1A, 0x15, 0x18, 0x15, 0x18
    },

    {
        0x50, 0x1C, 0x4E, 0x1C, 0x4F, 0x1C, 0x4D, 0x1C, 0x4E, 0x1C, 0x4F, 0x1C, 0x4F, 0x1C, 0x50, 0x1C, 0x4F, 0x1C, 0x51, 0x1D, 0x51, 0x1D, 0x50, 0x1C, 0x50, 0x1D, 0x50, 0x1C, 0x4F, 0x1C, 0x50, 0x1C, 0x4F, 0x1C, 0x50, 0x1C, 0x4F, 0x1C, 0x4F, 0x1C, 0x4F, 0x1D, 0x51, 0x1C, 0x4F, 0x1C, 0x4F, 0x1D, 0x51, 0x1D, 0x51, 0x1D, 0x52, 0x1D, 0x52, 0x1D, 0x52, 0x1D, 0x51, 0x1D, 0x4F, 0x1E, 0x47, 0x1C, 0x40, 0x1B, 0x3B, 0x1A, 0x42, 0x1C, 0x48, 0x1C, 0x46, 0x1B, 0x3B, 0x19, 0x2C, 0x15, 0x20, 0x12, 0x1B, 0x10, 0x19, 0x10, 0x17, 0x10, 0x15, 0x0F, 0x14, 0x0E, 0x14, 0x0E, 0x14, 0x0E, 0x14, 0x0E, 0x14, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x10, 0x16, 0x11, 0x17, 0x12, 0x18, 0x13, 0x1B, 0x17, 0x23, 0x23, 0x34, 0x36, 0x40, 0x43, 0x46, 0x48, 0x47, 0x4A, 0x49, 0x4C, 0x4A, 0x4C, 0x4B, 0x4D, 0x4C, 0x4F, 0x4C, 0x4F, 0x4D, 0x50, 0x4E, 0x50, 0x4E, 0x51, 0x4D, 0x4F, 0x4D, 0x4E, 0x4E, 0x50, 0x4E, 0x51, 0x4F, 0x51, 0x4F, 0x52, 0x50, 0x52, 0x51, 0x53, 0x51, 0x53, 0x51, 0x53, 0x51, 0x52, 0x50, 0x52, 0x4D, 0x4E, 0x48, 0x45, 0x3D, 0x37, 0x2E, 0x27, 0x23, 0x1C, 0x1E, 0x18, 0x1C, 0x16, 0x1B, 0x15, 0x1A, 0x13, 0x19, 0x13, 0x18, 0x12, 0x19, 0x11, 0x18, 0x12, 0x18, 0x12, 0x18, 0x11, 0x19, 0x12, 0x18, 0x11, 0x18, 0x11, 0x19, 0x11, 0x16, 0x10, 0x16, 0x10, 0x17, 0x0F, 0x16, 0x0F, 0x17, 0x10, 0x18, 0x10, 0x1A, 0x11, 0x1E, 0x13, 0x31, 0x19, 0x4B, 0x1F, 0x56, 0x20, 0x56, 0x20, 0x4A, 0x1D, 0x38, 0x1A, 0x3E, 0x1D, 0x52, 0x20, 0x5A, 0x21, 0x5E, 0x22, 0x62, 0x23, 0x63, 0x22, 0x5F, 0x22, 0x60, 0x22, 0x61, 0x22, 0x60, 0x22, 0x61, 0x22, 0x61, 0x22, 0x60, 0x22, 0x5F, 0x22, 0x61, 0x23, 0x5F, 0x21, 0x5E, 0x21, 0x5C, 0x20, 0x5C, 0x20, 0x5C, 0x21, 0x5D, 0x21, 0x5C, 0x20, 0x5D, 0x20, 0x5A, 0x1F, 0x5C, 0x20, 0x5C, 0x20, 0x5C, 0x20, 0x5B, 0x1F, 0x5B, 0x1F, 0x5B, 0x1F, 0x5C, 0x20, 0x5F, 0x21, 0x5C, 0x20, 0x5A, 0x1F, 0x5A, 0x20, 0x5A, 0x1F, 0x5C, 0x20, 0x5D, 0x20, 0x5D, 0x21, 0x5E, 0x21, 0x5E, 0x21, 0x5E, 0x21, 0x5F, 0x21, 0x5E, 0x21, 0x5D, 0x20, 0x5D, 0x21, 0x5F, 0x21, 0x5B, 0x20, 0x5D, 0x21, 0x5E, 0x22, 0x61, 0x22, 0x5F, 0x21, 0x5F, 0x21, 0x5B, 0x20, 0x5E, 0x21, 0x5F, 0x21, 0x5D, 0x21, 0x5D, 0x21, 0x5C, 0x21, 0x5C, 0x20, 0x58, 0x1F, 0x5B, 0x20, 0x5D, 0x21, 0x60, 0x22, 0x5E, 0x21, 0x5D, 0x21, 0x5F, 0x22, 0x5F, 0x23, 0x5F, 0x22, 0x5C, 0x20, 0x5C, 0x21, 0x5C, 0x20, 0x5D, 0x21, 0x5A, 0x20, 0x5E, 0x21, 0x5C, 0x21, 0x5D, 0x21, 0x5B, 0x20, 0x5B, 0x21, 0x5C, 0x20, 0x5B, 0x20, 0x4A, 0x1F, 0x3B, 0x1C, 0x30, 0x19, 0x2C, 0x18, 0x29, 0x17, 0x27, 0x16, 0x22, 0x12, 0x2A, 0x16, 0x4E, 0x1E, 0x58, 0x21, 0x5D, 0x21, 0x5A, 0x20, 0x4D, 0x1C, 0x3E, 0x1A, 0x3E, 0x1C, 0x3D, 0x1C, 0x3A, 0x1A, 0x2E, 0x17, 0x26, 0x13, 0x30, 0x16, 0x44, 0x1B, 0x52, 0x1F, 0x57, 0x20, 0x5B, 0x20, 0x5A, 0x21, 0x5C, 0x22, 0x5D, 0x22, 0x5F, 0x22, 0x5D, 0x21, 0x5C, 0x22, 0x5C, 0x21, 0x5E, 0x21, 0x5A, 0x20, 0x5C, 0x21, 0x5F, 0x22, 0x5E, 0x21, 0x5D, 0x21, 0x5F, 0x22, 0x5E, 0x21, 0x5E, 0x21, 0x5F, 0x22, 0x5E, 0x22, 0x5D, 0x20, 0x5C, 0x21, 0x5E, 0x22, 0x5D, 0x23, 0x5F, 0x22, 0x5E, 0x22, 0x60, 0x23, 0x5F, 0x22, 0x5C, 0x20, 0x57, 0x1F, 0x55, 0x1F, 0x52, 0x1E, 0x52, 0x1E, 0x52, 0x1E, 0x57, 0x20, 0x55, 0x1F, 0x54, 0x1F, 0x54, 0x1E, 0x54, 0x1E, 0x51, 0x1D, 0x52, 0x1D, 0x53, 0x1E, 0x51, 0x1E, 0x51, 0x1E, 0x51, 0x1E, 0x52, 0x1D, 0x52, 0x1E, 0x51, 0x1E, 0x52, 0x1E, 0x52, 0x1F, 0x53, 0x1E, 0x52, 0x1E, 0x52, 0x1F, 0x54, 0x1F, 0x53, 0x1E, 0x50, 0x1E, 0x4F, 0x1D, 0x42, 0x1A, 0x30, 0x18, 0x26, 0x17, 0x2D, 0x1A, 0x2F, 0x1A, 0x27, 0x17, 0x29, 0x19, 0x25, 0x1D, 0x23, 0x1F, 0x1F, 0x1E, 0x1F, 0x1D, 0x1E, 0x1C, 0x1D, 0x1A, 0x1D, 0x1A, 0x1A, 0x14, 0x25, 0x19, 0x25, 0x16, 0x27, 0x19, 0x27, 0x19, 0x1D, 0x16, 0x1A, 0x15, 0x19, 0x15, 0x1A, 0x15, 0x19, 0x14, 0x19, 0x14, 0x19, 0x13, 0x27, 0x18, 0x23, 0x15, 0x21, 0x16, 0x26, 0x18, 0x1B, 0x15, 0x1B, 0x15, 0x1C, 0x15, 0x1D, 0x15, 0x1C, 0x15, 0x20, 0x16, 0x21, 0x15, 0x24, 0x15, 0x24, 0x16, 0x2A, 0x18, 0x27, 0x17, 0x20, 0x15, 0x1D, 0x14, 0x1F, 0x14
    },

    {
        0x57, 0x4D, 0x56, 0x4C, 0x56, 0x4C, 0x55, 0x4B, 0x54, 0x4A, 0x56, 0x4D, 0x59, 0x4D, 0x58, 0x4D, 0x58, 0x4C, 0x59, 0x4D, 0x5A, 0x4D, 0x5A, 0x4D, 0x5A, 0x4D, 0x59, 0x4C, 0x58, 0x4C, 0x58, 0x4C, 0x58, 0x4C, 0x5B, 0x4C, 0x58, 0x4C, 0x57, 0x4C, 0x59, 0x4D, 0x59, 0x4D, 0x59, 0x4C, 0x58, 0x4C, 0x5A, 0x4D, 0x5A, 0x4D, 0x5C, 0x4F, 0x5C, 0x50, 0x5C, 0x4F, 0x58, 0x4D, 0x53, 0x49, 0x4A, 0x42, 0x41, 0x3B, 0x3D, 0x3B, 0x45, 0x42, 0x4B, 0x45, 0x47, 0x3F, 0x39, 0x34, 0x28, 0x25, 0x1D, 0x1C, 0x18, 0x18, 0x15, 0x17, 0x13, 0x15, 0x11, 0x14, 0x11, 0x13, 0x10, 0x13, 0x10, 0x13, 0x10, 0x13, 0x10, 0x13, 0x10, 0x13, 0x10, 0x14, 0x10, 0x14, 0x11, 0x14, 0x11, 0x15, 0x12, 0x15, 0x12, 0x15, 0x13, 0x17, 0x15, 0x19, 0x1A, 0x20, 0x26, 0x30, 0x31, 0x3C, 0x38, 0x41, 0x39, 0x43, 0x3C, 0x44, 0x3D, 0x45, 0x3E, 0x47, 0x3F, 0x49, 0x40, 0x49, 0x40, 0x4A, 0x41, 0x4A, 0x40, 0x4B, 0x40, 0x49, 0x3F, 0x48, 0x3F, 0x49, 0x3F, 0x49, 0x41, 0x4B, 0x41, 0x4B, 0x43, 0x4C, 0x44, 0x4E, 0x45, 0x4E, 0x44, 0x4D, 0x43, 0x4D, 0x42, 0x4B, 0x3F, 0x48, 0x3A, 0x41, 0x31, 0x35, 0x25, 0x28, 0x1C, 0x1F, 0x18, 0x1C, 0x16, 0x1A, 0x16, 0x19, 0x15, 0x19, 0x15, 0x19, 0x13, 0x17, 0x13, 0x17, 0x13, 0x18, 0x14, 0x17, 0x13, 0x17, 0x13, 0x17, 0x14, 0x17, 0x14, 0x17, 0x14, 0x17, 0x13, 0x16, 0x12, 0x15, 0x12, 0x15, 0x12, 0x15, 0x12, 0x16, 0x13, 0x16, 0x15, 0x18, 0x19, 0x1C, 0x28, 0x2C, 0x44, 0x46, 0x56, 0x50, 0x59, 0x51, 0x50, 0x48, 0x3F, 0x37, 0x3E, 0x3B, 0x52, 0x4E, 0x5F, 0x56, 0x65, 0x59, 0x69, 0x5B, 0x6B, 0x5C, 0x69, 0x5A, 0x68, 0x5C, 0x6B, 0x5C, 0x6A, 0x5C, 0x6A, 0x5C, 0x6A, 0x5C, 0x69, 0x5B, 0x67, 0x5A, 0x69, 0x5C, 0x68, 0x5B, 0x67, 0x5A, 0x65, 0x57, 0x64, 0x57, 0x64, 0x58, 0x65, 0x58, 0x66, 0x57, 0x67, 0x57, 0x64, 0x56, 0x65, 0x57, 0x66, 0x58, 0x65, 0x56, 0x64, 0x55, 0x64, 0x56, 0x64, 0x55, 0x65, 0x58, 0x66, 0x59, 0x66, 0x57, 0x62, 0x54, 0x64, 0x56, 0x64, 0x56, 0x65, 0x57, 0x66, 0x57, 0x67, 0x59, 0x67, 0x5A, 0x67, 0x59, 0x66, 0x59, 0x67, 0x5B, 0x66, 0x5B, 0x66, 0x58, 0x66, 0x59, 0x66, 0x5A, 0x66, 0x58, 0x67, 0x5A, 0x67, 0x5A, 0x69, 0x5C, 0x68, 0x5A, 0x68, 0x5A, 0x65, 0x57, 0x68, 0x59, 0x67, 0x59, 0x66, 0x58, 0x66, 0x57, 0x66, 0x58, 0x65, 0x56, 0x62, 0x55, 0x63, 0x55, 0x66, 0x58, 0x67, 0x5A, 0x65, 0x58, 0x66, 0x58, 0x69, 0x5B, 0x69, 0x5B, 0x69, 0x5B, 0x66, 0x58, 0x65, 0x57, 0x65, 0x58, 0x65, 0x58, 0x63, 0x56, 0x66, 0x59, 0x66, 0x58, 0x67, 0x58, 0x65, 0x57, 0x63, 0x57, 0x66, 0x58, 0x63, 0x55, 0x4E, 0x41, 0x3C, 0x34, 0x32, 0x2C, 0x2C, 0x29, 0x2A, 0x26, 0x27, 0x24, 0x22, 0x1E, 0x2F, 0x2E, 0x53, 0x4E, 0x5D, 0x55, 0x63, 0x58, 0x62, 0x55, 0x53, 0x47, 0x40, 0x3A, 0x3C, 0x38, 0x38, 0x34, 0x34, 0x30, 0x2C, 0x27, 0x29, 0x26, 0x37, 0x35, 0x4B, 0x47, 0x5A, 0x52, 0x5F, 0x55, 0x62, 0x58, 0x61, 0x56, 0x65, 0x59, 0x67, 0x58, 0x68, 0x5C, 0x66, 0x5A, 0x64, 0x59, 0x64, 0x58, 0x67, 0x58, 0x65, 0x57, 0x64, 0x59, 0x68, 0x5B, 0x66, 0x59, 0x68, 0x5A, 0x69, 0x5B, 0x68, 0x59, 0x68, 0x5A, 0x68, 0x5B, 0x68, 0x5A, 0x65, 0x57, 0x67, 0x58, 0x67, 0x59, 0x66, 0x5B, 0x67, 0x5A, 0x67, 0x5A, 0x68, 0x5B, 0x67, 0x59, 0x65, 0x57, 0x61, 0x53, 0x5F, 0x51, 0x5C, 0x4F, 0x5A, 0x4F, 0x5B, 0x4E, 0x5E, 0x52, 0x5D, 0x51, 0x5D, 0x51, 0x5A, 0x4F, 0x5B, 0x4F, 0x59, 0x4D, 0x59, 0x4E, 0x5A, 0x4F, 0x5A, 0x4E, 0x58, 0x4C, 0x57, 0x4C, 0x5C, 0x50, 0x5B, 0x4F, 0x5A, 0x4E, 0x5B, 0x4F, 0x5A, 0x50, 0x5B, 0x50, 0x5B, 0x4E, 0x5A, 0x4F, 0x5C, 0x52, 0x5B, 0x50, 0x59, 0x4D, 0x58, 0x4B, 0x47, 0x3E, 0x31, 0x2F, 0x26, 0x25, 0x2A, 0x2D, 0x29, 0x2C, 0x22, 0x21, 0x26, 0x28, 0x1F, 0x22, 0x1B, 0x1F, 0x18, 0x1D, 0x17, 0x1C, 0x18, 0x1C, 0x18, 0x1C, 0x17, 0x1B, 0x17, 0x19, 0x22, 0x27, 0x1F, 0x22, 0x22, 0x25, 0x21, 0x22, 0x18, 0x1A, 0x16, 0x18, 0x16, 0x19, 0x16, 0x1A, 0x16, 0x19, 0x17, 0x1A, 0x17, 0x1A, 0x21, 0x26, 0x1F, 0x20, 0x1E, 0x22, 0x22, 0x22, 0x19, 0x1C, 0x1A, 0x1E, 0x19, 0x1D, 0x1B, 0x1D, 0x1B, 0x1F, 0x1E, 0x22, 0x1D, 0x20, 0x20, 0x23, 0x22, 0x27, 0x24, 0x28, 0x23, 0x25, 0x1E, 0x20, 0x1A, 0x1C, 0x1D, 0x20
    },

    {
        0x4F, 0x1D, 0x4F, 0x1C, 0x4F, 0x1C, 0x4E, 0x1C, 0x4F, 0x1B, 0x50, 0x1C, 0x50, 0x1C, 0x51, 0x1D, 0x50, 0x1D, 0x50, 0x1C, 0x50, 0x1C, 0x51, 0x1C, 0x51, 0x1C, 0x51, 0x1D, 0x4F, 0x1C, 0x50, 0x1C, 0x4F, 0x1C, 0x50, 0x1D, 0x50, 0x1C, 0x4F, 0x1D, 0x4F, 0x1D, 0x4F, 0x1C, 0x4E, 0x1C, 0x4F, 0x1C, 0x50, 0x1D, 0x52, 0x1D, 0x52, 0x1E, 0x52, 0x1D, 0x50, 0x1D, 0x4E, 0x1D, 0x48, 0x1C, 0x40, 0x1B, 0x3C, 0x1A, 0x42, 0x1B, 0x48, 0x1D, 0x45, 0x1B, 0x3B, 0x19, 0x2E, 0x15, 0x21, 0x12, 0x1B, 0x11, 0x1A, 0x0F, 0x18, 0x10, 0x15, 0x0F, 0x15, 0x0F, 0x14, 0x0E, 0x14, 0x0E, 0x14, 0x0F, 0x14, 0x0E, 0x14, 0x0F, 0x14, 0x0F, 0x15, 0x0F, 0x14, 0x0E, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x10, 0x16, 0x10, 0x16, 0x11, 0x18, 0x13, 0x19, 0x16, 0x21, 0x21, 0x33, 0x34, 0x3F, 0x42, 0x45, 0x48, 0x47, 0x4A, 0x49, 0x4C, 0x4A, 0x4D, 0x4B, 0x4E, 0x4D, 0x4F, 0x4C, 0x4F, 0x4D, 0x50, 0x4C, 0x4E, 0x4A, 0x48, 0x43, 0x42, 0x45, 0x45, 0x4A, 0x4C, 0x4C, 0x4F, 0x4E, 0x50, 0x50, 0x51, 0x51, 0x54, 0x52, 0x54, 0x52, 0x54, 0x51, 0x53, 0x4E, 0x4F, 0x48, 0x48, 0x40, 0x3A, 0x2F, 0x29, 0x24, 0x1D, 0x1E, 0x18, 0x1C, 0x16, 0x1A, 0x14, 0x1A, 0x14, 0x19, 0x13, 0x19, 0x12, 0x19, 0x12, 0x18, 0x11, 0x18, 0x11, 0x19, 0x11, 0x18, 0x11, 0x18, 0x11, 0x19, 0x11, 0x19, 0x11, 0x18, 0x11, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x18, 0x10, 0x1A, 0x11, 0x1E, 0x13, 0x2F, 0x18, 0x48, 0x1E, 0x53, 0x20, 0x56, 0x20, 0x4D, 0x1D, 0x39, 0x1A, 0x40, 0x1D, 0x53, 0x20, 0x5C, 0x21, 0x5F, 0x22, 0x61, 0x22, 0x61, 0x23, 0x60, 0x22, 0x61, 0x22, 0x62, 0x22, 0x61, 0x21, 0x60, 0x22, 0x61, 0x22, 0x60, 0x22, 0x61, 0x23, 0x61, 0x22, 0x5E, 0x21, 0x5E, 0x21, 0x5E, 0x21, 0x5C, 0x20, 0x5C, 0x20, 0x5D, 0x20, 0x5F, 0x21, 0x5B, 0x20, 0x5C, 0x20, 0x5D, 0x20, 0x5A, 0x1F, 0x5A, 0x20, 0x5B, 0x1F, 0x5B, 0x20, 0x5D, 0x21, 0x5F, 0x21, 0x5A, 0x20, 0x59, 0x1F, 0x58, 0x1F, 0x5B, 0x1F, 0x5C, 0x20, 0x5C, 0x20, 0x5F, 0x21, 0x5E, 0x21, 0x5E, 0x21, 0x5F, 0x21, 0x60, 0x22, 0x61, 0x23, 0x60, 0x22, 0x60, 0x22, 0x61, 0x22, 0x5E, 0x21, 0x5E, 0x22, 0x5F, 0x22, 0x61, 0x22, 0x60, 0x22, 0x5F, 0x21, 0x5D, 0x20, 0x5D, 0x21, 0x5D, 0x20, 0x5E, 0x21, 0x5D, 0x21, 0x5F, 0x21, 0x5B, 0x20, 0x59, 0x1F, 0x59, 0x20, 0x5B, 0x20, 0x5B, 0x20, 0x5D, 0x20, 0x5E, 0x20, 0x5D, 0x22, 0x64, 0x25, 0x62, 0x22, 0x5C, 0x20, 0x5B, 0x21, 0x5F, 0x21, 0x5F, 0x21, 0x5C, 0x20, 0x5A, 0x20, 0x5C, 0x21, 0x5D, 0x20, 0x5B, 0x20, 0x5D, 0x22, 0x5D, 0x22, 0x5D, 0x21, 0x48, 0x1C, 0x34, 0x19, 0x2B, 0x17, 0x29, 0x16, 0x27, 0x15, 0x24, 0x13, 0x1E, 0x11, 0x30, 0x17, 0x52, 0x1F, 0x58, 0x21, 0x5C, 0x21, 0x5C, 0x21, 0x54, 0x1E, 0x41, 0x1A, 0x34, 0x17, 0x2F, 0x15, 0x2A, 0x14, 0x2A, 0x14, 0x32, 0x17, 0x40, 0x1B, 0x4D, 0x1D, 0x57, 0x20, 0x5A, 0x21, 0x5C, 0x21, 0x5D, 0x21, 0x5D, 0x21, 0x5C, 0x21, 0x5F, 0x22, 0x62, 0x23, 0x5D, 0x21, 0x5C, 0x21, 0x5F, 0x21, 0x5F, 0x21, 0x5F, 0x22, 0x5F, 0x22, 0x5F, 0x21, 0x5E, 0x21, 0x5F, 0x21, 0x5D, 0x21, 0x5F, 0x21, 0x5F, 0x22, 0x5F, 0x22, 0x5D, 0x21, 0x5E, 0x21, 0x5F, 0x22, 0x5E, 0x22, 0x5D, 0x21, 0x5E, 0x22, 0x5D, 0x22, 0x5C, 0x21, 0x5C, 0x21, 0x5A, 0x20, 0x56, 0x1F, 0x54, 0x1F, 0x55, 0x1E, 0x53, 0x1E, 0x53, 0x1E, 0x56, 0x20, 0x57, 0x20, 0x54, 0x1E, 0x53, 0x1E, 0x52, 0x1E, 0x51, 0x1D, 0x51, 0x1D, 0x51, 0x1E, 0x52, 0x1E, 0x51, 0x1E, 0x53, 0x1E, 0x53, 0x21, 0x56, 0x20, 0x53, 0x1E, 0x54, 0x1F, 0x54, 0x1E, 0x53, 0x1F, 0x54, 0x1F, 0x54, 0x1E, 0x53, 0x1E, 0x50, 0x1D, 0x50, 0x1D, 0x42, 0x1A, 0x31, 0x19, 0x27, 0x17, 0x30, 0x1A, 0x26, 0x16, 0x20, 0x15, 0x28, 0x18, 0x24, 0x17, 0x22, 0x16, 0x1F, 0x16, 0x20, 0x16, 0x21, 0x17, 0x24, 0x18, 0x25, 0x17, 0x21, 0x16, 0x28, 0x18, 0x2A, 0x18, 0x29, 0x18, 0x27, 0x17, 0x1F, 0x15, 0x23, 0x16, 0x23, 0x17, 0x26, 0x18, 0x20, 0x15, 0x25, 0x17, 0x22, 0x16, 0x27, 0x17, 0x25, 0x16, 0x24, 0x16, 0x26, 0x16, 0x24, 0x17, 0x28, 0x18, 0x22, 0x16, 0x27, 0x17, 0x23, 0x16, 0x26, 0x17, 0x22, 0x15, 0x26, 0x16, 0x26, 0x16, 0x21, 0x14, 0x23, 0x15, 0x20, 0x14, 0x20, 0x15, 0x29, 0x18
    },

    {
        0x57, 0x4C, 0x57, 0x4C, 0x57, 0x4C, 0x56, 0x4C, 0x56, 0x4C, 0x56, 0x4C, 0x58, 0x4C, 0x59, 0x4D, 0x58, 0x4D, 0x58, 0x4C, 0x58, 0x4D, 0x5A, 0x4D, 0x5A, 0x4E, 0x5A, 0x4E, 0x59, 0x4D, 0x58, 0x4C, 0x57, 0x4C, 0x5A, 0x4D, 0x5A, 0x4D, 0x59, 0x4C, 0x57, 0x4C, 0x57, 0x4C, 0x59, 0x4C, 0x58, 0x4B, 0x5A, 0x4D, 0x5B, 0x4E, 0x5B, 0x4F, 0x5B, 0x4F, 0x58, 0x4C, 0x53, 0x48, 0x4C, 0x42, 0x41, 0x3A, 0x3C, 0x39, 0x43, 0x41, 0x4B, 0x46, 0x46, 0x3F, 0x3A, 0x34, 0x29, 0x25, 0x1D, 0x1D, 0x18, 0x19, 0x15, 0x17, 0x13, 0x15, 0x11, 0x14, 0x10, 0x13, 0x11, 0x13, 0x10, 0x13, 0x10, 0x13, 0x10, 0x13, 0x10, 0x13, 0x11, 0x14, 0x11, 0x13, 0x10, 0x14, 0x11, 0x14, 0x11, 0x14, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x12, 0x16, 0x14, 0x18, 0x18, 0x1F, 0x25, 0x2E, 0x31, 0x3C, 0x37, 0x42, 0x3B, 0x44, 0x3C, 0x46, 0x3D, 0x47, 0x3E, 0x47, 0x3F, 0x49, 0x40, 0x48, 0x3F, 0x4A, 0x3F, 0x48, 0x3B, 0x44, 0x37, 0x3D, 0x36, 0x3E, 0x39, 0x45, 0x3D, 0x49, 0x40, 0x4B, 0x41, 0x4C, 0x42, 0x4C, 0x44, 0x4E, 0x43, 0x4D, 0x42, 0x4D, 0x3F, 0x49, 0x3B, 0x43, 0x33, 0x38, 0x26, 0x29, 0x1C, 0x1F, 0x19, 0x1C, 0x17, 0x1B, 0x16, 0x19, 0x15, 0x19, 0x14, 0x18, 0x14, 0x17, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x14, 0x18, 0x13, 0x17, 0x13, 0x16, 0x13, 0x16, 0x12, 0x15, 0x12, 0x15, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x13, 0x16, 0x15, 0x18, 0x18, 0x1B, 0x24, 0x28, 0x41, 0x41, 0x52, 0x4D, 0x5A, 0x52, 0x55, 0x4B, 0x3F, 0x37, 0x3E, 0x3B, 0x53, 0x4C, 0x61, 0x57, 0x66, 0x5A, 0x67, 0x5C, 0x69, 0x5C, 0x67, 0x5B, 0x68, 0x5B, 0x69, 0x5C, 0x69, 0x5B, 0x68, 0x5A, 0x6A, 0x5D, 0x69, 0x5C, 0x6A, 0x5B, 0x69, 0x5B, 0x67, 0x5A, 0x66, 0x59, 0x66, 0x5A, 0x64, 0x58, 0x65, 0x57, 0x65, 0x59, 0x68, 0x59, 0x65, 0x56, 0x65, 0x58, 0x66, 0x58, 0x64, 0x55, 0x63, 0x55, 0x64, 0x56, 0x65, 0x57, 0x66, 0x58, 0x67, 0x59, 0x63, 0x56, 0x62, 0x53, 0x61, 0x55, 0x63, 0x55, 0x64, 0x57, 0x65, 0x57, 0x67, 0x59, 0x66, 0x59, 0x68, 0x58, 0x66, 0x5A, 0x67, 0x5A, 0x68, 0x5C, 0x68, 0x5A, 0x68, 0x5C, 0x68, 0x5B, 0x67, 0x59, 0x67, 0x5A, 0x67, 0x5A, 0x6A, 0x5C, 0x68, 0x5A, 0x68, 0x5A, 0x66, 0x58, 0x68, 0x59, 0x65, 0x58, 0x67, 0x59, 0x66, 0x59, 0x67, 0x59, 0x64, 0x56, 0x62, 0x54, 0x63, 0x55, 0x63, 0x57, 0x65, 0x56, 0x66, 0x59, 0x67, 0x58, 0x67, 0x59, 0x6C, 0x5F, 0x6A, 0x5B, 0x65, 0x57, 0x64, 0x58, 0x67, 0x5A, 0x67, 0x59, 0x65, 0x57, 0x64, 0x55, 0x65, 0x57, 0x66, 0x57, 0x65, 0x57, 0x66, 0x59, 0x65, 0x5A, 0x65, 0x57, 0x4E, 0x41, 0x36, 0x2E, 0x2E, 0x27, 0x2A, 0x26, 0x27, 0x23, 0x24, 0x1F, 0x21, 0x1D, 0x36, 0x37, 0x58, 0x50, 0x5E, 0x55, 0x62, 0x57, 0x62, 0x56, 0x5A, 0x4E, 0x4B, 0x41, 0x3B, 0x32, 0x33, 0x2D, 0x2D, 0x29, 0x30, 0x2C, 0x39, 0x36, 0x4A, 0x44, 0x56, 0x4E, 0x5E, 0x54, 0x62, 0x57, 0x64, 0x59, 0x65, 0x58, 0x67, 0x5A, 0x66, 0x59, 0x68, 0x5C, 0x6A, 0x5C, 0x65, 0x58, 0x64, 0x58, 0x67, 0x5A, 0x68, 0x5A, 0x67, 0x5A, 0x66, 0x5A, 0x67, 0x5A, 0x68, 0x5B, 0x68, 0x5A, 0x67, 0x58, 0x67, 0x59, 0x69, 0x5B, 0x68, 0x59, 0x66, 0x59, 0x68, 0x59, 0x66, 0x59, 0x66, 0x5A, 0x65, 0x59, 0x67, 0x5A, 0x65, 0x58, 0x64, 0x58, 0x65, 0x58, 0x62, 0x55, 0x5F, 0x52, 0x5D, 0x52, 0x5D, 0x51, 0x5B, 0x4F, 0x5A, 0x4E, 0x5D, 0x54, 0x5E, 0x52, 0x5B, 0x4F, 0x5A, 0x4F, 0x59, 0x4D, 0x58, 0x4D, 0x58, 0x4D, 0x59, 0x4E, 0x5A, 0x50, 0x5A, 0x4F, 0x5B, 0x4F, 0x5A, 0x52, 0x5C, 0x52, 0x5A, 0x4E, 0x5C, 0x52, 0x5C, 0x50, 0x5A, 0x4F, 0x5B, 0x52, 0x5B, 0x50, 0x5B, 0x4E, 0x58, 0x4B, 0x58, 0x4C, 0x45, 0x3C, 0x30, 0x2D, 0x25, 0x27, 0x29, 0x2B, 0x21, 0x21, 0x1D, 0x1F, 0x24, 0x26, 0x23, 0x25, 0x1F, 0x22, 0x1C, 0x1F, 0x1E, 0x21, 0x1F, 0x23, 0x22, 0x27, 0x22, 0x25, 0x1E, 0x21, 0x25, 0x2A, 0x26, 0x29, 0x24, 0x27, 0x22, 0x24, 0x1E, 0x21, 0x20, 0x23, 0x1F, 0x23, 0x22, 0x25, 0x1D, 0x1E, 0x22, 0x27, 0x1E, 0x21, 0x23, 0x27, 0x22, 0x23, 0x1F, 0x24, 0x23, 0x24, 0x1F, 0x24, 0x22, 0x23, 0x1D, 0x22, 0x21, 0x22, 0x1E, 0x20, 0x22, 0x23, 0x1E, 0x20, 0x21, 0x24, 0x22, 0x22, 0x1D, 0x1E, 0x20, 0x21, 0x1C, 0x1E, 0x1D, 0x21, 0x24, 0x28
    },

    {
        0x4F, 0x1D, 0x4F, 0x1C, 0x4F, 0x1C, 0x4F, 0x1C, 0x4F, 0x1C, 0x4F, 0x1C, 0x50, 0x1C, 0x51, 0x1D, 0x50, 0x1D, 0x50, 0x1D, 0x4F, 0x1C, 0x51, 0x1D, 0x51, 0x1D, 0x52, 0x1D, 0x51, 0x1D, 0x4F, 0x1C, 0x50, 0x1C, 0x50, 0x1D, 0x50, 0x1D, 0x4F, 0x1D, 0x4F, 0x1D, 0x4F, 0x1D, 0x4F, 0x1D, 0x50, 0x1C, 0x51, 0x1C, 0x52, 0x1D, 0x52, 0x1D, 0x52, 0x1E, 0x4E, 0x1D, 0x47, 0x1B, 0x3F, 0x1A, 0x3A, 0x19, 0x3D, 0x1A, 0x47, 0x1C, 0x46, 0x1C, 0x3D, 0x18, 0x2E, 0x16, 0x22, 0x13, 0x1C, 0x11, 0x19, 0x10, 0x18, 0x0F, 0x16, 0x0F, 0x14, 0x0F, 0x14, 0x0E, 0x13, 0x0E, 0x13, 0x0E, 0x14, 0x0E, 0x14, 0x0E, 0x14, 0x0F, 0x14, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x10, 0x15, 0x0F, 0x15, 0x10, 0x16, 0x11, 0x17, 0x12, 0x19, 0x15, 0x1F, 0x1F, 0x30, 0x32, 0x3F, 0x42, 0x45, 0x48, 0x47, 0x4A, 0x49, 0x4B, 0x4A, 0x4D, 0x4C, 0x4F, 0x4C, 0x4F, 0x4D, 0x4D, 0x48, 0x49, 0x41, 0x3D, 0x35, 0x2F, 0x2F, 0x2E, 0x3B, 0x3D, 0x46, 0x49, 0x4C, 0x4F, 0x4E, 0x4F, 0x50, 0x51, 0x50, 0x53, 0x52, 0x53, 0x4F, 0x51, 0x4A, 0x48, 0x40, 0x3B, 0x33, 0x2A, 0x25, 0x1E, 0x1F, 0x18, 0x1C, 0x16, 0x1B, 0x14, 0x1A, 0x14, 0x19, 0x13, 0x19, 0x12, 0x18, 0x12, 0x19, 0x12, 0x18, 0x11, 0x18, 0x11, 0x19, 0x12, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x17, 0x10, 0x17, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x11, 0x1A, 0x11, 0x1D, 0x12, 0x2B, 0x18, 0x44, 0x1C, 0x53, 0x20, 0x57, 0x20, 0x51, 0x1F, 0x3B, 0x1A, 0x3D, 0x1C, 0x51, 0x20, 0x5C, 0x22, 0x5F, 0x22, 0x61, 0x23, 0x60, 0x22, 0x5F, 0x22, 0x61, 0x22, 0x5F, 0x22, 0x61, 0x23, 0x61, 0x22, 0x5F, 0x22, 0x60, 0x23, 0x5F, 0x22, 0x5D, 0x21, 0x5E, 0x21, 0x5F, 0x22, 0x5D, 0x20, 0x5D, 0x20, 0x5B, 0x20, 0x5F, 0x21, 0x5C, 0x21, 0x5B, 0x20, 0x5B, 0x20, 0x5B, 0x21, 0x5B, 0x20, 0x5A, 0x20, 0x5D, 0x20, 0x5D, 0x21, 0x5D, 0x21, 0x5B, 0x20, 0x59, 0x20, 0x5A, 0x1F, 0x5B, 0x1F, 0x5B, 0x20, 0x5D, 0x20, 0x5E, 0x20, 0x5C, 0x21, 0x5D, 0x21, 0x5F, 0x21, 0x5F, 0x21, 0x5F, 0x22, 0x5F, 0x22, 0x5D, 0x21, 0x5E, 0x21, 0x5E, 0x21, 0x5D, 0x21, 0x5E, 0x21, 0x5F, 0x22, 0x5E, 0x21, 0x61, 0x22, 0x5D, 0x21, 0x5F, 0x21, 0x5D, 0x21, 0x5D, 0x21, 0x5D, 0x21, 0x5D, 0x21, 0x5C, 0x21, 0x5C, 0x20, 0x5A, 0x1F, 0x5C, 0x21, 0x5C, 0x21, 0x5D, 0x21, 0x5D, 0x20, 0x5C, 0x20, 0x5D, 0x20, 0x5E, 0x21, 0x5D, 0x21, 0x5E, 0x21, 0x60, 0x22, 0x60, 0x21, 0x5B, 0x20, 0x5C, 0x20, 0x5A, 0x20, 0x5B, 0x20, 0x5D, 0x21, 0x60, 0x23, 0x5E, 0x21, 0x5C, 0x21, 0x50, 0x1D, 0x35, 0x17, 0x29, 0x15, 0x26, 0x14, 0x23, 0x13, 0x1F, 0x12, 0x23, 0x13, 0x41, 0x1B, 0x54, 0x1E, 0x56, 0x1F, 0x59, 0x20, 0x5B, 0x20, 0x59, 0x20, 0x52, 0x1E, 0x46, 0x1B, 0x3D, 0x18, 0x3A, 0x18, 0x40, 0x1A, 0x46, 0x1C, 0x4F, 0x1E, 0x56, 0x1F, 0x5A, 0x21, 0x5D, 0x22, 0x5D, 0x21, 0x5E, 0x22, 0x5C, 0x21, 0x5C, 0x21, 0x5E, 0x21, 0x5F, 0x21, 0x5F, 0x22, 0x5E, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x60, 0x22, 0x61, 0x23, 0x5E, 0x22, 0x5E, 0x22, 0x5D, 0x22, 0x5D, 0x22, 0x5F, 0x21, 0x5F, 0x21, 0x5F, 0x22, 0x60, 0x22, 0x60, 0x23, 0x5F, 0x22, 0x60, 0x23, 0x5D, 0x21, 0x5D, 0x22, 0x5D, 0x22, 0x5B, 0x21, 0x5C, 0x21, 0x58, 0x20, 0x58, 0x20, 0x56, 0x1F, 0x54, 0x1E, 0x55, 0x1F, 0x51, 0x1E, 0x54, 0x1F, 0x55, 0x1F, 0x54, 0x1E, 0x53, 0x1E, 0x51, 0x1D, 0x51, 0x1E, 0x50, 0x1D, 0x52, 0x1E, 0x52, 0x1E, 0x53, 0x1F, 0x55, 0x1F, 0x53, 0x1F, 0x53, 0x1F, 0x55, 0x1F, 0x54, 0x1F, 0x52, 0x1E, 0x52, 0x1E, 0x54, 0x1E, 0x52, 0x1E, 0x51, 0x1E, 0x50, 0x1E, 0x50, 0x1E, 0x46, 0x1C, 0x33, 0x19, 0x2A, 0x18, 0x2B, 0x18, 0x27, 0x17, 0x24, 0x16, 0x2D, 0x1A, 0x2B, 0x19, 0x28, 0x18, 0x25, 0x17, 0x28, 0x19, 0x25, 0x16, 0x28, 0x19, 0x24, 0x16, 0x22, 0x17, 0x2C, 0x19, 0x24, 0x15, 0x24, 0x16, 0x21, 0x15, 0x22, 0x16, 0x25, 0x16, 0x20, 0x15, 0x25, 0x16, 0x1E, 0x14, 0x25, 0x16, 0x20, 0x15, 0x28, 0x18, 0x21, 0x14, 0x24, 0x16, 0x21, 0x15, 0x24, 0x17, 0x1F, 0x15, 0x26, 0x18, 0x1F, 0x14, 0x21, 0x15, 0x26, 0x17, 0x1F, 0x14, 0x21, 0x14, 0x20, 0x14, 0x24, 0x16, 0x26, 0x17, 0x24, 0x16, 0x24, 0x16, 0x23, 0x15
    },

    {
        0x57, 0x4C, 0x56, 0x4C, 0x57, 0x4C, 0x57, 0x4C, 0x58, 0x4C, 0x57, 0x4D, 0x58, 0x4D, 0x5A, 0x4D, 0x58, 0x4D, 0x59, 0x4D, 0x59, 0x4D, 0x5A, 0x4E, 0x5A, 0x4D, 0x5A, 0x4E, 0x5A, 0x4E, 0x5A, 0x4D, 0x5A, 0x4D, 0x5A, 0x4D, 0x5A, 0x4D, 0x58, 0x4C, 0x58, 0x4C, 0x57, 0x4B, 0x58, 0x4D, 0x5A, 0x4D, 0x5A, 0x4E, 0x5C, 0x4F, 0x5C, 0x50, 0x59, 0x4E, 0x55, 0x49, 0x4C, 0x41, 0x41, 0x3A, 0x3C, 0x38, 0x40, 0x3F, 0x48, 0x45, 0x48, 0x41, 0x3D, 0x35, 0x2C, 0x27, 0x1E, 0x1D, 0x18, 0x19, 0x16, 0x17, 0x13, 0x15, 0x11, 0x14, 0x10, 0x14, 0x10, 0x12, 0x0F, 0x12, 0x10, 0x13, 0x10, 0x13, 0x10, 0x13, 0x10, 0x14, 0x10, 0x13, 0x10, 0x13, 0x10, 0x13, 0x10, 0x14, 0x11, 0x14, 0x11, 0x14, 0x11, 0x14, 0x11, 0x14, 0x12, 0x15, 0x13, 0x17, 0x14, 0x18, 0x18, 0x1D, 0x23, 0x2C, 0x30, 0x3B, 0x37, 0x40, 0x39, 0x43, 0x3B, 0x45, 0x3D, 0x47, 0x3E, 0x48, 0x40, 0x49, 0x40, 0x47, 0x3B, 0x43, 0x35, 0x3B, 0x2B, 0x2E, 0x24, 0x29, 0x2D, 0x37, 0x36, 0x42, 0x3C, 0x47, 0x3F, 0x49, 0x41, 0x4B, 0x43, 0x4D, 0x42, 0x4D, 0x40, 0x4B, 0x3C, 0x44, 0x35, 0x38, 0x28, 0x2B, 0x1E, 0x20, 0x18, 0x1C, 0x16, 0x1A, 0x16, 0x19, 0x15, 0x18, 0x15, 0x18, 0x13, 0x18, 0x13, 0x17, 0x14, 0x18, 0x13, 0x17, 0x14, 0x18, 0x14, 0x18, 0x14, 0x17, 0x13, 0x17, 0x13, 0x16, 0x13, 0x16, 0x13, 0x16, 0x13, 0x16, 0x12, 0x15, 0x12, 0x16, 0x12, 0x15, 0x12, 0x16, 0x12, 0x15, 0x12, 0x15, 0x13, 0x16, 0x16, 0x19, 0x18, 0x1A, 0x22, 0x25, 0x3C, 0x3E, 0x52, 0x4E, 0x5A, 0x54, 0x58, 0x4F, 0x41, 0x39, 0x3B, 0x39, 0x51, 0x4B, 0x5E, 0x57, 0x65, 0x5A, 0x66, 0x5A, 0x66, 0x5B, 0x68, 0x5B, 0x6A, 0x5B, 0x69, 0x5A, 0x69, 0x5C, 0x6B, 0x5C, 0x69, 0x5B, 0x68, 0x5A, 0x67, 0x5A, 0x65, 0x58, 0x65, 0x59, 0x67, 0x5A, 0x65, 0x57, 0x66, 0x58, 0x63, 0x56, 0x67, 0x59, 0x67, 0x58, 0x65, 0x57, 0x67, 0x57, 0x65, 0x56, 0x63, 0x55, 0x63, 0x56, 0x65, 0x58, 0x67, 0x58, 0x68, 0x58, 0x64, 0x55, 0x63, 0x55, 0x65, 0x57, 0x63, 0x57, 0x64, 0x57, 0x66, 0x58, 0x67, 0x58, 0x66, 0x57, 0x66, 0x58, 0x67, 0x5A, 0x67, 0x59, 0x67, 0x5A, 0x67, 0x5A, 0x64, 0x57, 0x66, 0x58, 0x66, 0x58, 0x66, 0x58, 0x66, 0x59, 0x68, 0x5A, 0x68, 0x5A, 0x68, 0x59, 0x67, 0x58, 0x67, 0x59, 0x66, 0x59, 0x66, 0x59, 0x66, 0x59, 0x65, 0x58, 0x64, 0x58, 0x64, 0x56, 0x63, 0x55, 0x65, 0x58, 0x66, 0x58, 0x67, 0x5A, 0x67, 0x59, 0x65, 0x57, 0x67, 0x59, 0x67, 0x59, 0x65, 0x59, 0x68, 0x5A, 0x68, 0x5C, 0x67, 0x58, 0x62, 0x55, 0x64, 0x57, 0x64, 0x56, 0x64, 0x55, 0x66, 0x58, 0x67, 0x5A, 0x66, 0x59, 0x66, 0x57, 0x58, 0x4B, 0x3A, 0x30, 0x2D, 0x27, 0x28, 0x22, 0x24, 0x1F, 0x23, 0x1E, 0x2B, 0x29, 0x49, 0x46, 0x5C, 0x52, 0x5D, 0x53, 0x62, 0x56, 0x62, 0x56, 0x62, 0x55, 0x5D, 0x51, 0x51, 0x46, 0x47, 0x3E, 0x43, 0x3D, 0x49, 0x43, 0x51, 0x48, 0x58, 0x4F, 0x60, 0x55, 0x63, 0x58, 0x65, 0x59, 0x66, 0x58, 0x67, 0x5A, 0x65, 0x58, 0x65, 0x58, 0x67, 0x5A, 0x67, 0x5A, 0x68, 0x5B, 0x67, 0x5A, 0x68, 0x5B, 0x69, 0x5B, 0x67, 0x5B, 0x68, 0x5C, 0x67, 0x5A, 0x68, 0x5B, 0x67, 0x5A, 0x67, 0x59, 0x67, 0x5A, 0x69, 0x59, 0x66, 0x5A, 0x6A, 0x5D, 0x6A, 0x5C, 0x68, 0x5A, 0x68, 0x5B, 0x65, 0x59, 0x66, 0x59, 0x64, 0x58, 0x62, 0x56, 0x64, 0x56, 0x61, 0x55, 0x62, 0x56, 0x61, 0x53, 0x5C, 0x4F, 0x5C, 0x50, 0x5A, 0x4E, 0x5C, 0x51, 0x5B, 0x4F, 0x5D, 0x50, 0x5A, 0x4E, 0x5A, 0x4D, 0x59, 0x4F, 0x58, 0x4C, 0x59, 0x4F, 0x58, 0x4E, 0x5C, 0x51, 0x5C, 0x50, 0x59, 0x4E, 0x59, 0x4D, 0x5C, 0x51, 0x5B, 0x51, 0x5A, 0x4F, 0x5A, 0x4F, 0x5D, 0x50, 0x5B, 0x4F, 0x59, 0x4E, 0x57, 0x4E, 0x59, 0x4F, 0x4A, 0x42, 0x32, 0x2E, 0x28, 0x2B, 0x28, 0x28, 0x24, 0x25, 0x20, 0x23, 0x28, 0x2D, 0x25, 0x26, 0x23, 0x27, 0x20, 0x20, 0x24, 0x29, 0x1F, 0x20, 0x23, 0x27, 0x20, 0x21, 0x1E, 0x22, 0x26, 0x2A, 0x20, 0x1F, 0x21, 0x22, 0x1E, 0x1D, 0x1F, 0x22, 0x1F, 0x20, 0x1D, 0x21, 0x20, 0x22, 0x1C, 0x1E, 0x20, 0x23, 0x1C, 0x1E, 0x23, 0x26, 0x1D, 0x1E, 0x21, 0x23, 0x1E, 0x20, 0x21, 0x24, 0x1D, 0x1F, 0x23, 0x27, 0x1C, 0x1D, 0x1F, 0x22, 0x21, 0x22, 0x1E, 0x20, 0x21, 0x22, 0x1F, 0x20, 0x23, 0x28, 0x25, 0x27, 0x23, 0x27, 0x21, 0x22, 0x20, 0x22
    },

    {
        0x4F, 0x1C, 0x4D, 0x1B, 0x4F, 0x1C, 0x4F, 0x1C, 0x4F, 0x1C, 0x50, 0x1C, 0x4F, 0x1C, 0x51, 0x1C, 0x51, 0x1C, 0x50, 0x1C, 0x50, 0x1D, 0x50, 0x1C, 0x51, 0x1D, 0x51, 0x1D, 0x51, 0x1C, 0x51, 0x1D, 0x50, 0x1C, 0x51, 0x1C, 0x51, 0x1C, 0x4E, 0x1C, 0x4E, 0x1C, 0x50, 0x1D, 0x50, 0x1D, 0x51, 0x1C, 0x52, 0x1D, 0x52, 0x1D, 0x51, 0x1E, 0x4D, 0x1C, 0x48, 0x1B, 0x40, 0x1A, 0x39, 0x19, 0x3D, 0x1A, 0x45, 0x1C, 0x45, 0x1B, 0x3E, 0x1A, 0x30, 0x16, 0x23, 0x13, 0x1D, 0x11, 0x19, 0x10, 0x17, 0x0F, 0x15, 0x0E, 0x14, 0x0E, 0x14, 0x0F, 0x13, 0x0E, 0x13, 0x0E, 0x13, 0x0E, 0x14, 0x0E, 0x14, 0x0E, 0x14, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x10, 0x14, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x10, 0x16, 0x10, 0x17, 0x11, 0x17, 0x12, 0x19, 0x14, 0x1E, 0x1E, 0x2F, 0x31, 0x3E, 0x40, 0x43, 0x46, 0x46, 0x49, 0x48, 0x4B, 0x4C, 0x4D, 0x4B, 0x4D, 0x49, 0x48, 0x42, 0x3D, 0x35, 0x2E, 0x27, 0x21, 0x21, 0x1C, 0x26, 0x26, 0x36, 0x38, 0x44, 0x47, 0x4A, 0x4D, 0x4D, 0x50, 0x4F, 0x51, 0x50, 0x50, 0x4B, 0x49, 0x41, 0x3C, 0x34, 0x2B, 0x26, 0x1E, 0x1F, 0x19, 0x1D, 0x16, 0x1A, 0x14, 0x19, 0x13, 0x19, 0x12, 0x19, 0x13, 0x19, 0x12, 0x18, 0x11, 0x18, 0x11, 0x19, 0x12, 0x19, 0x11, 0x19, 0x12, 0x19, 0x11, 0x18, 0x11, 0x18, 0x11, 0x17, 0x10, 0x16, 0x10, 0x17, 0x10, 0x16, 0x10, 0x16, 0x10, 0x17, 0x10, 0x17, 0x11, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x19, 0x11, 0x1D, 0x12, 0x28, 0x17, 0x46, 0x1D, 0x53, 0x20, 0x57, 0x21, 0x52, 0x1E, 0x3E, 0x1B, 0x3B, 0x1C, 0x50, 0x20, 0x5A, 0x21, 0x5D, 0x22, 0x60, 0x22, 0x60, 0x23, 0x61, 0x22, 0x61, 0x22, 0x61, 0x22, 0x62, 0x22, 0x61, 0x22, 0x5F, 0x22, 0x5E, 0x21, 0x5E, 0x21, 0x5E, 0x21, 0x5D, 0x22, 0x5C, 0x20, 0x5C, 0x20, 0x5B, 0x20, 0x5F, 0x21, 0x5D, 0x20, 0x5C, 0x20, 0x5C, 0x20, 0x5B, 0x20, 0x5B, 0x20, 0x5B, 0x20, 0x5D, 0x20, 0x5C, 0x20, 0x5B, 0x20, 0x5C, 0x20, 0x5B, 0x20, 0x5C, 0x20, 0x5C, 0x1F, 0x5D, 0x20, 0x5E, 0x21, 0x5C, 0x21, 0x5D, 0x20, 0x60, 0x22, 0x5F, 0x22, 0x5F, 0x21, 0x5E, 0x21, 0x5F, 0x22, 0x5F, 0x22, 0x5E, 0x22, 0x5D, 0x21, 0x5E, 0x22, 0x60, 0x22, 0x60, 0x23, 0x5F, 0x22, 0x5D, 0x21, 0x5C, 0x21, 0x5D, 0x21, 0x5D, 0x21, 0x5D, 0x20, 0x5E, 0x21, 0x5E, 0x22, 0x5A, 0x20, 0x5B, 0x20, 0x5C, 0x20, 0x5D, 0x21, 0x5E, 0x21, 0x60, 0x21, 0x5F, 0x20, 0x5B, 0x20, 0x5E, 0x21, 0x5E, 0x20, 0x5E, 0x21, 0x5C, 0x21, 0x5F, 0x22, 0x5E, 0x20, 0x5A, 0x20, 0x5C, 0x21, 0x5E, 0x21, 0x5B, 0x20, 0x5C, 0x21, 0x5D, 0x21, 0x5D, 0x21, 0x5E, 0x21, 0x58, 0x20, 0x43, 0x19, 0x2E, 0x15, 0x26, 0x13, 0x22, 0x12, 0x27, 0x14, 0x3C, 0x19, 0x52, 0x1E, 0x56, 0x20, 0x58, 0x20, 0x5C, 0x20, 0x5B, 0x20, 0x5C, 0x21, 0x5D, 0x21, 0x56, 0x1F, 0x52, 0x1D, 0x4F, 0x1E, 0x50, 0x1E, 0x53, 0x1F, 0x59, 0x20, 0x58, 0x20, 0x5D, 0x21, 0x5A, 0x21, 0x5A, 0x21, 0x5D, 0x22, 0x5C, 0x21, 0x5E, 0x21, 0x5E, 0x21, 0x5F, 0x22, 0x61, 0x23, 0x60, 0x22, 0x5E, 0x22, 0x60, 0x22, 0x5F, 0x22, 0x5E, 0x23, 0x5E, 0x22, 0x5F, 0x22, 0x60, 0x22, 0x60, 0x22, 0x5E, 0x22, 0x5E, 0x23, 0x61, 0x22, 0x5F, 0x22, 0x60, 0x22, 0x5F, 0x22, 0x5E, 0x23, 0x5F, 0x22, 0x5F, 0x22, 0x5D, 0x22, 0x5B, 0x21, 0x59, 0x20, 0x59, 0x20, 0x5A, 0x21, 0x5B, 0x20, 0x56, 0x1F, 0x56, 0x1F, 0x53, 0x1E, 0x57, 0x1F, 0x54, 0x1E, 0x53, 0x1E, 0x4F, 0x1D, 0x50, 0x1E, 0x53, 0x1E, 0x52, 0x1E, 0x54, 0x1F, 0x53, 0x1F, 0x55, 0x1F, 0x54, 0x1E, 0x53, 0x1F, 0x54, 0x1E, 0x54, 0x1E, 0x52, 0x1E, 0x52, 0x1E, 0x51, 0x1E, 0x52, 0x1E, 0x52, 0x1E, 0x52, 0x1E, 0x52, 0x1F, 0x53, 0x1E, 0x48, 0x1D, 0x34, 0x19, 0x2A, 0x18, 0x26, 0x15, 0x23, 0x15, 0x23, 0x16, 0x2B, 0x18, 0x23, 0x16, 0x26, 0x17, 0x22, 0x16, 0x26, 0x17, 0x23, 0x16, 0x28, 0x18, 0x22, 0x15, 0x26, 0x17, 0x25, 0x16, 0x21, 0x15, 0x22, 0x16, 0x24, 0x16, 0x26, 0x16, 0x24, 0x16, 0x25, 0x16, 0x26, 0x17, 0x28, 0x18, 0x24, 0x16, 0x26, 0x17, 0x27, 0x16, 0x2A, 0x18, 0x2A, 0x18, 0x2A, 0x18, 0x26, 0x17, 0x2D, 0x1A, 0x27, 0x17, 0x25, 0x16, 0x25, 0x16, 0x29, 0x17, 0x29, 0x16, 0x2A, 0x18, 0x25, 0x15, 0x2C, 0x18, 0x28, 0x16, 0x23, 0x14, 0x20, 0x14, 0x25, 0x16
    },

    {
        0x56, 0x4C, 0x56, 0x4B, 0x55, 0x4B, 0x56, 0x4C, 0x56, 0x4C, 0x58, 0x4E, 0x59, 0x4D, 0x5A, 0x4E, 0x5A, 0x4D, 0x5A, 0x4D, 0x5A, 0x4E, 0x5A, 0x4D, 0x59, 0x4E, 0x58, 0x4D, 0x5A, 0x4E, 0x59, 0x4D, 0x5A, 0x4D, 0x5B, 0x4D, 0x5A, 0x4D, 0x59, 0x4C, 0x58, 0x4D, 0x58, 0x4D, 0x59, 0x4D, 0x5A, 0x4E, 0x5C, 0x4E, 0x5B, 0x4E, 0x5A, 0x4C, 0x53, 0x48, 0x4D, 0x43, 0x44, 0x3B, 0x3B, 0x37, 0x41, 0x3F, 0x4A, 0x43, 0x48, 0x42, 0x3D, 0x38, 0x2D, 0x29, 0x1F, 0x1E, 0x19, 0x1A, 0x16, 0x18, 0x13, 0x16, 0x12, 0x15, 0x11, 0x14, 0x10, 0x13, 0x10, 0x13, 0x10, 0x12, 0x10, 0x13, 0x10, 0x13, 0x10, 0x13, 0x10, 0x13, 0x10, 0x13, 0x11, 0x14, 0x10, 0x14, 0x10, 0x14, 0x11, 0x14, 0x11, 0x14, 0x11, 0x14, 0x11, 0x14, 0x11, 0x15, 0x12, 0x15, 0x12, 0x16, 0x13, 0x17, 0x17, 0x1D, 0x21, 0x2B, 0x2F, 0x39, 0x36, 0x40, 0x39, 0x43, 0x3C, 0x46, 0x3D, 0x47, 0x3D, 0x46, 0x3B, 0x43, 0x35, 0x3B, 0x2B, 0x2E, 0x1F, 0x22, 0x1B, 0x1F, 0x1D, 0x23, 0x28, 0x32, 0x35, 0x3F, 0x3B, 0x46, 0x3E, 0x48, 0x40, 0x4C, 0x40, 0x4B, 0x3C, 0x45, 0x34, 0x3A, 0x29, 0x2B, 0x1E, 0x22, 0x1A, 0x1D, 0x17, 0x1B, 0x16, 0x19, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x13, 0x18, 0x13, 0x17, 0x14, 0x17, 0x13, 0x18, 0x14, 0x17, 0x14, 0x18, 0x14, 0x18, 0x13, 0x17, 0x13, 0x16, 0x13, 0x16, 0x12, 0x16, 0x13, 0x16, 0x12, 0x16, 0x12, 0x15, 0x12, 0x16, 0x12, 0x16, 0x13, 0x16, 0x13, 0x16, 0x13, 0x16, 0x13, 0x17, 0x14, 0x18, 0x18, 0x1A, 0x21, 0x24, 0x3F, 0x41, 0x52, 0x4F, 0x5A, 0x54, 0x57, 0x4F, 0x44, 0x3C, 0x3B, 0x37, 0x4F, 0x4A, 0x5D, 0x54, 0x63, 0x59, 0x66, 0x5B, 0x68, 0x5C, 0x69, 0x5D, 0x6B, 0x5C, 0x6A, 0x5B, 0x69, 0x5C, 0x6A, 0x5C, 0x67, 0x59, 0x66, 0x58, 0x67, 0x5A, 0x67, 0x5A, 0x65, 0x58, 0x65, 0x59, 0x65, 0x58, 0x65, 0x58, 0x67, 0x58, 0x65, 0x57, 0x65, 0x57, 0x64, 0x57, 0x65, 0x56, 0x64, 0x57, 0x66, 0x57, 0x66, 0x56, 0x67, 0x57, 0x63, 0x56, 0x65, 0x57, 0x65, 0x58, 0x64, 0x58, 0x65, 0x57, 0x66, 0x57, 0x69, 0x59, 0x65, 0x58, 0x66, 0x58, 0x68, 0x5B, 0x68, 0x5B, 0x67, 0x59, 0x67, 0x5A, 0x67, 0x5A, 0x67, 0x5A, 0x66, 0x59, 0x65, 0x59, 0x67, 0x5B, 0x69, 0x5C, 0x69, 0x5C, 0x68, 0x5B, 0x67, 0x59, 0x65, 0x58, 0x65, 0x58, 0x66, 0x58, 0x67, 0x59, 0x66, 0x5B, 0x66, 0x58, 0x62, 0x56, 0x63, 0x56, 0x64, 0x57, 0x65, 0x58, 0x69, 0x5B, 0x69, 0x5A, 0x68, 0x59, 0x65, 0x57, 0x66, 0x57, 0x65, 0x59, 0x67, 0x59, 0x66, 0x58, 0x67, 0x5A, 0x66, 0x59, 0x65, 0x58, 0x64, 0x59, 0x68, 0x59, 0x66, 0x57, 0x65, 0x58, 0x65, 0x58, 0x65, 0x59, 0x67, 0x57, 0x61, 0x54, 0x4C, 0x41, 0x35, 0x2D, 0x2C, 0x26, 0x2A, 0x25, 0x32, 0x2E, 0x47, 0x45, 0x5A, 0x50, 0x5F, 0x54, 0x61, 0x55, 0x64, 0x56, 0x61, 0x56, 0x65, 0x59, 0x66, 0x58, 0x63, 0x55, 0x5C, 0x51, 0x59, 0x50, 0x5C, 0x53, 0x5E, 0x53, 0x62, 0x55, 0x61, 0x57, 0x66, 0x57, 0x62, 0x56, 0x63, 0x56, 0x64, 0x58, 0x65, 0x59, 0x67, 0x59, 0x67, 0x59, 0x67, 0x5A, 0x69, 0x5C, 0x6A, 0x5B, 0x67, 0x59, 0x69, 0x5B, 0x65, 0x59, 0x67, 0x5B, 0x68, 0x5C, 0x68, 0x5B, 0x69, 0x5B, 0x69, 0x5A, 0x69, 0x5B, 0x68, 0x5B, 0x69, 0x5C, 0x67, 0x5B, 0x69, 0x5D, 0x67, 0x5B, 0x66, 0x5C, 0x67, 0x5C, 0x67, 0x5A, 0x67, 0x5B, 0x64, 0x58, 0x62, 0x56, 0x63, 0x57, 0x63, 0x55, 0x64, 0x57, 0x5F, 0x52, 0x5E, 0x51, 0x5D, 0x51, 0x5E, 0x52, 0x5C, 0x4F, 0x59, 0x4F, 0x58, 0x4D, 0x59, 0x4F, 0x5C, 0x50, 0x59, 0x4F, 0x5A, 0x4F, 0x5B, 0x50, 0x5C, 0x50, 0x5C, 0x51, 0x5B, 0x51, 0x5C, 0x50, 0x5B, 0x4F, 0x59, 0x4F, 0x5A, 0x4E, 0x5B, 0x4F, 0x5C, 0x4F, 0x5B, 0x4E, 0x5A, 0x4F, 0x59, 0x50, 0x5B, 0x4F, 0x4A, 0x40, 0x2F, 0x2B, 0x27, 0x27, 0x23, 0x22, 0x1F, 0x20, 0x21, 0x25, 0x25, 0x26, 0x22, 0x25, 0x21, 0x23, 0x1F, 0x24, 0x22, 0x24, 0x21, 0x24, 0x26, 0x28, 0x20, 0x23, 0x23, 0x27, 0x22, 0x25, 0x20, 0x22, 0x21, 0x24, 0x22, 0x27, 0x23, 0x27, 0x22, 0x24, 0x21, 0x25, 0x23, 0x27, 0x25, 0x2A, 0x22, 0x25, 0x23, 0x26, 0x24, 0x28, 0x27, 0x2B, 0x26, 0x28, 0x25, 0x27, 0x23, 0x26, 0x28, 0x2D, 0x21, 0x24, 0x21, 0x24, 0x22, 0x25, 0x25, 0x29, 0x24, 0x26, 0x24, 0x27, 0x21, 0x24, 0x26, 0x29, 0x22, 0x23, 0x1E, 0x1E, 0x1D, 0x20, 0x23, 0x26
    },

    {
        0x51, 0x1D, 0x4F, 0x1D, 0x4F, 0x1C, 0x4F, 0x1C, 0x50, 0x1D, 0x51, 0x1D, 0x50, 0x1C, 0x50, 0x1C, 0x51, 0x1C, 0x52, 0x1C, 0x52, 0x1D, 0x50, 0x1D, 0x51, 0x1D, 0x52, 0x1D, 0x50, 0x1D, 0x51, 0x1D, 0x51, 0x1D, 0x51, 0x1D, 0x51, 0x1D, 0x50, 0x1C, 0x50, 0x1C, 0x50, 0x1D, 0x50, 0x1D, 0x51, 0x1D, 0x52, 0x1D, 0x51, 0x1D, 0x4C, 0x1C, 0x48, 0x1B, 0x41, 0x1B, 0x3B, 0x1A, 0x3D, 0x1A, 0x46, 0x1B, 0x47, 0x1B, 0x3F, 0x1A, 0x34, 0x18, 0x24, 0x13, 0x1D, 0x11, 0x1A, 0x10, 0x17, 0x10, 0x16, 0x0F, 0x15, 0x0E, 0x14, 0x0E, 0x14, 0x0E, 0x13, 0x0E, 0x13, 0x0E, 0x13, 0x0E, 0x14, 0x0E, 0x14, 0x0E, 0x14, 0x0F, 0x15, 0x0F, 0x16, 0x0F, 0x15, 0x0F, 0x15, 0x10, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x10, 0x15, 0x10, 0x16, 0x10, 0x16, 0x11, 0x16, 0x11, 0x17, 0x12, 0x19, 0x14, 0x1E, 0x1C, 0x2C, 0x2E, 0x3C, 0x3E, 0x43, 0x46, 0x47, 0x4A, 0x48, 0x4A, 0x47, 0x48, 0x41, 0x3E, 0x36, 0x30, 0x28, 0x21, 0x1F, 0x1A, 0x1E, 0x19, 0x1E, 0x19, 0x23, 0x21, 0x34, 0x35, 0x43, 0x44, 0x4A, 0x4C, 0x4D, 0x4D, 0x4B, 0x49, 0x42, 0x3D, 0x35, 0x2C, 0x26, 0x1F, 0x20, 0x19, 0x1D, 0x16, 0x1B, 0x15, 0x19, 0x13, 0x19, 0x12, 0x19, 0x13, 0x18, 0x12, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x19, 0x12, 0x19, 0x11, 0x18, 0x11, 0x18, 0x11, 0x19, 0x10, 0x18, 0x11, 0x17, 0x10, 0x16, 0x10, 0x17, 0x10, 0x17, 0x11, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x18, 0x10, 0x19, 0x11, 0x1C, 0x12, 0x29, 0x17, 0x44, 0x1C, 0x51, 0x1F, 0x58, 0x21, 0x52, 0x1F, 0x3E, 0x1A, 0x3A, 0x1B, 0x4F, 0x1F, 0x59, 0x21, 0x5D, 0x23, 0x60, 0x22, 0x61, 0x23, 0x62, 0x22, 0x60, 0x22, 0x60, 0x22, 0x61, 0x22, 0x61, 0x22, 0x5F, 0x21, 0x5E, 0x22, 0x5D, 0x21, 0x5F, 0x22, 0x5D, 0x21, 0x5C, 0x21, 0x5C, 0x20, 0x5D, 0x20, 0x5C, 0x20, 0x5B, 0x20, 0x5E, 0x21, 0x5C, 0x20, 0x5B, 0x21, 0x5D, 0x20, 0x5D, 0x20, 0x5E, 0x21, 0x5C, 0x20, 0x5D, 0x20, 0x5D, 0x20, 0x5D, 0x21, 0x5C, 0x20, 0x5E, 0x21, 0x5F, 0x21, 0x5F, 0x21, 0x5C, 0x20, 0x5E, 0x22, 0x60, 0x22, 0x60, 0x21, 0x5E, 0x21, 0x5E, 0x21, 0x5E, 0x22, 0x60, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x61, 0x22, 0x62, 0x24, 0x61, 0x22, 0x5E, 0x21, 0x5D, 0x21, 0x5D, 0x21, 0x5E, 0x21, 0x5E, 0x21, 0x5D, 0x21, 0x5E, 0x21, 0x5C, 0x21, 0x5B, 0x1F, 0x5E, 0x21, 0x5C, 0x21, 0x60, 0x22, 0x5E, 0x21, 0x5E, 0x21, 0x5B, 0x21, 0x5D, 0x21, 0x5F, 0x21, 0x5D, 0x21, 0x5D, 0x22, 0x5B, 0x20, 0x5D, 0x20, 0x5E, 0x21, 0x61, 0x22, 0x5F, 0x21, 0x5D, 0x21, 0x5D, 0x21, 0x5B, 0x21, 0x5C, 0x21, 0x5C, 0x21, 0x5A, 0x20, 0x56, 0x1E, 0x49, 0x1B, 0x40, 0x19, 0x3E, 0x19, 0x48, 0x1D, 0x54, 0x1F, 0x57, 0x1F, 0x59, 0x20, 0x5C, 0x20, 0x5B, 0x21, 0x5A, 0x21, 0x5A, 0x21, 0x5C, 0x21, 0x5E, 0x21, 0x5D, 0x21, 0x5B, 0x20, 0x59, 0x20, 0x5B, 0x20, 0x5C, 0x21, 0x5B, 0x21, 0x5B, 0x20, 0x5B, 0x21, 0x5B, 0x21, 0x5C, 0x21, 0x5C, 0x21, 0x5D, 0x22, 0x5E, 0x22, 0x5F, 0x21, 0x5F, 0x22, 0x5F, 0x22, 0x5D, 0x21, 0x5E, 0x22, 0x5F, 0x22, 0x60, 0x22, 0x61, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x60, 0x22, 0x61, 0x23, 0x61, 0x23, 0x60, 0x23, 0x5E, 0x22, 0x61, 0x23, 0x61, 0x23, 0x5F, 0x23, 0x5F, 0x22, 0x5D, 0x22, 0x5E, 0x22, 0x5E, 0x22, 0x5C, 0x20, 0x57, 0x1F, 0x5A, 0x20, 0x5B, 0x21, 0x5C, 0x21, 0x5A, 0x20, 0x56, 0x1F, 0x52, 0x1E, 0x52, 0x1D, 0x51, 0x1E, 0x53, 0x1E, 0x52, 0x1F, 0x52, 0x1E, 0x54, 0x1F, 0x53, 0x1F, 0x54, 0x1E, 0x55, 0x1F, 0x54, 0x1E, 0x54, 0x1E, 0x51, 0x1D, 0x51, 0x1E, 0x52, 0x1E, 0x53, 0x1F, 0x52, 0x1E, 0x52, 0x1E, 0x55, 0x1E, 0x52, 0x1E, 0x53, 0x1F, 0x52, 0x1F, 0x44, 0x1C, 0x2C, 0x17, 0x27, 0x17, 0x26, 0x17, 0x28, 0x18, 0x2D, 0x19, 0x2B, 0x18, 0x29, 0x18, 0x2C, 0x19, 0x2B, 0x19, 0x2A, 0x18, 0x27, 0x17, 0x2F, 0x1A, 0x2C, 0x18, 0x25, 0x16, 0x2A, 0x18, 0x25, 0x15, 0x2E, 0x1A, 0x2E, 0x19, 0x28, 0x17, 0x2A, 0x18, 0x28, 0x17, 0x29, 0x18, 0x26, 0x15, 0x27, 0x17, 0x26, 0x16, 0x2C, 0x18, 0x28, 0x17, 0x24, 0x15, 0x24, 0x16, 0x27, 0x19, 0x27, 0x16, 0x21, 0x15, 0x26, 0x16, 0x24, 0x16, 0x28, 0x16, 0x21, 0x14, 0x2A, 0x18, 0x23, 0x15, 0x29, 0x16, 0x21, 0x13, 0x1E, 0x13, 0x22, 0x15, 0x24, 0x15
    },

    {
        0x57, 0x4D, 0x56, 0x4C, 0x57, 0x4C, 0x56, 0x4C, 0x57, 0x4D, 0x58, 0x4E, 0x59, 0x4E, 0x58, 0x4E, 0x59, 0x4E, 0x5A, 0x4E, 0x5A, 0x4F, 0x5A, 0x4E, 0x59, 0x4E, 0x5A, 0x4E, 0x5A, 0x4E, 0x59, 0x4E, 0x59, 0x4E, 0x5A, 0x4E, 0x5B, 0x4E, 0x5B, 0x4D, 0x59, 0x4D, 0x5A, 0x4D, 0x5A, 0x4D, 0x5A, 0x4E, 0x5A, 0x4E, 0x59, 0x4D, 0x54, 0x48, 0x4D, 0x42, 0x43, 0x3A, 0x3C, 0x38, 0x41, 0x3F, 0x49, 0x45, 0x49, 0x42, 0x3F, 0x38, 0x30, 0x2B, 0x21, 0x20, 0x1A, 0x1A, 0x17, 0x18, 0x14, 0x16, 0x12, 0x15, 0x11, 0x14, 0x10, 0x14, 0x10, 0x13, 0x10, 0x12, 0x0F, 0x12, 0x10, 0x13, 0x10, 0x13, 0x10, 0x13, 0x10, 0x13, 0x10, 0x13, 0x11, 0x15, 0x11, 0x15, 0x11, 0x14, 0x11, 0x14, 0x10, 0x14, 0x11, 0x14, 0x11, 0x15, 0x11, 0x15, 0x12, 0x15, 0x12, 0x16, 0x12, 0x16, 0x13, 0x17, 0x17, 0x1B, 0x20, 0x28, 0x2D, 0x37, 0x35, 0x3F, 0x39, 0x43, 0x3A, 0x44, 0x38, 0x41, 0x35, 0x3B, 0x2C, 0x2E, 0x1F, 0x22, 0x19, 0x1D, 0x18, 0x1B, 0x18, 0x1B, 0x1A, 0x1F, 0x24, 0x2E, 0x32, 0x3E, 0x3A, 0x46, 0x3D, 0x48, 0x3B, 0x44, 0x35, 0x3B, 0x2A, 0x2D, 0x1E, 0x21, 0x19, 0x1D, 0x17, 0x1B, 0x16, 0x19, 0x14, 0x18, 0x13, 0x18, 0x14, 0x17, 0x13, 0x17, 0x12, 0x16, 0x12, 0x16, 0x13, 0x17, 0x13, 0x16, 0x13, 0x16, 0x14, 0x18, 0x13, 0x17, 0x13, 0x17, 0x14, 0x18, 0x13, 0x17, 0x14, 0x17, 0x13, 0x16, 0x13, 0x15, 0x12, 0x15, 0x13, 0x17, 0x13, 0x17, 0x13, 0x16, 0x13, 0x16, 0x13, 0x16, 0x12, 0x16, 0x14, 0x17, 0x15, 0x17, 0x17, 0x19, 0x20, 0x24, 0x3B, 0x3D, 0x4E, 0x4B, 0x5B, 0x54, 0x58, 0x51, 0x44, 0x3B, 0x39, 0x35, 0x4C, 0x48, 0x5C, 0x53, 0x60, 0x56, 0x66, 0x5B, 0x69, 0x5C, 0x69, 0x5C, 0x69, 0x5B, 0x68, 0x5B, 0x69, 0x5B, 0x6A, 0x5B, 0x69, 0x5B, 0x67, 0x58, 0x67, 0x59, 0x67, 0x5B, 0x66, 0x58, 0x64, 0x57, 0x65, 0x57, 0x67, 0x59, 0x65, 0x58, 0x65, 0x57, 0x66, 0x59, 0x65, 0x57, 0x65, 0x57, 0x65, 0x57, 0x67, 0x58, 0x67, 0x58, 0x66, 0x59, 0x67, 0x58, 0x67, 0x58, 0x66, 0x59, 0x65, 0x59, 0x66, 0x59, 0x68, 0x5A, 0x67, 0x59, 0x64, 0x58, 0x66, 0x5A, 0x69, 0x5B, 0x68, 0x5A, 0x66, 0x59, 0x66, 0x58, 0x67, 0x5A, 0x68, 0x5A, 0x68, 0x5A, 0x69, 0x5B, 0x6A, 0x5E, 0x6B, 0x5E, 0x67, 0x5B, 0x67, 0x59, 0x65, 0x58, 0x66, 0x58, 0x65, 0x59, 0x65, 0x58, 0x66, 0x59, 0x66, 0x59, 0x64, 0x58, 0x64, 0x58, 0x66, 0x58, 0x65, 0x58, 0x6A, 0x5B, 0x68, 0x5B, 0x67, 0x58, 0x64, 0x56, 0x64, 0x58, 0x67, 0x5A, 0x66, 0x59, 0x67, 0x5A, 0x65, 0x57, 0x66, 0x59, 0x67, 0x5A, 0x69, 0x5C, 0x66, 0x5A, 0x67, 0x59, 0x66, 0x58, 0x62, 0x57, 0x65, 0x58, 0x65, 0x58, 0x60, 0x54, 0x5F, 0x53, 0x55, 0x4B, 0x4C, 0x44, 0x4B, 0x44, 0x52, 0x4C, 0x5B, 0x52, 0x5F, 0x54, 0x62, 0x56, 0x63, 0x56, 0x65, 0x58, 0x62, 0x57, 0x63, 0x56, 0x65, 0x58, 0x67, 0x5A, 0x66, 0x59, 0x64, 0x57, 0x62, 0x55, 0x64, 0x58, 0x65, 0x59, 0x63, 0x58, 0x63, 0x58, 0x64, 0x59, 0x63, 0x58, 0x65, 0x58, 0x65, 0x58, 0x66, 0x59, 0x66, 0x59, 0x67, 0x5A, 0x66, 0x5B, 0x65, 0x58, 0x66, 0x59, 0x68, 0x5A, 0x67, 0x5B, 0x6A, 0x5B, 0x6B, 0x5D, 0x69, 0x5C, 0x68, 0x5B, 0x6A, 0x5C, 0x6B, 0x5D, 0x68, 0x5B, 0x68, 0x5B, 0x66, 0x5A, 0x69, 0x5C, 0x68, 0x5C, 0x67, 0x5B, 0x67, 0x5C, 0x64, 0x58, 0x66, 0x5A, 0x67, 0x5A, 0x65, 0x57, 0x60, 0x55, 0x64, 0x56, 0x64, 0x58, 0x66, 0x58, 0x63, 0x56, 0x5E, 0x52, 0x5B, 0x50, 0x5B, 0x4E, 0x5A, 0x4D, 0x5B, 0x50, 0x5B, 0x4F, 0x5A, 0x4E, 0x5B, 0x50, 0x5B, 0x50, 0x5B, 0x50, 0x5D, 0x51, 0x5B, 0x50, 0x5B, 0x4F, 0x59, 0x4D, 0x5B, 0x4F, 0x59, 0x4E, 0x5B, 0x50, 0x5A, 0x4F, 0x5A, 0x50, 0x5D, 0x51, 0x5A, 0x4E, 0x5A, 0x50, 0x58, 0x4D, 0x46, 0x3C, 0x2B, 0x28, 0x27, 0x27, 0x23, 0x27, 0x27, 0x2C, 0x29, 0x2C, 0x27, 0x2A, 0x25, 0x27, 0x27, 0x2A, 0x25, 0x27, 0x25, 0x28, 0x23, 0x26, 0x29, 0x2C, 0x25, 0x28, 0x1F, 0x20, 0x25, 0x29, 0x21, 0x23, 0x2A, 0x30, 0x27, 0x28, 0x21, 0x24, 0x23, 0x25, 0x22, 0x26, 0x23, 0x26, 0x21, 0x21, 0x23, 0x26, 0x20, 0x22, 0x25, 0x28, 0x21, 0x21, 0x1E, 0x21, 0x1F, 0x20, 0x22, 0x26, 0x21, 0x20, 0x1F, 0x22, 0x22, 0x23, 0x20, 0x23, 0x23, 0x24, 0x1D, 0x1E, 0x25, 0x28, 0x1E, 0x21, 0x22, 0x24, 0x1D, 0x1F, 0x1D, 0x1E, 0x1F, 0x23, 0x1F, 0x20
    },

    {
        0x51, 0x1D, 0x50, 0x1D, 0x50, 0x1D, 0x50, 0x1C, 0x50, 0x1D, 0x51, 0x1D, 0x51, 0x1D, 0x51, 0x1D, 0x50, 0x1D, 0x51, 0x1C, 0x50, 0x1D, 0x51, 0x1D, 0x53, 0x1E, 0x53, 0x1E, 0x53, 0x1D, 0x53, 0x1E, 0x52, 0x1E, 0x52, 0x1D, 0x51, 0x1D, 0x50, 0x1D, 0x50, 0x1D, 0x4F, 0x1C, 0x50, 0x1C, 0x50, 0x1D, 0x50, 0x1D, 0x4D, 0x1C, 0x48, 0x1C, 0x41, 0x1A, 0x3A, 0x19, 0x3D, 0x1A, 0x46, 0x1C, 0x4A, 0x1C, 0x40, 0x1A, 0x34, 0x17, 0x28, 0x15, 0x20, 0x12, 0x1A, 0x11, 0x18, 0x10, 0x16, 0x0F, 0x15, 0x0F, 0x14, 0x0E, 0x14, 0x0E, 0x14, 0x0F, 0x13, 0x0F, 0x13, 0x0E, 0x13, 0x0E, 0x13, 0x0F, 0x14, 0x0F, 0x14, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x10, 0x16, 0x10, 0x16, 0x10, 0x15, 0x10, 0x15, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x11, 0x16, 0x10, 0x17, 0x11, 0x18, 0x12, 0x19, 0x14, 0x1C, 0x1A, 0x2A, 0x2C, 0x3A, 0x3D, 0x43, 0x45, 0x44, 0x44, 0x3F, 0x3C, 0x36, 0x30, 0x29, 0x21, 0x20, 0x19, 0x1D, 0x17, 0x1B, 0x16, 0x1C, 0x16, 0x1C, 0x17, 0x21, 0x1F, 0x31, 0x33, 0x41, 0x43, 0x46, 0x44, 0x42, 0x3C, 0x36, 0x2D, 0x28, 0x20, 0x21, 0x1A, 0x1E, 0x17, 0x1C, 0x15, 0x1A, 0x14, 0x19, 0x14, 0x19, 0x12, 0x18, 0x12, 0x18, 0x11, 0x17, 0x11, 0x18, 0x11, 0x18, 0x11, 0x17, 0x10, 0x18, 0x11, 0x19, 0x12, 0x1A, 0x12, 0x19, 0x12, 0x19, 0x12, 0x19, 0x12, 0x19, 0x11, 0x18, 0x11, 0x17, 0x10, 0x16, 0x10, 0x17, 0x11, 0x17, 0x11, 0x17, 0x11, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x18, 0x11, 0x1A, 0x11, 0x1C, 0x12, 0x25, 0x16, 0x41, 0x1C, 0x53, 0x20, 0x59, 0x21, 0x53, 0x1F, 0x3E, 0x1A, 0x37, 0x1A, 0x4D, 0x20, 0x58, 0x22, 0x5C, 0x22, 0x5F, 0x22, 0x60, 0x22, 0x5E, 0x22, 0x5F, 0x22, 0x60, 0x23, 0x60, 0x23, 0x5E, 0x22, 0x5D, 0x21, 0x5D, 0x21, 0x5E, 0x22, 0x5D, 0x21, 0x5E, 0x21, 0x5C, 0x21, 0x5E, 0x21, 0x5E, 0x21, 0x5C, 0x21, 0x5E, 0x21, 0x5D, 0x21, 0x5D, 0x21, 0x5D, 0x20, 0x5C, 0x21, 0x5E, 0x22, 0x5D, 0x20, 0x5B, 0x20, 0x5D, 0x20, 0x5D, 0x21, 0x5F, 0x22, 0x5F, 0x21, 0x5E, 0x22, 0x5F, 0x21, 0x5B, 0x20, 0x5C, 0x21, 0x5E, 0x21, 0x5F, 0x21, 0x5D, 0x21, 0x5D, 0x22, 0x61, 0x22, 0x5F, 0x22, 0x5D, 0x21, 0x5E, 0x20, 0x5E, 0x22, 0x62, 0x23, 0x60, 0x22, 0x5E, 0x21, 0x5C, 0x21, 0x5D, 0x22, 0x61, 0x22, 0x5D, 0x21, 0x5E, 0x21, 0x5F, 0x22, 0x5E, 0x21, 0x5E, 0x21, 0x5D, 0x20, 0x5D, 0x21, 0x5F, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x5B, 0x21, 0x5E, 0x21, 0x5E, 0x21, 0x5E, 0x21, 0x5F, 0x22, 0x5C, 0x21, 0x5E, 0x22, 0x5F, 0x21, 0x5F, 0x22, 0x5D, 0x22, 0x5E, 0x22, 0x5E, 0x22, 0x5D, 0x22, 0x5C, 0x20, 0x5D, 0x21, 0x5C, 0x21, 0x5B, 0x20, 0x5A, 0x20, 0x5A, 0x20, 0x58, 0x20, 0x59, 0x21, 0x58, 0x20, 0x5A, 0x21, 0x5D, 0x20, 0x5C, 0x21, 0x5D, 0x21, 0x5C, 0x21, 0x5D, 0x21, 0x5C, 0x21, 0x5B, 0x21, 0x5E, 0x21, 0x5C, 0x21, 0x5B, 0x21, 0x5E, 0x21, 0x5E, 0x22, 0x5F, 0x22, 0x5E, 0x22, 0x60, 0x23, 0x5C, 0x21, 0x5F, 0x22, 0x5D, 0x21, 0x5E, 0x22, 0x5F, 0x22, 0x61, 0x23, 0x5F, 0x22, 0x5E, 0x21, 0x5D, 0x21, 0x5F, 0x22, 0x5F, 0x22, 0x5E, 0x23, 0x60, 0x22, 0x60, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x62, 0x23, 0x60, 0x22, 0x60, 0x22, 0x60, 0x23, 0x60, 0x22, 0x5E, 0x23, 0x5F, 0x23, 0x5F, 0x22, 0x5F, 0x23, 0x5E, 0x22, 0x5E, 0x21, 0x5E, 0x22, 0x58, 0x21, 0x5B, 0x20, 0x5C, 0x21, 0x59, 0x21, 0x5C, 0x20, 0x57, 0x1F, 0x55, 0x1F, 0x55, 0x1F, 0x54, 0x1E, 0x53, 0x1E, 0x55, 0x1F, 0x52, 0x1E, 0x53, 0x1E, 0x54, 0x1F, 0x54, 0x1F, 0x54, 0x1F, 0x53, 0x1E, 0x52, 0x1E, 0x51, 0x1E, 0x51, 0x1E, 0x50, 0x1E, 0x53, 0x1F, 0x54, 0x1F, 0x54, 0x1F, 0x52, 0x1E, 0x50, 0x1E, 0x54, 0x1F, 0x55, 0x21, 0x46, 0x1C, 0x31, 0x18, 0x2E, 0x19, 0x2E, 0x1B, 0x2D, 0x18, 0x26, 0x17, 0x2A, 0x18, 0x27, 0x17, 0x26, 0x16, 0x20, 0x14, 0x29, 0x17, 0x22, 0x15, 0x27, 0x17, 0x22, 0x15, 0x1E, 0x14, 0x25, 0x16, 0x25, 0x16, 0x2E, 0x1A, 0x20, 0x14, 0x24, 0x16, 0x20, 0x14, 0x27, 0x17, 0x26, 0x16, 0x1F, 0x13, 0x25, 0x16, 0x20, 0x15, 0x24, 0x15, 0x1E, 0x13, 0x20, 0x13, 0x20, 0x14, 0x25, 0x16, 0x21, 0x14, 0x23, 0x16, 0x24, 0x15, 0x24, 0x16, 0x25, 0x15, 0x20, 0x14, 0x29, 0x17, 0x22, 0x14, 0x25, 0x15, 0x1F, 0x13, 0x24, 0x15, 0x24, 0x14, 0x22, 0x13
    },

    {
        0x57, 0x4E, 0x57, 0x4D, 0x58, 0x4E, 0x58, 0x4F, 0x58, 0x4E, 0x58, 0x4F, 0x59, 0x4F, 0x59, 0x4F, 0x59, 0x4E, 0x59, 0x4D, 0x5A, 0x4E, 0x59, 0x4E, 0x5A, 0x4F, 0x5B, 0x50, 0x5B, 0x4F, 0x5B, 0x4F, 0x5B, 0x50, 0x5A, 0x4E, 0x59, 0x4D, 0x5A, 0x4D, 0x5A, 0x4D, 0x59, 0x4D, 0x5B, 0x4E, 0x59, 0x4C, 0x57, 0x4B, 0x53, 0x48, 0x4D, 0x42, 0x44, 0x3B, 0x3C, 0x37, 0x41, 0x3E, 0x4A, 0x46, 0x4B, 0x44, 0x42, 0x3B, 0x31, 0x2E, 0x23, 0x23, 0x1C, 0x1D, 0x17, 0x18, 0x15, 0x17, 0x13, 0x15, 0x11, 0x14, 0x10, 0x14, 0x10, 0x13, 0x11, 0x14, 0x10, 0x13, 0x10, 0x13, 0x10, 0x13, 0x10, 0x13, 0x0F, 0x12, 0x10, 0x13, 0x11, 0x13, 0x11, 0x14, 0x11, 0x14, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x14, 0x11, 0x15, 0x11, 0x15, 0x12, 0x16, 0x12, 0x15, 0x12, 0x16, 0x14, 0x17, 0x14, 0x17, 0x16, 0x1A, 0x1E, 0x27, 0x2C, 0x37, 0x35, 0x3E, 0x35, 0x3F, 0x33, 0x3A, 0x2B, 0x2E, 0x20, 0x22, 0x19, 0x1D, 0x17, 0x1A, 0x16, 0x19, 0x16, 0x1A, 0x16, 0x1A, 0x19, 0x1E, 0x24, 0x2E, 0x32, 0x3D, 0x37, 0x40, 0x34, 0x39, 0x2A, 0x2C, 0x20, 0x23, 0x1B, 0x1E, 0x17, 0x1B, 0x16, 0x1A, 0x15, 0x19, 0x14, 0x18, 0x13, 0x18, 0x12, 0x17, 0x13, 0x17, 0x13, 0x16, 0x12, 0x16, 0x13, 0x17, 0x12, 0x16, 0x13, 0x17, 0x13, 0x18, 0x14, 0x18, 0x15, 0x19, 0x14, 0x19, 0x14, 0x18, 0x14, 0x17, 0x13, 0x16, 0x13, 0x16, 0x12, 0x16, 0x13, 0x16, 0x13, 0x16, 0x13, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x13, 0x16, 0x14, 0x17, 0x15, 0x18, 0x17, 0x19, 0x1D, 0x20, 0x38, 0x3B, 0x50, 0x4E, 0x59, 0x53, 0x58, 0x4F, 0x45, 0x3C, 0x37, 0x34, 0x4A, 0x46, 0x5A, 0x54, 0x60, 0x58, 0x65, 0x5A, 0x66, 0x59, 0x65, 0x59, 0x67, 0x5A, 0x68, 0x5B, 0x67, 0x5B, 0x67, 0x5A, 0x67, 0x58, 0x66, 0x59, 0x68, 0x5A, 0x66, 0x59, 0x66, 0x58, 0x63, 0x56, 0x66, 0x59, 0x67, 0x5A, 0x66, 0x59, 0x66, 0x5A, 0x66, 0x58, 0x66, 0x58, 0x67, 0x59, 0x66, 0x59, 0x68, 0x5A, 0x66, 0x59, 0x66, 0x58, 0x67, 0x58, 0x64, 0x57, 0x68, 0x5B, 0x66, 0x59, 0x67, 0x5A, 0x67, 0x5A, 0x64, 0x58, 0x63, 0x59, 0x66, 0x5A, 0x68, 0x5A, 0x66, 0x59, 0x66, 0x59, 0x68, 0x5A, 0x68, 0x5A, 0x67, 0x59, 0x67, 0x58, 0x68, 0x5B, 0x69, 0x5D, 0x68, 0x5B, 0x66, 0x59, 0x64, 0x59, 0x65, 0x5B, 0x68, 0x5B, 0x67, 0x5A, 0x67, 0x5A, 0x68, 0x5B, 0x67, 0x5A, 0x65, 0x58, 0x65, 0x58, 0x68, 0x5A, 0x68, 0x5B, 0x67, 0x5B, 0x67, 0x59, 0x65, 0x59, 0x65, 0x58, 0x65, 0x59, 0x67, 0x5A, 0x67, 0x5B, 0x65, 0x58, 0x67, 0x5B, 0x68, 0x59, 0x68, 0x5A, 0x65, 0x59, 0x67, 0x5A, 0x67, 0x5B, 0x65, 0x58, 0x65, 0x58, 0x65, 0x57, 0x65, 0x58, 0x64, 0x5A, 0x64, 0x57, 0x62, 0x57, 0x61, 0x56, 0x61, 0x56, 0x60, 0x55, 0x62, 0x57, 0x65, 0x59, 0x64, 0x59, 0x65, 0x58, 0x64, 0x58, 0x66, 0x59, 0x66, 0x57, 0x64, 0x57, 0x67, 0x59, 0x64, 0x58, 0x64, 0x59, 0x66, 0x5A, 0x67, 0x5A, 0x67, 0x5A, 0x66, 0x5B, 0x69, 0x5B, 0x65, 0x58, 0x66, 0x5A, 0x65, 0x59, 0x66, 0x5A, 0x68, 0x5B, 0x69, 0x5C, 0x68, 0x5B, 0x67, 0x5A, 0x65, 0x59, 0x68, 0x5A, 0x69, 0x5B, 0x68, 0x5B, 0x6A, 0x5D, 0x6B, 0x5D, 0x68, 0x5B, 0x69, 0x5B, 0x6A, 0x5D, 0x69, 0x5C, 0x68, 0x5C, 0x69, 0x5C, 0x66, 0x5A, 0x65, 0x5B, 0x65, 0x59, 0x66, 0x5A, 0x67, 0x5B, 0x66, 0x59, 0x66, 0x5A, 0x65, 0x58, 0x63, 0x56, 0x63, 0x56, 0x63, 0x56, 0x63, 0x57, 0x65, 0x56, 0x60, 0x53, 0x5F, 0x53, 0x5E, 0x52, 0x5B, 0x50, 0x5B, 0x4E, 0x5B, 0x50, 0x58, 0x4F, 0x5C, 0x4F, 0x5C, 0x51, 0x5C, 0x51, 0x5C, 0x51, 0x5A, 0x50, 0x5A, 0x4F, 0x59, 0x4E, 0x58, 0x4D, 0x57, 0x4D, 0x5A, 0x50, 0x5B, 0x51, 0x5B, 0x4F, 0x5B, 0x4E, 0x5A, 0x4F, 0x5A, 0x50, 0x5B, 0x51, 0x46, 0x3D, 0x2E, 0x2A, 0x2A, 0x2B, 0x27, 0x29, 0x26, 0x27, 0x21, 0x23, 0x25, 0x27, 0x23, 0x24, 0x20, 0x20, 0x1C, 0x1E, 0x24, 0x26, 0x1F, 0x21, 0x22, 0x23, 0x1F, 0x21, 0x1C, 0x1F, 0x23, 0x23, 0x21, 0x27, 0x28, 0x28, 0x1C, 0x1D, 0x21, 0x24, 0x1E, 0x20, 0x23, 0x27, 0x22, 0x24, 0x1D, 0x1D, 0x22, 0x23, 0x1F, 0x21, 0x1F, 0x20, 0x1D, 0x1E, 0x1D, 0x20, 0x20, 0x22, 0x23, 0x24, 0x1F, 0x20, 0x21, 0x25, 0x21, 0x21, 0x24, 0x27, 0x22, 0x23, 0x1E, 0x21, 0x24, 0x26, 0x21, 0x25, 0x21, 0x20, 0x1C, 0x1E, 0x22, 0x24, 0x20, 0x23, 0x1E, 0x1F
    },

    {
        0x51, 0x1E, 0x50, 0x1D, 0x51, 0x1D, 0x51, 0x1D, 0x52, 0x1D, 0x52, 0x1D, 0x52, 0x1D, 0x52, 0x1D, 0x51, 0x1D, 0x51, 0x1C, 0x50, 0x1D, 0x51, 0x1D, 0x52, 0x1D, 0x53, 0x1E, 0x53, 0x1E, 0x52, 0x1E, 0x53, 0x1E, 0x53, 0x1D, 0x52, 0x1D, 0x50, 0x1C, 0x51, 0x1D, 0x51, 0x1D, 0x51, 0x1D, 0x51, 0x1D, 0x4D, 0x1D, 0x48, 0x1B, 0x41, 0x1A, 0x3A, 0x19, 0x3C, 0x1A, 0x45, 0x1C, 0x4A, 0x1C, 0x44, 0x1B, 0x37, 0x19, 0x28, 0x14, 0x20, 0x13, 0x1D, 0x11, 0x19, 0x10, 0x17, 0x0F, 0x16, 0x0F, 0x15, 0x0F, 0x14, 0x0E, 0x14, 0x0E, 0x14, 0x0F, 0x14, 0x0F, 0x14, 0x0F, 0x15, 0x0F, 0x14, 0x0F, 0x14, 0x0F, 0x15, 0x0F, 0x15, 0x10, 0x16, 0x10, 0x16, 0x0F, 0x16, 0x0F, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x17, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x17, 0x11, 0x18, 0x12, 0x18, 0x13, 0x1C, 0x18, 0x28, 0x2A, 0x37, 0x38, 0x3B, 0x37, 0x33, 0x2E, 0x28, 0x21, 0x1F, 0x19, 0x1D, 0x16, 0x1B, 0x15, 0x1A, 0x14, 0x1A, 0x14, 0x1A, 0x14, 0x1B, 0x16, 0x20, 0x1E, 0x31, 0x2F, 0x3B, 0x35, 0x33, 0x2C, 0x27, 0x1F, 0x21, 0x1A, 0x1E, 0x18, 0x1C, 0x16, 0x1C, 0x15, 0x1B, 0x13, 0x19, 0x12, 0x19, 0x12, 0x18, 0x11, 0x18, 0x11, 0x17, 0x10, 0x17, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x19, 0x12, 0x1A, 0x13, 0x1C, 0x14, 0x1C, 0x13, 0x1A, 0x12, 0x18, 0x11, 0x18, 0x11, 0x17, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x18, 0x11, 0x19, 0x11, 0x1B, 0x11, 0x23, 0x15, 0x40, 0x1D, 0x54, 0x20, 0x58, 0x21, 0x53, 0x1E, 0x3F, 0x1B, 0x37, 0x1B, 0x4A, 0x1F, 0x58, 0x21, 0x5B, 0x21, 0x5E, 0x22, 0x5D, 0x22, 0x5E, 0x23, 0x5F, 0x22, 0x61, 0x24, 0x5F, 0x22, 0x5E, 0x21, 0x5E, 0x21, 0x60, 0x21, 0x5E, 0x21, 0x5D, 0x21, 0x5D, 0x21, 0x5E, 0x21, 0x5E, 0x21, 0x5F, 0x21, 0x5F, 0x21, 0x5E, 0x21, 0x5E, 0x21, 0x5E, 0x21, 0x5D, 0x21, 0x60, 0x22, 0x60, 0x22, 0x5C, 0x21, 0x5E, 0x21, 0x5D, 0x21, 0x5E, 0x21, 0x5F, 0x21, 0x5D, 0x21, 0x5E, 0x21, 0x5D, 0x21, 0x5E, 0x20, 0x5E, 0x20, 0x5E, 0x21, 0x5D, 0x21, 0x60, 0x21, 0x5E, 0x22, 0x5F, 0x22, 0x5E, 0x21, 0x5D, 0x21, 0x5D, 0x20, 0x5E, 0x22, 0x60, 0x22, 0x5F, 0x22, 0x5E, 0x22, 0x5C, 0x21, 0x60, 0x22, 0x5F, 0x22, 0x5F, 0x21, 0x5F, 0x22, 0x5D, 0x21, 0x5E, 0x21, 0x5D, 0x21, 0x5E, 0x22, 0x60, 0x22, 0x5D, 0x21, 0x60, 0x23, 0x60, 0x24, 0x5E, 0x22, 0x5E, 0x21, 0x5D, 0x21, 0x5F, 0x22, 0x60, 0x22, 0x5E, 0x21, 0x5F, 0x21, 0x5D, 0x21, 0x5B, 0x21, 0x5F, 0x21, 0x5E, 0x21, 0x5E, 0x21, 0x5C, 0x20, 0x5C, 0x21, 0x5C, 0x20, 0x5D, 0x21, 0x5E, 0x21, 0x5C, 0x21, 0x5B, 0x21, 0x5C, 0x21, 0x5C, 0x20, 0x5B, 0x20, 0x5E, 0x20, 0x5D, 0x21, 0x5D, 0x21, 0x5C, 0x21, 0x5F, 0x21, 0x5E, 0x21, 0x5C, 0x21, 0x5D, 0x21, 0x5E, 0x21, 0x5F, 0x23, 0x5E, 0x21, 0x5E, 0x21, 0x60, 0x22, 0x61, 0x23, 0x61, 0x23, 0x5F, 0x22, 0x5D, 0x22, 0x5C, 0x21, 0x5E, 0x22, 0x5D, 0x22, 0x62, 0x23, 0x61, 0x22, 0x5F, 0x22, 0x5E, 0x22, 0x5F, 0x21, 0x5E, 0x21, 0x5E, 0x22, 0x5F, 0x21, 0x60, 0x22, 0x5E, 0x22, 0x5F, 0x22, 0x62, 0x23, 0x63, 0x23, 0x5F, 0x23, 0x62, 0x24, 0x5F, 0x23, 0x60, 0x23, 0x61, 0x24, 0x62, 0x23, 0x5F, 0x22, 0x5D, 0x22, 0x5D, 0x22, 0x5C, 0x21, 0x5A, 0x21, 0x5C, 0x21, 0x5C, 0x21, 0x5A, 0x20, 0x58, 0x20, 0x59, 0x20, 0x5A, 0x21, 0x57, 0x20, 0x54, 0x1E, 0x54, 0x1F, 0x52, 0x1E, 0x51, 0x1E, 0x54, 0x1F, 0x54, 0x1F, 0x53, 0x1E, 0x52, 0x1F, 0x52, 0x1F, 0x52, 0x1E, 0x53, 0x1E, 0x51, 0x1E, 0x53, 0x1E, 0x53, 0x1E, 0x55, 0x1F, 0x53, 0x1D, 0x52, 0x1E, 0x52, 0x1E, 0x53, 0x1E, 0x52, 0x1E, 0x3D, 0x19, 0x27, 0x15, 0x24, 0x15, 0x25, 0x15, 0x23, 0x15, 0x22, 0x15, 0x24, 0x16, 0x24, 0x16, 0x23, 0x15, 0x24, 0x16, 0x28, 0x17, 0x27, 0x17, 0x29, 0x17, 0x27, 0x16, 0x21, 0x15, 0x26, 0x16, 0x2D, 0x19, 0x26, 0x15, 0x25, 0x17, 0x29, 0x18, 0x26, 0x17, 0x2C, 0x18, 0x21, 0x14, 0x25, 0x16, 0x28, 0x17, 0x27, 0x17, 0x26, 0x16, 0x27, 0x17, 0x27, 0x17, 0x2B, 0x18, 0x29, 0x18, 0x27, 0x17, 0x28, 0x17, 0x25, 0x16, 0x2D, 0x19, 0x25, 0x16, 0x28, 0x17, 0x29, 0x17, 0x27, 0x16, 0x24, 0x15, 0x26, 0x16, 0x2D, 0x18, 0x24, 0x14, 0x25, 0x16
    },

    {
        0x58, 0x4E, 0x57, 0x4E, 0x58, 0x4E, 0x59, 0x4E, 0x59, 0x4F, 0x5A, 0x4F, 0x59, 0x4F, 0x5A, 0x4F, 0x5A, 0x4E, 0x58, 0x4D, 0x59, 0x4D, 0x5A, 0x4D, 0x5B, 0x4E, 0x5B, 0x4F, 0x5D, 0x50, 0x5C, 0x4F, 0x5C, 0x4F, 0x5A, 0x4E, 0x5A, 0x4D, 0x58, 0x4C, 0x5A, 0x4E, 0x5A, 0x4D, 0x59, 0x4E, 0x58, 0x4C, 0x53, 0x48, 0x4D, 0x42, 0x44, 0x3B, 0x3C, 0x37, 0x3F, 0x3D, 0x49, 0x45, 0x4C, 0x46, 0x44, 0x3D, 0x34, 0x2F, 0x23, 0x22, 0x1C, 0x1C, 0x18, 0x1A, 0x15, 0x17, 0x13, 0x16, 0x12, 0x14, 0x11, 0x13, 0x11, 0x13, 0x10, 0x13, 0x10, 0x14, 0x10, 0x13, 0x10, 0x13, 0x10, 0x13, 0x10, 0x13, 0x10, 0x14, 0x10, 0x13, 0x11, 0x14, 0x11, 0x14, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x14, 0x11, 0x15, 0x12, 0x15, 0x11, 0x15, 0x11, 0x14, 0x11, 0x15, 0x12, 0x16, 0x12, 0x16, 0x13, 0x16, 0x16, 0x19, 0x1D, 0x25, 0x2A, 0x32, 0x2E, 0x34, 0x2A, 0x2B, 0x1F, 0x22, 0x19, 0x1C, 0x17, 0x1A, 0x16, 0x19, 0x14, 0x18, 0x15, 0x18, 0x15, 0x18, 0x16, 0x19, 0x19, 0x1E, 0x24, 0x2D, 0x2E, 0x35, 0x2A, 0x2D, 0x20, 0x23, 0x1C, 0x20, 0x19, 0x1C, 0x17, 0x1B, 0x16, 0x1A, 0x15, 0x18, 0x14, 0x17, 0x13, 0x17, 0x12, 0x16, 0x13, 0x16, 0x12, 0x16, 0x13, 0x16, 0x13, 0x16, 0x13, 0x17, 0x13, 0x17, 0x14, 0x18, 0x14, 0x19, 0x15, 0x1A, 0x15, 0x1A, 0x15, 0x19, 0x14, 0x17, 0x13, 0x17, 0x12, 0x16, 0x13, 0x16, 0x13, 0x16, 0x13, 0x16, 0x12, 0x16, 0x12, 0x16, 0x13, 0x16, 0x13, 0x15, 0x13, 0x15, 0x13, 0x16, 0x13, 0x16, 0x14, 0x17, 0x16, 0x18, 0x1C, 0x1F, 0x36, 0x3A, 0x50, 0x4E, 0x59, 0x53, 0x59, 0x51, 0x47, 0x3F, 0x37, 0x33, 0x47, 0x44, 0x58, 0x51, 0x5F, 0x56, 0x62, 0x57, 0x62, 0x58, 0x63, 0x59, 0x66, 0x5B, 0x68, 0x5B, 0x66, 0x59, 0x65, 0x58, 0x66, 0x59, 0x68, 0x5A, 0x66, 0x58, 0x66, 0x58, 0x66, 0x58, 0x66, 0x59, 0x66, 0x59, 0x67, 0x59, 0x67, 0x59, 0x66, 0x5A, 0x67, 0x5A, 0x65, 0x59, 0x65, 0x59, 0x69, 0x5B, 0x68, 0x5B, 0x65, 0x56, 0x65, 0x57, 0x66, 0x57, 0x67, 0x5A, 0x69, 0x5A, 0x67, 0x5A, 0x68, 0x5B, 0x66, 0x59, 0x66, 0x5A, 0x68, 0x59, 0x67, 0x58, 0x66, 0x59, 0x65, 0x59, 0x66, 0x5A, 0x67, 0x5A, 0x66, 0x59, 0x67, 0x58, 0x66, 0x58, 0x65, 0x59, 0x68, 0x5B, 0x67, 0x5A, 0x65, 0x58, 0x63, 0x58, 0x67, 0x5B, 0x68, 0x5A, 0x67, 0x59, 0x67, 0x5A, 0x65, 0x58, 0x65, 0x59, 0x65, 0x58, 0x66, 0x5A, 0x67, 0x5A, 0x65, 0x57, 0x66, 0x5A, 0x67, 0x5C, 0x66, 0x5A, 0x67, 0x58, 0x66, 0x57, 0x67, 0x5A, 0x68, 0x5A, 0x66, 0x59, 0x67, 0x59, 0x65, 0x58, 0x63, 0x56, 0x66, 0x58, 0x65, 0x59, 0x66, 0x58, 0x65, 0x58, 0x65, 0x58, 0x65, 0x57, 0x66, 0x5A, 0x65, 0x58, 0x63, 0x58, 0x62, 0x55, 0x64, 0x58, 0x64, 0x57, 0x63, 0x56, 0x65, 0x58, 0x65, 0x58, 0x65, 0x59, 0x64, 0x58, 0x66, 0x59, 0x67, 0x59, 0x65, 0x5A, 0x66, 0x5A, 0x66, 0x59, 0x68, 0x5B, 0x68, 0x5A, 0x67, 0x59, 0x69, 0x5C, 0x69, 0x5D, 0x69, 0x5C, 0x67, 0x5A, 0x66, 0x5A, 0x64, 0x58, 0x66, 0x59, 0x67, 0x59, 0x6B, 0x5E, 0x67, 0x5B, 0x66, 0x5B, 0x66, 0x5A, 0x66, 0x59, 0x69, 0x5A, 0x67, 0x5A, 0x67, 0x59, 0x69, 0x5B, 0x66, 0x59, 0x69, 0x5C, 0x6B, 0x5E, 0x6A, 0x5D, 0x69, 0x5B, 0x68, 0x5C, 0x67, 0x5C, 0x68, 0x5D, 0x68, 0x5C, 0x6A, 0x5D, 0x67, 0x5A, 0x66, 0x59, 0x66, 0x5A, 0x64, 0x57, 0x63, 0x56, 0x64, 0x58, 0x64, 0x56, 0x62, 0x54, 0x61, 0x54, 0x61, 0x55, 0x63, 0x58, 0x61, 0x54, 0x5C, 0x50, 0x5A, 0x50, 0x57, 0x4D, 0x58, 0x4D, 0x5A, 0x4F, 0x5B, 0x50, 0x5B, 0x50, 0x5A, 0x50, 0x59, 0x50, 0x5A, 0x4E, 0x5A, 0x4F, 0x59, 0x4F, 0x5A, 0x50, 0x5A, 0x4F, 0x5D, 0x52, 0x5A, 0x4E, 0x59, 0x4E, 0x58, 0x4E, 0x58, 0x4E, 0x58, 0x4C, 0x40, 0x36, 0x29, 0x25, 0x21, 0x21, 0x22, 0x22, 0x20, 0x21, 0x1F, 0x21, 0x20, 0x22, 0x22, 0x25, 0x21, 0x23, 0x23, 0x26, 0x26, 0x28, 0x24, 0x2A, 0x26, 0x28, 0x24, 0x24, 0x20, 0x21, 0x24, 0x26, 0x28, 0x2B, 0x22, 0x22, 0x22, 0x26, 0x25, 0x28, 0x23, 0x27, 0x26, 0x28, 0x1F, 0x21, 0x23, 0x24, 0x23, 0x26, 0x22, 0x27, 0x22, 0x24, 0x25, 0x27, 0x24, 0x28, 0x28, 0x2B, 0x25, 0x26, 0x25, 0x27, 0x23, 0x26, 0x22, 0x24, 0x27, 0x2A, 0x20, 0x23, 0x24, 0x27, 0x24, 0x26, 0x22, 0x24, 0x21, 0x24, 0x24, 0x28, 0x27, 0x28, 0x21, 0x24, 0x21, 0x26
    },

    {
        0x51, 0x1D, 0x50, 0x1D, 0x50, 0x1D, 0x50, 0x1C, 0x51, 0x1C, 0x52, 0x1C, 0x50, 0x1C, 0x51, 0x1D, 0x52, 0x1D, 0x51, 0x1D, 0x52, 0x1D, 0x52, 0x1D, 0x52, 0x1D, 0x52, 0x1E, 0x54, 0x1E, 0x53, 0x1E, 0x52, 0x1E, 0x51, 0x1E, 0x51, 0x1D, 0x51, 0x1C, 0x50, 0x1C, 0x50, 0x1D, 0x50, 0x1D, 0x4E, 0x1D, 0x4A, 0x1B, 0x42, 0x19, 0x3A, 0x19, 0x3A, 0x19, 0x45, 0x1B, 0x49, 0x1C, 0x44, 0x1A, 0x38, 0x18, 0x29, 0x14, 0x20, 0x12, 0x1D, 0x12, 0x1A, 0x11, 0x18, 0x10, 0x16, 0x0F, 0x15, 0x0F, 0x14, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x16, 0x10, 0x15, 0x10, 0x16, 0x10, 0x17, 0x11, 0x17, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x17, 0x10, 0x17, 0x11, 0x17, 0x11, 0x18, 0x13, 0x1B, 0x18, 0x25, 0x24, 0x2C, 0x26, 0x25, 0x1E, 0x1F, 0x18, 0x1C, 0x16, 0x1B, 0x15, 0x1A, 0x14, 0x1A, 0x13, 0x1A, 0x13, 0x19, 0x13, 0x19, 0x14, 0x1F, 0x19, 0x2C, 0x23, 0x37, 0x2A, 0x30, 0x22, 0x27, 0x1C, 0x22, 0x19, 0x1F, 0x17, 0x1D, 0x15, 0x1C, 0x14, 0x1B, 0x13, 0x19, 0x13, 0x18, 0x11, 0x18, 0x12, 0x18, 0x11, 0x17, 0x10, 0x17, 0x10, 0x18, 0x11, 0x18, 0x12, 0x19, 0x12, 0x1A, 0x12, 0x19, 0x12, 0x1B, 0x13, 0x1B, 0x12, 0x1A, 0x12, 0x19, 0x12, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x19, 0x11, 0x18, 0x11, 0x17, 0x10, 0x17, 0x11, 0x17, 0x10, 0x18, 0x10, 0x17, 0x10, 0x18, 0x11, 0x17, 0x10, 0x18, 0x11, 0x18, 0x10, 0x1A, 0x11, 0x22, 0x14, 0x3C, 0x1C, 0x52, 0x1F, 0x56, 0x20, 0x56, 0x20, 0x43, 0x1C, 0x35, 0x1A, 0x46, 0x1E, 0x56, 0x21, 0x5B, 0x22, 0x5D, 0x22, 0x5D, 0x22, 0x60, 0x22, 0x60, 0x22, 0x5E, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x5E, 0x22, 0x5F, 0x21, 0x5E, 0x22, 0x5E, 0x21, 0x5C, 0x21, 0x5E, 0x21, 0x5E, 0x21, 0x5E, 0x22, 0x5E, 0x22, 0x5F, 0x23, 0x60, 0x22, 0x5E, 0x22, 0x5F, 0x22, 0x60, 0x21, 0x5E, 0x21, 0x5C, 0x20, 0x5C, 0x20, 0x5F, 0x22, 0x5F, 0x22, 0x61, 0x22, 0x60, 0x22, 0x5F, 0x21, 0x5E, 0x21, 0x5E, 0x21, 0x5D, 0x21, 0x5D, 0x21, 0x5D, 0x21, 0x5F, 0x23, 0x5F, 0x22, 0x5D, 0x21, 0x5F, 0x21, 0x5E, 0x21, 0x5E, 0x21, 0x60, 0x22, 0x61, 0x22, 0x62, 0x23, 0x5E, 0x22, 0x5F, 0x22, 0x5E, 0x22, 0x61, 0x22, 0x5E, 0x21, 0x5E, 0x21, 0x5E, 0x21, 0x5F, 0x21, 0x5D, 0x21, 0x5E, 0x22, 0x5C, 0x21, 0x5C, 0x21, 0x5F, 0x24, 0x5E, 0x21, 0x5D, 0x21, 0x5C, 0x21, 0x5E, 0x21, 0x5D, 0x22, 0x5E, 0x21, 0x5C, 0x21, 0x5D, 0x21, 0x5D, 0x21, 0x5E, 0x21, 0x5E, 0x22, 0x5D, 0x21, 0x5C, 0x21, 0x5C, 0x20, 0x5B, 0x20, 0x5E, 0x21, 0x5C, 0x21, 0x5C, 0x21, 0x5D, 0x21, 0x5D, 0x22, 0x5D, 0x21, 0x5A, 0x20, 0x5C, 0x21, 0x5D, 0x21, 0x5D, 0x21, 0x5D, 0x21, 0x5C, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x5D, 0x22, 0x5E, 0x22, 0x5F, 0x22, 0x5E, 0x22, 0x5E, 0x22, 0x5F, 0x22, 0x60, 0x22, 0x60, 0x22, 0x60, 0x23, 0x5F, 0x23, 0x5D, 0x22, 0x5E, 0x22, 0x5F, 0x22, 0x63, 0x23, 0x60, 0x22, 0x5B, 0x20, 0x5E, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x5C, 0x21, 0x5E, 0x22, 0x5E, 0x22, 0x5D, 0x22, 0x60, 0x22, 0x62, 0x23, 0x61, 0x23, 0x60, 0x22, 0x62, 0x24, 0x61, 0x24, 0x60, 0x23, 0x60, 0x24, 0x62, 0x24, 0x60, 0x23, 0x5F, 0x23, 0x61, 0x22, 0x5F, 0x22, 0x5C, 0x22, 0x5B, 0x21, 0x5B, 0x21, 0x58, 0x20, 0x59, 0x20, 0x59, 0x21, 0x5C, 0x22, 0x5B, 0x21, 0x58, 0x1F, 0x55, 0x1F, 0x54, 0x20, 0x53, 0x1E, 0x53, 0x1F, 0x53, 0x1E, 0x54, 0x1F, 0x56, 0x20, 0x52, 0x1E, 0x51, 0x1E, 0x53, 0x1E, 0x52, 0x1F, 0x54, 0x1E, 0x52, 0x1E, 0x52, 0x1E, 0x52, 0x1E, 0x53, 0x1E, 0x52, 0x1E, 0x52, 0x1E, 0x50, 0x1D, 0x3E, 0x1A, 0x2B, 0x17, 0x2A, 0x17, 0x24, 0x17, 0x26, 0x17, 0x25, 0x16, 0x28, 0x17, 0x2D, 0x1A, 0x2D, 0x19, 0x2D, 0x18, 0x2E, 0x19, 0x2B, 0x18, 0x2A, 0x18, 0x27, 0x17, 0x25, 0x17, 0x2F, 0x19, 0x2D, 0x19, 0x26, 0x17, 0x2B, 0x19, 0x29, 0x18, 0x28, 0x17, 0x26, 0x16, 0x29, 0x17, 0x28, 0x16, 0x28, 0x17, 0x29, 0x18, 0x29, 0x18, 0x2B, 0x17, 0x2C, 0x19, 0x2B, 0x17, 0x27, 0x17, 0x2A, 0x18, 0x27, 0x17, 0x2B, 0x18, 0x25, 0x16, 0x25, 0x16, 0x28, 0x16, 0x27, 0x15, 0x21, 0x14, 0x2A, 0x17, 0x24, 0x14, 0x24, 0x15, 0x28, 0x16, 0x29, 0x17
    },

    {
        0x58, 0x4E, 0x57, 0x4E, 0x58, 0x4E, 0x59, 0x4E, 0x59, 0x4F, 0x5A, 0x4E, 0x59, 0x4E, 0x59, 0x4E, 0x5A, 0x4F, 0x5A, 0x4E, 0x5B, 0x4F, 0x5B, 0x4F, 0x5B, 0x4F, 0x5C, 0x4F, 0x5C, 0x50, 0x5D, 0x51, 0x5B, 0x4E, 0x5A, 0x4D, 0x5A, 0x4E, 0x5A, 0x4D, 0x5A, 0x4C, 0x59, 0x4E, 0x58, 0x4D, 0x54, 0x4A, 0x4F, 0x44, 0x46, 0x3C, 0x3D, 0x37, 0x3D, 0x3B, 0x48, 0x45, 0x4C, 0x45, 0x43, 0x3D, 0x35, 0x30, 0x26, 0x23, 0x1C, 0x1C, 0x18, 0x1A, 0x16, 0x18, 0x14, 0x16, 0x13, 0x15, 0x11, 0x14, 0x11, 0x14, 0x10, 0x13, 0x10, 0x13, 0x11, 0x14, 0x11, 0x14, 0x11, 0x14, 0x10, 0x14, 0x10, 0x14, 0x11, 0x14, 0x11, 0x14, 0x11, 0x14, 0x12, 0x15, 0x11, 0x15, 0x11, 0x15, 0x12, 0x15, 0x12, 0x16, 0x12, 0x15, 0x11, 0x15, 0x11, 0x15, 0x12, 0x15, 0x11, 0x15, 0x12, 0x15, 0x12, 0x15, 0x12, 0x15, 0x13, 0x16, 0x14, 0x17, 0x17, 0x1A, 0x1D, 0x22, 0x23, 0x27, 0x1F, 0x20, 0x19, 0x1C, 0x18, 0x1A, 0x16, 0x19, 0x15, 0x18, 0x14, 0x17, 0x14, 0x18, 0x14, 0x17, 0x16, 0x18, 0x1B, 0x21, 0x26, 0x30, 0x2E, 0x38, 0x2A, 0x2D, 0x22, 0x25, 0x1E, 0x21, 0x1A, 0x1D, 0x17, 0x1B, 0x16, 0x1A, 0x15, 0x19, 0x15, 0x18, 0x13, 0x16, 0x13, 0x16, 0x13, 0x17, 0x12, 0x16, 0x12, 0x16, 0x13, 0x17, 0x13, 0x17, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x15, 0x19, 0x15, 0x19, 0x15, 0x19, 0x14, 0x18, 0x14, 0x18, 0x14, 0x17, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x12, 0x16, 0x13, 0x16, 0x12, 0x16, 0x13, 0x16, 0x12, 0x16, 0x13, 0x15, 0x12, 0x15, 0x13, 0x16, 0x14, 0x16, 0x16, 0x18, 0x1C, 0x1E, 0x33, 0x36, 0x4B, 0x4A, 0x57, 0x51, 0x59, 0x52, 0x4A, 0x41, 0x38, 0x33, 0x44, 0x41, 0x58, 0x50, 0x5F, 0x57, 0x62, 0x58, 0x64, 0x59, 0x67, 0x5B, 0x68, 0x5B, 0x68, 0x5A, 0x68, 0x5B, 0x66, 0x5A, 0x66, 0x5A, 0x67, 0x5B, 0x67, 0x59, 0x68, 0x5A, 0x66, 0x59, 0x68, 0x5A, 0x68, 0x5A, 0x67, 0x5A, 0x64, 0x59, 0x67, 0x5A, 0x66, 0x59, 0x65, 0x5A, 0x67, 0x5B, 0x68, 0x5A, 0x67, 0x59, 0x65, 0x56, 0x64, 0x57, 0x68, 0x5A, 0x68, 0x5A, 0x68, 0x5A, 0x68, 0x5B, 0x66, 0x5A, 0x65, 0x59, 0x66, 0x58, 0x65, 0x59, 0x65, 0x58, 0x65, 0x58, 0x67, 0x5A, 0x67, 0x5A, 0x67, 0x59, 0x67, 0x59, 0x66, 0x58, 0x67, 0x5A, 0x67, 0x5A, 0x68, 0x5B, 0x68, 0x5C, 0x68, 0x5A, 0x66, 0x5A, 0x66, 0x59, 0x69, 0x5B, 0x68, 0x59, 0x65, 0x58, 0x67, 0x58, 0x68, 0x59, 0x65, 0x58, 0x66, 0x59, 0x64, 0x57, 0x63, 0x57, 0x67, 0x5A, 0x67, 0x59, 0x66, 0x58, 0x65, 0x59, 0x67, 0x59, 0x67, 0x5A, 0x66, 0x58, 0x65, 0x56, 0x65, 0x59, 0x67, 0x59, 0x67, 0x5A, 0x66, 0x59, 0x66, 0x59, 0x64, 0x58, 0x63, 0x57, 0x64, 0x57, 0x68, 0x59, 0x65, 0x57, 0x65, 0x58, 0x64, 0x58, 0x66, 0x59, 0x66, 0x58, 0x62, 0x56, 0x63, 0x57, 0x66, 0x59, 0x65, 0x58, 0x66, 0x59, 0x65, 0x58, 0x68, 0x5A, 0x67, 0x58, 0x63, 0x59, 0x66, 0x5A, 0x69, 0x5C, 0x67, 0x58, 0x65, 0x58, 0x66, 0x5A, 0x67, 0x5A, 0x68, 0x5B, 0x68, 0x5B, 0x66, 0x59, 0x65, 0x5A, 0x67, 0x5A, 0x68, 0x5C, 0x6A, 0x5C, 0x69, 0x5C, 0x63, 0x56, 0x66, 0x59, 0x68, 0x5B, 0x69, 0x5A, 0x65, 0x58, 0x68, 0x59, 0x65, 0x59, 0x68, 0x5A, 0x69, 0x5C, 0x6B, 0x5D, 0x6A, 0x5E, 0x68, 0x5C, 0x6B, 0x5E, 0x68, 0x5E, 0x67, 0x5C, 0x66, 0x5B, 0x69, 0x5C, 0x66, 0x5A, 0x68, 0x5C, 0x69, 0x5C, 0x67, 0x59, 0x64, 0x58, 0x65, 0x58, 0x63, 0x54, 0x60, 0x54, 0x62, 0x56, 0x61, 0x55, 0x64, 0x58, 0x62, 0x57, 0x60, 0x54, 0x5D, 0x53, 0x5B, 0x50, 0x5C, 0x50, 0x5A, 0x50, 0x5B, 0x51, 0x5C, 0x51, 0x5C, 0x51, 0x59, 0x4F, 0x5A, 0x4F, 0x5B, 0x50, 0x59, 0x4F, 0x5B, 0x4F, 0x59, 0x4D, 0x5A, 0x4E, 0x58, 0x4E, 0x5B, 0x4F, 0x5C, 0x4F, 0x5A, 0x4F, 0x56, 0x4C, 0x41, 0x38, 0x2D, 0x2B, 0x29, 0x28, 0x23, 0x25, 0x23, 0x26, 0x22, 0x25, 0x24, 0x27, 0x29, 0x2E, 0x28, 0x2D, 0x26, 0x29, 0x28, 0x2C, 0x25, 0x28, 0x26, 0x27, 0x22, 0x22, 0x23, 0x27, 0x28, 0x2B, 0x27, 0x2A, 0x22, 0x25, 0x25, 0x27, 0x25, 0x28, 0x23, 0x23, 0x22, 0x24, 0x24, 0x27, 0x23, 0x24, 0x25, 0x28, 0x23, 0x26, 0x25, 0x28, 0x25, 0x26, 0x27, 0x2B, 0x23, 0x23, 0x23, 0x26, 0x24, 0x25, 0x24, 0x27, 0x24, 0x26, 0x20, 0x20, 0x22, 0x25, 0x23, 0x25, 0x22, 0x22, 0x1E, 0x20, 0x26, 0x29, 0x1F, 0x20, 0x20, 0x22, 0x23, 0x25, 0x25, 0x26
    },

    {
        0x53, 0x1E, 0x51, 0x1D, 0x51, 0x1D, 0x52, 0x1C, 0x51, 0x1C, 0x52, 0x1D, 0x50, 0x1D, 0x51, 0x1D, 0x52, 0x1D, 0x51, 0x1C, 0x51, 0x1D, 0x51, 0x1D, 0x52, 0x1E, 0x53, 0x1E, 0x54, 0x1F, 0x54, 0x1E, 0x54, 0x1E, 0x52, 0x1D, 0x52, 0x1E, 0x51, 0x1D, 0x51, 0x1D, 0x50, 0x1D, 0x4E, 0x1D, 0x4A, 0x1B, 0x43, 0x1A, 0x3A, 0x19, 0x39, 0x19, 0x42, 0x1A, 0x48, 0x1B, 0x44, 0x1A, 0x38, 0x18, 0x29, 0x15, 0x20, 0x12, 0x1C, 0x11, 0x19, 0x10, 0x17, 0x10, 0x17, 0x10, 0x16, 0x0F, 0x15, 0x0F, 0x15, 0x0E, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x10, 0x15, 0x10, 0x16, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x17, 0x10, 0x17, 0x11, 0x17, 0x11, 0x17, 0x10, 0x16, 0x10, 0x16, 0x10, 0x17, 0x11, 0x16, 0x10, 0x17, 0x10, 0x17, 0x11, 0x17, 0x11, 0x17, 0x11, 0x18, 0x12, 0x1A, 0x15, 0x1E, 0x19, 0x23, 0x1C, 0x20, 0x18, 0x1D, 0x16, 0x1B, 0x15, 0x1A, 0x14, 0x19, 0x13, 0x19, 0x12, 0x19, 0x13, 0x19, 0x12, 0x1C, 0x15, 0x28, 0x1D, 0x40, 0x2C, 0x5B, 0x36, 0x4D, 0x2D, 0x33, 0x20, 0x29, 0x1C, 0x23, 0x18, 0x1D, 0x15, 0x1B, 0x13, 0x1A, 0x13, 0x19, 0x12, 0x19, 0x12, 0x18, 0x11, 0x18, 0x11, 0x17, 0x11, 0x17, 0x11, 0x18, 0x11, 0x19, 0x12, 0x18, 0x11, 0x19, 0x12, 0x18, 0x11, 0x1A, 0x12, 0x18, 0x11, 0x18, 0x11, 0x1A, 0x11, 0x19, 0x12, 0x19, 0x11, 0x19, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x17, 0x10, 0x18, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x18, 0x10, 0x1A, 0x11, 0x20, 0x14, 0x38, 0x1A, 0x4F, 0x1F, 0x58, 0x21, 0x57, 0x21, 0x43, 0x1B, 0x35, 0x1A, 0x47, 0x1E, 0x56, 0x21, 0x5C, 0x22, 0x5C, 0x22, 0x60, 0x23, 0x5F, 0x23, 0x60, 0x23, 0x61, 0x23, 0x60, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x5E, 0x21, 0x5F, 0x21, 0x60, 0x22, 0x61, 0x22, 0x60, 0x22, 0x5F, 0x22, 0x5E, 0x22, 0x5F, 0x22, 0x60, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x5E, 0x21, 0x5E, 0x21, 0x5D, 0x21, 0x5B, 0x20, 0x5F, 0x22, 0x5F, 0x21, 0x60, 0x22, 0x5F, 0x22, 0x5D, 0x21, 0x5E, 0x21, 0x5E, 0x21, 0x5D, 0x20, 0x5E, 0x21, 0x5C, 0x20, 0x5E, 0x22, 0x5E, 0x22, 0x5F, 0x21, 0x5C, 0x21, 0x5D, 0x21, 0x5F, 0x22, 0x5E, 0x21, 0x5D, 0x21, 0x60, 0x22, 0x60, 0x22, 0x5F, 0x21, 0x5F, 0x22, 0x5F, 0x21, 0x5C, 0x20, 0x5D, 0x21, 0x5B, 0x20, 0x5C, 0x21, 0x5C, 0x21, 0x5E, 0x22, 0x5C, 0x21, 0x5B, 0x20, 0x5B, 0x21, 0x5D, 0x20, 0x5D, 0x20, 0x5C, 0x21, 0x5F, 0x22, 0x5E, 0x22, 0x5E, 0x22, 0x5B, 0x20, 0x5B, 0x20, 0x5F, 0x22, 0x5F, 0x21, 0x5F, 0x22, 0x5E, 0x22, 0x5F, 0x21, 0x5D, 0x21, 0x5C, 0x20, 0x5E, 0x20, 0x5E, 0x21, 0x5E, 0x22, 0x5C, 0x21, 0x5E, 0x22, 0x5C, 0x20, 0x5C, 0x21, 0x5B, 0x21, 0x5D, 0x21, 0x5E, 0x21, 0x5D, 0x21, 0x5D, 0x21, 0x5C, 0x21, 0x5C, 0x21, 0x5D, 0x22, 0x5E, 0x21, 0x5E, 0x22, 0x60, 0x22, 0x5E, 0x21, 0x5E, 0x22, 0x5E, 0x22, 0x61, 0x23, 0x62, 0x23, 0x5E, 0x22, 0x5D, 0x21, 0x5F, 0x23, 0x5F, 0x22, 0x5E, 0x21, 0x5F, 0x22, 0x5E, 0x21, 0x5F, 0x22, 0x60, 0x22, 0x5E, 0x22, 0x5E, 0x21, 0x5D, 0x21, 0x5C, 0x21, 0x5E, 0x22, 0x61, 0x22, 0x61, 0x23, 0x60, 0x23, 0x62, 0x23, 0x65, 0x25, 0x5F, 0x23, 0x63, 0x24, 0x60, 0x24, 0x61, 0x24, 0x5F, 0x22, 0x5E, 0x22, 0x5E, 0x22, 0x5D, 0x21, 0x5B, 0x21, 0x5B, 0x21, 0x5C, 0x21, 0x5A, 0x20, 0x5B, 0x21, 0x5C, 0x20, 0x59, 0x20, 0x5A, 0x21, 0x58, 0x20, 0x57, 0x20, 0x55, 0x20, 0x54, 0x1F, 0x54, 0x1F, 0x57, 0x20, 0x59, 0x20, 0x54, 0x1F, 0x54, 0x1E, 0x51, 0x1E, 0x53, 0x1F, 0x51, 0x1E, 0x51, 0x1E, 0x54, 0x1E, 0x51, 0x1E, 0x53, 0x1E, 0x51, 0x1E, 0x53, 0x1E, 0x52, 0x1E, 0x52, 0x1F, 0x45, 0x1D, 0x36, 0x1C, 0x2B, 0x17, 0x28, 0x18, 0x30, 0x1B, 0x29, 0x18, 0x2E, 0x1A, 0x31, 0x1B, 0x2F, 0x1A, 0x27, 0x17, 0x27, 0x16, 0x22, 0x16, 0x27, 0x16, 0x23, 0x16, 0x28, 0x17, 0x26, 0x16, 0x22, 0x15, 0x26, 0x16, 0x23, 0x15, 0x26, 0x16, 0x20, 0x13, 0x2A, 0x18, 0x28, 0x17, 0x24, 0x15, 0x27, 0x16, 0x23, 0x16, 0x2A, 0x18, 0x26, 0x17, 0x24, 0x16, 0x1E, 0x13, 0x27, 0x17, 0x21, 0x15, 0x26, 0x16, 0x1F, 0x14, 0x22, 0x15, 0x22, 0x15, 0x26, 0x16, 0x22, 0x13, 0x22, 0x14, 0x27, 0x16, 0x22, 0x15, 0x2A, 0x18, 0x24, 0x15, 0x27, 0x16
    },

    {
        0x5A, 0x4F, 0x5A, 0x4E, 0x5A, 0x4F, 0x5A, 0x4D, 0x59, 0x4E, 0x5A, 0x4E, 0x59, 0x4D, 0x5B, 0x4F, 0x5B, 0x4F, 0x5A, 0x4D, 0x5B, 0x4E, 0x5B, 0x4E, 0x5D, 0x4F, 0x5C, 0x4F, 0x5D, 0x50, 0x5E, 0x51, 0x5E, 0x51, 0x5C, 0x4F, 0x5B, 0x4F, 0x5A, 0x4F, 0x59, 0x4E, 0x57, 0x4D, 0x55, 0x4A, 0x50, 0x45, 0x48, 0x3E, 0x3D, 0x37, 0x3D, 0x3A, 0x46, 0x42, 0x4B, 0x43, 0x44, 0x3D, 0x36, 0x30, 0x26, 0x23, 0x1C, 0x1C, 0x18, 0x19, 0x16, 0x17, 0x14, 0x16, 0x13, 0x16, 0x12, 0x15, 0x11, 0x14, 0x11, 0x14, 0x10, 0x14, 0x10, 0x14, 0x11, 0x14, 0x11, 0x14, 0x11, 0x14, 0x12, 0x14, 0x11, 0x15, 0x11, 0x14, 0x11, 0x15, 0x12, 0x15, 0x11, 0x15, 0x12, 0x15, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x15, 0x12, 0x16, 0x13, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x13, 0x16, 0x13, 0x16, 0x15, 0x17, 0x18, 0x1A, 0x1C, 0x1E, 0x22, 0x21, 0x1E, 0x1D, 0x1A, 0x1B, 0x18, 0x1A, 0x16, 0x19, 0x15, 0x17, 0x14, 0x17, 0x15, 0x17, 0x15, 0x18, 0x1A, 0x1D, 0x24, 0x2D, 0x37, 0x49, 0x4D, 0x63, 0x47, 0x50, 0x30, 0x33, 0x24, 0x29, 0x1F, 0x22, 0x1A, 0x1C, 0x17, 0x19, 0x15, 0x18, 0x14, 0x17, 0x14, 0x18, 0x13, 0x17, 0x13, 0x17, 0x12, 0x16, 0x13, 0x16, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x14, 0x17, 0x14, 0x17, 0x14, 0x18, 0x14, 0x17, 0x14, 0x17, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x14, 0x17, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x14, 0x17, 0x13, 0x16, 0x13, 0x16, 0x13, 0x16, 0x13, 0x16, 0x13, 0x16, 0x12, 0x16, 0x13, 0x16, 0x15, 0x17, 0x1A, 0x1C, 0x2F, 0x33, 0x4A, 0x49, 0x58, 0x54, 0x59, 0x53, 0x49, 0x41, 0x38, 0x33, 0x44, 0x42, 0x56, 0x4F, 0x5E, 0x56, 0x62, 0x58, 0x64, 0x5A, 0x65, 0x5A, 0x68, 0x5B, 0x68, 0x5C, 0x66, 0x5B, 0x66, 0x5A, 0x67, 0x5A, 0x67, 0x5B, 0x67, 0x59, 0x69, 0x5C, 0x69, 0x5C, 0x68, 0x5B, 0x66, 0x5B, 0x66, 0x5A, 0x66, 0x5B, 0x66, 0x5B, 0x66, 0x5B, 0x68, 0x5A, 0x65, 0x57, 0x66, 0x59, 0x66, 0x58, 0x66, 0x57, 0x68, 0x5B, 0x67, 0x59, 0x69, 0x5B, 0x69, 0x5B, 0x66, 0x59, 0x66, 0x59, 0x66, 0x59, 0x65, 0x59, 0x67, 0x59, 0x64, 0x57, 0x67, 0x5A, 0x67, 0x5A, 0x68, 0x5A, 0x65, 0x57, 0x65, 0x59, 0x67, 0x5A, 0x67, 0x58, 0x64, 0x57, 0x66, 0x5A, 0x67, 0x59, 0x66, 0x5A, 0x67, 0x5A, 0x65, 0x59, 0x64, 0x57, 0x64, 0x57, 0x65, 0x57, 0x66, 0x58, 0x64, 0x59, 0x66, 0x59, 0x66, 0x58, 0x65, 0x57, 0x64, 0x57, 0x66, 0x58, 0x66, 0x58, 0x66, 0x59, 0x67, 0x5A, 0x67, 0x59, 0x67, 0x5A, 0x63, 0x56, 0x63, 0x58, 0x69, 0x5B, 0x69, 0x5B, 0x69, 0x5B, 0x68, 0x59, 0x67, 0x59, 0x67, 0x59, 0x65, 0x57, 0x66, 0x58, 0x67, 0x58, 0x66, 0x59, 0x66, 0x59, 0x66, 0x5B, 0x64, 0x56, 0x64, 0x58, 0x65, 0x59, 0x67, 0x5A, 0x67, 0x59, 0x67, 0x59, 0x65, 0x58, 0x66, 0x58, 0x65, 0x59, 0x67, 0x5B, 0x66, 0x5B, 0x67, 0x5A, 0x68, 0x5A, 0x65, 0x59, 0x67, 0x5B, 0x66, 0x58, 0x69, 0x5D, 0x69, 0x5B, 0x65, 0x59, 0x66, 0x5A, 0x67, 0x5A, 0x67, 0x5C, 0x67, 0x5A, 0x69, 0x5B, 0x67, 0x5A, 0x69, 0x5C, 0x6A, 0x5B, 0x67, 0x5B, 0x66, 0x58, 0x67, 0x59, 0x65, 0x58, 0x65, 0x59, 0x69, 0x5D, 0x69, 0x5C, 0x67, 0x5B, 0x68, 0x5E, 0x6C, 0x5F, 0x68, 0x5C, 0x6A, 0x5E, 0x67, 0x5B, 0x69, 0x5E, 0x68, 0x5B, 0x64, 0x59, 0x66, 0x5B, 0x64, 0x57, 0x64, 0x58, 0x65, 0x5A, 0x67, 0x58, 0x63, 0x57, 0x64, 0x57, 0x64, 0x56, 0x61, 0x55, 0x61, 0x56, 0x5F, 0x55, 0x5D, 0x54, 0x5C, 0x51, 0x5A, 0x50, 0x5C, 0x52, 0x5E, 0x54, 0x5E, 0x53, 0x5A, 0x4F, 0x5B, 0x50, 0x59, 0x4E, 0x5B, 0x4F, 0x5A, 0x4F, 0x5B, 0x4E, 0x5C, 0x4F, 0x59, 0x4D, 0x5A, 0x4F, 0x5A, 0x4E, 0x5A, 0x4E, 0x5A, 0x4F, 0x58, 0x4E, 0x45, 0x3C, 0x33, 0x32, 0x29, 0x28, 0x24, 0x27, 0x2B, 0x30, 0x24, 0x28, 0x2A, 0x2D, 0x2A, 0x2D, 0x28, 0x29, 0x21, 0x24, 0x21, 0x23, 0x1F, 0x22, 0x23, 0x24, 0x21, 0x24, 0x23, 0x24, 0x1F, 0x21, 0x1E, 0x1F, 0x21, 0x24, 0x21, 0x22, 0x21, 0x22, 0x1E, 0x1E, 0x25, 0x29, 0x24, 0x25, 0x20, 0x21, 0x20, 0x23, 0x20, 0x24, 0x23, 0x27, 0x22, 0x25, 0x1F, 0x21, 0x1B, 0x1D, 0x23, 0x25, 0x1E, 0x20, 0x22, 0x24, 0x1D, 0x1E, 0x20, 0x23, 0x21, 0x23, 0x24, 0x28, 0x21, 0x20, 0x20, 0x23, 0x23, 0x25, 0x20, 0x25, 0x27, 0x29, 0x1F, 0x23, 0x23, 0x26
    },

    {
        0x52, 0x1E, 0x50, 0x1C, 0x50, 0x1D, 0x50, 0x1C, 0x50, 0x1C, 0x51, 0x1D, 0x51, 0x1D, 0x51, 0x1D, 0x52, 0x1D, 0x51, 0x1D, 0x51, 0x1D, 0x52, 0x1D, 0x52, 0x1D, 0x53, 0x1D, 0x54, 0x1E, 0x54, 0x1E, 0x54, 0x1E, 0x53, 0x1E, 0x54, 0x1E, 0x53, 0x1E, 0x51, 0x1D, 0x4F, 0x1D, 0x4A, 0x1C, 0x44, 0x1B, 0x3B, 0x19, 0x39, 0x19, 0x41, 0x1A, 0x47, 0x1B, 0x42, 0x19, 0x38, 0x17, 0x2A, 0x14, 0x21, 0x12, 0x1C, 0x11, 0x18, 0x10, 0x17, 0x10, 0x16, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x14, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x10, 0x15, 0x0F, 0x16, 0x0F, 0x15, 0x10, 0x16, 0x0F, 0x16, 0x10, 0x16, 0x10, 0x17, 0x10, 0x16, 0x10, 0x17, 0x11, 0x17, 0x11, 0x17, 0x10, 0x16, 0x10, 0x17, 0x10, 0x16, 0x10, 0x17, 0x10, 0x16, 0x10, 0x17, 0x11, 0x17, 0x11, 0x18, 0x11, 0x19, 0x11, 0x19, 0x13, 0x1C, 0x16, 0x20, 0x1B, 0x26, 0x1D, 0x24, 0x1B, 0x1F, 0x17, 0x1C, 0x15, 0x1B, 0x14, 0x1A, 0x13, 0x19, 0x12, 0x19, 0x12, 0x1B, 0x14, 0x25, 0x1B, 0x3B, 0x28, 0x60, 0x3A, 0x7B, 0x45, 0x7C, 0x42, 0x58, 0x2F, 0x36, 0x21, 0x28, 0x1A, 0x21, 0x16, 0x1D, 0x14, 0x1A, 0x12, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x12, 0x17, 0x11, 0x18, 0x11, 0x19, 0x12, 0x1A, 0x12, 0x19, 0x11, 0x19, 0x11, 0x18, 0x11, 0x19, 0x12, 0x19, 0x11, 0x18, 0x11, 0x19, 0x12, 0x19, 0x11, 0x18, 0x11, 0x1A, 0x12, 0x1A, 0x11, 0x18, 0x11, 0x19, 0x11, 0x18, 0x11, 0x18, 0x11, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x18, 0x10, 0x17, 0x10, 0x17, 0x10, 0x18, 0x10, 0x1A, 0x11, 0x1E, 0x13, 0x35, 0x1B, 0x4F, 0x1F, 0x58, 0x21, 0x56, 0x20, 0x46, 0x1B, 0x35, 0x1A, 0x43, 0x1E, 0x55, 0x20, 0x59, 0x21, 0x5E, 0x22, 0x5F, 0x23, 0x61, 0x23, 0x61, 0x22, 0x60, 0x22, 0x5E, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x5E, 0x21, 0x61, 0x22, 0x61, 0x22, 0x5E, 0x21, 0x5E, 0x21, 0x5F, 0x22, 0x5E, 0x21, 0x5F, 0x22, 0x60, 0x22, 0x5F, 0x21, 0x5D, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x60, 0x21, 0x5E, 0x21, 0x5E, 0x21, 0x5F, 0x21, 0x5F, 0x21, 0x5C, 0x20, 0x5E, 0x23, 0x60, 0x23, 0x5D, 0x22, 0x5D, 0x21, 0x5C, 0x21, 0x5F, 0x22, 0x60, 0x22, 0x5F, 0x22, 0x5D, 0x21, 0x5D, 0x21, 0x5D, 0x21, 0x5E, 0x21, 0x5E, 0x21, 0x5F, 0x21, 0x5D, 0x21, 0x5D, 0x21, 0x5E, 0x21, 0x5F, 0x21, 0x5E, 0x21, 0x5C, 0x21, 0x5E, 0x21, 0x60, 0x22, 0x5E, 0x22, 0x5D, 0x21, 0x5D, 0x21, 0x5E, 0x21, 0x5C, 0x20, 0x5A, 0x1F, 0x5E, 0x21, 0x5E, 0x22, 0x5D, 0x21, 0x5E, 0x22, 0x5D, 0x22, 0x5E, 0x21, 0x5B, 0x20, 0x5D, 0x22, 0x5F, 0x21, 0x5F, 0x22, 0x61, 0x22, 0x5F, 0x22, 0x5F, 0x21, 0x5A, 0x20, 0x5A, 0x1F, 0x5C, 0x21, 0x5E, 0x22, 0x5D, 0x21, 0x5C, 0x21, 0x5D, 0x21, 0x5E, 0x21, 0x5E, 0x22, 0x60, 0x22, 0x5E, 0x22, 0x5D, 0x20, 0x5E, 0x22, 0x5D, 0x22, 0x5D, 0x22, 0x5D, 0x21, 0x5C, 0x21, 0x5C, 0x22, 0x5D, 0x21, 0x5E, 0x21, 0x5F, 0x21, 0x5F, 0x22, 0x5F, 0x23, 0x5F, 0x22, 0x5D, 0x21, 0x5F, 0x22, 0x5E, 0x22, 0x5F, 0x22, 0x5E, 0x22, 0x5F, 0x23, 0x61, 0x22, 0x61, 0x22, 0x61, 0x23, 0x5D, 0x22, 0x5D, 0x21, 0x5D, 0x21, 0x5D, 0x22, 0x5F, 0x22, 0x61, 0x22, 0x60, 0x22, 0x5E, 0x23, 0x5F, 0x22, 0x63, 0x23, 0x63, 0x24, 0x62, 0x25, 0x60, 0x24, 0x61, 0x23, 0x5E, 0x22, 0x5D, 0x22, 0x5E, 0x21, 0x5C, 0x21, 0x5C, 0x21, 0x5C, 0x21, 0x5D, 0x21, 0x59, 0x20, 0x5A, 0x21, 0x59, 0x20, 0x58, 0x20, 0x5A, 0x21, 0x5A, 0x22, 0x5A, 0x22, 0x57, 0x1F, 0x55, 0x1F, 0x56, 0x1F, 0x55, 0x1F, 0x53, 0x1F, 0x52, 0x1E, 0x53, 0x1E, 0x53, 0x1E, 0x52, 0x1F, 0x53, 0x1E, 0x50, 0x1D, 0x52, 0x1D, 0x51, 0x1E, 0x53, 0x1E, 0x52, 0x1E, 0x51, 0x1E, 0x52, 0x1F, 0x51, 0x1E, 0x40, 0x1B, 0x2F, 0x19, 0x28, 0x16, 0x28, 0x18, 0x2B, 0x18, 0x27, 0x17, 0x2D, 0x19, 0x26, 0x17, 0x22, 0x15, 0x25, 0x16, 0x22, 0x15, 0x24, 0x16, 0x25, 0x16, 0x24, 0x16, 0x23, 0x16, 0x22, 0x15, 0x22, 0x16, 0x27, 0x17, 0x26, 0x16, 0x24, 0x16, 0x20, 0x14, 0x27, 0x17, 0x25, 0x15, 0x24, 0x16, 0x25, 0x16, 0x24, 0x16, 0x27, 0x17, 0x2C, 0x1A, 0x23, 0x15, 0x25, 0x16, 0x2A, 0x1A, 0x2D, 0x1A, 0x28, 0x17, 0x25, 0x17, 0x27, 0x18, 0x32, 0x1C, 0x2A, 0x18, 0x28, 0x16, 0x26, 0x17, 0x30, 0x1A, 0x2A, 0x18, 0x21, 0x16, 0x27, 0x19, 0x26, 0x17
    },

    {
        0x58, 0x4F, 0x58, 0x4D, 0x58, 0x4E, 0x59, 0x4E, 0x57, 0x4D, 0x58, 0x4E, 0x59, 0x4E, 0x5A, 0x4F, 0x5B, 0x50, 0x5C, 0x50, 0x5C, 0x4F, 0x5B, 0x4F, 0x5B, 0x4F, 0x5D, 0x51, 0x5D, 0x51, 0x5D, 0x51, 0x5D, 0x50, 0x5C, 0x4F, 0x5B, 0x50, 0x5B, 0x50, 0x59, 0x4F, 0x55, 0x4C, 0x50, 0x45, 0x48, 0x3E, 0x3E, 0x38, 0x3B, 0x39, 0x47, 0x43, 0x4B, 0x44, 0x43, 0x3C, 0x37, 0x30, 0x26, 0x23, 0x1D, 0x1E, 0x18, 0x1A, 0x16, 0x18, 0x13, 0x16, 0x12, 0x14, 0x11, 0x14, 0x11, 0x14, 0x11, 0x13, 0x11, 0x13, 0x10, 0x13, 0x11, 0x14, 0x11, 0x14, 0x11, 0x14, 0x11, 0x14, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x12, 0x15, 0x12, 0x15, 0x12, 0x15, 0x11, 0x15, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x11, 0x16, 0x12, 0x15, 0x11, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x17, 0x13, 0x17, 0x15, 0x18, 0x17, 0x19, 0x1B, 0x1C, 0x22, 0x21, 0x29, 0x26, 0x28, 0x24, 0x20, 0x1E, 0x1A, 0x1A, 0x17, 0x19, 0x15, 0x18, 0x15, 0x18, 0x15, 0x18, 0x19, 0x1C, 0x21, 0x29, 0x33, 0x44, 0x50, 0x68, 0x63, 0x7A, 0x66, 0x7A, 0x50, 0x58, 0x34, 0x37, 0x25, 0x27, 0x1E, 0x20, 0x19, 0x1C, 0x16, 0x19, 0x13, 0x17, 0x13, 0x16, 0x13, 0x16, 0x13, 0x16, 0x13, 0x17, 0x13, 0x17, 0x13, 0x18, 0x14, 0x18, 0x14, 0x18, 0x14, 0x17, 0x13, 0x17, 0x14, 0x18, 0x13, 0x17, 0x13, 0x17, 0x13, 0x18, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x13, 0x18, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x13, 0x16, 0x13, 0x16, 0x13, 0x16, 0x12, 0x16, 0x13, 0x16, 0x13, 0x16, 0x12, 0x16, 0x14, 0x17, 0x15, 0x17, 0x19, 0x1B, 0x2C, 0x30, 0x48, 0x49, 0x57, 0x54, 0x59, 0x54, 0x4C, 0x45, 0x38, 0x34, 0x40, 0x3F, 0x55, 0x4F, 0x5D, 0x55, 0x62, 0x59, 0x64, 0x5A, 0x67, 0x5B, 0x67, 0x5C, 0x66, 0x5A, 0x65, 0x5A, 0x66, 0x58, 0x67, 0x5A, 0x67, 0x5A, 0x68, 0x5B, 0x69, 0x5D, 0x66, 0x59, 0x65, 0x59, 0x66, 0x5A, 0x66, 0x59, 0x67, 0x59, 0x68, 0x5B, 0x67, 0x59, 0x67, 0x59, 0x67, 0x5A, 0x67, 0x5B, 0x68, 0x5B, 0x66, 0x59, 0x67, 0x5B, 0x68, 0x5B, 0x69, 0x5B, 0x66, 0x57, 0x66, 0x5C, 0x67, 0x5B, 0x65, 0x59, 0x63, 0x58, 0x65, 0x57, 0x66, 0x5A, 0x68, 0x5C, 0x67, 0x5A, 0x66, 0x59, 0x65, 0x59, 0x64, 0x58, 0x67, 0x5B, 0x67, 0x5A, 0x67, 0x59, 0x64, 0x58, 0x64, 0x58, 0x66, 0x59, 0x67, 0x5C, 0x68, 0x5B, 0x65, 0x59, 0x66, 0x5B, 0x6A, 0x5D, 0x69, 0x5A, 0x67, 0x5A, 0x67, 0x59, 0x66, 0x59, 0x66, 0x58, 0x65, 0x55, 0x67, 0x59, 0x65, 0x5A, 0x64, 0x58, 0x65, 0x59, 0x66, 0x5B, 0x66, 0x59, 0x63, 0x57, 0x66, 0x5A, 0x68, 0x5B, 0x69, 0x5B, 0x6A, 0x5C, 0x6B, 0x5C, 0x69, 0x5A, 0x63, 0x56, 0x63, 0x56, 0x66, 0x58, 0x67, 0x5A, 0x64, 0x58, 0x64, 0x58, 0x64, 0x58, 0x65, 0x59, 0x66, 0x59, 0x67, 0x5A, 0x66, 0x59, 0x65, 0x57, 0x66, 0x59, 0x67, 0x5A, 0x67, 0x59, 0x66, 0x5A, 0x64, 0x57, 0x65, 0x59, 0x65, 0x59, 0x66, 0x5B, 0x67, 0x5B, 0x66, 0x59, 0x67, 0x5C, 0x66, 0x5A, 0x65, 0x5A, 0x67, 0x5A, 0x66, 0x5B, 0x67, 0x5B, 0x69, 0x5C, 0x69, 0x5B, 0x6A, 0x5C, 0x69, 0x5B, 0x69, 0x5C, 0x66, 0x5A, 0x66, 0x5A, 0x66, 0x5A, 0x65, 0x5A, 0x66, 0x5A, 0x6B, 0x5D, 0x69, 0x5B, 0x66, 0x5B, 0x68, 0x5C, 0x6B, 0x5D, 0x6B, 0x5F, 0x69, 0x5D, 0x68, 0x5C, 0x69, 0x5C, 0x65, 0x58, 0x62, 0x58, 0x66, 0x5A, 0x64, 0x58, 0x65, 0x59, 0x65, 0x58, 0x66, 0x57, 0x63, 0x56, 0x65, 0x57, 0x62, 0x56, 0x62, 0x56, 0x61, 0x55, 0x60, 0x57, 0x61, 0x56, 0x5E, 0x53, 0x5D, 0x51, 0x5D, 0x52, 0x5C, 0x52, 0x59, 0x4F, 0x5A, 0x51, 0x5C, 0x50, 0x59, 0x4F, 0x59, 0x4F, 0x5C, 0x50, 0x58, 0x4D, 0x58, 0x4D, 0x58, 0x4E, 0x59, 0x4F, 0x59, 0x4F, 0x57, 0x4D, 0x59, 0x4F, 0x58, 0x4D, 0x42, 0x3A, 0x2D, 0x2C, 0x26, 0x25, 0x24, 0x26, 0x24, 0x26, 0x22, 0x26, 0x27, 0x27, 0x21, 0x23, 0x1E, 0x20, 0x22, 0x25, 0x20, 0x22, 0x21, 0x25, 0x21, 0x22, 0x20, 0x23, 0x1F, 0x21, 0x20, 0x22, 0x20, 0x24, 0x24, 0x27, 0x22, 0x25, 0x21, 0x23, 0x1E, 0x20, 0x22, 0x25, 0x1F, 0x21, 0x21, 0x24, 0x20, 0x22, 0x20, 0x24, 0x21, 0x25, 0x25, 0x2A, 0x1F, 0x23, 0x22, 0x24, 0x26, 0x2B, 0x27, 0x2C, 0x22, 0x24, 0x21, 0x23, 0x22, 0x27, 0x2C, 0x33, 0x23, 0x24, 0x22, 0x26, 0x23, 0x29, 0x28, 0x2B, 0x23, 0x27, 0x1C, 0x1D, 0x22, 0x27, 0x1E, 0x20
    },

    {
        0x51, 0x1E, 0x50, 0x1D, 0x51, 0x1E, 0x51, 0x1D, 0x51, 0x1D, 0x52, 0x1D, 0x51, 0x1D, 0x52, 0x1D, 0x53, 0x1E, 0x53, 0x1D, 0x52, 0x1E, 0x53, 0x1E, 0x53, 0x1D, 0x53, 0x1D, 0x53, 0x1E, 0x55, 0x1E, 0x54, 0x1E, 0x53, 0x1E, 0x53, 0x1E, 0x53, 0x1D, 0x51, 0x1E, 0x4D, 0x1D, 0x45, 0x1B, 0x3C, 0x1A, 0x3A, 0x19, 0x40, 0x1A, 0x46, 0x1B, 0x44, 0x1A, 0x39, 0x18, 0x2B, 0x15, 0x20, 0x12, 0x1C, 0x11, 0x1A, 0x11, 0x18, 0x0F, 0x15, 0x10, 0x15, 0x0F, 0x14, 0x0F, 0x14, 0x0F, 0x14, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x14, 0x0F, 0x15, 0x10, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x10, 0x15, 0x0F, 0x15, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x17, 0x11, 0x19, 0x11, 0x17, 0x11, 0x16, 0x10, 0x17, 0x10, 0x16, 0x11, 0x17, 0x11, 0x18, 0x11, 0x19, 0x12, 0x1A, 0x12, 0x19, 0x12, 0x19, 0x13, 0x1C, 0x15, 0x20, 0x19, 0x26, 0x1D, 0x28, 0x1E, 0x29, 0x1E, 0x26, 0x1B, 0x1F, 0x17, 0x1C, 0x14, 0x1A, 0x13, 0x19, 0x12, 0x1B, 0x14, 0x24, 0x1A, 0x38, 0x26, 0x59, 0x35, 0x78, 0x42, 0x83, 0x47, 0x87, 0x49, 0x82, 0x45, 0x60, 0x32, 0x39, 0x20, 0x28, 0x18, 0x21, 0x16, 0x1C, 0x14, 0x19, 0x12, 0x18, 0x11, 0x17, 0x11, 0x18, 0x11, 0x17, 0x11, 0x18, 0x11, 0x19, 0x12, 0x19, 0x12, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x19, 0x12, 0x19, 0x11, 0x19, 0x12, 0x19, 0x12, 0x19, 0x12, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x17, 0x10, 0x17, 0x10, 0x16, 0x10, 0x16, 0x10, 0x17, 0x10, 0x16, 0x10, 0x16, 0x10, 0x17, 0x10, 0x17, 0x10, 0x1A, 0x11, 0x1D, 0x13, 0x33, 0x1A, 0x4C, 0x20, 0x57, 0x21, 0x56, 0x20, 0x49, 0x1C, 0x37, 0x1A, 0x44, 0x1E, 0x54, 0x21, 0x5B, 0x22, 0x5E, 0x23, 0x5D, 0x22, 0x5E, 0x22, 0x5D, 0x22, 0x5D, 0x22, 0x5E, 0x23, 0x5D, 0x22, 0x60, 0x21, 0x60, 0x23, 0x61, 0x22, 0x5D, 0x21, 0x5E, 0x22, 0x5D, 0x22, 0x5C, 0x21, 0x5E, 0x22, 0x60, 0x22, 0x5E, 0x21, 0x5D, 0x21, 0x61, 0x23, 0x60, 0x21, 0x61, 0x22, 0x5F, 0x21, 0x5D, 0x21, 0x60, 0x22, 0x5F, 0x22, 0x5B, 0x20, 0x5D, 0x22, 0x63, 0x25, 0x5D, 0x21, 0x5C, 0x21, 0x5E, 0x22, 0x5F, 0x23, 0x5D, 0x23, 0x5F, 0x22, 0x5F, 0x22, 0x5E, 0x22, 0x5D, 0x21, 0x5E, 0x21, 0x5F, 0x22, 0x5D, 0x21, 0x5F, 0x22, 0x5D, 0x21, 0x5D, 0x21, 0x60, 0x22, 0x61, 0x22, 0x5D, 0x21, 0x61, 0x23, 0x60, 0x21, 0x60, 0x21, 0x5E, 0x21, 0x5D, 0x21, 0x5F, 0x22, 0x5C, 0x21, 0x5D, 0x21, 0x60, 0x23, 0x5E, 0x22, 0x5E, 0x22, 0x5D, 0x22, 0x5E, 0x22, 0x5D, 0x21, 0x59, 0x20, 0x5F, 0x22, 0x5E, 0x21, 0x60, 0x22, 0x60, 0x22, 0x61, 0x22, 0x61, 0x22, 0x5E, 0x21, 0x5A, 0x20, 0x5E, 0x21, 0x5F, 0x22, 0x5D, 0x21, 0x5E, 0x22, 0x5D, 0x21, 0x5E, 0x21, 0x5D, 0x21, 0x5D, 0x22, 0x5F, 0x22, 0x5C, 0x22, 0x5D, 0x22, 0x5F, 0x23, 0x60, 0x22, 0x5E, 0x21, 0x5E, 0x22, 0x5D, 0x22, 0x5D, 0x22, 0x5F, 0x22, 0x60, 0x23, 0x5C, 0x22, 0x60, 0x23, 0x60, 0x22, 0x5E, 0x22, 0x5F, 0x23, 0x5E, 0x22, 0x60, 0x22, 0x5F, 0x22, 0x60, 0x23, 0x62, 0x22, 0x5E, 0x22, 0x5F, 0x22, 0x5E, 0x22, 0x61, 0x22, 0x5F, 0x22, 0x5E, 0x21, 0x5D, 0x21, 0x60, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x61, 0x23, 0x61, 0x23, 0x61, 0x25, 0x60, 0x24, 0x61, 0x24, 0x61, 0x23, 0x5E, 0x22, 0x5D, 0x23, 0x61, 0x22, 0x60, 0x22, 0x60, 0x22, 0x5D, 0x22, 0x5C, 0x21, 0x5D, 0x21, 0x5D, 0x22, 0x5D, 0x22, 0x5A, 0x21, 0x5D, 0x22, 0x5C, 0x22, 0x5B, 0x22, 0x59, 0x21, 0x58, 0x21, 0x57, 0x20, 0x56, 0x20, 0x54, 0x1F, 0x54, 0x20, 0x54, 0x1E, 0x52, 0x1F, 0x53, 0x1F, 0x54, 0x1E, 0x52, 0x1E, 0x51, 0x1E, 0x52, 0x1E, 0x53, 0x1F, 0x53, 0x1F, 0x50, 0x1E, 0x52, 0x1E, 0x52, 0x1E, 0x40, 0x1B, 0x2C, 0x17, 0x25, 0x16, 0x28, 0x18, 0x21, 0x15, 0x25, 0x17, 0x23, 0x15, 0x25, 0x17, 0x27, 0x19, 0x28, 0x19, 0x2B, 0x1A, 0x2A, 0x1A, 0x28, 0x19, 0x2C, 0x1B, 0x2B, 0x1A, 0x29, 0x19, 0x2C, 0x1A, 0x2D, 0x19, 0x27, 0x19, 0x26, 0x19, 0x23, 0x19, 0x29, 0x1B, 0x29, 0x1C, 0x2B, 0x1D, 0x25, 0x1A, 0x27, 0x1A, 0x31, 0x1B, 0x2B, 0x19, 0x2A, 0x19, 0x28, 0x1B, 0x30, 0x22, 0x27, 0x1E, 0x25, 0x1E, 0x23, 0x1E, 0x2F, 0x25, 0x2C, 0x20, 0x23, 0x18, 0x27, 0x17, 0x24, 0x17, 0x26, 0x1C, 0x22, 0x1E, 0x21, 0x23, 0x26, 0x27, 0x25, 0x27
    },

    {
        0x58, 0x4E, 0x57, 0x4D, 0x58, 0x4E, 0x58, 0x4F, 0x59, 0x4E, 0x59, 0x4F, 0x59, 0x4E, 0x5A, 0x4E, 0x5B, 0x50, 0x5B, 0x4F, 0x5C, 0x50, 0x5C, 0x50, 0x5C, 0x4F, 0x5C, 0x50, 0x5C, 0x50, 0x5D, 0x50, 0x5C, 0x4F, 0x5C, 0x4F, 0x5B, 0x4F, 0x5B, 0x50, 0x58, 0x4E, 0x51, 0x47, 0x4A, 0x3F, 0x3F, 0x38, 0x3C, 0x39, 0x45, 0x41, 0x4A, 0x44, 0x44, 0x3D, 0x38, 0x32, 0x28, 0x25, 0x1D, 0x1D, 0x19, 0x1A, 0x16, 0x18, 0x14, 0x16, 0x12, 0x15, 0x11, 0x14, 0x10, 0x13, 0x10, 0x13, 0x11, 0x14, 0x10, 0x13, 0x10, 0x13, 0x11, 0x14, 0x11, 0x14, 0x11, 0x14, 0x11, 0x14, 0x11, 0x14, 0x11, 0x14, 0x11, 0x14, 0x11, 0x14, 0x12, 0x15, 0x12, 0x15, 0x11, 0x15, 0x12, 0x16, 0x13, 0x18, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x17, 0x14, 0x17, 0x14, 0x18, 0x15, 0x18, 0x17, 0x19, 0x1A, 0x1C, 0x21, 0x20, 0x2A, 0x25, 0x2D, 0x27, 0x2D, 0x27, 0x2A, 0x24, 0x21, 0x1E, 0x1B, 0x1B, 0x18, 0x18, 0x16, 0x18, 0x19, 0x1C, 0x20, 0x28, 0x31, 0x40, 0x4C, 0x62, 0x63, 0x78, 0x6A, 0x80, 0x6D, 0x81, 0x6A, 0x7E, 0x55, 0x60, 0x37, 0x39, 0x26, 0x28, 0x1E, 0x21, 0x19, 0x1C, 0x16, 0x19, 0x14, 0x17, 0x13, 0x16, 0x13, 0x16, 0x12, 0x17, 0x13, 0x17, 0x13, 0x18, 0x13, 0x18, 0x14, 0x17, 0x13, 0x17, 0x13, 0x17, 0x14, 0x18, 0x14, 0x17, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x14, 0x17, 0x13, 0x16, 0x13, 0x17, 0x13, 0x16, 0x13, 0x17, 0x12, 0x16, 0x12, 0x16, 0x12, 0x15, 0x12, 0x15, 0x12, 0x15, 0x12, 0x16, 0x12, 0x15, 0x12, 0x15, 0x12, 0x16, 0x13, 0x15, 0x15, 0x17, 0x18, 0x1A, 0x29, 0x2E, 0x45, 0x46, 0x56, 0x52, 0x57, 0x52, 0x4F, 0x48, 0x3B, 0x35, 0x40, 0x3E, 0x54, 0x4F, 0x5E, 0x55, 0x62, 0x59, 0x63, 0x58, 0x64, 0x57, 0x65, 0x59, 0x65, 0x59, 0x65, 0x5A, 0x65, 0x59, 0x68, 0x59, 0x67, 0x5B, 0x68, 0x5B, 0x65, 0x58, 0x65, 0x59, 0x66, 0x5A, 0x64, 0x5A, 0x65, 0x59, 0x67, 0x5A, 0x66, 0x58, 0x65, 0x59, 0x69, 0x5B, 0x67, 0x5A, 0x6A, 0x5C, 0x67, 0x5A, 0x66, 0x5A, 0x68, 0x5B, 0x69, 0x5B, 0x65, 0x58, 0x65, 0x5A, 0x68, 0x5D, 0x66, 0x57, 0x63, 0x57, 0x64, 0x5A, 0x66, 0x5B, 0x65, 0x5A, 0x66, 0x5B, 0x67, 0x5A, 0x69, 0x5B, 0x65, 0x5A, 0x67, 0x59, 0x68, 0x5B, 0x66, 0x58, 0x66, 0x5A, 0x66, 0x5A, 0x66, 0x5A, 0x68, 0x5A, 0x6A, 0x5D, 0x67, 0x59, 0x68, 0x5B, 0x69, 0x5A, 0x69, 0x5B, 0x67, 0x59, 0x65, 0x59, 0x67, 0x5A, 0x65, 0x59, 0x66, 0x59, 0x6A, 0x5D, 0x66, 0x5A, 0x67, 0x59, 0x66, 0x58, 0x66, 0x59, 0x64, 0x58, 0x62, 0x56, 0x68, 0x5A, 0x67, 0x5A, 0x6A, 0x5C, 0x67, 0x5B, 0x6A, 0x5D, 0x6A, 0x5C, 0x67, 0x59, 0x63, 0x56, 0x67, 0x5A, 0x68, 0x5A, 0x65, 0x59, 0x66, 0x5B, 0x65, 0x5A, 0x68, 0x5B, 0x65, 0x57, 0x66, 0x59, 0x67, 0x5A, 0x66, 0x58, 0x65, 0x5A, 0x68, 0x5B, 0x68, 0x5C, 0x67, 0x5B, 0x66, 0x59, 0x66, 0x5A, 0x65, 0x5A, 0x67, 0x5B, 0x68, 0x5C, 0x66, 0x5A, 0x68, 0x5C, 0x68, 0x5B, 0x67, 0x5B, 0x67, 0x5B, 0x66, 0x5C, 0x69, 0x5C, 0x69, 0x5C, 0x69, 0x5B, 0x69, 0x5D, 0x6A, 0x5A, 0x69, 0x5A, 0x67, 0x5A, 0x6A, 0x5C, 0x68, 0x5A, 0x68, 0x5A, 0x67, 0x59, 0x6A, 0x5C, 0x68, 0x5B, 0x6A, 0x5D, 0x6A, 0x5D, 0x6A, 0x5E, 0x69, 0x5E, 0x68, 0x5D, 0x68, 0x5D, 0x68, 0x5C, 0x66, 0x5A, 0x66, 0x5C, 0x69, 0x5D, 0x67, 0x5B, 0x69, 0x5B, 0x67, 0x5A, 0x65, 0x58, 0x66, 0x5A, 0x65, 0x58, 0x66, 0x59, 0x64, 0x57, 0x66, 0x59, 0x63, 0x59, 0x62, 0x58, 0x60, 0x56, 0x5F, 0x55, 0x60, 0x55, 0x5D, 0x52, 0x5B, 0x51, 0x5D, 0x51, 0x5C, 0x50, 0x59, 0x4F, 0x5B, 0x4F, 0x5A, 0x50, 0x59, 0x4F, 0x59, 0x4E, 0x5A, 0x4E, 0x5A, 0x50, 0x59, 0x4F, 0x58, 0x4E, 0x59, 0x4D, 0x58, 0x4E, 0x40, 0x38, 0x2A, 0x27, 0x22, 0x22, 0x24, 0x27, 0x1F, 0x21, 0x22, 0x24, 0x1E, 0x20, 0x21, 0x25, 0x23, 0x28, 0x23, 0x27, 0x25, 0x2A, 0x24, 0x29, 0x24, 0x27, 0x27, 0x2D, 0x25, 0x29, 0x24, 0x28, 0x25, 0x2B, 0x26, 0x27, 0x21, 0x25, 0x20, 0x22, 0x1D, 0x22, 0x24, 0x2A, 0x23, 0x29, 0x24, 0x28, 0x20, 0x25, 0x21, 0x29, 0x28, 0x2D, 0x23, 0x26, 0x25, 0x28, 0x1F, 0x24, 0x26, 0x2E, 0x1E, 0x23, 0x1E, 0x25, 0x1C, 0x21, 0x24, 0x2E, 0x21, 0x25, 0x1E, 0x23, 0x1F, 0x21, 0x1E, 0x22, 0x1E, 0x22, 0x1A, 0x20, 0x19, 0x21, 0x1B, 0x24, 0x1A, 0x24
    },

    {
        0x52, 0x1E, 0x51, 0x1D, 0x51, 0x1D, 0x52, 0x1D, 0x53, 0x1E, 0x53, 0x1D, 0x52, 0x1E, 0x51, 0x1D, 0x52, 0x1D, 0x52, 0x1E, 0x53, 0x1E, 0x53, 0x1D, 0x51, 0x1D, 0x52, 0x1D, 0x52, 0x1D, 0x52, 0x1D, 0x52, 0x1D, 0x52, 0x1E, 0x51, 0x1D, 0x50, 0x1D, 0x4C, 0x1D, 0x45, 0x1B, 0x3E, 0x1A, 0x39, 0x19, 0x40, 0x1A, 0x47, 0x1C, 0x45, 0x1A, 0x3A, 0x18, 0x2B, 0x15, 0x20, 0x12, 0x1C, 0x11, 0x19, 0x10, 0x17, 0x0F, 0x16, 0x0F, 0x15, 0x0F, 0x14, 0x0F, 0x14, 0x0F, 0x14, 0x0F, 0x14, 0x0E, 0x14, 0x0F, 0x14, 0x0E, 0x14, 0x0F, 0x15, 0x0F, 0x14, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x10, 0x15, 0x0F, 0x15, 0x10, 0x16, 0x10, 0x16, 0x10, 0x15, 0x0F, 0x16, 0x10, 0x17, 0x10, 0x17, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x11, 0x18, 0x11, 0x18, 0x11, 0x19, 0x12, 0x18, 0x12, 0x19, 0x12, 0x1A, 0x14, 0x1F, 0x18, 0x24, 0x1B, 0x27, 0x1D, 0x28, 0x1E, 0x29, 0x1E, 0x28, 0x1D, 0x24, 0x1A, 0x1E, 0x16, 0x1A, 0x13, 0x1B, 0x14, 0x22, 0x19, 0x35, 0x25, 0x55, 0x34, 0x73, 0x40, 0x81, 0x46, 0x89, 0x4A, 0x8C, 0x4A, 0x8A, 0x49, 0x85, 0x47, 0x67, 0x35, 0x3C, 0x22, 0x28, 0x1A, 0x21, 0x15, 0x1D, 0x13, 0x1A, 0x12, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x12, 0x18, 0x11, 0x18, 0x12, 0x19, 0x11, 0x18, 0x12, 0x18, 0x12, 0x18, 0x11, 0x19, 0x12, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x10, 0x17, 0x11, 0x17, 0x10, 0x17, 0x10, 0x17, 0x11, 0x17, 0x10, 0x16, 0x0F, 0x15, 0x0F, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x0F, 0x16, 0x0F, 0x18, 0x10, 0x1C, 0x13, 0x31, 0x19, 0x4B, 0x1F, 0x56, 0x20, 0x55, 0x20, 0x4C, 0x1D, 0x37, 0x1A, 0x3F, 0x1D, 0x54, 0x20, 0x5A, 0x21, 0x5C, 0x22, 0x5B, 0x21, 0x5B, 0x22, 0x5F, 0x23, 0x5E, 0x23, 0x5F, 0x22, 0x5D, 0x22, 0x60, 0x22, 0x60, 0x22, 0x5E, 0x22, 0x5D, 0x22, 0x5E, 0x23, 0x60, 0x23, 0x60, 0x23, 0x5E, 0x22, 0x5E, 0x22, 0x5D, 0x21, 0x5E, 0x21, 0x5F, 0x21, 0x5F, 0x22, 0x60, 0x23, 0x5E, 0x21, 0x5E, 0x22, 0x61, 0x23, 0x5E, 0x21, 0x5D, 0x21, 0x5D, 0x21, 0x5D, 0x21, 0x5C, 0x21, 0x5E, 0x21, 0x5F, 0x22, 0x5E, 0x22, 0x60, 0x23, 0x5F, 0x22, 0x60, 0x22, 0x5E, 0x22, 0x5E, 0x21, 0x5F, 0x22, 0x5E, 0x21, 0x5E, 0x21, 0x5E, 0x22, 0x5E, 0x21, 0x5F, 0x21, 0x5F, 0x22, 0x5E, 0x21, 0x5F, 0x22, 0x5F, 0x22, 0x5E, 0x21, 0x61, 0x22, 0x5F, 0x21, 0x5F, 0x21, 0x5E, 0x21, 0x5F, 0x21, 0x61, 0x22, 0x63, 0x22, 0x5F, 0x23, 0x60, 0x22, 0x5D, 0x21, 0x5D, 0x21, 0x5B, 0x20, 0x5C, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x60, 0x23, 0x61, 0x23, 0x5F, 0x22, 0x5D, 0x21, 0x5C, 0x21, 0x5E, 0x21, 0x60, 0x22, 0x5D, 0x22, 0x5D, 0x21, 0x5C, 0x21, 0x5E, 0x21, 0x5B, 0x20, 0x5C, 0x21, 0x60, 0x22, 0x5E, 0x22, 0x5D, 0x21, 0x5F, 0x22, 0x61, 0x23, 0x5E, 0x22, 0x5F, 0x22, 0x5F, 0x23, 0x5D, 0x22, 0x5E, 0x21, 0x5E, 0x23, 0x5E, 0x22, 0x60, 0x23, 0x60, 0x22, 0x5C, 0x21, 0x5E, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x5E, 0x22, 0x5E, 0x21, 0x5E, 0x22, 0x5F, 0x22, 0x60, 0x22, 0x5E, 0x21, 0x61, 0x23, 0x5E, 0x21, 0x5F, 0x22, 0x5F, 0x22, 0x5D, 0x22, 0x5F, 0x23, 0x62, 0x23, 0x61, 0x22, 0x62, 0x23, 0x60, 0x23, 0x62, 0x24, 0x61, 0x25, 0x5F, 0x23, 0x62, 0x24, 0x61, 0x24, 0x61, 0x23, 0x5F, 0x22, 0x5D, 0x22, 0x5D, 0x21, 0x5E, 0x22, 0x5C, 0x21, 0x5C, 0x21, 0x5D, 0x22, 0x59, 0x20, 0x5B, 0x21, 0x5A, 0x20, 0x58, 0x21, 0x59, 0x21, 0x5A, 0x21, 0x58, 0x20, 0x55, 0x20, 0x54, 0x20, 0x54, 0x20, 0x53, 0x1F, 0x52, 0x1E, 0x53, 0x1E, 0x53, 0x1E, 0x4F, 0x1D, 0x52, 0x1E, 0x53, 0x1F, 0x53, 0x1F, 0x51, 0x1E, 0x52, 0x1E, 0x50, 0x1E, 0x4D, 0x1D, 0x3C, 0x19, 0x26, 0x15, 0x25, 0x16, 0x24, 0x16, 0x27, 0x18, 0x2D, 0x19, 0x2A, 0x1A, 0x2D, 0x1F, 0x2F, 0x24, 0x31, 0x26, 0x2F, 0x28, 0x2C, 0x25, 0x2F, 0x27, 0x2C, 0x24, 0x2A, 0x1C, 0x29, 0x19, 0x24, 0x16, 0x29, 0x1B, 0x27, 0x25, 0x25, 0x29, 0x27, 0x2D, 0x2C, 0x30, 0x2B, 0x31, 0x2A, 0x30, 0x2A, 0x2B, 0x27, 0x1C, 0x28, 0x17, 0x21, 0x16, 0x26, 0x22, 0x27, 0x30, 0x29, 0x36, 0x28, 0x35, 0x29, 0x36, 0x28, 0x36, 0x2A, 0x39, 0x25, 0x29, 0x22, 0x1A, 0x20, 0x16, 0x26, 0x19, 0x25, 0x2A, 0x28, 0x36, 0x2A, 0x39, 0x2A, 0x3B, 0x2A, 0x3B
    },

    {
        0x58, 0x4F, 0x58, 0x4E, 0x58, 0x4E, 0x59, 0x4F, 0x59, 0x51, 0x5B, 0x50, 0x5B, 0x4F, 0x59, 0x4F, 0x5B, 0x4F, 0x5B, 0x4F, 0x5B, 0x50, 0x5B, 0x4F, 0x5C, 0x4F, 0x5B, 0x4F, 0x5B, 0x4F, 0x5B, 0x4F, 0x5B, 0x50, 0x5B, 0x4F, 0x58, 0x4D, 0x56, 0x4B, 0x50, 0x46, 0x48, 0x40, 0x40, 0x39, 0x3B, 0x39, 0x44, 0x41, 0x4B, 0x45, 0x47, 0x3F, 0x3A, 0x33, 0x28, 0x25, 0x1D, 0x1D, 0x18, 0x1A, 0x16, 0x18, 0x14, 0x15, 0x11, 0x15, 0x11, 0x14, 0x11, 0x14, 0x10, 0x13, 0x10, 0x13, 0x10, 0x13, 0x10, 0x13, 0x10, 0x13, 0x10, 0x14, 0x11, 0x14, 0x11, 0x14, 0x10, 0x14, 0x10, 0x14, 0x11, 0x14, 0x11, 0x14, 0x11, 0x14, 0x11, 0x15, 0x11, 0x15, 0x11, 0x14, 0x12, 0x15, 0x12, 0x16, 0x12, 0x15, 0x11, 0x15, 0x11, 0x15, 0x12, 0x16, 0x13, 0x17, 0x13, 0x17, 0x14, 0x18, 0x15, 0x18, 0x17, 0x19, 0x1A, 0x1B, 0x20, 0x20, 0x28, 0x24, 0x2C, 0x25, 0x2E, 0x26, 0x2E, 0x27, 0x2D, 0x27, 0x29, 0x24, 0x21, 0x1E, 0x1B, 0x1A, 0x1A, 0x1C, 0x21, 0x27, 0x30, 0x3E, 0x48, 0x5E, 0x5F, 0x74, 0x69, 0x7F, 0x6F, 0x84, 0x71, 0x88, 0x6F, 0x85, 0x6D, 0x81, 0x5B, 0x66, 0x39, 0x3D, 0x27, 0x29, 0x1D, 0x21, 0x19, 0x1C, 0x15, 0x19, 0x13, 0x16, 0x14, 0x17, 0x12, 0x17, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x13, 0x18, 0x13, 0x17, 0x14, 0x18, 0x14, 0x18, 0x13, 0x17, 0x13, 0x17, 0x13, 0x16, 0x12, 0x17, 0x13, 0x16, 0x13, 0x16, 0x12, 0x15, 0x12, 0x15, 0x12, 0x15, 0x12, 0x15, 0x11, 0x15, 0x12, 0x15, 0x12, 0x16, 0x12, 0x15, 0x12, 0x15, 0x12, 0x15, 0x12, 0x15, 0x14, 0x17, 0x18, 0x1A, 0x27, 0x2C, 0x45, 0x47, 0x56, 0x52, 0x58, 0x52, 0x51, 0x49, 0x3B, 0x35, 0x3D, 0x39, 0x53, 0x4E, 0x5E, 0x55, 0x60, 0x58, 0x61, 0x57, 0x63, 0x58, 0x65, 0x5A, 0x67, 0x5C, 0x67, 0x59, 0x66, 0x5A, 0x68, 0x5C, 0x67, 0x5B, 0x67, 0x5A, 0x66, 0x59, 0x66, 0x5A, 0x67, 0x5B, 0x67, 0x5B, 0x67, 0x5A, 0x67, 0x5A, 0x67, 0x5A, 0x68, 0x5A, 0x69, 0x5A, 0x67, 0x5B, 0x66, 0x5B, 0x66, 0x5B, 0x67, 0x5C, 0x68, 0x5C, 0x66, 0x58, 0x65, 0x58, 0x66, 0x58, 0x66, 0x59, 0x64, 0x57, 0x65, 0x59, 0x65, 0x5A, 0x67, 0x5A, 0x67, 0x5B, 0x67, 0x5B, 0x68, 0x5B, 0x67, 0x5B, 0x65, 0x59, 0x66, 0x5A, 0x66, 0x59, 0x66, 0x5A, 0x66, 0x5A, 0x68, 0x5A, 0x67, 0x59, 0x68, 0x59, 0x68, 0x5A, 0x68, 0x5B, 0x68, 0x5C, 0x67, 0x5B, 0x69, 0x5C, 0x68, 0x5B, 0x68, 0x5B, 0x68, 0x5A, 0x6A, 0x5B, 0x6B, 0x5D, 0x6A, 0x5D, 0x6A, 0x5D, 0x69, 0x5B, 0x66, 0x59, 0x67, 0x59, 0x63, 0x57, 0x65, 0x59, 0x67, 0x59, 0x68, 0x5A, 0x69, 0x5C, 0x69, 0x5C, 0x67, 0x5A, 0x65, 0x58, 0x66, 0x58, 0x68, 0x5A, 0x68, 0x5A, 0x65, 0x5A, 0x66, 0x59, 0x64, 0x58, 0x67, 0x59, 0x64, 0x55, 0x66, 0x5A, 0x69, 0x5B, 0x66, 0x59, 0x64, 0x59, 0x66, 0x59, 0x68, 0x5B, 0x65, 0x5B, 0x67, 0x5B, 0x68, 0x5C, 0x65, 0x59, 0x65, 0x58, 0x66, 0x5A, 0x66, 0x5B, 0x69, 0x5C, 0x68, 0x5A, 0x64, 0x58, 0x66, 0x5B, 0x67, 0x5B, 0x68, 0x5B, 0x69, 0x5B, 0x68, 0x5A, 0x67, 0x5A, 0x69, 0x5C, 0x69, 0x5C, 0x68, 0x5C, 0x69, 0x5D, 0x67, 0x59, 0x69, 0x5C, 0x68, 0x5B, 0x66, 0x5A, 0x68, 0x5D, 0x6C, 0x5E, 0x6A, 0x5D, 0x6A, 0x5E, 0x68, 0x5C, 0x6C, 0x5F, 0x69, 0x5D, 0x66, 0x5B, 0x6A, 0x5D, 0x6B, 0x5E, 0x68, 0x5C, 0x65, 0x5B, 0x64, 0x58, 0x67, 0x5A, 0x67, 0x5A, 0x66, 0x58, 0x65, 0x5A, 0x65, 0x58, 0x61, 0x55, 0x64, 0x57, 0x61, 0x55, 0x5F, 0x55, 0x61, 0x56, 0x61, 0x56, 0x60, 0x55, 0x5E, 0x52, 0x5C, 0x50, 0x5D, 0x52, 0x5B, 0x51, 0x5A, 0x4E, 0x5B, 0x4F, 0x59, 0x4D, 0x57, 0x4D, 0x59, 0x50, 0x5C, 0x51, 0x5C, 0x51, 0x59, 0x4F, 0x58, 0x4C, 0x56, 0x4C, 0x53, 0x49, 0x3C, 0x33, 0x27, 0x23, 0x23, 0x23, 0x22, 0x23, 0x24, 0x2A, 0x28, 0x2A, 0x26, 0x2C, 0x25, 0x2D, 0x25, 0x2D, 0x25, 0x2F, 0x24, 0x2D, 0x21, 0x29, 0x22, 0x2C, 0x21, 0x28, 0x22, 0x24, 0x23, 0x26, 0x1F, 0x21, 0x23, 0x29, 0x1E, 0x26, 0x1C, 0x25, 0x1C, 0x27, 0x1D, 0x28, 0x1D, 0x28, 0x1D, 0x27, 0x1C, 0x25, 0x20, 0x26, 0x20, 0x21, 0x1D, 0x20, 0x1E, 0x24, 0x1B, 0x25, 0x1B, 0x27, 0x1A, 0x26, 0x1A, 0x27, 0x1A, 0x27, 0x1B, 0x28, 0x19, 0x22, 0x1B, 0x21, 0x1E, 0x21, 0x23, 0x26, 0x1B, 0x25, 0x1A, 0x26, 0x1A, 0x27, 0x1A, 0x28, 0x1A, 0x28
    },

    {
        0x50, 0x1D, 0x51, 0x1D, 0x51, 0x1D, 0x52, 0x1E, 0x53, 0x1E, 0x53, 0x1E, 0x54, 0x1E, 0x54, 0x1E, 0x52, 0x1D, 0x53, 0x1E, 0x51, 0x1E, 0x52, 0x1D, 0x53, 0x1D, 0x52, 0x1D, 0x53, 0x1D, 0x53, 0x1D, 0x52, 0x1E, 0x53, 0x1E, 0x50, 0x1D, 0x4C, 0x1C, 0x45, 0x1B, 0x3D, 0x19, 0x38, 0x18, 0x3E, 0x1A, 0x46, 0x1B, 0x46, 0x1B, 0x3D, 0x19, 0x2E, 0x15, 0x22, 0x12, 0x1C, 0x11, 0x1A, 0x10, 0x17, 0x0F, 0x16, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x14, 0x0E, 0x13, 0x0E, 0x13, 0x0E, 0x14, 0x0F, 0x14, 0x0F, 0x14, 0x0F, 0x15, 0x10, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x14, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x16, 0x10, 0x15, 0x0F, 0x15, 0x0F, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x17, 0x10, 0x16, 0x10, 0x18, 0x11, 0x18, 0x11, 0x19, 0x12, 0x1A, 0x13, 0x1B, 0x14, 0x1E, 0x17, 0x23, 0x1B, 0x25, 0x1B, 0x28, 0x1D, 0x28, 0x1D, 0x29, 0x1E, 0x29, 0x1E, 0x28, 0x1D, 0x25, 0x1A, 0x1F, 0x17, 0x22, 0x19, 0x33, 0x23, 0x53, 0x32, 0x72, 0x3F, 0x7F, 0x44, 0x87, 0x47, 0x8C, 0x4B, 0x90, 0x4C, 0x8F, 0x4C, 0x8D, 0x4B, 0x87, 0x47, 0x6B, 0x37, 0x3E, 0x22, 0x28, 0x18, 0x20, 0x15, 0x1C, 0x13, 0x19, 0x11, 0x18, 0x12, 0x18, 0x11, 0x19, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x17, 0x11, 0x18, 0x11, 0x18, 0x12, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x16, 0x10, 0x17, 0x10, 0x17, 0x10, 0x16, 0x10, 0x17, 0x10, 0x16, 0x10, 0x17, 0x10, 0x17, 0x10, 0x16, 0x0F, 0x16, 0x0F, 0x16, 0x10, 0x16, 0x0F, 0x15, 0x0F, 0x17, 0x10, 0x18, 0x10, 0x1C, 0x12, 0x2D, 0x18, 0x4B, 0x1E, 0x56, 0x21, 0x59, 0x21, 0x4C, 0x1D, 0x37, 0x1A, 0x3E, 0x1D, 0x54, 0x22, 0x58, 0x21, 0x59, 0x21, 0x5E, 0x22, 0x5E, 0x22, 0x60, 0x23, 0x60, 0x22, 0x60, 0x22, 0x62, 0x23, 0x5F, 0x23, 0x5F, 0x22, 0x5F, 0x22, 0x5F, 0x23, 0x5F, 0x23, 0x62, 0x24, 0x60, 0x22, 0x60, 0x22, 0x60, 0x22, 0x5E, 0x21, 0x5E, 0x21, 0x60, 0x22, 0x5E, 0x22, 0x60, 0x23, 0x60, 0x24, 0x61, 0x23, 0x61, 0x23, 0x5E, 0x21, 0x5D, 0x21, 0x5D, 0x20, 0x5D, 0x21, 0x5B, 0x20, 0x5B, 0x21, 0x5E, 0x23, 0x61, 0x23, 0x62, 0x23, 0x61, 0x23, 0x5F, 0x21, 0x5E, 0x21, 0x5F, 0x22, 0x5F, 0x21, 0x5F, 0x22, 0x60, 0x22, 0x5F, 0x21, 0x5E, 0x21, 0x5F, 0x21, 0x5F, 0x21, 0x5F, 0x21, 0x62, 0x23, 0x5F, 0x22, 0x5E, 0x21, 0x5F, 0x21, 0x5F, 0x21, 0x5F, 0x21, 0x5E, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x60, 0x23, 0x62, 0x22, 0x5E, 0x21, 0x5E, 0x21, 0x5C, 0x20, 0x5E, 0x21, 0x5D, 0x22, 0x5C, 0x21, 0x5F, 0x23, 0x60, 0x23, 0x61, 0x22, 0x5D, 0x21, 0x5D, 0x22, 0x60, 0x22, 0x62, 0x23, 0x60, 0x22, 0x5C, 0x22, 0x5C, 0x21, 0x5C, 0x21, 0x5C, 0x20, 0x5E, 0x21, 0x5F, 0x22, 0x5E, 0x21, 0x5C, 0x20, 0x5C, 0x21, 0x5F, 0x23, 0x5F, 0x22, 0x5D, 0x21, 0x5F, 0x22, 0x5E, 0x21, 0x5D, 0x21, 0x5E, 0x21, 0x5F, 0x22, 0x60, 0x22, 0x61, 0x22, 0x5E, 0x22, 0x61, 0x23, 0x5F, 0x22, 0x5D, 0x22, 0x5E, 0x22, 0x5D, 0x22, 0x5D, 0x22, 0x61, 0x22, 0x60, 0x22, 0x5F, 0x22, 0x5E, 0x22, 0x5F, 0x22, 0x60, 0x23, 0x5E, 0x22, 0x5E, 0x23, 0x62, 0x23, 0x63, 0x24, 0x63, 0x24, 0x61, 0x24, 0x62, 0x23, 0x5F, 0x22, 0x60, 0x24, 0x5F, 0x24, 0x60, 0x23, 0x60, 0x24, 0x5F, 0x23, 0x5E, 0x22, 0x5B, 0x21, 0x5D, 0x22, 0x5D, 0x21, 0x5C, 0x21, 0x5A, 0x21, 0x5D, 0x22, 0x5B, 0x21, 0x5B, 0x21, 0x5C, 0x21, 0x5A, 0x22, 0x5B, 0x21, 0x5B, 0x22, 0x5A, 0x21, 0x57, 0x20, 0x52, 0x1F, 0x56, 0x20, 0x55, 0x1F, 0x51, 0x1E, 0x51, 0x1E, 0x52, 0x1F, 0x50, 0x1E, 0x53, 0x1F, 0x53, 0x1F, 0x54, 0x20, 0x52, 0x1E, 0x50, 0x1E, 0x51, 0x1E, 0x4F, 0x1D, 0x3B, 0x19, 0x2A, 0x17, 0x26, 0x18, 0x2F, 0x1B, 0x30, 0x1B, 0x2C, 0x1A, 0x2C, 0x21, 0x2A, 0x34, 0x2D, 0x3B, 0x2C, 0x3C, 0x2D, 0x3D, 0x2C, 0x3C, 0x2C, 0x3C, 0x29, 0x30, 0x21, 0x1A, 0x21, 0x16, 0x23, 0x17, 0x27, 0x20, 0x28, 0x35, 0x2B, 0x3B, 0x2C, 0x3D, 0x2B, 0x3C, 0x2B, 0x3A, 0x2A, 0x39, 0x26, 0x2D, 0x21, 0x1A, 0x23, 0x17, 0x28, 0x19, 0x27, 0x29, 0x29, 0x36, 0x29, 0x39, 0x29, 0x39, 0x29, 0x39, 0x28, 0x38, 0x28, 0x37, 0x23, 0x26, 0x21, 0x1A, 0x29, 0x17, 0x25, 0x18, 0x26, 0x2B, 0x27, 0x32, 0x27, 0x34, 0x28, 0x34, 0x26, 0x33
    },

    {
        0x58, 0x4E, 0x57, 0x4E, 0x58, 0x4F, 0x59, 0x4F, 0x5B, 0x50, 0x5B, 0x50, 0x5B, 0x50, 0x5C, 0x50, 0x5B, 0x50, 0x5C, 0x50, 0x5B, 0x50, 0x5B, 0x50, 0x5B, 0x4F, 0x5C, 0x50, 0x5C, 0x51, 0x5B, 0x50, 0x5B, 0x50, 0x59, 0x4F, 0x55, 0x4D, 0x51, 0x47, 0x48, 0x3F, 0x3F, 0x38, 0x3A, 0x38, 0x43, 0x40, 0x4C, 0x45, 0x49, 0x40, 0x3C, 0x35, 0x2C, 0x27, 0x1E, 0x1E, 0x1A, 0x1B, 0x16, 0x18, 0x14, 0x16, 0x12, 0x15, 0x11, 0x14, 0x11, 0x14, 0x10, 0x13, 0x10, 0x13, 0x10, 0x13, 0x10, 0x13, 0x10, 0x13, 0x11, 0x14, 0x11, 0x14, 0x10, 0x14, 0x11, 0x14, 0x11, 0x14, 0x10, 0x14, 0x11, 0x13, 0x10, 0x13, 0x11, 0x14, 0x11, 0x14, 0x11, 0x14, 0x11, 0x14, 0x11, 0x15, 0x11, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x17, 0x13, 0x17, 0x14, 0x18, 0x17, 0x19, 0x1A, 0x1B, 0x1F, 0x1F, 0x27, 0x24, 0x2B, 0x25, 0x2E, 0x26, 0x2E, 0x27, 0x30, 0x28, 0x30, 0x27, 0x2E, 0x27, 0x2A, 0x24, 0x23, 0x1F, 0x21, 0x24, 0x2C, 0x39, 0x45, 0x5B, 0x5C, 0x72, 0x66, 0x7B, 0x6D, 0x82, 0x72, 0x87, 0x74, 0x89, 0x74, 0x89, 0x73, 0x87, 0x6E, 0x83, 0x5E, 0x6B, 0x39, 0x3D, 0x24, 0x27, 0x1C, 0x1F, 0x17, 0x1A, 0x15, 0x18, 0x14, 0x17, 0x13, 0x18, 0x13, 0x17, 0x13, 0x18, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x14, 0x17, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x13, 0x16, 0x12, 0x16, 0x12, 0x16, 0x13, 0x16, 0x12, 0x15, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x15, 0x12, 0x15, 0x12, 0x15, 0x12, 0x16, 0x12, 0x16, 0x11, 0x15, 0x12, 0x15, 0x11, 0x15, 0x11, 0x14, 0x12, 0x15, 0x13, 0x16, 0x17, 0x19, 0x24, 0x27, 0x42, 0x45, 0x55, 0x52, 0x5B, 0x54, 0x53, 0x4A, 0x3B, 0x35, 0x3B, 0x3A, 0x53, 0x4F, 0x5C, 0x54, 0x5F, 0x57, 0x63, 0x5A, 0x66, 0x5A, 0x67, 0x5B, 0x67, 0x5A, 0x69, 0x5D, 0x6A, 0x5E, 0x67, 0x5C, 0x6A, 0x5C, 0x66, 0x5A, 0x67, 0x5B, 0x66, 0x5C, 0x6A, 0x5C, 0x6A, 0x5B, 0x68, 0x5A, 0x68, 0x5B, 0x66, 0x59, 0x67, 0x59, 0x68, 0x5B, 0x65, 0x59, 0x66, 0x5C, 0x68, 0x5D, 0x67, 0x5D, 0x68, 0x5C, 0x65, 0x58, 0x65, 0x59, 0x65, 0x58, 0x65, 0x57, 0x65, 0x59, 0x63, 0x57, 0x65, 0x59, 0x68, 0x5C, 0x69, 0x5E, 0x69, 0x5B, 0x67, 0x5A, 0x66, 0x59, 0x68, 0x5B, 0x68, 0x5B, 0x67, 0x5A, 0x69, 0x5C, 0x67, 0x5B, 0x69, 0x5C, 0x68, 0x5A, 0x68, 0x5A, 0x68, 0x5C, 0x6B, 0x5E, 0x67, 0x5B, 0x68, 0x59, 0x67, 0x5A, 0x67, 0x5B, 0x68, 0x5B, 0x69, 0x5C, 0x6A, 0x5C, 0x69, 0x5B, 0x69, 0x5D, 0x6A, 0x5C, 0x69, 0x5B, 0x67, 0x59, 0x65, 0x57, 0x66, 0x59, 0x66, 0x59, 0x65, 0x58, 0x66, 0x5B, 0x67, 0x5A, 0x68, 0x5B, 0x65, 0x58, 0x68, 0x5A, 0x68, 0x5B, 0x69, 0x5D, 0x67, 0x5B, 0x65, 0x59, 0x63, 0x57, 0x65, 0x58, 0x69, 0x59, 0x68, 0x5B, 0x69, 0x5B, 0x68, 0x59, 0x65, 0x58, 0x65, 0x59, 0x67, 0x5B, 0x67, 0x59, 0x66, 0x59, 0x68, 0x5B, 0x66, 0x58, 0x65, 0x59, 0x68, 0x5A, 0x66, 0x5A, 0x66, 0x5B, 0x69, 0x5C, 0x66, 0x5B, 0x68, 0x5B, 0x67, 0x5A, 0x66, 0x58, 0x66, 0x59, 0x65, 0x59, 0x66, 0x5B, 0x69, 0x5C, 0x68, 0x5A, 0x67, 0x5A, 0x67, 0x5A, 0x6A, 0x5B, 0x69, 0x5D, 0x67, 0x5A, 0x68, 0x5D, 0x6A, 0x5E, 0x6C, 0x5E, 0x6D, 0x60, 0x68, 0x5D, 0x6C, 0x5D, 0x67, 0x5B, 0x66, 0x5A, 0x67, 0x5C, 0x67, 0x5C, 0x68, 0x5C, 0x66, 0x5C, 0x64, 0x59, 0x63, 0x58, 0x65, 0x5A, 0x67, 0x58, 0x65, 0x56, 0x64, 0x57, 0x64, 0x59, 0x64, 0x59, 0x64, 0x58, 0x64, 0x59, 0x63, 0x59, 0x64, 0x58, 0x62, 0x57, 0x60, 0x55, 0x5D, 0x52, 0x5D, 0x50, 0x5F, 0x52, 0x5C, 0x51, 0x59, 0x4E, 0x5A, 0x4E, 0x5A, 0x50, 0x57, 0x4D, 0x5B, 0x50, 0x5B, 0x4E, 0x5B, 0x51, 0x59, 0x4E, 0x5A, 0x4E, 0x5A, 0x4F, 0x57, 0x4D, 0x3E, 0x34, 0x28, 0x26, 0x25, 0x28, 0x2A, 0x2D, 0x29, 0x2C, 0x25, 0x29, 0x23, 0x28, 0x1E, 0x2A, 0x1D, 0x2B, 0x1D, 0x2A, 0x1D, 0x2B, 0x1C, 0x2A, 0x1C, 0x29, 0x1C, 0x26, 0x1B, 0x1F, 0x1C, 0x1F, 0x20, 0x25, 0x1F, 0x22, 0x1C, 0x28, 0x1C, 0x29, 0x1C, 0x2A, 0x1B, 0x29, 0x1A, 0x28, 0x1A, 0x28, 0x19, 0x22, 0x19, 0x1E, 0x20, 0x24, 0x23, 0x27, 0x1C, 0x24, 0x1B, 0x26, 0x1B, 0x26, 0x1A, 0x26, 0x19, 0x25, 0x19, 0x25, 0x19, 0x24, 0x17, 0x1D, 0x1C, 0x23, 0x22, 0x24, 0x1E, 0x22, 0x1C, 0x24, 0x1A, 0x24, 0x19, 0x24, 0x19, 0x24, 0x18, 0x22
    },

    {
        0x51, 0x1E, 0x50, 0x1D, 0x51, 0x1D, 0x51, 0x1D, 0x52, 0x1E, 0x53, 0x1E, 0x54, 0x1E, 0x54, 0x1E, 0x53, 0x1E, 0x53, 0x1D, 0x53, 0x1E, 0x52, 0x1D, 0x51, 0x1D, 0x52, 0x1E, 0x52, 0x1D, 0x52, 0x1D, 0x53, 0x1E, 0x50, 0x1D, 0x4C, 0x1D, 0x46, 0x1B, 0x3E, 0x1A, 0x39, 0x19, 0x3D, 0x1A, 0x45, 0x1B, 0x45, 0x1B, 0x3C, 0x18, 0x2E, 0x16, 0x22, 0x12, 0x1C, 0x11, 0x19, 0x10, 0x18, 0x10, 0x16, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x14, 0x0E, 0x14, 0x0E, 0x14, 0x0E, 0x14, 0x0F, 0x14, 0x0E, 0x15, 0x0F, 0x14, 0x0F, 0x14, 0x0F, 0x14, 0x0F, 0x14, 0x0F, 0x14, 0x0F, 0x15, 0x0F, 0x14, 0x0F, 0x15, 0x0F, 0x15, 0x10, 0x16, 0x10, 0x15, 0x10, 0x15, 0x0F, 0x15, 0x10, 0x17, 0x10, 0x18, 0x11, 0x17, 0x10, 0x17, 0x11, 0x18, 0x12, 0x19, 0x11, 0x19, 0x12, 0x1A, 0x14, 0x1E, 0x17, 0x22, 0x1A, 0x25, 0x1C, 0x27, 0x1D, 0x29, 0x1E, 0x29, 0x1E, 0x29, 0x1E, 0x29, 0x1E, 0x28, 0x1E, 0x27, 0x1C, 0x25, 0x1A, 0x27, 0x1C, 0x43, 0x2C, 0x6A, 0x3C, 0x7A, 0x43, 0x83, 0x46, 0x8A, 0x48, 0x8D, 0x4B, 0x90, 0x4C, 0x92, 0x4D, 0x92, 0x4D, 0x8F, 0x4B, 0x86, 0x45, 0x62, 0x31, 0x34, 0x1D, 0x22, 0x16, 0x1D, 0x14, 0x1A, 0x12, 0x19, 0x12, 0x18, 0x11, 0x19, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x17, 0x11, 0x18, 0x11, 0x18, 0x11, 0x17, 0x11, 0x18, 0x11, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x16, 0x10, 0x16, 0x10, 0x17, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x0F, 0x16, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x15, 0x0F, 0x16, 0x10, 0x16, 0x10, 0x18, 0x11, 0x1A, 0x12, 0x2B, 0x17, 0x4A, 0x1E, 0x56, 0x21, 0x58, 0x21, 0x4F, 0x1E, 0x37, 0x19, 0x3D, 0x1E, 0x53, 0x21, 0x5A, 0x21, 0x5D, 0x22, 0x5C, 0x21, 0x5F, 0x22, 0x5E, 0x22, 0x5E, 0x22, 0x62, 0x23, 0x5F, 0x22, 0x60, 0x22, 0x5F, 0x22, 0x5F, 0x23, 0x60, 0x22, 0x61, 0x22, 0x5F, 0x21, 0x5F, 0x22, 0x5D, 0x21, 0x5F, 0x21, 0x5E, 0x21, 0x5E, 0x21, 0x60, 0x23, 0x60, 0x23, 0x62, 0x23, 0x62, 0x24, 0x60, 0x22, 0x5D, 0x21, 0x5E, 0x21, 0x5C, 0x20, 0x5C, 0x21, 0x5C, 0x22, 0x5B, 0x20, 0x5E, 0x22, 0x60, 0x23, 0x60, 0x23, 0x62, 0x23, 0x5F, 0x22, 0x5C, 0x21, 0x60, 0x21, 0x5E, 0x21, 0x5C, 0x20, 0x5E, 0x20, 0x5F, 0x21, 0x5F, 0x21, 0x5F, 0x22, 0x5F, 0x21, 0x62, 0x22, 0x63, 0x22, 0x5E, 0x20, 0x5D, 0x21, 0x5D, 0x21, 0x5F, 0x21, 0x5F, 0x22, 0x5F, 0x22, 0x61, 0x22, 0x60, 0x22, 0x61, 0x23, 0x60, 0x22, 0x60, 0x22, 0x5D, 0x20, 0x5D, 0x21, 0x5C, 0x21, 0x5E, 0x21, 0x5F, 0x22, 0x5E, 0x22, 0x60, 0x23, 0x60, 0x22, 0x5E, 0x21, 0x5D, 0x21, 0x5D, 0x22, 0x64, 0x24, 0x60, 0x23, 0x5E, 0x22, 0x5D, 0x21, 0x5D, 0x21, 0x61, 0x22, 0x61, 0x22, 0x61, 0x22, 0x60, 0x22, 0x5F, 0x21, 0x5F, 0x21, 0x5F, 0x21, 0x5F, 0x22, 0x5E, 0x21, 0x5D, 0x21, 0x5D, 0x21, 0x5B, 0x21, 0x5D, 0x22, 0x5E, 0x22, 0x5D, 0x22, 0x5E, 0x22, 0x5E, 0x22, 0x5F, 0x22, 0x5D, 0x22, 0x5F, 0x22, 0x5D, 0x21, 0x5D, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x5E, 0x22, 0x5E, 0x21, 0x5E, 0x21, 0x5E, 0x21, 0x60, 0x22, 0x60, 0x23, 0x63, 0x23, 0x62, 0x24, 0x62, 0x23, 0x62, 0x23, 0x60, 0x23, 0x63, 0x24, 0x60, 0x23, 0x5E, 0x23, 0x60, 0x23, 0x5F, 0x23, 0x5E, 0x23, 0x5D, 0x22, 0x5B, 0x22, 0x5B, 0x21, 0x5C, 0x21, 0x5A, 0x21, 0x5A, 0x20, 0x5B, 0x20, 0x5C, 0x21, 0x5E, 0x21, 0x5B, 0x21, 0x5C, 0x22, 0x5D, 0x21, 0x5C, 0x21, 0x58, 0x20, 0x56, 0x20, 0x57, 0x20, 0x55, 0x20, 0x57, 0x20, 0x55, 0x20, 0x53, 0x1E, 0x53, 0x1E, 0x52, 0x1E, 0x52, 0x1E, 0x51, 0x1F, 0x52, 0x1F, 0x54, 0x1F, 0x54, 0x1E, 0x53, 0x1E, 0x53, 0x1E, 0x51, 0x1D, 0x3C, 0x19, 0x2A, 0x17, 0x2A, 0x1A, 0x2C, 0x18, 0x25, 0x16, 0x25, 0x18, 0x25, 0x20, 0x2B, 0x36, 0x2A, 0x3A, 0x2C, 0x3A, 0x2B, 0x3A, 0x2A, 0x39, 0x29, 0x38, 0x25, 0x29, 0x1D, 0x17, 0x25, 0x18, 0x28, 0x18, 0x21, 0x1E, 0x29, 0x31, 0x29, 0x33, 0x27, 0x32, 0x26, 0x31, 0x27, 0x30, 0x25, 0x2D, 0x21, 0x20, 0x1C, 0x16, 0x25, 0x17, 0x23, 0x17, 0x26, 0x21, 0x23, 0x24, 0x21, 0x24, 0x20, 0x22, 0x1E, 0x22, 0x1E, 0x20, 0x1D, 0x1F, 0x1A, 0x17, 0x1F, 0x16, 0x20, 0x14, 0x27, 0x19, 0x23, 0x1B, 0x20, 0x1B, 0x1B, 0x19, 0x1A, 0x18, 0x1A, 0x17
    },

    {
        0x59, 0x4F, 0x58, 0x4E, 0x59, 0x4F, 0x58, 0x50, 0x59, 0x51, 0x5B, 0x51, 0x5B, 0x51, 0x5C, 0x50, 0x5C, 0x51, 0x5C, 0x50, 0x5C, 0x50, 0x5B, 0x4E, 0x5B, 0x4E, 0x5B, 0x4F, 0x5B, 0x4F, 0x5A, 0x4F, 0x59, 0x4F, 0x55, 0x4C, 0x4F, 0x47, 0x49, 0x41, 0x40, 0x3A, 0x3B, 0x38, 0x41, 0x3F, 0x4A, 0x44, 0x48, 0x41, 0x3D, 0x36, 0x2C, 0x27, 0x1E, 0x1E, 0x19, 0x1A, 0x17, 0x19, 0x14, 0x17, 0x12, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x14, 0x10, 0x13, 0x11, 0x14, 0x10, 0x13, 0x10, 0x13, 0x10, 0x13, 0x10, 0x14, 0x0F, 0x13, 0x10, 0x14, 0x10, 0x14, 0x10, 0x14, 0x11, 0x14, 0x11, 0x14, 0x11, 0x14, 0x10, 0x14, 0x11, 0x14, 0x11, 0x15, 0x11, 0x15, 0x11, 0x14, 0x11, 0x15, 0x12, 0x16, 0x13, 0x16, 0x12, 0x16, 0x12, 0x16, 0x13, 0x17, 0x14, 0x18, 0x14, 0x19, 0x18, 0x1B, 0x1E, 0x1F, 0x26, 0x23, 0x2A, 0x25, 0x2C, 0x26, 0x2E, 0x28, 0x2F, 0x27, 0x30, 0x28, 0x30, 0x28, 0x2F, 0x28, 0x2C, 0x27, 0x29, 0x23, 0x26, 0x27, 0x36, 0x47, 0x54, 0x6B, 0x61, 0x76, 0x68, 0x7E, 0x6E, 0x84, 0x71, 0x87, 0x74, 0x8A, 0x76, 0x8B, 0x76, 0x8C, 0x72, 0x89, 0x6A, 0x7C, 0x51, 0x5B, 0x2D, 0x2F, 0x1D, 0x20, 0x18, 0x1C, 0x16, 0x19, 0x14, 0x18, 0x13, 0x17, 0x14, 0x17, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x13, 0x16, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x12, 0x16, 0x13, 0x16, 0x12, 0x16, 0x12, 0x15, 0x12, 0x15, 0x12, 0x16, 0x12, 0x15, 0x12, 0x16, 0x12, 0x15, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x13, 0x16, 0x12, 0x15, 0x11, 0x15, 0x12, 0x15, 0x13, 0x16, 0x13, 0x16, 0x16, 0x18, 0x22, 0x26, 0x41, 0x43, 0x53, 0x4F, 0x59, 0x54, 0x54, 0x4D, 0x3D, 0x36, 0x3B, 0x39, 0x50, 0x4D, 0x5B, 0x55, 0x5F, 0x57, 0x62, 0x58, 0x64, 0x59, 0x66, 0x5A, 0x67, 0x5B, 0x6A, 0x5C, 0x68, 0x5C, 0x68, 0x5B, 0x68, 0x5B, 0x66, 0x5C, 0x69, 0x5C, 0x69, 0x5C, 0x67, 0x5B, 0x67, 0x5B, 0x65, 0x5A, 0x67, 0x5B, 0x66, 0x59, 0x66, 0x59, 0x68, 0x5C, 0x67, 0x5C, 0x69, 0x5D, 0x6A, 0x5C, 0x68, 0x5B, 0x67, 0x5A, 0x65, 0x59, 0x65, 0x58, 0x65, 0x58, 0x64, 0x59, 0x63, 0x58, 0x64, 0x5B, 0x65, 0x5B, 0x68, 0x5B, 0x69, 0x5C, 0x68, 0x5B, 0x65, 0x58, 0x68, 0x5B, 0x67, 0x59, 0x65, 0x59, 0x67, 0x5B, 0x68, 0x5C, 0x69, 0x5A, 0x67, 0x5A, 0x68, 0x5A, 0x6B, 0x5D, 0x6A, 0x5D, 0x68, 0x5A, 0x67, 0x59, 0x67, 0x59, 0x67, 0x5B, 0x68, 0x5A, 0x68, 0x5B, 0x6A, 0x5C, 0x6A, 0x5C, 0x69, 0x5D, 0x69, 0x5D, 0x6A, 0x5B, 0x66, 0x58, 0x67, 0x59, 0x65, 0x58, 0x67, 0x5A, 0x68, 0x5B, 0x66, 0x5B, 0x68, 0x5B, 0x68, 0x5B, 0x67, 0x59, 0x67, 0x5A, 0x67, 0x59, 0x68, 0x5C, 0x67, 0x5B, 0x67, 0x5B, 0x67, 0x5A, 0x66, 0x59, 0x6B, 0x5C, 0x69, 0x5D, 0x6A, 0x5D, 0x6A, 0x5D, 0x67, 0x5C, 0x67, 0x5C, 0x66, 0x5A, 0x67, 0x5B, 0x64, 0x59, 0x67, 0x5A, 0x67, 0x5A, 0x65, 0x59, 0x66, 0x59, 0x66, 0x5A, 0x65, 0x59, 0x67, 0x5A, 0x67, 0x5B, 0x66, 0x59, 0x67, 0x5A, 0x67, 0x5A, 0x65, 0x5A, 0x66, 0x5A, 0x67, 0x5B, 0x69, 0x5B, 0x69, 0x5B, 0x67, 0x5A, 0x67, 0x59, 0x68, 0x5C, 0x67, 0x5B, 0x69, 0x5D, 0x6C, 0x5F, 0x6C, 0x5E, 0x69, 0x5D, 0x6B, 0x5D, 0x68, 0x5D, 0x6B, 0x5F, 0x67, 0x5C, 0x67, 0x5A, 0x69, 0x5B, 0x67, 0x5B, 0x66, 0x5B, 0x65, 0x58, 0x63, 0x58, 0x66, 0x58, 0x66, 0x58, 0x65, 0x57, 0x64, 0x57, 0x64, 0x59, 0x64, 0x58, 0x65, 0x59, 0x63, 0x57, 0x65, 0x58, 0x65, 0x59, 0x64, 0x58, 0x5F, 0x56, 0x5E, 0x54, 0x5F, 0x55, 0x5F, 0x52, 0x60, 0x53, 0x5C, 0x51, 0x5B, 0x50, 0x5C, 0x51, 0x5A, 0x4E, 0x59, 0x4F, 0x57, 0x4E, 0x59, 0x51, 0x5A, 0x51, 0x5C, 0x50, 0x5A, 0x4F, 0x5A, 0x4F, 0x58, 0x4B, 0x3C, 0x33, 0x28, 0x26, 0x28, 0x2B, 0x25, 0x27, 0x20, 0x21, 0x21, 0x25, 0x1E, 0x23, 0x1D, 0x28, 0x1C, 0x27, 0x1C, 0x28, 0x1B, 0x26, 0x1A, 0x27, 0x1A, 0x26, 0x19, 0x20, 0x18, 0x1D, 0x23, 0x27, 0x22, 0x27, 0x1D, 0x23, 0x1E, 0x28, 0x1B, 0x24, 0x19, 0x22, 0x18, 0x22, 0x19, 0x22, 0x18, 0x20, 0x17, 0x1D, 0x18, 0x1D, 0x1F, 0x22, 0x1F, 0x22, 0x20, 0x25, 0x1A, 0x1E, 0x17, 0x1D, 0x17, 0x1C, 0x15, 0x1B, 0x16, 0x1A, 0x17, 0x1B, 0x15, 0x18, 0x1B, 0x20, 0x1D, 0x1E, 0x23, 0x28, 0x1F, 0x20, 0x19, 0x1D, 0x16, 0x19, 0x16, 0x19, 0x15, 0x19
    },

    {
        0x51, 0x1E, 0x51, 0x1E, 0x53, 0x1E, 0x52, 0x1E, 0x52, 0x1E, 0x54, 0x1F, 0x54, 0x1E, 0x54, 0x1E, 0x54, 0x1E, 0x54, 0x1E, 0x54, 0x1E, 0x53, 0x1E, 0x51, 0x1D, 0x52, 0x1E, 0x51, 0x1D, 0x52, 0x1D, 0x50, 0x1D, 0x4C, 0x1C, 0x46, 0x1B, 0x3D, 0x1A, 0x39, 0x19, 0x3D, 0x1B, 0x47, 0x1C, 0x46, 0x1B, 0x3F, 0x19, 0x2F, 0x15, 0x23, 0x13, 0x1C, 0x11, 0x19, 0x10, 0x18, 0x10, 0x16, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x14, 0x0F, 0x14, 0x0E, 0x14, 0x0F, 0x14, 0x0E, 0x14, 0x0F, 0x14, 0x0F, 0x15, 0x0F, 0x14, 0x0F, 0x15, 0x0F, 0x15, 0x10, 0x15, 0x10, 0x15, 0x0F, 0x15, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x0F, 0x16, 0x10, 0x17, 0x10, 0x17, 0x10, 0x16, 0x10, 0x16, 0x11, 0x18, 0x11, 0x19, 0x12, 0x1A, 0x13, 0x1C, 0x15, 0x21, 0x19, 0x25, 0x1C, 0x27, 0x1C, 0x28, 0x1D, 0x29, 0x1E, 0x2A, 0x1F, 0x2A, 0x1F, 0x2A, 0x1E, 0x2A, 0x1F, 0x28, 0x1C, 0x24, 0x19, 0x22, 0x18, 0x33, 0x24, 0x5D, 0x38, 0x78, 0x42, 0x82, 0x45, 0x88, 0x4A, 0x8E, 0x4B, 0x90, 0x4D, 0x93, 0x4F, 0x92, 0x4E, 0x90, 0x4B, 0x80, 0x41, 0x5F, 0x30, 0x35, 0x1D, 0x23, 0x16, 0x1D, 0x13, 0x1A, 0x12, 0x19, 0x12, 0x18, 0x11, 0x18, 0x12, 0x19, 0x12, 0x18, 0x11, 0x17, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x17, 0x11, 0x17, 0x11, 0x17, 0x11, 0x17, 0x11, 0x17, 0x11, 0x17, 0x10, 0x16, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x16, 0x10, 0x16, 0x10, 0x17, 0x10, 0x17, 0x11, 0x17, 0x10, 0x16, 0x0F, 0x16, 0x0F, 0x15, 0x0F, 0x16, 0x10, 0x17, 0x10, 0x17, 0x10, 0x18, 0x10, 0x1B, 0x12, 0x29, 0x18, 0x47, 0x1E, 0x55, 0x22, 0x58, 0x21, 0x50, 0x1E, 0x3A, 0x1B, 0x3C, 0x1D, 0x50, 0x21, 0x5A, 0x22, 0x5A, 0x21, 0x5E, 0x21, 0x5E, 0x22, 0x5F, 0x22, 0x60, 0x22, 0x60, 0x22, 0x60, 0x22, 0x5D, 0x22, 0x5E, 0x22, 0x5E, 0x22, 0x61, 0x22, 0x5F, 0x21, 0x5E, 0x22, 0x5E, 0x21, 0x5D, 0x21, 0x5D, 0x20, 0x5E, 0x21, 0x5F, 0x21, 0x5E, 0x21, 0x5F, 0x21, 0x61, 0x22, 0x61, 0x22, 0x60, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x5E, 0x21, 0x5D, 0x21, 0x5E, 0x22, 0x60, 0x22, 0x60, 0x23, 0x63, 0x24, 0x62, 0x23, 0x61, 0x23, 0x5E, 0x21, 0x5E, 0x22, 0x60, 0x22, 0x5E, 0x22, 0x60, 0x22, 0x63, 0x22, 0x60, 0x22, 0x5E, 0x21, 0x60, 0x22, 0x60, 0x22, 0x60, 0x22, 0x5D, 0x21, 0x5C, 0x21, 0x5C, 0x20, 0x5F, 0x21, 0x5F, 0x22, 0x60, 0x23, 0x61, 0x22, 0x62, 0x23, 0x60, 0x22, 0x60, 0x22, 0x61, 0x22, 0x5D, 0x21, 0x5D, 0x21, 0x5A, 0x21, 0x5F, 0x22, 0x5F, 0x22, 0x61, 0x23, 0x5E, 0x22, 0x60, 0x23, 0x5E, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x5F, 0x23, 0x61, 0x23, 0x5F, 0x22, 0x60, 0x22, 0x5F, 0x22, 0x61, 0x22, 0x60, 0x22, 0x62, 0x22, 0x60, 0x21, 0x61, 0x22, 0x5F, 0x21, 0x5F, 0x22, 0x5F, 0x22, 0x5F, 0x23, 0x5E, 0x22, 0x5F, 0x22, 0x5F, 0x23, 0x5B, 0x21, 0x61, 0x23, 0x5F, 0x23, 0x5F, 0x22, 0x5F, 0x22, 0x5B, 0x21, 0x5D, 0x21, 0x62, 0x23, 0x60, 0x22, 0x60, 0x22, 0x5F, 0x21, 0x5E, 0x22, 0x5F, 0x22, 0x5D, 0x21, 0x5F, 0x22, 0x5E, 0x21, 0x5E, 0x23, 0x61, 0x23, 0x63, 0x23, 0x60, 0x23, 0x62, 0x24, 0x62, 0x24, 0x62, 0x24, 0x62, 0x24, 0x61, 0x23, 0x61, 0x23, 0x60, 0x22, 0x5E, 0x22, 0x5D, 0x22, 0x5D, 0x22, 0x5E, 0x23, 0x5F, 0x22, 0x5E, 0x22, 0x5C, 0x22, 0x5C, 0x21, 0x5D, 0x22, 0x5D, 0x22, 0x5E, 0x22, 0x5D, 0x22, 0x5C, 0x22, 0x5E, 0x22, 0x5D, 0x22, 0x5B, 0x22, 0x5A, 0x22, 0x5A, 0x21, 0x58, 0x20, 0x56, 0x20, 0x54, 0x1F, 0x54, 0x1E, 0x54, 0x1F, 0x51, 0x1F, 0x53, 0x1F, 0x54, 0x20, 0x54, 0x20, 0x51, 0x1E, 0x54, 0x1E, 0x53, 0x1F, 0x53, 0x1F, 0x4D, 0x1C, 0x37, 0x19, 0x28, 0x17, 0x2A, 0x18, 0x27, 0x17, 0x25, 0x17, 0x28, 0x19, 0x29, 0x1D, 0x29, 0x24, 0x22, 0x23, 0x20, 0x21, 0x1F, 0x20, 0x1E, 0x1F, 0x1E, 0x1D, 0x1C, 0x18, 0x1D, 0x16, 0x2D, 0x19, 0x26, 0x17, 0x2D, 0x1C, 0x28, 0x1B, 0x1D, 0x17, 0x1A, 0x17, 0x1A, 0x17, 0x19, 0x15, 0x19, 0x14, 0x19, 0x13, 0x1F, 0x16, 0x22, 0x15, 0x23, 0x16, 0x22, 0x16, 0x1C, 0x15, 0x1C, 0x15, 0x1B, 0x15, 0x1E, 0x15, 0x1C, 0x15, 0x1E, 0x15, 0x20, 0x15, 0x22, 0x17, 0x27, 0x17, 0x26, 0x19, 0x2D, 0x1A, 0x23, 0x16, 0x1B, 0x14, 0x22, 0x16, 0x23, 0x17
    },

    {
        0x58, 0x4F, 0x5A, 0x52, 0x59, 0x4F, 0x59, 0x50, 0x59, 0x50, 0x5B, 0x51, 0x5B, 0x50, 0x5C, 0x51, 0x5C, 0x51, 0x5D, 0x51, 0x5C, 0x51, 0x5C, 0x4E, 0x5B, 0x4F, 0x5B, 0x4E, 0x5A, 0x4F, 0x59, 0x4E, 0x57, 0x4C, 0x52, 0x47, 0x49, 0x40, 0x40, 0x38, 0x3A, 0x36, 0x41, 0x3F, 0x4B, 0x45, 0x4A, 0x42, 0x3F, 0x38, 0x2D, 0x28, 0x1F, 0x1E, 0x1A, 0x1A, 0x16, 0x18, 0x14, 0x16, 0x12, 0x14, 0x11, 0x14, 0x11, 0x14, 0x11, 0x14, 0x11, 0x14, 0x11, 0x14, 0x10, 0x13, 0x10, 0x13, 0x10, 0x13, 0x10, 0x13, 0x10, 0x13, 0x10, 0x13, 0x10, 0x14, 0x11, 0x14, 0x10, 0x13, 0x10, 0x14, 0x11, 0x14, 0x11, 0x15, 0x11, 0x14, 0x11, 0x14, 0x11, 0x15, 0x11, 0x15, 0x11, 0x14, 0x11, 0x14, 0x12, 0x16, 0x12, 0x15, 0x11, 0x15, 0x12, 0x15, 0x13, 0x17, 0x13, 0x18, 0x15, 0x19, 0x19, 0x1C, 0x21, 0x21, 0x28, 0x24, 0x2A, 0x25, 0x2D, 0x26, 0x2E, 0x28, 0x30, 0x29, 0x31, 0x29, 0x30, 0x29, 0x2E, 0x28, 0x2A, 0x25, 0x25, 0x20, 0x1F, 0x1F, 0x26, 0x2F, 0x43, 0x57, 0x5B, 0x72, 0x65, 0x7B, 0x6C, 0x83, 0x70, 0x86, 0x73, 0x8A, 0x77, 0x8C, 0x75, 0x8C, 0x6F, 0x84, 0x63, 0x71, 0x49, 0x4D, 0x2A, 0x2B, 0x1D, 0x20, 0x17, 0x1B, 0x15, 0x19, 0x15, 0x19, 0x13, 0x18, 0x13, 0x17, 0x13, 0x17, 0x13, 0x18, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x14, 0x17, 0x13, 0x17, 0x13, 0x18, 0x13, 0x17, 0x13, 0x17, 0x13, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x15, 0x11, 0x15, 0x12, 0x16, 0x12, 0x16, 0x12, 0x15, 0x12, 0x15, 0x12, 0x15, 0x12, 0x16, 0x12, 0x16, 0x12, 0x15, 0x12, 0x15, 0x12, 0x15, 0x12, 0x14, 0x11, 0x15, 0x12, 0x15, 0x13, 0x15, 0x12, 0x16, 0x16, 0x19, 0x20, 0x25, 0x3E, 0x40, 0x52, 0x50, 0x5A, 0x55, 0x55, 0x4E, 0x40, 0x39, 0x3A, 0x37, 0x4D, 0x4A, 0x5A, 0x54, 0x5D, 0x55, 0x63, 0x59, 0x66, 0x5A, 0x66, 0x5B, 0x68, 0x5C, 0x67, 0x5C, 0x68, 0x5B, 0x67, 0x5A, 0x67, 0x5B, 0x67, 0x59, 0x68, 0x5B, 0x69, 0x5C, 0x67, 0x5B, 0x67, 0x5A, 0x66, 0x59, 0x66, 0x58, 0x67, 0x5A, 0x68, 0x5B, 0x67, 0x59, 0x66, 0x5A, 0x6B, 0x5D, 0x6A, 0x5C, 0x68, 0x5C, 0x66, 0x5B, 0x68, 0x5B, 0x67, 0x59, 0x64, 0x59, 0x66, 0x5A, 0x67, 0x5B, 0x66, 0x5C, 0x6A, 0x5D, 0x69, 0x5D, 0x68, 0x5C, 0x66, 0x58, 0x66, 0x59, 0x67, 0x5B, 0x67, 0x5A, 0x6B, 0x5D, 0x6B, 0x5F, 0x69, 0x5C, 0x68, 0x5B, 0x69, 0x5C, 0x69, 0x5C, 0x69, 0x5A, 0x66, 0x59, 0x65, 0x58, 0x65, 0x58, 0x67, 0x5A, 0x67, 0x5B, 0x67, 0x5A, 0x69, 0x5D, 0x6B, 0x5E, 0x6A, 0x5B, 0x6A, 0x5C, 0x6A, 0x5D, 0x67, 0x5B, 0x65, 0x57, 0x63, 0x57, 0x67, 0x5B, 0x67, 0x5B, 0x68, 0x5B, 0x67, 0x59, 0x68, 0x5C, 0x66, 0x5A, 0x68, 0x5C, 0x68, 0x5C, 0x69, 0x5C, 0x6A, 0x5D, 0x67, 0x5D, 0x69, 0x5B, 0x68, 0x5D, 0x6B, 0x5E, 0x6A, 0x5C, 0x69, 0x5D, 0x67, 0x5C, 0x68, 0x5B, 0x67, 0x5B, 0x69, 0x5B, 0x68, 0x5A, 0x68, 0x5C, 0x66, 0x5A, 0x69, 0x5C, 0x67, 0x5B, 0x64, 0x58, 0x67, 0x5C, 0x68, 0x5C, 0x67, 0x5B, 0x68, 0x5B, 0x63, 0x57, 0x66, 0x59, 0x6B, 0x5D, 0x69, 0x5D, 0x69, 0x5D, 0x68, 0x5A, 0x68, 0x5B, 0x69, 0x5A, 0x67, 0x5A, 0x69, 0x5B, 0x68, 0x5B, 0x68, 0x5B, 0x6B, 0x5E, 0x6C, 0x5E, 0x6A, 0x5D, 0x6B, 0x5E, 0x6A, 0x5C, 0x69, 0x5D, 0x68, 0x5E, 0x69, 0x5E, 0x69, 0x5D, 0x67, 0x5C, 0x68, 0x5B, 0x67, 0x5A, 0x67, 0x5A, 0x66, 0x5B, 0x68, 0x5A, 0x66, 0x59, 0x65, 0x59, 0x65, 0x57, 0x63, 0x59, 0x66, 0x5A, 0x65, 0x5B, 0x65, 0x59, 0x65, 0x59, 0x66, 0x58, 0x64, 0x59, 0x61, 0x57, 0x62, 0x57, 0x62, 0x56, 0x61, 0x54, 0x60, 0x53, 0x5E, 0x51, 0x5C, 0x50, 0x5D, 0x50, 0x5A, 0x4F, 0x59, 0x4F, 0x5B, 0x51, 0x5B, 0x51, 0x58, 0x4E, 0x5C, 0x51, 0x5A, 0x4F, 0x5A, 0x4F, 0x53, 0x49, 0x38, 0x31, 0x28, 0x27, 0x27, 0x28, 0x24, 0x24, 0x22, 0x24, 0x23, 0x28, 0x24, 0x29, 0x1F, 0x25, 0x19, 0x1F, 0x18, 0x1C, 0x16, 0x1C, 0x17, 0x1B, 0x16, 0x1A, 0x16, 0x1A, 0x1A, 0x20, 0x25, 0x28, 0x20, 0x24, 0x29, 0x2D, 0x20, 0x22, 0x18, 0x1A, 0x16, 0x18, 0x16, 0x1A, 0x16, 0x18, 0x16, 0x19, 0x15, 0x18, 0x1C, 0x22, 0x1E, 0x20, 0x1F, 0x21, 0x1F, 0x21, 0x1A, 0x1E, 0x1A, 0x1D, 0x1A, 0x1E, 0x1C, 0x1F, 0x19, 0x1D, 0x1D, 0x21, 0x1E, 0x22, 0x20, 0x26, 0x22, 0x26, 0x23, 0x28, 0x27, 0x28, 0x20, 0x21, 0x1A, 0x1C, 0x1F, 0x24, 0x1F, 0x22
    },

    {
        0x51, 0x1E, 0x53, 0x1D, 0x53, 0x1E, 0x53, 0x1E, 0x53, 0x1F, 0x53, 0x1E, 0x55, 0x1F, 0x54, 0x1E, 0x54, 0x1D, 0x53, 0x1E, 0x55, 0x1E, 0x54, 0x1E, 0x53, 0x1E, 0x53, 0x1D, 0x51, 0x1D, 0x50, 0x1D, 0x4E, 0x1C, 0x47, 0x1C, 0x40, 0x19, 0x38, 0x18, 0x3A, 0x19, 0x44, 0x1B, 0x46, 0x1B, 0x3F, 0x19, 0x32, 0x16, 0x23, 0x12, 0x1C, 0x10, 0x1A, 0x10, 0x18, 0x10, 0x16, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0E, 0x14, 0x0E, 0x15, 0x0F, 0x15, 0x0F, 0x14, 0x0F, 0x14, 0x0F, 0x14, 0x0F, 0x14, 0x0F, 0x14, 0x0E, 0x14, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x10, 0x15, 0x10, 0x16, 0x0F, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x17, 0x11, 0x18, 0x11, 0x17, 0x11, 0x19, 0x12, 0x1A, 0x14, 0x1F, 0x18, 0x24, 0x1A, 0x26, 0x1C, 0x28, 0x1D, 0x29, 0x1E, 0x2B, 0x1F, 0x2A, 0x1E, 0x2B, 0x1F, 0x29, 0x1E, 0x26, 0x1B, 0x20, 0x16, 0x1C, 0x14, 0x1F, 0x16, 0x34, 0x25, 0x5F, 0x38, 0x79, 0x43, 0x84, 0x47, 0x8B, 0x4B, 0x8E, 0x4C, 0x93, 0x4D, 0x8E, 0x4B, 0x83, 0x43, 0x67, 0x33, 0x40, 0x22, 0x28, 0x18, 0x21, 0x15, 0x1D, 0x13, 0x1A, 0x12, 0x1A, 0x12, 0x19, 0x11, 0x19, 0x11, 0x19, 0x11, 0x18, 0x11, 0x19, 0x12, 0x19, 0x12, 0x19, 0x12, 0x19, 0x12, 0x19, 0x12, 0x19, 0x11, 0x18, 0x11, 0x18, 0x11, 0x17, 0x11, 0x17, 0x10, 0x17, 0x10, 0x17, 0x11, 0x17, 0x10, 0x16, 0x10, 0x16, 0x10, 0x18, 0x11, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x16, 0x0F, 0x15, 0x0F, 0x16, 0x10, 0x16, 0x0F, 0x16, 0x10, 0x16, 0x10, 0x18, 0x11, 0x1C, 0x14, 0x2A, 0x18, 0x45, 0x1E, 0x55, 0x20, 0x57, 0x21, 0x53, 0x1F, 0x3B, 0x1B, 0x38, 0x1C, 0x4D, 0x20, 0x58, 0x22, 0x5D, 0x23, 0x5F, 0x22, 0x5F, 0x22, 0x60, 0x22, 0x5F, 0x22, 0x5E, 0x22, 0x60, 0x22, 0x60, 0x22, 0x5F, 0x21, 0x5E, 0x22, 0x5F, 0x21, 0x5D, 0x21, 0x5E, 0x21, 0x5D, 0x21, 0x5C, 0x21, 0x5C, 0x21, 0x5F, 0x21, 0x5F, 0x21, 0x61, 0x22, 0x60, 0x22, 0x62, 0x23, 0x60, 0x22, 0x5E, 0x21, 0x61, 0x22, 0x5F, 0x21, 0x5E, 0x22, 0x5F, 0x22, 0x60, 0x23, 0x60, 0x24, 0x64, 0x24, 0x62, 0x23, 0x60, 0x22, 0x5F, 0x22, 0x5C, 0x21, 0x5D, 0x21, 0x5E, 0x22, 0x60, 0x21, 0x62, 0x22, 0x61, 0x22, 0x5E, 0x21, 0x5F, 0x21, 0x60, 0x21, 0x5E, 0x22, 0x5E, 0x21, 0x5E, 0x21, 0x5D, 0x21, 0x5F, 0x22, 0x61, 0x23, 0x60, 0x23, 0x60, 0x22, 0x63, 0x23, 0x61, 0x23, 0x60, 0x22, 0x62, 0x22, 0x60, 0x22, 0x5F, 0x21, 0x5C, 0x21, 0x5F, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x5D, 0x22, 0x5F, 0x22, 0x60, 0x22, 0x60, 0x22, 0x5E, 0x22, 0x61, 0x23, 0x63, 0x23, 0x60, 0x23, 0x60, 0x22, 0x61, 0x22, 0x60, 0x22, 0x5D, 0x21, 0x61, 0x23, 0x61, 0x23, 0x5E, 0x21, 0x5F, 0x22, 0x5E, 0x21, 0x5D, 0x22, 0x61, 0x23, 0x63, 0x24, 0x61, 0x23, 0x5D, 0x22, 0x5C, 0x22, 0x5E, 0x23, 0x63, 0x24, 0x61, 0x22, 0x5F, 0x22, 0x5C, 0x21, 0x5F, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x5E, 0x21, 0x5D, 0x21, 0x5E, 0x21, 0x5E, 0x22, 0x61, 0x22, 0x5F, 0x21, 0x5F, 0x22, 0x61, 0x23, 0x61, 0x23, 0x60, 0x23, 0x61, 0x24, 0x61, 0x23, 0x61, 0x23, 0x61, 0x23, 0x62, 0x23, 0x60, 0x23, 0x61, 0x22, 0x5E, 0x21, 0x5F, 0x23, 0x5F, 0x23, 0x5E, 0x22, 0x5F, 0x22, 0x5D, 0x22, 0x5C, 0x22, 0x5A, 0x22, 0x5C, 0x22, 0x5E, 0x22, 0x5C, 0x22, 0x5C, 0x21, 0x5B, 0x21, 0x5B, 0x20, 0x5A, 0x21, 0x58, 0x20, 0x5B, 0x22, 0x58, 0x20, 0x58, 0x20, 0x55, 0x1F, 0x55, 0x1F, 0x54, 0x1F, 0x55, 0x1F, 0x53, 0x1E, 0x53, 0x1E, 0x58, 0x21, 0x55, 0x20, 0x51, 0x1E, 0x52, 0x1E, 0x52, 0x1E, 0x4F, 0x1E, 0x51, 0x1E, 0x3D, 0x1A, 0x2B, 0x18, 0x2D, 0x19, 0x2D, 0x1A, 0x2B, 0x18, 0x30, 0x1C, 0x2B, 0x19, 0x23, 0x17, 0x1E, 0x16, 0x1D, 0x15, 0x1F, 0x15, 0x1E, 0x15, 0x1C, 0x14, 0x1C, 0x13, 0x24, 0x17, 0x24, 0x16, 0x22, 0x16, 0x2B, 0x19, 0x23, 0x17, 0x21, 0x16, 0x21, 0x16, 0x23, 0x17, 0x21, 0x16, 0x22, 0x16, 0x23, 0x16, 0x25, 0x16, 0x25, 0x16, 0x29, 0x18, 0x2A, 0x18, 0x25, 0x18, 0x2E, 0x1B, 0x28, 0x19, 0x2D, 0x1A, 0x24, 0x17, 0x2D, 0x1A, 0x25, 0x16, 0x29, 0x18, 0x23, 0x14, 0x26, 0x17, 0x25, 0x16, 0x20, 0x15, 0x21, 0x16, 0x24, 0x16, 0x25, 0x17
    },

    {
        0x59, 0x4F, 0x5A, 0x4F, 0x5B, 0x51, 0x5A, 0x50, 0x5A, 0x50, 0x5A, 0x50, 0x5C, 0x51, 0x5C, 0x51, 0x5C, 0x51, 0x5C, 0x52, 0x5D, 0x52, 0x5D, 0x50, 0x5C, 0x51, 0x5B, 0x4F, 0x59, 0x4E, 0x56, 0x4C, 0x53, 0x49, 0x4B, 0x42, 0x42, 0x39, 0x3A, 0x35, 0x3E, 0x3C, 0x48, 0x43, 0x49, 0x41, 0x40, 0x38, 0x30, 0x2B, 0x20, 0x1F, 0x19, 0x1A, 0x16, 0x18, 0x14, 0x16, 0x13, 0x15, 0x11, 0x14, 0x11, 0x14, 0x10, 0x13, 0x10, 0x14, 0x10, 0x13, 0x10, 0x13, 0x10, 0x13, 0x10, 0x13, 0x10, 0x14, 0x10, 0x13, 0x10, 0x13, 0x0F, 0x13, 0x10, 0x13, 0x10, 0x14, 0x10, 0x13, 0x11, 0x14, 0x10, 0x14, 0x11, 0x14, 0x10, 0x14, 0x11, 0x14, 0x11, 0x14, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x12, 0x16, 0x12, 0x16, 0x13, 0x17, 0x14, 0x18, 0x15, 0x19, 0x1E, 0x1F, 0x25, 0x23, 0x2A, 0x26, 0x2D, 0x26, 0x2E, 0x27, 0x2F, 0x28, 0x2F, 0x28, 0x2F, 0x28, 0x2D, 0x26, 0x28, 0x23, 0x1F, 0x1D, 0x19, 0x19, 0x19, 0x1C, 0x25, 0x2F, 0x42, 0x55, 0x5A, 0x71, 0x66, 0x7D, 0x6D, 0x85, 0x72, 0x87, 0x73, 0x89, 0x6F, 0x83, 0x64, 0x72, 0x4E, 0x53, 0x31, 0x32, 0x21, 0x25, 0x1B, 0x1F, 0x18, 0x1B, 0x15, 0x19, 0x14, 0x18, 0x14, 0x18, 0x13, 0x17, 0x14, 0x18, 0x13, 0x17, 0x13, 0x17, 0x14, 0x18, 0x14, 0x17, 0x13, 0x18, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x12, 0x17, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x15, 0x11, 0x14, 0x12, 0x15, 0x12, 0x16, 0x12, 0x15, 0x12, 0x15, 0x11, 0x15, 0x12, 0x15, 0x12, 0x15, 0x12, 0x15, 0x12, 0x15, 0x11, 0x15, 0x12, 0x14, 0x11, 0x15, 0x12, 0x15, 0x12, 0x15, 0x11, 0x15, 0x13, 0x16, 0x16, 0x1A, 0x21, 0x25, 0x3D, 0x3F, 0x51, 0x4E, 0x5A, 0x53, 0x58, 0x4F, 0x41, 0x39, 0x36, 0x34, 0x4A, 0x47, 0x5A, 0x53, 0x60, 0x59, 0x64, 0x5C, 0x66, 0x5B, 0x69, 0x5D, 0x68, 0x5C, 0x66, 0x5A, 0x69, 0x5B, 0x68, 0x5B, 0x69, 0x5B, 0x66, 0x5A, 0x68, 0x59, 0x67, 0x5A, 0x67, 0x59, 0x65, 0x58, 0x65, 0x57, 0x66, 0x58, 0x67, 0x5A, 0x66, 0x5A, 0x67, 0x5B, 0x69, 0x5C, 0x6B, 0x5C, 0x69, 0x5B, 0x67, 0x5A, 0x69, 0x5C, 0x66, 0x59, 0x66, 0x5A, 0x67, 0x5B, 0x69, 0x5B, 0x67, 0x5C, 0x6A, 0x5E, 0x69, 0x5D, 0x66, 0x5B, 0x67, 0x5A, 0x64, 0x57, 0x64, 0x58, 0x65, 0x5A, 0x66, 0x5A, 0x69, 0x5B, 0x69, 0x5B, 0x67, 0x5A, 0x67, 0x5A, 0x68, 0x5B, 0x67, 0x5A, 0x68, 0x5B, 0x66, 0x59, 0x65, 0x58, 0x68, 0x5A, 0x69, 0x5C, 0x68, 0x5C, 0x6A, 0x5C, 0x6C, 0x5E, 0x6B, 0x5D, 0x6B, 0x5E, 0x6B, 0x5D, 0x6A, 0x5B, 0x68, 0x5A, 0x65, 0x58, 0x67, 0x5A, 0x67, 0x5A, 0x68, 0x59, 0x67, 0x5A, 0x68, 0x5B, 0x68, 0x5C, 0x68, 0x5A, 0x67, 0x5B, 0x6A, 0x5D, 0x6A, 0x5E, 0x69, 0x5C, 0x68, 0x5A, 0x6A, 0x5D, 0x68, 0x59, 0x67, 0x59, 0x69, 0x5D, 0x68, 0x5C, 0x64, 0x58, 0x67, 0x59, 0x67, 0x59, 0x66, 0x5A, 0x6A, 0x5D, 0x6B, 0x5F, 0x6C, 0x5E, 0x6A, 0x5A, 0x65, 0x58, 0x66, 0x58, 0x69, 0x5E, 0x69, 0x5A, 0x66, 0x5A, 0x66, 0x59, 0x67, 0x5B, 0x65, 0x5B, 0x67, 0x5A, 0x68, 0x5B, 0x68, 0x5A, 0x68, 0x5A, 0x68, 0x59, 0x69, 0x5D, 0x6B, 0x5D, 0x69, 0x5C, 0x6A, 0x5C, 0x69, 0x5C, 0x69, 0x5C, 0x68, 0x5C, 0x6B, 0x5D, 0x6A, 0x5E, 0x69, 0x5D, 0x6A, 0x5D, 0x6A, 0x5E, 0x69, 0x5B, 0x68, 0x5B, 0x66, 0x58, 0x66, 0x5A, 0x66, 0x5A, 0x67, 0x5A, 0x65, 0x5B, 0x63, 0x58, 0x63, 0x57, 0x63, 0x57, 0x63, 0x58, 0x64, 0x58, 0x63, 0x58, 0x63, 0x57, 0x63, 0x58, 0x65, 0x57, 0x64, 0x58, 0x61, 0x56, 0x62, 0x57, 0x61, 0x55, 0x60, 0x55, 0x5E, 0x52, 0x5E, 0x52, 0x5C, 0x51, 0x5D, 0x51, 0x5C, 0x4F, 0x5D, 0x50, 0x5D, 0x54, 0x5A, 0x51, 0x58, 0x4E, 0x5A, 0x4F, 0x5A, 0x4E, 0x58, 0x4E, 0x59, 0x4D, 0x3D, 0x36, 0x2A, 0x2A, 0x29, 0x2B, 0x29, 0x2E, 0x25, 0x26, 0x2B, 0x30, 0x24, 0x24, 0x20, 0x22, 0x1B, 0x1D, 0x1C, 0x20, 0x1D, 0x20, 0x1D, 0x20, 0x1B, 0x1E, 0x1A, 0x1F, 0x22, 0x27, 0x21, 0x23, 0x1F, 0x23, 0x26, 0x2A, 0x1F, 0x22, 0x1F, 0x23, 0x1E, 0x22, 0x21, 0x26, 0x20, 0x24, 0x20, 0x24, 0x22, 0x24, 0x21, 0x25, 0x24, 0x28, 0x22, 0x26, 0x26, 0x28, 0x21, 0x25, 0x28, 0x2C, 0x23, 0x27, 0x26, 0x2A, 0x20, 0x23, 0x28, 0x2C, 0x1F, 0x20, 0x24, 0x27, 0x1F, 0x20, 0x23, 0x26, 0x20, 0x21, 0x1E, 0x20, 0x1F, 0x23, 0x21, 0x23, 0x23, 0x27
    },

    {
        0x53, 0x1E, 0x52, 0x1E, 0x53, 0x1E, 0x54, 0x1E, 0x53, 0x1E, 0x54, 0x1F, 0x55, 0x1F, 0x55, 0x1E, 0x56, 0x1E, 0x56, 0x1E, 0x54, 0x1E, 0x53, 0x1E, 0x53, 0x1E, 0x54, 0x1D, 0x51, 0x1D, 0x4D, 0x1C, 0x47, 0x1B, 0x40, 0x1A, 0x38, 0x19, 0x3A, 0x19, 0x43, 0x1B, 0x44, 0x1B, 0x3F, 0x19, 0x31, 0x16, 0x24, 0x13, 0x1C, 0x11, 0x19, 0x10, 0x18, 0x0F, 0x16, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x14, 0x0F, 0x14, 0x0F, 0x15, 0x0F, 0x14, 0x0E, 0x14, 0x0F, 0x14, 0x0F, 0x14, 0x0F, 0x14, 0x0F, 0x14, 0x0F, 0x15, 0x0F, 0x14, 0x0F, 0x15, 0x0F, 0x14, 0x0F, 0x14, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x10, 0x15, 0x10, 0x16, 0x10, 0x16, 0x0F, 0x15, 0x0F, 0x16, 0x10, 0x15, 0x10, 0x16, 0x10, 0x16, 0x10, 0x17, 0x11, 0x17, 0x11, 0x18, 0x11, 0x1A, 0x15, 0x20, 0x19, 0x25, 0x1B, 0x27, 0x1C, 0x29, 0x1D, 0x28, 0x1D, 0x29, 0x1E, 0x29, 0x1D, 0x26, 0x1B, 0x21, 0x18, 0x1B, 0x13, 0x1A, 0x12, 0x1B, 0x14, 0x1E, 0x16, 0x32, 0x23, 0x5A, 0x37, 0x79, 0x43, 0x86, 0x48, 0x8E, 0x4C, 0x8E, 0x4A, 0x83, 0x44, 0x67, 0x35, 0x43, 0x24, 0x2E, 0x1B, 0x25, 0x17, 0x20, 0x15, 0x1D, 0x13, 0x1A, 0x12, 0x19, 0x13, 0x18, 0x11, 0x19, 0x12, 0x19, 0x12, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x19, 0x12, 0x19, 0x12, 0x18, 0x12, 0x18, 0x11, 0x17, 0x11, 0x18, 0x11, 0x17, 0x11, 0x17, 0x10, 0x17, 0x10, 0x17, 0x11, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x17, 0x11, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x15, 0x0F, 0x15, 0x0F, 0x16, 0x10, 0x16, 0x0F, 0x15, 0x0F, 0x16, 0x0F, 0x16, 0x0F, 0x16, 0x10, 0x16, 0x10, 0x17, 0x11, 0x18, 0x12, 0x1E, 0x14, 0x26, 0x17, 0x44, 0x1D, 0x54, 0x20, 0x56, 0x21, 0x51, 0x1F, 0x3C, 0x1A, 0x38, 0x1B, 0x4A, 0x1F, 0x57, 0x21, 0x5F, 0x23, 0x61, 0x23, 0x61, 0x23, 0x60, 0x22, 0x5F, 0x21, 0x60, 0x23, 0x60, 0x23, 0x60, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x5E, 0x22, 0x5C, 0x21, 0x5E, 0x21, 0x5D, 0x21, 0x5D, 0x20, 0x5C, 0x21, 0x5D, 0x21, 0x5F, 0x22, 0x5F, 0x23, 0x61, 0x22, 0x60, 0x22, 0x5E, 0x22, 0x5F, 0x22, 0x60, 0x22, 0x5F, 0x21, 0x5F, 0x22, 0x60, 0x22, 0x61, 0x24, 0x61, 0x23, 0x60, 0x23, 0x60, 0x22, 0x62, 0x23, 0x60, 0x22, 0x5E, 0x21, 0x5B, 0x21, 0x5E, 0x22, 0x5C, 0x21, 0x5E, 0x22, 0x5E, 0x20, 0x5E, 0x21, 0x5E, 0x21, 0x5E, 0x22, 0x5F, 0x21, 0x5C, 0x21, 0x5E, 0x22, 0x5D, 0x22, 0x60, 0x23, 0x61, 0x23, 0x61, 0x22, 0x62, 0x22, 0x61, 0x23, 0x60, 0x22, 0x62, 0x23, 0x60, 0x23, 0x5F, 0x22, 0x5D, 0x22, 0x5D, 0x21, 0x5D, 0x23, 0x60, 0x23, 0x61, 0x24, 0x61, 0x23, 0x62, 0x23, 0x60, 0x22, 0x60, 0x23, 0x61, 0x23, 0x62, 0x24, 0x62, 0x23, 0x5E, 0x22, 0x5F, 0x22, 0x60, 0x22, 0x5E, 0x22, 0x5E, 0x22, 0x60, 0x22, 0x5D, 0x21, 0x5E, 0x22, 0x5B, 0x21, 0x5D, 0x22, 0x5F, 0x24, 0x64, 0x25, 0x63, 0x23, 0x61, 0x23, 0x5F, 0x23, 0x61, 0x24, 0x5F, 0x23, 0x60, 0x22, 0x5E, 0x22, 0x5F, 0x23, 0x5E, 0x23, 0x5E, 0x22, 0x5F, 0x22, 0x5E, 0x22, 0x5D, 0x22, 0x5E, 0x22, 0x5F, 0x22, 0x60, 0x22, 0x5F, 0x23, 0x61, 0x23, 0x5F, 0x22, 0x5D, 0x22, 0x5F, 0x22, 0x61, 0x23, 0x62, 0x24, 0x63, 0x24, 0x5F, 0x23, 0x61, 0x24, 0x61, 0x25, 0x60, 0x23, 0x5E, 0x22, 0x5D, 0x22, 0x5B, 0x22, 0x5E, 0x21, 0x5E, 0x22, 0x61, 0x24, 0x5E, 0x22, 0x5D, 0x23, 0x5A, 0x21, 0x5B, 0x21, 0x5D, 0x22, 0x5D, 0x22, 0x5E, 0x22, 0x5A, 0x21, 0x5C, 0x21, 0x59, 0x21, 0x5C, 0x23, 0x5E, 0x23, 0x5B, 0x22, 0x57, 0x20, 0x59, 0x20, 0x55, 0x20, 0x55, 0x1F, 0x53, 0x1F, 0x52, 0x1F, 0x55, 0x20, 0x54, 0x1F, 0x54, 0x20, 0x54, 0x1F, 0x54, 0x1F, 0x55, 0x20, 0x54, 0x1E, 0x52, 0x1F, 0x3B, 0x1A, 0x2A, 0x17, 0x29, 0x19, 0x2D, 0x18, 0x26, 0x18, 0x2D, 0x1A, 0x25, 0x17, 0x2C, 0x1B, 0x29, 0x19, 0x2E, 0x1A, 0x2B, 0x19, 0x2D, 0x19, 0x2C, 0x19, 0x2B, 0x18, 0x2A, 0x18, 0x2D, 0x19, 0x26, 0x18, 0x34, 0x1C, 0x23, 0x16, 0x27, 0x18, 0x23, 0x16, 0x30, 0x1B, 0x29, 0x18, 0x26, 0x17, 0x28, 0x17, 0x27, 0x18, 0x2C, 0x18, 0x22, 0x16, 0x28, 0x18, 0x25, 0x17, 0x28, 0x17, 0x21, 0x15, 0x25, 0x16, 0x1F, 0x14, 0x26, 0x17, 0x21, 0x14, 0x24, 0x15, 0x27, 0x17, 0x29, 0x18, 0x2D, 0x19, 0x2E, 0x1A, 0x27, 0x18, 0x2A, 0x19, 0x2C, 0x18
    },

    {
        0x5A, 0x50, 0x5B, 0x4F, 0x5B, 0x51, 0x5B, 0x52, 0x5C, 0x4F, 0x5B, 0x52, 0x5D, 0x51, 0x5E, 0x52, 0x5F, 0x52, 0x5E, 0x52, 0x5C, 0x50, 0x5B, 0x50, 0x5C, 0x50, 0x5C, 0x4F, 0x59, 0x4D, 0x52, 0x47, 0x4B, 0x41, 0x43, 0x3A, 0x3A, 0x35, 0x3D, 0x3B, 0x46, 0x43, 0x48, 0x41, 0x3F, 0x38, 0x30, 0x2A, 0x21, 0x1F, 0x19, 0x1A, 0x16, 0x18, 0x14, 0x16, 0x12, 0x14, 0x11, 0x14, 0x11, 0x14, 0x10, 0x13, 0x10, 0x13, 0x10, 0x14, 0x11, 0x14, 0x10, 0x13, 0x10, 0x13, 0x10, 0x13, 0x10, 0x13, 0x10, 0x12, 0x10, 0x13, 0x10, 0x13, 0x10, 0x13, 0x10, 0x13, 0x11, 0x13, 0x11, 0x14, 0x10, 0x14, 0x11, 0x14, 0x10, 0x14, 0x11, 0x14, 0x11, 0x14, 0x11, 0x14, 0x11, 0x15, 0x11, 0x15, 0x11, 0x14, 0x11, 0x15, 0x11, 0x14, 0x12, 0x15, 0x11, 0x15, 0x12, 0x16, 0x12, 0x16, 0x13, 0x16, 0x16, 0x19, 0x1E, 0x1F, 0x26, 0x24, 0x2B, 0x26, 0x2D, 0x27, 0x2E, 0x27, 0x2E, 0x28, 0x2C, 0x26, 0x28, 0x23, 0x20, 0x1D, 0x18, 0x19, 0x16, 0x18, 0x17, 0x19, 0x19, 0x1C, 0x22, 0x2B, 0x3E, 0x51, 0x59, 0x70, 0x68, 0x7E, 0x6D, 0x84, 0x6D, 0x82, 0x63, 0x73, 0x4E, 0x55, 0x33, 0x35, 0x23, 0x27, 0x1E, 0x21, 0x1A, 0x1D, 0x17, 0x1B, 0x15, 0x19, 0x13, 0x17, 0x13, 0x17, 0x13, 0x18, 0x14, 0x18, 0x13, 0x17, 0x12, 0x16, 0x14, 0x17, 0x14, 0x18, 0x14, 0x18, 0x14, 0x17, 0x13, 0x17, 0x13, 0x16, 0x13, 0x17, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x15, 0x11, 0x15, 0x11, 0x15, 0x12, 0x16, 0x12, 0x14, 0x12, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x14, 0x12, 0x14, 0x12, 0x15, 0x12, 0x15, 0x12, 0x14, 0x12, 0x15, 0x12, 0x15, 0x12, 0x15, 0x13, 0x16, 0x14, 0x17, 0x17, 0x1A, 0x1F, 0x22, 0x39, 0x3C, 0x51, 0x4F, 0x58, 0x52, 0x56, 0x4F, 0x42, 0x3B, 0x34, 0x32, 0x48, 0x47, 0x58, 0x52, 0x61, 0x59, 0x66, 0x5C, 0x67, 0x5D, 0x68, 0x5D, 0x68, 0x5B, 0x68, 0x5D, 0x68, 0x5B, 0x69, 0x5C, 0x68, 0x5C, 0x67, 0x5A, 0x67, 0x5A, 0x65, 0x58, 0x66, 0x59, 0x67, 0x59, 0x66, 0x58, 0x65, 0x59, 0x64, 0x59, 0x67, 0x5A, 0x68, 0x5C, 0x6B, 0x5C, 0x6A, 0x5C, 0x69, 0x5B, 0x69, 0x5A, 0x69, 0x5B, 0x67, 0x59, 0x68, 0x5C, 0x67, 0x5C, 0x67, 0x5D, 0x68, 0x5C, 0x69, 0x5C, 0x67, 0x5A, 0x6A, 0x5D, 0x68, 0x5B, 0x65, 0x5A, 0x62, 0x56, 0x67, 0x59, 0x65, 0x57, 0x66, 0x5B, 0x67, 0x5B, 0x67, 0x5A, 0x67, 0x5A, 0x66, 0x5B, 0x68, 0x59, 0x62, 0x57, 0x66, 0x5A, 0x67, 0x5B, 0x69, 0x5B, 0x6B, 0x5E, 0x6C, 0x5D, 0x6C, 0x5D, 0x6C, 0x5C, 0x6B, 0x5D, 0x6B, 0x5D, 0x6A, 0x5D, 0x69, 0x5C, 0x68, 0x5A, 0x66, 0x58, 0x66, 0x5A, 0x68, 0x5D, 0x6A, 0x5E, 0x6A, 0x5D, 0x6B, 0x5C, 0x68, 0x5D, 0x68, 0x5C, 0x69, 0x5E, 0x6A, 0x5D, 0x69, 0x5B, 0x68, 0x5B, 0x68, 0x5A, 0x69, 0x5B, 0x68, 0x5B, 0x68, 0x5B, 0x69, 0x5C, 0x65, 0x5A, 0x67, 0x5A, 0x65, 0x58, 0x66, 0x5A, 0x68, 0x5C, 0x6C, 0x5E, 0x6C, 0x5E, 0x69, 0x5C, 0x68, 0x5C, 0x6A, 0x5E, 0x66, 0x5B, 0x68, 0x5B, 0x66, 0x59, 0x67, 0x5A, 0x65, 0x5A, 0x66, 0x5A, 0x67, 0x5B, 0x66, 0x5A, 0x65, 0x59, 0x67, 0x5A, 0x68, 0x5A, 0x68, 0x5B, 0x68, 0x5B, 0x69, 0x5C, 0x6A, 0x5C, 0x68, 0x5A, 0x69, 0x5C, 0x69, 0x5C, 0x6C, 0x5E, 0x6C, 0x5E, 0x67, 0x5B, 0x69, 0x5D, 0x69, 0x5D, 0x69, 0x5C, 0x66, 0x5A, 0x66, 0x5A, 0x67, 0x5A, 0x66, 0x59, 0x66, 0x5B, 0x6A, 0x5E, 0x65, 0x59, 0x66, 0x5A, 0x64, 0x58, 0x62, 0x57, 0x64, 0x58, 0x66, 0x5B, 0x66, 0x5B, 0x63, 0x57, 0x65, 0x57, 0x62, 0x56, 0x64, 0x58, 0x65, 0x5A, 0x63, 0x57, 0x60, 0x54, 0x61, 0x55, 0x5E, 0x53, 0x5D, 0x52, 0x5A, 0x4F, 0x5B, 0x4F, 0x5E, 0x53, 0x5E, 0x53, 0x5D, 0x51, 0x5A, 0x50, 0x5B, 0x50, 0x5C, 0x52, 0x5C, 0x50, 0x58, 0x4D, 0x3B, 0x33, 0x28, 0x25, 0x28, 0x2A, 0x26, 0x27, 0x24, 0x29, 0x26, 0x29, 0x22, 0x24, 0x28, 0x2E, 0x26, 0x29, 0x28, 0x2C, 0x25, 0x27, 0x24, 0x2A, 0x28, 0x2C, 0x24, 0x28, 0x25, 0x28, 0x26, 0x28, 0x24, 0x29, 0x2C, 0x2E, 0x20, 0x21, 0x24, 0x26, 0x20, 0x23, 0x29, 0x2D, 0x22, 0x23, 0x23, 0x29, 0x22, 0x22, 0x23, 0x29, 0x23, 0x25, 0x1F, 0x23, 0x23, 0x25, 0x22, 0x26, 0x22, 0x21, 0x1E, 0x20, 0x20, 0x22, 0x1D, 0x20, 0x22, 0x25, 0x21, 0x22, 0x22, 0x26, 0x24, 0x27, 0x24, 0x29, 0x28, 0x2C, 0x28, 0x2A, 0x25, 0x29, 0x25, 0x2A, 0x25, 0x26
    },

    {
        0x52, 0x1E, 0x53, 0x1E, 0x54, 0x1E, 0x55, 0x1E, 0x54, 0x1E, 0x55, 0x1F, 0x55, 0x1F, 0x55, 0x1E, 0x55, 0x1E, 0x54, 0x1E, 0x52, 0x1E, 0x52, 0x1D, 0x52, 0x1E, 0x52, 0x1E, 0x4E, 0x1C, 0x48, 0x1C, 0x40, 0x1A, 0x38, 0x19, 0x39, 0x19, 0x43, 0x1A, 0x45, 0x1B, 0x40, 0x1A, 0x33, 0x16, 0x25, 0x13, 0x1D, 0x10, 0x1A, 0x10, 0x18, 0x10, 0x16, 0x0F, 0x16, 0x0F, 0x15, 0x0F, 0x14, 0x0E, 0x15, 0x0F, 0x14, 0x0F, 0x15, 0x0E, 0x15, 0x0F, 0x14, 0x0F, 0x14, 0x0F, 0x14, 0x0F, 0x14, 0x0E, 0x14, 0x0E, 0x14, 0x0E, 0x14, 0x0F, 0x15, 0x0F, 0x14, 0x0F, 0x14, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x14, 0x0F, 0x14, 0x0F, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x10, 0x15, 0x10, 0x16, 0x10, 0x17, 0x11, 0x16, 0x10, 0x17, 0x10, 0x17, 0x11, 0x18, 0x12, 0x1B, 0x14, 0x21, 0x19, 0x25, 0x1B, 0x28, 0x1E, 0x28, 0x1D, 0x28, 0x1D, 0x25, 0x1B, 0x21, 0x17, 0x1C, 0x14, 0x19, 0x12, 0x19, 0x12, 0x19, 0x12, 0x1B, 0x13, 0x1F, 0x16, 0x2E, 0x21, 0x55, 0x34, 0x77, 0x43, 0x82, 0x46, 0x7F, 0x42, 0x69, 0x36, 0x45, 0x26, 0x30, 0x1D, 0x28, 0x19, 0x22, 0x16, 0x1E, 0x14, 0x1B, 0x13, 0x1A, 0x12, 0x19, 0x12, 0x18, 0x12, 0x19, 0x12, 0x1A, 0x12, 0x18, 0x11, 0x18, 0x11, 0x18, 0x12, 0x19, 0x12, 0x19, 0x12, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x17, 0x10, 0x16, 0x10, 0x17, 0x10, 0x17, 0x10, 0x16, 0x10, 0x16, 0x10, 0x17, 0x10, 0x16, 0x10, 0x16, 0x0F, 0x15, 0x0F, 0x16, 0x10, 0x15, 0x0F, 0x15, 0x10, 0x16, 0x0F, 0x16, 0x0F, 0x17, 0x10, 0x16, 0x0F, 0x15, 0x0F, 0x16, 0x0F, 0x16, 0x0F, 0x16, 0x10, 0x17, 0x10, 0x18, 0x11, 0x1B, 0x12, 0x24, 0x16, 0x3F, 0x1C, 0x52, 0x20, 0x56, 0x21, 0x56, 0x21, 0x3D, 0x1A, 0x36, 0x1B, 0x49, 0x1F, 0x57, 0x21, 0x5E, 0x23, 0x5F, 0x23, 0x60, 0x22, 0x5F, 0x22, 0x5E, 0x21, 0x5F, 0x22, 0x60, 0x23, 0x5F, 0x22, 0x5D, 0x22, 0x5D, 0x22, 0x5D, 0x21, 0x5E, 0x21, 0x5E, 0x21, 0x5F, 0x21, 0x61, 0x22, 0x5F, 0x23, 0x5F, 0x22, 0x61, 0x22, 0x60, 0x21, 0x60, 0x22, 0x5F, 0x21, 0x60, 0x22, 0x60, 0x22, 0x5E, 0x21, 0x5F, 0x22, 0x60, 0x23, 0x61, 0x22, 0x5F, 0x23, 0x60, 0x23, 0x60, 0x22, 0x61, 0x23, 0x62, 0x23, 0x5F, 0x21, 0x5C, 0x21, 0x5C, 0x20, 0x5E, 0x20, 0x5F, 0x21, 0x5F, 0x21, 0x5E, 0x21, 0x5E, 0x20, 0x5D, 0x20, 0x5D, 0x21, 0x5B, 0x21, 0x5F, 0x22, 0x5F, 0x22, 0x62, 0x22, 0x61, 0x22, 0x5F, 0x22, 0x62, 0x22, 0x60, 0x22, 0x60, 0x22, 0x61, 0x22, 0x63, 0x23, 0x63, 0x23, 0x61, 0x22, 0x61, 0x23, 0x60, 0x22, 0x61, 0x23, 0x62, 0x24, 0x61, 0x23, 0x62, 0x23, 0x61, 0x23, 0x62, 0x22, 0x60, 0x23, 0x60, 0x22, 0x60, 0x23, 0x60, 0x22, 0x61, 0x22, 0x5E, 0x22, 0x5F, 0x22, 0x5E, 0x21, 0x61, 0x22, 0x61, 0x23, 0x60, 0x22, 0x5F, 0x21, 0x5D, 0x21, 0x5F, 0x22, 0x60, 0x23, 0x61, 0x22, 0x61, 0x23, 0x5F, 0x23, 0x60, 0x23, 0x5E, 0x22, 0x5D, 0x22, 0x5C, 0x21, 0x5E, 0x22, 0x5E, 0x22, 0x5D, 0x22, 0x5E, 0x22, 0x5E, 0x22, 0x5D, 0x21, 0x5C, 0x21, 0x5E, 0x22, 0x5F, 0x22, 0x5E, 0x22, 0x5E, 0x22, 0x63, 0x24, 0x60, 0x23, 0x62, 0x23, 0x61, 0x22, 0x62, 0x24, 0x60, 0x23, 0x61, 0x23, 0x60, 0x23, 0x5E, 0x23, 0x61, 0x23, 0x5C, 0x21, 0x5C, 0x21, 0x5E, 0x23, 0x5C, 0x22, 0x63, 0x24, 0x62, 0x23, 0x5E, 0x22, 0x5D, 0x22, 0x5B, 0x21, 0x5B, 0x22, 0x5C, 0x22, 0x5E, 0x21, 0x5A, 0x21, 0x5D, 0x21, 0x59, 0x20, 0x5A, 0x22, 0x5D, 0x23, 0x5F, 0x24, 0x5A, 0x21, 0x59, 0x20, 0x57, 0x20, 0x54, 0x20, 0x53, 0x1E, 0x52, 0x1E, 0x54, 0x1F, 0x54, 0x1F, 0x56, 0x1F, 0x56, 0x20, 0x53, 0x1F, 0x53, 0x1F, 0x52, 0x1F, 0x54, 0x1F, 0x51, 0x1F, 0x39, 0x1B, 0x2B, 0x18, 0x30, 0x1B, 0x2C, 0x19, 0x2C, 0x19, 0x27, 0x17, 0x26, 0x18, 0x30, 0x1B, 0x29, 0x18, 0x26, 0x17, 0x25, 0x16, 0x29, 0x18, 0x28, 0x17, 0x20, 0x14, 0x25, 0x16, 0x24, 0x15, 0x28, 0x18, 0x25, 0x16, 0x25, 0x17, 0x2A, 0x18, 0x25, 0x16, 0x27, 0x17, 0x25, 0x16, 0x29, 0x18, 0x25, 0x16, 0x29, 0x18, 0x26, 0x16, 0x29, 0x18, 0x28, 0x16, 0x25, 0x16, 0x25, 0x17, 0x27, 0x17, 0x29, 0x17, 0x2A, 0x18, 0x29, 0x18, 0x28, 0x18, 0x2E, 0x19, 0x2B, 0x18, 0x26, 0x17, 0x24, 0x16, 0x28, 0x16, 0x2D, 0x1A, 0x29, 0x18, 0x2C, 0x19
    },

    {
        0x5A, 0x50, 0x5B, 0x51, 0x5B, 0x52, 0x5B, 0x52, 0x5C, 0x52, 0x5D, 0x53, 0x5E, 0x52, 0x5E, 0x52, 0x5E, 0x52, 0x5D, 0x51, 0x5C, 0x50, 0x5B, 0x50, 0x59, 0x4F, 0x58, 0x4E, 0x54, 0x4A, 0x4C, 0x43, 0x43, 0x3A, 0x3B, 0x36, 0x3D, 0x3C, 0x47, 0x43, 0x48, 0x43, 0x41, 0x3B, 0x32, 0x2C, 0x22, 0x20, 0x1A, 0x1A, 0x16, 0x18, 0x15, 0x16, 0x12, 0x15, 0x12, 0x14, 0x11, 0x14, 0x11, 0x15, 0x10, 0x14, 0x10, 0x14, 0x10, 0x14, 0x11, 0x14, 0x10, 0x13, 0x10, 0x13, 0x10, 0x13, 0x10, 0x13, 0x10, 0x13, 0x10, 0x13, 0x10, 0x13, 0x10, 0x14, 0x10, 0x13, 0x10, 0x13, 0x10, 0x14, 0x10, 0x14, 0x11, 0x14, 0x11, 0x14, 0x11, 0x14, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x10, 0x14, 0x10, 0x14, 0x11, 0x15, 0x12, 0x15, 0x12, 0x16, 0x12, 0x15, 0x12, 0x16, 0x12, 0x16, 0x13, 0x17, 0x17, 0x19, 0x1E, 0x1F, 0x26, 0x24, 0x2B, 0x26, 0x2C, 0x27, 0x2B, 0x25, 0x27, 0x22, 0x20, 0x1D, 0x19, 0x19, 0x16, 0x18, 0x16, 0x18, 0x15, 0x19, 0x16, 0x19, 0x18, 0x1C, 0x20, 0x28, 0x3A, 0x4E, 0x57, 0x6E, 0x63, 0x78, 0x5F, 0x70, 0x4F, 0x57, 0x33, 0x36, 0x25, 0x2A, 0x1F, 0x24, 0x1A, 0x1F, 0x18, 0x1C, 0x16, 0x1A, 0x14, 0x18, 0x14, 0x18, 0x13, 0x17, 0x13, 0x18, 0x14, 0x18, 0x13, 0x17, 0x13, 0x16, 0x13, 0x18, 0x14, 0x18, 0x13, 0x17, 0x13, 0x17, 0x14, 0x18, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x15, 0x12, 0x15, 0x11, 0x15, 0x12, 0x16, 0x12, 0x15, 0x12, 0x15, 0x11, 0x14, 0x12, 0x15, 0x11, 0x15, 0x11, 0x14, 0x11, 0x14, 0x12, 0x15, 0x12, 0x15, 0x12, 0x15, 0x11, 0x14, 0x12, 0x15, 0x12, 0x15, 0x12, 0x16, 0x12, 0x16, 0x13, 0x17, 0x15, 0x19, 0x1C, 0x1F, 0x35, 0x39, 0x4F, 0x4D, 0x58, 0x53, 0x59, 0x52, 0x43, 0x3D, 0x35, 0x32, 0x46, 0x44, 0x59, 0x53, 0x62, 0x58, 0x65, 0x5B, 0x67, 0x5A, 0x67, 0x5A, 0x66, 0x5A, 0x68, 0x5A, 0x69, 0x5C, 0x67, 0x5A, 0x66, 0x58, 0x66, 0x59, 0x66, 0x5B, 0x68, 0x5A, 0x68, 0x59, 0x69, 0x5B, 0x6A, 0x5C, 0x67, 0x5B, 0x67, 0x5A, 0x68, 0x5C, 0x69, 0x5B, 0x6B, 0x5C, 0x6A, 0x5A, 0x68, 0x5B, 0x6A, 0x5C, 0x68, 0x5A, 0x68, 0x5B, 0x67, 0x5C, 0x68, 0x5C, 0x68, 0x5A, 0x68, 0x5C, 0x69, 0x5C, 0x6A, 0x5F, 0x6A, 0x5E, 0x68, 0x5B, 0x66, 0x58, 0x64, 0x57, 0x67, 0x5A, 0x67, 0x59, 0x67, 0x5B, 0x67, 0x58, 0x67, 0x59, 0x67, 0x59, 0x65, 0x59, 0x64, 0x57, 0x68, 0x5B, 0x68, 0x5A, 0x6C, 0x5E, 0x69, 0x5A, 0x69, 0x5B, 0x6C, 0x5D, 0x6A, 0x5D, 0x6A, 0x5C, 0x6B, 0x5C, 0x6D, 0x5F, 0x6B, 0x5E, 0x6A, 0x5D, 0x69, 0x5E, 0x68, 0x5B, 0x6A, 0x5E, 0x6B, 0x5E, 0x6B, 0x5D, 0x6B, 0x5D, 0x6B, 0x5F, 0x6B, 0x5E, 0x6A, 0x5D, 0x68, 0x5B, 0x69, 0x5C, 0x6A, 0x5C, 0x6C, 0x5D, 0x69, 0x5C, 0x68, 0x5C, 0x67, 0x5A, 0x69, 0x5C, 0x6A, 0x5E, 0x69, 0x5B, 0x68, 0x5B, 0x66, 0x5A, 0x69, 0x5C, 0x69, 0x5C, 0x6B, 0x5D, 0x6A, 0x5C, 0x69, 0x5C, 0x6A, 0x5C, 0x66, 0x5A, 0x65, 0x58, 0x65, 0x59, 0x68, 0x5B, 0x67, 0x5A, 0x64, 0x59, 0x68, 0x5B, 0x6A, 0x5B, 0x66, 0x58, 0x64, 0x59, 0x66, 0x5B, 0x67, 0x5A, 0x66, 0x5B, 0x67, 0x5A, 0x6C, 0x60, 0x69, 0x5C, 0x6B, 0x5D, 0x69, 0x5D, 0x6A, 0x5E, 0x68, 0x5D, 0x6A, 0x5D, 0x6A, 0x5C, 0x67, 0x5D, 0x69, 0x5D, 0x64, 0x57, 0x64, 0x59, 0x65, 0x59, 0x65, 0x59, 0x69, 0x5F, 0x69, 0x5D, 0x65, 0x5B, 0x66, 0x59, 0x63, 0x58, 0x61, 0x58, 0x64, 0x58, 0x65, 0x59, 0x63, 0x57, 0x66, 0x5A, 0x62, 0x57, 0x62, 0x58, 0x66, 0x5B, 0x66, 0x5B, 0x62, 0x55, 0x5D, 0x53, 0x5E, 0x52, 0x5D, 0x51, 0x5D, 0x51, 0x5B, 0x50, 0x5B, 0x51, 0x5B, 0x51, 0x5D, 0x51, 0x5D, 0x51, 0x5B, 0x50, 0x5D, 0x51, 0x59, 0x4E, 0x5C, 0x52, 0x57, 0x4D, 0x3B, 0x37, 0x2C, 0x2A, 0x2B, 0x2F, 0x27, 0x29, 0x25, 0x26, 0x24, 0x25, 0x23, 0x25, 0x29, 0x2E, 0x23, 0x24, 0x23, 0x26, 0x22, 0x24, 0x25, 0x2A, 0x22, 0x24, 0x1E, 0x20, 0x23, 0x27, 0x21, 0x22, 0x25, 0x2A, 0x22, 0x23, 0x24, 0x28, 0x27, 0x2A, 0x23, 0x26, 0x23, 0x26, 0x23, 0x26, 0x26, 0x29, 0x22, 0x25, 0x24, 0x28, 0x22, 0x25, 0x26, 0x2A, 0x25, 0x27, 0x23, 0x25, 0x23, 0x27, 0x25, 0x27, 0x25, 0x28, 0x27, 0x2B, 0x25, 0x26, 0x25, 0x29, 0x29, 0x2D, 0x26, 0x28, 0x23, 0x24, 0x20, 0x25, 0x23, 0x26, 0x28, 0x2C, 0x24, 0x28, 0x28, 0x2B
    },

    {
        0x52, 0x1E, 0x53, 0x1E, 0x54, 0x1E, 0x55, 0x1E, 0x55, 0x1F, 0x55, 0x1E, 0x56, 0x1E, 0x54, 0x1E, 0x55, 0x1E, 0x54, 0x1E, 0x54, 0x1E, 0x52, 0x1E, 0x52, 0x1E, 0x4E, 0x1D, 0x48, 0x1B, 0x42, 0x1A, 0x3A, 0x19, 0x3A, 0x19, 0x43, 0x1B, 0x47, 0x1B, 0x41, 0x1A, 0x36, 0x17, 0x27, 0x14, 0x1D, 0x11, 0x1A, 0x10, 0x18, 0x10, 0x17, 0x10, 0x16, 0x0F, 0x16, 0x0F, 0x15, 0x0F, 0x17, 0x0F, 0x15, 0x0F, 0x14, 0x0F, 0x14, 0x0E, 0x15, 0x0F, 0x14, 0x0E, 0x15, 0x0F, 0x14, 0x0E, 0x14, 0x0F, 0x14, 0x0F, 0x14, 0x0F, 0x14, 0x0F, 0x15, 0x10, 0x14, 0x0F, 0x14, 0x0F, 0x14, 0x0F, 0x14, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x10, 0x15, 0x0F, 0x15, 0x10, 0x16, 0x0F, 0x15, 0x10, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x10, 0x16, 0x10, 0x17, 0x11, 0x17, 0x10, 0x17, 0x10, 0x17, 0x11, 0x17, 0x11, 0x18, 0x11, 0x1A, 0x13, 0x20, 0x18, 0x25, 0x1B, 0x28, 0x1D, 0x25, 0x1B, 0x22, 0x17, 0x1D, 0x14, 0x1A, 0x12, 0x19, 0x12, 0x18, 0x12, 0x19, 0x12, 0x19, 0x12, 0x1B, 0x13, 0x1E, 0x15, 0x2C, 0x1F, 0x53, 0x34, 0x6E, 0x3D, 0x64, 0x34, 0x45, 0x25, 0x2E, 0x1B, 0x29, 0x1A, 0x28, 0x1A, 0x23, 0x16, 0x1D, 0x14, 0x1B, 0x12, 0x19, 0x12, 0x19, 0x12, 0x19, 0x12, 0x19, 0x12, 0x1A, 0x12, 0x19, 0x12, 0x19, 0x11, 0x19, 0x12, 0x19, 0x12, 0x19, 0x12, 0x18, 0x11, 0x19, 0x12, 0x19, 0x12, 0x19, 0x11, 0x19, 0x11, 0x17, 0x11, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x0F, 0x16, 0x10, 0x16, 0x0F, 0x16, 0x0F, 0x16, 0x0F, 0x16, 0x0F, 0x15, 0x0F, 0x15, 0x0E, 0x16, 0x0F, 0x16, 0x0F, 0x16, 0x0F, 0x16, 0x10, 0x16, 0x0F, 0x17, 0x10, 0x17, 0x10, 0x18, 0x10, 0x18, 0x11, 0x1A, 0x12, 0x20, 0x15, 0x3D, 0x1C, 0x51, 0x20, 0x59, 0x22, 0x56, 0x20, 0x3F, 0x1A, 0x33, 0x19, 0x48, 0x1E, 0x55, 0x20, 0x59, 0x21, 0x5D, 0x21, 0x5E, 0x21, 0x5C, 0x21, 0x5D, 0x21, 0x60, 0x23, 0x60, 0x22, 0x5E, 0x22, 0x5F, 0x21, 0x5D, 0x21, 0x5D, 0x20, 0x5E, 0x21, 0x5E, 0x22, 0x63, 0x23, 0x62, 0x22, 0x5F, 0x21, 0x5E, 0x21, 0x60, 0x21, 0x61, 0x22, 0x5F, 0x21, 0x5D, 0x21, 0x5F, 0x21, 0x5E, 0x21, 0x60, 0x22, 0x5F, 0x22, 0x62, 0x22, 0x5F, 0x21, 0x5E, 0x21, 0x5F, 0x22, 0x62, 0x23, 0x64, 0x23, 0x5F, 0x21, 0x5F, 0x21, 0x5C, 0x20, 0x5C, 0x21, 0x5C, 0x20, 0x5F, 0x21, 0x5D, 0x21, 0x5F, 0x21, 0x5F, 0x21, 0x5F, 0x22, 0x5C, 0x20, 0x5E, 0x21, 0x5E, 0x21, 0x61, 0x22, 0x60, 0x22, 0x60, 0x22, 0x62, 0x22, 0x60, 0x22, 0x61, 0x22, 0x60, 0x22, 0x62, 0x22, 0x64, 0x23, 0x60, 0x22, 0x5E, 0x22, 0x60, 0x23, 0x63, 0x24, 0x61, 0x23, 0x61, 0x23, 0x61, 0x22, 0x62, 0x22, 0x60, 0x22, 0x62, 0x23, 0x5F, 0x22, 0x61, 0x22, 0x60, 0x22, 0x61, 0x22, 0x62, 0x23, 0x61, 0x22, 0x61, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x5E, 0x22, 0x5D, 0x21, 0x5F, 0x22, 0x61, 0x23, 0x62, 0x23, 0x62, 0x23, 0x60, 0x22, 0x60, 0x23, 0x60, 0x23, 0x61, 0x23, 0x5D, 0x22, 0x5E, 0x22, 0x60, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x5E, 0x22, 0x5F, 0x22, 0x5E, 0x21, 0x5C, 0x21, 0x5B, 0x22, 0x5F, 0x22, 0x5D, 0x21, 0x5E, 0x21, 0x5F, 0x24, 0x5F, 0x23, 0x5D, 0x22, 0x5F, 0x23, 0x60, 0x23, 0x62, 0x23, 0x61, 0x23, 0x60, 0x21, 0x5F, 0x21, 0x5F, 0x23, 0x5E, 0x22, 0x5C, 0x22, 0x5E, 0x21, 0x5C, 0x21, 0x5F, 0x23, 0x5E, 0x22, 0x5E, 0x22, 0x5E, 0x22, 0x62, 0x25, 0x5B, 0x21, 0x5A, 0x21, 0x5B, 0x21, 0x5B, 0x20, 0x5C, 0x21, 0x5B, 0x21, 0x5C, 0x21, 0x5B, 0x22, 0x5B, 0x21, 0x5A, 0x21, 0x57, 0x1F, 0x53, 0x1F, 0x54, 0x1E, 0x56, 0x20, 0x58, 0x20, 0x55, 0x1F, 0x54, 0x1F, 0x53, 0x1F, 0x53, 0x1E, 0x54, 0x1E, 0x53, 0x1E, 0x52, 0x1E, 0x55, 0x1F, 0x51, 0x1F, 0x3C, 0x1B, 0x2C, 0x19, 0x2C, 0x18, 0x27, 0x16, 0x23, 0x16, 0x2C, 0x19, 0x2B, 0x18, 0x26, 0x16, 0x27, 0x17, 0x2D, 0x19, 0x2E, 0x19, 0x27, 0x17, 0x29, 0x18, 0x2D, 0x19, 0x2F, 0x1A, 0x2C, 0x19, 0x30, 0x1A, 0x2C, 0x1A, 0x33, 0x1C, 0x32, 0x1B, 0x2B, 0x18, 0x26, 0x17, 0x2E, 0x19, 0x30, 0x1A, 0x32, 0x1B, 0x28, 0x16, 0x30, 0x1A, 0x2D, 0x19, 0x27, 0x17, 0x2A, 0x17, 0x2D, 0x1A, 0x2A, 0x17, 0x25, 0x16, 0x2A, 0x17, 0x27, 0x17, 0x30, 0x19, 0x26, 0x16, 0x25, 0x16, 0x23, 0x15, 0x28, 0x17, 0x26, 0x16, 0x24, 0x16, 0x24, 0x16, 0x2B, 0x18
    },

    {
        0x5A, 0x50, 0x5A, 0x51, 0x5C, 0x52, 0x5C, 0x53, 0x5B, 0x52, 0x5C, 0x53, 0x5E, 0x53, 0x5E, 0x53, 0x5D, 0x52, 0x5C, 0x51, 0x5C, 0x51, 0x5A, 0x50, 0x57, 0x4E, 0x54, 0x4A, 0x4D, 0x44, 0x45, 0x3C, 0x3B, 0x36, 0x3C, 0x3A, 0x47, 0x44, 0x4A, 0x44, 0x42, 0x3C, 0x34, 0x2E, 0x23, 0x22, 0x1A, 0x1B, 0x17, 0x18, 0x14, 0x17, 0x13, 0x17, 0x12, 0x16, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x14, 0x10, 0x14, 0x10, 0x14, 0x10, 0x14, 0x11, 0x13, 0x10, 0x14, 0x10, 0x13, 0x10, 0x14, 0x10, 0x14, 0x10, 0x14, 0x10, 0x14, 0x10, 0x14, 0x10, 0x13, 0x10, 0x14, 0x10, 0x13, 0x10, 0x14, 0x10, 0x15, 0x10, 0x15, 0x10, 0x14, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x10, 0x14, 0x10, 0x14, 0x10, 0x15, 0x11, 0x15, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x13, 0x17, 0x14, 0x17, 0x15, 0x18, 0x1D, 0x1E, 0x25, 0x24, 0x29, 0x26, 0x27, 0x23, 0x21, 0x1F, 0x1A, 0x1B, 0x16, 0x18, 0x15, 0x18, 0x14, 0x18, 0x15, 0x17, 0x14, 0x18, 0x15, 0x19, 0x18, 0x1C, 0x1F, 0x28, 0x37, 0x4A, 0x4F, 0x61, 0x4B, 0x53, 0x34, 0x36, 0x24, 0x28, 0x1F, 0x24, 0x1F, 0x26, 0x1B, 0x1F, 0x17, 0x1B, 0x15, 0x19, 0x14, 0x19, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x13, 0x17, 0x13, 0x18, 0x14, 0x19, 0x14, 0x19, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x12, 0x16, 0x11, 0x15, 0x12, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x12, 0x16, 0x12, 0x15, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x13, 0x17, 0x15, 0x18, 0x1A, 0x1E, 0x33, 0x38, 0x4C, 0x4E, 0x59, 0x54, 0x59, 0x53, 0x45, 0x3E, 0x35, 0x31, 0x45, 0x42, 0x57, 0x52, 0x5D, 0x55, 0x62, 0x59, 0x64, 0x5A, 0x64, 0x58, 0x64, 0x59, 0x67, 0x5C, 0x68, 0x5C, 0x65, 0x5A, 0x66, 0x5A, 0x66, 0x59, 0x66, 0x5A, 0x69, 0x5A, 0x68, 0x5B, 0x6C, 0x5F, 0x6C, 0x5E, 0x68, 0x5B, 0x66, 0x5A, 0x69, 0x5C, 0x6B, 0x5D, 0x69, 0x5A, 0x66, 0x59, 0x67, 0x5A, 0x68, 0x5A, 0x69, 0x5C, 0x68, 0x5C, 0x6B, 0x5E, 0x69, 0x5B, 0x68, 0x5B, 0x69, 0x5C, 0x6A, 0x5E, 0x6C, 0x5F, 0x68, 0x5B, 0x67, 0x5A, 0x65, 0x58, 0x65, 0x5A, 0x64, 0x59, 0x67, 0x5C, 0x66, 0x5A, 0x67, 0x5C, 0x6A, 0x5C, 0x69, 0x5B, 0x66, 0x58, 0x67, 0x5B, 0x67, 0x5A, 0x69, 0x5D, 0x69, 0x5B, 0x6A, 0x5D, 0x6B, 0x5E, 0x6A, 0x5D, 0x6A, 0x5E, 0x6A, 0x5C, 0x6B, 0x5E, 0x6B, 0x5F, 0x6A, 0x5B, 0x67, 0x5C, 0x69, 0x5E, 0x6C, 0x60, 0x6A, 0x5D, 0x6A, 0x5D, 0x69, 0x5D, 0x69, 0x5D, 0x6A, 0x5D, 0x6A, 0x5E, 0x68, 0x5B, 0x6A, 0x5E, 0x69, 0x5C, 0x6B, 0x5C, 0x6B, 0x5E, 0x6B, 0x5D, 0x6B, 0x5E, 0x68, 0x5B, 0x68, 0x5C, 0x67, 0x5B, 0x69, 0x5B, 0x68, 0x5C, 0x6B, 0x5E, 0x6B, 0x5E, 0x6C, 0x5E, 0x69, 0x5B, 0x68, 0x5C, 0x68, 0x5C, 0x6A, 0x5C, 0x66, 0x5B, 0x66, 0x5B, 0x67, 0x5C, 0x67, 0x5C, 0x68, 0x5B, 0x68, 0x5D, 0x68, 0x5A, 0x65, 0x59, 0x64, 0x59, 0x65, 0x59, 0x66, 0x5A, 0x67, 0x5A, 0x66, 0x5A, 0x67, 0x5C, 0x69, 0x5C, 0x66, 0x5A, 0x6A, 0x5C, 0x6A, 0x5E, 0x6B, 0x5E, 0x6C, 0x5E, 0x69, 0x5A, 0x67, 0x5C, 0x68, 0x5B, 0x69, 0x5C, 0x63, 0x5A, 0x66, 0x58, 0x63, 0x58, 0x66, 0x5A, 0x64, 0x59, 0x66, 0x5B, 0x66, 0x5B, 0x67, 0x5E, 0x61, 0x56, 0x61, 0x58, 0x62, 0x56, 0x62, 0x57, 0x64, 0x58, 0x64, 0x58, 0x64, 0x58, 0x63, 0x58, 0x62, 0x58, 0x62, 0x57, 0x5C, 0x53, 0x5B, 0x51, 0x5D, 0x51, 0x5F, 0x54, 0x5F, 0x53, 0x5C, 0x50, 0x5B, 0x51, 0x5C, 0x52, 0x5C, 0x50, 0x5C, 0x51, 0x5A, 0x4F, 0x59, 0x4F, 0x5B, 0x52, 0x56, 0x4C, 0x39, 0x34, 0x2A, 0x2A, 0x28, 0x28, 0x23, 0x24, 0x21, 0x26, 0x29, 0x2D, 0x28, 0x2B, 0x22, 0x24, 0x24, 0x29, 0x27, 0x2C, 0x29, 0x2D, 0x22, 0x24, 0x27, 0x2C, 0x28, 0x2D, 0x28, 0x2B, 0x27, 0x2B, 0x28, 0x2B, 0x29, 0x30, 0x2D, 0x31, 0x2A, 0x2D, 0x25, 0x26, 0x23, 0x25, 0x28, 0x2C, 0x29, 0x2C, 0x2A, 0x2E, 0x23, 0x24, 0x2B, 0x30, 0x27, 0x28, 0x22, 0x25, 0x26, 0x28, 0x27, 0x2C, 0x23, 0x24, 0x21, 0x25, 0x24, 0x26, 0x24, 0x28, 0x28, 0x2A, 0x21, 0x21, 0x20, 0x24, 0x1F, 0x20, 0x25, 0x29, 0x21, 0x22, 0x1F, 0x22, 0x20, 0x24, 0x25, 0x29
    },

    {
        0x53, 0x1F, 0x54, 0x1E, 0x53, 0x1E, 0x54, 0x1E, 0x55, 0x1E, 0x55, 0x1E, 0x55, 0x1E, 0x56, 0x1F, 0x54, 0x1E, 0x54, 0x1E, 0x54, 0x1E, 0x52, 0x1E, 0x50, 0x1D, 0x4B, 0x1C, 0x42, 0x1B, 0x3A, 0x19, 0x39, 0x19, 0x41, 0x1B, 0x47, 0x1C, 0x41, 0x1A, 0x36, 0x17, 0x28, 0x13, 0x1E, 0x11, 0x1A, 0x10, 0x18, 0x10, 0x16, 0x0F, 0x16, 0x10, 0x16, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x14, 0x0E, 0x14, 0x0E, 0x14, 0x0F, 0x14, 0x0F, 0x15, 0x0F, 0x14, 0x0F, 0x14, 0x0E, 0x14, 0x0F, 0x14, 0x0F, 0x13, 0x0E, 0x14, 0x0E, 0x14, 0x0E, 0x15, 0x0F, 0x14, 0x0F, 0x14, 0x0F, 0x14, 0x0F, 0x15, 0x0F, 0x14, 0x0F, 0x14, 0x0F, 0x15, 0x0F, 0x16, 0x10, 0x15, 0x0F, 0x15, 0x0F, 0x16, 0x10, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x10, 0x16, 0x10, 0x17, 0x11, 0x17, 0x10, 0x17, 0x11, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x11, 0x1A, 0x14, 0x22, 0x1A, 0x27, 0x1C, 0x24, 0x19, 0x1F, 0x16, 0x1C, 0x14, 0x1B, 0x13, 0x19, 0x12, 0x18, 0x11, 0x18, 0x11, 0x19, 0x12, 0x19, 0x12, 0x1B, 0x14, 0x21, 0x18, 0x30, 0x25, 0x4B, 0x30, 0x44, 0x28, 0x2F, 0x1E, 0x28, 0x1A, 0x24, 0x17, 0x22, 0x17, 0x1F, 0x15, 0x1C, 0x13, 0x1A, 0x12, 0x19, 0x12, 0x18, 0x11, 0x18, 0x12, 0x19, 0x12, 0x19, 0x11, 0x19, 0x12, 0x19, 0x12, 0x19, 0x12, 0x1A, 0x12, 0x1A, 0x12, 0x19, 0x12, 0x19, 0x12, 0x1A, 0x12, 0x19, 0x12, 0x18, 0x11, 0x17, 0x11, 0x17, 0x11, 0x17, 0x10, 0x17, 0x10, 0x16, 0x10, 0x17, 0x10, 0x16, 0x10, 0x16, 0x10, 0x15, 0x10, 0x15, 0x0F, 0x16, 0x10, 0x16, 0x10, 0x15, 0x0F, 0x16, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x16, 0x0F, 0x15, 0x0F, 0x16, 0x10, 0x16, 0x10, 0x17, 0x10, 0x18, 0x10, 0x17, 0x10, 0x17, 0x11, 0x18, 0x10, 0x19, 0x11, 0x21, 0x15, 0x3C, 0x1C, 0x4E, 0x1F, 0x56, 0x20, 0x56, 0x21, 0x41, 0x1B, 0x32, 0x19, 0x44, 0x1D, 0x54, 0x20, 0x57, 0x20, 0x5D, 0x21, 0x5F, 0x22, 0x5C, 0x22, 0x5E, 0x21, 0x5F, 0x23, 0x5E, 0x22, 0x5F, 0x22, 0x5D, 0x21, 0x5D, 0x21, 0x5F, 0x21, 0x5D, 0x21, 0x61, 0x23, 0x62, 0x23, 0x5F, 0x21, 0x5E, 0x21, 0x5E, 0x21, 0x5F, 0x21, 0x5E, 0x21, 0x5C, 0x21, 0x5E, 0x21, 0x5E, 0x21, 0x5D, 0x22, 0x5F, 0x23, 0x61, 0x22, 0x61, 0x22, 0x5F, 0x21, 0x5E, 0x21, 0x63, 0x23, 0x63, 0x23, 0x5F, 0x21, 0x5F, 0x22, 0x5C, 0x20, 0x5D, 0x21, 0x5C, 0x21, 0x5F, 0x21, 0x5C, 0x21, 0x60, 0x22, 0x5E, 0x22, 0x60, 0x23, 0x60, 0x22, 0x5E, 0x22, 0x60, 0x22, 0x5E, 0x22, 0x61, 0x22, 0x5F, 0x20, 0x5F, 0x21, 0x5E, 0x22, 0x60, 0x23, 0x5F, 0x22, 0x60, 0x22, 0x61, 0x22, 0x63, 0x22, 0x60, 0x22, 0x61, 0x23, 0x62, 0x24, 0x60, 0x22, 0x61, 0x23, 0x60, 0x22, 0x61, 0x23, 0x60, 0x22, 0x60, 0x23, 0x60, 0x22, 0x60, 0x23, 0x5F, 0x22, 0x61, 0x22, 0x61, 0x23, 0x60, 0x23, 0x62, 0x24, 0x61, 0x23, 0x66, 0x25, 0x62, 0x24, 0x62, 0x23, 0x62, 0x23, 0x64, 0x23, 0x63, 0x23, 0x61, 0x23, 0x61, 0x23, 0x62, 0x23, 0x60, 0x23, 0x5F, 0x22, 0x61, 0x23, 0x60, 0x22, 0x5E, 0x22, 0x5F, 0x22, 0x5C, 0x21, 0x60, 0x22, 0x5D, 0x21, 0x5B, 0x21, 0x5F, 0x22, 0x5E, 0x22, 0x5F, 0x22, 0x5E, 0x22, 0x5E, 0x22, 0x5F, 0x23, 0x5F, 0x22, 0x5D, 0x22, 0x5F, 0x22, 0x62, 0x24, 0x61, 0x23, 0x5E, 0x22, 0x5E, 0x22, 0x5E, 0x22, 0x60, 0x23, 0x5F, 0x23, 0x5E, 0x22, 0x5B, 0x21, 0x59, 0x21, 0x5C, 0x22, 0x5D, 0x22, 0x5E, 0x21, 0x5C, 0x21, 0x5B, 0x21, 0x5A, 0x20, 0x5B, 0x21, 0x59, 0x20, 0x5A, 0x21, 0x5A, 0x21, 0x5B, 0x20, 0x5C, 0x21, 0x5D, 0x21, 0x59, 0x20, 0x58, 0x21, 0x57, 0x20, 0x58, 0x21, 0x57, 0x20, 0x56, 0x20, 0x57, 0x20, 0x55, 0x20, 0x56, 0x1F, 0x56, 0x20, 0x52, 0x1E, 0x54, 0x1F, 0x50, 0x1E, 0x52, 0x1F, 0x54, 0x20, 0x4F, 0x1D, 0x3A, 0x1B, 0x33, 0x1B, 0x26, 0x16, 0x2F, 0x1A, 0x2F, 0x1A, 0x2E, 0x1A, 0x2B, 0x18, 0x28, 0x17, 0x31, 0x1B, 0x28, 0x16, 0x2C, 0x19, 0x22, 0x16, 0x2F, 0x1A, 0x28, 0x17, 0x26, 0x16, 0x26, 0x17, 0x28, 0x17, 0x2C, 0x19, 0x28, 0x18, 0x22, 0x15, 0x24, 0x15, 0x25, 0x17, 0x2D, 0x19, 0x22, 0x15, 0x28, 0x17, 0x21, 0x15, 0x2E, 0x19, 0x23, 0x15, 0x29, 0x17, 0x27, 0x16, 0x25, 0x16, 0x22, 0x14, 0x26, 0x16, 0x24, 0x15, 0x28, 0x18, 0x22, 0x15, 0x21, 0x14, 0x26, 0x17, 0x27, 0x17, 0x2C, 0x17, 0x26, 0x16, 0x2C, 0x18, 0x25, 0x16, 0x29, 0x18
    },

    {
        0x5B, 0x51, 0x5C, 0x51, 0x5B, 0x52, 0x5C, 0x52, 0x5C, 0x52, 0x5C, 0x53, 0x5D, 0x52, 0x5D, 0x52, 0x5C, 0x51, 0x5C, 0x51, 0x5B, 0x50, 0x58, 0x4F, 0x54, 0x4B, 0x4E, 0x45, 0x47, 0x3E, 0x3C, 0x36, 0x3C, 0x3A, 0x45, 0x42, 0x4A, 0x43, 0x43, 0x3C, 0x35, 0x2F, 0x24, 0x22, 0x1A, 0x1B, 0x16, 0x18, 0x14, 0x16, 0x13, 0x15, 0x12, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x14, 0x10, 0x13, 0x10, 0x13, 0x10, 0x13, 0x10, 0x13, 0x11, 0x14, 0x10, 0x13, 0x10, 0x13, 0x10, 0x13, 0x11, 0x13, 0x0F, 0x13, 0x10, 0x13, 0x0F, 0x13, 0x10, 0x13, 0x10, 0x13, 0x10, 0x13, 0x10, 0x13, 0x10, 0x14, 0x10, 0x13, 0x10, 0x13, 0x11, 0x13, 0x11, 0x15, 0x10, 0x14, 0x10, 0x15, 0x11, 0x15, 0x11, 0x14, 0x10, 0x14, 0x11, 0x15, 0x12, 0x16, 0x12, 0x16, 0x12, 0x17, 0x12, 0x16, 0x12, 0x15, 0x12, 0x16, 0x13, 0x16, 0x13, 0x17, 0x17, 0x1A, 0x1F, 0x22, 0x26, 0x26, 0x24, 0x21, 0x1C, 0x1D, 0x19, 0x1B, 0x17, 0x1A, 0x16, 0x18, 0x14, 0x18, 0x14, 0x17, 0x13, 0x17, 0x14, 0x18, 0x16, 0x1A, 0x1C, 0x20, 0x26, 0x30, 0x37, 0x45, 0x35, 0x3A, 0x27, 0x2A, 0x21, 0x25, 0x1D, 0x21, 0x1B, 0x1F, 0x17, 0x1C, 0x15, 0x19, 0x14, 0x18, 0x13, 0x17, 0x14, 0x18, 0x14, 0x18, 0x13, 0x18, 0x14, 0x18, 0x13, 0x17, 0x14, 0x18, 0x14, 0x18, 0x14, 0x19, 0x14, 0x19, 0x14, 0x19, 0x14, 0x18, 0x14, 0x18, 0x14, 0x17, 0x13, 0x17, 0x13, 0x17, 0x12, 0x16, 0x12, 0x17, 0x12, 0x16, 0x12, 0x15, 0x12, 0x16, 0x12, 0x16, 0x11, 0x15, 0x11, 0x15, 0x11, 0x14, 0x11, 0x15, 0x11, 0x15, 0x11, 0x14, 0x11, 0x15, 0x11, 0x14, 0x11, 0x14, 0x11, 0x14, 0x11, 0x14, 0x12, 0x14, 0x11, 0x15, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x14, 0x16, 0x1A, 0x1D, 0x31, 0x35, 0x4A, 0x49, 0x55, 0x53, 0x58, 0x54, 0x49, 0x41, 0x34, 0x2F, 0x41, 0x40, 0x55, 0x4F, 0x5B, 0x55, 0x61, 0x58, 0x64, 0x5B, 0x64, 0x58, 0x65, 0x59, 0x68, 0x5C, 0x66, 0x5A, 0x68, 0x5B, 0x67, 0x5A, 0x66, 0x59, 0x69, 0x5A, 0x68, 0x5A, 0x6B, 0x5D, 0x6D, 0x5D, 0x68, 0x5A, 0x67, 0x5A, 0x68, 0x59, 0x68, 0x5A, 0x67, 0x5B, 0x65, 0x58, 0x66, 0x59, 0x67, 0x59, 0x67, 0x5A, 0x68, 0x5B, 0x6A, 0x5E, 0x6A, 0x5B, 0x6A, 0x5C, 0x68, 0x5B, 0x6A, 0x5D, 0x6B, 0x5D, 0x68, 0x59, 0x68, 0x5A, 0x65, 0x57, 0x65, 0x58, 0x63, 0x57, 0x67, 0x5B, 0x63, 0x58, 0x68, 0x5D, 0x69, 0x5D, 0x69, 0x5C, 0x69, 0x5C, 0x67, 0x5A, 0x69, 0x5D, 0x67, 0x5A, 0x69, 0x5B, 0x66, 0x58, 0x69, 0x5C, 0x69, 0x5B, 0x6A, 0x5C, 0x69, 0x5B, 0x6A, 0x5B, 0x6B, 0x5F, 0x6C, 0x5D, 0x68, 0x5D, 0x6A, 0x5D, 0x6B, 0x5D, 0x6A, 0x5C, 0x6B, 0x5D, 0x6B, 0x5B, 0x69, 0x5D, 0x69, 0x5C, 0x68, 0x5B, 0x68, 0x5C, 0x6A, 0x5D, 0x6A, 0x5C, 0x69, 0x5C, 0x6C, 0x5F, 0x69, 0x5C, 0x6B, 0x5F, 0x6B, 0x5D, 0x6E, 0x61, 0x6B, 0x5F, 0x6B, 0x5F, 0x6A, 0x5E, 0x6C, 0x5E, 0x6B, 0x5F, 0x6A, 0x5C, 0x6A, 0x5F, 0x69, 0x5D, 0x68, 0x5D, 0x68, 0x5C, 0x6A, 0x5E, 0x69, 0x5C, 0x68, 0x5C, 0x67, 0x5B, 0x65, 0x59, 0x68, 0x5C, 0x67, 0x5A, 0x63, 0x56, 0x66, 0x5B, 0x67, 0x5A, 0x68, 0x5B, 0x68, 0x5B, 0x65, 0x5A, 0x69, 0x5D, 0x66, 0x5C, 0x65, 0x59, 0x69, 0x5C, 0x6B, 0x5F, 0x6A, 0x5D, 0x67, 0x59, 0x67, 0x5A, 0x66, 0x59, 0x68, 0x5C, 0x66, 0x5C, 0x65, 0x5A, 0x64, 0x57, 0x60, 0x55, 0x63, 0x58, 0x66, 0x5A, 0x66, 0x5A, 0x63, 0x58, 0x62, 0x57, 0x62, 0x57, 0x64, 0x58, 0x61, 0x55, 0x63, 0x58, 0x64, 0x57, 0x63, 0x57, 0x65, 0x59, 0x65, 0x5A, 0x61, 0x56, 0x5F, 0x55, 0x5F, 0x55, 0x60, 0x55, 0x5D, 0x53, 0x5E, 0x54, 0x5E, 0x54, 0x5D, 0x52, 0x5C, 0x51, 0x5D, 0x52, 0x5A, 0x4F, 0x5C, 0x50, 0x58, 0x4D, 0x5A, 0x50, 0x5B, 0x51, 0x55, 0x49, 0x38, 0x34, 0x2F, 0x2E, 0x22, 0x24, 0x2B, 0x2F, 0x29, 0x2B, 0x27, 0x28, 0x25, 0x27, 0x23, 0x25, 0x2B, 0x30, 0x22, 0x23, 0x26, 0x2A, 0x1F, 0x21, 0x27, 0x2C, 0x23, 0x25, 0x21, 0x22, 0x23, 0x27, 0x23, 0x24, 0x25, 0x28, 0x23, 0x25, 0x1F, 0x22, 0x21, 0x22, 0x22, 0x27, 0x27, 0x27, 0x1E, 0x20, 0x23, 0x26, 0x1E, 0x21, 0x27, 0x2A, 0x1F, 0x21, 0x25, 0x29, 0x22, 0x23, 0x22, 0x24, 0x1F, 0x20, 0x22, 0x26, 0x21, 0x23, 0x24, 0x26, 0x1E, 0x20, 0x20, 0x22, 0x24, 0x27, 0x25, 0x2A, 0x27, 0x28, 0x24, 0x28, 0x27, 0x27, 0x22, 0x25, 0x27, 0x2A
    },

    {
        0x53, 0x1F, 0x55, 0x1D, 0x55, 0x1E, 0x54, 0x1E, 0x54, 0x1E, 0x55, 0x1E, 0x54, 0x1E, 0x55, 0x1F, 0x55, 0x1E, 0x55, 0x1E, 0x54, 0x1E, 0x50, 0x1D, 0x4B, 0x1C, 0x42, 0x1B, 0x3B, 0x19, 0x38, 0x18, 0x41, 0x1A, 0x46, 0x1B, 0x43, 0x1B, 0x37, 0x17, 0x29, 0x14, 0x1F, 0x12, 0x1A, 0x10, 0x18, 0x0F, 0x16, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x14, 0x0F, 0x14, 0x0E, 0x14, 0x0F, 0x14, 0x0F, 0x14, 0x0E, 0x14, 0x0F, 0x13, 0x0E, 0x14, 0x0E, 0x14, 0x0E, 0x13, 0x0E, 0x14, 0x0F, 0x14, 0x0E, 0x13, 0x0F, 0x15, 0x0F, 0x13, 0x0F, 0x14, 0x0F, 0x14, 0x0F, 0x14, 0x0F, 0x14, 0x0F, 0x14, 0x0F, 0x14, 0x0F, 0x14, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x17, 0x10, 0x17, 0x11, 0x17, 0x11, 0x17, 0x10, 0x17, 0x11, 0x17, 0x10, 0x17, 0x11, 0x18, 0x12, 0x1D, 0x17, 0x2B, 0x23, 0x34, 0x27, 0x2C, 0x1E, 0x22, 0x18, 0x1E, 0x15, 0x1D, 0x14, 0x1B, 0x13, 0x1A, 0x13, 0x19, 0x12, 0x18, 0x11, 0x18, 0x12, 0x1B, 0x14, 0x24, 0x1C, 0x3B, 0x2F, 0x58, 0x3E, 0x4E, 0x32, 0x35, 0x23, 0x29, 0x1B, 0x24, 0x18, 0x20, 0x16, 0x1D, 0x14, 0x1A, 0x13, 0x19, 0x12, 0x18, 0x11, 0x18, 0x11, 0x18, 0x12, 0x18, 0x11, 0x18, 0x11, 0x19, 0x12, 0x18, 0x12, 0x19, 0x12, 0x1A, 0x12, 0x1A, 0x12, 0x19, 0x12, 0x19, 0x12, 0x18, 0x11, 0x18, 0x11, 0x17, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x17, 0x11, 0x17, 0x10, 0x17, 0x10, 0x16, 0x10, 0x16, 0x10, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x10, 0x16, 0x0F, 0x16, 0x10, 0x16, 0x10, 0x16, 0x0F, 0x16, 0x10, 0x17, 0x10, 0x17, 0x10, 0x16, 0x10, 0x17, 0x10, 0x17, 0x10, 0x18, 0x11, 0x1D, 0x13, 0x34, 0x1A, 0x4C, 0x1E, 0x54, 0x20, 0x55, 0x20, 0x42, 0x1B, 0x31, 0x19, 0x45, 0x1E, 0x54, 0x20, 0x5A, 0x22, 0x5D, 0x22, 0x5C, 0x21, 0x5D, 0x22, 0x60, 0x22, 0x5F, 0x22, 0x61, 0x23, 0x62, 0x23, 0x60, 0x22, 0x61, 0x22, 0x61, 0x22, 0x60, 0x21, 0x60, 0x22, 0x5F, 0x21, 0x5E, 0x22, 0x5E, 0x21, 0x5F, 0x20, 0x5E, 0x21, 0x5F, 0x21, 0x5F, 0x21, 0x60, 0x22, 0x5D, 0x21, 0x5D, 0x22, 0x60, 0x22, 0x60, 0x22, 0x5E, 0x21, 0x60, 0x22, 0x61, 0x23, 0x61, 0x22, 0x5E, 0x21, 0x5E, 0x21, 0x5D, 0x21, 0x5D, 0x21, 0x5D, 0x21, 0x61, 0x22, 0x5D, 0x21, 0x60, 0x21, 0x5D, 0x21, 0x5F, 0x22, 0x60, 0x22, 0x60, 0x22, 0x63, 0x23, 0x5E, 0x21, 0x5F, 0x22, 0x5E, 0x22, 0x60, 0x21, 0x5F, 0x22, 0x61, 0x22, 0x5F, 0x22, 0x61, 0x23, 0x61, 0x22, 0x63, 0x23, 0x61, 0x22, 0x60, 0x22, 0x5F, 0x22, 0x5E, 0x22, 0x61, 0x23, 0x61, 0x22, 0x61, 0x22, 0x60, 0x22, 0x61, 0x22, 0x61, 0x22, 0x61, 0x23, 0x62, 0x23, 0x62, 0x22, 0x62, 0x23, 0x63, 0x23, 0x61, 0x23, 0x5E, 0x22, 0x61, 0x22, 0x61, 0x23, 0x63, 0x25, 0x62, 0x22, 0x5F, 0x22, 0x62, 0x24, 0x62, 0x23, 0x60, 0x23, 0x5F, 0x22, 0x5D, 0x23, 0x5B, 0x22, 0x5E, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x5C, 0x21, 0x5D, 0x21, 0x5D, 0x21, 0x5F, 0x21, 0x5B, 0x21, 0x5D, 0x21, 0x5D, 0x22, 0x5F, 0x22, 0x5E, 0x22, 0x5F, 0x22, 0x5E, 0x22, 0x5F, 0x23, 0x5E, 0x22, 0x5F, 0x23, 0x62, 0x24, 0x62, 0x23, 0x5C, 0x21, 0x5B, 0x21, 0x5A, 0x20, 0x5F, 0x22, 0x5D, 0x22, 0x5C, 0x21, 0x5A, 0x21, 0x5B, 0x22, 0x5E, 0x21, 0x5C, 0x21, 0x5C, 0x22, 0x5B, 0x21, 0x5C, 0x21, 0x5D, 0x21, 0x5C, 0x22, 0x5B, 0x21, 0x59, 0x21, 0x5A, 0x21, 0x5A, 0x21, 0x5C, 0x21, 0x5B, 0x21, 0x5A, 0x21, 0x58, 0x21, 0x59, 0x22, 0x5B, 0x22, 0x58, 0x20, 0x57, 0x20, 0x56, 0x1F, 0x55, 0x20, 0x53, 0x1F, 0x53, 0x1F, 0x54, 0x1F, 0x53, 0x1D, 0x52, 0x1E, 0x51, 0x1E, 0x53, 0x20, 0x50, 0x1E, 0x36, 0x19, 0x2A, 0x17, 0x24, 0x16, 0x29, 0x18, 0x25, 0x16, 0x22, 0x16, 0x27, 0x17, 0x24, 0x16, 0x2B, 0x19, 0x24, 0x16, 0x29, 0x18, 0x23, 0x16, 0x2D, 0x19, 0x23, 0x15, 0x22, 0x15, 0x27, 0x17, 0x28, 0x17, 0x29, 0x18, 0x2A, 0x18, 0x28, 0x18, 0x26, 0x16, 0x29, 0x18, 0x2B, 0x19, 0x26, 0x17, 0x2B, 0x19, 0x29, 0x18, 0x2C, 0x19, 0x27, 0x17, 0x28, 0x17, 0x2A, 0x18, 0x2B, 0x18, 0x29, 0x16, 0x2B, 0x18, 0x2A, 0x17, 0x26, 0x16, 0x27, 0x17, 0x2C, 0x17, 0x2D, 0x19, 0x2B, 0x18, 0x27, 0x16, 0x28, 0x17, 0x23, 0x15, 0x25, 0x16, 0x33, 0x1B
    },

    {
        0x5A, 0x50, 0x5C, 0x52, 0x5D, 0x51, 0x5C, 0x51, 0x5B, 0x51, 0x5C, 0x51, 0x5C, 0x51, 0x5D, 0x52, 0x5D, 0x51, 0x5C, 0x51, 0x5B, 0x50, 0x55, 0x4B, 0x4F, 0x45, 0x45, 0x3D, 0x3C, 0x38, 0x3A, 0x38, 0x44, 0x42, 0x49, 0x43, 0x44, 0x3D, 0x36, 0x30, 0x26, 0x23, 0x1B, 0x1C, 0x17, 0x19, 0x14, 0x16, 0x12, 0x15, 0x11, 0x15, 0x11, 0x14, 0x10, 0x15, 0x11, 0x15, 0x11, 0x15, 0x10, 0x14, 0x10, 0x13, 0x10, 0x13, 0x10, 0x14, 0x11, 0x14, 0x10, 0x13, 0x10, 0x13, 0x10, 0x13, 0x10, 0x13, 0x10, 0x13, 0x10, 0x13, 0x0F, 0x13, 0x10, 0x13, 0x10, 0x14, 0x10, 0x14, 0x10, 0x14, 0x10, 0x13, 0x10, 0x14, 0x11, 0x14, 0x10, 0x13, 0x10, 0x14, 0x10, 0x14, 0x11, 0x14, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x13, 0x16, 0x13, 0x16, 0x13, 0x16, 0x15, 0x18, 0x1B, 0x20, 0x26, 0x32, 0x30, 0x3B, 0x2A, 0x2D, 0x20, 0x23, 0x1C, 0x1F, 0x19, 0x1C, 0x18, 0x1B, 0x16, 0x18, 0x14, 0x17, 0x14, 0x18, 0x14, 0x18, 0x17, 0x1B, 0x20, 0x28, 0x31, 0x44, 0x46, 0x61, 0x45, 0x50, 0x30, 0x34, 0x25, 0x28, 0x1F, 0x23, 0x1B, 0x1E, 0x17, 0x1B, 0x15, 0x19, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x13, 0x18, 0x13, 0x19, 0x14, 0x19, 0x14, 0x19, 0x14, 0x18, 0x13, 0x18, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x12, 0x17, 0x13, 0x17, 0x13, 0x16, 0x12, 0x16, 0x12, 0x16, 0x11, 0x15, 0x11, 0x14, 0x11, 0x14, 0x11, 0x14, 0x11, 0x15, 0x11, 0x14, 0x11, 0x14, 0x11, 0x14, 0x11, 0x14, 0x11, 0x14, 0x11, 0x15, 0x11, 0x15, 0x12, 0x15, 0x11, 0x15, 0x12, 0x15, 0x12, 0x16, 0x12, 0x16, 0x12, 0x15, 0x12, 0x16, 0x13, 0x16, 0x14, 0x17, 0x17, 0x1A, 0x2B, 0x2F, 0x47, 0x49, 0x56, 0x51, 0x58, 0x53, 0x4A, 0x42, 0x34, 0x2F, 0x42, 0x41, 0x55, 0x4F, 0x5E, 0x56, 0x63, 0x58, 0x63, 0x58, 0x67, 0x5A, 0x69, 0x5C, 0x67, 0x5C, 0x68, 0x5D, 0x6A, 0x5E, 0x69, 0x5D, 0x6B, 0x5D, 0x6B, 0x5B, 0x6B, 0x5D, 0x6B, 0x5C, 0x6A, 0x5C, 0x68, 0x5B, 0x68, 0x5C, 0x67, 0x5A, 0x68, 0x5B, 0x69, 0x5C, 0x68, 0x5C, 0x6A, 0x5B, 0x67, 0x5A, 0x67, 0x5A, 0x6A, 0x5C, 0x6A, 0x5C, 0x68, 0x5B, 0x6A, 0x5D, 0x6A, 0x5E, 0x6B, 0x5D, 0x68, 0x5B, 0x66, 0x5B, 0x67, 0x5C, 0x66, 0x5C, 0x65, 0x5A, 0x6A, 0x5C, 0x67, 0x5A, 0x68, 0x5C, 0x67, 0x5A, 0x6A, 0x5D, 0x6B, 0x5C, 0x6A, 0x5D, 0x6C, 0x5E, 0x67, 0x5A, 0x69, 0x5D, 0x69, 0x5C, 0x69, 0x5C, 0x68, 0x5C, 0x6A, 0x5B, 0x69, 0x5B, 0x6B, 0x5E, 0x6C, 0x5D, 0x6D, 0x5F, 0x6C, 0x5D, 0x6A, 0x5C, 0x68, 0x5B, 0x68, 0x5A, 0x69, 0x5C, 0x6B, 0x5E, 0x6C, 0x60, 0x6A, 0x5D, 0x6B, 0x5D, 0x6B, 0x5D, 0x69, 0x5D, 0x6C, 0x5E, 0x6B, 0x5E, 0x6B, 0x5E, 0x6C, 0x5E, 0x69, 0x5C, 0x69, 0x5C, 0x6A, 0x5C, 0x6E, 0x5D, 0x6B, 0x5F, 0x6A, 0x5E, 0x67, 0x5B, 0x6B, 0x60, 0x6B, 0x60, 0x68, 0x5E, 0x65, 0x59, 0x63, 0x5A, 0x61, 0x58, 0x65, 0x5A, 0x67, 0x5C, 0x66, 0x5B, 0x65, 0x58, 0x66, 0x59, 0x65, 0x59, 0x64, 0x59, 0x64, 0x59, 0x65, 0x59, 0x65, 0x59, 0x67, 0x5C, 0x67, 0x5B, 0x67, 0x5B, 0x67, 0x5C, 0x67, 0x5C, 0x66, 0x5B, 0x67, 0x5C, 0x6C, 0x5F, 0x6A, 0x5D, 0x67, 0x5A, 0x65, 0x57, 0x63, 0x57, 0x68, 0x5B, 0x65, 0x59, 0x63, 0x58, 0x63, 0x58, 0x64, 0x5A, 0x67, 0x5A, 0x66, 0x59, 0x65, 0x59, 0x65, 0x59, 0x65, 0x59, 0x66, 0x59, 0x64, 0x58, 0x64, 0x57, 0x62, 0x57, 0x62, 0x56, 0x61, 0x58, 0x65, 0x58, 0x64, 0x59, 0x65, 0x58, 0x60, 0x55, 0x62, 0x58, 0x64, 0x57, 0x5F, 0x55, 0x60, 0x54, 0x60, 0x54, 0x5E, 0x52, 0x5C, 0x53, 0x59, 0x4F, 0x5D, 0x52, 0x5B, 0x50, 0x5A, 0x50, 0x58, 0x4D, 0x5B, 0x4F, 0x55, 0x4A, 0x36, 0x33, 0x28, 0x25, 0x23, 0x23, 0x25, 0x27, 0x21, 0x23, 0x1F, 0x22, 0x23, 0x26, 0x20, 0x23, 0x26, 0x27, 0x20, 0x24, 0x26, 0x27, 0x22, 0x27, 0x29, 0x2D, 0x21, 0x23, 0x21, 0x24, 0x24, 0x29, 0x25, 0x27, 0x25, 0x2A, 0x27, 0x2A, 0x25, 0x29, 0x24, 0x26, 0x25, 0x2A, 0x28, 0x2B, 0x23, 0x26, 0x28, 0x2D, 0x26, 0x29, 0x28, 0x2C, 0x24, 0x26, 0x24, 0x27, 0x25, 0x28, 0x26, 0x2A, 0x25, 0x26, 0x27, 0x2B, 0x26, 0x27, 0x22, 0x23, 0x27, 0x2C, 0x24, 0x26, 0x28, 0x2D, 0x24, 0x27, 0x23, 0x26, 0x23, 0x25, 0x1F, 0x1F, 0x22, 0x27, 0x2C, 0x2F
    },

    {
        0x54, 0x1E, 0x53, 0x1E, 0x54, 0x1F, 0x55, 0x1E, 0x53, 0x1E, 0x54, 0x1E, 0x53, 0x1E, 0x53, 0x1E, 0x54, 0x1E, 0x54, 0x1E, 0x51, 0x1E, 0x4B, 0x1C, 0x44, 0x1A, 0x3C, 0x19, 0x38, 0x19, 0x40, 0x1A, 0x46, 0x1B, 0x42, 0x1A, 0x39, 0x18, 0x2A, 0x14, 0x21, 0x12, 0x1C, 0x10, 0x19, 0x10, 0x16, 0x0F, 0x15, 0x0F, 0x14, 0x0E, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x14, 0x0F, 0x14, 0x0F, 0x14, 0x0E, 0x14, 0x0E, 0x14, 0x0F, 0x13, 0x0E, 0x14, 0x0F, 0x14, 0x0E, 0x13, 0x0E, 0x13, 0x0F, 0x14, 0x0E, 0x14, 0x0F, 0x14, 0x0F, 0x14, 0x0E, 0x14, 0x0F, 0x14, 0x0F, 0x14, 0x0F, 0x14, 0x0E, 0x14, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x10, 0x16, 0x10, 0x16, 0x10, 0x17, 0x10, 0x17, 0x11, 0x18, 0x11, 0x18, 0x12, 0x19, 0x12, 0x18, 0x11, 0x17, 0x10, 0x17, 0x10, 0x17, 0x11, 0x1C, 0x15, 0x29, 0x22, 0x46, 0x38, 0x6A, 0x4A, 0x5D, 0x3A, 0x37, 0x23, 0x26, 0x1A, 0x21, 0x17, 0x1E, 0x14, 0x1C, 0x14, 0x1A, 0x13, 0x19, 0x12, 0x1A, 0x13, 0x21, 0x1A, 0x34, 0x2B, 0x5B, 0x46, 0x84, 0x5E, 0x89, 0x58, 0x5E, 0x3A, 0x38, 0x24, 0x2A, 0x1B, 0x23, 0x18, 0x1F, 0x16, 0x1B, 0x13, 0x19, 0x11, 0x18, 0x11, 0x18, 0x12, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x19, 0x11, 0x19, 0x12, 0x1A, 0x12, 0x1A, 0x13, 0x19, 0x12, 0x19, 0x12, 0x18, 0x12, 0x19, 0x12, 0x19, 0x12, 0x18, 0x11, 0x17, 0x10, 0x17, 0x11, 0x18, 0x11, 0x17, 0x10, 0x17, 0x10, 0x16, 0x0F, 0x16, 0x10, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x14, 0x0E, 0x14, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x16, 0x0F, 0x16, 0x0F, 0x16, 0x10, 0x16, 0x0F, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x16, 0x10, 0x17, 0x10, 0x17, 0x10, 0x18, 0x10, 0x1C, 0x13, 0x34, 0x1A, 0x4E, 0x1F, 0x55, 0x20, 0x56, 0x20, 0x44, 0x1B, 0x32, 0x19, 0x41, 0x1D, 0x53, 0x20, 0x59, 0x22, 0x5C, 0x22, 0x5F, 0x23, 0x5E, 0x22, 0x60, 0x22, 0x61, 0x23, 0x62, 0x23, 0x63, 0x24, 0x61, 0x22, 0x5E, 0x21, 0x5F, 0x22, 0x5F, 0x21, 0x5E, 0x21, 0x60, 0x23, 0x60, 0x22, 0x5F, 0x21, 0x60, 0x22, 0x61, 0x22, 0x62, 0x23, 0x62, 0x23, 0x60, 0x21, 0x5D, 0x22, 0x5E, 0x21, 0x60, 0x22, 0x5C, 0x20, 0x5F, 0x22, 0x61, 0x22, 0x61, 0x23, 0x5F, 0x22, 0x5F, 0x22, 0x62, 0x23, 0x61, 0x22, 0x5F, 0x21, 0x5F, 0x21, 0x5D, 0x21, 0x5F, 0x21, 0x62, 0x22, 0x62, 0x22, 0x5F, 0x22, 0x60, 0x21, 0x60, 0x22, 0x5C, 0x22, 0x5F, 0x23, 0x61, 0x22, 0x5F, 0x21, 0x62, 0x22, 0x5F, 0x21, 0x5F, 0x22, 0x61, 0x22, 0x61, 0x22, 0x61, 0x22, 0x62, 0x22, 0x5F, 0x21, 0x60, 0x22, 0x5C, 0x22, 0x5E, 0x22, 0x60, 0x22, 0x63, 0x22, 0x62, 0x22, 0x60, 0x22, 0x61, 0x22, 0x5E, 0x22, 0x5F, 0x22, 0x61, 0x22, 0x60, 0x22, 0x63, 0x23, 0x5E, 0x22, 0x5F, 0x22, 0x63, 0x23, 0x64, 0x24, 0x62, 0x24, 0x61, 0x23, 0x61, 0x24, 0x63, 0x25, 0x62, 0x24, 0x5F, 0x23, 0x57, 0x23, 0x55, 0x23, 0x53, 0x23, 0x59, 0x22, 0x5A, 0x21, 0x5C, 0x22, 0x59, 0x20, 0x5B, 0x21, 0x5B, 0x21, 0x59, 0x21, 0x5F, 0x22, 0x5B, 0x21, 0x5D, 0x22, 0x5E, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x61, 0x24, 0x5E, 0x22, 0x5D, 0x22, 0x61, 0x23, 0x5F, 0x22, 0x5E, 0x22, 0x5E, 0x21, 0x5D, 0x22, 0x5D, 0x22, 0x5D, 0x22, 0x5F, 0x22, 0x5B, 0x21, 0x5C, 0x22, 0x5D, 0x22, 0x5F, 0x22, 0x5D, 0x22, 0x5D, 0x21, 0x5A, 0x21, 0x5B, 0x22, 0x5C, 0x20, 0x5B, 0x21, 0x5B, 0x21, 0x5E, 0x23, 0x58, 0x21, 0x59, 0x21, 0x5A, 0x21, 0x5B, 0x21, 0x5C, 0x22, 0x5B, 0x22, 0x59, 0x21, 0x59, 0x20, 0x57, 0x20, 0x5A, 0x21, 0x58, 0x20, 0x58, 0x20, 0x56, 0x20, 0x55, 0x1F, 0x55, 0x1F, 0x53, 0x1E, 0x53, 0x1F, 0x51, 0x1E, 0x53, 0x1E, 0x50, 0x1E, 0x37, 0x19, 0x2F, 0x19, 0x2B, 0x18, 0x30, 0x1A, 0x2A, 0x17, 0x26, 0x17, 0x30, 0x1B, 0x2D, 0x19, 0x2E, 0x1A, 0x28, 0x17, 0x30, 0x1B, 0x2D, 0x19, 0x30, 0x1A, 0x2D, 0x19, 0x28, 0x16, 0x2C, 0x1A, 0x2E, 0x19, 0x2E, 0x1A, 0x2D, 0x19, 0x28, 0x18, 0x2E, 0x1A, 0x28, 0x18, 0x2F, 0x19, 0x26, 0x18, 0x34, 0x1B, 0x25, 0x17, 0x2F, 0x1A, 0x26, 0x16, 0x28, 0x17, 0x24, 0x15, 0x24, 0x16, 0x22, 0x15, 0x2B, 0x18, 0x24, 0x15, 0x27, 0x16, 0x2A, 0x18, 0x21, 0x14, 0x28, 0x16, 0x21, 0x15, 0x26, 0x16, 0x22, 0x14, 0x24, 0x16, 0x2D, 0x1A, 0x2D, 0x18
    },

    {
        0x5C, 0x50, 0x5A, 0x51, 0x5C, 0x52, 0x5D, 0x52, 0x5D, 0x52, 0x5C, 0x52, 0x5C, 0x51, 0x5B, 0x50, 0x5C, 0x51, 0x5B, 0x50, 0x58, 0x4D, 0x50, 0x46, 0x48, 0x3E, 0x3E, 0x38, 0x3B, 0x38, 0x43, 0x40, 0x49, 0x44, 0x45, 0x3E, 0x38, 0x32, 0x28, 0x24, 0x1D, 0x1D, 0x18, 0x1A, 0x15, 0x17, 0x13, 0x15, 0x12, 0x14, 0x11, 0x14, 0x11, 0x14, 0x11, 0x14, 0x11, 0x14, 0x10, 0x13, 0x10, 0x13, 0x10, 0x14, 0x11, 0x14, 0x10, 0x14, 0x11, 0x14, 0x10, 0x13, 0x0F, 0x13, 0x10, 0x12, 0x10, 0x13, 0x10, 0x13, 0x10, 0x13, 0x10, 0x13, 0x10, 0x13, 0x10, 0x13, 0x10, 0x13, 0x10, 0x14, 0x10, 0x13, 0x10, 0x14, 0x10, 0x13, 0x11, 0x13, 0x11, 0x14, 0x11, 0x14, 0x11, 0x15, 0x11, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x13, 0x17, 0x14, 0x18, 0x13, 0x18, 0x13, 0x17, 0x13, 0x16, 0x13, 0x16, 0x15, 0x17, 0x1A, 0x1F, 0x24, 0x30, 0x3A, 0x52, 0x54, 0x73, 0x50, 0x60, 0x34, 0x39, 0x24, 0x27, 0x1E, 0x20, 0x1A, 0x1D, 0x18, 0x1B, 0x16, 0x1A, 0x15, 0x18, 0x17, 0x1B, 0x1E, 0x25, 0x2D, 0x3E, 0x48, 0x67, 0x66, 0x8A, 0x6D, 0x8A, 0x54, 0x5E, 0x35, 0x38, 0x25, 0x29, 0x1F, 0x23, 0x1A, 0x1D, 0x16, 0x19, 0x14, 0x18, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x14, 0x17, 0x14, 0x18, 0x14, 0x19, 0x14, 0x19, 0x15, 0x19, 0x14, 0x18, 0x14, 0x18, 0x13, 0x17, 0x14, 0x19, 0x14, 0x19, 0x13, 0x17, 0x13, 0x16, 0x13, 0x17, 0x13, 0x17, 0x12, 0x16, 0x12, 0x16, 0x12, 0x15, 0x12, 0x14, 0x11, 0x14, 0x11, 0x14, 0x11, 0x14, 0x11, 0x14, 0x11, 0x13, 0x11, 0x14, 0x11, 0x14, 0x11, 0x15, 0x12, 0x16, 0x12, 0x15, 0x12, 0x15, 0x12, 0x16, 0x12, 0x15, 0x12, 0x16, 0x12, 0x15, 0x12, 0x15, 0x12, 0x16, 0x12, 0x16, 0x13, 0x16, 0x14, 0x17, 0x17, 0x1A, 0x29, 0x2F, 0x47, 0x49, 0x55, 0x51, 0x5A, 0x53, 0x4C, 0x43, 0x36, 0x31, 0x3F, 0x3E, 0x52, 0x4E, 0x5D, 0x56, 0x61, 0x58, 0x67, 0x5C, 0x66, 0x5A, 0x69, 0x5C, 0x69, 0x5F, 0x6B, 0x5F, 0x6C, 0x60, 0x6B, 0x5C, 0x6A, 0x5C, 0x69, 0x5C, 0x67, 0x59, 0x67, 0x5B, 0x69, 0x5D, 0x67, 0x5B, 0x6A, 0x5C, 0x6B, 0x5E, 0x6C, 0x5E, 0x6D, 0x5F, 0x6C, 0x5F, 0x6A, 0x5C, 0x67, 0x59, 0x66, 0x5A, 0x69, 0x5B, 0x64, 0x58, 0x68, 0x5B, 0x6B, 0x5D, 0x6A, 0x5D, 0x69, 0x5C, 0x69, 0x5C, 0x68, 0x5D, 0x67, 0x5C, 0x67, 0x5C, 0x68, 0x5B, 0x67, 0x5A, 0x68, 0x5C, 0x6B, 0x5E, 0x6C, 0x5E, 0x6B, 0x5A, 0x6A, 0x5B, 0x6A, 0x5C, 0x66, 0x5A, 0x6A, 0x5E, 0x6B, 0x5C, 0x6A, 0x5C, 0x6B, 0x5E, 0x68, 0x5B, 0x69, 0x5B, 0x6C, 0x5D, 0x6B, 0x5D, 0x6B, 0x5E, 0x6B, 0x5C, 0x6A, 0x5B, 0x6A, 0x5C, 0x68, 0x5A, 0x68, 0x5A, 0x6B, 0x5C, 0x6D, 0x5E, 0x6D, 0x5E, 0x6B, 0x5D, 0x6B, 0x5D, 0x68, 0x5B, 0x68, 0x5B, 0x6B, 0x5D, 0x6A, 0x5C, 0x6D, 0x5E, 0x6A, 0x5B, 0x6A, 0x5D, 0x6D, 0x5F, 0x6E, 0x61, 0x6B, 0x5D, 0x68, 0x5C, 0x67, 0x5D, 0x67, 0x5D, 0x65, 0x5C, 0x60, 0x57, 0x56, 0x51, 0x52, 0x4D, 0x50, 0x4C, 0x57, 0x52, 0x5D, 0x54, 0x64, 0x59, 0x62, 0x56, 0x64, 0x59, 0x63, 0x56, 0x61, 0x56, 0x67, 0x5C, 0x65, 0x59, 0x66, 0x5B, 0x67, 0x5A, 0x69, 0x5C, 0x69, 0x5C, 0x6A, 0x5E, 0x67, 0x5A, 0x68, 0x5B, 0x69, 0x5D, 0x68, 0x5B, 0x6A, 0x5C, 0x66, 0x5A, 0x65, 0x59, 0x65, 0x59, 0x68, 0x5C, 0x68, 0x5B, 0x63, 0x58, 0x62, 0x58, 0x66, 0x5B, 0x68, 0x5C, 0x68, 0x5A, 0x66, 0x59, 0x64, 0x57, 0x65, 0x58, 0x66, 0x59, 0x64, 0x57, 0x64, 0x57, 0x64, 0x58, 0x61, 0x57, 0x63, 0x56, 0x64, 0x57, 0x65, 0x57, 0x66, 0x5A, 0x63, 0x58, 0x61, 0x55, 0x61, 0x55, 0x60, 0x55, 0x62, 0x56, 0x61, 0x55, 0x5D, 0x54, 0x5F, 0x55, 0x5D, 0x54, 0x60, 0x53, 0x5C, 0x50, 0x5C, 0x50, 0x5A, 0x4E, 0x5B, 0x4F, 0x55, 0x49, 0x38, 0x32, 0x2E, 0x2F, 0x29, 0x2B, 0x2B, 0x2F, 0x26, 0x27, 0x24, 0x26, 0x2B, 0x30, 0x27, 0x2B, 0x29, 0x2D, 0x25, 0x27, 0x2B, 0x2F, 0x26, 0x2A, 0x29, 0x2C, 0x27, 0x2A, 0x24, 0x23, 0x27, 0x2D, 0x27, 0x29, 0x26, 0x29, 0x26, 0x28, 0x24, 0x27, 0x28, 0x29, 0x24, 0x28, 0x27, 0x28, 0x24, 0x27, 0x29, 0x2C, 0x21, 0x26, 0x28, 0x2B, 0x22, 0x23, 0x24, 0x26, 0x1F, 0x1F, 0x21, 0x23, 0x1F, 0x20, 0x26, 0x2A, 0x20, 0x21, 0x23, 0x26, 0x24, 0x26, 0x1F, 0x21, 0x24, 0x25, 0x1E, 0x20, 0x23, 0x25, 0x1F, 0x20, 0x23, 0x26, 0x29, 0x2F, 0x27, 0x28
    },

    {
        0x54, 0x1E, 0x53, 0x1E, 0x55, 0x1E, 0x56, 0x1E, 0x55, 0x1F, 0x55, 0x1E, 0x54, 0x1F, 0x53, 0x1E, 0x54, 0x1E, 0x52, 0x1E, 0x4D, 0x1D, 0x46, 0x1B, 0x3D, 0x1A, 0x38, 0x18, 0x40, 0x1A, 0x47, 0x1B, 0x45, 0x1B, 0x3A, 0x18, 0x2C, 0x14, 0x20, 0x12, 0x1C, 0x11, 0x1A, 0x11, 0x18, 0x10, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x14, 0x0E, 0x14, 0x0F, 0x13, 0x0E, 0x14, 0x0E, 0x14, 0x0F, 0x14, 0x0F, 0x14, 0x0F, 0x14, 0x0E, 0x14, 0x0F, 0x14, 0x0F, 0x14, 0x0E, 0x14, 0x0E, 0x14, 0x0E, 0x14, 0x0F, 0x14, 0x0F, 0x14, 0x0F, 0x14, 0x0F, 0x15, 0x10, 0x15, 0x0F, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x18, 0x11, 0x19, 0x12, 0x1A, 0x13, 0x1A, 0x12, 0x18, 0x11, 0x17, 0x11, 0x17, 0x10, 0x1A, 0x14, 0x27, 0x20, 0x43, 0x36, 0x6D, 0x52, 0x8A, 0x5F, 0x8D, 0x5D, 0x6D, 0x44, 0x3E, 0x29, 0x2A, 0x1C, 0x23, 0x18, 0x20, 0x16, 0x1C, 0x14, 0x1C, 0x14, 0x21, 0x1A, 0x31, 0x28, 0x54, 0x43, 0x84, 0x5F, 0x9C, 0x6A, 0xA1, 0x6D, 0x97, 0x62, 0x68, 0x41, 0x3C, 0x27, 0x2A, 0x1C, 0x23, 0x18, 0x1D, 0x15, 0x1A, 0x13, 0x19, 0x12, 0x18, 0x12, 0x19, 0x11, 0x19, 0x12, 0x19, 0x11, 0x18, 0x11, 0x19, 0x12, 0x19, 0x12, 0x1A, 0x12, 0x19, 0x12, 0x19, 0x12, 0x19, 0x11, 0x18, 0x11, 0x19, 0x12, 0x1A, 0x12, 0x19, 0x11, 0x17, 0x11, 0x17, 0x11, 0x17, 0x10, 0x16, 0x10, 0x17, 0x10, 0x16, 0x10, 0x15, 0x0F, 0x15, 0x10, 0x15, 0x0F, 0x14, 0x0F, 0x14, 0x0F, 0x14, 0x0F, 0x15, 0x10, 0x15, 0x0F, 0x15, 0x0F, 0x16, 0x10, 0x16, 0x0F, 0x16, 0x10, 0x18, 0x11, 0x17, 0x10, 0x16, 0x10, 0x16, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x0F, 0x17, 0x10, 0x16, 0x10, 0x17, 0x10, 0x1C, 0x13, 0x32, 0x19, 0x4B, 0x1F, 0x54, 0x20, 0x57, 0x20, 0x48, 0x1C, 0x32, 0x19, 0x40, 0x1D, 0x53, 0x20, 0x59, 0x22, 0x5E, 0x22, 0x5E, 0x22, 0x5D, 0x22, 0x61, 0x23, 0x61, 0x22, 0x61, 0x23, 0x62, 0x22, 0x61, 0x22, 0x61, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x60, 0x21, 0x5F, 0x21, 0x60, 0x22, 0x62, 0x22, 0x63, 0x23, 0x64, 0x23, 0x62, 0x23, 0x61, 0x23, 0x5E, 0x22, 0x5D, 0x21, 0x5F, 0x21, 0x5D, 0x21, 0x5E, 0x21, 0x5F, 0x21, 0x62, 0x23, 0x61, 0x22, 0x60, 0x22, 0x61, 0x23, 0x60, 0x22, 0x60, 0x23, 0x5F, 0x22, 0x60, 0x22, 0x5F, 0x21, 0x5F, 0x22, 0x60, 0x22, 0x5E, 0x21, 0x5F, 0x22, 0x5E, 0x22, 0x60, 0x23, 0x61, 0x25, 0x61, 0x23, 0x5E, 0x21, 0x5F, 0x22, 0x5F, 0x22, 0x5E, 0x22, 0x61, 0x22, 0x5F, 0x22, 0x5F, 0x23, 0x61, 0x22, 0x60, 0x23, 0x61, 0x23, 0x5D, 0x22, 0x5C, 0x21, 0x5F, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x5E, 0x22, 0x5F, 0x22, 0x5D, 0x22, 0x5E, 0x22, 0x61, 0x23, 0x63, 0x23, 0x62, 0x23, 0x62, 0x24, 0x61, 0x22, 0x61, 0x24, 0x60, 0x25, 0x62, 0x29, 0x64, 0x2B, 0x5D, 0x27, 0x5C, 0x24, 0x5B, 0x23, 0x51, 0x23, 0x4C, 0x23, 0x4A, 0x23, 0x4A, 0x23, 0x4D, 0x23, 0x50, 0x21, 0x57, 0x21, 0x5A, 0x21, 0x5E, 0x21, 0x59, 0x20, 0x5A, 0x21, 0x5C, 0x22, 0x5C, 0x21, 0x5D, 0x22, 0x5D, 0x22, 0x5F, 0x23, 0x5D, 0x22, 0x5D, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x5B, 0x22, 0x5E, 0x22, 0x5F, 0x23, 0x5D, 0x22, 0x5C, 0x22, 0x5D, 0x22, 0x5D, 0x21, 0x5C, 0x22, 0x5B, 0x21, 0x5C, 0x22, 0x60, 0x22, 0x60, 0x23, 0x5C, 0x21, 0x5D, 0x22, 0x5E, 0x22, 0x5C, 0x21, 0x5D, 0x22, 0x5B, 0x21, 0x5D, 0x21, 0x5C, 0x22, 0x59, 0x21, 0x5B, 0x21, 0x59, 0x21, 0x59, 0x21, 0x5B, 0x22, 0x5B, 0x21, 0x58, 0x20, 0x57, 0x1F, 0x59, 0x21, 0x59, 0x21, 0x58, 0x21, 0x58, 0x20, 0x58, 0x20, 0x58, 0x20, 0x54, 0x1F, 0x56, 0x1F, 0x52, 0x1E, 0x53, 0x1E, 0x4F, 0x1E, 0x39, 0x1C, 0x32, 0x19, 0x25, 0x16, 0x2C, 0x18, 0x27, 0x16, 0x27, 0x18, 0x30, 0x1A, 0x28, 0x18, 0x29, 0x18, 0x26, 0x17, 0x2B, 0x18, 0x23, 0x16, 0x29, 0x17, 0x22, 0x15, 0x21, 0x15, 0x2C, 0x18, 0x21, 0x14, 0x28, 0x17, 0x20, 0x15, 0x27, 0x17, 0x23, 0x16, 0x27, 0x17, 0x27, 0x17, 0x26, 0x16, 0x24, 0x16, 0x2B, 0x19, 0x29, 0x17, 0x25, 0x17, 0x27, 0x17, 0x23, 0x15, 0x26, 0x16, 0x24, 0x16, 0x27, 0x17, 0x23, 0x15, 0x26, 0x17, 0x25, 0x16, 0x2F, 0x1A, 0x2A, 0x19, 0x2A, 0x18, 0x2C, 0x1A, 0x2A, 0x18, 0x2E, 0x19, 0x2B, 0x19, 0x2A, 0x18
    },

    {
        0x5C, 0x52, 0x5B, 0x52, 0x5D, 0x53, 0x5F, 0x53, 0x5F, 0x54, 0x5D, 0x53, 0x5D, 0x53, 0x5B, 0x51, 0x5B, 0x51, 0x57, 0x4D, 0x53, 0x49, 0x4A, 0x41, 0x3E, 0x38, 0x39, 0x37, 0x43, 0x41, 0x4A, 0x44, 0x47, 0x40, 0x3A, 0x33, 0x29, 0x25, 0x1D, 0x1D, 0x18, 0x1A, 0x16, 0x18, 0x14, 0x16, 0x12, 0x15, 0x11, 0x14, 0x11, 0x14, 0x11, 0x14, 0x11, 0x14, 0x11, 0x14, 0x11, 0x14, 0x11, 0x14, 0x11, 0x15, 0x11, 0x14, 0x10, 0x14, 0x11, 0x13, 0x10, 0x13, 0x10, 0x13, 0x10, 0x13, 0x10, 0x13, 0x10, 0x13, 0x10, 0x13, 0x10, 0x13, 0x10, 0x13, 0x10, 0x13, 0x10, 0x13, 0x10, 0x14, 0x10, 0x13, 0x10, 0x14, 0x10, 0x13, 0x10, 0x14, 0x11, 0x15, 0x11, 0x14, 0x11, 0x15, 0x11, 0x16, 0x12, 0x15, 0x11, 0x15, 0x12, 0x17, 0x14, 0x18, 0x15, 0x19, 0x15, 0x19, 0x13, 0x17, 0x13, 0x16, 0x14, 0x17, 0x19, 0x1D, 0x23, 0x2D, 0x38, 0x4F, 0x56, 0x77, 0x6B, 0x8A, 0x6E, 0x8C, 0x5D, 0x6F, 0x3B, 0x41, 0x27, 0x2A, 0x1F, 0x22, 0x1B, 0x1E, 0x19, 0x1C, 0x19, 0x1C, 0x1E, 0x25, 0x2A, 0x3A, 0x43, 0x61, 0x65, 0x8A, 0x74, 0x97, 0x78, 0x9A, 0x75, 0x92, 0x5A, 0x69, 0x37, 0x3D, 0x26, 0x29, 0x1F, 0x22, 0x1A, 0x1C, 0x16, 0x19, 0x14, 0x17, 0x14, 0x17, 0x13, 0x17, 0x14, 0x18, 0x14, 0x18, 0x13, 0x18, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x14, 0x19, 0x14, 0x17, 0x13, 0x17, 0x13, 0x18, 0x14, 0x18, 0x13, 0x17, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x15, 0x12, 0x16, 0x11, 0x15, 0x11, 0x14, 0x11, 0x15, 0x11, 0x14, 0x10, 0x14, 0x10, 0x13, 0x11, 0x13, 0x11, 0x14, 0x11, 0x15, 0x11, 0x14, 0x12, 0x15, 0x11, 0x14, 0x12, 0x15, 0x15, 0x16, 0x12, 0x15, 0x12, 0x15, 0x12, 0x15, 0x12, 0x15, 0x13, 0x16, 0x11, 0x16, 0x12, 0x16, 0x12, 0x15, 0x13, 0x16, 0x17, 0x1A, 0x27, 0x2C, 0x45, 0x46, 0x54, 0x50, 0x59, 0x53, 0x50, 0x48, 0x38, 0x32, 0x3E, 0x3C, 0x53, 0x4E, 0x5D, 0x56, 0x62, 0x5B, 0x65, 0x5A, 0x66, 0x59, 0x69, 0x5D, 0x69, 0x5D, 0x69, 0x5C, 0x69, 0x5C, 0x6B, 0x5E, 0x69, 0x5D, 0x68, 0x5D, 0x68, 0x5D, 0x68, 0x5C, 0x6A, 0x5C, 0x69, 0x5C, 0x6D, 0x5F, 0x6D, 0x60, 0x6E, 0x5F, 0x6C, 0x5D, 0x69, 0x5D, 0x68, 0x5A, 0x67, 0x59, 0x68, 0x5B, 0x65, 0x59, 0x68, 0x5A, 0x69, 0x5B, 0x6C, 0x5E, 0x6C, 0x5D, 0x69, 0x5C, 0x6A, 0x5D, 0x68, 0x5B, 0x67, 0x5D, 0x68, 0x5B, 0x68, 0x5C, 0x68, 0x5B, 0x6A, 0x5C, 0x69, 0x5A, 0x69, 0x5B, 0x68, 0x5B, 0x69, 0x5C, 0x68, 0x5D, 0x6B, 0x5E, 0x69, 0x5C, 0x68, 0x59, 0x69, 0x5C, 0x69, 0x5D, 0x69, 0x5C, 0x6B, 0x5C, 0x6A, 0x5C, 0x6B, 0x5E, 0x69, 0x5D, 0x6A, 0x5C, 0x6B, 0x5C, 0x67, 0x58, 0x65, 0x59, 0x69, 0x5C, 0x69, 0x5B, 0x6A, 0x5D, 0x67, 0x59, 0x69, 0x5C, 0x68, 0x5A, 0x68, 0x5C, 0x6B, 0x5E, 0x6E, 0x5F, 0x6D, 0x5E, 0x6B, 0x5E, 0x69, 0x5C, 0x6A, 0x5D, 0x68, 0x5E, 0x65, 0x60, 0x62, 0x60, 0x5E, 0x57, 0x5D, 0x56, 0x5A, 0x53, 0x4E, 0x4B, 0x49, 0x47, 0x46, 0x47, 0x46, 0x46, 0x47, 0x47, 0x4D, 0x4C, 0x5B, 0x52, 0x61, 0x57, 0x66, 0x5A, 0x62, 0x57, 0x63, 0x57, 0x64, 0x59, 0x66, 0x58, 0x66, 0x5A, 0x66, 0x5A, 0x67, 0x5B, 0x66, 0x59, 0x64, 0x5A, 0x68, 0x5C, 0x6A, 0x5C, 0x68, 0x5A, 0x65, 0x59, 0x67, 0x5B, 0x69, 0x5D, 0x65, 0x58, 0x66, 0x59, 0x67, 0x58, 0x66, 0x5A, 0x64, 0x58, 0x65, 0x59, 0x65, 0x59, 0x69, 0x5C, 0x68, 0x5B, 0x64, 0x59, 0x66, 0x59, 0x67, 0x5A, 0x65, 0x58, 0x66, 0x5A, 0x64, 0x58, 0x66, 0x59, 0x65, 0x5A, 0x63, 0x57, 0x65, 0x58, 0x64, 0x58, 0x63, 0x57, 0x62, 0x58, 0x65, 0x58, 0x61, 0x55, 0x60, 0x54, 0x61, 0x55, 0x61, 0x55, 0x5F, 0x54, 0x5E, 0x55, 0x60, 0x54, 0x5F, 0x54, 0x5D, 0x53, 0x5D, 0x52, 0x5B, 0x50, 0x5B, 0x51, 0x56, 0x4B, 0x39, 0x38, 0x2E, 0x2B, 0x24, 0x25, 0x27, 0x29, 0x22, 0x24, 0x24, 0x27, 0x29, 0x2A, 0x23, 0x26, 0x24, 0x26, 0x21, 0x25, 0x23, 0x25, 0x21, 0x25, 0x24, 0x25, 0x20, 0x20, 0x1F, 0x22, 0x26, 0x29, 0x1E, 0x20, 0x24, 0x26, 0x1F, 0x21, 0x24, 0x26, 0x21, 0x22, 0x24, 0x28, 0x23, 0x24, 0x23, 0x26, 0x20, 0x23, 0x25, 0x29, 0x24, 0x26, 0x25, 0x29, 0x24, 0x26, 0x22, 0x25, 0x25, 0x27, 0x22, 0x25, 0x23, 0x26, 0x20, 0x21, 0x24, 0x28, 0x23, 0x26, 0x2B, 0x31, 0x27, 0x2C, 0x26, 0x29, 0x28, 0x2D, 0x27, 0x2B, 0x28, 0x2A, 0x24, 0x28, 0x27, 0x29
    },

    {
        0x54, 0x1F, 0x54, 0x1D, 0x56, 0x1E, 0x56, 0x1E, 0x55, 0x1E, 0x55, 0x1F, 0x55, 0x1F, 0x53, 0x1E, 0x51, 0x1E, 0x4D, 0x1D, 0x47, 0x1B, 0x3D, 0x19, 0x38, 0x18, 0x3E, 0x19, 0x45, 0x1B, 0x45, 0x1B, 0x3C, 0x18, 0x2E, 0x15, 0x21, 0x12, 0x1C, 0x10, 0x19, 0x10, 0x19, 0x11, 0x17, 0x10, 0x16, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x16, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x14, 0x0F, 0x14, 0x0F, 0x14, 0x0F, 0x14, 0x0E, 0x14, 0x0F, 0x14, 0x0F, 0x14, 0x0F, 0x14, 0x0E, 0x15, 0x0F, 0x14, 0x0E, 0x14, 0x0E, 0x14, 0x0F, 0x14, 0x0F, 0x14, 0x0E, 0x14, 0x0F, 0x15, 0x10, 0x15, 0x0F, 0x15, 0x0F, 0x16, 0x10, 0x15, 0x10, 0x16, 0x10, 0x17, 0x11, 0x17, 0x11, 0x19, 0x12, 0x1A, 0x12, 0x1A, 0x12, 0x19, 0x11, 0x18, 0x11, 0x1B, 0x14, 0x25, 0x1E, 0x3F, 0x34, 0x68, 0x4E, 0x8C, 0x63, 0x96, 0x69, 0x9B, 0x68, 0x96, 0x64, 0x77, 0x4A, 0x46, 0x2D, 0x2E, 0x1E, 0x25, 0x19, 0x22, 0x18, 0x24, 0x1B, 0x31, 0x29, 0x54, 0x42, 0x7F, 0x5D, 0x98, 0x6B, 0xA2, 0x70, 0xA7, 0x72, 0xA5, 0x71, 0x9F, 0x69, 0x72, 0x46, 0x40, 0x29, 0x2B, 0x1D, 0x23, 0x18, 0x1E, 0x15, 0x1A, 0x12, 0x19, 0x12, 0x18, 0x11, 0x19, 0x12, 0x19, 0x11, 0x18, 0x11, 0x19, 0x12, 0x18, 0x12, 0x18, 0x11, 0x19, 0x12, 0x19, 0x12, 0x19, 0x11, 0x18, 0x12, 0x18, 0x11, 0x17, 0x11, 0x18, 0x11, 0x18, 0x11, 0x17, 0x11, 0x17, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x0F, 0x16, 0x10, 0x16, 0x10, 0x15, 0x0F, 0x15, 0x0F, 0x14, 0x0E, 0x14, 0x0F, 0x16, 0x10, 0x15, 0x10, 0x16, 0x10, 0x16, 0x10, 0x15, 0x0F, 0x16, 0x0F, 0x16, 0x0F, 0x16, 0x10, 0x16, 0x0F, 0x16, 0x10, 0x17, 0x10, 0x18, 0x11, 0x17, 0x10, 0x16, 0x10, 0x17, 0x10, 0x17, 0x0F, 0x16, 0x10, 0x19, 0x12, 0x2E, 0x18, 0x4A, 0x1D, 0x57, 0x21, 0x5B, 0x22, 0x4C, 0x1D, 0x32, 0x19, 0x3D, 0x1C, 0x55, 0x21, 0x5C, 0x22, 0x5C, 0x22, 0x5D, 0x21, 0x5F, 0x22, 0x5C, 0x21, 0x60, 0x22, 0x61, 0x22, 0x62, 0x21, 0x61, 0x22, 0x64, 0x23, 0x63, 0x23, 0x61, 0x22, 0x5C, 0x20, 0x5E, 0x22, 0x60, 0x23, 0x62, 0x22, 0x62, 0x23, 0x64, 0x24, 0x63, 0x24, 0x5F, 0x22, 0x5E, 0x22, 0x5E, 0x22, 0x5E, 0x21, 0x60, 0x22, 0x61, 0x21, 0x64, 0x23, 0x60, 0x22, 0x61, 0x22, 0x60, 0x22, 0x60, 0x22, 0x61, 0x24, 0x63, 0x23, 0x62, 0x24, 0x64, 0x24, 0x62, 0x23, 0x60, 0x22, 0x61, 0x23, 0x65, 0x24, 0x63, 0x24, 0x60, 0x24, 0x61, 0x24, 0x61, 0x23, 0x60, 0x21, 0x5F, 0x22, 0x65, 0x23, 0x62, 0x22, 0x61, 0x23, 0x61, 0x22, 0x60, 0x22, 0x62, 0x23, 0x62, 0x22, 0x60, 0x23, 0x5F, 0x22, 0x5E, 0x22, 0x5F, 0x21, 0x5F, 0x21, 0x60, 0x22, 0x5C, 0x21, 0x5D, 0x21, 0x5D, 0x21, 0x5E, 0x22, 0x5F, 0x22, 0x61, 0x22, 0x5F, 0x22, 0x60, 0x22, 0x5F, 0x22, 0x5D, 0x24, 0x67, 0x31, 0x6B, 0x38, 0x5D, 0x32, 0x4C, 0x26, 0x43, 0x1F, 0x4B, 0x22, 0x4A, 0x23, 0x4B, 0x23, 0x4A, 0x23, 0x49, 0x23, 0x4B, 0x24, 0x47, 0x1F, 0x4B, 0x1E, 0x56, 0x21, 0x5E, 0x22, 0x5B, 0x21, 0x5D, 0x21, 0x5B, 0x22, 0x5C, 0x22, 0x5C, 0x22, 0x60, 0x23, 0x60, 0x22, 0x5D, 0x21, 0x5C, 0x21, 0x5E, 0x22, 0x60, 0x22, 0x5E, 0x21, 0x5A, 0x21, 0x5F, 0x22, 0x5E, 0x22, 0x5D, 0x22, 0x5C, 0x21, 0x5E, 0x22, 0x5F, 0x23, 0x5E, 0x23, 0x5D, 0x22, 0x5D, 0x21, 0x5F, 0x22, 0x5D, 0x22, 0x5D, 0x21, 0x5C, 0x22, 0x5C, 0x22, 0x5D, 0x21, 0x5E, 0x22, 0x5C, 0x21, 0x5D, 0x22, 0x5C, 0x22, 0x5D, 0x22, 0x5C, 0x22, 0x59, 0x20, 0x5A, 0x21, 0x5A, 0x22, 0x5D, 0x22, 0x59, 0x21, 0x5A, 0x20, 0x58, 0x20, 0x59, 0x22, 0x5B, 0x22, 0x58, 0x20, 0x57, 0x20, 0x58, 0x21, 0x57, 0x20, 0x53, 0x1F, 0x55, 0x20, 0x54, 0x1F, 0x50, 0x1E, 0x40, 0x1E, 0x2C, 0x18, 0x28, 0x18, 0x28, 0x17, 0x23, 0x15, 0x2B, 0x19, 0x28, 0x17, 0x26, 0x17, 0x27, 0x17, 0x2C, 0x19, 0x28, 0x17, 0x26, 0x17, 0x2B, 0x19, 0x2A, 0x18, 0x2F, 0x19, 0x26, 0x17, 0x28, 0x17, 0x2A, 0x18, 0x2D, 0x1A, 0x2C, 0x19, 0x2C, 0x19, 0x2B, 0x1A, 0x2C, 0x19, 0x30, 0x1A, 0x2C, 0x19, 0x29, 0x18, 0x2B, 0x19, 0x31, 0x1B, 0x2D, 0x19, 0x29, 0x18, 0x2E, 0x1B, 0x28, 0x18, 0x2C, 0x19, 0x24, 0x16, 0x2D, 0x1B, 0x2D, 0x1A, 0x31, 0x1B, 0x2F, 0x1A, 0x25, 0x17, 0x34, 0x1E, 0x2B, 0x1A, 0x26, 0x19, 0x29, 0x1A, 0x2B, 0x1B
    },

    {
        0x5B, 0x53, 0x5C, 0x52, 0x5D, 0x52, 0x5E, 0x53, 0x5E, 0x54, 0x5D, 0x53, 0x5D, 0x52, 0x5A, 0x51, 0x55, 0x4D, 0x51, 0x49, 0x4A, 0x40, 0x3F, 0x38, 0x3A, 0x37, 0x41, 0x40, 0x49, 0x43, 0x45, 0x3F, 0x3B, 0x35, 0x2B, 0x27, 0x1D, 0x1D, 0x18, 0x1A, 0x16, 0x18, 0x14, 0x18, 0x13, 0x16, 0x12, 0x15, 0x11, 0x15, 0x11, 0x14, 0x11, 0x14, 0x11, 0x14, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x14, 0x10, 0x14, 0x10, 0x14, 0x0F, 0x13, 0x10, 0x14, 0x10, 0x13, 0x10, 0x13, 0x10, 0x13, 0x0F, 0x13, 0x10, 0x13, 0x10, 0x13, 0x10, 0x13, 0x10, 0x13, 0x10, 0x13, 0x10, 0x14, 0x10, 0x14, 0x10, 0x14, 0x10, 0x14, 0x11, 0x14, 0x10, 0x14, 0x11, 0x15, 0x11, 0x16, 0x11, 0x16, 0x12, 0x16, 0x13, 0x17, 0x13, 0x18, 0x14, 0x19, 0x14, 0x19, 0x13, 0x18, 0x14, 0x18, 0x18, 0x1D, 0x22, 0x2C, 0x35, 0x4B, 0x52, 0x74, 0x6B, 0x8C, 0x72, 0x93, 0x75, 0x94, 0x74, 0x92, 0x64, 0x7A, 0x41, 0x48, 0x2B, 0x2E, 0x22, 0x26, 0x1E, 0x22, 0x21, 0x27, 0x2B, 0x3B, 0x43, 0x60, 0x61, 0x86, 0x74, 0x96, 0x7B, 0xA0, 0x80, 0xA3, 0x80, 0xA3, 0x7B, 0x9C, 0x61, 0x72, 0x3C, 0x41, 0x27, 0x2C, 0x1F, 0x22, 0x1A, 0x1D, 0x16, 0x19, 0x14, 0x18, 0x13, 0x17, 0x14, 0x19, 0x14, 0x18, 0x13, 0x18, 0x14, 0x18, 0x13, 0x18, 0x13, 0x17, 0x14, 0x19, 0x14, 0x18, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x13, 0x16, 0x13, 0x17, 0x13, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x10, 0x14, 0x11, 0x14, 0x10, 0x14, 0x10, 0x14, 0x11, 0x15, 0x12, 0x16, 0x11, 0x15, 0x11, 0x14, 0x11, 0x14, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x12, 0x16, 0x13, 0x17, 0x12, 0x16, 0x12, 0x16, 0x12, 0x15, 0x12, 0x15, 0x13, 0x16, 0x16, 0x18, 0x25, 0x29, 0x43, 0x44, 0x55, 0x53, 0x5E, 0x59, 0x53, 0x4B, 0x38, 0x32, 0x3B, 0x3A, 0x53, 0x50, 0x5D, 0x57, 0x61, 0x58, 0x62, 0x59, 0x67, 0x5C, 0x66, 0x5A, 0x69, 0x5C, 0x6A, 0x5C, 0x6A, 0x5E, 0x69, 0x5E, 0x6C, 0x5E, 0x6A, 0x5F, 0x6B, 0x5D, 0x68, 0x59, 0x68, 0x5C, 0x69, 0x5D, 0x6B, 0x5E, 0x6A, 0x5E, 0x6D, 0x62, 0x6B, 0x5F, 0x68, 0x5B, 0x68, 0x5B, 0x68, 0x5C, 0x67, 0x5B, 0x6B, 0x5D, 0x6B, 0x5E, 0x6D, 0x5F, 0x69, 0x5D, 0x6A, 0x5D, 0x69, 0x5C, 0x6A, 0x5C, 0x6A, 0x5F, 0x6C, 0x5F, 0x6A, 0x5F, 0x6D, 0x61, 0x6C, 0x60, 0x6A, 0x5D, 0x6B, 0x5F, 0x6C, 0x60, 0x6C, 0x5F, 0x68, 0x5D, 0x6B, 0x5E, 0x6A, 0x5E, 0x69, 0x5B, 0x69, 0x5C, 0x6D, 0x5F, 0x6B, 0x5E, 0x6B, 0x5D, 0x69, 0x5C, 0x6A, 0x5C, 0x6B, 0x5E, 0x6C, 0x5F, 0x69, 0x5C, 0x6A, 0x5C, 0x66, 0x5B, 0x69, 0x5B, 0x69, 0x5C, 0x6B, 0x5D, 0x66, 0x59, 0x67, 0x5B, 0x66, 0x59, 0x65, 0x59, 0x67, 0x5B, 0x69, 0x5C, 0x68, 0x5B, 0x69, 0x5D, 0x68, 0x5C, 0x63, 0x5A, 0x63, 0x66, 0x5F, 0x62, 0x50, 0x51, 0x47, 0x43, 0x41, 0x3C, 0x47, 0x46, 0x45, 0x47, 0x46, 0x47, 0x45, 0x47, 0x45, 0x47, 0x45, 0x47, 0x44, 0x43, 0x4A, 0x46, 0x5C, 0x54, 0x64, 0x59, 0x62, 0x58, 0x64, 0x59, 0x65, 0x59, 0x64, 0x5A, 0x67, 0x5A, 0x67, 0x5D, 0x68, 0x5C, 0x66, 0x59, 0x65, 0x59, 0x67, 0x5C, 0x68, 0x5B, 0x68, 0x5B, 0x65, 0x58, 0x67, 0x5B, 0x66, 0x5A, 0x65, 0x59, 0x66, 0x59, 0x66, 0x5A, 0x67, 0x5C, 0x67, 0x5B, 0x66, 0x59, 0x66, 0x59, 0x67, 0x5B, 0x68, 0x5C, 0x66, 0x5B, 0x67, 0x5A, 0x67, 0x59, 0x67, 0x5B, 0x67, 0x5A, 0x64, 0x58, 0x66, 0x59, 0x64, 0x59, 0x67, 0x5A, 0x65, 0x5A, 0x61, 0x56, 0x63, 0x57, 0x63, 0x5A, 0x66, 0x5B, 0x63, 0x57, 0x63, 0x57, 0x60, 0x53, 0x61, 0x56, 0x61, 0x57, 0x5E, 0x53, 0x5E, 0x53, 0x60, 0x55, 0x5E, 0x54, 0x5B, 0x51, 0x5E, 0x52, 0x5C, 0x50, 0x57, 0x4C, 0x3C, 0x3A, 0x29, 0x27, 0x25, 0x27, 0x24, 0x25, 0x21, 0x23, 0x28, 0x2E, 0x22, 0x25, 0x22, 0x25, 0x25, 0x29, 0x28, 0x2C, 0x24, 0x29, 0x21, 0x24, 0x27, 0x2D, 0x28, 0x2D, 0x2A, 0x2E, 0x23, 0x27, 0x25, 0x28, 0x27, 0x2C, 0x2B, 0x31, 0x28, 0x2B, 0x27, 0x2B, 0x27, 0x2D, 0x28, 0x2C, 0x28, 0x2C, 0x28, 0x2B, 0x24, 0x29, 0x28, 0x2A, 0x2A, 0x30, 0x27, 0x2A, 0x22, 0x25, 0x28, 0x2E, 0x22, 0x26, 0x25, 0x29, 0x1F, 0x23, 0x28, 0x2F, 0x26, 0x2B, 0x27, 0x2A, 0x27, 0x2A, 0x21, 0x24, 0x2A, 0x31, 0x23, 0x27, 0x20, 0x24, 0x22, 0x2A, 0x23, 0x28
    },

    {
        0x55, 0x1F, 0x54, 0x1E, 0x54, 0x1E, 0x55, 0x1E, 0x55, 0x1E, 0x56, 0x1E, 0x53, 0x1E, 0x51, 0x1D, 0x4D, 0x1D, 0x47, 0x1C, 0x3F, 0x1B, 0x38, 0x19, 0x3C, 0x1A, 0x45, 0x1B, 0x45, 0x1A, 0x3C, 0x19, 0x2E, 0x15, 0x21, 0x12, 0x1C, 0x11, 0x19, 0x10, 0x18, 0x0F, 0x17, 0x10, 0x16, 0x10, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x14, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x14, 0x0E, 0x14, 0x0E, 0x14, 0x0E, 0x14, 0x0F, 0x15, 0x0F, 0x14, 0x0F, 0x14, 0x0E, 0x14, 0x0F, 0x15, 0x0F, 0x14, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x10, 0x15, 0x0F, 0x15, 0x10, 0x16, 0x10, 0x16, 0x10, 0x17, 0x11, 0x18, 0x11, 0x18, 0x11, 0x19, 0x11, 0x19, 0x12, 0x19, 0x12, 0x1B, 0x15, 0x25, 0x1E, 0x3E, 0x32, 0x66, 0x4C, 0x89, 0x60, 0x95, 0x68, 0x9C, 0x6B, 0x9E, 0x6D, 0x9F, 0x6D, 0x9C, 0x6A, 0x84, 0x51, 0x50, 0x31, 0x33, 0x22, 0x2C, 0x20, 0x35, 0x2A, 0x53, 0x42, 0x7F, 0x5D, 0x99, 0x6B, 0xA1, 0x6F, 0xAA, 0x74, 0xAF, 0x77, 0xB0, 0x78, 0xAD, 0x76, 0xA5, 0x6D, 0x7A, 0x4B, 0x46, 0x2C, 0x2D, 0x1E, 0x23, 0x18, 0x1E, 0x15, 0x1A, 0x12, 0x19, 0x12, 0x19, 0x12, 0x1A, 0x12, 0x19, 0x11, 0x19, 0x12, 0x19, 0x12, 0x19, 0x12, 0x19, 0x12, 0x19, 0x12, 0x18, 0x12, 0x18, 0x11, 0x18, 0x10, 0x17, 0x11, 0x18, 0x10, 0x17, 0x10, 0x17, 0x10, 0x16, 0x10, 0x16, 0x10, 0x17, 0x10, 0x16, 0x0F, 0x16, 0x10, 0x17, 0x10, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0E, 0x15, 0x0F, 0x16, 0x10, 0x16, 0x10, 0x16, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x17, 0x11, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x16, 0x0F, 0x17, 0x10, 0x15, 0x0F, 0x16, 0x0F, 0x19, 0x11, 0x2A, 0x17, 0x4C, 0x1F, 0x58, 0x22, 0x5B, 0x22, 0x4C, 0x1D, 0x35, 0x19, 0x3D, 0x1D, 0x53, 0x21, 0x58, 0x21, 0x5A, 0x21, 0x5D, 0x21, 0x5F, 0x21, 0x5E, 0x22, 0x5F, 0x21, 0x5E, 0x22, 0x60, 0x22, 0x60, 0x22, 0x62, 0x23, 0x64, 0x23, 0x5F, 0x21, 0x60, 0x21, 0x5F, 0x22, 0x60, 0x22, 0x61, 0x23, 0x63, 0x24, 0x63, 0x24, 0x61, 0x23, 0x62, 0x22, 0x60, 0x22, 0x5D, 0x21, 0x5F, 0x22, 0x61, 0x22, 0x62, 0x23, 0x62, 0x23, 0x60, 0x22, 0x60, 0x22, 0x63, 0x23, 0x60, 0x22, 0x60, 0x22, 0x61, 0x23, 0x64, 0x24, 0x65, 0x25, 0x62, 0x23, 0x63, 0x23, 0x61, 0x24, 0x61, 0x23, 0x61, 0x23, 0x63, 0x24, 0x62, 0x23, 0x5E, 0x22, 0x5E, 0x22, 0x61, 0x22, 0x61, 0x22, 0x62, 0x23, 0x5E, 0x21, 0x60, 0x22, 0x61, 0x22, 0x62, 0x23, 0x61, 0x23, 0x61, 0x22, 0x61, 0x23, 0x62, 0x23, 0x60, 0x22, 0x60, 0x22, 0x5E, 0x22, 0x60, 0x21, 0x5D, 0x21, 0x5E, 0x21, 0x5E, 0x21, 0x5F, 0x22, 0x5F, 0x23, 0x61, 0x23, 0x5E, 0x23, 0x5F, 0x2A, 0x63, 0x35, 0x51, 0x2C, 0x41, 0x22, 0x38, 0x1E, 0x31, 0x1A, 0x3F, 0x20, 0x48, 0x22, 0x49, 0x22, 0x49, 0x24, 0x48, 0x23, 0x47, 0x23, 0x45, 0x20, 0x41, 0x1B, 0x4F, 0x1F, 0x5A, 0x21, 0x5E, 0x22, 0x5D, 0x22, 0x5E, 0x22, 0x5E, 0x22, 0x5D, 0x22, 0x5F, 0x22, 0x5E, 0x22, 0x5D, 0x21, 0x5B, 0x21, 0x5C, 0x21, 0x5A, 0x21, 0x60, 0x22, 0x60, 0x22, 0x5D, 0x22, 0x5E, 0x22, 0x5D, 0x22, 0x60, 0x22, 0x60, 0x23, 0x60, 0x23, 0x62, 0x23, 0x5C, 0x22, 0x5C, 0x21, 0x5D, 0x22, 0x5E, 0x22, 0x5E, 0x22, 0x5B, 0x22, 0x5E, 0x22, 0x5E, 0x22, 0x5C, 0x22, 0x5B, 0x21, 0x5E, 0x21, 0x60, 0x22, 0x5A, 0x22, 0x5D, 0x22, 0x5D, 0x21, 0x5C, 0x22, 0x5D, 0x21, 0x5C, 0x20, 0x5A, 0x21, 0x5A, 0x20, 0x59, 0x22, 0x5A, 0x22, 0x55, 0x20, 0x56, 0x1F, 0x56, 0x20, 0x57, 0x20, 0x56, 0x20, 0x58, 0x20, 0x54, 0x20, 0x52, 0x1F, 0x4F, 0x1D, 0x38, 0x1B, 0x2F, 0x19, 0x29, 0x18, 0x30, 0x1A, 0x34, 0x1B, 0x2C, 0x18, 0x2D, 0x1B, 0x28, 0x19, 0x36, 0x1D, 0x30, 0x1B, 0x2F, 0x1B, 0x27, 0x19, 0x38, 0x1F, 0x31, 0x1B, 0x26, 0x17, 0x2D, 0x1A, 0x29, 0x17, 0x33, 0x1C, 0x30, 0x1C, 0x2F, 0x1D, 0x2C, 0x1C, 0x33, 0x20, 0x30, 0x1E, 0x29, 0x1B, 0x2D, 0x1B, 0x2A, 0x1A, 0x2F, 0x19, 0x26, 0x17, 0x2C, 0x1C, 0x29, 0x1F, 0x32, 0x22, 0x28, 0x1F, 0x2D, 0x22, 0x2C, 0x24, 0x35, 0x27, 0x29, 0x1D, 0x26, 0x19, 0x29, 0x18, 0x24, 0x1C, 0x35, 0x2C, 0x2E, 0x2B, 0x32, 0x31, 0x35, 0x33, 0x36, 0x34
    },

    {
        0x5C, 0x52, 0x5C, 0x51, 0x5D, 0x51, 0x5E, 0x52, 0x5E, 0x52, 0x5D, 0x52, 0x5B, 0x4F, 0x56, 0x4D, 0x51, 0x49, 0x4B, 0x42, 0x41, 0x3A, 0x3B, 0x37, 0x40, 0x3D, 0x48, 0x43, 0x48, 0x40, 0x3D, 0x36, 0x2C, 0x28, 0x1E, 0x1E, 0x18, 0x1A, 0x16, 0x17, 0x14, 0x17, 0x13, 0x17, 0x13, 0x16, 0x12, 0x15, 0x12, 0x14, 0x11, 0x14, 0x11, 0x14, 0x11, 0x14, 0x11, 0x15, 0x11, 0x15, 0x12, 0x15, 0x11, 0x15, 0x11, 0x14, 0x10, 0x14, 0x11, 0x14, 0x11, 0x13, 0x11, 0x14, 0x10, 0x14, 0x10, 0x13, 0x10, 0x13, 0x0F, 0x13, 0x10, 0x13, 0x10, 0x13, 0x10, 0x13, 0x10, 0x13, 0x10, 0x13, 0x10, 0x13, 0x10, 0x13, 0x11, 0x14, 0x10, 0x14, 0x11, 0x14, 0x10, 0x14, 0x11, 0x15, 0x11, 0x16, 0x11, 0x15, 0x12, 0x16, 0x13, 0x17, 0x13, 0x17, 0x14, 0x18, 0x14, 0x18, 0x15, 0x19, 0x19, 0x1D, 0x21, 0x2B, 0x34, 0x49, 0x51, 0x71, 0x69, 0x8A, 0x73, 0x93, 0x77, 0x97, 0x7A, 0x99, 0x7A, 0x9B, 0x78, 0x99, 0x6A, 0x81, 0x48, 0x51, 0x2F, 0x34, 0x2A, 0x2F, 0x30, 0x3D, 0x44, 0x60, 0x64, 0x88, 0x75, 0x96, 0x79, 0x9E, 0x80, 0xA3, 0x85, 0xA8, 0x86, 0xA8, 0x84, 0xA6, 0x7F, 0xA1, 0x69, 0x7B, 0x41, 0x47, 0x2A, 0x2D, 0x1F, 0x23, 0x1A, 0x1D, 0x17, 0x1A, 0x15, 0x18, 0x14, 0x18, 0x14, 0x19, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x13, 0x18, 0x13, 0x18, 0x13, 0x17, 0x13, 0x17, 0x13, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x15, 0x12, 0x15, 0x12, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x12, 0x15, 0x10, 0x14, 0x11, 0x14, 0x11, 0x13, 0x11, 0x14, 0x12, 0x16, 0x12, 0x15, 0x11, 0x15, 0x11, 0x14, 0x11, 0x14, 0x11, 0x14, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x12, 0x15, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x13, 0x16, 0x12, 0x15, 0x12, 0x16, 0x12, 0x15, 0x13, 0x15, 0x15, 0x17, 0x22, 0x25, 0x42, 0x45, 0x57, 0x53, 0x5E, 0x58, 0x54, 0x4C, 0x3C, 0x34, 0x3A, 0x39, 0x50, 0x4E, 0x5C, 0x56, 0x5F, 0x55, 0x64, 0x59, 0x65, 0x59, 0x66, 0x5A, 0x69, 0x5A, 0x68, 0x5B, 0x69, 0x5D, 0x6B, 0x5D, 0x6C, 0x5E, 0x6E, 0x5F, 0x6A, 0x5C, 0x6A, 0x5D, 0x68, 0x5B, 0x69, 0x5C, 0x69, 0x5F, 0x6C, 0x61, 0x6B, 0x60, 0x6B, 0x5E, 0x6B, 0x5D, 0x6A, 0x5D, 0x68, 0x5B, 0x68, 0x5C, 0x6B, 0x5C, 0x6B, 0x5E, 0x6B, 0x5E, 0x6A, 0x5D, 0x6A, 0x5D, 0x6B, 0x5F, 0x69, 0x5C, 0x68, 0x5D, 0x6A, 0x5E, 0x6B, 0x5E, 0x6B, 0x61, 0x6B, 0x5E, 0x6B, 0x5E, 0x6A, 0x5E, 0x6A, 0x5E, 0x69, 0x5E, 0x6A, 0x5D, 0x6C, 0x5F, 0x68, 0x5A, 0x68, 0x5B, 0x6C, 0x5E, 0x6C, 0x5E, 0x6C, 0x5F, 0x69, 0x5D, 0x68, 0x5D, 0x6B, 0x5D, 0x6B, 0x5E, 0x6B, 0x5D, 0x6B, 0x5D, 0x6A, 0x5D, 0x6C, 0x5F, 0x6B, 0x5D, 0x6A, 0x5D, 0x6B, 0x5C, 0x69, 0x5C, 0x66, 0x5A, 0x67, 0x5B, 0x67, 0x59, 0x68, 0x5C, 0x6A, 0x5D, 0x69, 0x5C, 0x65, 0x5B, 0x5E, 0x5B, 0x57, 0x59, 0x47, 0x42, 0x3C, 0x37, 0x35, 0x30, 0x32, 0x2D, 0x3D, 0x40, 0x43, 0x44, 0x43, 0x46, 0x45, 0x46, 0x43, 0x44, 0x43, 0x45, 0x40, 0x40, 0x3F, 0x3D, 0x52, 0x4E, 0x61, 0x58, 0x66, 0x5C, 0x67, 0x59, 0x65, 0x5B, 0x69, 0x5B, 0x68, 0x5B, 0x67, 0x5A, 0x67, 0x5A, 0x65, 0x59, 0x67, 0x59, 0x63, 0x57, 0x63, 0x57, 0x68, 0x5D, 0x69, 0x5C, 0x66, 0x5A, 0x66, 0x5C, 0x67, 0x5A, 0x69, 0x5C, 0x67, 0x5D, 0x69, 0x5F, 0x69, 0x5E, 0x67, 0x59, 0x66, 0x58, 0x65, 0x5A, 0x6A, 0x5B, 0x66, 0x59, 0x67, 0x5A, 0x66, 0x59, 0x66, 0x5B, 0x63, 0x58, 0x64, 0x57, 0x66, 0x5B, 0x67, 0x5B, 0x63, 0x58, 0x66, 0x59, 0x66, 0x5B, 0x65, 0x59, 0x65, 0x59, 0x64, 0x57, 0x64, 0x57, 0x63, 0x56, 0x62, 0x59, 0x61, 0x56, 0x5F, 0x52, 0x5D, 0x52, 0x5E, 0x54, 0x5F, 0x54, 0x5F, 0x54, 0x61, 0x54, 0x5D, 0x51, 0x5B, 0x4E, 0x54, 0x49, 0x36, 0x34, 0x2D, 0x2B, 0x26, 0x28, 0x2B, 0x30, 0x2D, 0x31, 0x24, 0x25, 0x27, 0x2D, 0x23, 0x28, 0x2D, 0x32, 0x26, 0x2C, 0x27, 0x2B, 0x22, 0x29, 0x2F, 0x35, 0x28, 0x2C, 0x20, 0x22, 0x2A, 0x2E, 0x25, 0x26, 0x2C, 0x32, 0x26, 0x2A, 0x26, 0x2E, 0x23, 0x29, 0x2A, 0x35, 0x26, 0x2D, 0x21, 0x29, 0x24, 0x29, 0x23, 0x29, 0x27, 0x2A, 0x20, 0x22, 0x26, 0x2E, 0x21, 0x2D, 0x25, 0x30, 0x1E, 0x2B, 0x21, 0x2F, 0x20, 0x31, 0x26, 0x36, 0x21, 0x28, 0x22, 0x28, 0x24, 0x26, 0x1F, 0x29, 0x23, 0x33, 0x1E, 0x31, 0x20, 0x36, 0x22, 0x39, 0x21, 0x36
    },

    {
        0x54, 0x1F, 0x54, 0x1E, 0x55, 0x1F, 0x55, 0x1E, 0x56, 0x1E, 0x55, 0x1E, 0x51, 0x1D, 0x4C, 0x1C, 0x47, 0x1B, 0x3F, 0x1A, 0x3A, 0x1A, 0x3E, 0x1B, 0x47, 0x1C, 0x46, 0x1B, 0x3F, 0x19, 0x31, 0x16, 0x24, 0x13, 0x1C, 0x11, 0x19, 0x10, 0x18, 0x0F, 0x18, 0x10, 0x1A, 0x12, 0x1A, 0x12, 0x17, 0x10, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x16, 0x10, 0x17, 0x10, 0x17, 0x10, 0x16, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x14, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x14, 0x0F, 0x14, 0x0F, 0x14, 0x0E, 0x14, 0x0E, 0x14, 0x0F, 0x14, 0x0F, 0x14, 0x0E, 0x14, 0x0F, 0x14, 0x0F, 0x14, 0x0F, 0x15, 0x0F, 0x14, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x18, 0x11, 0x18, 0x11, 0x19, 0x12, 0x1A, 0x12, 0x1C, 0x15, 0x25, 0x1E, 0x3C, 0x31, 0x63, 0x4C, 0x89, 0x60, 0x98, 0x69, 0xA0, 0x6D, 0xA2, 0x6F, 0xA4, 0x6F, 0xA7, 0x71, 0xA6, 0x72, 0xA2, 0x6D, 0x8D, 0x58, 0x5C, 0x3A, 0x44, 0x32, 0x57, 0x44, 0x81, 0x5E, 0x9D, 0x6D, 0xA5, 0x72, 0xA8, 0x75, 0xAD, 0x76, 0xB1, 0x79, 0xB3, 0x7C, 0xB4, 0x7B, 0xB1, 0x79, 0xA9, 0x6F, 0x83, 0x50, 0x49, 0x2F, 0x2E, 0x1E, 0x24, 0x19, 0x1E, 0x16, 0x1B, 0x13, 0x19, 0x19, 0x1A, 0x12, 0x19, 0x12, 0x19, 0x12, 0x19, 0x12, 0x19, 0x11, 0x19, 0x11, 0x18, 0x11, 0x17, 0x10, 0x18, 0x11, 0x18, 0x11, 0x17, 0x11, 0x17, 0x10, 0x17, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x16, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x16, 0x0F, 0x16, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x17, 0x10, 0x17, 0x10, 0x16, 0x0F, 0x16, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x15, 0x0F, 0x15, 0x0F, 0x16, 0x0F, 0x15, 0x0F, 0x16, 0x10, 0x1A, 0x11, 0x2A, 0x17, 0x48, 0x1E, 0x5A, 0x21, 0x5C, 0x22, 0x52, 0x1E, 0x36, 0x19, 0x39, 0x1C, 0x50, 0x1F, 0x58, 0x20, 0x5D, 0x22, 0x5C, 0x21, 0x5E, 0x21, 0x5F, 0x22, 0x60, 0x21, 0x61, 0x22, 0x61, 0x22, 0x60, 0x22, 0x62, 0x23, 0x62, 0x22, 0x61, 0x21, 0x5E, 0x21, 0x60, 0x21, 0x60, 0x22, 0x61, 0x23, 0x63, 0x24, 0x63, 0x22, 0x62, 0x22, 0x62, 0x23, 0x62, 0x23, 0x60, 0x22, 0x62, 0x23, 0x62, 0x22, 0x63, 0x24, 0x65, 0x23, 0x62, 0x22, 0x62, 0x23, 0x5F, 0x22, 0x60, 0x22, 0x62, 0x23, 0x61, 0x22, 0x64, 0x23, 0x62, 0x23, 0x62, 0x23, 0x63, 0x23, 0x64, 0x25, 0x63, 0x24, 0x64, 0x24, 0x61, 0x22, 0x5F, 0x22, 0x60, 0x23, 0x63, 0x23, 0x62, 0x23, 0x63, 0x23, 0x62, 0x22, 0x60, 0x23, 0x61, 0x22, 0x61, 0x23, 0x61, 0x23, 0x5F, 0x22, 0x5F, 0x22, 0x63, 0x23, 0x63, 0x23, 0x5F, 0x22, 0x5F, 0x21, 0x60, 0x21, 0x60, 0x22, 0x60, 0x22, 0x5E, 0x21, 0x60, 0x22, 0x60, 0x23, 0x61, 0x23, 0x5E, 0x23, 0x54, 0x29, 0x48, 0x26, 0x37, 0x1E, 0x2F, 0x19, 0x2B, 0x18, 0x2A, 0x17, 0x3C, 0x1F, 0x47, 0x23, 0x49, 0x24, 0x49, 0x23, 0x48, 0x23, 0x49, 0x23, 0x46, 0x20, 0x36, 0x18, 0x49, 0x1D, 0x5B, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x5E, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x5E, 0x22, 0x5D, 0x22, 0x5F, 0x22, 0x5E, 0x21, 0x5B, 0x21, 0x5B, 0x21, 0x5D, 0x21, 0x5F, 0x22, 0x5C, 0x21, 0x5F, 0x21, 0x5E, 0x22, 0x5E, 0x22, 0x60, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x5E, 0x22, 0x5E, 0x22, 0x5F, 0x22, 0x5E, 0x22, 0x5F, 0x22, 0x60, 0x23, 0x5D, 0x22, 0x5E, 0x22, 0x5E, 0x23, 0x5B, 0x21, 0x5C, 0x21, 0x5C, 0x21, 0x59, 0x21, 0x5C, 0x22, 0x5E, 0x22, 0x5F, 0x22, 0x5C, 0x20, 0x59, 0x20, 0x5A, 0x20, 0x5A, 0x20, 0x59, 0x22, 0x5A, 0x21, 0x56, 0x1F, 0x55, 0x20, 0x55, 0x1F, 0x56, 0x20, 0x55, 0x1E, 0x54, 0x1E, 0x53, 0x1F, 0x53, 0x1E, 0x4D, 0x1C, 0x35, 0x1A, 0x2B, 0x18, 0x26, 0x17, 0x31, 0x1A, 0x27, 0x17, 0x24, 0x17, 0x2F, 0x1C, 0x2D, 0x20, 0x34, 0x24, 0x2F, 0x24, 0x31, 0x24, 0x2F, 0x26, 0x3A, 0x2A, 0x2D, 0x20, 0x26, 0x19, 0x2E, 0x1B, 0x28, 0x19, 0x39, 0x29, 0x39, 0x31, 0x43, 0x3A, 0x3F, 0x39, 0x46, 0x3F, 0x43, 0x3B, 0x41, 0x3C, 0x33, 0x25, 0x2C, 0x1B, 0x2B, 0x19, 0x27, 0x1D, 0x3D, 0x3A, 0x47, 0x45, 0x47, 0x46, 0x46, 0x47, 0x4A, 0x4B, 0x4B, 0x4B, 0x4B, 0x46, 0x36, 0x25, 0x31, 0x1D, 0x2D, 0x1A, 0x33, 0x2C, 0x41, 0x42, 0x46, 0x49, 0x45, 0x48, 0x45, 0x49, 0x45, 0x49
    },

    {
        0x5B, 0x52, 0x5C, 0x52, 0x5D, 0x52, 0x5D, 0x52, 0x5D, 0x53, 0x5C, 0x52, 0x57, 0x4D, 0x51, 0x48, 0x4A, 0x42, 0x40, 0x3A, 0x3B, 0x39, 0x41, 0x3F, 0x4A, 0x47, 0x47, 0x41, 0x3D, 0x38, 0x2E, 0x2A, 0x1F, 0x1E, 0x19, 0x1A, 0x16, 0x18, 0x14, 0x17, 0x13, 0x17, 0x14, 0x1A, 0x15, 0x1A, 0x13, 0x16, 0x11, 0x15, 0x11, 0x14, 0x11, 0x14, 0x11, 0x14, 0x11, 0x15, 0x11, 0x15, 0x11, 0x16, 0x12, 0x16, 0x11, 0x14, 0x11, 0x15, 0x11, 0x14, 0x10, 0x14, 0x10, 0x14, 0x10, 0x14, 0x10, 0x14, 0x10, 0x13, 0x10, 0x13, 0x10, 0x14, 0x10, 0x14, 0x10, 0x13, 0x10, 0x14, 0x10, 0x14, 0x10, 0x14, 0x10, 0x14, 0x10, 0x14, 0x10, 0x14, 0x10, 0x14, 0x10, 0x14, 0x10, 0x14, 0x11, 0x15, 0x11, 0x15, 0x12, 0x16, 0x13, 0x17, 0x13, 0x17, 0x14, 0x18, 0x15, 0x19, 0x19, 0x1D, 0x21, 0x2B, 0x33, 0x48, 0x50, 0x6E, 0x6B, 0x8B, 0x75, 0x96, 0x7A, 0x9C, 0x7B, 0x9B, 0x7D, 0x9E, 0x7F, 0xA0, 0x7F, 0xA1, 0x7C, 0x9F, 0x71, 0x8D, 0x52, 0x5E, 0x3F, 0x4C, 0x49, 0x64, 0x66, 0x8B, 0x77, 0x99, 0x7B, 0x9E, 0x7F, 0xA3, 0x83, 0xA7, 0x87, 0xAB, 0x8A, 0xAD, 0x89, 0xAD, 0x87, 0xAA, 0x82, 0xA2, 0x6D, 0x82, 0x43, 0x4B, 0x2B, 0x2F, 0x21, 0x24, 0x1B, 0x1E, 0x17, 0x1A, 0x15, 0x19, 0x14, 0x19, 0x14, 0x18, 0x14, 0x18, 0x14, 0x19, 0x14, 0x19, 0x14, 0x18, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x12, 0x16, 0x13, 0x16, 0x12, 0x16, 0x12, 0x16, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x14, 0x11, 0x14, 0x10, 0x14, 0x10, 0x14, 0x10, 0x14, 0x10, 0x14, 0x11, 0x15, 0x12, 0x15, 0x11, 0x14, 0x11, 0x14, 0x11, 0x15, 0x11, 0x15, 0x11, 0x14, 0x11, 0x15, 0x12, 0x16, 0x12, 0x16, 0x11, 0x15, 0x12, 0x15, 0x12, 0x16, 0x12, 0x16, 0x13, 0x16, 0x11, 0x14, 0x11, 0x14, 0x12, 0x16, 0x12, 0x15, 0x13, 0x16, 0x15, 0x18, 0x20, 0x25, 0x41, 0x44, 0x58, 0x56, 0x5D, 0x59, 0x57, 0x50, 0x3D, 0x35, 0x39, 0x36, 0x4F, 0x4C, 0x5D, 0x55, 0x62, 0x58, 0x62, 0x58, 0x67, 0x5B, 0x68, 0x5C, 0x69, 0x5C, 0x69, 0x5D, 0x6A, 0x5C, 0x69, 0x5D, 0x6D, 0x5E, 0x6B, 0x5E, 0x6A, 0x5C, 0x67, 0x5B, 0x6A, 0x5D, 0x6A, 0x5E, 0x6C, 0x5E, 0x6C, 0x5F, 0x6B, 0x5E, 0x6A, 0x5D, 0x6C, 0x5F, 0x6B, 0x5F, 0x69, 0x5D, 0x6A, 0x5E, 0x6C, 0x5E, 0x6C, 0x60, 0x6C, 0x60, 0x6A, 0x5D, 0x6A, 0x5E, 0x68, 0x5C, 0x68, 0x5D, 0x6C, 0x60, 0x6A, 0x5E, 0x6C, 0x60, 0x6B, 0x5D, 0x6B, 0x5F, 0x6B, 0x5F, 0x6D, 0x61, 0x6D, 0x60, 0x6C, 0x60, 0x69, 0x5C, 0x69, 0x5C, 0x6A, 0x5D, 0x6D, 0x5E, 0x6D, 0x60, 0x6E, 0x60, 0x6B, 0x5E, 0x68, 0x5D, 0x69, 0x5C, 0x69, 0x5D, 0x6A, 0x5D, 0x68, 0x5C, 0x69, 0x5D, 0x6C, 0x60, 0x6D, 0x5E, 0x68, 0x5C, 0x68, 0x5B, 0x6B, 0x5D, 0x6B, 0x5E, 0x6B, 0x5D, 0x68, 0x5B, 0x69, 0x5C, 0x6A, 0x5D, 0x6C, 0x5F, 0x64, 0x58, 0x50, 0x4A, 0x44, 0x3F, 0x35, 0x30, 0x2F, 0x2B, 0x2C, 0x27, 0x2A, 0x29, 0x39, 0x3B, 0x40, 0x44, 0x43, 0x46, 0x44, 0x46, 0x44, 0x46, 0x43, 0x45, 0x3E, 0x40, 0x35, 0x34, 0x4C, 0x49, 0x60, 0x59, 0x64, 0x5B, 0x67, 0x5C, 0x67, 0x5B, 0x68, 0x5B, 0x66, 0x5A, 0x68, 0x5B, 0x67, 0x5B, 0x69, 0x5D, 0x67, 0x5B, 0x63, 0x58, 0x63, 0x59, 0x67, 0x5A, 0x67, 0x5A, 0x64, 0x58, 0x67, 0x5B, 0x67, 0x5B, 0x67, 0x5B, 0x6A, 0x5D, 0x6A, 0x5C, 0x68, 0x5B, 0x67, 0x5B, 0x66, 0x59, 0x6A, 0x5B, 0x67, 0x5A, 0x69, 0x5D, 0x68, 0x5B, 0x66, 0x5A, 0x64, 0x59, 0x65, 0x58, 0x63, 0x57, 0x62, 0x57, 0x64, 0x58, 0x62, 0x56, 0x63, 0x5A, 0x67, 0x5A, 0x66, 0x5B, 0x66, 0x57, 0x63, 0x56, 0x63, 0x56, 0x63, 0x57, 0x61, 0x57, 0x61, 0x55, 0x5E, 0x53, 0x5E, 0x54, 0x5C, 0x52, 0x5F, 0x54, 0x5D, 0x51, 0x5D, 0x51, 0x5B, 0x4E, 0x5B, 0x50, 0x53, 0x47, 0x34, 0x32, 0x28, 0x27, 0x24, 0x26, 0x28, 0x2B, 0x23, 0x24, 0x22, 0x27, 0x25, 0x2A, 0x23, 0x31, 0x27, 0x33, 0x22, 0x34, 0x23, 0x33, 0x22, 0x36, 0x27, 0x39, 0x23, 0x2D, 0x21, 0x26, 0x28, 0x2C, 0x24, 0x29, 0x2A, 0x3C, 0x26, 0x3E, 0x28, 0x46, 0x26, 0x44, 0x28, 0x49, 0x27, 0x46, 0x26, 0x44, 0x23, 0x30, 0x25, 0x2C, 0x26, 0x2C, 0x21, 0x29, 0x24, 0x40, 0x26, 0x47, 0x25, 0x46, 0x24, 0x45, 0x25, 0x48, 0x27, 0x48, 0x27, 0x46, 0x25, 0x2E, 0x27, 0x2D, 0x27, 0x2B, 0x22, 0x32, 0x23, 0x3E, 0x23, 0x41, 0x23, 0x40, 0x23, 0x3F, 0x23, 0x41
    },

    {
        0x55, 0x1F, 0x55, 0x1E, 0x56, 0x1E, 0x55, 0x1E, 0x56, 0x1E, 0x55, 0x1E, 0x4F, 0x1D, 0x48, 0x1C, 0x40, 0x1A, 0x39, 0x19, 0x3E, 0x1B, 0x48, 0x1D, 0x49, 0x1D, 0x41, 0x1A, 0x32, 0x16, 0x24, 0x13, 0x1D, 0x10, 0x19, 0x10, 0x18, 0x0F, 0x17, 0x0F, 0x16, 0x0F, 0x18, 0x11, 0x1C, 0x12, 0x18, 0x11, 0x16, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x14, 0x0F, 0x15, 0x0F, 0x16, 0x0F, 0x16, 0x10, 0x17, 0x10, 0x16, 0x0F, 0x16, 0x0F, 0x16, 0x10, 0x16, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x14, 0x0F, 0x14, 0x0F, 0x14, 0x0E, 0x14, 0x0F, 0x15, 0x0F, 0x14, 0x0F, 0x14, 0x0F, 0x15, 0x0F, 0x14, 0x0F, 0x15, 0x0F, 0x15, 0x10, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x17, 0x11, 0x17, 0x11, 0x18, 0x12, 0x1B, 0x15, 0x25, 0x1D, 0x3B, 0x30, 0x61, 0x4B, 0x89, 0x60, 0x99, 0x6A, 0x9F, 0x6D, 0xA2, 0x71, 0xA6, 0x72, 0xA8, 0x72, 0xAA, 0x74, 0xA9, 0x74, 0xA9, 0x73, 0xA7, 0x72, 0x97, 0x61, 0x79, 0x55, 0x89, 0x62, 0x9E, 0x6E, 0xA6, 0x73, 0xA9, 0x75, 0xAD, 0x77, 0xB2, 0x7A, 0xB4, 0x7B, 0xB7, 0x7E, 0xB7, 0x7F, 0xB6, 0x7D, 0xB0, 0x78, 0xA9, 0x70, 0x87, 0x55, 0x4F, 0x32, 0x30, 0x20, 0x25, 0x19, 0x1F, 0x16, 0x1C, 0x14, 0x1A, 0x13, 0x1A, 0x12, 0x19, 0x12, 0x19, 0x12, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x16, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x10, 0x16, 0x10, 0x16, 0x0F, 0x17, 0x10, 0x16, 0x10, 0x15, 0x0F, 0x14, 0x0E, 0x14, 0x0F, 0x16, 0x0F, 0x16, 0x10, 0x15, 0x0F, 0x17, 0x10, 0x17, 0x10, 0x16, 0x10, 0x17, 0x10, 0x18, 0x10, 0x17, 0x10, 0x17, 0x10, 0x16, 0x0F, 0x16, 0x10, 0x16, 0x0F, 0x16, 0x0F, 0x17, 0x10, 0x17, 0x10, 0x1A, 0x11, 0x26, 0x16, 0x47, 0x1E, 0x58, 0x21, 0x5B, 0x21, 0x53, 0x1F, 0x36, 0x19, 0x3A, 0x1B, 0x52, 0x20, 0x5A, 0x21, 0x5B, 0x20, 0x5D, 0x22, 0x60, 0x22, 0x61, 0x23, 0x63, 0x23, 0x62, 0x21, 0x5E, 0x22, 0x60, 0x23, 0x63, 0x22, 0x63, 0x23, 0x5F, 0x22, 0x61, 0x22, 0x63, 0x23, 0x63, 0x22, 0x61, 0x23, 0x62, 0x24, 0x62, 0x23, 0x62, 0x23, 0x61, 0x23, 0x62, 0x22, 0x61, 0x23, 0x61, 0x22, 0x61, 0x23, 0x60, 0x22, 0x5F, 0x22, 0x62, 0x22, 0x61, 0x22, 0x61, 0x22, 0x61, 0x23, 0x5F, 0x22, 0x62, 0x23, 0x63, 0x23, 0x60, 0x22, 0x63, 0x23, 0x64, 0x24, 0x63, 0x24, 0x63, 0x24, 0x62, 0x22, 0x61, 0x23, 0x62, 0x23, 0x61, 0x23, 0x62, 0x23, 0x64, 0x24, 0x62, 0x23, 0x5F, 0x22, 0x5D, 0x21, 0x5F, 0x22, 0x61, 0x23, 0x5D, 0x22, 0x61, 0x23, 0x61, 0x22, 0x62, 0x22, 0x60, 0x22, 0x60, 0x23, 0x63, 0x24, 0x62, 0x24, 0x60, 0x22, 0x5F, 0x22, 0x60, 0x22, 0x63, 0x23, 0x62, 0x23, 0x5B, 0x22, 0x43, 0x20, 0x39, 0x1F, 0x2E, 0x19, 0x28, 0x17, 0x28, 0x16, 0x26, 0x15, 0x34, 0x1C, 0x41, 0x21, 0x49, 0x23, 0x49, 0x24, 0x4B, 0x25, 0x4A, 0x24, 0x3E, 0x1B, 0x2E, 0x16, 0x46, 0x1D, 0x5B, 0x22, 0x5F, 0x22, 0x5F, 0x23, 0x5F, 0x23, 0x5D, 0x22, 0x5B, 0x21, 0x5C, 0x21, 0x60, 0x22, 0x62, 0x22, 0x5E, 0x22, 0x5E, 0x22, 0x5F, 0x23, 0x5F, 0x22, 0x5E, 0x22, 0x5C, 0x21, 0x5D, 0x22, 0x5F, 0x21, 0x5E, 0x21, 0x5D, 0x22, 0x5E, 0x23, 0x60, 0x23, 0x5E, 0x22, 0x5E, 0x22, 0x5E, 0x22, 0x5F, 0x22, 0x5E, 0x22, 0x5E, 0x23, 0x5C, 0x22, 0x5D, 0x23, 0x5D, 0x22, 0x5E, 0x22, 0x5C, 0x21, 0x5C, 0x21, 0x5A, 0x21, 0x5E, 0x22, 0x5E, 0x22, 0x5D, 0x21, 0x5A, 0x20, 0x58, 0x20, 0x58, 0x20, 0x5B, 0x22, 0x5A, 0x21, 0x58, 0x20, 0x57, 0x20, 0x55, 0x1F, 0x56, 0x20, 0x57, 0x20, 0x53, 0x1F, 0x54, 0x1F, 0x53, 0x1E, 0x51, 0x1E, 0x4E, 0x1D, 0x34, 0x19, 0x2A, 0x17, 0x27, 0x17, 0x2E, 0x1A, 0x2C, 0x19, 0x2A, 0x1A, 0x3A, 0x31, 0x4B, 0x47, 0x52, 0x4C, 0x53, 0x4E, 0x53, 0x4E, 0x53, 0x4F, 0x51, 0x4D, 0x40, 0x2E, 0x2C, 0x1D, 0x37, 0x20, 0x33, 0x1E, 0x45, 0x3D, 0x55, 0x50, 0x59, 0x53, 0x58, 0x52, 0x58, 0x53, 0x59, 0x51, 0x51, 0x4B, 0x36, 0x26, 0x2C, 0x1C, 0x2C, 0x1A, 0x2A, 0x22, 0x46, 0x42, 0x4C, 0x48, 0x4D, 0x4B, 0x4E, 0x4B, 0x4E, 0x4C, 0x4F, 0x4B, 0x46, 0x3E, 0x23, 0x1B, 0x25, 0x18, 0x24, 0x17, 0x2B, 0x29, 0x3F, 0x3E, 0x40, 0x3E, 0x3E, 0x3D, 0x3D, 0x3C, 0x3B, 0x3A
    },

    {
        0x5C, 0x53, 0x5D, 0x53, 0x5E, 0x53, 0x5E, 0x54, 0x5C, 0x53, 0x5B, 0x51, 0x55, 0x4B, 0x4B, 0x43, 0x43, 0x3B, 0x3A, 0x36, 0x40, 0x3E, 0x4B, 0x46, 0x4A, 0x44, 0x40, 0x3A, 0x2F, 0x2B, 0x20, 0x1F, 0x1A, 0x1B, 0x16, 0x18, 0x14, 0x16, 0x12, 0x15, 0x12, 0x15, 0x13, 0x17, 0x15, 0x1A, 0x13, 0x16, 0x11, 0x14, 0x11, 0x14, 0x11, 0x14, 0x10, 0x14, 0x11, 0x14, 0x11, 0x15, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x14, 0x11, 0x14, 0x11, 0x14, 0x10, 0x14, 0x10, 0x14, 0x11, 0x14, 0x10, 0x13, 0x10, 0x13, 0x10, 0x14, 0x11, 0x14, 0x10, 0x14, 0x11, 0x14, 0x10, 0x13, 0x11, 0x14, 0x10, 0x14, 0x11, 0x15, 0x11, 0x15, 0x11, 0x16, 0x12, 0x16, 0x12, 0x16, 0x13, 0x16, 0x14, 0x18, 0x18, 0x1C, 0x21, 0x2A, 0x31, 0x45, 0x4D, 0x6D, 0x6A, 0x8A, 0x75, 0x96, 0x7A, 0x9B, 0x7D, 0x9C, 0x7F, 0x9F, 0x80, 0xA2, 0x82, 0xA4, 0x82, 0xA2, 0x81, 0xA3, 0x7E, 0xA0, 0x77, 0x95, 0x67, 0x82, 0x6D, 0x8E, 0x7A, 0x9D, 0x7F, 0xA3, 0x83, 0xA5, 0x84, 0xA8, 0x86, 0xAA, 0x88, 0xAC, 0x8A, 0xAE, 0x8B, 0xAF, 0x8A, 0xAC, 0x87, 0xA8, 0x81, 0xA3, 0x70, 0x87, 0x48, 0x50, 0x2D, 0x30, 0x22, 0x26, 0x1C, 0x20, 0x18, 0x1B, 0x15, 0x19, 0x15, 0x19, 0x14, 0x18, 0x14, 0x18, 0x13, 0x17, 0x14, 0x17, 0x13, 0x17, 0x13, 0x17, 0x13, 0x16, 0x13, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x15, 0x12, 0x15, 0x11, 0x15, 0x11, 0x14, 0x11, 0x14, 0x11, 0x14, 0x11, 0x15, 0x12, 0x15, 0x12, 0x15, 0x12, 0x16, 0x11, 0x15, 0x10, 0x14, 0x10, 0x14, 0x10, 0x13, 0x11, 0x15, 0x12, 0x15, 0x11, 0x15, 0x12, 0x15, 0x12, 0x16, 0x11, 0x15, 0x12, 0x16, 0x13, 0x17, 0x12, 0x16, 0x13, 0x16, 0x12, 0x14, 0x12, 0x15, 0x12, 0x16, 0x12, 0x14, 0x12, 0x15, 0x13, 0x16, 0x16, 0x18, 0x1F, 0x22, 0x3E, 0x41, 0x55, 0x53, 0x5E, 0x58, 0x5A, 0x51, 0x3E, 0x35, 0x39, 0x36, 0x50, 0x4C, 0x5E, 0x55, 0x60, 0x57, 0x64, 0x59, 0x68, 0x5C, 0x6A, 0x5C, 0x6D, 0x5F, 0x6B, 0x5D, 0x68, 0x5A, 0x6A, 0x5D, 0x6C, 0x5F, 0x6B, 0x5F, 0x68, 0x5B, 0x6B, 0x5E, 0x6E, 0x60, 0x6E, 0x5F, 0x6C, 0x5E, 0x6C, 0x5F, 0x6A, 0x5F, 0x6A, 0x5E, 0x6A, 0x5D, 0x6A, 0x5D, 0x69, 0x5D, 0x6A, 0x5B, 0x6A, 0x5D, 0x6B, 0x5E, 0x69, 0x5C, 0x6B, 0x5D, 0x6B, 0x5E, 0x6A, 0x5C, 0x6A, 0x5C, 0x68, 0x5B, 0x6B, 0x5F, 0x6C, 0x5E, 0x6A, 0x5D, 0x6C, 0x5F, 0x6D, 0x5E, 0x6C, 0x5F, 0x6C, 0x60, 0x6A, 0x5C, 0x6B, 0x5F, 0x6B, 0x5E, 0x6B, 0x5F, 0x6D, 0x5F, 0x6D, 0x5F, 0x6A, 0x5E, 0x6A, 0x5C, 0x65, 0x59, 0x67, 0x5B, 0x68, 0x5C, 0x65, 0x5A, 0x69, 0x5E, 0x6A, 0x5C, 0x6A, 0x5D, 0x6A, 0x5D, 0x6A, 0x5E, 0x6B, 0x60, 0x6C, 0x5F, 0x68, 0x5A, 0x6A, 0x5D, 0x69, 0x5C, 0x6D, 0x5F, 0x6B, 0x5E, 0x62, 0x53, 0x45, 0x3D, 0x38, 0x31, 0x2F, 0x29, 0x2A, 0x25, 0x29, 0x26, 0x26, 0x24, 0x32, 0x34, 0x3D, 0x40, 0x42, 0x46, 0x44, 0x47, 0x46, 0x49, 0x43, 0x46, 0x36, 0x35, 0x2F, 0x2E, 0x4A, 0x47, 0x61, 0x5A, 0x65, 0x5A, 0x68, 0x5C, 0x69, 0x5A, 0x66, 0x59, 0x66, 0x58, 0x66, 0x58, 0x69, 0x5D, 0x69, 0x5D, 0x67, 0x5B, 0x67, 0x5C, 0x68, 0x5C, 0x69, 0x5D, 0x67, 0x5A, 0x64, 0x58, 0x66, 0x5A, 0x67, 0x5B, 0x66, 0x5A, 0x67, 0x5A, 0x69, 0x5C, 0x69, 0x5D, 0x67, 0x5B, 0x67, 0x5B, 0x67, 0x59, 0x68, 0x5C, 0x67, 0x5A, 0x66, 0x59, 0x64, 0x59, 0x65, 0x5A, 0x66, 0x5C, 0x67, 0x5A, 0x66, 0x58, 0x65, 0x57, 0x64, 0x59, 0x68, 0x5B, 0x67, 0x5B, 0x66, 0x59, 0x63, 0x56, 0x60, 0x55, 0x61, 0x55, 0x63, 0x58, 0x62, 0x55, 0x61, 0x54, 0x5F, 0x54, 0x5C, 0x51, 0x5E, 0x53, 0x60, 0x53, 0x5C, 0x51, 0x5F, 0x51, 0x5C, 0x50, 0x57, 0x4E, 0x53, 0x49, 0x35, 0x31, 0x29, 0x28, 0x26, 0x27, 0x2B, 0x30, 0x27, 0x2A, 0x25, 0x29, 0x27, 0x3F, 0x29, 0x4F, 0x2A, 0x51, 0x2A, 0x54, 0x2A, 0x54, 0x2B, 0x54, 0x29, 0x50, 0x27, 0x37, 0x22, 0x2C, 0x31, 0x38, 0x2B, 0x32, 0x2B, 0x48, 0x2E, 0x55, 0x2E, 0x56, 0x2B, 0x55, 0x2B, 0x56, 0x2B, 0x52, 0x28, 0x4B, 0x1F, 0x29, 0x22, 0x29, 0x24, 0x27, 0x20, 0x2A, 0x25, 0x43, 0x26, 0x47, 0x26, 0x47, 0x27, 0x49, 0x26, 0x4A, 0x26, 0x46, 0x24, 0x3B, 0x18, 0x1F, 0x1E, 0x22, 0x1F, 0x21, 0x1F, 0x2F, 0x23, 0x39, 0x21, 0x38, 0x20, 0x34, 0x1F, 0x32, 0x1E, 0x2F
    },

    {
        0x56, 0x1F, 0x55, 0x1E, 0x56, 0x1F, 0x56, 0x1E, 0x54, 0x1E, 0x51, 0x1D, 0x49, 0x1C, 0x41, 0x1A, 0x39, 0x19, 0x3B, 0x19, 0x46, 0x1B, 0x47, 0x1C, 0x41, 0x1A, 0x34, 0x17, 0x26, 0x13, 0x1E, 0x11, 0x1A, 0x10, 0x18, 0x10, 0x17, 0x0F, 0x16, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x16, 0x10, 0x16, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x16, 0x0F, 0x16, 0x0F, 0x16, 0x0F, 0x16, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x11, 0x17, 0x11, 0x17, 0x10, 0x15, 0x0F, 0x15, 0x0F, 0x14, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x14, 0x0E, 0x14, 0x0F, 0x14, 0x0E, 0x14, 0x0F, 0x14, 0x0F, 0x15, 0x0F, 0x15, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x17, 0x11, 0x17, 0x11, 0x18, 0x11, 0x17, 0x11, 0x18, 0x11, 0x1A, 0x13, 0x22, 0x1C, 0x38, 0x2E, 0x5E, 0x47, 0x83, 0x5E, 0x96, 0x68, 0x9F, 0x6F, 0xA5, 0x71, 0xA7, 0x72, 0xAA, 0x73, 0xAB, 0x74, 0xAC, 0x74, 0xAC, 0x74, 0xAC, 0x75, 0xAC, 0x75, 0xAA, 0x74, 0xA6, 0x71, 0xA6, 0x72, 0xA8, 0x73, 0xAA, 0x76, 0xB0, 0x78, 0xB0, 0x7A, 0xB3, 0x7B, 0xB3, 0x7B, 0xB3, 0x7C, 0xB5, 0x7E, 0xB5, 0x7D, 0xB4, 0x7A, 0xAF, 0x78, 0xAB, 0x73, 0x90, 0x59, 0x54, 0x34, 0x31, 0x21, 0x26, 0x1A, 0x21, 0x17, 0x1D, 0x14, 0x1A, 0x12, 0x19, 0x12, 0x19, 0x11, 0x19, 0x11, 0x19, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x17, 0x10, 0x16, 0x10, 0x17, 0x10, 0x16, 0x0F, 0x14, 0x0F, 0x14, 0x0E, 0x14, 0x0F, 0x15, 0x0F, 0x16, 0x0F, 0x16, 0x0F, 0x17, 0x10, 0x17, 0x10, 0x16, 0x0F, 0x18, 0x10, 0x18, 0x10, 0x17, 0x10, 0x17, 0x10, 0x16, 0x0F, 0x17, 0x0F, 0x16, 0x0F, 0x16, 0x0F, 0x16, 0x10, 0x17, 0x10, 0x17, 0x10, 0x18, 0x11, 0x24, 0x14, 0x45, 0x1C, 0x54, 0x20, 0x5A, 0x22, 0x52, 0x1E, 0x39, 0x19, 0x36, 0x1A, 0x50, 0x20, 0x59, 0x20, 0x5C, 0x21, 0x5F, 0x22, 0x60, 0x22, 0x62, 0x22, 0x61, 0x22, 0x60, 0x21, 0x5F, 0x22, 0x61, 0x22, 0x62, 0x23, 0x61, 0x22, 0x60, 0x22, 0x64, 0x23, 0x62, 0x23, 0x63, 0x23, 0x65, 0x24, 0x62, 0x23, 0x63, 0x23, 0x5E, 0x22, 0x60, 0x22, 0x61, 0x23, 0x5F, 0x22, 0x61, 0x22, 0x61, 0x23, 0x61, 0x23, 0x60, 0x22, 0x60, 0x22, 0x62, 0x22, 0x61, 0x22, 0x5E, 0x21, 0x63, 0x23, 0x63, 0x23, 0x62, 0x22, 0x63, 0x23, 0x64, 0x24, 0x63, 0x23, 0x61, 0x23, 0x60, 0x23, 0x61, 0x23, 0x62, 0x24, 0x61, 0x23, 0x61, 0x22, 0x62, 0x23, 0x61, 0x22, 0x60, 0x22, 0x5D, 0x21, 0x5E, 0x22, 0x61, 0x24, 0x60, 0x22, 0x61, 0x22, 0x61, 0x22, 0x62, 0x22, 0x62, 0x22, 0x64, 0x24, 0x65, 0x25, 0x63, 0x23, 0x61, 0x22, 0x60, 0x22, 0x60, 0x22, 0x61, 0x22, 0x63, 0x23, 0x5D, 0x21, 0x3C, 0x19, 0x2D, 0x17, 0x27, 0x15, 0x26, 0x15, 0x25, 0x14, 0x1F, 0x11, 0x26, 0x15, 0x3F, 0x1E, 0x46, 0x23, 0x48, 0x23, 0x47, 0x22, 0x43, 0x1E, 0x2C, 0x14, 0x2F, 0x16, 0x4A, 0x1D, 0x5D, 0x23, 0x5E, 0x22, 0x5E, 0x22, 0x60, 0x23, 0x5D, 0x21, 0x5E, 0x21, 0x5D, 0x22, 0x5F, 0x22, 0x60, 0x22, 0x5F, 0x23, 0x62, 0x23, 0x5E, 0x22, 0x60, 0x22, 0x5D, 0x22, 0x58, 0x20, 0x5A, 0x20, 0x5C, 0x21, 0x5E, 0x22, 0x5E, 0x22, 0x5E, 0x22, 0x5F, 0x23, 0x5F, 0x22, 0x5D, 0x23, 0x5D, 0x22, 0x5E, 0x22, 0x5D, 0x22, 0x5B, 0x22, 0x5D, 0x22, 0x5D, 0x21, 0x5C, 0x22, 0x5B, 0x20, 0x5E, 0x21, 0x5A, 0x20, 0x5C, 0x21, 0x5F, 0x22, 0x5E, 0x21, 0x5D, 0x23, 0x58, 0x20, 0x59, 0x20, 0x58, 0x21, 0x58, 0x20, 0x58, 0x20, 0x58, 0x21, 0x58, 0x21, 0x56, 0x1F, 0x56, 0x20, 0x56, 0x1F, 0x55, 0x1F, 0x53, 0x1E, 0x52, 0x1F, 0x53, 0x1F, 0x4F, 0x1D, 0x37, 0x1B, 0x31, 0x19, 0x29, 0x19, 0x32, 0x1A, 0x29, 0x18, 0x29, 0x1B, 0x47, 0x3F, 0x58, 0x51, 0x59, 0x51, 0x5A, 0x52, 0x5B, 0x52, 0x59, 0x50, 0x54, 0x4B, 0x32, 0x23, 0x23, 0x19, 0x32, 0x1D, 0x2A, 0x1C, 0x46, 0x3B, 0x55, 0x49, 0x53, 0x46, 0x51, 0x47, 0x4D, 0x42, 0x49, 0x3E, 0x42, 0x35, 0x24, 0x19, 0x27, 0x1A, 0x28, 0x18, 0x25, 0x1C, 0x34, 0x29, 0x32, 0x2A, 0x30, 0x28, 0x2E, 0x27, 0x2D, 0x26, 0x2B, 0x23, 0x25, 0x1D, 0x1D, 0x15, 0x28, 0x17, 0x29, 0x19, 0x2D, 0x1C, 0x2A, 0x1C, 0x1F, 0x18, 0x1E, 0x18, 0x1D, 0x17, 0x1C, 0x17
    },

    {
        0x5C, 0x51, 0x5D, 0x53, 0x5E, 0x53, 0x5C, 0x52, 0x59, 0x51, 0x55, 0x4C, 0x4D, 0x44, 0x43, 0x3C, 0x3B, 0x38, 0x3D, 0x3C, 0x48, 0x45, 0x4A, 0x44, 0x42, 0x3B, 0x31, 0x2D, 0x21, 0x20, 0x1A, 0x1B, 0x16, 0x18, 0x15, 0x17, 0x13, 0x16, 0x12, 0x15, 0x11, 0x14, 0x11, 0x15, 0x12, 0x15, 0x11, 0x14, 0x11, 0x14, 0x11, 0x14, 0x11, 0x14, 0x11, 0x15, 0x11, 0x15, 0x12, 0x15, 0x11, 0x15, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x13, 0x17, 0x12, 0x17, 0x12, 0x15, 0x11, 0x15, 0x10, 0x13, 0x10, 0x13, 0x10, 0x13, 0x10, 0x14, 0x10, 0x14, 0x10, 0x13, 0x10, 0x14, 0x10, 0x13, 0x10, 0x13, 0x10, 0x14, 0x11, 0x14, 0x11, 0x14, 0x11, 0x15, 0x10, 0x14, 0x11, 0x15, 0x12, 0x15, 0x12, 0x17, 0x13, 0x16, 0x12, 0x16, 0x13, 0x16, 0x16, 0x1B, 0x1F, 0x27, 0x2F, 0x42, 0x4A, 0x69, 0x66, 0x86, 0x74, 0x94, 0x79, 0x9C, 0x7E, 0xA1, 0x80, 0xA1, 0x80, 0xA2, 0x82, 0xA3, 0x82, 0xA3, 0x82, 0xA2, 0x83, 0xA4, 0x82, 0xA6, 0x82, 0xA5, 0x81, 0xA1, 0x80, 0xA1, 0x80, 0xA2, 0x82, 0xA4, 0x85, 0xA7, 0x85, 0xAB, 0x88, 0xA9, 0x89, 0xAC, 0x8A, 0xAC, 0x8A, 0xAE, 0x8A, 0xAE, 0x89, 0xAB, 0x86, 0xA8, 0x81, 0xA3, 0x72, 0x8C, 0x4C, 0x56, 0x2F, 0x33, 0x22, 0x26, 0x1D, 0x20, 0x19, 0x1C, 0x16, 0x19, 0x14, 0x18, 0x13, 0x17, 0x13, 0x17, 0x13, 0x18, 0x13, 0x17, 0x13, 0x17, 0x13, 0x16, 0x13, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x11, 0x16, 0x12, 0x16, 0x11, 0x15, 0x11, 0x14, 0x11, 0x14, 0x11, 0x15, 0x11, 0x15, 0x12, 0x16, 0x12, 0x15, 0x12, 0x15, 0x12, 0x15, 0x11, 0x13, 0x10, 0x14, 0x10, 0x13, 0x10, 0x14, 0x11, 0x15, 0x12, 0x15, 0x12, 0x16, 0x12, 0x16, 0x11, 0x15, 0x12, 0x16, 0x12, 0x16, 0x12, 0x15, 0x12, 0x15, 0x11, 0x15, 0x12, 0x16, 0x12, 0x14, 0x12, 0x14, 0x12, 0x15, 0x13, 0x16, 0x13, 0x16, 0x14, 0x16, 0x1C, 0x20, 0x3C, 0x3F, 0x54, 0x51, 0x5C, 0x57, 0x59, 0x50, 0x41, 0x39, 0x37, 0x32, 0x4F, 0x4B, 0x5C, 0x54, 0x62, 0x59, 0x66, 0x5C, 0x69, 0x5D, 0x6A, 0x5C, 0x6B, 0x5C, 0x68, 0x5A, 0x67, 0x5A, 0x69, 0x5C, 0x6B, 0x5E, 0x69, 0x5C, 0x6C, 0x5E, 0x6D, 0x60, 0x6D, 0x5E, 0x6D, 0x5F, 0x6E, 0x60, 0x6B, 0x5D, 0x6B, 0x5F, 0x67, 0x5B, 0x69, 0x5B, 0x69, 0x5D, 0x69, 0x5D, 0x6B, 0x5E, 0x6B, 0x5E, 0x69, 0x5D, 0x69, 0x5C, 0x6A, 0x5D, 0x6B, 0x5F, 0x6B, 0x5E, 0x68, 0x5C, 0x6B, 0x5E, 0x6C, 0x5F, 0x6A, 0x5D, 0x6D, 0x61, 0x6C, 0x5F, 0x6B, 0x60, 0x6A, 0x5E, 0x68, 0x5C, 0x6A, 0x5D, 0x6A, 0x5E, 0x6B, 0x5D, 0x6B, 0x5D, 0x6C, 0x5E, 0x6A, 0x5D, 0x6A, 0x5C, 0x67, 0x5B, 0x68, 0x5C, 0x67, 0x5D, 0x68, 0x5C, 0x6A, 0x5C, 0x6C, 0x5E, 0x6B, 0x5E, 0x6B, 0x5E, 0x6C, 0x60, 0x6D, 0x60, 0x6E, 0x60, 0x6B, 0x5E, 0x68, 0x5D, 0x6A, 0x5C, 0x6B, 0x5D, 0x6C, 0x61, 0x64, 0x57, 0x42, 0x35, 0x31, 0x29, 0x2A, 0x25, 0x27, 0x24, 0x26, 0x22, 0x1F, 0x1B, 0x27, 0x28, 0x3B, 0x3D, 0x40, 0x43, 0x41, 0x43, 0x3F, 0x41, 0x38, 0x38, 0x2B, 0x26, 0x33, 0x33, 0x50, 0x4C, 0x62, 0x5A, 0x64, 0x5B, 0x67, 0x5B, 0x6A, 0x5B, 0x67, 0x58, 0x67, 0x5B, 0x66, 0x5B, 0x68, 0x5B, 0x68, 0x5D, 0x67, 0x5D, 0x69, 0x5D, 0x66, 0x59, 0x68, 0x5B, 0x65, 0x59, 0x61, 0x56, 0x62, 0x56, 0x66, 0x58, 0x69, 0x5C, 0x68, 0x59, 0x65, 0x59, 0x67, 0x5C, 0x67, 0x5A, 0x67, 0x5B, 0x66, 0x5B, 0x67, 0x5B, 0x68, 0x5B, 0x64, 0x57, 0x66, 0x5B, 0x66, 0x5A, 0x65, 0x59, 0x63, 0x57, 0x66, 0x59, 0x64, 0x56, 0x65, 0x59, 0x67, 0x5D, 0x67, 0x5B, 0x66, 0x59, 0x62, 0x55, 0x61, 0x56, 0x60, 0x56, 0x61, 0x56, 0x61, 0x56, 0x61, 0x55, 0x60, 0x56, 0x5D, 0x52, 0x60, 0x55, 0x5E, 0x52, 0x5D, 0x51, 0x5A, 0x4F, 0x5A, 0x50, 0x5C, 0x51, 0x53, 0x49, 0x36, 0x35, 0x2D, 0x2C, 0x27, 0x2B, 0x2B, 0x2B, 0x23, 0x23, 0x23, 0x28, 0x29, 0x49, 0x2C, 0x53, 0x2B, 0x52, 0x2A, 0x52, 0x2A, 0x51, 0x29, 0x4F, 0x28, 0x4B, 0x1D, 0x26, 0x1D, 0x24, 0x29, 0x2D, 0x23, 0x2A, 0x2A, 0x42, 0x2A, 0x49, 0x28, 0x43, 0x27, 0x44, 0x25, 0x3F, 0x23, 0x3C, 0x21, 0x34, 0x18, 0x1E, 0x21, 0x29, 0x21, 0x24, 0x21, 0x28, 0x22, 0x2B, 0x1C, 0x29, 0x1A, 0x26, 0x1A, 0x24, 0x19, 0x22, 0x19, 0x21, 0x17, 0x1E, 0x17, 0x1E, 0x25, 0x2A, 0x25, 0x2A, 0x28, 0x2E, 0x22, 0x26, 0x18, 0x1C, 0x17, 0x1C, 0x17, 0x1C, 0x17, 0x1D
    },

    {
        0x54, 0x1E, 0x55, 0x1E, 0x54, 0x1F, 0x54, 0x1E, 0x51, 0x1D, 0x4B, 0x1D, 0x42, 0x1A, 0x3A, 0x19, 0x3B, 0x19, 0x45, 0x1B, 0x48, 0x1C, 0x43, 0x1A, 0x36, 0x17, 0x27, 0x13, 0x1E, 0x11, 0x1B, 0x11, 0x1A, 0x10, 0x18, 0x10, 0x17, 0x10, 0x15, 0x0E, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x14, 0x0F, 0x15, 0x0F, 0x16, 0x0F, 0x16, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x11, 0x18, 0x11, 0x19, 0x11, 0x18, 0x11, 0x17, 0x10, 0x16, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x14, 0x0E, 0x14, 0x0E, 0x15, 0x0F, 0x14, 0x0F, 0x15, 0x0F, 0x14, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x17, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x19, 0x12, 0x21, 0x1A, 0x33, 0x2A, 0x59, 0x45, 0x81, 0x5C, 0x94, 0x66, 0x9A, 0x6C, 0xA2, 0x70, 0xA8, 0x72, 0xAA, 0x74, 0xAC, 0x74, 0xAB, 0x75, 0xAD, 0x76, 0xAD, 0x77, 0xAF, 0x78, 0xB1, 0x79, 0xB1, 0x78, 0xAE, 0x77, 0xAF, 0x76, 0xAD, 0x76, 0xAD, 0x76, 0xAE, 0x78, 0xB2, 0x79, 0xB6, 0x7B, 0xB5, 0x7C, 0xB6, 0x7D, 0xB8, 0x7D, 0xB6, 0x7D, 0xB6, 0x7A, 0xB2, 0x7A, 0xB0, 0x79, 0xAD, 0x76, 0x97, 0x60, 0x5C, 0x3A, 0x34, 0x23, 0x28, 0x1B, 0x21, 0x17, 0x1C, 0x14, 0x1A, 0x12, 0x19, 0x11, 0x18, 0x11, 0x19, 0x11, 0x18, 0x11, 0x18, 0x10, 0x17, 0x11, 0x18, 0x11, 0x17, 0x11, 0x17, 0x11, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x16, 0x10, 0x15, 0x0F, 0x14, 0x0F, 0x15, 0x0F, 0x16, 0x10, 0x17, 0x11, 0x17, 0x10, 0x15, 0x0F, 0x16, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x16, 0x10, 0x16, 0x0F, 0x16, 0x10, 0x16, 0x10, 0x16, 0x0F, 0x16, 0x10, 0x17, 0x10, 0x17, 0x10, 0x16, 0x10, 0x16, 0x0F, 0x16, 0x0F, 0x16, 0x0F, 0x16, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x0F, 0x17, 0x0F, 0x18, 0x10, 0x22, 0x15, 0x43, 0x1E, 0x57, 0x22, 0x5B, 0x22, 0x54, 0x1E, 0x38, 0x18, 0x32, 0x1A, 0x4C, 0x1F, 0x59, 0x21, 0x5C, 0x21, 0x60, 0x22, 0x60, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x60, 0x23, 0x5F, 0x22, 0x5F, 0x22, 0x60, 0x22, 0x62, 0x22, 0x64, 0x23, 0x62, 0x23, 0x66, 0x24, 0x64, 0x24, 0x61, 0x22, 0x63, 0x23, 0x5F, 0x22, 0x5D, 0x21, 0x61, 0x22, 0x64, 0x23, 0x62, 0x22, 0x62, 0x23, 0x62, 0x24, 0x61, 0x23, 0x62, 0x23, 0x61, 0x23, 0x63, 0x23, 0x63, 0x22, 0x63, 0x23, 0x62, 0x22, 0x62, 0x23, 0x64, 0x23, 0x63, 0x24, 0x64, 0x25, 0x66, 0x26, 0x62, 0x24, 0x60, 0x23, 0x60, 0x23, 0x60, 0x22, 0x5F, 0x22, 0x62, 0x22, 0x62, 0x22, 0x62, 0x22, 0x60, 0x22, 0x61, 0x22, 0x61, 0x23, 0x60, 0x23, 0x5F, 0x22, 0x63, 0x22, 0x61, 0x22, 0x60, 0x22, 0x62, 0x23, 0x5F, 0x22, 0x60, 0x23, 0x61, 0x23, 0x60, 0x22, 0x5F, 0x22, 0x60, 0x22, 0x64, 0x24, 0x60, 0x22, 0x42, 0x1A, 0x29, 0x14, 0x22, 0x13, 0x21, 0x12, 0x1F, 0x11, 0x1D, 0x11, 0x2D, 0x16, 0x37, 0x19, 0x3A, 0x1A, 0x37, 0x1A, 0x33, 0x17, 0x27, 0x13, 0x26, 0x13, 0x3A, 0x19, 0x4F, 0x1E, 0x5D, 0x21, 0x5C, 0x21, 0x61, 0x23, 0x60, 0x22, 0x5E, 0x22, 0x5F, 0x22, 0x5D, 0x21, 0x5C, 0x21, 0x5F, 0x21, 0x5F, 0x22, 0x5F, 0x22, 0x5C, 0x21, 0x5F, 0x22, 0x5F, 0x22, 0x5C, 0x21, 0x5D, 0x22, 0x5F, 0x22, 0x5F, 0x23, 0x5F, 0x22, 0x5D, 0x21, 0x5F, 0x22, 0x60, 0x22, 0x5F, 0x22, 0x5F, 0x23, 0x5F, 0x22, 0x60, 0x23, 0x5C, 0x22, 0x5B, 0x22, 0x5E, 0x22, 0x5D, 0x21, 0x5B, 0x21, 0x5C, 0x21, 0x5B, 0x20, 0x5B, 0x22, 0x5F, 0x22, 0x5D, 0x22, 0x5E, 0x21, 0x5A, 0x20, 0x5B, 0x21, 0x59, 0x20, 0x5A, 0x21, 0x58, 0x20, 0x5A, 0x21, 0x59, 0x20, 0x55, 0x1F, 0x57, 0x1F, 0x56, 0x20, 0x56, 0x1F, 0x54, 0x1F, 0x54, 0x1F, 0x54, 0x1F, 0x4C, 0x1C, 0x35, 0x1A, 0x2A, 0x17, 0x2A, 0x18, 0x27, 0x18, 0x24, 0x17, 0x2B, 0x1B, 0x3B, 0x2C, 0x3B, 0x2E, 0x38, 0x2E, 0x35, 0x2A, 0x31, 0x28, 0x30, 0x26, 0x2C, 0x22, 0x20, 0x17, 0x25, 0x18, 0x2C, 0x1A, 0x2D, 0x1C, 0x34, 0x22, 0x2D, 0x1F, 0x25, 0x1C, 0x23, 0x1B, 0x23, 0x1A, 0x22, 0x19, 0x20, 0x17, 0x1E, 0x15, 0x2B, 0x1A, 0x26, 0x17, 0x2E, 0x1C, 0x2A, 0x1A, 0x23, 0x17, 0x26, 0x19, 0x1F, 0x16, 0x21, 0x16, 0x22, 0x17, 0x27, 0x19, 0x24, 0x16, 0x2D, 0x19, 0x2C, 0x19, 0x2E, 0x1C, 0x2D, 0x1A, 0x21, 0x16, 0x23, 0x17, 0x27, 0x19, 0x27, 0x18
    },

    {
        0x5C, 0x51, 0x5B, 0x50, 0x5C, 0x52, 0x5A, 0x50, 0x55, 0x4C, 0x4E, 0x45, 0x43, 0x3C, 0x3B, 0x37, 0x3D, 0x3D, 0x47, 0x44, 0x4B, 0x45, 0x42, 0x3D, 0x34, 0x2F, 0x23, 0x22, 0x1A, 0x1C, 0x17, 0x1A, 0x15, 0x18, 0x13, 0x16, 0x12, 0x15, 0x12, 0x15, 0x10, 0x14, 0x11, 0x14, 0x11, 0x14, 0x11, 0x14, 0x11, 0x14, 0x10, 0x14, 0x11, 0x15, 0x12, 0x15, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x17, 0x13, 0x18, 0x14, 0x18, 0x14, 0x17, 0x13, 0x16, 0x12, 0x14, 0x11, 0x14, 0x11, 0x14, 0x10, 0x14, 0x10, 0x13, 0x10, 0x13, 0x10, 0x14, 0x11, 0x13, 0x11, 0x14, 0x10, 0x14, 0x10, 0x14, 0x10, 0x14, 0x11, 0x14, 0x11, 0x14, 0x11, 0x15, 0x11, 0x15, 0x11, 0x16, 0x12, 0x16, 0x13, 0x17, 0x13, 0x17, 0x14, 0x18, 0x17, 0x1A, 0x1D, 0x25, 0x2D, 0x3D, 0x47, 0x66, 0x66, 0x86, 0x71, 0x90, 0x76, 0x96, 0x7A, 0x9B, 0x7F, 0xA0, 0x82, 0xA3, 0x82, 0xA5, 0x85, 0xA5, 0x85, 0xA7, 0x86, 0xA7, 0x85, 0xA8, 0x88, 0xAA, 0x88, 0xA8, 0x84, 0xA6, 0x85, 0xA5, 0x86, 0xA6, 0x86, 0xA7, 0x87, 0xA7, 0x87, 0xAC, 0x8A, 0xAC, 0x8B, 0xAC, 0x8A, 0xAE, 0x8C, 0xAE, 0x8A, 0xAE, 0x8A, 0xAC, 0x87, 0xA9, 0x86, 0xAA, 0x83, 0xA6, 0x78, 0x93, 0x52, 0x5D, 0x30, 0x35, 0x23, 0x27, 0x1D, 0x20, 0x18, 0x1B, 0x15, 0x18, 0x14, 0x17, 0x13, 0x17, 0x13, 0x18, 0x13, 0x17, 0x12, 0x17, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x15, 0x12, 0x16, 0x11, 0x15, 0x11, 0x14, 0x10, 0x14, 0x11, 0x14, 0x12, 0x16, 0x12, 0x17, 0x12, 0x16, 0x12, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x14, 0x10, 0x13, 0x11, 0x14, 0x12, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x12, 0x15, 0x12, 0x15, 0x12, 0x15, 0x12, 0x15, 0x11, 0x15, 0x11, 0x15, 0x12, 0x14, 0x13, 0x16, 0x12, 0x16, 0x13, 0x16, 0x12, 0x15, 0x13, 0x16, 0x14, 0x17, 0x1B, 0x1F, 0x39, 0x3E, 0x54, 0x52, 0x5E, 0x57, 0x5A, 0x51, 0x40, 0x37, 0x34, 0x2F, 0x4A, 0x48, 0x5C, 0x55, 0x61, 0x58, 0x66, 0x5C, 0x69, 0x5C, 0x69, 0x5C, 0x68, 0x5B, 0x67, 0x5D, 0x67, 0x5B, 0x68, 0x5B, 0x6B, 0x5D, 0x6C, 0x5F, 0x6E, 0x60, 0x6E, 0x60, 0x6F, 0x62, 0x6D, 0x5F, 0x6B, 0x5D, 0x6C, 0x5E, 0x6A, 0x5C, 0x68, 0x5A, 0x6B, 0x5F, 0x6D, 0x60, 0x6C, 0x5E, 0x6A, 0x5E, 0x69, 0x5E, 0x6B, 0x5E, 0x6B, 0x5E, 0x69, 0x5F, 0x6B, 0x5F, 0x6D, 0x5F, 0x6C, 0x5F, 0x6B, 0x5E, 0x6C, 0x5D, 0x6C, 0x5F, 0x6B, 0x61, 0x6B, 0x63, 0x6C, 0x61, 0x6A, 0x5F, 0x69, 0x5E, 0x68, 0x5D, 0x69, 0x5D, 0x69, 0x5E, 0x6A, 0x5D, 0x6A, 0x5E, 0x6B, 0x5D, 0x6A, 0x5D, 0x6B, 0x5C, 0x69, 0x5E, 0x68, 0x5C, 0x6A, 0x5E, 0x6D, 0x5F, 0x6B, 0x5F, 0x69, 0x5D, 0x6B, 0x5E, 0x69, 0x5C, 0x69, 0x5B, 0x6B, 0x5E, 0x69, 0x5D, 0x6A, 0x5C, 0x6A, 0x5D, 0x6D, 0x60, 0x6A, 0x5B, 0x4C, 0x3E, 0x30, 0x27, 0x27, 0x21, 0x23, 0x1E, 0x22, 0x1D, 0x25, 0x21, 0x35, 0x34, 0x38, 0x34, 0x36, 0x33, 0x32, 0x2E, 0x2D, 0x29, 0x26, 0x22, 0x2B, 0x29, 0x41, 0x40, 0x57, 0x50, 0x64, 0x5A, 0x65, 0x59, 0x69, 0x5E, 0x6A, 0x5C, 0x68, 0x5D, 0x67, 0x5B, 0x67, 0x5A, 0x67, 0x5A, 0x68, 0x5B, 0x67, 0x5C, 0x66, 0x5B, 0x66, 0x5A, 0x65, 0x5B, 0x66, 0x5C, 0x65, 0x5A, 0x66, 0x5B, 0x69, 0x5D, 0x69, 0x5C, 0x6A, 0x5D, 0x66, 0x5C, 0x68, 0x5C, 0x6A, 0x5C, 0x67, 0x5C, 0x67, 0x5B, 0x68, 0x5A, 0x6A, 0x5C, 0x66, 0x59, 0x65, 0x59, 0x68, 0x5B, 0x65, 0x59, 0x63, 0x58, 0x64, 0x58, 0x64, 0x58, 0x64, 0x5A, 0x67, 0x5B, 0x65, 0x5A, 0x66, 0x59, 0x63, 0x57, 0x62, 0x57, 0x63, 0x56, 0x62, 0x56, 0x62, 0x55, 0x61, 0x55, 0x61, 0x56, 0x5E, 0x54, 0x5F, 0x53, 0x60, 0x54, 0x5E, 0x52, 0x5B, 0x51, 0x5C, 0x51, 0x5C, 0x50, 0x51, 0x44, 0x32, 0x30, 0x27, 0x26, 0x26, 0x29, 0x25, 0x27, 0x23, 0x27, 0x27, 0x2D, 0x2A, 0x38, 0x22, 0x30, 0x1E, 0x2B, 0x1C, 0x28, 0x1B, 0x26, 0x1B, 0x25, 0x1A, 0x22, 0x18, 0x1C, 0x21, 0x26, 0x28, 0x2E, 0x27, 0x2D, 0x2B, 0x34, 0x23, 0x29, 0x1D, 0x23, 0x1D, 0x23, 0x1B, 0x22, 0x1C, 0x22, 0x1B, 0x1F, 0x1C, 0x20, 0x25, 0x2A, 0x24, 0x27, 0x28, 0x30, 0x26, 0x2A, 0x1E, 0x23, 0x22, 0x27, 0x1B, 0x1E, 0x1E, 0x23, 0x1F, 0x24, 0x23, 0x27, 0x20, 0x23, 0x26, 0x2A, 0x26, 0x27, 0x29, 0x2F, 0x26, 0x28, 0x1D, 0x20, 0x21, 0x25, 0x24, 0x27, 0x22, 0x24
    },

    {
        0x53, 0x1E, 0x53, 0x1E, 0x53, 0x1E, 0x51, 0x1D, 0x4D, 0x1C, 0x44, 0x1B, 0x3A, 0x19, 0x3A, 0x19, 0x45, 0x1B, 0x49, 0x1C, 0x43, 0x1B, 0x38, 0x18, 0x29, 0x14, 0x1F, 0x11, 0x1B, 0x11, 0x19, 0x10, 0x18, 0x10, 0x18, 0x10, 0x17, 0x0F, 0x16, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x14, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x16, 0x10, 0x17, 0x10, 0x17, 0x10, 0x18, 0x11, 0x19, 0x11, 0x18, 0x11, 0x1A, 0x12, 0x1B, 0x13, 0x17, 0x10, 0x16, 0x10, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x14, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x10, 0x16, 0x10, 0x16, 0x0F, 0x16, 0x10, 0x15, 0x10, 0x16, 0x10, 0x17, 0x11, 0x17, 0x11, 0x17, 0x11, 0x18, 0x12, 0x20, 0x1A, 0x34, 0x2B, 0x55, 0x43, 0x80, 0x5B, 0x95, 0x68, 0x9C, 0x6C, 0xA1, 0x6F, 0xA5, 0x72, 0xA7, 0x73, 0xAC, 0x77, 0xAF, 0x77, 0xAE, 0x78, 0xAF, 0x76, 0xAF, 0x79, 0xB3, 0x7A, 0xB2, 0x7B, 0xB4, 0x7A, 0xB2, 0x7A, 0xB1, 0x78, 0xB0, 0x79, 0xB1, 0x79, 0xB0, 0x79, 0xB4, 0x7B, 0xB5, 0x7C, 0xB3, 0x7C, 0xB5, 0x7D, 0xB6, 0x7D, 0xB5, 0x7C, 0xB4, 0x7C, 0xB5, 0x7C, 0xB6, 0x7C, 0xB5, 0x7B, 0xB0, 0x78, 0x9D, 0x65, 0x63, 0x3D, 0x37, 0x24, 0x28, 0x1B, 0x21, 0x16, 0x1C, 0x14, 0x19, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x17, 0x11, 0x17, 0x11, 0x17, 0x10, 0x17, 0x10, 0x18, 0x11, 0x17, 0x10, 0x17, 0x10, 0x16, 0x0F, 0x15, 0x0F, 0x16, 0x10, 0x17, 0x10, 0x18, 0x11, 0x16, 0x10, 0x15, 0x0F, 0x16, 0x10, 0x16, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x16, 0x0F, 0x16, 0x10, 0x16, 0x0F, 0x16, 0x0F, 0x16, 0x10, 0x16, 0x10, 0x15, 0x10, 0x16, 0x10, 0x16, 0x0F, 0x15, 0x0F, 0x16, 0x0F, 0x16, 0x10, 0x16, 0x0F, 0x18, 0x11, 0x17, 0x10, 0x17, 0x10, 0x16, 0x0F, 0x17, 0x10, 0x17, 0x0F, 0x19, 0x11, 0x21, 0x15, 0x41, 0x1E, 0x56, 0x21, 0x5B, 0x21, 0x55, 0x1F, 0x3B, 0x19, 0x33, 0x19, 0x4C, 0x1F, 0x58, 0x20, 0x5B, 0x21, 0x60, 0x22, 0x5E, 0x20, 0x5E, 0x21, 0x60, 0x22, 0x60, 0x23, 0x61, 0x23, 0x61, 0x22, 0x62, 0x23, 0x65, 0x23, 0x61, 0x22, 0x62, 0x23, 0x62, 0x23, 0x61, 0x22, 0x61, 0x22, 0x60, 0x22, 0x61, 0x22, 0x63, 0x22, 0x62, 0x23, 0x63, 0x23, 0x61, 0x23, 0x63, 0x24, 0x61, 0x23, 0x61, 0x23, 0x62, 0x23, 0x61, 0x22, 0x64, 0x22, 0x61, 0x22, 0x60, 0x22, 0x61, 0x21, 0x63, 0x23, 0x63, 0x24, 0x63, 0x24, 0x63, 0x24, 0x61, 0x23, 0x65, 0x24, 0x63, 0x24, 0x61, 0x23, 0x63, 0x24, 0x63, 0x23, 0x61, 0x24, 0x61, 0x22, 0x60, 0x22, 0x60, 0x23, 0x62, 0x23, 0x62, 0x23, 0x63, 0x23, 0x61, 0x22, 0x60, 0x22, 0x62, 0x23, 0x62, 0x23, 0x63, 0x24, 0x62, 0x23, 0x60, 0x22, 0x60, 0x22, 0x5E, 0x21, 0x60, 0x22, 0x60, 0x23, 0x5E, 0x21, 0x59, 0x1F, 0x3A, 0x18, 0x29, 0x14, 0x23, 0x12, 0x2A, 0x15, 0x3D, 0x1C, 0x4E, 0x1D, 0x3F, 0x19, 0x34, 0x15, 0x2B, 0x14, 0x27, 0x13, 0x2C, 0x14, 0x36, 0x18, 0x4C, 0x1D, 0x56, 0x20, 0x5D, 0x22, 0x62, 0x22, 0x61, 0x22, 0x61, 0x23, 0x62, 0x24, 0x62, 0x25, 0x5F, 0x23, 0x5E, 0x22, 0x60, 0x22, 0x5D, 0x21, 0x5D, 0x21, 0x5E, 0x22, 0x5E, 0x22, 0x5F, 0x22, 0x5E, 0x22, 0x5D, 0x22, 0x60, 0x23, 0x60, 0x23, 0x61, 0x23, 0x61, 0x24, 0x60, 0x22, 0x5F, 0x23, 0x5F, 0x22, 0x60, 0x23, 0x5C, 0x23, 0x60, 0x23, 0x5E, 0x22, 0x5E, 0x22, 0x5D, 0x22, 0x5D, 0x21, 0x5C, 0x21, 0x5B, 0x21, 0x5D, 0x22, 0x5D, 0x22, 0x5C, 0x21, 0x5D, 0x21, 0x5A, 0x21, 0x58, 0x20, 0x56, 0x20, 0x58, 0x20, 0x59, 0x20, 0x5B, 0x21, 0x5B, 0x21, 0x58, 0x20, 0x56, 0x1F, 0x57, 0x1F, 0x54, 0x1F, 0x56, 0x20, 0x55, 0x1F, 0x55, 0x1F, 0x53, 0x1F, 0x4C, 0x1D, 0x32, 0x19, 0x2F, 0x1A, 0x2C, 0x1A, 0x33, 0x1B, 0x32, 0x1B, 0x2C, 0x1B, 0x30, 0x1B, 0x24, 0x19, 0x23, 0x18, 0x20, 0x16, 0x21, 0x16, 0x21, 0x17, 0x28, 0x18, 0x25, 0x17, 0x24, 0x17, 0x31, 0x1C, 0x2E, 0x1D, 0x3C, 0x23, 0x30, 0x1E, 0x2D, 0x1D, 0x2D, 0x1C, 0x2E, 0x1C, 0x2D, 0x1A, 0x29, 0x19, 0x26, 0x17, 0x29, 0x1A, 0x2C, 0x1A, 0x29, 0x19, 0x2A, 0x19, 0x24, 0x17, 0x2A, 0x18, 0x23, 0x16, 0x2D, 0x1A, 0x25, 0x16, 0x25, 0x17, 0x26, 0x16, 0x29, 0x18, 0x25, 0x16, 0x2B, 0x19, 0x27, 0x19, 0x2C, 0x19, 0x27, 0x18, 0x29, 0x19, 0x28, 0x18
    },

    {
        0x5B, 0x50, 0x59, 0x4F, 0x58, 0x50, 0x54, 0x4D, 0x4F, 0x47, 0x47, 0x3E, 0x3C, 0x37, 0x3D, 0x3C, 0x47, 0x44, 0x4A, 0x44, 0x44, 0x3E, 0x36, 0x30, 0x25, 0x23, 0x1B, 0x1C, 0x16, 0x19, 0x15, 0x17, 0x13, 0x17, 0x13, 0x16, 0x12, 0x16, 0x11, 0x15, 0x11, 0x14, 0x11, 0x15, 0x11, 0x15, 0x10, 0x14, 0x11, 0x14, 0x11, 0x14, 0x12, 0x15, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x13, 0x17, 0x13, 0x18, 0x14, 0x17, 0x13, 0x19, 0x15, 0x1A, 0x13, 0x17, 0x12, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x14, 0x10, 0x14, 0x10, 0x14, 0x10, 0x14, 0x10, 0x13, 0x10, 0x14, 0x10, 0x14, 0x10, 0x14, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x12, 0x16, 0x12, 0x16, 0x13, 0x16, 0x15, 0x19, 0x1D, 0x25, 0x2C, 0x3D, 0x45, 0x64, 0x64, 0x85, 0x71, 0x93, 0x77, 0x98, 0x7C, 0x9D, 0x7F, 0xA0, 0x81, 0xA1, 0x83, 0xA4, 0x86, 0xA7, 0x85, 0xA7, 0x86, 0xA6, 0x85, 0xA6, 0x87, 0xA8, 0x89, 0xAB, 0x8A, 0xAC, 0x89, 0xAB, 0x88, 0xA9, 0x88, 0xA9, 0x88, 0xAA, 0x88, 0xA7, 0x89, 0xAB, 0x89, 0xAC, 0x89, 0xAB, 0x8B, 0xAF, 0x8A, 0xAE, 0x8B, 0xAD, 0x8A, 0xAD, 0x88, 0xAC, 0x88, 0xAD, 0x88, 0xAC, 0x86, 0xA9, 0x7C, 0x9C, 0x58, 0x64, 0x34, 0x37, 0x24, 0x28, 0x1D, 0x20, 0x18, 0x1B, 0x14, 0x18, 0x13, 0x18, 0x14, 0x17, 0x12, 0x17, 0x12, 0x17, 0x13, 0x17, 0x12, 0x17, 0x12, 0x16, 0x12, 0x16, 0x12, 0x17, 0x12, 0x16, 0x13, 0x17, 0x12, 0x16, 0x12, 0x16, 0x11, 0x15, 0x11, 0x14, 0x12, 0x16, 0x12, 0x16, 0x13, 0x17, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x14, 0x11, 0x14, 0x11, 0x15, 0x11, 0x14, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x12, 0x15, 0x11, 0x15, 0x11, 0x14, 0x12, 0x15, 0x11, 0x15, 0x12, 0x14, 0x12, 0x15, 0x11, 0x15, 0x12, 0x15, 0x13, 0x16, 0x13, 0x16, 0x12, 0x15, 0x12, 0x16, 0x13, 0x16, 0x12, 0x16, 0x14, 0x17, 0x1B, 0x1D, 0x36, 0x3A, 0x53, 0x50, 0x5C, 0x56, 0x5B, 0x52, 0x45, 0x3C, 0x34, 0x31, 0x4A, 0x48, 0x5B, 0x54, 0x61, 0x59, 0x67, 0x5B, 0x66, 0x5A, 0x66, 0x5A, 0x68, 0x5C, 0x67, 0x5D, 0x6A, 0x5F, 0x6B, 0x5D, 0x6B, 0x5E, 0x6E, 0x5F, 0x6A, 0x5C, 0x6B, 0x5D, 0x6A, 0x5F, 0x69, 0x5C, 0x6B, 0x5E, 0x69, 0x5C, 0x6B, 0x60, 0x6D, 0x61, 0x6B, 0x60, 0x6C, 0x5E, 0x6A, 0x5C, 0x6C, 0x5F, 0x6B, 0x5E, 0x6A, 0x5E, 0x6B, 0x5E, 0x6C, 0x5F, 0x6E, 0x60, 0x6A, 0x5C, 0x69, 0x5C, 0x6C, 0x5D, 0x6C, 0x5F, 0x6C, 0x61, 0x6E, 0x5F, 0x6B, 0x5F, 0x6A, 0x5E, 0x6D, 0x61, 0x6B, 0x5E, 0x6B, 0x60, 0x6D, 0x61, 0x6C, 0x5E, 0x6B, 0x5F, 0x6B, 0x5D, 0x6A, 0x5D, 0x6A, 0x5E, 0x6C, 0x5E, 0x6C, 0x5E, 0x6D, 0x60, 0x69, 0x5D, 0x6A, 0x5D, 0x6C, 0x5E, 0x6B, 0x5F, 0x6E, 0x60, 0x6C, 0x60, 0x69, 0x5C, 0x68, 0x5B, 0x69, 0x5B, 0x69, 0x5D, 0x6B, 0x5F, 0x67, 0x5A, 0x64, 0x57, 0x49, 0x3C, 0x34, 0x2C, 0x2E, 0x28, 0x38, 0x35, 0x4C, 0x4B, 0x57, 0x4F, 0x48, 0x3F, 0x39, 0x32, 0x31, 0x2B, 0x2E, 0x2A, 0x35, 0x32, 0x41, 0x3E, 0x54, 0x4E, 0x5E, 0x55, 0x65, 0x5B, 0x6C, 0x5E, 0x6B, 0x5D, 0x6A, 0x5D, 0x6C, 0x61, 0x6C, 0x62, 0x68, 0x5C, 0x66, 0x5B, 0x68, 0x5D, 0x66, 0x57, 0x66, 0x5A, 0x69, 0x5C, 0x66, 0x5C, 0x67, 0x5C, 0x66, 0x5A, 0x67, 0x5B, 0x67, 0x5C, 0x69, 0x5D, 0x69, 0x5C, 0x67, 0x5E, 0x67, 0x5B, 0x69, 0x5C, 0x68, 0x5D, 0x68, 0x5E, 0x65, 0x5B, 0x6A, 0x5D, 0x67, 0x5B, 0x68, 0x5B, 0x64, 0x5A, 0x66, 0x5A, 0x65, 0x58, 0x63, 0x59, 0x66, 0x5A, 0x66, 0x5A, 0x64, 0x59, 0x65, 0x5A, 0x63, 0x57, 0x60, 0x55, 0x60, 0x54, 0x61, 0x56, 0x62, 0x56, 0x64, 0x59, 0x63, 0x56, 0x5F, 0x55, 0x5D, 0x52, 0x60, 0x53, 0x5B, 0x51, 0x5D, 0x53, 0x5D, 0x51, 0x5C, 0x52, 0x5A, 0x50, 0x51, 0x46, 0x33, 0x31, 0x2C, 0x2C, 0x28, 0x2D, 0x2D, 0x30, 0x2A, 0x2C, 0x25, 0x2A, 0x26, 0x27, 0x1F, 0x24, 0x20, 0x23, 0x1C, 0x21, 0x1D, 0x21, 0x1C, 0x22, 0x24, 0x2A, 0x21, 0x25, 0x21, 0x24, 0x29, 0x2D, 0x28, 0x2E, 0x31, 0x38, 0x28, 0x2C, 0x28, 0x2F, 0x24, 0x2A, 0x27, 0x2B, 0x26, 0x29, 0x24, 0x28, 0x20, 0x23, 0x26, 0x2B, 0x24, 0x27, 0x23, 0x26, 0x23, 0x25, 0x20, 0x24, 0x23, 0x25, 0x20, 0x25, 0x28, 0x2C, 0x21, 0x24, 0x21, 0x23, 0x24, 0x26, 0x26, 0x29, 0x20, 0x23, 0x28, 0x2C, 0x24, 0x2A, 0x28, 0x2A, 0x24, 0x27, 0x26, 0x2B, 0x25, 0x29
    },

    {
        0x54, 0x1F, 0x52, 0x1D, 0x51, 0x1D, 0x4A, 0x1D, 0x43, 0x1A, 0x3A, 0x19, 0x38, 0x19, 0x42, 0x1B, 0x48, 0x1C, 0x43, 0x1B, 0x3A, 0x19, 0x2A, 0x14, 0x20, 0x12, 0x1B, 0x10, 0x19, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x10, 0x15, 0x0F, 0x16, 0x10, 0x16, 0x11, 0x17, 0x11, 0x17, 0x10, 0x16, 0x10, 0x18, 0x11, 0x18, 0x11, 0x18, 0x12, 0x1A, 0x12, 0x1A, 0x12, 0x17, 0x10, 0x16, 0x10, 0x16, 0x0F, 0x15, 0x0F, 0x14, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x14, 0x0F, 0x15, 0x0F, 0x15, 0x10, 0x15, 0x10, 0x16, 0x11, 0x16, 0x11, 0x17, 0x10, 0x16, 0x11, 0x16, 0x10, 0x16, 0x11, 0x18, 0x11, 0x18, 0x12, 0x1F, 0x19, 0x32, 0x2A, 0x57, 0x44, 0x80, 0x5E, 0x97, 0x6A, 0xA1, 0x6E, 0xA4, 0x71, 0xA7, 0x72, 0xA8, 0x73, 0xAB, 0x74, 0xAD, 0x77, 0xB0, 0x79, 0xB0, 0x7A, 0xAF, 0x78, 0xAE, 0x77, 0xAE, 0x79, 0xB1, 0x7A, 0xB4, 0x7C, 0xB5, 0x7B, 0xB5, 0x7B, 0xB4, 0x7B, 0xB5, 0x7C, 0xB6, 0x7D, 0xB6, 0x7C, 0xB5, 0x7B, 0xB4, 0x7C, 0xB5, 0x7C, 0xB5, 0x7B, 0xB4, 0x7C, 0xB3, 0x7B, 0xB3, 0x7B, 0xB5, 0x7D, 0xB7, 0x7C, 0xB7, 0x7C, 0xB0, 0x78, 0xA3, 0x67, 0x69, 0x40, 0x3A, 0x26, 0x28, 0x1B, 0x20, 0x16, 0x1C, 0x14, 0x18, 0x12, 0x19, 0x12, 0x18, 0x11, 0x17, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x17, 0x11, 0x17, 0x10, 0x17, 0x11, 0x17, 0x10, 0x17, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x17, 0x11, 0x18, 0x11, 0x17, 0x11, 0x16, 0x10, 0x15, 0x10, 0x16, 0x0F, 0x16, 0x10, 0x15, 0x0F, 0x15, 0x0F, 0x16, 0x0F, 0x15, 0x10, 0x15, 0x0F, 0x16, 0x10, 0x16, 0x10, 0x17, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x17, 0x10, 0x16, 0x10, 0x16, 0x10, 0x15, 0x0F, 0x16, 0x0F, 0x16, 0x10, 0x17, 0x10, 0x15, 0x0E, 0x16, 0x10, 0x18, 0x10, 0x1E, 0x13, 0x3F, 0x1D, 0x55, 0x20, 0x56, 0x21, 0x56, 0x20, 0x3F, 0x1A, 0x32, 0x1A, 0x4A, 0x1E, 0x58, 0x21, 0x5D, 0x21, 0x5E, 0x22, 0x5C, 0x21, 0x5D, 0x21, 0x5F, 0x22, 0x63, 0x24, 0x63, 0x23, 0x5D, 0x22, 0x62, 0x22, 0x61, 0x23, 0x61, 0x24, 0x62, 0x24, 0x62, 0x23, 0x63, 0x24, 0x62, 0x23, 0x63, 0x23, 0x66, 0x23, 0x65, 0x24, 0x61, 0x24, 0x61, 0x23, 0x61, 0x23, 0x61, 0x23, 0x61, 0x23, 0x61, 0x23, 0x61, 0x22, 0x63, 0x23, 0x5D, 0x22, 0x5F, 0x22, 0x63, 0x23, 0x62, 0x23, 0x62, 0x24, 0x62, 0x24, 0x64, 0x24, 0x64, 0x25, 0x65, 0x24, 0x62, 0x25, 0x66, 0x26, 0x67, 0x26, 0x64, 0x24, 0x63, 0x23, 0x61, 0x22, 0x5E, 0x21, 0x5E, 0x22, 0x60, 0x23, 0x60, 0x22, 0x60, 0x23, 0x5F, 0x22, 0x5F, 0x22, 0x60, 0x21, 0x5E, 0x22, 0x61, 0x23, 0x64, 0x24, 0x61, 0x23, 0x60, 0x22, 0x61, 0x22, 0x60, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x61, 0x22, 0x5A, 0x20, 0x4E, 0x1D, 0x49, 0x1D, 0x55, 0x20, 0x5E, 0x22, 0x5C, 0x21, 0x54, 0x1F, 0x47, 0x1B, 0x40, 0x1A, 0x40, 0x19, 0x45, 0x1B, 0x4E, 0x1E, 0x57, 0x20, 0x5C, 0x21, 0x5D, 0x22, 0x61, 0x21, 0x5F, 0x23, 0x60, 0x22, 0x61, 0x24, 0x68, 0x28, 0x64, 0x25, 0x5D, 0x22, 0x5C, 0x21, 0x5C, 0x21, 0x5C, 0x21, 0x5C, 0x21, 0x5E, 0x22, 0x5C, 0x21, 0x5E, 0x22, 0x5F, 0x23, 0x5C, 0x22, 0x60, 0x23, 0x5D, 0x22, 0x5D, 0x22, 0x5D, 0x22, 0x5F, 0x22, 0x60, 0x23, 0x61, 0x23, 0x60, 0x23, 0x60, 0x23, 0x5E, 0x22, 0x5E, 0x22, 0x5C, 0x22, 0x5F, 0x22, 0x5D, 0x22, 0x5C, 0x21, 0x5F, 0x22, 0x5E, 0x23, 0x5D, 0x22, 0x5C, 0x21, 0x5B, 0x21, 0x5A, 0x22, 0x5A, 0x21, 0x5A, 0x21, 0x5A, 0x20, 0x59, 0x22, 0x5F, 0x24, 0x58, 0x21, 0x57, 0x20, 0x55, 0x1F, 0x55, 0x1F, 0x54, 0x1F, 0x55, 0x1F, 0x53, 0x20, 0x52, 0x1F, 0x4C, 0x1D, 0x32, 0x1A, 0x2B, 0x18, 0x2A, 0x18, 0x2A, 0x17, 0x26, 0x17, 0x25, 0x17, 0x25, 0x17, 0x2B, 0x1A, 0x27, 0x17, 0x25, 0x17, 0x26, 0x17, 0x27, 0x19, 0x2E, 0x1A, 0x2C, 0x19, 0x28, 0x19, 0x2A, 0x1A, 0x2E, 0x1D, 0x2F, 0x1C, 0x2C, 0x1C, 0x31, 0x1E, 0x2A, 0x1B, 0x2D, 0x1B, 0x2C, 0x1A, 0x27, 0x18, 0x28, 0x18, 0x31, 0x1C, 0x2A, 0x18, 0x29, 0x19, 0x28, 0x17, 0x2F, 0x1B, 0x2D, 0x1A, 0x29, 0x19, 0x32, 0x1B, 0x2A, 0x18, 0x2F, 0x1B, 0x2F, 0x1A, 0x2C, 0x19, 0x28, 0x18, 0x31, 0x1B, 0x2B, 0x19, 0x23, 0x16, 0x2D, 0x1A, 0x30, 0x1B, 0x2F, 0x1A
    },

    {
        0x5B, 0x52, 0x58, 0x4F, 0x54, 0x4B, 0x4E, 0x46, 0x46, 0x3E, 0x3B, 0x36, 0x3B, 0x3A, 0x45, 0x43, 0x4A, 0x45, 0x43, 0x3F, 0x38, 0x33, 0x27, 0x24, 0x1C, 0x1D, 0x17, 0x19, 0x14, 0x17, 0x13, 0x16, 0x12, 0x16, 0x13, 0x17, 0x13, 0x17, 0x11, 0x15, 0x11, 0x14, 0x11, 0x15, 0x11, 0x14, 0x11, 0x14, 0x11, 0x15, 0x11, 0x15, 0x12, 0x15, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x15, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x14, 0x18, 0x13, 0x18, 0x12, 0x16, 0x12, 0x16, 0x11, 0x15, 0x11, 0x14, 0x11, 0x14, 0x10, 0x14, 0x11, 0x15, 0x10, 0x14, 0x11, 0x14, 0x10, 0x14, 0x10, 0x14, 0x11, 0x15, 0x11, 0x15, 0x11, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x15, 0x12, 0x16, 0x13, 0x16, 0x15, 0x19, 0x1C, 0x23, 0x2B, 0x3C, 0x47, 0x66, 0x66, 0x89, 0x74, 0x96, 0x79, 0x9C, 0x7E, 0x9F, 0x80, 0xA0, 0x81, 0xA1, 0x82, 0xA3, 0x85, 0xA4, 0x85, 0xA8, 0x87, 0xAB, 0x87, 0xA9, 0x86, 0xA7, 0x85, 0xA9, 0x89, 0xAA, 0x89, 0xAC, 0x8A, 0xAB, 0x89, 0xAC, 0x8A, 0xAC, 0x8B, 0xAE, 0x8B, 0xAF, 0x8D, 0xB0, 0x8B, 0xAE, 0x89, 0xAD, 0x8A, 0xAD, 0x89, 0xAA, 0x87, 0xAB, 0x89, 0xAC, 0x87, 0xAC, 0x8A, 0xAE, 0x8B, 0xAF, 0x8A, 0xAE, 0x86, 0xAA, 0x7D, 0x9D, 0x5C, 0x6A, 0x36, 0x3C, 0x24, 0x28, 0x1C, 0x20, 0x18, 0x1B, 0x15, 0x18, 0x14, 0x18, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x13, 0x16, 0x13, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x15, 0x12, 0x15, 0x12, 0x15, 0x12, 0x16, 0x13, 0x17, 0x12, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x14, 0x11, 0x14, 0x11, 0x14, 0x11, 0x15, 0x12, 0x15, 0x11, 0x14, 0x11, 0x14, 0x11, 0x15, 0x12, 0x16, 0x12, 0x16, 0x12, 0x15, 0x11, 0x15, 0x11, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x15, 0x11, 0x15, 0x12, 0x15, 0x11, 0x14, 0x11, 0x15, 0x12, 0x16, 0x12, 0x16, 0x11, 0x15, 0x13, 0x15, 0x14, 0x16, 0x19, 0x1C, 0x34, 0x39, 0x50, 0x4F, 0x59, 0x53, 0x5B, 0x54, 0x48, 0x3F, 0x35, 0x2F, 0x47, 0x44, 0x5A, 0x54, 0x61, 0x58, 0x64, 0x5A, 0x64, 0x58, 0x66, 0x5A, 0x67, 0x5C, 0x6C, 0x5F, 0x6C, 0x5F, 0x68, 0x5B, 0x6B, 0x5E, 0x6A, 0x5E, 0x6A, 0x5E, 0x6B, 0x60, 0x69, 0x5E, 0x6C, 0x60, 0x6A, 0x5E, 0x6E, 0x60, 0x6F, 0x61, 0x6E, 0x63, 0x6B, 0x5F, 0x6C, 0x5E, 0x6B, 0x5E, 0x6B, 0x5E, 0x6C, 0x5E, 0x6B, 0x5D, 0x6B, 0x5E, 0x6D, 0x5E, 0x68, 0x5A, 0x69, 0x5D, 0x6B, 0x60, 0x69, 0x5E, 0x6C, 0x60, 0x6D, 0x5F, 0x6D, 0x60, 0x6E, 0x62, 0x6D, 0x63, 0x6D, 0x62, 0x6F, 0x63, 0x6F, 0x64, 0x6B, 0x60, 0x6D, 0x60, 0x6B, 0x5D, 0x68, 0x5B, 0x68, 0x5C, 0x6A, 0x5D, 0x69, 0x5D, 0x6A, 0x5E, 0x69, 0x5C, 0x6B, 0x5E, 0x6A, 0x5C, 0x69, 0x5B, 0x6B, 0x5F, 0x6D, 0x60, 0x6B, 0x5E, 0x68, 0x5C, 0x6A, 0x5D, 0x69, 0x5B, 0x69, 0x5C, 0x69, 0x5C, 0x6D, 0x5F, 0x67, 0x59, 0x5D, 0x4F, 0x59, 0x51, 0x62, 0x59, 0x67, 0x5B, 0x65, 0x58, 0x5D, 0x52, 0x53, 0x49, 0x4C, 0x44, 0x4C, 0x44, 0x51, 0x4A, 0x57, 0x51, 0x60, 0x56, 0x65, 0x5A, 0x67, 0x5A, 0x6A, 0x5C, 0x68, 0x5C, 0x6B, 0x5C, 0x6B, 0x5E, 0x6D, 0x60, 0x6C, 0x60, 0x67, 0x5B, 0x67, 0x5A, 0x66, 0x58, 0x66, 0x5A, 0x66, 0x5A, 0x67, 0x5C, 0x64, 0x58, 0x67, 0x5B, 0x65, 0x5C, 0x65, 0x5A, 0x67, 0x5C, 0x67, 0x59, 0x64, 0x5A, 0x66, 0x5B, 0x68, 0x5A, 0x6A, 0x5E, 0x6A, 0x5E, 0x6A, 0x5E, 0x67, 0x5B, 0x65, 0x59, 0x66, 0x59, 0x66, 0x5A, 0x68, 0x5C, 0x65, 0x5B, 0x64, 0x5A, 0x69, 0x5E, 0x68, 0x5B, 0x67, 0x5B, 0x65, 0x59, 0x64, 0x59, 0x65, 0x5A, 0x63, 0x58, 0x62, 0x57, 0x61, 0x56, 0x62, 0x57, 0x66, 0x5C, 0x61, 0x56, 0x5F, 0x54, 0x5F, 0x53, 0x5D, 0x51, 0x5C, 0x51, 0x5C, 0x51, 0x5C, 0x52, 0x59, 0x51, 0x4F, 0x45, 0x31, 0x2E, 0x27, 0x26, 0x28, 0x2C, 0x25, 0x25, 0x22, 0x25, 0x22, 0x25, 0x22, 0x24, 0x27, 0x2A, 0x22, 0x26, 0x21, 0x26, 0x22, 0x26, 0x25, 0x2B, 0x29, 0x2F, 0x26, 0x28, 0x25, 0x2A, 0x27, 0x2A, 0x2A, 0x31, 0x29, 0x2F, 0x27, 0x2D, 0x2B, 0x30, 0x26, 0x2C, 0x2B, 0x2F, 0x27, 0x2A, 0x24, 0x27, 0x26, 0x2B, 0x2D, 0x32, 0x27, 0x2A, 0x26, 0x2A, 0x28, 0x2B, 0x2C, 0x31, 0x29, 0x2C, 0x26, 0x2B, 0x2D, 0x31, 0x26, 0x29, 0x2C, 0x32, 0x28, 0x2A, 0x26, 0x29, 0x24, 0x27, 0x2A, 0x2E, 0x24, 0x25, 0x21, 0x24, 0x29, 0x2C, 0x2B, 0x31, 0x28, 0x29
    },

    {
        0x53, 0x1E, 0x51, 0x1D, 0x4B, 0x1C, 0x45, 0x1A, 0x3B, 0x19, 0x39, 0x19, 0x40, 0x1A, 0x47, 0x1B, 0x45, 0x1A, 0x3B, 0x18, 0x2C, 0x15, 0x21, 0x13, 0x1C, 0x11, 0x1A, 0x10, 0x18, 0x10, 0x17, 0x0F, 0x16, 0x0F, 0x16, 0x10, 0x17, 0x10, 0x15, 0x0F, 0x15, 0x0F, 0x16, 0x0F, 0x15, 0x0F, 0x16, 0x0F, 0x15, 0x0F, 0x16, 0x0F, 0x16, 0x0F, 0x15, 0x0F, 0x16, 0x10, 0x16, 0x0F, 0x15, 0x0F, 0x16, 0x10, 0x16, 0x10, 0x16, 0x0F, 0x17, 0x11, 0x18, 0x11, 0x17, 0x10, 0x16, 0x10, 0x15, 0x10, 0x15, 0x0F, 0x15, 0x0F, 0x14, 0x0E, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x10, 0x15, 0x0F, 0x15, 0x0F, 0x16, 0x10, 0x17, 0x10, 0x18, 0x11, 0x16, 0x10, 0x17, 0x10, 0x17, 0x10, 0x18, 0x12, 0x1E, 0x18, 0x2E, 0x26, 0x53, 0x40, 0x82, 0x5E, 0x9B, 0x6B, 0xA2, 0x6F, 0xA8, 0x73, 0xA9, 0x74, 0xAA, 0x75, 0xAA, 0x74, 0xAA, 0x75, 0xAD, 0x76, 0xAE, 0x78, 0xB0, 0x78, 0xB3, 0x7A, 0xB2, 0x7A, 0xB2, 0x79, 0xB0, 0x7A, 0xB3, 0x7C, 0xB3, 0x7B, 0xB4, 0x7B, 0xB4, 0x7A, 0xB5, 0x7C, 0xB7, 0x7C, 0xB7, 0x7C, 0xB7, 0x7D, 0xB6, 0x7D, 0xB4, 0x7C, 0xB3, 0x7A, 0xB3, 0x7B, 0xB5, 0x7D, 0xB7, 0x7C, 0xB6, 0x7D, 0xB8, 0x7D, 0xB6, 0x7D, 0xB3, 0x7C, 0xAF, 0x78, 0xA5, 0x6D, 0x74, 0x47, 0x3D, 0x27, 0x27, 0x1A, 0x20, 0x16, 0x1B, 0x13, 0x1A, 0x12, 0x19, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x17, 0x11, 0x18, 0x11, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x16, 0x10, 0x16, 0x10, 0x17, 0x10, 0x17, 0x10, 0x16, 0x10, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x16, 0x10, 0x16, 0x10, 0x15, 0x0F, 0x16, 0x0F, 0x16, 0x10, 0x16, 0x10, 0x16, 0x0F, 0x16, 0x0F, 0x17, 0x10, 0x17, 0x10, 0x16, 0x10, 0x17, 0x10, 0x16, 0x10, 0x16, 0x0F, 0x15, 0x0F, 0x17, 0x10, 0x16, 0x0F, 0x16, 0x0F, 0x15, 0x0F, 0x17, 0x10, 0x17, 0x10, 0x16, 0x0F, 0x1D, 0x13, 0x39, 0x1A, 0x50, 0x1F, 0x5A, 0x21, 0x59, 0x20, 0x41, 0x19, 0x30, 0x18, 0x46, 0x1E, 0x56, 0x20, 0x5B, 0x20, 0x5C, 0x21, 0x5C, 0x22, 0x60, 0x22, 0x61, 0x22, 0x63, 0x22, 0x61, 0x22, 0x61, 0x22, 0x60, 0x22, 0x63, 0x23, 0x63, 0x24, 0x64, 0x23, 0x62, 0x23, 0x63, 0x23, 0x63, 0x23, 0x64, 0x23, 0x63, 0x23, 0x61, 0x23, 0x62, 0x23, 0x61, 0x23, 0x62, 0x23, 0x62, 0x22, 0x61, 0x22, 0x61, 0x22, 0x62, 0x22, 0x63, 0x24, 0x65, 0x25, 0x64, 0x25, 0x65, 0x24, 0x62, 0x23, 0x61, 0x24, 0x66, 0x25, 0x64, 0x25, 0x66, 0x25, 0x68, 0x25, 0x66, 0x24, 0x63, 0x23, 0x63, 0x22, 0x61, 0x24, 0x63, 0x23, 0x5F, 0x22, 0x5E, 0x21, 0x62, 0x22, 0x60, 0x24, 0x61, 0x23, 0x5F, 0x21, 0x60, 0x22, 0x60, 0x23, 0x60, 0x22, 0x62, 0x23, 0x65, 0x25, 0x60, 0x23, 0x5F, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x5E, 0x21, 0x5E, 0x21, 0x60, 0x22, 0x63, 0x23, 0x5D, 0x21, 0x5C, 0x21, 0x5E, 0x22, 0x60, 0x23, 0x5D, 0x21, 0x5C, 0x21, 0x58, 0x20, 0x57, 0x1F, 0x55, 0x1F, 0x5A, 0x20, 0x58, 0x20, 0x5B, 0x20, 0x5D, 0x21, 0x5E, 0x22, 0x60, 0x22, 0x61, 0x22, 0x5F, 0x22, 0x5C, 0x21, 0x5D, 0x21, 0x5C, 0x22, 0x5E, 0x21, 0x5B, 0x20, 0x5D, 0x22, 0x5D, 0x22, 0x5E, 0x22, 0x5F, 0x22, 0x5D, 0x21, 0x5D, 0x21, 0x5B, 0x21, 0x5C, 0x22, 0x5D, 0x22, 0x5D, 0x22, 0x5C, 0x22, 0x5E, 0x22, 0x5E, 0x22, 0x5F, 0x23, 0x62, 0x23, 0x60, 0x22, 0x5E, 0x22, 0x5C, 0x22, 0x5A, 0x21, 0x5F, 0x22, 0x5F, 0x22, 0x5D, 0x22, 0x5C, 0x22, 0x5D, 0x22, 0x60, 0x22, 0x5D, 0x23, 0x5B, 0x21, 0x5C, 0x22, 0x5C, 0x21, 0x57, 0x20, 0x58, 0x20, 0x59, 0x21, 0x59, 0x20, 0x57, 0x20, 0x58, 0x20, 0x57, 0x20, 0x56, 0x1F, 0x54, 0x1F, 0x56, 0x20, 0x56, 0x20, 0x57, 0x21, 0x57, 0x20, 0x4D, 0x1D, 0x32, 0x18, 0x2B, 0x17, 0x2F, 0x1A, 0x2D, 0x19, 0x2C, 0x18, 0x29, 0x19, 0x34, 0x1B, 0x33, 0x1B, 0x31, 0x1B, 0x28, 0x17, 0x2F, 0x1A, 0x34, 0x1C, 0x33, 0x1B, 0x2C, 0x19, 0x2A, 0x1A, 0x36, 0x1E, 0x35, 0x1E, 0x37, 0x1F, 0x2F, 0x1C, 0x37, 0x1E, 0x33, 0x1D, 0x36, 0x1D, 0x2B, 0x18, 0x2C, 0x1B, 0x2F, 0x19, 0x2D, 0x1A, 0x2B, 0x18, 0x2D, 0x1B, 0x37, 0x1D, 0x2B, 0x19, 0x2C, 0x1A, 0x2C, 0x1A, 0x2C, 0x17, 0x23, 0x16, 0x2B, 0x18, 0x23, 0x15, 0x26, 0x16, 0x23, 0x15, 0x2A, 0x18, 0x23, 0x15, 0x2E, 0x1A, 0x2A, 0x18, 0x31, 0x1B, 0x26, 0x16
    },

    {
        0x59, 0x50, 0x55, 0x4C, 0x50, 0x47, 0x47, 0x3F, 0x3C, 0x36, 0x3A, 0x38, 0x43, 0x41, 0x49, 0x45, 0x45, 0x3F, 0x38, 0x33, 0x28, 0x26, 0x1D, 0x1D, 0x18, 0x1A, 0x16, 0x18, 0x13, 0x16, 0x13, 0x16, 0x12, 0x16, 0x12, 0x15, 0x12, 0x16, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x14, 0x11, 0x15, 0x11, 0x15, 0x12, 0x15, 0x12, 0x15, 0x11, 0x14, 0x11, 0x15, 0x11, 0x15, 0x11, 0x14, 0x12, 0x15, 0x11, 0x14, 0x11, 0x15, 0x12, 0x16, 0x12, 0x16, 0x12, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x10, 0x14, 0x11, 0x14, 0x10, 0x14, 0x11, 0x14, 0x11, 0x15, 0x11, 0x14, 0x11, 0x14, 0x11, 0x15, 0x12, 0x16, 0x12, 0x16, 0x12, 0x15, 0x12, 0x15, 0x13, 0x16, 0x15, 0x18, 0x1B, 0x21, 0x27, 0x37, 0x41, 0x5D, 0x64, 0x87, 0x76, 0x97, 0x79, 0x9A, 0x7E, 0xA0, 0x82, 0xA3, 0x83, 0xA4, 0x83, 0xA4, 0x82, 0xA3, 0x84, 0xA5, 0x85, 0xA6, 0x85, 0xA8, 0x87, 0xA9, 0x87, 0xA9, 0x87, 0xA8, 0x86, 0xA8, 0x88, 0xAB, 0x89, 0xAF, 0x8A, 0xAD, 0x8A, 0xAC, 0x89, 0xAE, 0x89, 0xAC, 0x8B, 0xAD, 0x8B, 0xAD, 0x89, 0xAD, 0x8A, 0xAC, 0x88, 0xAB, 0x89, 0xAD, 0x89, 0xAF, 0x8A, 0xAE, 0x8A, 0xAE, 0x8B, 0xAF, 0x8B, 0xAD, 0x89, 0xAC, 0x85, 0xAA, 0x7E, 0xA2, 0x62, 0x75, 0x37, 0x3C, 0x21, 0x26, 0x1B, 0x1F, 0x17, 0x1A, 0x14, 0x18, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x12, 0x16, 0x13, 0x17, 0x12, 0x16, 0x13, 0x17, 0x13, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x14, 0x11, 0x14, 0x11, 0x14, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x14, 0x11, 0x15, 0x11, 0x16, 0x12, 0x15, 0x11, 0x15, 0x11, 0x15, 0x12, 0x15, 0x12, 0x15, 0x12, 0x15, 0x11, 0x15, 0x12, 0x15, 0x12, 0x15, 0x13, 0x16, 0x12, 0x16, 0x12, 0x15, 0x12, 0x15, 0x13, 0x16, 0x13, 0x16, 0x13, 0x15, 0x18, 0x1B, 0x30, 0x33, 0x4C, 0x4C, 0x5C, 0x58, 0x5F, 0x56, 0x49, 0x3F, 0x33, 0x2D, 0x42, 0x41, 0x57, 0x51, 0x5F, 0x55, 0x62, 0x59, 0x65, 0x5A, 0x68, 0x5C, 0x6A, 0x5D, 0x6B, 0x5E, 0x6B, 0x5D, 0x68, 0x5C, 0x69, 0x5D, 0x69, 0x5F, 0x6B, 0x60, 0x6C, 0x60, 0x6D, 0x60, 0x6C, 0x5F, 0x6D, 0x5F, 0x6F, 0x60, 0x6C, 0x5F, 0x6C, 0x5F, 0x6C, 0x60, 0x6B, 0x5F, 0x6B, 0x5D, 0x69, 0x5D, 0x6D, 0x5E, 0x6B, 0x5D, 0x6B, 0x5F, 0x6B, 0x60, 0x6D, 0x61, 0x6D, 0x62, 0x6D, 0x61, 0x6C, 0x5F, 0x6D, 0x5F, 0x6F, 0x63, 0x6C, 0x62, 0x6F, 0x64, 0x6F, 0x64, 0x6D, 0x60, 0x6B, 0x60, 0x6C, 0x5F, 0x69, 0x5E, 0x6B, 0x60, 0x68, 0x5D, 0x68, 0x5B, 0x6C, 0x5E, 0x68, 0x5E, 0x6A, 0x5E, 0x68, 0x5B, 0x6A, 0x5D, 0x68, 0x5D, 0x6B, 0x5E, 0x6C, 0x60, 0x6D, 0x60, 0x6A, 0x5C, 0x68, 0x5D, 0x68, 0x5D, 0x68, 0x5C, 0x67, 0x5C, 0x68, 0x5B, 0x69, 0x5E, 0x6E, 0x60, 0x68, 0x5C, 0x65, 0x5A, 0x67, 0x5C, 0x6A, 0x5E, 0x67, 0x5A, 0x65, 0x58, 0x62, 0x58, 0x62, 0x55, 0x60, 0x56, 0x64, 0x58, 0x63, 0x57, 0x63, 0x57, 0x65, 0x58, 0x67, 0x5C, 0x68, 0x5D, 0x6B, 0x5D, 0x69, 0x5A, 0x66, 0x58, 0x65, 0x59, 0x65, 0x57, 0x67, 0x5A, 0x64, 0x58, 0x64, 0x59, 0x66, 0x5A, 0x67, 0x5A, 0x66, 0x5C, 0x66, 0x5A, 0x66, 0x5B, 0x64, 0x59, 0x64, 0x59, 0x64, 0x59, 0x67, 0x5C, 0x67, 0x5A, 0x68, 0x5C, 0x67, 0x5B, 0x68, 0x5D, 0x6A, 0x5D, 0x67, 0x5B, 0x66, 0x5A, 0x67, 0x5A, 0x63, 0x58, 0x68, 0x5D, 0x67, 0x5B, 0x68, 0x5A, 0x64, 0x5A, 0x64, 0x5A, 0x68, 0x5B, 0x65, 0x5A, 0x63, 0x59, 0x65, 0x59, 0x66, 0x59, 0x61, 0x55, 0x5E, 0x54, 0x60, 0x57, 0x60, 0x55, 0x5F, 0x55, 0x61, 0x54, 0x5F, 0x56, 0x5D, 0x53, 0x5D, 0x52, 0x5F, 0x53, 0x5D, 0x54, 0x5E, 0x53, 0x5E, 0x53, 0x51, 0x45, 0x31, 0x30, 0x2A, 0x2A, 0x2B, 0x2E, 0x2A, 0x2E, 0x26, 0x29, 0x27, 0x2E, 0x2D, 0x31, 0x2C, 0x31, 0x2A, 0x2C, 0x24, 0x27, 0x2A, 0x2E, 0x2B, 0x30, 0x2A, 0x2D, 0x27, 0x29, 0x26, 0x2E, 0x2E, 0x31, 0x2C, 0x30, 0x2E, 0x32, 0x28, 0x2B, 0x31, 0x36, 0x2B, 0x30, 0x2D, 0x31, 0x25, 0x26, 0x29, 0x2F, 0x27, 0x27, 0x28, 0x2C, 0x26, 0x28, 0x28, 0x2F, 0x2E, 0x30, 0x25, 0x28, 0x25, 0x27, 0x27, 0x2C, 0x25, 0x24, 0x20, 0x24, 0x27, 0x28, 0x1E, 0x1F, 0x24, 0x27, 0x21, 0x23, 0x25, 0x28, 0x21, 0x25, 0x2B, 0x2F, 0x25, 0x27, 0x2C, 0x2F, 0x23, 0x25
    },

    {
        0x51, 0x1E, 0x4C, 0x1C, 0x45, 0x1B, 0x3D, 0x19, 0x38, 0x18, 0x3F, 0x1A, 0x46, 0x1B, 0x44, 0x1A, 0x3C, 0x18, 0x2D, 0x15, 0x22, 0x13, 0x1C, 0x11, 0x19, 0x10, 0x19, 0x11, 0x19, 0x10, 0x18, 0x10, 0x17, 0x11, 0x17, 0x10, 0x18, 0x11, 0x17, 0x10, 0x16, 0x0F, 0x16, 0x10, 0x16, 0x10, 0x17, 0x10, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x14, 0x0F, 0x15, 0x0F, 0x16, 0x0F, 0x15, 0x0F, 0x16, 0x10, 0x17, 0x11, 0x17, 0x11, 0x17, 0x10, 0x16, 0x10, 0x16, 0x10, 0x15, 0x10, 0x15, 0x0F, 0x15, 0x0F, 0x16, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x10, 0x15, 0x0F, 0x15, 0x0F, 0x16, 0x10, 0x16, 0x11, 0x18, 0x10, 0x16, 0x10, 0x17, 0x11, 0x18, 0x12, 0x1E, 0x17, 0x2C, 0x24, 0x49, 0x3B, 0x75, 0x57, 0x90, 0x65, 0x9A, 0x6A, 0xA0, 0x6E, 0xA4, 0x70, 0xA9, 0x74, 0xAB, 0x73, 0xAB, 0x75, 0xAD, 0x76, 0xAE, 0x77, 0xAF, 0x79, 0xAF, 0x78, 0xAF, 0x79, 0xB0, 0x7A, 0xB0, 0x79, 0xB2, 0x79, 0xB3, 0x7A, 0xB6, 0x7C, 0xB8, 0x7B, 0xB6, 0x7A, 0xB4, 0x7B, 0xB3, 0x7B, 0xB4, 0x7C, 0xB5, 0x7D, 0xB4, 0x7C, 0xB5, 0x7B, 0xB3, 0x7A, 0xB4, 0x7B, 0xB3, 0x7C, 0xB6, 0x7C, 0xB6, 0x7D, 0xB7, 0x7E, 0xB6, 0x7D, 0xB4, 0x7D, 0xB6, 0x7B, 0xB3, 0x7A, 0xA7, 0x6C, 0x6C, 0x3F, 0x33, 0x21, 0x23, 0x18, 0x1D, 0x14, 0x1B, 0x12, 0x19, 0x11, 0x18, 0x11, 0x18, 0x11, 0x17, 0x11, 0x18, 0x11, 0x17, 0x11, 0x18, 0x11, 0x18, 0x11, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x16, 0x10, 0x17, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x0F, 0x16, 0x10, 0x16, 0x10, 0x15, 0x0F, 0x15, 0x10, 0x16, 0x0F, 0x16, 0x0F, 0x16, 0x10, 0x16, 0x0F, 0x16, 0x0F, 0x16, 0x11, 0x17, 0x10, 0x17, 0x10, 0x16, 0x10, 0x16, 0x0F, 0x16, 0x0F, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x15, 0x10, 0x17, 0x10, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x19, 0x11, 0x17, 0x10, 0x15, 0x0F, 0x16, 0x0F, 0x1C, 0x13, 0x36, 0x1A, 0x52, 0x20, 0x5A, 0x21, 0x59, 0x21, 0x42, 0x1A, 0x2F, 0x18, 0x44, 0x1D, 0x54, 0x21, 0x5C, 0x21, 0x5D, 0x22, 0x61, 0x22, 0x60, 0x22, 0x61, 0x22, 0x62, 0x22, 0x61, 0x22, 0x5E, 0x23, 0x64, 0x24, 0x65, 0x25, 0x66, 0x24, 0x65, 0x25, 0x62, 0x23, 0x63, 0x23, 0x64, 0x24, 0x65, 0x24, 0x64, 0x24, 0x64, 0x23, 0x62, 0x23, 0x64, 0x23, 0x5F, 0x23, 0x63, 0x24, 0x64, 0x23, 0x63, 0x24, 0x65, 0x24, 0x61, 0x24, 0x62, 0x23, 0x62, 0x23, 0x61, 0x22, 0x64, 0x24, 0x67, 0x26, 0x67, 0x25, 0x69, 0x25, 0x61, 0x23, 0x60, 0x23, 0x60, 0x23, 0x63, 0x23, 0x60, 0x23, 0x64, 0x24, 0x64, 0x25, 0x61, 0x23, 0x62, 0x24, 0x61, 0x24, 0x61, 0x24, 0x62, 0x23, 0x61, 0x22, 0x63, 0x23, 0x60, 0x22, 0x66, 0x25, 0x64, 0x24, 0x5F, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x63, 0x23, 0x60, 0x23, 0x5F, 0x22, 0x61, 0x22, 0x60, 0x22, 0x62, 0x25, 0x5F, 0x22, 0x60, 0x22, 0x61, 0x23, 0x5F, 0x22, 0x5E, 0x22, 0x5B, 0x21, 0x5D, 0x21, 0x5D, 0x21, 0x5C, 0x20, 0x5C, 0x20, 0x5A, 0x21, 0x5C, 0x20, 0x5E, 0x21, 0x5E, 0x21, 0x5E, 0x21, 0x5E, 0x23, 0x5C, 0x21, 0x5C, 0x22, 0x5D, 0x22, 0x5A, 0x20, 0x5B, 0x21, 0x58, 0x21, 0x5C, 0x22, 0x5C, 0x22, 0x5D, 0x21, 0x5D, 0x22, 0x5E, 0x22, 0x5D, 0x22, 0x5D, 0x22, 0x5E, 0x22, 0x60, 0x23, 0x5E, 0x22, 0x5F, 0x22, 0x5E, 0x23, 0x5F, 0x23, 0x5F, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x5E, 0x23, 0x5E, 0x23, 0x5F, 0x22, 0x5F, 0x23, 0x5F, 0x23, 0x5D, 0x22, 0x5E, 0x23, 0x5D, 0x23, 0x5A, 0x21, 0x5B, 0x21, 0x5B, 0x21, 0x5E, 0x22, 0x5A, 0x22, 0x59, 0x21, 0x5B, 0x22, 0x55, 0x20, 0x5A, 0x21, 0x5B, 0x21, 0x58, 0x20, 0x58, 0x20, 0x57, 0x20, 0x57, 0x20, 0x59, 0x20, 0x58, 0x21, 0x57, 0x20, 0x4D, 0x1D, 0x39, 0x1C, 0x33, 0x1B, 0x2E, 0x1A, 0x2D, 0x18, 0x25, 0x16, 0x31, 0x1B, 0x2B, 0x18, 0x2B, 0x19, 0x24, 0x16, 0x26, 0x17, 0x28, 0x16, 0x24, 0x16, 0x25, 0x16, 0x23, 0x16, 0x2E, 0x1B, 0x2B, 0x18, 0x2A, 0x1A, 0x29, 0x19, 0x29, 0x1B, 0x30, 0x1B, 0x28, 0x19, 0x2A, 0x18, 0x25, 0x17, 0x2D, 0x1A, 0x26, 0x17, 0x2C, 0x1A, 0x26, 0x17, 0x2B, 0x1A, 0x26, 0x16, 0x28, 0x18, 0x25, 0x17, 0x28, 0x17, 0x27, 0x17, 0x29, 0x17, 0x2B, 0x18, 0x29, 0x19, 0x2D, 0x19, 0x2B, 0x18, 0x2F, 0x1B, 0x33, 0x1C, 0x32, 0x1A, 0x2C, 0x1A, 0x2E, 0x19, 0x2B, 0x18
    },

    {
        0x56, 0x4D, 0x4F, 0x47, 0x48, 0x40, 0x3E, 0x38, 0x39, 0x39, 0x42, 0x40, 0x47, 0x43, 0x44, 0x3F, 0x39, 0x34, 0x28, 0x26, 0x1D, 0x1E, 0x18, 0x19, 0x15, 0x19, 0x14, 0x17, 0x14, 0x17, 0x14, 0x17, 0x14, 0x17, 0x14, 0x17, 0x14, 0x18, 0x13, 0x16, 0x12, 0x15, 0x12, 0x16, 0x12, 0x16, 0x11, 0x15, 0x12, 0x15, 0x10, 0x14, 0x10, 0x14, 0x10, 0x14, 0x11, 0x14, 0x10, 0x14, 0x11, 0x14, 0x11, 0x15, 0x10, 0x14, 0x11, 0x15, 0x11, 0x15, 0x11, 0x16, 0x12, 0x15, 0x11, 0x15, 0x11, 0x14, 0x11, 0x14, 0x11, 0x14, 0x10, 0x14, 0x11, 0x15, 0x11, 0x14, 0x11, 0x14, 0x11, 0x14, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x12, 0x16, 0x12, 0x17, 0x12, 0x16, 0x12, 0x16, 0x14, 0x18, 0x19, 0x20, 0x26, 0x34, 0x3C, 0x56, 0x5B, 0x7C, 0x6E, 0x8F, 0x75, 0x96, 0x7B, 0x9C, 0x7E, 0x9E, 0x81, 0xA1, 0x84, 0xA3, 0x82, 0xA3, 0x83, 0xA3, 0x85, 0xA5, 0x86, 0xA8, 0x85, 0xA8, 0x85, 0xA6, 0x86, 0xA9, 0x87, 0xAA, 0x86, 0xA8, 0x86, 0xAB, 0x8A, 0xAB, 0x8A, 0xAC, 0x89, 0xAB, 0x89, 0xAD, 0x89, 0xAB, 0x88, 0xAD, 0x8B, 0xAF, 0x89, 0xAD, 0x8A, 0xAB, 0x88, 0xAB, 0x88, 0xAA, 0x88, 0xAB, 0x89, 0xAC, 0x8A, 0xAE, 0x8B, 0xB0, 0x8B, 0xAF, 0x89, 0xAE, 0x89, 0xAC, 0x84, 0xA9, 0x7A, 0x9A, 0x55, 0x63, 0x2B, 0x2F, 0x1D, 0x21, 0x17, 0x1B, 0x15, 0x19, 0x13, 0x17, 0x13, 0x16, 0x13, 0x17, 0x12, 0x16, 0x12, 0x17, 0x12, 0x17, 0x13, 0x17, 0x12, 0x17, 0x13, 0x17, 0x12, 0x16, 0x11, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x15, 0x11, 0x15, 0x12, 0x15, 0x12, 0x15, 0x11, 0x14, 0x11, 0x15, 0x11, 0x15, 0x11, 0x14, 0x11, 0x15, 0x11, 0x14, 0x11, 0x15, 0x12, 0x15, 0x12, 0x15, 0x11, 0x15, 0x12, 0x15, 0x12, 0x16, 0x12, 0x15, 0x11, 0x14, 0x11, 0x15, 0x11, 0x14, 0x11, 0x15, 0x12, 0x15, 0x12, 0x15, 0x11, 0x14, 0x12, 0x15, 0x11, 0x14, 0x12, 0x15, 0x11, 0x15, 0x14, 0x18, 0x13, 0x16, 0x12, 0x14, 0x13, 0x15, 0x17, 0x1A, 0x2C, 0x31, 0x4D, 0x4D, 0x5C, 0x56, 0x5F, 0x57, 0x4A, 0x41, 0x33, 0x2D, 0x40, 0x40, 0x55, 0x4F, 0x5F, 0x57, 0x65, 0x5C, 0x68, 0x5D, 0x69, 0x5D, 0x6D, 0x60, 0x6B, 0x5E, 0x6A, 0x5D, 0x68, 0x5D, 0x6B, 0x61, 0x6D, 0x62, 0x6F, 0x61, 0x6D, 0x62, 0x6B, 0x5D, 0x6D, 0x60, 0x6E, 0x61, 0x6E, 0x62, 0x6F, 0x62, 0x6E, 0x60, 0x6A, 0x5E, 0x6C, 0x5F, 0x69, 0x5C, 0x6C, 0x5F, 0x6C, 0x60, 0x6D, 0x60, 0x6D, 0x60, 0x6A, 0x5E, 0x6A, 0x5E, 0x6C, 0x5E, 0x6A, 0x5F, 0x6E, 0x62, 0x6E, 0x63, 0x6F, 0x62, 0x70, 0x63, 0x6B, 0x5E, 0x69, 0x5D, 0x6A, 0x5E, 0x6E, 0x61, 0x6C, 0x5F, 0x6C, 0x60, 0x6E, 0x63, 0x69, 0x5E, 0x6C, 0x5F, 0x6B, 0x5F, 0x6B, 0x5E, 0x6D, 0x60, 0x6B, 0x5F, 0x6C, 0x5F, 0x6B, 0x5D, 0x6F, 0x62, 0x6D, 0x60, 0x69, 0x5C, 0x69, 0x5D, 0x67, 0x5C, 0x6B, 0x60, 0x6A, 0x5E, 0x69, 0x5C, 0x6C, 0x5E, 0x6B, 0x5D, 0x6B, 0x61, 0x66, 0x5B, 0x67, 0x5C, 0x6A, 0x5E, 0x68, 0x5B, 0x68, 0x5B, 0x62, 0x59, 0x66, 0x5A, 0x66, 0x59, 0x66, 0x5A, 0x67, 0x5A, 0x63, 0x59, 0x66, 0x59, 0x67, 0x5A, 0x68, 0x59, 0x68, 0x5A, 0x68, 0x5C, 0x67, 0x59, 0x67, 0x5A, 0x67, 0x5A, 0x64, 0x57, 0x62, 0x58, 0x60, 0x56, 0x64, 0x59, 0x65, 0x5A, 0x66, 0x5A, 0x66, 0x5A, 0x66, 0x5B, 0x65, 0x59, 0x66, 0x5C, 0x67, 0x5C, 0x69, 0x5C, 0x68, 0x5B, 0x68, 0x5C, 0x66, 0x5B, 0x67, 0x5C, 0x68, 0x5B, 0x69, 0x5E, 0x68, 0x5B, 0x66, 0x5B, 0x69, 0x5C, 0x67, 0x5B, 0x67, 0x5A, 0x69, 0x5C, 0x65, 0x5B, 0x67, 0x5D, 0x66, 0x5B, 0x62, 0x57, 0x65, 0x58, 0x63, 0x59, 0x66, 0x5A, 0x62, 0x57, 0x60, 0x57, 0x60, 0x56, 0x5D, 0x54, 0x61, 0x57, 0x61, 0x56, 0x5F, 0x55, 0x5F, 0x54, 0x60, 0x55, 0x61, 0x56, 0x61, 0x54, 0x60, 0x55, 0x5E, 0x53, 0x50, 0x45, 0x37, 0x38, 0x2D, 0x2D, 0x2A, 0x2E, 0x27, 0x27, 0x20, 0x22, 0x2B, 0x2F, 0x24, 0x24, 0x24, 0x26, 0x20, 0x21, 0x24, 0x28, 0x23, 0x23, 0x22, 0x24, 0x21, 0x21, 0x20, 0x21, 0x29, 0x2D, 0x24, 0x26, 0x27, 0x2B, 0x23, 0x26, 0x27, 0x2C, 0x28, 0x2A, 0x25, 0x28, 0x24, 0x27, 0x22, 0x27, 0x27, 0x29, 0x23, 0x25, 0x28, 0x2A, 0x22, 0x24, 0x27, 0x2A, 0x22, 0x23, 0x25, 0x29, 0x23, 0x25, 0x26, 0x2A, 0x26, 0x28, 0x27, 0x2A, 0x27, 0x28, 0x28, 0x2E, 0x27, 0x2B, 0x27, 0x28, 0x2C, 0x32, 0x2F, 0x31, 0x2A, 0x2C, 0x28, 0x2C, 0x28, 0x29, 0x28, 0x29
    },

    {
        0x4E, 0x1E, 0x46, 0x1B, 0x3E, 0x1A, 0x39, 0x18, 0x40, 0x1A, 0x48, 0x1C, 0x45, 0x1B, 0x3D, 0x18, 0x2F, 0x16, 0x22, 0x12, 0x1D, 0x11, 0x19, 0x10, 0x18, 0x10, 0x18, 0x10, 0x18, 0x10, 0x19, 0x12, 0x1A, 0x13, 0x1B, 0x12, 0x1B, 0x13, 0x1A, 0x11, 0x19, 0x11, 0x17, 0x10, 0x16, 0x10, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x16, 0x0F, 0x15, 0x0F, 0x16, 0x10, 0x17, 0x11, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x0F, 0x16, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x16, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x1A, 0x14, 0x28, 0x22, 0x47, 0x39, 0x71, 0x54, 0x8C, 0x62, 0x96, 0x69, 0x9D, 0x6D, 0xA4, 0x70, 0xA8, 0x73, 0xAB, 0x74, 0xAC, 0x77, 0xAC, 0x77, 0xAD, 0x77, 0xAD, 0x78, 0xB1, 0x79, 0xB1, 0x79, 0xB1, 0x77, 0xAF, 0x76, 0xAF, 0x78, 0xB2, 0x7A, 0xB0, 0x79, 0xB2, 0x7B, 0xB2, 0x7A, 0xB1, 0x79, 0xB4, 0x7C, 0xB5, 0x7B, 0xB4, 0x7B, 0xB4, 0x7C, 0xB5, 0x7E, 0xB6, 0x7D, 0xB3, 0x7C, 0xB4, 0x7C, 0xB5, 0x7B, 0xB3, 0x7B, 0xB4, 0x7D, 0xB6, 0x7C, 0xB6, 0x7D, 0xB4, 0x7C, 0xB4, 0x7B, 0xB1, 0x78, 0x9D, 0x66, 0x73, 0x45, 0x3A, 0x23, 0x24, 0x18, 0x1E, 0x14, 0x1B, 0x13, 0x1A, 0x12, 0x18, 0x11, 0x17, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x17, 0x11, 0x16, 0x10, 0x17, 0x11, 0x17, 0x10, 0x16, 0x10, 0x16, 0x10, 0x15, 0x0F, 0x16, 0x10, 0x15, 0x0F, 0x16, 0x10, 0x16, 0x10, 0x16, 0x0F, 0x16, 0x10, 0x16, 0x0F, 0x15, 0x0F, 0x16, 0x0F, 0x16, 0x0F, 0x16, 0x0F, 0x17, 0x10, 0x18, 0x10, 0x17, 0x10, 0x16, 0x0F, 0x16, 0x0F, 0x17, 0x10, 0x16, 0x0F, 0x16, 0x10, 0x16, 0x0F, 0x15, 0x0F, 0x16, 0x0F, 0x16, 0x0F, 0x15, 0x0F, 0x16, 0x0F, 0x15, 0x0F, 0x17, 0x10, 0x17, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x17, 0x10, 0x1B, 0x12, 0x33, 0x1A, 0x50, 0x1F, 0x5B, 0x21, 0x5A, 0x20, 0x44, 0x1A, 0x2F, 0x18, 0x40, 0x1C, 0x54, 0x1F, 0x5E, 0x23, 0x61, 0x23, 0x5F, 0x22, 0x65, 0x24, 0x65, 0x23, 0x65, 0x23, 0x65, 0x24, 0x66, 0x25, 0x66, 0x25, 0x66, 0x24, 0x65, 0x24, 0x63, 0x23, 0x64, 0x23, 0x65, 0x23, 0x63, 0x24, 0x65, 0x24, 0x64, 0x24, 0x63, 0x23, 0x62, 0x23, 0x61, 0x22, 0x62, 0x23, 0x63, 0x23, 0x62, 0x23, 0x63, 0x23, 0x63, 0x23, 0x64, 0x24, 0x62, 0x23, 0x64, 0x23, 0x63, 0x24, 0x67, 0x25, 0x62, 0x23, 0x66, 0x25, 0x65, 0x24, 0x63, 0x23, 0x61, 0x23, 0x61, 0x23, 0x63, 0x23, 0x64, 0x25, 0x62, 0x24, 0x63, 0x24, 0x64, 0x24, 0x66, 0x24, 0x63, 0x24, 0x64, 0x24, 0x61, 0x23, 0x64, 0x24, 0x66, 0x24, 0x64, 0x24, 0x62, 0x23, 0x62, 0x23, 0x61, 0x22, 0x5E, 0x22, 0x61, 0x22, 0x63, 0x23, 0x61, 0x22, 0x62, 0x23, 0x62, 0x23, 0x61, 0x22, 0x5E, 0x22, 0x5E, 0x21, 0x60, 0x23, 0x5D, 0x22, 0x5C, 0x21, 0x5E, 0x21, 0x5E, 0x22, 0x5F, 0x21, 0x5C, 0x21, 0x5D, 0x20, 0x5B, 0x21, 0x5C, 0x21, 0x5E, 0x21, 0x61, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x5E, 0x21, 0x5E, 0x22, 0x5A, 0x20, 0x59, 0x20, 0x5B, 0x21, 0x5E, 0x22, 0x5E, 0x21, 0x5E, 0x22, 0x5F, 0x22, 0x5D, 0x22, 0x5F, 0x22, 0x60, 0x23, 0x5C, 0x21, 0x5D, 0x22, 0x5E, 0x22, 0x5F, 0x22, 0x5E, 0x23, 0x5F, 0x23, 0x5E, 0x23, 0x5F, 0x23, 0x5F, 0x22, 0x5C, 0x22, 0x5D, 0x23, 0x61, 0x23, 0x5F, 0x23, 0x5F, 0x22, 0x5E, 0x22, 0x5E, 0x23, 0x5F, 0x23, 0x5D, 0x22, 0x5B, 0x21, 0x5B, 0x22, 0x5B, 0x21, 0x5C, 0x23, 0x5E, 0x24, 0x5A, 0x21, 0x55, 0x20, 0x59, 0x21, 0x59, 0x21, 0x59, 0x21, 0x59, 0x20, 0x59, 0x20, 0x59, 0x20, 0x58, 0x20, 0x59, 0x20, 0x56, 0x1F, 0x4C, 0x1D, 0x3A, 0x1B, 0x27, 0x16, 0x30, 0x1B, 0x25, 0x16, 0x26, 0x17, 0x2F, 0x19, 0x24, 0x17, 0x30, 0x1B, 0x2B, 0x1A, 0x30, 0x1B, 0x29, 0x18, 0x2C, 0x19, 0x2A, 0x18, 0x2C, 0x1A, 0x2F, 0x1A, 0x2B, 0x1A, 0x30, 0x1B, 0x30, 0x1D, 0x36, 0x1D, 0x2E, 0x1B, 0x2E, 0x1B, 0x2F, 0x1B, 0x2C, 0x1A, 0x29, 0x18, 0x2B, 0x19, 0x2F, 0x1B, 0x2E, 0x1A, 0x31, 0x1B, 0x2F, 0x1A, 0x30, 0x1A, 0x31, 0x1B, 0x31, 0x1C, 0x2E, 0x19, 0x2D, 0x1A, 0x30, 0x1A, 0x2C, 0x18, 0x2B, 0x18, 0x28, 0x17, 0x34, 0x1C, 0x2A, 0x18, 0x24, 0x16, 0x29, 0x19, 0x30, 0x1B, 0x2E, 0x19
    },

    {
        0x51, 0x49, 0x49, 0x42, 0x3F, 0x3A, 0x3A, 0x38, 0x42, 0x41, 0x4B, 0x45, 0x46, 0x41, 0x3C, 0x36, 0x2B, 0x27, 0x1D, 0x1E, 0x18, 0x1A, 0x15, 0x18, 0x14, 0x17, 0x13, 0x16, 0x13, 0x17, 0x14, 0x19, 0x15, 0x1A, 0x16, 0x1A, 0x15, 0x1B, 0x15, 0x19, 0x14, 0x18, 0x12, 0x15, 0x12, 0x15, 0x11, 0x14, 0x11, 0x14, 0x11, 0x14, 0x11, 0x14, 0x10, 0x13, 0x10, 0x14, 0x11, 0x14, 0x10, 0x14, 0x11, 0x14, 0x11, 0x14, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x12, 0x15, 0x11, 0x15, 0x11, 0x14, 0x11, 0x14, 0x10, 0x14, 0x10, 0x14, 0x11, 0x15, 0x10, 0x14, 0x10, 0x14, 0x11, 0x14, 0x10, 0x14, 0x10, 0x14, 0x11, 0x15, 0x12, 0x16, 0x12, 0x16, 0x11, 0x15, 0x12, 0x15, 0x16, 0x1C, 0x21, 0x2E, 0x38, 0x52, 0x58, 0x7B, 0x6B, 0x8B, 0x73, 0x95, 0x78, 0x99, 0x7D, 0x9F, 0x80, 0xA2, 0x82, 0xA3, 0x84, 0xA6, 0x85, 0xA6, 0x86, 0xA7, 0x86, 0xA8, 0x85, 0xA8, 0x85, 0xA6, 0x85, 0xA7, 0x84, 0xA3, 0x85, 0xA8, 0x87, 0xAA, 0x87, 0xAA, 0x88, 0xAA, 0x89, 0xAA, 0x87, 0xA9, 0x89, 0xAD, 0x89, 0xAC, 0x88, 0xAA, 0x89, 0xAA, 0x8A, 0xAE, 0x8A, 0xAD, 0x8A, 0xAE, 0x8A, 0xAD, 0x89, 0xAD, 0x89, 0xAC, 0x89, 0xAD, 0x89, 0xAC, 0x8B, 0xAC, 0x89, 0xAE, 0x88, 0xAC, 0x83, 0xA6, 0x72, 0x8C, 0x52, 0x5E, 0x2D, 0x2F, 0x1D, 0x21, 0x18, 0x1B, 0x15, 0x1A, 0x14, 0x18, 0x12, 0x17, 0x13, 0x17, 0x12, 0x17, 0x13, 0x17, 0x12, 0x16, 0x12, 0x17, 0x13, 0x17, 0x12, 0x16, 0x12, 0x15, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x15, 0x10, 0x15, 0x11, 0x15, 0x11, 0x14, 0x11, 0x14, 0x11, 0x16, 0x11, 0x14, 0x11, 0x15, 0x11, 0x14, 0x11, 0x15, 0x11, 0x15, 0x12, 0x15, 0x11, 0x15, 0x12, 0x16, 0x12, 0x16, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x12, 0x15, 0x11, 0x15, 0x12, 0x15, 0x12, 0x15, 0x11, 0x14, 0x11, 0x15, 0x12, 0x15, 0x11, 0x14, 0x12, 0x14, 0x11, 0x14, 0x12, 0x15, 0x12, 0x15, 0x12, 0x14, 0x12, 0x14, 0x13, 0x16, 0x17, 0x19, 0x2A, 0x2F, 0x4B, 0x4C, 0x5D, 0x58, 0x5E, 0x56, 0x4D, 0x44, 0x33, 0x2D, 0x3D, 0x3B, 0x56, 0x50, 0x62, 0x5B, 0x67, 0x5E, 0x6A, 0x5E, 0x6E, 0x61, 0x6F, 0x61, 0x6E, 0x61, 0x6D, 0x61, 0x6E, 0x61, 0x6D, 0x61, 0x6F, 0x62, 0x6D, 0x61, 0x6B, 0x5F, 0x6D, 0x60, 0x6F, 0x5F, 0x6B, 0x60, 0x6C, 0x60, 0x6D, 0x5F, 0x6B, 0x5F, 0x6B, 0x5E, 0x6B, 0x5E, 0x6B, 0x5E, 0x6D, 0x5F, 0x6B, 0x5F, 0x6C, 0x5F, 0x6C, 0x61, 0x6E, 0x61, 0x6B, 0x5F, 0x6E, 0x61, 0x6C, 0x61, 0x6F, 0x63, 0x6B, 0x5F, 0x6F, 0x63, 0x6E, 0x61, 0x6C, 0x5F, 0x6A, 0x5F, 0x6B, 0x5E, 0x6C, 0x5F, 0x6A, 0x5F, 0x6B, 0x60, 0x6A, 0x60, 0x6E, 0x62, 0x6E, 0x62, 0x6F, 0x62, 0x6E, 0x60, 0x6A, 0x5E, 0x6E, 0x61, 0x6F, 0x61, 0x6E, 0x60, 0x6A, 0x5F, 0x6C, 0x5F, 0x69, 0x5C, 0x66, 0x5A, 0x69, 0x5E, 0x6D, 0x5F, 0x6B, 0x5F, 0x6B, 0x5F, 0x6C, 0x5E, 0x6C, 0x5E, 0x68, 0x5C, 0x69, 0x5C, 0x69, 0x5C, 0x67, 0x59, 0x64, 0x59, 0x64, 0x59, 0x67, 0x5C, 0x69, 0x5C, 0x65, 0x59, 0x67, 0x59, 0x66, 0x59, 0x66, 0x59, 0x68, 0x5B, 0x6B, 0x5D, 0x69, 0x5B, 0x68, 0x5E, 0x67, 0x5B, 0x67, 0x5B, 0x67, 0x5B, 0x63, 0x56, 0x62, 0x57, 0x63, 0x58, 0x66, 0x5B, 0x66, 0x58, 0x67, 0x5B, 0x68, 0x5B, 0x66, 0x5A, 0x68, 0x5D, 0x69, 0x5D, 0x66, 0x59, 0x66, 0x59, 0x67, 0x5C, 0x66, 0x5B, 0x66, 0x5B, 0x67, 0x5C, 0x67, 0x5D, 0x67, 0x5B, 0x66, 0x5B, 0x64, 0x59, 0x68, 0x5C, 0x6B, 0x60, 0x68, 0x5B, 0x67, 0x5B, 0x66, 0x5B, 0x65, 0x5A, 0x67, 0x5B, 0x67, 0x5A, 0x64, 0x59, 0x64, 0x59, 0x66, 0x59, 0x65, 0x59, 0x64, 0x5B, 0x61, 0x55, 0x5C, 0x51, 0x61, 0x56, 0x61, 0x58, 0x60, 0x56, 0x60, 0x55, 0x60, 0x54, 0x62, 0x55, 0x60, 0x55, 0x61, 0x56, 0x5E, 0x52, 0x50, 0x45, 0x37, 0x35, 0x24, 0x25, 0x2A, 0x2C, 0x22, 0x23, 0x26, 0x2B, 0x28, 0x2A, 0x22, 0x25, 0x2C, 0x34, 0x29, 0x2D, 0x2A, 0x2C, 0x27, 0x2A, 0x27, 0x2C, 0x28, 0x2A, 0x29, 0x2E, 0x28, 0x29, 0x28, 0x2D, 0x2B, 0x30, 0x2C, 0x32, 0x30, 0x34, 0x2A, 0x30, 0x2A, 0x2E, 0x2C, 0x31, 0x29, 0x2C, 0x26, 0x29, 0x28, 0x2C, 0x2B, 0x30, 0x2A, 0x2F, 0x2B, 0x2E, 0x2A, 0x2E, 0x2B, 0x30, 0x2B, 0x30, 0x2C, 0x2F, 0x27, 0x2A, 0x28, 0x2D, 0x2B, 0x2E, 0x26, 0x27, 0x28, 0x2D, 0x22, 0x24, 0x2D, 0x32, 0x23, 0x26, 0x21, 0x23, 0x25, 0x29, 0x2B, 0x30, 0x28, 0x29
    },

    {
        0x48, 0x1C, 0x40, 0x1A, 0x3B, 0x19, 0x3F, 0x1A, 0x47, 0x1C, 0x47, 0x1B, 0x3E, 0x1A, 0x30, 0x16, 0x24, 0x13, 0x1D, 0x11, 0x1A, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x19, 0x12, 0x1B, 0x13, 0x1E, 0x15, 0x1F, 0x15, 0x1D, 0x13, 0x19, 0x11, 0x17, 0x0F, 0x15, 0x0F, 0x14, 0x0E, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x0F, 0x17, 0x11, 0x17, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x15, 0x10, 0x16, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x14, 0x0F, 0x15, 0x0F, 0x15, 0x10, 0x16, 0x10, 0x16, 0x10, 0x17, 0x10, 0x17, 0x10, 0x16, 0x0F, 0x17, 0x11, 0x20, 0x1A, 0x3C, 0x31, 0x68, 0x4E, 0x89, 0x60, 0x94, 0x68, 0x9E, 0x6C, 0xA3, 0x70, 0xA6, 0x71, 0xA8, 0x74, 0xAB, 0x76, 0xAF, 0x76, 0xAE, 0x78, 0xB1, 0x78, 0xB0, 0x77, 0xB0, 0x79, 0xAF, 0x78, 0xAE, 0x78, 0xAD, 0x78, 0xAE, 0x77, 0xAF, 0x78, 0xB2, 0x7A, 0xB2, 0x7B, 0xB2, 0x7B, 0xB4, 0x7B, 0xB4, 0x7C, 0xB5, 0x7C, 0xB2, 0x7B, 0xB4, 0x7D, 0xB5, 0x7D, 0xB5, 0x7C, 0xB5, 0x7C, 0xB6, 0x7C, 0xB5, 0x7C, 0xB4, 0x7C, 0xB4, 0x7B, 0xB7, 0x7D, 0xB4, 0x7B, 0xB2, 0x7A, 0xB0, 0x78, 0xA4, 0x6C, 0x7F, 0x4F, 0x4A, 0x2D, 0x2E, 0x1D, 0x24, 0x18, 0x1D, 0x14, 0x1B, 0x13, 0x19, 0x12, 0x19, 0x12, 0x19, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x17, 0x10, 0x17, 0x11, 0x18, 0x10, 0x17, 0x11, 0x18, 0x11, 0x17, 0x10, 0x17, 0x10, 0x16, 0x10, 0x15, 0x0F, 0x15, 0x0F, 0x16, 0x0F, 0x16, 0x10, 0x16, 0x10, 0x15, 0x0F, 0x15, 0x10, 0x15, 0x0F, 0x15, 0x0E, 0x15, 0x0F, 0x16, 0x10, 0x16, 0x10, 0x16, 0x0F, 0x17, 0x10, 0x15, 0x0F, 0x16, 0x0F, 0x16, 0x0F, 0x16, 0x10, 0x16, 0x10, 0x17, 0x10, 0x16, 0x0F, 0x16, 0x0F, 0x16, 0x0F, 0x16, 0x0F, 0x16, 0x0F, 0x17, 0x10, 0x16, 0x0F, 0x17, 0x10, 0x17, 0x0F, 0x16, 0x0F, 0x16, 0x0F, 0x16, 0x0F, 0x17, 0x0F, 0x1A, 0x12, 0x2F, 0x19, 0x4D, 0x1F, 0x58, 0x20, 0x58, 0x20, 0x46, 0x1B, 0x2F, 0x17, 0x40, 0x1C, 0x57, 0x21, 0x60, 0x22, 0x5F, 0x23, 0x62, 0x23, 0x64, 0x24, 0x65, 0x23, 0x62, 0x23, 0x64, 0x24, 0x63, 0x24, 0x64, 0x22, 0x62, 0x23, 0x60, 0x23, 0x63, 0x23, 0x63, 0x23, 0x60, 0x23, 0x64, 0x23, 0x64, 0x24, 0x64, 0x24, 0x63, 0x24, 0x62, 0x23, 0x61, 0x23, 0x63, 0x23, 0x61, 0x22, 0x62, 0x23, 0x63, 0x24, 0x63, 0x23, 0x60, 0x23, 0x63, 0x24, 0x65, 0x24, 0x64, 0x24, 0x63, 0x23, 0x61, 0x24, 0x65, 0x24, 0x63, 0x23, 0x61, 0x23, 0x63, 0x23, 0x62, 0x23, 0x61, 0x25, 0x61, 0x24, 0x63, 0x24, 0x67, 0x24, 0x62, 0x23, 0x64, 0x24, 0x61, 0x23, 0x62, 0x22, 0x62, 0x23, 0x62, 0x23, 0x65, 0x24, 0x60, 0x23, 0x61, 0x23, 0x5F, 0x21, 0x5E, 0x22, 0x61, 0x22, 0x60, 0x22, 0x5F, 0x22, 0x63, 0x22, 0x61, 0x23, 0x60, 0x22, 0x5E, 0x21, 0x5F, 0x22, 0x5D, 0x21, 0x5C, 0x21, 0x5C, 0x22, 0x5D, 0x21, 0x5F, 0x22, 0x5E, 0x22, 0x5D, 0x22, 0x5C, 0x21, 0x5E, 0x20, 0x5B, 0x21, 0x5D, 0x21, 0x60, 0x22, 0x5E, 0x22, 0x5F, 0x22, 0x5D, 0x21, 0x5E, 0x22, 0x5E, 0x22, 0x5C, 0x20, 0x5A, 0x21, 0x58, 0x21, 0x5D, 0x21, 0x5B, 0x21, 0x5A, 0x21, 0x5D, 0x22, 0x5C, 0x22, 0x5E, 0x22, 0x5F, 0x22, 0x5D, 0x22, 0x5C, 0x22, 0x5C, 0x21, 0x5A, 0x22, 0x5C, 0x23, 0x62, 0x23, 0x60, 0x23, 0x5E, 0x22, 0x5B, 0x21, 0x5C, 0x22, 0x5F, 0x23, 0x5F, 0x24, 0x5E, 0x22, 0x5C, 0x21, 0x59, 0x22, 0x5D, 0x22, 0x5C, 0x22, 0x5B, 0x21, 0x5A, 0x21, 0x5B, 0x21, 0x5D, 0x22, 0x5D, 0x23, 0x5E, 0x23, 0x59, 0x21, 0x59, 0x21, 0x5A, 0x21, 0x5B, 0x21, 0x5A, 0x21, 0x58, 0x20, 0x58, 0x20, 0x59, 0x20, 0x57, 0x20, 0x57, 0x1F, 0x54, 0x1F, 0x4A, 0x1D, 0x33, 0x18, 0x2A, 0x18, 0x2C, 0x19, 0x2C, 0x19, 0x37, 0x1D, 0x2D, 0x19, 0x2A, 0x18, 0x37, 0x1F, 0x31, 0x1B, 0x29, 0x18, 0x2C, 0x18, 0x2F, 0x1A, 0x2E, 0x19, 0x2B, 0x19, 0x2A, 0x19, 0x32, 0x1B, 0x2E, 0x1B, 0x38, 0x1E, 0x32, 0x1D, 0x36, 0x1F, 0x2F, 0x1B, 0x39, 0x1F, 0x2E, 0x19, 0x35, 0x1C, 0x2B, 0x18, 0x34, 0x1D, 0x2B, 0x18, 0x2B, 0x19, 0x2A, 0x18, 0x2B, 0x1A, 0x2B, 0x19, 0x28, 0x18, 0x26, 0x16, 0x28, 0x18, 0x26, 0x18, 0x25, 0x17, 0x2C, 0x19, 0x23, 0x16, 0x2D, 0x19, 0x2A, 0x18, 0x29, 0x17, 0x2D, 0x19, 0x33, 0x1B, 0x28, 0x17
    },

    {
        0x49, 0x42, 0x40, 0x3B, 0x3B, 0x3A, 0x42, 0x40, 0x48, 0x46, 0x47, 0x42, 0x3D, 0x39, 0x2D, 0x2A, 0x1F, 0x20, 0x19, 0x1B, 0x16, 0x19, 0x14, 0x17, 0x13, 0x17, 0x12, 0x16, 0x13, 0x17, 0x13, 0x19, 0x15, 0x1B, 0x17, 0x1D, 0x18, 0x1E, 0x17, 0x1C, 0x14, 0x18, 0x12, 0x15, 0x11, 0x14, 0x10, 0x14, 0x10, 0x14, 0x11, 0x14, 0x11, 0x14, 0x10, 0x14, 0x10, 0x14, 0x11, 0x15, 0x11, 0x14, 0x11, 0x15, 0x11, 0x15, 0x11, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x15, 0x12, 0x16, 0x11, 0x15, 0x11, 0x15, 0x10, 0x15, 0x10, 0x14, 0x11, 0x15, 0x11, 0x14, 0x10, 0x14, 0x10, 0x14, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x16, 0x11, 0x15, 0x11, 0x15, 0x13, 0x17, 0x19, 0x22, 0x2C, 0x44, 0x4E, 0x70, 0x66, 0x86, 0x6F, 0x90, 0x77, 0x99, 0x7C, 0x9D, 0x80, 0xA2, 0x82, 0xA3, 0x83, 0xA4, 0x85, 0xA8, 0x85, 0xA9, 0x87, 0xA8, 0x86, 0xA7, 0x85, 0xA8, 0x84, 0xA6, 0x85, 0xA7, 0x85, 0xA8, 0x86, 0xA7, 0x86, 0xA8, 0x88, 0xA9, 0x88, 0xAA, 0x88, 0xAB, 0x89, 0xAB, 0x89, 0xAC, 0x8A, 0xAE, 0x89, 0xAC, 0x89, 0xAD, 0x8A, 0xAE, 0x89, 0xAD, 0x89, 0xAB, 0x89, 0xAC, 0x89, 0xAD, 0x88, 0xAD, 0x88, 0xAC, 0x89, 0xAE, 0x8A, 0xAD, 0x87, 0xAA, 0x82, 0xA3, 0x75, 0x8F, 0x5A, 0x67, 0x34, 0x39, 0x22, 0x27, 0x1C, 0x20, 0x17, 0x1C, 0x15, 0x1A, 0x14, 0x18, 0x14, 0x18, 0x13, 0x18, 0x12, 0x18, 0x12, 0x17, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x13, 0x17, 0x12, 0x17, 0x13, 0x17, 0x12, 0x16, 0x11, 0x16, 0x11, 0x15, 0x11, 0x14, 0x11, 0x14, 0x11, 0x15, 0x11, 0x15, 0x11, 0x14, 0x10, 0x14, 0x11, 0x15, 0x11, 0x15, 0x11, 0x14, 0x11, 0x14, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x14, 0x11, 0x15, 0x11, 0x15, 0x12, 0x15, 0x12, 0x15, 0x12, 0x16, 0x12, 0x16, 0x11, 0x15, 0x11, 0x14, 0x11, 0x15, 0x12, 0x15, 0x13, 0x16, 0x12, 0x15, 0x13, 0x17, 0x13, 0x16, 0x11, 0x14, 0x12, 0x15, 0x12, 0x16, 0x13, 0x15, 0x16, 0x18, 0x26, 0x2B, 0x49, 0x49, 0x59, 0x55, 0x5F, 0x56, 0x50, 0x47, 0x36, 0x2F, 0x3E, 0x3D, 0x57, 0x55, 0x62, 0x5A, 0x64, 0x5B, 0x6A, 0x5E, 0x6D, 0x60, 0x6E, 0x60, 0x6A, 0x5F, 0x6D, 0x61, 0x6C, 0x61, 0x6C, 0x60, 0x6C, 0x5E, 0x6A, 0x5D, 0x6D, 0x5F, 0x6E, 0x60, 0x6B, 0x5F, 0x6E, 0x60, 0x6E, 0x60, 0x6C, 0x61, 0x6A, 0x5F, 0x6C, 0x5F, 0x6A, 0x5E, 0x6B, 0x5F, 0x6B, 0x5E, 0x6C, 0x60, 0x6E, 0x61, 0x6A, 0x5E, 0x6A, 0x5C, 0x6C, 0x60, 0x6F, 0x63, 0x6C, 0x61, 0x6C, 0x60, 0x6A, 0x5F, 0x6D, 0x61, 0x6E, 0x5F, 0x6B, 0x5F, 0x6C, 0x60, 0x6B, 0x5F, 0x69, 0x5D, 0x68, 0x5D, 0x6D, 0x61, 0x6F, 0x63, 0x6C, 0x5F, 0x6E, 0x61, 0x6A, 0x5D, 0x6B, 0x5F, 0x6A, 0x5E, 0x6A, 0x5E, 0x6E, 0x62, 0x6C, 0x5D, 0x6B, 0x5D, 0x69, 0x5C, 0x68, 0x5C, 0x69, 0x5F, 0x6A, 0x5E, 0x69, 0x5D, 0x6B, 0x60, 0x6B, 0x5F, 0x69, 0x5C, 0x69, 0x5B, 0x69, 0x5C, 0x68, 0x5B, 0x67, 0x59, 0x64, 0x5A, 0x65, 0x5A, 0x67, 0x5C, 0x68, 0x5B, 0x67, 0x5B, 0x67, 0x5A, 0x66, 0x5A, 0x65, 0x58, 0x66, 0x5C, 0x6A, 0x5E, 0x68, 0x5B, 0x68, 0x5C, 0x68, 0x5A, 0x67, 0x5C, 0x66, 0x5C, 0x65, 0x57, 0x64, 0x59, 0x62, 0x58, 0x66, 0x59, 0x65, 0x59, 0x62, 0x59, 0x66, 0x5B, 0x65, 0x59, 0x67, 0x5C, 0x67, 0x5B, 0x67, 0x5A, 0x62, 0x59, 0x63, 0x59, 0x63, 0x59, 0x65, 0x5A, 0x6A, 0x5F, 0x67, 0x5C, 0x67, 0x5B, 0x62, 0x58, 0x65, 0x5A, 0x67, 0x5D, 0x69, 0x5E, 0x67, 0x5B, 0x63, 0x59, 0x5F, 0x56, 0x66, 0x5B, 0x67, 0x5A, 0x64, 0x59, 0x63, 0x58, 0x65, 0x59, 0x64, 0x5A, 0x65, 0x5B, 0x64, 0x5A, 0x62, 0x57, 0x62, 0x57, 0x64, 0x59, 0x63, 0x58, 0x62, 0x57, 0x61, 0x57, 0x63, 0x57, 0x63, 0x56, 0x5F, 0x53, 0x5E, 0x55, 0x5B, 0x51, 0x4D, 0x43, 0x31, 0x2D, 0x29, 0x29, 0x29, 0x2B, 0x29, 0x30, 0x2F, 0x32, 0x29, 0x2C, 0x27, 0x29, 0x2C, 0x35, 0x2A, 0x2C, 0x25, 0x29, 0x28, 0x29, 0x2B, 0x31, 0x29, 0x2B, 0x26, 0x29, 0x27, 0x2C, 0x2A, 0x2D, 0x29, 0x30, 0x30, 0x37, 0x2B, 0x2F, 0x30, 0x34, 0x29, 0x2C, 0x31, 0x36, 0x27, 0x2A, 0x2F, 0x33, 0x25, 0x27, 0x2E, 0x34, 0x24, 0x25, 0x26, 0x2A, 0x24, 0x26, 0x28, 0x2B, 0x25, 0x27, 0x23, 0x26, 0x22, 0x22, 0x24, 0x27, 0x24, 0x26, 0x21, 0x26, 0x27, 0x29, 0x21, 0x26, 0x28, 0x2B, 0x27, 0x2C, 0x27, 0x2A, 0x28, 0x2E, 0x2C, 0x30, 0x25, 0x26
    },

    {
        0x40, 0x1B, 0x3A, 0x19, 0x3D, 0x1A, 0x46, 0x1B, 0x46, 0x1A, 0x3F, 0x18, 0x31, 0x16, 0x24, 0x13, 0x1E, 0x12, 0x1B, 0x11, 0x1A, 0x11, 0x18, 0x11, 0x18, 0x10, 0x18, 0x11, 0x17, 0x10, 0x18, 0x11, 0x1A, 0x12, 0x1A, 0x12, 0x1C, 0x13, 0x1D, 0x13, 0x1A, 0x11, 0x16, 0x0F, 0x15, 0x0F, 0x14, 0x0F, 0x15, 0x0F, 0x14, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x10, 0x17, 0x10, 0x17, 0x10, 0x16, 0x10, 0x17, 0x11, 0x17, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x15, 0x10, 0x16, 0x0F, 0x16, 0x0F, 0x16, 0x10, 0x15, 0x0F, 0x15, 0x0F, 0x16, 0x10, 0x15, 0x10, 0x15, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x11, 0x1D, 0x18, 0x3F, 0x34, 0x75, 0x54, 0x8A, 0x60, 0x94, 0x67, 0x9B, 0x6C, 0xA1, 0x6F, 0xA6, 0x73, 0xAB, 0x75, 0xAC, 0x75, 0xAF, 0x77, 0xAF, 0x79, 0xAE, 0x78, 0xAF, 0x78, 0xAD, 0x78, 0xAE, 0x76, 0xAE, 0x77, 0xAE, 0x77, 0xAF, 0x79, 0xAF, 0x77, 0xB0, 0x79, 0xB2, 0x7A, 0xB3, 0x7B, 0xB2, 0x7B, 0xB3, 0x7A, 0xB3, 0x7B, 0xB3, 0x7B, 0xB4, 0x7B, 0xB6, 0x7D, 0xB8, 0x7E, 0xB3, 0x7A, 0xB3, 0x7D, 0xB6, 0x7D, 0xB5, 0x7C, 0xB5, 0x7B, 0xB4, 0x7B, 0xB5, 0x7C, 0xB2, 0x78, 0xA1, 0x6B, 0x7E, 0x50, 0x4E, 0x31, 0x31, 0x21, 0x27, 0x1A, 0x20, 0x16, 0x1D, 0x15, 0x1A, 0x12, 0x18, 0x12, 0x19, 0x11, 0x1A, 0x12, 0x18, 0x11, 0x17, 0x11, 0x17, 0x11, 0x17, 0x11, 0x17, 0x10, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x15, 0x0F, 0x15, 0x0F, 0x16, 0x0F, 0x16, 0x0F, 0x14, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x16, 0x0F, 0x16, 0x10, 0x16, 0x0F, 0x17, 0x10, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x16, 0x10, 0x16, 0x10, 0x17, 0x11, 0x16, 0x10, 0x16, 0x0F, 0x16, 0x10, 0x16, 0x0F, 0x15, 0x0F, 0x16, 0x0F, 0x15, 0x0F, 0x16, 0x10, 0x17, 0x11, 0x19, 0x12, 0x18, 0x11, 0x16, 0x10, 0x16, 0x0F, 0x15, 0x0F, 0x16, 0x0F, 0x17, 0x10, 0x1A, 0x11, 0x2F, 0x1A, 0x4D, 0x1F, 0x58, 0x21, 0x5D, 0x21, 0x4A, 0x1C, 0x31, 0x18, 0x40, 0x1D, 0x55, 0x21, 0x5A, 0x21, 0x60, 0x22, 0x64, 0x23, 0x62, 0x22, 0x64, 0x24, 0x65, 0x24, 0x63, 0x23, 0x61, 0x23, 0x61, 0x23, 0x61, 0x23, 0x64, 0x23, 0x64, 0x23, 0x64, 0x23, 0x63, 0x23, 0x62, 0x24, 0x64, 0x24, 0x61, 0x23, 0x63, 0x24, 0x64, 0x24, 0x62, 0x23, 0x61, 0x23, 0x62, 0x23, 0x64, 0x23, 0x60, 0x23, 0x63, 0x24, 0x5F, 0x23, 0x66, 0x25, 0x66, 0x24, 0x65, 0x24, 0x64, 0x24, 0x62, 0x24, 0x65, 0x24, 0x65, 0x24, 0x63, 0x24, 0x64, 0x25, 0x63, 0x25, 0x60, 0x24, 0x62, 0x23, 0x64, 0x24, 0x62, 0x23, 0x61, 0x23, 0x61, 0x23, 0x61, 0x23, 0x60, 0x22, 0x62, 0x23, 0x63, 0x23, 0x63, 0x24, 0x62, 0x23, 0x60, 0x22, 0x5C, 0x21, 0x60, 0x23, 0x60, 0x23, 0x5E, 0x21, 0x5F, 0x22, 0x5F, 0x21, 0x5D, 0x22, 0x59, 0x20, 0x5E, 0x22, 0x5F, 0x22, 0x5B, 0x22, 0x5D, 0x22, 0x5B, 0x21, 0x5E, 0x21, 0x5D, 0x22, 0x5E, 0x21, 0x5C, 0x21, 0x5D, 0x21, 0x5B, 0x21, 0x5D, 0x21, 0x5E, 0x21, 0x60, 0x22, 0x5D, 0x22, 0x5E, 0x21, 0x5D, 0x22, 0x5E, 0x22, 0x5C, 0x21, 0x5B, 0x21, 0x5D, 0x22, 0x5F, 0x22, 0x60, 0x22, 0x5D, 0x21, 0x5C, 0x22, 0x5E, 0x22, 0x5E, 0x22, 0x5D, 0x22, 0x5B, 0x21, 0x5C, 0x22, 0x5C, 0x22, 0x5E, 0x22, 0x5E, 0x23, 0x5F, 0x22, 0x5D, 0x21, 0x5F, 0x23, 0x5F, 0x23, 0x5F, 0x23, 0x5E, 0x22, 0x5E, 0x22, 0x5B, 0x21, 0x5B, 0x22, 0x5C, 0x22, 0x5C, 0x22, 0x5B, 0x22, 0x5D, 0x21, 0x5B, 0x21, 0x5D, 0x22, 0x5B, 0x25, 0x5D, 0x22, 0x5C, 0x21, 0x5C, 0x21, 0x57, 0x20, 0x59, 0x21, 0x59, 0x20, 0x59, 0x20, 0x59, 0x20, 0x59, 0x21, 0x58, 0x20, 0x57, 0x20, 0x57, 0x21, 0x57, 0x21, 0x49, 0x1D, 0x34, 0x1B, 0x30, 0x19, 0x2F, 0x1B, 0x32, 0x1A, 0x2E, 0x1A, 0x29, 0x18, 0x28, 0x17, 0x32, 0x1B, 0x27, 0x17, 0x29, 0x19, 0x29, 0x18, 0x2D, 0x19, 0x28, 0x17, 0x24, 0x16, 0x2C, 0x1A, 0x27, 0x17, 0x2E, 0x1B, 0x2F, 0x1B, 0x29, 0x19, 0x2F, 0x1A, 0x29, 0x1A, 0x2E, 0x19, 0x25, 0x17, 0x2C, 0x19, 0x24, 0x16, 0x2B, 0x18, 0x25, 0x16, 0x32, 0x1C, 0x2C, 0x19, 0x32, 0x1C, 0x2C, 0x19, 0x28, 0x18, 0x2B, 0x19, 0x30, 0x1C, 0x36, 0x1E, 0x2C, 0x18, 0x2E, 0x1A, 0x30, 0x1A, 0x34, 0x1D, 0x32, 0x1B, 0x2E, 0x1A, 0x2D, 0x19, 0x30, 0x1B, 0x27, 0x17
    },

    {
        0x41, 0x3C, 0x3B, 0x38, 0x40, 0x3F, 0x48, 0x45, 0x46, 0x42, 0x3E, 0x38, 0x2E, 0x2A, 0x20, 0x20, 0x19, 0x1B, 0x17, 0x19, 0x15, 0x19, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x12, 0x16, 0x13, 0x17, 0x14, 0x18, 0x15, 0x18, 0x15, 0x19, 0x16, 0x1B, 0x14, 0x18, 0x11, 0x15, 0x11, 0x14, 0x10, 0x14, 0x10, 0x14, 0x10, 0x14, 0x11, 0x14, 0x10, 0x14, 0x10, 0x14, 0x11, 0x14, 0x11, 0x15, 0x11, 0x16, 0x11, 0x15, 0x11, 0x15, 0x12, 0x16, 0x11, 0x15, 0x11, 0x15, 0x12, 0x15, 0x11, 0x15, 0x11, 0x16, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x14, 0x10, 0x14, 0x11, 0x15, 0x11, 0x15, 0x10, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x14, 0x11, 0x15, 0x16, 0x1C, 0x29, 0x3E, 0x50, 0x70, 0x66, 0x86, 0x70, 0x90, 0x76, 0x96, 0x79, 0x9A, 0x7E, 0xA0, 0x81, 0xA3, 0x83, 0xA4, 0x85, 0xA6, 0x86, 0xA9, 0x85, 0xA8, 0x87, 0xA7, 0x84, 0xA6, 0x84, 0xA5, 0x85, 0xA5, 0x84, 0xA3, 0x85, 0xA7, 0x84, 0xA7, 0x85, 0xA9, 0x88, 0xAA, 0x88, 0xAC, 0x87, 0xAB, 0x88, 0xAB, 0x88, 0xAA, 0x88, 0xAB, 0x88, 0xAB, 0x89, 0xAC, 0x8C, 0xAF, 0x8A, 0xAD, 0x89, 0xAE, 0x8B, 0xAE, 0x89, 0xAC, 0x87, 0xAB, 0x88, 0xAC, 0x87, 0xAB, 0x81, 0xA4, 0x76, 0x8F, 0x5B, 0x67, 0x38, 0x3C, 0x25, 0x2A, 0x1E, 0x23, 0x19, 0x1E, 0x16, 0x1B, 0x15, 0x19, 0x13, 0x17, 0x13, 0x18, 0x14, 0x18, 0x13, 0x17, 0x12, 0x17, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x13, 0x16, 0x13, 0x18, 0x13, 0x17, 0x12, 0x15, 0x11, 0x14, 0x12, 0x15, 0x11, 0x15, 0x11, 0x14, 0x10, 0x14, 0x11, 0x15, 0x10, 0x14, 0x11, 0x14, 0x11, 0x14, 0x11, 0x15, 0x11, 0x14, 0x11, 0x14, 0x11, 0x15, 0x12, 0x15, 0x11, 0x14, 0x11, 0x14, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x12, 0x16, 0x12, 0x16, 0x11, 0x14, 0x12, 0x15, 0x11, 0x14, 0x11, 0x14, 0x11, 0x15, 0x11, 0x14, 0x11, 0x15, 0x13, 0x17, 0x13, 0x19, 0x13, 0x17, 0x12, 0x15, 0x12, 0x14, 0x12, 0x15, 0x13, 0x16, 0x13, 0x16, 0x15, 0x17, 0x24, 0x2A, 0x45, 0x47, 0x58, 0x55, 0x60, 0x59, 0x53, 0x4A, 0x37, 0x31, 0x3D, 0x3C, 0x56, 0x51, 0x5E, 0x58, 0x67, 0x5D, 0x6C, 0x5F, 0x6B, 0x5F, 0x6C, 0x60, 0x6E, 0x61, 0x6C, 0x60, 0x6B, 0x5E, 0x6A, 0x5C, 0x6B, 0x5F, 0x6E, 0x5F, 0x6C, 0x60, 0x6E, 0x60, 0x6B, 0x5F, 0x6C, 0x5E, 0x6D, 0x61, 0x6A, 0x5F, 0x6C, 0x60, 0x6D, 0x60, 0x6B, 0x5E, 0x6A, 0x5F, 0x6B, 0x5F, 0x6D, 0x61, 0x6B, 0x5D, 0x6B, 0x5F, 0x6A, 0x5D, 0x6F, 0x63, 0x6E, 0x61, 0x6E, 0x61, 0x6E, 0x61, 0x6B, 0x61, 0x6E, 0x62, 0x6E, 0x61, 0x6C, 0x61, 0x6F, 0x61, 0x6C, 0x5F, 0x69, 0x5F, 0x6D, 0x61, 0x6B, 0x5F, 0x6C, 0x5D, 0x6C, 0x5E, 0x6A, 0x5C, 0x6C, 0x5F, 0x69, 0x5C, 0x6B, 0x5F, 0x6D, 0x60, 0x6D, 0x60, 0x6D, 0x5F, 0x69, 0x5C, 0x66, 0x5A, 0x6A, 0x5D, 0x69, 0x5C, 0x67, 0x5C, 0x6A, 0x5D, 0x68, 0x5B, 0x66, 0x59, 0x63, 0x57, 0x66, 0x5B, 0x67, 0x5C, 0x66, 0x5A, 0x65, 0x5B, 0x66, 0x59, 0x65, 0x5A, 0x67, 0x5A, 0x68, 0x5A, 0x66, 0x5A, 0x67, 0x5A, 0x64, 0x59, 0x67, 0x5B, 0x67, 0x5B, 0x6A, 0x5C, 0x67, 0x5A, 0x66, 0x59, 0x66, 0x5A, 0x65, 0x5A, 0x66, 0x5A, 0x66, 0x5A, 0x67, 0x5B, 0x66, 0x5B, 0x68, 0x5D, 0x66, 0x5B, 0x66, 0x5A, 0x67, 0x5B, 0x68, 0x5B, 0x66, 0x5B, 0x64, 0x58, 0x65, 0x5A, 0x63, 0x5A, 0x66, 0x5A, 0x67, 0x5C, 0x67, 0x5B, 0x64, 0x5B, 0x68, 0x5E, 0x68, 0x5D, 0x67, 0x5D, 0x65, 0x5A, 0x65, 0x5B, 0x64, 0x57, 0x65, 0x5A, 0x65, 0x5A, 0x64, 0x59, 0x64, 0x58, 0x63, 0x59, 0x64, 0x59, 0x66, 0x5A, 0x65, 0x59, 0x63, 0x59, 0x64, 0x5B, 0x64, 0x59, 0x60, 0x55, 0x63, 0x57, 0x62, 0x57, 0x62, 0x57, 0x62, 0x55, 0x60, 0x54, 0x61, 0x55, 0x60, 0x55, 0x5D, 0x54, 0x5E, 0x54, 0x4C, 0x41, 0x34, 0x34, 0x2B, 0x2A, 0x29, 0x2E, 0x2C, 0x2C, 0x26, 0x2A, 0x25, 0x27, 0x22, 0x25, 0x29, 0x2D, 0x22, 0x24, 0x26, 0x29, 0x22, 0x24, 0x27, 0x29, 0x23, 0x25, 0x20, 0x22, 0x26, 0x2B, 0x21, 0x23, 0x28, 0x2D, 0x28, 0x29, 0x25, 0x28, 0x29, 0x2A, 0x26, 0x2B, 0x27, 0x29, 0x22, 0x25, 0x27, 0x2A, 0x21, 0x25, 0x25, 0x28, 0x24, 0x27, 0x2F, 0x34, 0x29, 0x2E, 0x2B, 0x30, 0x28, 0x2A, 0x26, 0x2B, 0x29, 0x2D, 0x2B, 0x32, 0x30, 0x36, 0x27, 0x28, 0x2C, 0x30, 0x29, 0x2C, 0x2E, 0x33, 0x2A, 0x2C, 0x27, 0x2A, 0x29, 0x2D, 0x29, 0x2C, 0x24, 0x28
    },

    {
        0x3B, 0x1A, 0x3D, 0x1A, 0x47, 0x1B, 0x46, 0x1B, 0x3E, 0x19, 0x32, 0x16, 0x24, 0x13, 0x1D, 0x11, 0x1A, 0x10, 0x1A, 0x10, 0x19, 0x11, 0x18, 0x11, 0x18, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x19, 0x11, 0x17, 0x11, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x16, 0x0F, 0x16, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x16, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x17, 0x11, 0x18, 0x11, 0x17, 0x10, 0x17, 0x11, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x15, 0x0F, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x15, 0x0F, 0x16, 0x10, 0x15, 0x10, 0x15, 0x10, 0x16, 0x0F, 0x15, 0x0F, 0x16, 0x10, 0x17, 0x10, 0x16, 0x10, 0x17, 0x10, 0x18, 0x12, 0x21, 0x1C, 0x46, 0x3A, 0x79, 0x56, 0x8F, 0x63, 0x99, 0x6A, 0x9F, 0x6D, 0xA3, 0x70, 0xA8, 0x73, 0xAC, 0x75, 0xAE, 0x77, 0xB0, 0x78, 0xAF, 0x78, 0xB0, 0x79, 0xAF, 0x78, 0xAD, 0x77, 0xAC, 0x76, 0xAD, 0x78, 0xAF, 0x77, 0xB0, 0x79, 0xAF, 0x78, 0xB1, 0x79, 0xB1, 0x79, 0xB1, 0x7A, 0xB2, 0x7A, 0xB6, 0x7B, 0xB3, 0x7A, 0xB3, 0x7A, 0xB2, 0x7A, 0xB5, 0x7C, 0xB5, 0x7C, 0xB6, 0x7C, 0xB7, 0x7D, 0xB6, 0x7D, 0xB5, 0x7B, 0xB3, 0x7A, 0xB2, 0x79, 0xA4, 0x6D, 0x85, 0x53, 0x51, 0x33, 0x32, 0x21, 0x28, 0x1B, 0x21, 0x17, 0x1E, 0x15, 0x1B, 0x13, 0x19, 0x12, 0x19, 0x12, 0x19, 0x11, 0x19, 0x12, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x17, 0x11, 0x18, 0x10, 0x18, 0x11, 0x19, 0x12, 0x17, 0x10, 0x16, 0x0F, 0x16, 0x10, 0x16, 0x10, 0x16, 0x0F, 0x16, 0x0F, 0x15, 0x10, 0x15, 0x0F, 0x15, 0x0F, 0x14, 0x0F, 0x15, 0x0F, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x0F, 0x15, 0x0F, 0x16, 0x0F, 0x16, 0x10, 0x16, 0x10, 0x18, 0x11, 0x17, 0x10, 0x16, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0E, 0x15, 0x0F, 0x15, 0x0F, 0x16, 0x10, 0x1A, 0x14, 0x24, 0x1B, 0x21, 0x17, 0x1A, 0x12, 0x17, 0x10, 0x16, 0x0F, 0x17, 0x10, 0x16, 0x0F, 0x16, 0x0F, 0x18, 0x11, 0x28, 0x17, 0x4B, 0x1E, 0x5A, 0x21, 0x5C, 0x20, 0x4D, 0x1D, 0x32, 0x18, 0x3A, 0x1C, 0x55, 0x21, 0x5E, 0x23, 0x63, 0x23, 0x60, 0x22, 0x62, 0x23, 0x64, 0x23, 0x61, 0x22, 0x61, 0x23, 0x61, 0x23, 0x62, 0x23, 0x65, 0x23, 0x64, 0x24, 0x63, 0x23, 0x65, 0x24, 0x63, 0x23, 0x63, 0x25, 0x67, 0x27, 0x67, 0x26, 0x64, 0x24, 0x63, 0x24, 0x64, 0x24, 0x63, 0x23, 0x61, 0x23, 0x60, 0x22, 0x5F, 0x22, 0x62, 0x23, 0x66, 0x24, 0x63, 0x23, 0x65, 0x25, 0x65, 0x24, 0x66, 0x26, 0x63, 0x24, 0x64, 0x24, 0x62, 0x23, 0x63, 0x24, 0x65, 0x25, 0x63, 0x24, 0x65, 0x24, 0x61, 0x22, 0x5F, 0x23, 0x5F, 0x22, 0x5E, 0x21, 0x60, 0x22, 0x61, 0x22, 0x62, 0x23, 0x63, 0x23, 0x62, 0x23, 0x62, 0x23, 0x63, 0x23, 0x61, 0x23, 0x5F, 0x22, 0x60, 0x22, 0x62, 0x23, 0x61, 0x22, 0x60, 0x22, 0x5C, 0x21, 0x5E, 0x22, 0x5E, 0x22, 0x5F, 0x22, 0x5C, 0x22, 0x5B, 0x21, 0x5D, 0x21, 0x5C, 0x21, 0x5B, 0x20, 0x5C, 0x21, 0x5F, 0x22, 0x5D, 0x20, 0x5B, 0x21, 0x5C, 0x21, 0x5C, 0x21, 0x5D, 0x21, 0x5E, 0x21, 0x59, 0x20, 0x5C, 0x21, 0x5F, 0x22, 0x5E, 0x21, 0x5D, 0x21, 0x5E, 0x21, 0x5F, 0x22, 0x5C, 0x21, 0x5E, 0x22, 0x60, 0x23, 0x60, 0x22, 0x61, 0x22, 0x5E, 0x22, 0x5B, 0x22, 0x5C, 0x22, 0x5E, 0x22, 0x5C, 0x22, 0x5C, 0x22, 0x5F, 0x23, 0x60, 0x23, 0x5F, 0x23, 0x5F, 0x23, 0x5D, 0x22, 0x59, 0x21, 0x5B, 0x21, 0x5B, 0x22, 0x5C, 0x21, 0x5B, 0x21, 0x5A, 0x21, 0x59, 0x20, 0x58, 0x20, 0x59, 0x20, 0x5A, 0x21, 0x5A, 0x21, 0x5B, 0x21, 0x5C, 0x20, 0x5A, 0x20, 0x58, 0x20, 0x59, 0x21, 0x5A, 0x21, 0x56, 0x1F, 0x57, 0x1E, 0x56, 0x20, 0x5A, 0x20, 0x57, 0x20, 0x55, 0x20, 0x56, 0x20, 0x48, 0x1D, 0x33, 0x19, 0x29, 0x17, 0x2A, 0x19, 0x2E, 0x1A, 0x25, 0x16, 0x2A, 0x19, 0x27, 0x18, 0x29, 0x18, 0x2A, 0x18, 0x29, 0x18, 0x2B, 0x18, 0x29, 0x18, 0x2C, 0x19, 0x29, 0x17, 0x2B, 0x19, 0x29, 0x19, 0x31, 0x1B, 0x2E, 0x1B, 0x2C, 0x1A, 0x30, 0x1B, 0x33, 0x1C, 0x30, 0x1B, 0x2E, 0x19, 0x30, 0x1B, 0x30, 0x1B, 0x35, 0x1D, 0x30, 0x1B, 0x36, 0x1D, 0x2C, 0x19, 0x32, 0x1B, 0x29, 0x18, 0x30, 0x1C, 0x2B, 0x18, 0x29, 0x18, 0x2C, 0x19, 0x24, 0x16, 0x30, 0x1A, 0x26, 0x16, 0x2F, 0x19, 0x26, 0x16, 0x28, 0x18, 0x2A, 0x1A, 0x33, 0x1B, 0x2B, 0x19
    },

    {
        0x3B, 0x39, 0x40, 0x3F, 0x49, 0x46, 0x47, 0x42, 0x3E, 0x39, 0x2F, 0x2B, 0x20, 0x20, 0x19, 0x1B, 0x16, 0x19, 0x15, 0x19, 0x15, 0x18, 0x14, 0x17, 0x13, 0x17, 0x12, 0x16, 0x12, 0x16, 0x12, 0x17, 0x13, 0x17, 0x13, 0x16, 0x13, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x15, 0x11, 0x15, 0x11, 0x14, 0x11, 0x14, 0x11, 0x15, 0x11, 0x15, 0x11, 0x14, 0x11, 0x15, 0x11, 0x14, 0x11, 0x15, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x15, 0x12, 0x15, 0x11, 0x15, 0x11, 0x15, 0x12, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x14, 0x11, 0x16, 0x11, 0x15, 0x12, 0x16, 0x13, 0x17, 0x18, 0x1F, 0x2C, 0x3F, 0x50, 0x70, 0x68, 0x88, 0x71, 0x92, 0x78, 0x98, 0x7D, 0x9D, 0x81, 0xA2, 0x83, 0xA6, 0x84, 0xA7, 0x85, 0xA7, 0x87, 0xA8, 0x86, 0xA7, 0x86, 0xA8, 0x86, 0xA7, 0x85, 0xA5, 0x84, 0xA8, 0x85, 0xA7, 0x85, 0xA6, 0x86, 0xA9, 0x86, 0xA7, 0x86, 0xA9, 0x86, 0xAA, 0x88, 0xAC, 0x8A, 0xAD, 0x8A, 0xAC, 0x88, 0xAB, 0x88, 0xAB, 0x89, 0xAC, 0x8A, 0xAC, 0x89, 0xAD, 0x8A, 0xAD, 0x8B, 0xAF, 0x88, 0xAD, 0x89, 0xAE, 0x83, 0xA8, 0x77, 0x94, 0x5F, 0x6D, 0x3B, 0x3F, 0x26, 0x2B, 0x1E, 0x23, 0x1A, 0x1E, 0x17, 0x1C, 0x15, 0x19, 0x14, 0x18, 0x13, 0x18, 0x14, 0x19, 0x13, 0x18, 0x13, 0x18, 0x13, 0x17, 0x13, 0x17, 0x13, 0x16, 0x12, 0x17, 0x12, 0x18, 0x14, 0x19, 0x13, 0x17, 0x12, 0x16, 0x12, 0x15, 0x12, 0x16, 0x11, 0x14, 0x11, 0x15, 0x11, 0x15, 0x11, 0x14, 0x11, 0x14, 0x11, 0x13, 0x11, 0x14, 0x12, 0x16, 0x12, 0x16, 0x12, 0x15, 0x11, 0x15, 0x12, 0x15, 0x12, 0x15, 0x11, 0x15, 0x12, 0x15, 0x12, 0x16, 0x11, 0x15, 0x12, 0x16, 0x12, 0x16, 0x11, 0x15, 0x11, 0x14, 0x12, 0x14, 0x11, 0x14, 0x11, 0x14, 0x11, 0x14, 0x12, 0x16, 0x14, 0x1B, 0x18, 0x27, 0x18, 0x21, 0x14, 0x18, 0x12, 0x16, 0x12, 0x16, 0x12, 0x15, 0x12, 0x15, 0x13, 0x15, 0x14, 0x17, 0x20, 0x24, 0x43, 0x46, 0x59, 0x56, 0x5F, 0x59, 0x56, 0x4D, 0x39, 0x31, 0x39, 0x37, 0x55, 0x52, 0x62, 0x5A, 0x67, 0x5D, 0x6B, 0x5E, 0x6C, 0x5F, 0x6C, 0x61, 0x6A, 0x5D, 0x6C, 0x5F, 0x6B, 0x5C, 0x6B, 0x5E, 0x70, 0x61, 0x6E, 0x62, 0x6D, 0x60, 0x6D, 0x60, 0x6D, 0x60, 0x6C, 0x60, 0x70, 0x65, 0x70, 0x65, 0x6D, 0x61, 0x6D, 0x61, 0x6D, 0x61, 0x6C, 0x60, 0x6B, 0x5E, 0x69, 0x5D, 0x69, 0x5B, 0x6C, 0x5F, 0x6E, 0x62, 0x6E, 0x61, 0x6E, 0x61, 0x6D, 0x60, 0x6E, 0x63, 0x6E, 0x60, 0x6D, 0x61, 0x6B, 0x5F, 0x6E, 0x62, 0x6E, 0x62, 0x6C, 0x61, 0x6E, 0x61, 0x6A, 0x5D, 0x69, 0x5C, 0x69, 0x5C, 0x68, 0x5C, 0x69, 0x5D, 0x6B, 0x5E, 0x6C, 0x5E, 0x6B, 0x5F, 0x69, 0x5E, 0x6C, 0x60, 0x6B, 0x5F, 0x6A, 0x5D, 0x68, 0x5B, 0x6A, 0x5E, 0x6B, 0x5D, 0x6B, 0x5E, 0x68, 0x5D, 0x65, 0x5B, 0x68, 0x5B, 0x67, 0x5B, 0x66, 0x5A, 0x63, 0x59, 0x62, 0x57, 0x65, 0x5A, 0x64, 0x59, 0x65, 0x58, 0x65, 0x59, 0x66, 0x5C, 0x65, 0x58, 0x63, 0x56, 0x67, 0x5A, 0x66, 0x59, 0x68, 0x5B, 0x67, 0x5C, 0x65, 0x58, 0x65, 0x5A, 0x66, 0x5C, 0x66, 0x5A, 0x66, 0x58, 0x68, 0x5B, 0x68, 0x5A, 0x66, 0x5A, 0x68, 0x5C, 0x68, 0x5D, 0x6B, 0x5D, 0x6B, 0x5F, 0x67, 0x5B, 0x65, 0x5A, 0x68, 0x5B, 0x68, 0x5D, 0x64, 0x5A, 0x65, 0x5A, 0x67, 0x5C, 0x65, 0x5E, 0x68, 0x5C, 0x66, 0x5C, 0x65, 0x59, 0x64, 0x59, 0x62, 0x57, 0x64, 0x59, 0x65, 0x59, 0x65, 0x59, 0x63, 0x58, 0x62, 0x55, 0x62, 0x56, 0x62, 0x56, 0x63, 0x57, 0x65, 0x58, 0x63, 0x58, 0x64, 0x58, 0x61, 0x55, 0x61, 0x55, 0x63, 0x58, 0x63, 0x57, 0x5F, 0x54, 0x61, 0x54, 0x60, 0x55, 0x62, 0x56, 0x5F, 0x53, 0x5E, 0x53, 0x5C, 0x53, 0x4B, 0x41, 0x31, 0x2E, 0x27, 0x27, 0x27, 0x2A, 0x29, 0x2C, 0x21, 0x23, 0x27, 0x2A, 0x26, 0x2A, 0x25, 0x29, 0x27, 0x29, 0x26, 0x29, 0x29, 0x2C, 0x27, 0x2A, 0x29, 0x2E, 0x24, 0x25, 0x28, 0x2B, 0x27, 0x2D, 0x2B, 0x2E, 0x2A, 0x31, 0x29, 0x2D, 0x2D, 0x30, 0x2D, 0x33, 0x2A, 0x30, 0x28, 0x2B, 0x2C, 0x32, 0x2A, 0x2E, 0x30, 0x37, 0x29, 0x2B, 0x2E, 0x35, 0x26, 0x29, 0x2B, 0x2F, 0x23, 0x27, 0x2A, 0x30, 0x24, 0x26, 0x26, 0x29, 0x26, 0x27, 0x21, 0x25, 0x28, 0x2B, 0x23, 0x26, 0x28, 0x2B, 0x23, 0x26, 0x25, 0x2A, 0x25, 0x2C, 0x2C, 0x30, 0x26, 0x2B
    },

    {
        0x3D, 0x1B, 0x46, 0x1C, 0x49, 0x1C, 0x41, 0x1A, 0x34, 0x16, 0x26, 0x13, 0x1E, 0x11, 0x1C, 0x11, 0x19, 0x11, 0x18, 0x10, 0x18, 0x11, 0x17, 0x10, 0x17, 0x10, 0x17, 0x0F, 0x16, 0x10, 0x17, 0x10, 0x17, 0x10, 0x16, 0x10, 0x17, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x10, 0x16, 0x10, 0x15, 0x10, 0x16, 0x0F, 0x16, 0x10, 0x17, 0x11, 0x18, 0x11, 0x17, 0x10, 0x17, 0x11, 0x17, 0x10, 0x17, 0x11, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x17, 0x10, 0x16, 0x10, 0x16, 0x10, 0x15, 0x10, 0x16, 0x10, 0x17, 0x10, 0x16, 0x10, 0x15, 0x10, 0x16, 0x10, 0x17, 0x11, 0x17, 0x11, 0x17, 0x11, 0x18, 0x11, 0x19, 0x13, 0x22, 0x1C, 0x43, 0x38, 0x77, 0x56, 0x91, 0x64, 0x9A, 0x69, 0x9F, 0x6D, 0xA5, 0x71, 0xAA, 0x74, 0xAD, 0x77, 0xB0, 0x78, 0xAE, 0x78, 0xB0, 0x79, 0xAF, 0x78, 0xAE, 0x78, 0xAE, 0x76, 0xAD, 0x77, 0xAF, 0x78, 0xB0, 0x79, 0xB1, 0x79, 0xB1, 0x79, 0xAF, 0x79, 0xB2, 0x7A, 0xB1, 0x7A, 0xB3, 0x7B, 0xB3, 0x7C, 0xB3, 0x79, 0xB2, 0x7A, 0xB5, 0x7C, 0xB5, 0x7D, 0xB6, 0x7E, 0xB4, 0x7C, 0xB4, 0x7D, 0xB4, 0x7C, 0xB2, 0x79, 0xA8, 0x6E, 0x89, 0x55, 0x55, 0x35, 0x34, 0x22, 0x29, 0x1C, 0x23, 0x18, 0x1E, 0x15, 0x1B, 0x13, 0x19, 0x12, 0x19, 0x12, 0x1B, 0x14, 0x20, 0x18, 0x20, 0x17, 0x1C, 0x14, 0x1A, 0x13, 0x19, 0x12, 0x18, 0x11, 0x17, 0x11, 0x17, 0x11, 0x17, 0x11, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x15, 0x10, 0x16, 0x0F, 0x15, 0x0F, 0x16, 0x10, 0x15, 0x0F, 0x15, 0x0F, 0x17, 0x11, 0x19, 0x11, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x0F, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x17, 0x10, 0x17, 0x10, 0x16, 0x10, 0x16, 0x10, 0x15, 0x0F, 0x15, 0x0F, 0x16, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x1A, 0x14, 0x24, 0x1C, 0x2D, 0x22, 0x2E, 0x21, 0x24, 0x19, 0x1A, 0x13, 0x17, 0x10, 0x17, 0x10, 0x16, 0x10, 0x16, 0x0F, 0x17, 0x10, 0x18, 0x11, 0x27, 0x16, 0x47, 0x1D, 0x59, 0x21, 0x5C, 0x21, 0x51, 0x1E, 0x33, 0x18, 0x3C, 0x1C, 0x55, 0x21, 0x5E, 0x22, 0x63, 0x23, 0x63, 0x22, 0x61, 0x22, 0x60, 0x22, 0x60, 0x22, 0x5F, 0x21, 0x62, 0x22, 0x64, 0x24, 0x63, 0x23, 0x63, 0x23, 0x64, 0x24, 0x66, 0x24, 0x67, 0x26, 0x68, 0x27, 0x69, 0x27, 0x67, 0x25, 0x66, 0x25, 0x68, 0x25, 0x65, 0x24, 0x63, 0x24, 0x62, 0x23, 0x62, 0x23, 0x65, 0x24, 0x66, 0x25, 0x63, 0x24, 0x64, 0x24, 0x60, 0x23, 0x64, 0x25, 0x66, 0x25, 0x64, 0x25, 0x64, 0x24, 0x64, 0x24, 0x64, 0x24, 0x63, 0x23, 0x61, 0x23, 0x66, 0x24, 0x5F, 0x22, 0x5D, 0x21, 0x5D, 0x21, 0x5D, 0x21, 0x62, 0x22, 0x61, 0x22, 0x60, 0x22, 0x5F, 0x22, 0x63, 0x23, 0x64, 0x24, 0x61, 0x23, 0x61, 0x22, 0x62, 0x23, 0x63, 0x23, 0x62, 0x23, 0x61, 0x23, 0x60, 0x23, 0x5E, 0x22, 0x5E, 0x23, 0x5E, 0x22, 0x5E, 0x22, 0x5C, 0x21, 0x5C, 0x21, 0x5B, 0x21, 0x5B, 0x21, 0x5F, 0x23, 0x5B, 0x21, 0x5A, 0x20, 0x59, 0x20, 0x5B, 0x20, 0x5B, 0x21, 0x5E, 0x21, 0x5A, 0x20, 0x5D, 0x21, 0x5B, 0x21, 0x5B, 0x22, 0x5E, 0x22, 0x5C, 0x21, 0x5C, 0x22, 0x5F, 0x23, 0x5F, 0x22, 0x62, 0x23, 0x61, 0x23, 0x61, 0x23, 0x60, 0x23, 0x5D, 0x22, 0x60, 0x23, 0x61, 0x24, 0x5E, 0x23, 0x5F, 0x23, 0x60, 0x23, 0x5F, 0x22, 0x5C, 0x22, 0x5E, 0x22, 0x5D, 0x22, 0x5E, 0x23, 0x5E, 0x23, 0x5C, 0x22, 0x5E, 0x23, 0x5D, 0x21, 0x5D, 0x22, 0x5C, 0x21, 0x5B, 0x21, 0x59, 0x21, 0x5B, 0x21, 0x5C, 0x21, 0x5A, 0x21, 0x5C, 0x22, 0x5B, 0x21, 0x58, 0x20, 0x58, 0x21, 0x5C, 0x22, 0x5B, 0x21, 0x58, 0x20, 0x56, 0x20, 0x58, 0x20, 0x55, 0x20, 0x58, 0x21, 0x55, 0x20, 0x54, 0x1F, 0x47, 0x1C, 0x34, 0x1B, 0x28, 0x18, 0x2A, 0x18, 0x2B, 0x18, 0x27, 0x16, 0x2E, 0x1B, 0x32, 0x1B, 0x32, 0x1C, 0x2F, 0x19, 0x2F, 0x1B, 0x2C, 0x19, 0x31, 0x1C, 0x30, 0x1B, 0x28, 0x18, 0x2D, 0x1A, 0x2F, 0x1A, 0x2B, 0x1A, 0x38, 0x1E, 0x2C, 0x1B, 0x35, 0x1C, 0x2A, 0x19, 0x2D, 0x1A, 0x29, 0x18, 0x30, 0x1A, 0x25, 0x17, 0x30, 0x1A, 0x27, 0x18, 0x30, 0x1B, 0x28, 0x18, 0x2B, 0x1A, 0x29, 0x1A, 0x2F, 0x1C, 0x29, 0x19, 0x2F, 0x1C, 0x2D, 0x1A, 0x2C, 0x1A, 0x32, 0x1B, 0x2C, 0x1B, 0x39, 0x21, 0x3E, 0x25, 0x37, 0x21, 0x39, 0x25, 0x35, 0x21, 0x33, 0x21
    },

    {
        0x3F, 0x3F, 0x49, 0x47, 0x4B, 0x47, 0x42, 0x3B, 0x31, 0x2C, 0x21, 0x20, 0x1A, 0x1B, 0x17, 0x19, 0x15, 0x18, 0x13, 0x17, 0x13, 0x17, 0x12, 0x16, 0x13, 0x16, 0x12, 0x15, 0x11, 0x15, 0x12, 0x16, 0x13, 0x16, 0x12, 0x15, 0x12, 0x16, 0x11, 0x15, 0x12, 0x15, 0x11, 0x15, 0x11, 0x14, 0x11, 0x14, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x16, 0x11, 0x15, 0x12, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x12, 0x17, 0x11, 0x16, 0x12, 0x16, 0x13, 0x16, 0x14, 0x17, 0x19, 0x1E, 0x2A, 0x3B, 0x4E, 0x6E, 0x69, 0x8A, 0x72, 0x92, 0x77, 0x97, 0x7C, 0x9D, 0x80, 0xA1, 0x83, 0xA7, 0x86, 0xA8, 0x86, 0xA8, 0x87, 0xA8, 0x87, 0xA7, 0x85, 0xA6, 0x84, 0xA5, 0x84, 0xA6, 0x84, 0xA6, 0x85, 0xA7, 0x86, 0xAA, 0x86, 0xA8, 0x85, 0xA8, 0x87, 0xAB, 0x86, 0xAA, 0x88, 0xAB, 0x88, 0xAC, 0x88, 0xAA, 0x87, 0xAA, 0x88, 0xAC, 0x8A, 0xB0, 0x8A, 0xAF, 0x8A, 0xAE, 0x89, 0xAC, 0x86, 0xAB, 0x82, 0xA5, 0x77, 0x96, 0x61, 0x70, 0x3D, 0x41, 0x27, 0x2C, 0x1F, 0x24, 0x1A, 0x1F, 0x17, 0x1C, 0x15, 0x19, 0x14, 0x18, 0x14, 0x19, 0x15, 0x1B, 0x19, 0x24, 0x19, 0x22, 0x16, 0x1C, 0x14, 0x1A, 0x14, 0x19, 0x13, 0x17, 0x12, 0x17, 0x12, 0x16, 0x12, 0x16, 0x12, 0x15, 0x12, 0x16, 0x12, 0x15, 0x12, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x14, 0x11, 0x15, 0x11, 0x14, 0x11, 0x15, 0x12, 0x16, 0x13, 0x17, 0x12, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x12, 0x15, 0x12, 0x16, 0x11, 0x16, 0x12, 0x16, 0x12, 0x15, 0x11, 0x14, 0x11, 0x14, 0x12, 0x14, 0x11, 0x14, 0x11, 0x15, 0x12, 0x15, 0x13, 0x1B, 0x18, 0x26, 0x1B, 0x2C, 0x1B, 0x2C, 0x18, 0x23, 0x17, 0x1A, 0x13, 0x17, 0x13, 0x15, 0x12, 0x14, 0x12, 0x14, 0x13, 0x16, 0x14, 0x16, 0x1E, 0x22, 0x3F, 0x42, 0x58, 0x55, 0x62, 0x5B, 0x59, 0x50, 0x3C, 0x33, 0x3A, 0x39, 0x55, 0x51, 0x60, 0x59, 0x6A, 0x60, 0x6A, 0x5F, 0x69, 0x5D, 0x69, 0x5E, 0x69, 0x5D, 0x6B, 0x5D, 0x6E, 0x5F, 0x6F, 0x60, 0x6D, 0x5F, 0x6D, 0x61, 0x6E, 0x61, 0x6F, 0x63, 0x71, 0x65, 0x71, 0x65, 0x70, 0x65, 0x70, 0x63, 0x6F, 0x63, 0x70, 0x64, 0x6E, 0x61, 0x6C, 0x5F, 0x6C, 0x5F, 0x6C, 0x60, 0x6E, 0x61, 0x6F, 0x63, 0x6D, 0x60, 0x6E, 0x61, 0x6A, 0x5E, 0x6E, 0x63, 0x70, 0x64, 0x6E, 0x62, 0x6D, 0x61, 0x6D, 0x60, 0x6F, 0x60, 0x6C, 0x5F, 0x6A, 0x5E, 0x6F, 0x63, 0x6B, 0x5E, 0x69, 0x5B, 0x68, 0x5B, 0x68, 0x5B, 0x6C, 0x5D, 0x69, 0x5F, 0x69, 0x5C, 0x68, 0x5B, 0x6C, 0x5F, 0x6C, 0x60, 0x6A, 0x5E, 0x6A, 0x5E, 0x6B, 0x5E, 0x6D, 0x5F, 0x6D, 0x60, 0x6A, 0x5E, 0x67, 0x5D, 0x66, 0x5A, 0x67, 0x5C, 0x66, 0x5B, 0x67, 0x5C, 0x65, 0x5A, 0x64, 0x58, 0x62, 0x58, 0x64, 0x58, 0x65, 0x5A, 0x63, 0x57, 0x64, 0x57, 0x64, 0x59, 0x66, 0x58, 0x66, 0x59, 0x67, 0x5A, 0x64, 0x58, 0x66, 0x59, 0x65, 0x58, 0x64, 0x5A, 0x67, 0x5B, 0x64, 0x58, 0x67, 0x5A, 0x67, 0x5C, 0x68, 0x5C, 0x6B, 0x5E, 0x68, 0x5D, 0x6A, 0x5E, 0x6B, 0x5D, 0x67, 0x5C, 0x68, 0x5D, 0x6A, 0x5E, 0x67, 0x5D, 0x68, 0x5D, 0x6B, 0x5E, 0x68, 0x5B, 0x64, 0x5A, 0x68, 0x5C, 0x66, 0x5A, 0x68, 0x5E, 0x68, 0x5B, 0x63, 0x5A, 0x68, 0x5B, 0x66, 0x5A, 0x67, 0x5A, 0x67, 0x59, 0x65, 0x59, 0x63, 0x58, 0x64, 0x59, 0x65, 0x5A, 0x63, 0x56, 0x66, 0x5A, 0x66, 0x59, 0x62, 0x55, 0x62, 0x57, 0x66, 0x5A, 0x64, 0x58, 0x5F, 0x54, 0x60, 0x54, 0x62, 0x55, 0x5D, 0x54, 0x5F, 0x55, 0x5E, 0x52, 0x5C, 0x52, 0x4B, 0x41, 0x32, 0x30, 0x27, 0x28, 0x28, 0x29, 0x26, 0x29, 0x24, 0x24, 0x2A, 0x30, 0x29, 0x2C, 0x2A, 0x30, 0x28, 0x29, 0x29, 0x2F, 0x25, 0x27, 0x2B, 0x32, 0x29, 0x2B, 0x23, 0x26, 0x2A, 0x2E, 0x26, 0x28, 0x27, 0x2D, 0x2E, 0x32, 0x26, 0x2C, 0x2B, 0x2E, 0x22, 0x26, 0x27, 0x2C, 0x23, 0x27, 0x28, 0x2B, 0x20, 0x24, 0x2A, 0x2D, 0x22, 0x25, 0x2A, 0x2E, 0x22, 0x27, 0x24, 0x2A, 0x23, 0x2C, 0x28, 0x2F, 0x22, 0x2B, 0x28, 0x31, 0x27, 0x2F, 0x2A, 0x30, 0x2D, 0x32, 0x27, 0x2F, 0x2F, 0x3D, 0x34, 0x44, 0x2A, 0x39, 0x2D, 0x43, 0x28, 0x3B, 0x27, 0x3B
    },

    {
        0x45, 0x1C, 0x48, 0x1C, 0x43, 0x1B, 0x37, 0x17, 0x26, 0x13, 0x1E, 0x11, 0x1A, 0x10, 0x19, 0x10, 0x18, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x16, 0x0F, 0x16, 0x0F, 0x16, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x15, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x11, 0x18, 0x12, 0x18, 0x11, 0x17, 0x11, 0x17, 0x10, 0x16, 0x11, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x11, 0x17, 0x11, 0x17, 0x11, 0x18, 0x12, 0x18, 0x12, 0x18, 0x12, 0x18, 0x12, 0x17, 0x11, 0x18, 0x11, 0x1A, 0x14, 0x22, 0x1C, 0x3F, 0x34, 0x75, 0x54, 0x90, 0x63, 0x9B, 0x6A, 0xA1, 0x6F, 0xA5, 0x71, 0xA9, 0x74, 0xAC, 0x77, 0xAF, 0x77, 0xB0, 0x79, 0xB0, 0x78, 0xAF, 0x78, 0xAF, 0x77, 0xAE, 0x78, 0xB0, 0x78, 0xB0, 0x78, 0xB2, 0x79, 0xB1, 0x78, 0xB0, 0x78, 0xB0, 0x79, 0xB1, 0x7A, 0xB2, 0x7B, 0xB3, 0x7B, 0xB4, 0x7C, 0xB3, 0x7A, 0xB4, 0x7D, 0xB7, 0x7D, 0xB8, 0x7E, 0xB7, 0x7D, 0xB5, 0x7C, 0xB1, 0x7A, 0xA8, 0x6F, 0x8B, 0x58, 0x59, 0x37, 0x35, 0x23, 0x28, 0x1C, 0x23, 0x18, 0x1F, 0x16, 0x1B, 0x14, 0x1A, 0x13, 0x19, 0x12, 0x1A, 0x14, 0x25, 0x20, 0x46, 0x37, 0x4D, 0x33, 0x2D, 0x1F, 0x21, 0x17, 0x1E, 0x16, 0x1B, 0x13, 0x19, 0x12, 0x19, 0x11, 0x17, 0x11, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x17, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x15, 0x10, 0x16, 0x10, 0x16, 0x10, 0x15, 0x0F, 0x16, 0x0F, 0x16, 0x0F, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x15, 0x0F, 0x16, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x16, 0x10, 0x15, 0x0F, 0x15, 0x10, 0x16, 0x10, 0x16, 0x10, 0x19, 0x13, 0x22, 0x1B, 0x2C, 0x21, 0x2F, 0x22, 0x32, 0x26, 0x2F, 0x21, 0x26, 0x1A, 0x1C, 0x14, 0x19, 0x12, 0x17, 0x10, 0x16, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x23, 0x15, 0x45, 0x1D, 0x57, 0x21, 0x5A, 0x23, 0x51, 0x1E, 0x34, 0x18, 0x38, 0x1B, 0x53, 0x20, 0x5C, 0x21, 0x62, 0x23, 0x61, 0x23, 0x62, 0x23, 0x61, 0x22, 0x62, 0x23, 0x61, 0x23, 0x61, 0x22, 0x64, 0x23, 0x66, 0x24, 0x65, 0x24, 0x67, 0x25, 0x69, 0x27, 0x68, 0x26, 0x66, 0x25, 0x66, 0x25, 0x68, 0x26, 0x65, 0x24, 0x66, 0x25, 0x67, 0x24, 0x65, 0x24, 0x65, 0x25, 0x66, 0x24, 0x64, 0x24, 0x65, 0x24, 0x66, 0x23, 0x63, 0x23, 0x63, 0x24, 0x63, 0x23, 0x65, 0x25, 0x65, 0x24, 0x62, 0x24, 0x62, 0x23, 0x60, 0x22, 0x61, 0x24, 0x64, 0x24, 0x61, 0x23, 0x60, 0x22, 0x5F, 0x22, 0x60, 0x22, 0x62, 0x23, 0x61, 0x22, 0x5F, 0x22, 0x5F, 0x23, 0x5F, 0x22, 0x61, 0x23, 0x60, 0x23, 0x61, 0x23, 0x5F, 0x23, 0x61, 0x23, 0x62, 0x22, 0x60, 0x23, 0x60, 0x23, 0x61, 0x24, 0x5D, 0x22, 0x60, 0x22, 0x60, 0x22, 0x5F, 0x22, 0x5C, 0x22, 0x5A, 0x21, 0x59, 0x20, 0x58, 0x20, 0x58, 0x20, 0x5C, 0x20, 0x59, 0x21, 0x5D, 0x21, 0x5B, 0x20, 0x5D, 0x21, 0x5C, 0x21, 0x5D, 0x21, 0x60, 0x24, 0x61, 0x23, 0x5E, 0x22, 0x5C, 0x21, 0x5C, 0x22, 0x5D, 0x22, 0x5D, 0x22, 0x5D, 0x22, 0x5F, 0x23, 0x5F, 0x23, 0x5F, 0x23, 0x63, 0x25, 0x66, 0x26, 0x65, 0x26, 0x63, 0x24, 0x60, 0x24, 0x60, 0x23, 0x5F, 0x22, 0x5D, 0x22, 0x5E, 0x23, 0x5D, 0x22, 0x5D, 0x22, 0x5F, 0x22, 0x5C, 0x22, 0x5C, 0x22, 0x5B, 0x21, 0x5C, 0x21, 0x5A, 0x22, 0x5C, 0x21, 0x5F, 0x22, 0x5D, 0x21, 0x5C, 0x21, 0x5C, 0x22, 0x5C, 0x22, 0x5C, 0x21, 0x5A, 0x21, 0x5B, 0x22, 0x5B, 0x22, 0x59, 0x21, 0x57, 0x20, 0x59, 0x21, 0x5A, 0x21, 0x5A, 0x21, 0x54, 0x1F, 0x53, 0x1F, 0x58, 0x20, 0x49, 0x1E, 0x3B, 0x1C, 0x2A, 0x18, 0x31, 0x1B, 0x2D, 0x19, 0x28, 0x18, 0x2E, 0x1A, 0x23, 0x16, 0x2E, 0x1B, 0x26, 0x18, 0x2E, 0x1B, 0x2A, 0x19, 0x2F, 0x1B, 0x2B, 0x1A, 0x2E, 0x1D, 0x2C, 0x1A, 0x28, 0x18, 0x2C, 0x1B, 0x2E, 0x1C, 0x33, 0x20, 0x34, 0x20, 0x2F, 0x1F, 0x37, 0x22, 0x35, 0x23, 0x38, 0x22, 0x2F, 0x1C, 0x31, 0x1B, 0x2F, 0x1C, 0x39, 0x24, 0x45, 0x2E, 0x53, 0x39, 0x5E, 0x3E, 0x5C, 0x3E, 0x5A, 0x3E, 0x61, 0x42, 0x50, 0x2F, 0x36, 0x1F, 0x34, 0x1D, 0x34, 0x24, 0x68, 0x4B, 0x79, 0x56, 0x7F, 0x5A, 0x87, 0x60, 0x87, 0x62, 0x84, 0x5D
    },

    {
        0x49, 0x46, 0x49, 0x44, 0x43, 0x3D, 0x33, 0x2E, 0x22, 0x22, 0x1A, 0x1B, 0x16, 0x18, 0x14, 0x17, 0x13, 0x17, 0x13, 0x15, 0x13, 0x16, 0x12, 0x16, 0x13, 0x15, 0x12, 0x15, 0x12, 0x15, 0x12, 0x15, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x14, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x16, 0x12, 0x16, 0x12, 0x17, 0x13, 0x17, 0x13, 0x17, 0x12, 0x16, 0x12, 0x16, 0x12, 0x15, 0x12, 0x16, 0x11, 0x15, 0x12, 0x16, 0x11, 0x15, 0x11, 0x14, 0x11, 0x15, 0x11, 0x16, 0x12, 0x16, 0x12, 0x17, 0x12, 0x18, 0x13, 0x19, 0x13, 0x19, 0x13, 0x18, 0x13, 0x17, 0x12, 0x17, 0x13, 0x16, 0x14, 0x18, 0x1A, 0x1F, 0x29, 0x39, 0x4C, 0x69, 0x66, 0x88, 0x72, 0x93, 0x78, 0x99, 0x7C, 0x9E, 0x7F, 0xA3, 0x83, 0xA6, 0x85, 0xA5, 0x87, 0xA8, 0x87, 0xA8, 0x86, 0xA7, 0x85, 0xA7, 0x85, 0xA8, 0x86, 0xA9, 0x86, 0xA8, 0x86, 0xA9, 0x86, 0xA8, 0x86, 0xA6, 0x86, 0xAA, 0x88, 0xA9, 0x88, 0xAC, 0x89, 0xAD, 0x89, 0xAD, 0x8A, 0xAD, 0x8A, 0xAE, 0x8A, 0xAD, 0x8A, 0xAE, 0x8A, 0xB0, 0x88, 0xAC, 0x85, 0xAA, 0x7B, 0x9A, 0x63, 0x74, 0x41, 0x45, 0x28, 0x2C, 0x1F, 0x25, 0x1B, 0x1F, 0x18, 0x1C, 0x15, 0x19, 0x14, 0x18, 0x13, 0x18, 0x15, 0x1B, 0x1B, 0x2D, 0x2B, 0x55, 0x31, 0x56, 0x20, 0x30, 0x19, 0x22, 0x17, 0x1E, 0x16, 0x1B, 0x14, 0x19, 0x14, 0x18, 0x13, 0x17, 0x12, 0x16, 0x12, 0x16, 0x11, 0x16, 0x12, 0x16, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x12, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x14, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x15, 0x12, 0x15, 0x12, 0x16, 0x12, 0x15, 0x11, 0x14, 0x11, 0x15, 0x12, 0x15, 0x11, 0x15, 0x13, 0x1A, 0x17, 0x25, 0x1A, 0x2B, 0x1B, 0x2E, 0x1C, 0x2F, 0x1C, 0x2E, 0x19, 0x24, 0x15, 0x1B, 0x14, 0x19, 0x13, 0x15, 0x12, 0x15, 0x12, 0x15, 0x13, 0x15, 0x13, 0x15, 0x1C, 0x1F, 0x3D, 0x3F, 0x56, 0x52, 0x5D, 0x58, 0x59, 0x51, 0x3D, 0x35, 0x37, 0x36, 0x51, 0x4E, 0x60, 0x58, 0x68, 0x5E, 0x6A, 0x5F, 0x6A, 0x5E, 0x68, 0x5E, 0x6C, 0x5E, 0x6C, 0x5F, 0x6D, 0x60, 0x6F, 0x61, 0x6D, 0x61, 0x6E, 0x61, 0x70, 0x64, 0x70, 0x64, 0x71, 0x63, 0x6F, 0x61, 0x6E, 0x62, 0x6F, 0x64, 0x6F, 0x62, 0x6F, 0x62, 0x70, 0x62, 0x6E, 0x62, 0x70, 0x63, 0x70, 0x62, 0x6E, 0x63, 0x6F, 0x62, 0x70, 0x60, 0x6C, 0x61, 0x6C, 0x5E, 0x6B, 0x5D, 0x6D, 0x61, 0x6F, 0x61, 0x6C, 0x5F, 0x6D, 0x5F, 0x6B, 0x5D, 0x6A, 0x60, 0x6C, 0x5F, 0x6B, 0x5E, 0x6B, 0x5E, 0x6A, 0x5E, 0x6B, 0x5F, 0x6C, 0x5F, 0x6A, 0x5D, 0x68, 0x5C, 0x69, 0x5D, 0x69, 0x5E, 0x6B, 0x5E, 0x6A, 0x5E, 0x6D, 0x5D, 0x69, 0x5C, 0x6C, 0x5E, 0x6B, 0x5F, 0x6B, 0x5D, 0x6A, 0x5E, 0x69, 0x5F, 0x66, 0x5B, 0x67, 0x5B, 0x69, 0x5D, 0x68, 0x5C, 0x67, 0x5A, 0x64, 0x59, 0x61, 0x55, 0x62, 0x56, 0x61, 0x54, 0x64, 0x57, 0x62, 0x58, 0x67, 0x5B, 0x65, 0x58, 0x66, 0x59, 0x65, 0x5A, 0x66, 0x5A, 0x67, 0x5E, 0x68, 0x5D, 0x66, 0x5B, 0x66, 0x5A, 0x67, 0x5A, 0x66, 0x5C, 0x67, 0x5B, 0x67, 0x5B, 0x66, 0x5C, 0x67, 0x5C, 0x67, 0x5C, 0x6A, 0x63, 0x6C, 0x62, 0x6F, 0x63, 0x6A, 0x5E, 0x68, 0x5D, 0x6A, 0x5E, 0x67, 0x5C, 0x65, 0x5A, 0x67, 0x5C, 0x65, 0x5A, 0x65, 0x5B, 0x67, 0x5B, 0x65, 0x5A, 0x64, 0x59, 0x64, 0x58, 0x65, 0x57, 0x63, 0x59, 0x66, 0x5B, 0x69, 0x5C, 0x66, 0x5B, 0x67, 0x5A, 0x66, 0x59, 0x66, 0x59, 0x65, 0x59, 0x63, 0x58, 0x65, 0x59, 0x63, 0x59, 0x61, 0x57, 0x60, 0x55, 0x61, 0x56, 0x62, 0x57, 0x61, 0x56, 0x5E, 0x52, 0x5E, 0x52, 0x5F, 0x55, 0x4D, 0x45, 0x37, 0x34, 0x29, 0x29, 0x2C, 0x2F, 0x27, 0x2A, 0x24, 0x25, 0x27, 0x29, 0x20, 0x24, 0x27, 0x2D, 0x21, 0x28, 0x27, 0x2F, 0x26, 0x2D, 0x27, 0x2F, 0x24, 0x2D, 0x27, 0x31, 0x26, 0x2B, 0x25, 0x29, 0x28, 0x2F, 0x28, 0x33, 0x2A, 0x39, 0x2B, 0x38, 0x26, 0x35, 0x2B, 0x3F, 0x2A, 0x40, 0x2C, 0x3E, 0x27, 0x2F, 0x2C, 0x32, 0x29, 0x30, 0x2E, 0x44, 0x30, 0x53, 0x34, 0x63, 0x38, 0x69, 0x37, 0x69, 0x35, 0x69, 0x37, 0x6E, 0x32, 0x49, 0x28, 0x31, 0x2A, 0x2E, 0x27, 0x3A, 0x38, 0x75, 0x3C, 0x84, 0x3C, 0x89, 0x3F, 0x8C, 0x3E, 0x8E, 0x3D, 0x8A
    },

    {
        0x49, 0x1D, 0x43, 0x1A, 0x37, 0x17, 0x28, 0x14, 0x1F, 0x11, 0x1B, 0x10, 0x19, 0x10, 0x17, 0x0F, 0x17, 0x0F, 0x17, 0x10, 0x17, 0x10, 0x16, 0x0F, 0x16, 0x0F, 0x16, 0x0F, 0x15, 0x0F, 0x16, 0x0F, 0x16, 0x0F, 0x16, 0x10, 0x17, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x0F, 0x16, 0x10, 0x16, 0x0F, 0x16, 0x10, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x16, 0x10, 0x16, 0x10, 0x15, 0x0F, 0x16, 0x10, 0x16, 0x10, 0x17, 0x10, 0x17, 0x11, 0x16, 0x10, 0x17, 0x11, 0x17, 0x11, 0x17, 0x10, 0x16, 0x11, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x18, 0x12, 0x1D, 0x16, 0x21, 0x19, 0x20, 0x17, 0x1E, 0x16, 0x1C, 0x14, 0x1B, 0x13, 0x1A, 0x13, 0x19, 0x12, 0x19, 0x12, 0x1B, 0x14, 0x22, 0x1A, 0x3B, 0x31, 0x6D, 0x52, 0x90, 0x64, 0x9B, 0x6B, 0xA1, 0x6F, 0xA7, 0x71, 0xAB, 0x76, 0xAB, 0x76, 0xAE, 0x77, 0xB1, 0x79, 0xB0, 0x77, 0xAF, 0x77, 0xB0, 0x78, 0xAE, 0x77, 0xAF, 0x77, 0xB0, 0x78, 0xB0, 0x78, 0xAE, 0x78, 0xAF, 0x79, 0xB1, 0x7B, 0xB4, 0x7B, 0xB5, 0x7C, 0xB4, 0x7A, 0xB3, 0x7B, 0xB3, 0x7B, 0xB3, 0x7B, 0xB5, 0x7C, 0xB4, 0x7D, 0xB4, 0x7A, 0xA9, 0x72, 0x90, 0x5A, 0x5D, 0x39, 0x37, 0x24, 0x29, 0x1C, 0x23, 0x18, 0x1F, 0x16, 0x1C, 0x14, 0x19, 0x13, 0x19, 0x12, 0x1A, 0x13, 0x25, 0x20, 0x48, 0x3D, 0x7E, 0x5F, 0x98, 0x67, 0x6B, 0x42, 0x36, 0x24, 0x26, 0x1B, 0x21, 0x17, 0x1B, 0x13, 0x19, 0x12, 0x19, 0x11, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x15, 0x0F, 0x16, 0x0F, 0x16, 0x10, 0x17, 0x10, 0x17, 0x10, 0x15, 0x0F, 0x15, 0x0F, 0x16, 0x0F, 0x16, 0x0F, 0x15, 0x10, 0x15, 0x0F, 0x15, 0x0F, 0x17, 0x10, 0x17, 0x10, 0x16, 0x0F, 0x17, 0x10, 0x16, 0x10, 0x16, 0x0F, 0x16, 0x0F, 0x15, 0x0F, 0x16, 0x0F, 0x19, 0x13, 0x21, 0x1A, 0x2B, 0x20, 0x2E, 0x23, 0x31, 0x24, 0x33, 0x24, 0x31, 0x24, 0x30, 0x22, 0x26, 0x1A, 0x1D, 0x14, 0x18, 0x11, 0x17, 0x0F, 0x16, 0x0F, 0x17, 0x0F, 0x16, 0x0F, 0x17, 0x0F, 0x20, 0x13, 0x40, 0x1C, 0x57, 0x21, 0x5B, 0x21, 0x54, 0x1E, 0x36, 0x19, 0x34, 0x1A, 0x4E, 0x1F, 0x5A, 0x21, 0x5C, 0x22, 0x5F, 0x22, 0x62, 0x23, 0x61, 0x23, 0x62, 0x23, 0x64, 0x23, 0x64, 0x23, 0x65, 0x23, 0x62, 0x24, 0x65, 0x24, 0x66, 0x24, 0x64, 0x24, 0x65, 0x24, 0x66, 0x24, 0x66, 0x24, 0x65, 0x25, 0x65, 0x24, 0x66, 0x25, 0x63, 0x24, 0x66, 0x24, 0x66, 0x24, 0x64, 0x24, 0x66, 0x25, 0x63, 0x23, 0x62, 0x22, 0x62, 0x24, 0x63, 0x24, 0x64, 0x24, 0x65, 0x25, 0x63, 0x23, 0x62, 0x23, 0x5F, 0x22, 0x60, 0x22, 0x5F, 0x22, 0x61, 0x23, 0x60, 0x23, 0x61, 0x22, 0x61, 0x22, 0x62, 0x22, 0x61, 0x22, 0x60, 0x23, 0x64, 0x23, 0x5F, 0x22, 0x63, 0x24, 0x60, 0x23, 0x60, 0x22, 0x5E, 0x22, 0x61, 0x22, 0x62, 0x23, 0x60, 0x22, 0x61, 0x23, 0x61, 0x23, 0x5F, 0x22, 0x5C, 0x22, 0x61, 0x24, 0x62, 0x24, 0x5E, 0x21, 0x5C, 0x21, 0x5C, 0x21, 0x5A, 0x20, 0x59, 0x21, 0x5A, 0x20, 0x58, 0x20, 0x5A, 0x20, 0x5D, 0x21, 0x5B, 0x20, 0x5A, 0x20, 0x5C, 0x21, 0x60, 0x23, 0x60, 0x22, 0x5E, 0x22, 0x5C, 0x21, 0x5F, 0x23, 0x60, 0x23, 0x5E, 0x21, 0x5D, 0x21, 0x5D, 0x22, 0x5F, 0x24, 0x60, 0x23, 0x60, 0x23, 0x60, 0x23, 0x61, 0x23, 0x5E, 0x23, 0x5F, 0x22, 0x62, 0x23, 0x60, 0x22, 0x5E, 0x22, 0x5D, 0x21, 0x5C, 0x21, 0x5E, 0x22, 0x5C, 0x21, 0x5D, 0x22, 0x5B, 0x21, 0x5B, 0x21, 0x5A, 0x21, 0x5A, 0x21, 0x5C, 0x21, 0x5F, 0x22, 0x5A, 0x21, 0x5F, 0x21, 0x5C, 0x21, 0x5A, 0x21, 0x5A, 0x21, 0x5A, 0x20, 0x5A, 0x20, 0x5B, 0x21, 0x58, 0x20, 0x57, 0x20, 0x59, 0x20, 0x57, 0x20, 0x57, 0x21, 0x5B, 0x22, 0x5E, 0x22, 0x5A, 0x21, 0x49, 0x1C, 0x2F, 0x18, 0x29, 0x17, 0x2A, 0x18, 0x23, 0x16, 0x2A, 0x18, 0x2E, 0x1C, 0x35, 0x22, 0x43, 0x2D, 0x4C, 0x31, 0x51, 0x35, 0x50, 0x33, 0x59, 0x3A, 0x58, 0x37, 0x36, 0x1F, 0x2E, 0x1B, 0x2E, 0x1A, 0x38, 0x27, 0x6A, 0x49, 0x70, 0x4E, 0x78, 0x53, 0x75, 0x53, 0x81, 0x59, 0x86, 0x5C, 0x6D, 0x43, 0x33, 0x1F, 0x39, 0x20, 0x29, 0x1B, 0x60, 0x4A, 0x88, 0x60, 0x92, 0x67, 0x96, 0x68, 0x96, 0x68, 0x91, 0x66, 0x90, 0x63, 0x4F, 0x30, 0x2F, 0x1E, 0x2D, 0x1A, 0x3D, 0x2C, 0x7F, 0x5C, 0x94, 0x69, 0x96, 0x6B, 0x98, 0x6E, 0x93, 0x68, 0x93, 0x66
    },

    {
        0x4A, 0x45, 0x43, 0x3E, 0x33, 0x30, 0x23, 0x22, 0x1A, 0x1B, 0x16, 0x19, 0x14, 0x17, 0x13, 0x16, 0x13, 0x16, 0x13, 0x16, 0x13, 0x17, 0x13, 0x16, 0x13, 0x16, 0x12, 0x15, 0x12, 0x15, 0x11, 0x15, 0x11, 0x15, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x15, 0x12, 0x16, 0x12, 0x15, 0x12, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x14, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x11, 0x16, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x12, 0x16, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x13, 0x18, 0x15, 0x21, 0x19, 0x26, 0x18, 0x22, 0x16, 0x1E, 0x15, 0x1C, 0x15, 0x1B, 0x13, 0x19, 0x13, 0x18, 0x13, 0x18, 0x15, 0x19, 0x19, 0x1F, 0x26, 0x34, 0x46, 0x65, 0x66, 0x88, 0x71, 0x94, 0x77, 0x9A, 0x7E, 0x9F, 0x81, 0xA3, 0x84, 0xA7, 0x86, 0xA8, 0x87, 0xA8, 0x86, 0xA8, 0x85, 0xA8, 0x85, 0xA7, 0x84, 0xA6, 0x86, 0xA9, 0x87, 0xA9, 0x87, 0xA7, 0x86, 0xA8, 0x85, 0xA9, 0x87, 0xAA, 0x88, 0xAC, 0x8A, 0xAD, 0x88, 0xAA, 0x88, 0xAC, 0x88, 0xAB, 0x88, 0xAC, 0x88, 0xAD, 0x88, 0xAD, 0x86, 0xA9, 0x7A, 0x9A, 0x65, 0x77, 0x42, 0x49, 0x29, 0x2F, 0x20, 0x26, 0x1B, 0x20, 0x17, 0x1C, 0x15, 0x19, 0x14, 0x18, 0x13, 0x18, 0x14, 0x1B, 0x1B, 0x2D, 0x2C, 0x5A, 0x42, 0x8A, 0x4C, 0x98, 0x3E, 0x6D, 0x25, 0x38, 0x1C, 0x27, 0x19, 0x21, 0x15, 0x1A, 0x14, 0x18, 0x12, 0x17, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x11, 0x15, 0x11, 0x15, 0x11, 0x14, 0x11, 0x15, 0x11, 0x15, 0x12, 0x16, 0x12, 0x16, 0x11, 0x15, 0x11, 0x14, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x14, 0x11, 0x15, 0x12, 0x15, 0x12, 0x15, 0x11, 0x15, 0x12, 0x15, 0x12, 0x15, 0x12, 0x15, 0x12, 0x15, 0x12, 0x15, 0x11, 0x15, 0x13, 0x1A, 0x17, 0x24, 0x1A, 0x2B, 0x1C, 0x2E, 0x1C, 0x30, 0x1D, 0x30, 0x1C, 0x2F, 0x1C, 0x2D, 0x19, 0x25, 0x16, 0x1C, 0x14, 0x17, 0x12, 0x15, 0x12, 0x15, 0x12, 0x15, 0x12, 0x14, 0x13, 0x15, 0x1B, 0x1E, 0x38, 0x3C, 0x53, 0x52, 0x5E, 0x59, 0x5A, 0x52, 0x3E, 0x36, 0x34, 0x30, 0x4E, 0x4B, 0x5F, 0x56, 0x62, 0x58, 0x67, 0x5B, 0x6A, 0x61, 0x6A, 0x5D, 0x6C, 0x61, 0x6C, 0x5F, 0x6F, 0x62, 0x6D, 0x60, 0x6B, 0x5F, 0x6D, 0x61, 0x71, 0x63, 0x6D, 0x60, 0x6F, 0x63, 0x6E, 0x62, 0x70, 0x64, 0x6D, 0x62, 0x6E, 0x63, 0x70, 0x64, 0x6E, 0x62, 0x6F, 0x63, 0x71, 0x63, 0x6E, 0x62, 0x6E, 0x61, 0x6D, 0x60, 0x6C, 0x5F, 0x6B, 0x60, 0x6D, 0x61, 0x6E, 0x62, 0x6F, 0x62, 0x6C, 0x5F, 0x6B, 0x5E, 0x69, 0x5D, 0x6A, 0x5D, 0x6A, 0x5F, 0x6C, 0x5E, 0x6B, 0x5E, 0x6B, 0x5E, 0x6C, 0x5E, 0x6C, 0x5E, 0x6B, 0x5E, 0x6B, 0x5F, 0x6D, 0x61, 0x68, 0x5D, 0x6B, 0x60, 0x6A, 0x5D, 0x69, 0x5B, 0x68, 0x5B, 0x6A, 0x5E, 0x6B, 0x60, 0x6A, 0x5C, 0x68, 0x5F, 0x69, 0x5D, 0x68, 0x5C, 0x66, 0x5A, 0x69, 0x5F, 0x69, 0x5D, 0x66, 0x5A, 0x66, 0x59, 0x65, 0x59, 0x64, 0x57, 0x62, 0x58, 0x63, 0x58, 0x63, 0x57, 0x64, 0x58, 0x65, 0x59, 0x64, 0x59, 0x63, 0x58, 0x64, 0x59, 0x67, 0x5D, 0x68, 0x5C, 0x66, 0x5A, 0x66, 0x5B, 0x6A, 0x5D, 0x67, 0x5C, 0x68, 0x5B, 0x65, 0x5A, 0x66, 0x5A, 0x67, 0x5E, 0x68, 0x5D, 0x6B, 0x5E, 0x67, 0x5B, 0x6A, 0x5F, 0x65, 0x5D, 0x68, 0x5D, 0x6A, 0x5E, 0x66, 0x5C, 0x66, 0x5C, 0x65, 0x59, 0x65, 0x59, 0x67, 0x5B, 0x64, 0x59, 0x64, 0x59, 0x65, 0x5A, 0x65, 0x59, 0x63, 0x57, 0x63, 0x58, 0x65, 0x58, 0x67, 0x5B, 0x66, 0x5A, 0x67, 0x5C, 0x65, 0x58, 0x63, 0x57, 0x64, 0x58, 0x62, 0x56, 0x63, 0x57, 0x62, 0x57, 0x5F, 0x55, 0x5F, 0x54, 0x61, 0x55, 0x60, 0x54, 0x60, 0x57, 0x63, 0x58, 0x65, 0x5B, 0x60, 0x57, 0x4B, 0x41, 0x2C, 0x29, 0x26, 0x27, 0x25, 0x28, 0x24, 0x27, 0x27, 0x2C, 0x29, 0x34, 0x2A, 0x41, 0x30, 0x55, 0x32, 0x58, 0x33, 0x5D, 0x31, 0x58, 0x37, 0x65, 0x35, 0x5A, 0x24, 0x2B, 0x27, 0x2D, 0x26, 0x29, 0x2B, 0x42, 0x39, 0x73, 0x39, 0x7B, 0x3B, 0x81, 0x39, 0x80, 0x3C, 0x88, 0x3D, 0x89, 0x35, 0x5F, 0x23, 0x2E, 0x2D, 0x33, 0x22, 0x28, 0x31, 0x6B, 0x3B, 0x86, 0x3E, 0x8D, 0x3F, 0x90, 0x3E, 0x8F, 0x3D, 0x8C, 0x3C, 0x86, 0x28, 0x3D, 0x22, 0x2D, 0x26, 0x2C, 0x2A, 0x45, 0x39, 0x7C, 0x3F, 0x8B, 0x3F, 0x8D, 0x3E, 0x8F, 0x3C, 0x86, 0x3B, 0x86
    },

    {
        0x44, 0x1A, 0x39, 0x17, 0x29, 0x14, 0x1F, 0x11, 0x1B, 0x10, 0x19, 0x10, 0x17, 0x0F, 0x17, 0x10, 0x18, 0x10, 0x18, 0x10, 0x18, 0x10, 0x17, 0x10, 0x18, 0x10, 0x17, 0x10, 0x16, 0x0F, 0x16, 0x10, 0x15, 0x10, 0x16, 0x10, 0x17, 0x11, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x16, 0x10, 0x16, 0x0F, 0x15, 0x0F, 0x15, 0x10, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x16, 0x10, 0x16, 0x0F, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x17, 0x11, 0x17, 0x10, 0x16, 0x10, 0x17, 0x10, 0x17, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x0F, 0x16, 0x10, 0x16, 0x10, 0x17, 0x10, 0x17, 0x12, 0x1F, 0x18, 0x31, 0x28, 0x4C, 0x37, 0x49, 0x30, 0x2F, 0x20, 0x24, 0x19, 0x20, 0x16, 0x1E, 0x14, 0x1B, 0x14, 0x1A, 0x13, 0x19, 0x13, 0x1C, 0x15, 0x21, 0x1A, 0x34, 0x2C, 0x66, 0x4D, 0x8D, 0x62, 0x9B, 0x6C, 0xA3, 0x70, 0xA8, 0x74, 0xAD, 0x76, 0xAF, 0x77, 0xB0, 0x78, 0xAF, 0x78, 0xAF, 0x79, 0xAF, 0x78, 0xAD, 0x78, 0xAF, 0x77, 0xB0, 0x7A, 0xB1, 0x79, 0xB0, 0x77, 0xAD, 0x78, 0xB0, 0x7A, 0xB3, 0x7D, 0xB4, 0x7C, 0xB5, 0x7C, 0xB1, 0x7B, 0xB1, 0x7A, 0xB0, 0x7A, 0xB2, 0x7A, 0xB2, 0x7A, 0xAD, 0x74, 0x93, 0x5F, 0x61, 0x3C, 0x39, 0x25, 0x2C, 0x1E, 0x25, 0x19, 0x20, 0x16, 0x1D, 0x14, 0x1B, 0x13, 0x19, 0x12, 0x1A, 0x13, 0x23, 0x1D, 0x47, 0x3C, 0x80, 0x62, 0xA4, 0x75, 0xAB, 0x77, 0xA5, 0x71, 0x77, 0x4B, 0x40, 0x29, 0x2A, 0x1C, 0x21, 0x16, 0x1B, 0x13, 0x19, 0x11, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x16, 0x0F, 0x16, 0x10, 0x15, 0x0F, 0x16, 0x0F, 0x16, 0x10, 0x17, 0x10, 0x16, 0x10, 0x16, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x16, 0x10, 0x16, 0x10, 0x17, 0x10, 0x17, 0x10, 0x16, 0x0F, 0x16, 0x10, 0x17, 0x0F, 0x16, 0x0F, 0x19, 0x13, 0x23, 0x1B, 0x2E, 0x22, 0x30, 0x24, 0x30, 0x24, 0x32, 0x25, 0x31, 0x24, 0x32, 0x25, 0x30, 0x23, 0x2F, 0x22, 0x28, 0x1A, 0x1C, 0x13, 0x19, 0x11, 0x17, 0x10, 0x17, 0x10, 0x16, 0x0F, 0x16, 0x0F, 0x17, 0x0F, 0x20, 0x13, 0x40, 0x1C, 0x55, 0x20, 0x5B, 0x21, 0x55, 0x1E, 0x37, 0x18, 0x32, 0x19, 0x4F, 0x1F, 0x59, 0x21, 0x5D, 0x22, 0x62, 0x23, 0x61, 0x23, 0x63, 0x23, 0x63, 0x23, 0x66, 0x23, 0x62, 0x23, 0x62, 0x23, 0x62, 0x23, 0x63, 0x23, 0x65, 0x24, 0x64, 0x24, 0x62, 0x24, 0x63, 0x23, 0x64, 0x24, 0x66, 0x24, 0x64, 0x23, 0x64, 0x24, 0x64, 0x24, 0x64, 0x24, 0x63, 0x23, 0x63, 0x23, 0x63, 0x23, 0x62, 0x23, 0x61, 0x23, 0x62, 0x24, 0x65, 0x25, 0x67, 0x24, 0x63, 0x24, 0x61, 0x23, 0x61, 0x23, 0x64, 0x24, 0x67, 0x25, 0x64, 0x24, 0x62, 0x23, 0x60, 0x21, 0x5F, 0x21, 0x5F, 0x22, 0x63, 0x23, 0x62, 0x23, 0x63, 0x24, 0x5F, 0x23, 0x62, 0x23, 0x60, 0x22, 0x60, 0x21, 0x5E, 0x22, 0x61, 0x23, 0x60, 0x22, 0x5F, 0x23, 0x61, 0x23, 0x5E, 0x23, 0x60, 0x24, 0x62, 0x25, 0x62, 0x23, 0x5E, 0x21, 0x5C, 0x21, 0x5D, 0x21, 0x5C, 0x21, 0x59, 0x20, 0x59, 0x20, 0x5C, 0x21, 0x5A, 0x20, 0x5A, 0x20, 0x59, 0x1F, 0x5B, 0x21, 0x5B, 0x20, 0x5C, 0x21, 0x5B, 0x21, 0x5B, 0x21, 0x5D, 0x21, 0x5D, 0x21, 0x5D, 0x21, 0x5D, 0x22, 0x5B, 0x21, 0x5A, 0x21, 0x5B, 0x22, 0x61, 0x24, 0x60, 0x24, 0x5F, 0x23, 0x5E, 0x22, 0x60, 0x23, 0x5E, 0x22, 0x5C, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x5B, 0x21, 0x5D, 0x22, 0x5D, 0x22, 0x5E, 0x21, 0x5C, 0x21, 0x5B, 0x21, 0x5C, 0x21, 0x59, 0x21, 0x5B, 0x21, 0x58, 0x20, 0x59, 0x21, 0x5D, 0x22, 0x59, 0x21, 0x5D, 0x21, 0x59, 0x21, 0x5B, 0x21, 0x5A, 0x22, 0x5A, 0x21, 0x59, 0x20, 0x59, 0x20, 0x57, 0x1F, 0x57, 0x20, 0x5A, 0x20, 0x55, 0x1F, 0x5A, 0x21, 0x5C, 0x22, 0x5A, 0x22, 0x56, 0x20, 0x45, 0x1C, 0x2F, 0x1A, 0x2F, 0x1A, 0x32, 0x1D, 0x35, 0x1C, 0x2D, 0x1A, 0x3F, 0x2A, 0x79, 0x54, 0x8B, 0x61, 0x8C, 0x61, 0x8F, 0x64, 0x8E, 0x61, 0x8E, 0x63, 0x75, 0x49, 0x2F, 0x1E, 0x31, 0x1C, 0x2A, 0x1A, 0x41, 0x2F, 0x82, 0x5B, 0x92, 0x65, 0x92, 0x66, 0x91, 0x66, 0x90, 0x64, 0x8F, 0x64, 0x64, 0x3D, 0x2C, 0x1C, 0x2D, 0x1B, 0x2B, 0x1C, 0x64, 0x49, 0x82, 0x5B, 0x87, 0x5E, 0x85, 0x5C, 0x81, 0x58, 0x7B, 0x54, 0x73, 0x4E, 0x36, 0x21, 0x28, 0x1A, 0x32, 0x1C, 0x34, 0x24, 0x5A, 0x3E, 0x5B, 0x40, 0x59, 0x3E, 0x53, 0x3A, 0x4B, 0x34, 0x44, 0x30
    },

    {
        0x44, 0x3F, 0x35, 0x30, 0x24, 0x23, 0x1A, 0x1C, 0x16, 0x19, 0x15, 0x18, 0x14, 0x17, 0x15, 0x18, 0x14, 0x18, 0x15, 0x18, 0x15, 0x18, 0x14, 0x17, 0x14, 0x17, 0x13, 0x17, 0x13, 0x16, 0x12, 0x15, 0x12, 0x15, 0x12, 0x15, 0x12, 0x16, 0x12, 0x17, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x10, 0x15, 0x11, 0x15, 0x11, 0x16, 0x11, 0x15, 0x12, 0x16, 0x11, 0x15, 0x11, 0x16, 0x11, 0x16, 0x12, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x16, 0x11, 0x15, 0x11, 0x16, 0x12, 0x19, 0x17, 0x23, 0x1F, 0x3C, 0x2D, 0x59, 0x2F, 0x51, 0x21, 0x32, 0x1A, 0x24, 0x17, 0x20, 0x15, 0x1D, 0x14, 0x1B, 0x14, 0x19, 0x13, 0x19, 0x15, 0x1A, 0x19, 0x1E, 0x23, 0x2F, 0x41, 0x5D, 0x63, 0x84, 0x71, 0x93, 0x79, 0x9B, 0x7E, 0xA1, 0x82, 0xA5, 0x84, 0xA7, 0x84, 0xA8, 0x86, 0xA8, 0x85, 0xA9, 0x87, 0xA8, 0x85, 0xA8, 0x86, 0xA8, 0x87, 0xA9, 0x86, 0xA9, 0x86, 0xA8, 0x85, 0xA7, 0x86, 0xAA, 0x88, 0xAD, 0x8A, 0xAD, 0x8A, 0xAD, 0x86, 0xAA, 0x86, 0xA9, 0x85, 0xA9, 0x84, 0xA9, 0x83, 0xA9, 0x7C, 0x9E, 0x69, 0x7E, 0x45, 0x4B, 0x2A, 0x2F, 0x22, 0x27, 0x1C, 0x22, 0x19, 0x1E, 0x16, 0x1B, 0x14, 0x19, 0x14, 0x18, 0x15, 0x1B, 0x1B, 0x2B, 0x2B, 0x58, 0x43, 0x8C, 0x50, 0xA0, 0x53, 0xA5, 0x53, 0xA1, 0x44, 0x79, 0x2A, 0x41, 0x1D, 0x29, 0x18, 0x20, 0x15, 0x1A, 0x13, 0x17, 0x12, 0x16, 0x12, 0x16, 0x11, 0x16, 0x11, 0x16, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x10, 0x15, 0x11, 0x16, 0x12, 0x16, 0x12, 0x16, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x11, 0x15, 0x11, 0x15, 0x12, 0x16, 0x12, 0x16, 0x14, 0x1B, 0x18, 0x26, 0x1B, 0x2E, 0x1C, 0x2F, 0x1C, 0x2F, 0x1D, 0x30, 0x1C, 0x31, 0x1D, 0x30, 0x1C, 0x2F, 0x1C, 0x2D, 0x1A, 0x26, 0x15, 0x1C, 0x13, 0x17, 0x12, 0x16, 0x13, 0x16, 0x12, 0x15, 0x12, 0x15, 0x13, 0x16, 0x19, 0x1D, 0x36, 0x3A, 0x53, 0x52, 0x5F, 0x59, 0x5D, 0x54, 0x40, 0x37, 0x35, 0x30, 0x4E, 0x4C, 0x5E, 0x57, 0x63, 0x5C, 0x69, 0x5F, 0x6B, 0x60, 0x6D, 0x60, 0x6D, 0x61, 0x6E, 0x61, 0x6C, 0x5F, 0x6B, 0x5E, 0x6B, 0x5F, 0x6E, 0x60, 0x6E, 0x62, 0x6F, 0x61, 0x6D, 0x5F, 0x6B, 0x5F, 0x6A, 0x60, 0x6E, 0x60, 0x6E, 0x62, 0x6D, 0x62, 0x6F, 0x62, 0x6F, 0x61, 0x6D, 0x62, 0x6E, 0x60, 0x6E, 0x61, 0x6B, 0x5E, 0x68, 0x5E, 0x6B, 0x60, 0x6E, 0x62, 0x71, 0x64, 0x6D, 0x61, 0x6C, 0x5E, 0x6A, 0x5F, 0x6C, 0x60, 0x6F, 0x63, 0x6D, 0x61, 0x6E, 0x60, 0x6B, 0x5D, 0x69, 0x5D, 0x6B, 0x5E, 0x6D, 0x5F, 0x6C, 0x5E, 0x6C, 0x60, 0x6A, 0x5F, 0x6B, 0x60, 0x69, 0x5C, 0x69, 0x5C, 0x6A, 0x5E, 0x6B, 0x5E, 0x69, 0x5D, 0x69, 0x5D, 0x6A, 0x5F, 0x67, 0x5C, 0x69, 0x5F, 0x6B, 0x61, 0x6A, 0x5D, 0x69, 0x5C, 0x67, 0x5B, 0x67, 0x5A, 0x65, 0x58, 0x62, 0x57, 0x63, 0x57, 0x66, 0x5A, 0x66, 0x59, 0x66, 0x5A, 0x63, 0x56, 0x64, 0x59, 0x65, 0x59, 0x65, 0x5A, 0x64, 0x59, 0x65, 0x5A, 0x65, 0x5A, 0x66, 0x5B, 0x69, 0x5C, 0x66, 0x5A, 0x64, 0x57, 0x64, 0x59, 0x65, 0x5A, 0x69, 0x5E, 0x69, 0x5E, 0x68, 0x5D, 0x68, 0x5E, 0x69, 0x5D, 0x67, 0x5B, 0x65, 0x5B, 0x68, 0x5B, 0x66, 0x5C, 0x63, 0x59, 0x65, 0x5B, 0x66, 0x5B, 0x67, 0x59, 0x64, 0x57, 0x61, 0x58, 0x62, 0x57, 0x61, 0x56, 0x63, 0x57, 0x61, 0x57, 0x63, 0x58, 0x66, 0x5A, 0x61, 0x55, 0x64, 0x57, 0x64, 0x57, 0x64, 0x58, 0x62, 0x58, 0x63, 0x58, 0x63, 0x57, 0x60, 0x57, 0x5F, 0x54, 0x60, 0x56, 0x62, 0x56, 0x5F, 0x54, 0x62, 0x57, 0x63, 0x59, 0x61, 0x58, 0x5F, 0x54, 0x47, 0x3D, 0x31, 0x33, 0x2C, 0x2C, 0x2F, 0x35, 0x2D, 0x2F, 0x25, 0x29, 0x2D, 0x44, 0x39, 0x7C, 0x3C, 0x88, 0x3B, 0x86, 0x3D, 0x8B, 0x3C, 0x8A, 0x3C, 0x8A, 0x34, 0x63, 0x20, 0x2C, 0x28, 0x2E, 0x25, 0x2D, 0x2C, 0x4B, 0x3B, 0x80, 0x3D, 0x89, 0x3C, 0x87, 0x3C, 0x8A, 0x3C, 0x87, 0x3B, 0x83, 0x2D, 0x4E, 0x1F, 0x2A, 0x26, 0x2B, 0x24, 0x2D, 0x30, 0x64, 0x37, 0x75, 0x36, 0x74, 0x34, 0x6E, 0x31, 0x68, 0x2F, 0x63, 0x2D, 0x58, 0x1C, 0x26, 0x20, 0x29, 0x2B, 0x31, 0x27, 0x34, 0x2C, 0x4A, 0x27, 0x44, 0x24, 0x40, 0x23, 0x3C, 0x20, 0x35, 0x1E, 0x30
    },

    {
        0x3A, 0x18, 0x2A, 0x14, 0x1F, 0x11, 0x1B, 0x10, 0x18, 0x0F, 0x18, 0x10, 0x1A, 0x11, 0x1C, 0x12, 0x1C, 0x11, 0x1B, 0x12, 0x1B, 0x12, 0x1A, 0x11, 0x19, 0x10, 0x19, 0x10, 0x17, 0x10, 0x16, 0x0F, 0x16, 0x0F, 0x16, 0x10, 0x17, 0x10, 0x18, 0x11, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x16, 0x10, 0x16, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x16, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x16, 0x10, 0x16, 0x0F, 0x16, 0x10, 0x17, 0x10, 0x17, 0x11, 0x17, 0x10, 0x16, 0x0F, 0x16, 0x0F, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x17, 0x11, 0x1E, 0x18, 0x31, 0x29, 0x56, 0x43, 0x7E, 0x5A, 0x87, 0x5A, 0x66, 0x3F, 0x3A, 0x26, 0x28, 0x1B, 0x22, 0x18, 0x1F, 0x16, 0x1D, 0x14, 0x1B, 0x13, 0x1A, 0x12, 0x1B, 0x15, 0x20, 0x18, 0x2F, 0x28, 0x60, 0x49, 0x8B, 0x61, 0x9B, 0x6A, 0xA4, 0x70, 0xA9, 0x73, 0xAB, 0x76, 0xB0, 0x77, 0xAF, 0x78, 0xAF, 0x78, 0xAF, 0x77, 0xB1, 0x78, 0xB1, 0x7A, 0xB1, 0x7A, 0xB1, 0x7A, 0xB1, 0x79, 0xB0, 0x79, 0xB1, 0x7A, 0xB5, 0x7C, 0xB5, 0x7C, 0xB4, 0x7B, 0xB2, 0x7B, 0xB1, 0x7A, 0xAF, 0x79, 0xB0, 0x78, 0xA9, 0x71, 0x93, 0x5D, 0x65, 0x3E, 0x3A, 0x26, 0x2A, 0x1D, 0x25, 0x1A, 0x21, 0x17, 0x1D, 0x15, 0x1B, 0x13, 0x1A, 0x12, 0x1A, 0x13, 0x22, 0x1C, 0x42, 0x39, 0x7D, 0x60, 0xA3, 0x75, 0xAC, 0x7B, 0xB4, 0x80, 0xB5, 0x80, 0xB3, 0x7B, 0x8A, 0x56, 0x46, 0x2D, 0x2B, 0x1D, 0x21, 0x17, 0x1B, 0x13, 0x19, 0x12, 0x18, 0x11, 0x17, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x0F, 0x16, 0x10, 0x15, 0x10, 0x17, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x0F, 0x16, 0x0F, 0x16, 0x10, 0x16, 0x0F, 0x17, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x0F, 0x16, 0x10, 0x16, 0x0F, 0x16, 0x10, 0x17, 0x10, 0x1A, 0x13, 0x23, 0x1B, 0x2E, 0x22, 0x32, 0x25, 0x32, 0x24, 0x32, 0x25, 0x32, 0x24, 0x32, 0x24, 0x32, 0x26, 0x32, 0x25, 0x32, 0x24, 0x30, 0x23, 0x28, 0x1C, 0x1D, 0x14, 0x19, 0x11, 0x17, 0x10, 0x17, 0x10, 0x16, 0x0F, 0x15, 0x0F, 0x16, 0x0F, 0x1D, 0x12, 0x3D, 0x1B, 0x55, 0x20, 0x5F, 0x23, 0x57, 0x1F, 0x3B, 0x19, 0x33, 0x1A, 0x4F, 0x21, 0x5C, 0x23, 0x61, 0x23, 0x64, 0x23, 0x65, 0x24, 0x64, 0x24, 0x64, 0x23, 0x62, 0x24, 0x61, 0x23, 0x60, 0x23, 0x63, 0x23, 0x64, 0x24, 0x64, 0x23, 0x65, 0x24, 0x62, 0x23, 0x5E, 0x22, 0x63, 0x22, 0x63, 0x23, 0x64, 0x23, 0x63, 0x23, 0x63, 0x23, 0x64, 0x24, 0x67, 0x24, 0x62, 0x22, 0x5F, 0x23, 0x5F, 0x24, 0x63, 0x24, 0x61, 0x23, 0x65, 0x23, 0x64, 0x23, 0x60, 0x23, 0x64, 0x23, 0x64, 0x23, 0x62, 0x24, 0x62, 0x23, 0x63, 0x23, 0x60, 0x22, 0x60, 0x21, 0x5F, 0x22, 0x64, 0x23, 0x63, 0x23, 0x62, 0x24, 0x62, 0x24, 0x61, 0x23, 0x62, 0x23, 0x60, 0x23, 0x60, 0x22, 0x60, 0x22, 0x5D, 0x21, 0x5F, 0x22, 0x5F, 0x23, 0x61, 0x24, 0x62, 0x24, 0x60, 0x23, 0x5E, 0x22, 0x5F, 0x21, 0x5E, 0x21, 0x5E, 0x22, 0x5A, 0x20, 0x5B, 0x21, 0x59, 0x20, 0x5C, 0x21, 0x5C, 0x21, 0x5E, 0x21, 0x5A, 0x20, 0x5B, 0x21, 0x5C, 0x21, 0x5E, 0x22, 0x5F, 0x23, 0x5E, 0x21, 0x5B, 0x20, 0x5C, 0x20, 0x5D, 0x22, 0x5D, 0x21, 0x5E, 0x23, 0x5E, 0x21, 0x5D, 0x22, 0x60, 0x23, 0x5D, 0x22, 0x5D, 0x21, 0x5C, 0x21, 0x5C, 0x21, 0x5D, 0x21, 0x5F, 0x22, 0x5C, 0x21, 0x5C, 0x22, 0x5E, 0x21, 0x5A, 0x20, 0x5B, 0x21, 0x5C, 0x21, 0x59, 0x20, 0x5C, 0x22, 0x5A, 0x21, 0x5B, 0x21, 0x5A, 0x21, 0x5B, 0x21, 0x5A, 0x21, 0x5C, 0x21, 0x58, 0x20, 0x59, 0x21, 0x5B, 0x21, 0x5B, 0x21, 0x5E, 0x22, 0x5C, 0x21, 0x58, 0x20, 0x59, 0x20, 0x57, 0x20, 0x59, 0x21, 0x5B, 0x20, 0x5A, 0x21, 0x5A, 0x20, 0x59, 0x20, 0x56, 0x20, 0x57, 0x20, 0x43, 0x1B, 0x38, 0x1D, 0x2A, 0x18, 0x34, 0x1C, 0x28, 0x18, 0x28, 0x19, 0x3B, 0x2A, 0x7B, 0x55, 0x86, 0x5C, 0x85, 0x5B, 0x86, 0x5B, 0x82, 0x59, 0x7E, 0x54, 0x62, 0x3B, 0x26, 0x1A, 0x33, 0x1D, 0x35, 0x1E, 0x40, 0x2A, 0x64, 0x42, 0x61, 0x42, 0x5D, 0x40, 0x58, 0x3D, 0x55, 0x39, 0x4B, 0x32, 0x34, 0x21, 0x27, 0x19, 0x35, 0x1D, 0x2D, 0x1B, 0x42, 0x28, 0x35, 0x23, 0x2D, 0x20, 0x29, 0x1D, 0x26, 0x1B, 0x25, 0x1A, 0x21, 0x17, 0x1D, 0x14, 0x2A, 0x1A, 0x2C, 0x19, 0x30, 0x1D, 0x2F, 0x1D, 0x27, 0x19, 0x28, 0x1A, 0x28, 0x1A, 0x23, 0x17, 0x23, 0x18
    },

    {
        0x38, 0x33, 0x26, 0x24, 0x1B, 0x1C, 0x17, 0x19, 0x15, 0x17, 0x16, 0x18, 0x17, 0x1B, 0x1A, 0x1E, 0x1B, 0x1E, 0x1A, 0x1D, 0x1A, 0x1C, 0x18, 0x1B, 0x16, 0x19, 0x15, 0x18, 0x14, 0x17, 0x13, 0x16, 0x13, 0x16, 0x12, 0x16, 0x12, 0x18, 0x13, 0x17, 0x12, 0x16, 0x12, 0x16, 0x12, 0x17, 0x12, 0x16, 0x11, 0x15, 0x11, 0x15, 0x12, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x16, 0x12, 0x16, 0x12, 0x16, 0x13, 0x17, 0x12, 0x17, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x16, 0x11, 0x16, 0x12, 0x15, 0x12, 0x18, 0x16, 0x22, 0x20, 0x3B, 0x30, 0x64, 0x42, 0x85, 0x46, 0x88, 0x3B, 0x68, 0x27, 0x3B, 0x1C, 0x29, 0x19, 0x23, 0x17, 0x1F, 0x16, 0x1D, 0x15, 0x1A, 0x14, 0x1A, 0x16, 0x1A, 0x19, 0x1F, 0x22, 0x2B, 0x3C, 0x56, 0x60, 0x82, 0x71, 0x92, 0x79, 0x9C, 0x7E, 0xA0, 0x83, 0xA7, 0x86, 0xA9, 0x86, 0xA9, 0x85, 0xA8, 0x85, 0xA8, 0x86, 0xA7, 0x86, 0xA9, 0x87, 0xAA, 0x88, 0xAC, 0x86, 0xAC, 0x88, 0xAA, 0x88, 0xAC, 0x89, 0xAE, 0x8A, 0xAC, 0x89, 0xAC, 0x87, 0xAA, 0x87, 0xAB, 0x86, 0xA9, 0x83, 0xA7, 0x7C, 0x9B, 0x69, 0x7D, 0x47, 0x4E, 0x2A, 0x30, 0x21, 0x26, 0x1C, 0x22, 0x19, 0x1E, 0x16, 0x1B, 0x15, 0x1A, 0x14, 0x19, 0x15, 0x1B, 0x1A, 0x29, 0x29, 0x52, 0x42, 0x89, 0x51, 0xA2, 0x55, 0xA9, 0x58, 0xAE, 0x59, 0xAF, 0x59, 0xAE, 0x4B, 0x89, 0x2E, 0x49, 0x1F, 0x2B, 0x19, 0x21, 0x16, 0x1B, 0x14, 0x18, 0x13, 0x18, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x11, 0x15, 0x11, 0x15, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x15, 0x11, 0x15, 0x12, 0x15, 0x12, 0x16, 0x12, 0x15, 0x12, 0x15, 0x12, 0x17, 0x12, 0x16, 0x12, 0x16, 0x12, 0x15, 0x12, 0x16, 0x12, 0x15, 0x12, 0x15, 0x12, 0x16, 0x14, 0x1B, 0x18, 0x26, 0x1B, 0x2E, 0x1E, 0x31, 0x1D, 0x30, 0x1C, 0x2F, 0x1D, 0x31, 0x1D, 0x30, 0x1D, 0x31, 0x1D, 0x30, 0x1D, 0x30, 0x1C, 0x2E, 0x1B, 0x27, 0x15, 0x1C, 0x13, 0x18, 0x13, 0x16, 0x13, 0x16, 0x12, 0x15, 0x12, 0x15, 0x13, 0x15, 0x18, 0x1A, 0x33, 0x39, 0x52, 0x52, 0x60, 0x5B, 0x5F, 0x56, 0x46, 0x3D, 0x35, 0x32, 0x4D, 0x4D, 0x5E, 0x59, 0x67, 0x5E, 0x6C, 0x61, 0x6D, 0x63, 0x6F, 0x64, 0x6D, 0x61, 0x6C, 0x5F, 0x6A, 0x5F, 0x68, 0x5E, 0x6D, 0x60, 0x6E, 0x62, 0x6F, 0x62, 0x71, 0x61, 0x6C, 0x5E, 0x67, 0x5D, 0x6D, 0x62, 0x6E, 0x61, 0x6C, 0x61, 0x6D, 0x60, 0x6D, 0x5F, 0x6E, 0x61, 0x72, 0x64, 0x6D, 0x5F, 0x69, 0x5D, 0x6A, 0x5E, 0x6C, 0x60, 0x6B, 0x5E, 0x6F, 0x62, 0x6F, 0x60, 0x6C, 0x60, 0x6E, 0x60, 0x6E, 0x61, 0x6D, 0x61, 0x6D, 0x60, 0x70, 0x60, 0x6C, 0x5F, 0x6B, 0x5E, 0x6A, 0x5F, 0x6F, 0x62, 0x6F, 0x61, 0x6C, 0x61, 0x6A, 0x5F, 0x69, 0x5E, 0x6C, 0x60, 0x6A, 0x5D, 0x6A, 0x5E, 0x6A, 0x5D, 0x69, 0x5B, 0x6A, 0x5D, 0x68, 0x5E, 0x69, 0x5F, 0x67, 0x5F, 0x69, 0x5C, 0x69, 0x5C, 0x67, 0x5D, 0x69, 0x5C, 0x67, 0x5C, 0x65, 0x58, 0x64, 0x59, 0x64, 0x58, 0x67, 0x5A, 0x66, 0x59, 0x6A, 0x5C, 0x65, 0x59, 0x65, 0x5A, 0x67, 0x5A, 0x68, 0x5C, 0x68, 0x5C, 0x66, 0x5A, 0x66, 0x5A, 0x67, 0x5B, 0x68, 0x5D, 0x67, 0x5B, 0x68, 0x5C, 0x67, 0x5D, 0x66, 0x5C, 0x69, 0x5E, 0x67, 0x5C, 0x66, 0x58, 0x66, 0x5B, 0x68, 0x5A, 0x69, 0x5C, 0x69, 0x5B, 0x66, 0x59, 0x64, 0x5A, 0x66, 0x5A, 0x63, 0x58, 0x65, 0x5A, 0x68, 0x5A, 0x63, 0x57, 0x65, 0x5A, 0x62, 0x58, 0x63, 0x59, 0x63, 0x57, 0x64, 0x59, 0x64, 0x59, 0x65, 0x5B, 0x62, 0x56, 0x61, 0x56, 0x64, 0x58, 0x64, 0x59, 0x66, 0x5C, 0x66, 0x5A, 0x63, 0x57, 0x62, 0x55, 0x60, 0x55, 0x61, 0x56, 0x64, 0x57, 0x62, 0x58, 0x63, 0x56, 0x60, 0x55, 0x5F, 0x55, 0x5D, 0x55, 0x45, 0x3B, 0x32, 0x32, 0x28, 0x29, 0x2D, 0x2E, 0x25, 0x27, 0x25, 0x2B, 0x2A, 0x40, 0x38, 0x76, 0x39, 0x79, 0x36, 0x75, 0x35, 0x73, 0x33, 0x6F, 0x31, 0x68, 0x29, 0x47, 0x1B, 0x24, 0x2C, 0x33, 0x2D, 0x33, 0x2C, 0x40, 0x2F, 0x53, 0x28, 0x4B, 0x26, 0x45, 0x24, 0x41, 0x23, 0x3C, 0x21, 0x36, 0x1B, 0x25, 0x1F, 0x26, 0x2C, 0x33, 0x25, 0x2A, 0x2E, 0x39, 0x1E, 0x27, 0x1B, 0x23, 0x19, 0x21, 0x19, 0x20, 0x19, 0x20, 0x19, 0x1F, 0x17, 0x1C, 0x24, 0x2C, 0x25, 0x28, 0x2A, 0x33, 0x26, 0x2B, 0x21, 0x29, 0x21, 0x2A, 0x21, 0x28, 0x1B, 0x20, 0x1F, 0x27
    },

    {
        0x2C, 0x15, 0x20, 0x11, 0x1B, 0x10, 0x18, 0x0F, 0x18, 0x10, 0x1B, 0x12, 0x24, 0x17, 0x2E, 0x1B, 0x30, 0x1A, 0x26, 0x16, 0x21, 0x15, 0x1E, 0x13, 0x1C, 0x12, 0x1A, 0x11, 0x19, 0x10, 0x17, 0x10, 0x17, 0x10, 0x18, 0x11, 0x18, 0x11, 0x17, 0x10, 0x16, 0x0F, 0x16, 0x0F, 0x17, 0x10, 0x17, 0x0F, 0x16, 0x0F, 0x16, 0x0F, 0x16, 0x0F, 0x16, 0x0F, 0x16, 0x0F, 0x15, 0x0F, 0x16, 0x0F, 0x16, 0x10, 0x15, 0x0F, 0x16, 0x10, 0x17, 0x11, 0x17, 0x10, 0x17, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x0F, 0x16, 0x10, 0x16, 0x10, 0x17, 0x10, 0x17, 0x11, 0x1D, 0x17, 0x2E, 0x26, 0x4F, 0x41, 0x7E, 0x5C, 0x92, 0x67, 0x97, 0x6A, 0x93, 0x62, 0x71, 0x45, 0x42, 0x2A, 0x2C, 0x1E, 0x24, 0x19, 0x21, 0x18, 0x1E, 0x15, 0x1C, 0x14, 0x1C, 0x14, 0x1C, 0x15, 0x20, 0x18, 0x2C, 0x25, 0x57, 0x44, 0x87, 0x60, 0x9C, 0x6B, 0xA2, 0x70, 0xA9, 0x74, 0xAE, 0x76, 0xAF, 0x78, 0xB0, 0x78, 0xAF, 0x77, 0xB0, 0x7A, 0xB1, 0x79, 0xB3, 0x7B, 0xB5, 0x7B, 0xB4, 0x7B, 0xB3, 0x7A, 0xB1, 0x7A, 0xB1, 0x7A, 0xB4, 0x7C, 0xB0, 0x79, 0xB2, 0x7B, 0xB3, 0x7A, 0xB0, 0x78, 0xAA, 0x72, 0x94, 0x5E, 0x66, 0x40, 0x3B, 0x26, 0x2B, 0x1D, 0x25, 0x19, 0x20, 0x17, 0x1D, 0x14, 0x1B, 0x14, 0x1A, 0x13, 0x1B, 0x14, 0x23, 0x1C, 0x3E, 0x36, 0x74, 0x5B, 0xA0, 0x72, 0xAC, 0x7B, 0xB2, 0x7E, 0xB7, 0x82, 0xBC, 0x86, 0xBF, 0x88, 0xB9, 0x7F, 0x91, 0x5B, 0x4A, 0x2F, 0x2C, 0x1D, 0x22, 0x17, 0x1C, 0x14, 0x19, 0x12, 0x17, 0x11, 0x17, 0x11, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x16, 0x10, 0x16, 0x10, 0x17, 0x10, 0x17, 0x11, 0x18, 0x11, 0x17, 0x10, 0x17, 0x11, 0x17, 0x10, 0x18, 0x11, 0x16, 0x0F, 0x17, 0x11, 0x17, 0x10, 0x18, 0x11, 0x16, 0x0F, 0x17, 0x10, 0x16, 0x10, 0x16, 0x10, 0x19, 0x12, 0x22, 0x1B, 0x2D, 0x22, 0x31, 0x24, 0x33, 0x25, 0x32, 0x25, 0x32, 0x24, 0x32, 0x25, 0x33, 0x26, 0x32, 0x25, 0x33, 0x26, 0x32, 0x25, 0x31, 0x24, 0x2F, 0x23, 0x2A, 0x1E, 0x1D, 0x14, 0x19, 0x11, 0x18, 0x11, 0x17, 0x0F, 0x16, 0x0F, 0x15, 0x0F, 0x16, 0x0F, 0x1C, 0x12, 0x3B, 0x1B, 0x55, 0x21, 0x5D, 0x22, 0x5A, 0x21, 0x40, 0x1C, 0x34, 0x1C, 0x4F, 0x21, 0x5D, 0x22, 0x61, 0x23, 0x63, 0x24, 0x64, 0x23, 0x64, 0x23, 0x60, 0x22, 0x61, 0x22, 0x62, 0x23, 0x64, 0x24, 0x64, 0x23, 0x63, 0x23, 0x64, 0x23, 0x63, 0x23, 0x62, 0x22, 0x63, 0x23, 0x63, 0x24, 0x63, 0x23, 0x64, 0x23, 0x61, 0x23, 0x62, 0x24, 0x64, 0x24, 0x64, 0x23, 0x62, 0x24, 0x62, 0x24, 0x65, 0x25, 0x63, 0x24, 0x66, 0x24, 0x65, 0x23, 0x63, 0x23, 0x64, 0x23, 0x62, 0x23, 0x64, 0x24, 0x62, 0x23, 0x65, 0x23, 0x64, 0x23, 0x63, 0x22, 0x61, 0x22, 0x63, 0x24, 0x67, 0x25, 0x68, 0x26, 0x66, 0x25, 0x63, 0x24, 0x63, 0x25, 0x60, 0x23, 0x60, 0x23, 0x60, 0x24, 0x60, 0x23, 0x5F, 0x24, 0x63, 0x24, 0x61, 0x24, 0x5E, 0x24, 0x61, 0x24, 0x61, 0x23, 0x60, 0x22, 0x61, 0x22, 0x5F, 0x23, 0x5D, 0x22, 0x5C, 0x20, 0x59, 0x21, 0x5B, 0x20, 0x5C, 0x21, 0x5D, 0x21, 0x5C, 0x20, 0x5D, 0x22, 0x60, 0x22, 0x5E, 0x21, 0x5B, 0x21, 0x5D, 0x21, 0x5C, 0x21, 0x5E, 0x21, 0x5E, 0x21, 0x5D, 0x22, 0x5E, 0x22, 0x5E, 0x23, 0x60, 0x23, 0x5C, 0x22, 0x5D, 0x21, 0x5A, 0x21, 0x5B, 0x21, 0x5E, 0x21, 0x5E, 0x21, 0x5D, 0x22, 0x5B, 0x21, 0x5C, 0x21, 0x5D, 0x21, 0x5E, 0x22, 0x5E, 0x22, 0x5D, 0x21, 0x5E, 0x22, 0x5D, 0x22, 0x5B, 0x21, 0x59, 0x20, 0x59, 0x20, 0x5B, 0x20, 0x5C, 0x21, 0x5B, 0x22, 0x59, 0x20, 0x5A, 0x21, 0x5B, 0x21, 0x5C, 0x21, 0x5C, 0x21, 0x5B, 0x21, 0x57, 0x20, 0x56, 0x1F, 0x55, 0x1F, 0x56, 0x20, 0x5B, 0x21, 0x58, 0x20, 0x57, 0x20, 0x56, 0x20, 0x58, 0x20, 0x56, 0x20, 0x44, 0x1C, 0x32, 0x19, 0x33, 0x1E, 0x30, 0x1B, 0x36, 0x1C, 0x2A, 0x19, 0x3D, 0x23, 0x45, 0x2B, 0x3B, 0x29, 0x36, 0x25, 0x31, 0x22, 0x2C, 0x1F, 0x26, 0x1B, 0x20, 0x16, 0x22, 0x17, 0x37, 0x1E, 0x2B, 0x19, 0x31, 0x1D, 0x2D, 0x1B, 0x22, 0x18, 0x21, 0x17, 0x23, 0x18, 0x23, 0x17, 0x20, 0x16, 0x1F, 0x15, 0x22, 0x16, 0x2A, 0x19, 0x24, 0x18, 0x2C, 0x1A, 0x26, 0x18, 0x26, 0x18, 0x25, 0x18, 0x26, 0x18, 0x29, 0x19, 0x2A, 0x19, 0x25, 0x16, 0x2C, 0x1A, 0x2B, 0x18, 0x36, 0x1F, 0x36, 0x1D, 0x35, 0x1D, 0x2B, 0x1A, 0x29, 0x19, 0x27, 0x18, 0x2E, 0x1B
    },

    {
        0x28, 0x25, 0x1C, 0x1D, 0x17, 0x19, 0x15, 0x17, 0x15, 0x17, 0x19, 0x1D, 0x22, 0x28, 0x2D, 0x37, 0x32, 0x36, 0x28, 0x28, 0x1F, 0x22, 0x1C, 0x1F, 0x1A, 0x1C, 0x18, 0x1A, 0x16, 0x19, 0x14, 0x18, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x12, 0x16, 0x12, 0x15, 0x11, 0x15, 0x12, 0x16, 0x12, 0x15, 0x12, 0x15, 0x12, 0x16, 0x12, 0x15, 0x11, 0x14, 0x11, 0x15, 0x11, 0x15, 0x10, 0x14, 0x11, 0x14, 0x11, 0x15, 0x11, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x16, 0x11, 0x15, 0x11, 0x16, 0x13, 0x18, 0x16, 0x21, 0x1E, 0x37, 0x2D, 0x5E, 0x40, 0x82, 0x48, 0x90, 0x4C, 0x92, 0x4A, 0x91, 0x40, 0x71, 0x2A, 0x43, 0x1E, 0x2C, 0x1A, 0x25, 0x19, 0x21, 0x17, 0x1E, 0x15, 0x1B, 0x15, 0x1B, 0x16, 0x1A, 0x18, 0x1D, 0x1F, 0x27, 0x38, 0x4E, 0x5B, 0x7D, 0x71, 0x93, 0x77, 0x9C, 0x7E, 0xA0, 0x81, 0xA5, 0x84, 0xA8, 0x86, 0xA9, 0x86, 0xAB, 0x88, 0xAB, 0x88, 0xAB, 0x89, 0xAD, 0x8A, 0xAC, 0x88, 0xAD, 0x89, 0xAB, 0x87, 0xAA, 0x86, 0xA9, 0x88, 0xAC, 0x87, 0xAA, 0x87, 0xAA, 0x86, 0xAB, 0x83, 0xA7, 0x7C, 0x9C, 0x6A, 0x7E, 0x4A, 0x51, 0x2C, 0x31, 0x21, 0x26, 0x1B, 0x20, 0x19, 0x1E, 0x16, 0x1B, 0x14, 0x1A, 0x15, 0x1A, 0x15, 0x1C, 0x1B, 0x29, 0x28, 0x4E, 0x3E, 0x85, 0x4F, 0x9D, 0x54, 0xA8, 0x57, 0xAC, 0x59, 0xAF, 0x5B, 0xB4, 0x5D, 0xB6, 0x5B, 0xB2, 0x4D, 0x8F, 0x2F, 0x4A, 0x1E, 0x2B, 0x19, 0x21, 0x15, 0x1B, 0x13, 0x18, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x17, 0x12, 0x16, 0x12, 0x16, 0x11, 0x16, 0x12, 0x17, 0x12, 0x17, 0x13, 0x17, 0x12, 0x16, 0x12, 0x16, 0x12, 0x17, 0x13, 0x18, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x15, 0x12, 0x16, 0x13, 0x1A, 0x17, 0x25, 0x1B, 0x2D, 0x1C, 0x2F, 0x1D, 0x30, 0x1D, 0x2F, 0x1C, 0x2F, 0x1D, 0x30, 0x1D, 0x30, 0x1D, 0x31, 0x1D, 0x30, 0x1D, 0x30, 0x1D, 0x2E, 0x1C, 0x2E, 0x1A, 0x2A, 0x16, 0x1D, 0x13, 0x17, 0x13, 0x17, 0x13, 0x16, 0x13, 0x16, 0x12, 0x15, 0x13, 0x15, 0x17, 0x1A, 0x31, 0x37, 0x52, 0x53, 0x60, 0x5B, 0x5F, 0x59, 0x49, 0x40, 0x35, 0x32, 0x4A, 0x4A, 0x5F, 0x59, 0x67, 0x5D, 0x6B, 0x61, 0x6C, 0x61, 0x6A, 0x5E, 0x6A, 0x5D, 0x6B, 0x5E, 0x6B, 0x61, 0x6C, 0x61, 0x6D, 0x61, 0x6D, 0x60, 0x6F, 0x61, 0x6E, 0x60, 0x6D, 0x5E, 0x6E, 0x61, 0x6E, 0x60, 0x6D, 0x61, 0x6F, 0x61, 0x6C, 0x60, 0x6E, 0x62, 0x6E, 0x62, 0x6F, 0x62, 0x6C, 0x61, 0x6D, 0x61, 0x6E, 0x63, 0x6C, 0x61, 0x6E, 0x62, 0x70, 0x62, 0x6F, 0x61, 0x70, 0x62, 0x6C, 0x5F, 0x6D, 0x61, 0x6E, 0x60, 0x70, 0x61, 0x6F, 0x61, 0x6F, 0x5F, 0x6D, 0x5F, 0x6E, 0x60, 0x71, 0x65, 0x72, 0x66, 0x6E, 0x63, 0x6C, 0x60, 0x6C, 0x61, 0x6B, 0x5F, 0x6B, 0x5D, 0x6C, 0x5E, 0x69, 0x5E, 0x67, 0x5F, 0x6A, 0x5F, 0x69, 0x5D, 0x66, 0x5E, 0x69, 0x5F, 0x68, 0x5F, 0x69, 0x5C, 0x6B, 0x5E, 0x68, 0x5C, 0x66, 0x5C, 0x66, 0x58, 0x65, 0x58, 0x67, 0x5A, 0x67, 0x59, 0x68, 0x5A, 0x66, 0x5A, 0x66, 0x5A, 0x6A, 0x5D, 0x69, 0x5B, 0x66, 0x59, 0x65, 0x5A, 0x68, 0x5B, 0x68, 0x5C, 0x68, 0x5C, 0x67, 0x5C, 0x69, 0x5C, 0x66, 0x5C, 0x69, 0x5E, 0x65, 0x59, 0x65, 0x5B, 0x64, 0x58, 0x65, 0x5A, 0x67, 0x5B, 0x68, 0x5C, 0x67, 0x5C, 0x67, 0x5A, 0x65, 0x5A, 0x66, 0x5B, 0x67, 0x5C, 0x68, 0x5A, 0x65, 0x5B, 0x66, 0x5C, 0x65, 0x5B, 0x65, 0x5A, 0x62, 0x57, 0x63, 0x57, 0x64, 0x58, 0x65, 0x59, 0x63, 0x59, 0x62, 0x58, 0x65, 0x58, 0x64, 0x58, 0x64, 0x59, 0x65, 0x59, 0x63, 0x57, 0x61, 0x55, 0x5F, 0x53, 0x60, 0x55, 0x60, 0x55, 0x64, 0x58, 0x63, 0x56, 0x61, 0x55, 0x60, 0x55, 0x60, 0x55, 0x5C, 0x52, 0x46, 0x3E, 0x32, 0x30, 0x2D, 0x33, 0x2D, 0x30, 0x30, 0x33, 0x26, 0x29, 0x30, 0x3B, 0x27, 0x33, 0x1E, 0x29, 0x1C, 0x26, 0x1B, 0x25, 0x19, 0x21, 0x18, 0x1E, 0x17, 0x1B, 0x1D, 0x25, 0x2F, 0x34, 0x23, 0x25, 0x2A, 0x31, 0x23, 0x26, 0x1C, 0x21, 0x1A, 0x1F, 0x1E, 0x25, 0x1C, 0x21, 0x1A, 0x1E, 0x1C, 0x1E, 0x1E, 0x23, 0x24, 0x27, 0x20, 0x25, 0x25, 0x29, 0x22, 0x27, 0x21, 0x26, 0x22, 0x29, 0x23, 0x2A, 0x26, 0x2B, 0x27, 0x2C, 0x23, 0x28, 0x28, 0x2F, 0x27, 0x2A, 0x2F, 0x38, 0x2F, 0x33, 0x2C, 0x2F, 0x24, 0x26, 0x23, 0x28, 0x24, 0x28, 0x29, 0x2E
    },

    {
        0x21, 0x12, 0x1B, 0x10, 0x19, 0x10, 0x18, 0x0F, 0x1B, 0x11, 0x24, 0x17, 0x36, 0x20, 0x50, 0x2B, 0x5B, 0x2C, 0x47, 0x22, 0x2E, 0x1A, 0x24, 0x15, 0x20, 0x13, 0x1C, 0x12, 0x1B, 0x11, 0x1A, 0x12, 0x19, 0x11, 0x19, 0x11, 0x19, 0x11, 0x17, 0x10, 0x16, 0x0F, 0x16, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x16, 0x0F, 0x16, 0x10, 0x16, 0x10, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x17, 0x11, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x17, 0x11, 0x1C, 0x17, 0x2E, 0x27, 0x51, 0x40, 0x7C, 0x5C, 0x94, 0x69, 0x9C, 0x6E, 0xA0, 0x70, 0xA0, 0x6E, 0x99, 0x67, 0x7C, 0x4E, 0x4B, 0x30, 0x31, 0x21, 0x28, 0x1B, 0x23, 0x18, 0x1F, 0x16, 0x1D, 0x15, 0x1B, 0x14, 0x1B, 0x14, 0x1E, 0x16, 0x28, 0x21, 0x4E, 0x3F, 0x84, 0x5F, 0x9B, 0x6C, 0xA3, 0x6F, 0xA8, 0x73, 0xAC, 0x76, 0xAE, 0x78, 0xB1, 0x78, 0xB3, 0x79, 0xB3, 0x7A, 0xB2, 0x7A, 0xB2, 0x7B, 0xB3, 0x7B, 0xB4, 0x7A, 0xB2, 0x7A, 0xB3, 0x7A, 0xB1, 0x79, 0xB0, 0x79, 0xB1, 0x79, 0xAF, 0x78, 0xA8, 0x72, 0x95, 0x60, 0x6B, 0x41, 0x3D, 0x27, 0x2C, 0x1E, 0x25, 0x19, 0x20, 0x17, 0x1D, 0x15, 0x1C, 0x14, 0x1B, 0x13, 0x1B, 0x14, 0x22, 0x1B, 0x41, 0x37, 0x76, 0x5B, 0x9F, 0x73, 0xAB, 0x7A, 0xB3, 0x7F, 0xB8, 0x84, 0xBA, 0x85, 0xBB, 0x87, 0xC0, 0x89, 0xBC, 0x86, 0xB8, 0x80, 0x96, 0x61, 0x51, 0x33, 0x2D, 0x1E, 0x21, 0x17, 0x1B, 0x13, 0x18, 0x11, 0x17, 0x10, 0x17, 0x10, 0x16, 0x10, 0x16, 0x10, 0x17, 0x10, 0x16, 0x10, 0x17, 0x10, 0x17, 0x11, 0x17, 0x11, 0x17, 0x11, 0x18, 0x11, 0x17, 0x11, 0x1C, 0x13, 0x18, 0x11, 0x18, 0x10, 0x18, 0x11, 0x16, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x19, 0x13, 0x21, 0x1B, 0x2D, 0x22, 0x31, 0x24, 0x34, 0x26, 0x32, 0x25, 0x33, 0x26, 0x33, 0x25, 0x32, 0x26, 0x32, 0x24, 0x32, 0x25, 0x33, 0x26, 0x33, 0x25, 0x33, 0x26, 0x32, 0x25, 0x31, 0x23, 0x2C, 0x1E, 0x1F, 0x14, 0x1A, 0x12, 0x18, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x0F, 0x16, 0x0F, 0x1B, 0x13, 0x3A, 0x1B, 0x56, 0x21, 0x5C, 0x23, 0x5B, 0x23, 0x43, 0x1C, 0x33, 0x1A, 0x49, 0x1F, 0x5A, 0x22, 0x5D, 0x22, 0x5F, 0x22, 0x60, 0x22, 0x63, 0x23, 0x63, 0x23, 0x65, 0x24, 0x63, 0x24, 0x63, 0x23, 0x64, 0x23, 0x64, 0x23, 0x62, 0x22, 0x5E, 0x22, 0x62, 0x23, 0x66, 0x24, 0x66, 0x24, 0x65, 0x24, 0x65, 0x24, 0x63, 0x24, 0x65, 0x23, 0x65, 0x23, 0x64, 0x24, 0x65, 0x24, 0x65, 0x24, 0x64, 0x24, 0x65, 0x24, 0x65, 0x23, 0x64, 0x23, 0x64, 0x23, 0x61, 0x23, 0x62, 0x24, 0x65, 0x24, 0x63, 0x23, 0x62, 0x22, 0x61, 0x22, 0x64, 0x24, 0x65, 0x25, 0x63, 0x24, 0x69, 0x25, 0x67, 0x24, 0x63, 0x24, 0x65, 0x25, 0x64, 0x24, 0x61, 0x24, 0x61, 0x26, 0x64, 0x26, 0x63, 0x24, 0x5E, 0x22, 0x5C, 0x22, 0x5E, 0x22, 0x5C, 0x21, 0x5C, 0x21, 0x5D, 0x20, 0x5C, 0x21, 0x5D, 0x22, 0x5F, 0x23, 0x5F, 0x21, 0x5B, 0x20, 0x59, 0x20, 0x5B, 0x21, 0x5C, 0x20, 0x5A, 0x20, 0x5D, 0x22, 0x5C, 0x20, 0x5E, 0x21, 0x5E, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x5E, 0x22, 0x5F, 0x22, 0x60, 0x22, 0x5C, 0x21, 0x5E, 0x23, 0x5F, 0x22, 0x5B, 0x21, 0x58, 0x21, 0x5B, 0x21, 0x5B, 0x21, 0x5A, 0x20, 0x5B, 0x20, 0x5C, 0x21, 0x5E, 0x22, 0x5E, 0x22, 0x5C, 0x22, 0x5C, 0x22, 0x5C, 0x22, 0x5E, 0x22, 0x5E, 0x21, 0x5E, 0x22, 0x5D, 0x21, 0x5A, 0x21, 0x5B, 0x21, 0x59, 0x21, 0x5C, 0x22, 0x5A, 0x21, 0x5A, 0x20, 0x57, 0x20, 0x59, 0x22, 0x5A, 0x21, 0x59, 0x21, 0x58, 0x20, 0x59, 0x20, 0x57, 0x1F, 0x58, 0x1F, 0x58, 0x1F, 0x58, 0x20, 0x5A, 0x23, 0x5A, 0x21, 0x59, 0x21, 0x57, 0x20, 0x47, 0x1E, 0x3B, 0x1C, 0x2C, 0x19, 0x32, 0x1B, 0x2B, 0x18, 0x29, 0x19, 0x2E, 0x1A, 0x25, 0x18, 0x25, 0x17, 0x25, 0x19, 0x26, 0x18, 0x24, 0x17, 0x25, 0x16, 0x23, 0x16, 0x2B, 0x19, 0x32, 0x1B, 0x28, 0x19, 0x36, 0x1D, 0x2A, 0x19, 0x2A, 0x19, 0x27, 0x18, 0x2D, 0x1A, 0x2A, 0x19, 0x2C, 0x1A, 0x2F, 0x1B, 0x2B, 0x19, 0x2F, 0x1A, 0x2E, 0x1A, 0x31, 0x1B, 0x2F, 0x1B, 0x36, 0x1D, 0x2C, 0x1B, 0x35, 0x1C, 0x2C, 0x1A, 0x39, 0x1E, 0x2F, 0x1A, 0x32, 0x1C, 0x29, 0x17, 0x2F, 0x1A, 0x2C, 0x19, 0x28, 0x17, 0x26, 0x17, 0x32, 0x1B, 0x2A, 0x18, 0x34, 0x1D
    },

    {
        0x1D, 0x1E, 0x17, 0x19, 0x15, 0x17, 0x15, 0x17, 0x19, 0x1C, 0x22, 0x29, 0x33, 0x3E, 0x49, 0x58, 0x56, 0x5F, 0x49, 0x49, 0x32, 0x31, 0x24, 0x26, 0x1D, 0x1F, 0x1A, 0x1D, 0x18, 0x1A, 0x17, 0x1A, 0x15, 0x19, 0x16, 0x19, 0x15, 0x17, 0x13, 0x16, 0x12, 0x16, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x16, 0x12, 0x16, 0x12, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x12, 0x16, 0x12, 0x16, 0x12, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x12, 0x16, 0x12, 0x18, 0x16, 0x20, 0x1E, 0x37, 0x2E, 0x5E, 0x41, 0x84, 0x49, 0x92, 0x4E, 0x98, 0x50, 0x9B, 0x50, 0x9C, 0x4D, 0x97, 0x44, 0x7E, 0x30, 0x4C, 0x21, 0x31, 0x1B, 0x27, 0x18, 0x21, 0x17, 0x1E, 0x16, 0x1D, 0x15, 0x1A, 0x15, 0x1A, 0x17, 0x1C, 0x1D, 0x25, 0x31, 0x47, 0x58, 0x7D, 0x71, 0x94, 0x79, 0x9E, 0x7E, 0xA1, 0x81, 0xA6, 0x83, 0xA6, 0x87, 0xAA, 0x87, 0xAA, 0x87, 0xAB, 0x88, 0xAC, 0x89, 0xAC, 0x88, 0xAC, 0x8B, 0xAD, 0x88, 0xAC, 0x87, 0xAB, 0x88, 0xAA, 0x85, 0xA9, 0x86, 0xAA, 0x84, 0xA9, 0x7C, 0x9C, 0x6B, 0x82, 0x4C, 0x53, 0x2C, 0x31, 0x22, 0x26, 0x1C, 0x21, 0x18, 0x1D, 0x17, 0x1C, 0x15, 0x1A, 0x15, 0x1A, 0x16, 0x1C, 0x1A, 0x28, 0x29, 0x51, 0x40, 0x85, 0x4F, 0x9E, 0x55, 0xA9, 0x57, 0xAC, 0x5A, 0xB2, 0x5B, 0xB3, 0x5B, 0xB4, 0x5D, 0xB6, 0x5B, 0xB3, 0x5A, 0xB1, 0x4F, 0x95, 0x34, 0x52, 0x1F, 0x2C, 0x19, 0x21, 0x15, 0x1A, 0x13, 0x17, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x11, 0x15, 0x11, 0x15, 0x12, 0x15, 0x12, 0x15, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x17, 0x15, 0x1B, 0x13, 0x17, 0x12, 0x17, 0x13, 0x17, 0x12, 0x16, 0x12, 0x16, 0x13, 0x16, 0x12, 0x17, 0x13, 0x1A, 0x17, 0x25, 0x1C, 0x2D, 0x1D, 0x30, 0x1E, 0x32, 0x1D, 0x30, 0x1D, 0x31, 0x1D, 0x31, 0x1D, 0x31, 0x1E, 0x30, 0x1D, 0x30, 0x1E, 0x30, 0x1E, 0x32, 0x1D, 0x32, 0x1E, 0x2F, 0x1C, 0x2F, 0x1B, 0x2A, 0x17, 0x1D, 0x14, 0x19, 0x13, 0x17, 0x13, 0x17, 0x13, 0x16, 0x13, 0x16, 0x13, 0x16, 0x17, 0x1A, 0x30, 0x36, 0x53, 0x52, 0x5E, 0x59, 0x60, 0x5B, 0x4C, 0x43, 0x34, 0x31, 0x46, 0x43, 0x5D, 0x57, 0x62, 0x59, 0x66, 0x5B, 0x69, 0x5D, 0x6C, 0x62, 0x6C, 0x60, 0x6D, 0x61, 0x6A, 0x60, 0x6B, 0x61, 0x6E, 0x62, 0x6F, 0x60, 0x6B, 0x5D, 0x6A, 0x5E, 0x6D, 0x61, 0x6E, 0x61, 0x6F, 0x63, 0x6F, 0x63, 0x6F, 0x62, 0x6C, 0x61, 0x6E, 0x62, 0x6D, 0x60, 0x6D, 0x62, 0x70, 0x62, 0x6E, 0x62, 0x6D, 0x62, 0x6E, 0x61, 0x6E, 0x62, 0x6F, 0x62, 0x6F, 0x61, 0x6D, 0x5F, 0x6B, 0x60, 0x6F, 0x62, 0x6F, 0x60, 0x6F, 0x60, 0x6D, 0x5F, 0x6F, 0x61, 0x6F, 0x63, 0x6D, 0x61, 0x72, 0x65, 0x70, 0x62, 0x6C, 0x61, 0x6D, 0x62, 0x6B, 0x60, 0x6B, 0x5F, 0x69, 0x62, 0x6A, 0x5F, 0x6A, 0x5E, 0x68, 0x5C, 0x67, 0x5A, 0x67, 0x5B, 0x65, 0x5A, 0x67, 0x5A, 0x67, 0x58, 0x66, 0x59, 0x66, 0x5B, 0x68, 0x5C, 0x69, 0x5C, 0x64, 0x58, 0x64, 0x57, 0x68, 0x5B, 0x66, 0x59, 0x64, 0x59, 0x69, 0x5B, 0x66, 0x5A, 0x68, 0x5C, 0x69, 0x5C, 0x68, 0x5B, 0x68, 0x5C, 0x69, 0x5C, 0x68, 0x5B, 0x6B, 0x5E, 0x6A, 0x5C, 0x66, 0x59, 0x68, 0x5B, 0x68, 0x5C, 0x64, 0x58, 0x61, 0x57, 0x63, 0x58, 0x63, 0x5A, 0x64, 0x57, 0x64, 0x57, 0x66, 0x5A, 0x65, 0x5A, 0x68, 0x5B, 0x64, 0x59, 0x65, 0x59, 0x68, 0x5A, 0x65, 0x5B, 0x66, 0x5B, 0x65, 0x5A, 0x66, 0x5A, 0x65, 0x59, 0x65, 0x5A, 0x65, 0x59, 0x65, 0x59, 0x62, 0x57, 0x64, 0x57, 0x5F, 0x54, 0x64, 0x59, 0x64, 0x58, 0x63, 0x58, 0x64, 0x58, 0x62, 0x57, 0x5F, 0x54, 0x60, 0x56, 0x61, 0x55, 0x64, 0x57, 0x65, 0x5A, 0x63, 0x58, 0x61, 0x58, 0x61, 0x55, 0x49, 0x43, 0x33, 0x32, 0x28, 0x29, 0x2D, 0x30, 0x24, 0x25, 0x23, 0x29, 0x24, 0x26, 0x20, 0x25, 0x21, 0x24, 0x22, 0x28, 0x21, 0x25, 0x20, 0x26, 0x23, 0x27, 0x21, 0x28, 0x26, 0x2C, 0x2A, 0x2F, 0x25, 0x2C, 0x2F, 0x33, 0x26, 0x29, 0x26, 0x2C, 0x23, 0x28, 0x28, 0x2D, 0x27, 0x2D, 0x28, 0x2C, 0x29, 0x2E, 0x27, 0x2D, 0x2C, 0x32, 0x2A, 0x2D, 0x2C, 0x31, 0x2A, 0x2F, 0x2F, 0x33, 0x27, 0x2C, 0x2D, 0x30, 0x29, 0x2F, 0x30, 0x34, 0x27, 0x29, 0x2A, 0x30, 0x23, 0x25, 0x28, 0x2C, 0x25, 0x28, 0x23, 0x26, 0x22, 0x27, 0x2C, 0x30, 0x24, 0x28, 0x2F, 0x36
    },

    {
        0x1C, 0x11, 0x19, 0x0F, 0x18, 0x10, 0x1A, 0x11, 0x22, 0x16, 0x34, 0x1F, 0x4F, 0x2B, 0x68, 0x34, 0x71, 0x37, 0x6B, 0x32, 0x52, 0x27, 0x34, 0x1B, 0x25, 0x16, 0x20, 0x13, 0x1C, 0x12, 0x1B, 0x12, 0x1A, 0x11, 0x1A, 0x12, 0x1A, 0x11, 0x17, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x15, 0x0F, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x0F, 0x15, 0x10, 0x15, 0x0F, 0x16, 0x0F, 0x16, 0x10, 0x17, 0x10, 0x16, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x11, 0x18, 0x11, 0x1C, 0x16, 0x2B, 0x24, 0x4D, 0x3D, 0x7B, 0x5B, 0x94, 0x69, 0x9E, 0x70, 0xA6, 0x74, 0xA6, 0x76, 0xA9, 0x76, 0xA4, 0x74, 0xA2, 0x6F, 0x89, 0x57, 0x53, 0x34, 0x33, 0x22, 0x28, 0x1C, 0x23, 0x19, 0x20, 0x16, 0x1D, 0x15, 0x1B, 0x14, 0x1B, 0x14, 0x1D, 0x16, 0x26, 0x1F, 0x47, 0x3B, 0x7E, 0x5C, 0x9B, 0x6B, 0xA3, 0x70, 0xA8, 0x73, 0xAD, 0x77, 0xAE, 0x78, 0xB0, 0x79, 0xB1, 0x79, 0xB3, 0x7A, 0xB5, 0x7B, 0xB2, 0x7B, 0xB2, 0x78, 0xB2, 0x7A, 0xB4, 0x7B, 0xB3, 0x7B, 0xB2, 0x7A, 0xB0, 0x7A, 0xAC, 0x74, 0x97, 0x63, 0x6E, 0x44, 0x3F, 0x28, 0x2C, 0x1E, 0x25, 0x19, 0x21, 0x17, 0x1D, 0x15, 0x1B, 0x13, 0x1A, 0x12, 0x1C, 0x14, 0x20, 0x19, 0x39, 0x32, 0x73, 0x5A, 0xA2, 0x76, 0xAD, 0x7C, 0xB3, 0x80, 0xB9, 0x82, 0xB8, 0x83, 0xBD, 0x86, 0xBB, 0x87, 0xBD, 0x87, 0xBC, 0x87, 0xBD, 0x86, 0xB8, 0x81, 0x9C, 0x64, 0x56, 0x37, 0x2F, 0x20, 0x22, 0x17, 0x1C, 0x13, 0x18, 0x11, 0x17, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x11, 0x17, 0x15, 0x18, 0x14, 0x17, 0x12, 0x17, 0x11, 0x17, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x0F, 0x16, 0x10, 0x19, 0x12, 0x21, 0x1A, 0x2F, 0x22, 0x30, 0x24, 0x32, 0x25, 0x34, 0x25, 0x33, 0x25, 0x33, 0x26, 0x32, 0x25, 0x35, 0x27, 0x35, 0x27, 0x37, 0x28, 0x37, 0x28, 0x34, 0x26, 0x36, 0x27, 0x35, 0x26, 0x34, 0x26, 0x33, 0x25, 0x2D, 0x1F, 0x20, 0x16, 0x19, 0x11, 0x17, 0x10, 0x17, 0x10, 0x18, 0x10, 0x18, 0x11, 0x18, 0x11, 0x1C, 0x13, 0x37, 0x1A, 0x55, 0x22, 0x5D, 0x22, 0x5E, 0x23, 0x45, 0x1D, 0x31, 0x1A, 0x46, 0x1E, 0x57, 0x20, 0x5D, 0x21, 0x60, 0x22, 0x67, 0x25, 0x66, 0x24, 0x66, 0x24, 0x62, 0x23, 0x60, 0x23, 0x63, 0x23, 0x63, 0x23, 0x63, 0x22, 0x61, 0x22, 0x60, 0x22, 0x61, 0x23, 0x66, 0x25, 0x67, 0x24, 0x65, 0x24, 0x62, 0x23, 0x64, 0x23, 0x63, 0x24, 0x63, 0x23, 0x63, 0x23, 0x60, 0x23, 0x65, 0x25, 0x65, 0x24, 0x64, 0x24, 0x62, 0x23, 0x62, 0x23, 0x62, 0x23, 0x64, 0x23, 0x62, 0x23, 0x65, 0x22, 0x63, 0x23, 0x65, 0x24, 0x67, 0x24, 0x65, 0x24, 0x64, 0x24, 0x64, 0x24, 0x64, 0x24, 0x62, 0x23, 0x5D, 0x22, 0x5E, 0x23, 0x61, 0x25, 0x65, 0x25, 0x5F, 0x23, 0x5C, 0x21, 0x5E, 0x21, 0x5D, 0x22, 0x5C, 0x21, 0x5D, 0x21, 0x5D, 0x21, 0x5E, 0x21, 0x5C, 0x20, 0x5D, 0x23, 0x5F, 0x22, 0x5F, 0x21, 0x5B, 0x20, 0x5B, 0x20, 0x5D, 0x21, 0x5E, 0x22, 0x5A, 0x20, 0x5B, 0x20, 0x5B, 0x20, 0x5A, 0x20, 0x5C, 0x21, 0x5D, 0x21, 0x5D, 0x21, 0x5D, 0x20, 0x5C, 0x21, 0x5E, 0x21, 0x5C, 0x20, 0x5B, 0x21, 0x5F, 0x22, 0x5D, 0x22, 0x59, 0x20, 0x59, 0x20, 0x5A, 0x20, 0x5A, 0x21, 0x5A, 0x21, 0x5B, 0x21, 0x5C, 0x21, 0x5C, 0x21, 0x5C, 0x20, 0x59, 0x20, 0x5B, 0x20, 0x5A, 0x21, 0x5A, 0x22, 0x5E, 0x22, 0x59, 0x20, 0x5B, 0x21, 0x59, 0x20, 0x5A, 0x21, 0x5A, 0x21, 0x5A, 0x21, 0x5B, 0x21, 0x5B, 0x21, 0x59, 0x20, 0x5B, 0x20, 0x59, 0x21, 0x5C, 0x22, 0x5B, 0x21, 0x59, 0x20, 0x54, 0x1F, 0x58, 0x20, 0x5A, 0x20, 0x5B, 0x21, 0x58, 0x20, 0x57, 0x20, 0x58, 0x20, 0x56, 0x1F, 0x40, 0x1B, 0x27, 0x15, 0x28, 0x19, 0x2F, 0x19, 0x2B, 0x1A, 0x32, 0x1A, 0x2D, 0x19, 0x2C, 0x1A, 0x36, 0x1D, 0x31, 0x1B, 0x31, 0x1B, 0x27, 0x17, 0x34, 0x1C, 0x2E, 0x19, 0x26, 0x18, 0x35, 0x1C, 0x2E, 0x1A, 0x33, 0x1C, 0x2A, 0x18, 0x35, 0x1E, 0x29, 0x18, 0x36, 0x1E, 0x33, 0x1A, 0x28, 0x17, 0x2C, 0x19, 0x30, 0x1B, 0x32, 0x1B, 0x26, 0x17, 0x33, 0x1B, 0x2B, 0x19, 0x2D, 0x18, 0x29, 0x19, 0x2C, 0x18, 0x2A, 0x18, 0x2C, 0x19, 0x28, 0x18, 0x2C, 0x19, 0x2C, 0x19, 0x34, 0x1C, 0x35, 0x1C, 0x2C, 0x19, 0x27, 0x17, 0x2D, 0x19, 0x26, 0x16, 0x30, 0x1A
    },

    {
        0x18, 0x1A, 0x15, 0x17, 0x15, 0x17, 0x19, 0x1C, 0x21, 0x27, 0x31, 0x3C, 0x4B, 0x58, 0x60, 0x6B, 0x68, 0x71, 0x64, 0x6C, 0x53, 0x53, 0x37, 0x35, 0x26, 0x26, 0x1E, 0x20, 0x1B, 0x1C, 0x18, 0x1B, 0x17, 0x1A, 0x17, 0x19, 0x15, 0x19, 0x13, 0x16, 0x13, 0x16, 0x12, 0x16, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x12, 0x16, 0x11, 0x15, 0x11, 0x15, 0x12, 0x15, 0x11, 0x15, 0x11, 0x15, 0x12, 0x15, 0x11, 0x16, 0x12, 0x16, 0x11, 0x16, 0x12, 0x16, 0x12, 0x16, 0x11, 0x16, 0x12, 0x16, 0x12, 0x17, 0x12, 0x17, 0x16, 0x20, 0x1D, 0x34, 0x2C, 0x5A, 0x3F, 0x82, 0x49, 0x93, 0x4D, 0x99, 0x50, 0xA0, 0x53, 0xA2, 0x54, 0xA4, 0x52, 0xA2, 0x51, 0x9F, 0x48, 0x88, 0x33, 0x55, 0x23, 0x33, 0x1B, 0x28, 0x18, 0x22, 0x17, 0x1F, 0x16, 0x1C, 0x15, 0x1B, 0x15, 0x1A, 0x17, 0x1C, 0x1D, 0x23, 0x2D, 0x40, 0x53, 0x75, 0x6E, 0x92, 0x78, 0x9B, 0x7D, 0xA1, 0x82, 0xA6, 0x86, 0xA8, 0x86, 0xAA, 0x88, 0xAB, 0x88, 0xAC, 0x8A, 0xAB, 0x88, 0xAC, 0x89, 0xAB, 0x88, 0xAC, 0x8A, 0xAE, 0x89, 0xAB, 0x87, 0xAD, 0x84, 0xA8, 0x7F, 0xA0, 0x6D, 0x83, 0x4E, 0x57, 0x2E, 0x33, 0x22, 0x27, 0x1C, 0x21, 0x19, 0x1D, 0x16, 0x1B, 0x15, 0x19, 0x14, 0x19, 0x16, 0x1C, 0x1A, 0x25, 0x25, 0x48, 0x3E, 0x81, 0x50, 0xA2, 0x54, 0xA9, 0x58, 0xAC, 0x5A, 0xAF, 0x5B, 0xB1, 0x5B, 0xB2, 0x5B, 0xB4, 0x5C, 0xB4, 0x5C, 0xB6, 0x5B, 0xB3, 0x5A, 0xB0, 0x51, 0x97, 0x37, 0x59, 0x20, 0x2F, 0x19, 0x22, 0x15, 0x1A, 0x13, 0x17, 0x12, 0x16, 0x12, 0x16, 0x11, 0x15, 0x12, 0x16, 0x12, 0x15, 0x11, 0x15, 0x11, 0x16, 0x13, 0x18, 0x12, 0x17, 0x12, 0x16, 0x12, 0x16, 0x12, 0x15, 0x11, 0x15, 0x12, 0x16, 0x12, 0x16, 0x12, 0x14, 0x11, 0x15, 0x12, 0x17, 0x13, 0x19, 0x17, 0x23, 0x1C, 0x2E, 0x1C, 0x2F, 0x1D, 0x30, 0x1D, 0x30, 0x1D, 0x31, 0x1D, 0x30, 0x1D, 0x32, 0x1E, 0x33, 0x1F, 0x33, 0x20, 0x36, 0x20, 0x36, 0x1F, 0x32, 0x1F, 0x33, 0x1E, 0x33, 0x1D, 0x32, 0x1D, 0x31, 0x1C, 0x2D, 0x18, 0x20, 0x14, 0x19, 0x13, 0x17, 0x13, 0x17, 0x14, 0x18, 0x14, 0x18, 0x15, 0x18, 0x17, 0x1B, 0x2D, 0x32, 0x50, 0x52, 0x5E, 0x5B, 0x63, 0x5C, 0x4E, 0x46, 0x34, 0x30, 0x43, 0x43, 0x5C, 0x56, 0x64, 0x5A, 0x69, 0x5D, 0x6F, 0x65, 0x70, 0x63, 0x6F, 0x63, 0x6A, 0x5F, 0x6A, 0x5F, 0x6C, 0x5F, 0x6E, 0x61, 0x6C, 0x60, 0x6B, 0x5D, 0x69, 0x5D, 0x6C, 0x5F, 0x6E, 0x63, 0x6F, 0x63, 0x6E, 0x61, 0x6C, 0x5F, 0x6E, 0x60, 0x6D, 0x5F, 0x6E, 0x61, 0x6F, 0x5F, 0x6A, 0x5E, 0x6E, 0x64, 0x6E, 0x61, 0x6C, 0x61, 0x6B, 0x60, 0x6B, 0x5F, 0x6C, 0x5F, 0x6F, 0x62, 0x6E, 0x60, 0x6E, 0x60, 0x6F, 0x61, 0x71, 0x63, 0x72, 0x64, 0x6F, 0x62, 0x6F, 0x61, 0x70, 0x62, 0x6D, 0x60, 0x6D, 0x60, 0x69, 0x5C, 0x67, 0x5C, 0x6B, 0x60, 0x6C, 0x61, 0x68, 0x5C, 0x66, 0x5B, 0x68, 0x5C, 0x68, 0x5C, 0x68, 0x5C, 0x68, 0x5C, 0x68, 0x5B, 0x69, 0x5C, 0x66, 0x5A, 0x67, 0x5C, 0x69, 0x5C, 0x68, 0x5B, 0x65, 0x59, 0x65, 0x59, 0x65, 0x5A, 0x65, 0x5C, 0x65, 0x59, 0x67, 0x58, 0x65, 0x59, 0x66, 0x59, 0x65, 0x5A, 0x66, 0x5A, 0x66, 0x5A, 0x67, 0x5B, 0x67, 0x5A, 0x69, 0x5B, 0x65, 0x59, 0x67, 0x5B, 0x68, 0x5C, 0x66, 0x5A, 0x63, 0x57, 0x61, 0x55, 0x61, 0x56, 0x60, 0x58, 0x63, 0x5A, 0x66, 0x5A, 0x67, 0x5A, 0x65, 0x5A, 0x65, 0x57, 0x64, 0x57, 0x65, 0x58, 0x64, 0x58, 0x65, 0x59, 0x67, 0x5B, 0x62, 0x54, 0x66, 0x59, 0x63, 0x57, 0x63, 0x58, 0x62, 0x58, 0x62, 0x56, 0x65, 0x59, 0x65, 0x5A, 0x64, 0x5A, 0x64, 0x57, 0x60, 0x55, 0x64, 0x5A, 0x64, 0x58, 0x63, 0x58, 0x5E, 0x52, 0x62, 0x58, 0x65, 0x58, 0x65, 0x57, 0x62, 0x55, 0x61, 0x56, 0x5F, 0x55, 0x5E, 0x53, 0x41, 0x37, 0x27, 0x26, 0x27, 0x2A, 0x28, 0x2C, 0x2A, 0x30, 0x2B, 0x2F, 0x29, 0x2D, 0x28, 0x2E, 0x30, 0x37, 0x29, 0x2D, 0x2B, 0x30, 0x24, 0x29, 0x2E, 0x33, 0x26, 0x29, 0x23, 0x27, 0x2E, 0x32, 0x27, 0x2D, 0x2C, 0x30, 0x24, 0x27, 0x2F, 0x35, 0x23, 0x26, 0x31, 0x38, 0x2A, 0x2B, 0x26, 0x2A, 0x26, 0x28, 0x2C, 0x33, 0x29, 0x2A, 0x22, 0x27, 0x2D, 0x30, 0x25, 0x2A, 0x28, 0x29, 0x25, 0x2B, 0x26, 0x29, 0x26, 0x2B, 0x2A, 0x2E, 0x25, 0x28, 0x28, 0x2D, 0x29, 0x2F, 0x2E, 0x34, 0x2E, 0x34, 0x27, 0x2A, 0x22, 0x26, 0x28, 0x2C, 0x23, 0x27, 0x2A, 0x2E
    },

    {
        0x1A, 0x10, 0x18, 0x0F, 0x1A, 0x11, 0x21, 0x16, 0x32, 0x1F, 0x4D, 0x2A, 0x67, 0x34, 0x73, 0x38, 0x78, 0x3A, 0x78, 0x3A, 0x72, 0x37, 0x58, 0x29, 0x37, 0x1D, 0x27, 0x17, 0x20, 0x14, 0x1D, 0x13, 0x1B, 0x11, 0x1A, 0x11, 0x19, 0x11, 0x18, 0x10, 0x17, 0x10, 0x17, 0x10, 0x16, 0x10, 0x16, 0x0F, 0x16, 0x0F, 0x16, 0x10, 0x17, 0x10, 0x17, 0x10, 0x15, 0x0F, 0x16, 0x0F, 0x16, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x16, 0x10, 0x16, 0x10, 0x17, 0x11, 0x17, 0x10, 0x17, 0x11, 0x17, 0x11, 0x18, 0x11, 0x1B, 0x15, 0x29, 0x22, 0x49, 0x3C, 0x78, 0x59, 0x94, 0x6B, 0x9E, 0x70, 0xA3, 0x73, 0xA7, 0x76, 0xAA, 0x78, 0xAC, 0x79, 0xAE, 0x7A, 0xAD, 0x7A, 0xAB, 0x76, 0x94, 0x5E, 0x5E, 0x3A, 0x37, 0x24, 0x2B, 0x1D, 0x24, 0x19, 0x21, 0x17, 0x1F, 0x15, 0x1B, 0x14, 0x1A, 0x12, 0x1C, 0x15, 0x24, 0x1C, 0x3E, 0x34, 0x77, 0x58, 0x96, 0x68, 0x9F, 0x6F, 0xA9, 0x73, 0xAC, 0x77, 0xAD, 0x77, 0xB0, 0x79, 0xB0, 0x7A, 0xB3, 0x7B, 0xB2, 0x7A, 0xB5, 0x7B, 0xB3, 0x7A, 0xB3, 0x7B, 0xB6, 0x7C, 0xB2, 0x7A, 0xAD, 0x77, 0x9B, 0x65, 0x71, 0x45, 0x40, 0x29, 0x2C, 0x1E, 0x25, 0x19, 0x1F, 0x16, 0x1D, 0x14, 0x1A, 0x12, 0x19, 0x12, 0x19, 0x12, 0x1F, 0x19, 0x38, 0x30, 0x6B, 0x55, 0x9D, 0x72, 0xAD, 0x7B, 0xB3, 0x80, 0xBB, 0x84, 0xBC, 0x86, 0xBB, 0x86, 0xBA, 0x86, 0xBD, 0x86, 0xBF, 0x87, 0xBC, 0x85, 0xBD, 0x85, 0xB9, 0x83, 0xB5, 0x80, 0xA4, 0x6B, 0x61, 0x3D, 0x31, 0x20, 0x23, 0x18, 0x1C, 0x14, 0x18, 0x11, 0x17, 0x10, 0x16, 0x10, 0x17, 0x10, 0x16, 0x10, 0x16, 0x11, 0x19, 0x1A, 0x21, 0x2B, 0x23, 0x27, 0x1B, 0x18, 0x17, 0x13, 0x17, 0x11, 0x16, 0x0F, 0x16, 0x10, 0x17, 0x10, 0x16, 0x0F, 0x16, 0x0F, 0x17, 0x12, 0x1F, 0x19, 0x2A, 0x20, 0x30, 0x24, 0x32, 0x24, 0x33, 0x25, 0x32, 0x25, 0x32, 0x25, 0x32, 0x24, 0x32, 0x26, 0x36, 0x27, 0x38, 0x29, 0x36, 0x28, 0x35, 0x26, 0x34, 0x25, 0x34, 0x26, 0x34, 0x25, 0x35, 0x25, 0x33, 0x26, 0x34, 0x26, 0x30, 0x20, 0x22, 0x17, 0x1A, 0x12, 0x19, 0x11, 0x1A, 0x12, 0x1B, 0x12, 0x19, 0x11, 0x18, 0x11, 0x1B, 0x12, 0x35, 0x1B, 0x53, 0x21, 0x5E, 0x24, 0x61, 0x24, 0x49, 0x1D, 0x2F, 0x19, 0x45, 0x1E, 0x59, 0x21, 0x5D, 0x22, 0x60, 0x22, 0x65, 0x24, 0x64, 0x24, 0x64, 0x24, 0x65, 0x24, 0x65, 0x24, 0x65, 0x24, 0x63, 0x23, 0x63, 0x23, 0x62, 0x24, 0x62, 0x24, 0x65, 0x25, 0x65, 0x24, 0x62, 0x23, 0x62, 0x23, 0x62, 0x22, 0x64, 0x23, 0x63, 0x23, 0x63, 0x23, 0x62, 0x23, 0x64, 0x24, 0x6A, 0x26, 0x64, 0x23, 0x5F, 0x22, 0x63, 0x23, 0x63, 0x24, 0x66, 0x25, 0x60, 0x22, 0x60, 0x22, 0x63, 0x22, 0x60, 0x22, 0x62, 0x23, 0x64, 0x23, 0x63, 0x23, 0x64, 0x23, 0x60, 0x22, 0x61, 0x23, 0x62, 0x24, 0x66, 0x27, 0x63, 0x24, 0x61, 0x23, 0x5F, 0x22, 0x5E, 0x22, 0x60, 0x22, 0x59, 0x21, 0x5D, 0x21, 0x5F, 0x22, 0x5B, 0x21, 0x5E, 0x21, 0x5B, 0x20, 0x5B, 0x21, 0x5C, 0x21, 0x5D, 0x21, 0x59, 0x20, 0x59, 0x20, 0x5A, 0x20, 0x5C, 0x21, 0x5E, 0x22, 0x5A, 0x21, 0x5A, 0x20, 0x5C, 0x21, 0x5C, 0x20, 0x5C, 0x21, 0x5B, 0x21, 0x5C, 0x21, 0x5D, 0x21, 0x5E, 0x22, 0x5E, 0x22, 0x5D, 0x21, 0x5E, 0x22, 0x5B, 0x20, 0x59, 0x20, 0x58, 0x20, 0x5A, 0x20, 0x5A, 0x20, 0x5B, 0x20, 0x5A, 0x20, 0x5C, 0x22, 0x5A, 0x20, 0x59, 0x1F, 0x59, 0x20, 0x5A, 0x20, 0x5A, 0x21, 0x5D, 0x21, 0x5B, 0x22, 0x5C, 0x21, 0x5B, 0x21, 0x58, 0x21, 0x59, 0x20, 0x59, 0x21, 0x5D, 0x21, 0x5D, 0x21, 0x5D, 0x22, 0x5D, 0x22, 0x59, 0x21, 0x59, 0x20, 0x5C, 0x21, 0x59, 0x20, 0x59, 0x20, 0x57, 0x20, 0x58, 0x20, 0x57, 0x1F, 0x56, 0x1F, 0x57, 0x20, 0x57, 0x20, 0x56, 0x1F, 0x56, 0x1F, 0x41, 0x1B, 0x31, 0x19, 0x2C, 0x1A, 0x39, 0x1E, 0x31, 0x1A, 0x28, 0x18, 0x2F, 0x19, 0x31, 0x1B, 0x30, 0x1A, 0x25, 0x17, 0x2E, 0x19, 0x27, 0x17, 0x2E, 0x1A, 0x24, 0x15, 0x2B, 0x19, 0x2F, 0x1A, 0x2E, 0x1A, 0x2E, 0x19, 0x25, 0x16, 0x2F, 0x1A, 0x26, 0x18, 0x34, 0x1C, 0x2B, 0x17, 0x2E, 0x1A, 0x2C, 0x18, 0x31, 0x1B, 0x2F, 0x1A, 0x29, 0x18, 0x2F, 0x19, 0x2C, 0x19, 0x34, 0x1B, 0x2C, 0x19, 0x31, 0x1A, 0x2D, 0x1A, 0x34, 0x1D, 0x2D, 0x19, 0x34, 0x1C, 0x2F, 0x1A, 0x28, 0x17, 0x2A, 0x19, 0x26, 0x16, 0x28, 0x18, 0x34, 0x1C, 0x30, 0x1C, 0x30, 0x1A
    },

    {
        0x16, 0x18, 0x15, 0x17, 0x19, 0x1B, 0x20, 0x26, 0x30, 0x3A, 0x49, 0x56, 0x61, 0x6A, 0x6B, 0x72, 0x6F, 0x77, 0x6F, 0x77, 0x6A, 0x72, 0x59, 0x5A, 0x3B, 0x38, 0x28, 0x28, 0x20, 0x21, 0x1C, 0x1E, 0x19, 0x1B, 0x17, 0x19, 0x16, 0x19, 0x15, 0x18, 0x13, 0x17, 0x13, 0x16, 0x12, 0x16, 0x12, 0x15, 0x12, 0x15, 0x12, 0x15, 0x12, 0x17, 0x12, 0x16, 0x12, 0x15, 0x11, 0x15, 0x12, 0x15, 0x11, 0x15, 0x12, 0x16, 0x12, 0x16, 0x12, 0x15, 0x12, 0x16, 0x13, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x18, 0x15, 0x1E, 0x1C, 0x32, 0x2B, 0x56, 0x3F, 0x80, 0x4A, 0x94, 0x4D, 0x9A, 0x50, 0x9E, 0x53, 0xA3, 0x54, 0xA5, 0x56, 0xA7, 0x55, 0xA8, 0x55, 0xA6, 0x53, 0xA4, 0x4D, 0x92, 0x39, 0x60, 0x25, 0x37, 0x1D, 0x2A, 0x1B, 0x24, 0x18, 0x21, 0x17, 0x1E, 0x15, 0x1A, 0x14, 0x19, 0x16, 0x1B, 0x1B, 0x20, 0x29, 0x37, 0x4D, 0x6D, 0x6B, 0x8F, 0x77, 0x9B, 0x7D, 0xA0, 0x81, 0xA4, 0x83, 0xA7, 0x86, 0xA7, 0x86, 0xAA, 0x89, 0xAD, 0x8A, 0xAD, 0x8A, 0xAE, 0x88, 0xAC, 0x88, 0xAC, 0x88, 0xAD, 0x85, 0xAA, 0x7F, 0xA2, 0x70, 0x8A, 0x51, 0x59, 0x2F, 0x33, 0x22, 0x27, 0x1C, 0x21, 0x18, 0x1D, 0x16, 0x1B, 0x14, 0x18, 0x14, 0x18, 0x14, 0x19, 0x18, 0x23, 0x25, 0x47, 0x3B, 0x7D, 0x4F, 0x9F, 0x55, 0xA6, 0x57, 0xAD, 0x5B, 0xB3, 0x5D, 0xB6, 0x5D, 0xB5, 0x5C, 0xB4, 0x5D, 0xB4, 0x5E, 0xB6, 0x5B, 0xB1, 0x5B, 0xB4, 0x5A, 0xB1, 0x58, 0xAE, 0x53, 0xA2, 0x3B, 0x63, 0x22, 0x31, 0x19, 0x22, 0x16, 0x1B, 0x13, 0x17, 0x12, 0x17, 0x12, 0x16, 0x12, 0x16, 0x12, 0x15, 0x12, 0x16, 0x13, 0x1A, 0x17, 0x24, 0x19, 0x23, 0x15, 0x1B, 0x13, 0x17, 0x12, 0x16, 0x11, 0x15, 0x12, 0x15, 0x12, 0x16, 0x12, 0x15, 0x12, 0x15, 0x13, 0x18, 0x15, 0x22, 0x1A, 0x2C, 0x1C, 0x30, 0x1D, 0x2F, 0x1D, 0x31, 0x1D, 0x30, 0x1D, 0x30, 0x1D, 0x30, 0x1E, 0x31, 0x20, 0x35, 0x21, 0x35, 0x1F, 0x33, 0x20, 0x33, 0x1E, 0x31, 0x1E, 0x31, 0x1D, 0x31, 0x1E, 0x32, 0x1E, 0x31, 0x1E, 0x32, 0x1E, 0x2F, 0x19, 0x22, 0x15, 0x1A, 0x15, 0x19, 0x15, 0x1A, 0x16, 0x1A, 0x16, 0x19, 0x15, 0x18, 0x17, 0x1A, 0x2B, 0x31, 0x4D, 0x4F, 0x5E, 0x5A, 0x65, 0x5E, 0x51, 0x48, 0x37, 0x2F, 0x43, 0x42, 0x5C, 0x55, 0x63, 0x59, 0x68, 0x5E, 0x6E, 0x61, 0x6D, 0x62, 0x6F, 0x62, 0x70, 0x63, 0x6F, 0x62, 0x6F, 0x62, 0x6C, 0x60, 0x6C, 0x60, 0x6C, 0x60, 0x6D, 0x61, 0x70, 0x64, 0x6F, 0x61, 0x6B, 0x5F, 0x6C, 0x61, 0x6E, 0x60, 0x6D, 0x60, 0x6F, 0x61, 0x6D, 0x60, 0x6B, 0x5E, 0x6C, 0x61, 0x74, 0x66, 0x6D, 0x5F, 0x69, 0x5C, 0x6C, 0x5F, 0x6E, 0x63, 0x70, 0x63, 0x6D, 0x5D, 0x6C, 0x5C, 0x6F, 0x60, 0x6C, 0x5D, 0x6C, 0x60, 0x6C, 0x5F, 0x6F, 0x62, 0x6E, 0x61, 0x6B, 0x5E, 0x6D, 0x60, 0x6D, 0x62, 0x6E, 0x65, 0x6B, 0x5F, 0x6D, 0x61, 0x68, 0x5D, 0x69, 0x5C, 0x6A, 0x5C, 0x63, 0x57, 0x66, 0x5A, 0x68, 0x5C, 0x68, 0x5B, 0x6A, 0x5B, 0x68, 0x59, 0x65, 0x5A, 0x68, 0x5A, 0x68, 0x5B, 0x64, 0x57, 0x63, 0x57, 0x63, 0x58, 0x65, 0x5A, 0x69, 0x5C, 0x65, 0x59, 0x63, 0x57, 0x65, 0x5A, 0x64, 0x58, 0x65, 0x5A, 0x65, 0x59, 0x66, 0x5B, 0x68, 0x5C, 0x68, 0x5B, 0x68, 0x5B, 0x66, 0x5A, 0x68, 0x5A, 0x65, 0x58, 0x64, 0x59, 0x61, 0x56, 0x62, 0x57, 0x64, 0x57, 0x63, 0x57, 0x65, 0x59, 0x68, 0x5A, 0x63, 0x56, 0x63, 0x57, 0x65, 0x59, 0x64, 0x56, 0x63, 0x58, 0x64, 0x58, 0x64, 0x5A, 0x66, 0x5A, 0x65, 0x59, 0x61, 0x56, 0x64, 0x57, 0x63, 0x57, 0x66, 0x59, 0x67, 0x5A, 0x67, 0x5B, 0x66, 0x5A, 0x62, 0x57, 0x63, 0x58, 0x63, 0x58, 0x62, 0x57, 0x60, 0x55, 0x61, 0x58, 0x61, 0x56, 0x60, 0x54, 0x5F, 0x54, 0x60, 0x56, 0x61, 0x55, 0x60, 0x55, 0x5D, 0x51, 0x41, 0x3A, 0x2F, 0x2E, 0x2A, 0x2F, 0x33, 0x38, 0x28, 0x2A, 0x23, 0x28, 0x28, 0x2A, 0x2A, 0x30, 0x29, 0x2B, 0x21, 0x24, 0x26, 0x29, 0x24, 0x28, 0x27, 0x2B, 0x24, 0x25, 0x27, 0x2C, 0x29, 0x2C, 0x29, 0x2F, 0x2A, 0x2E, 0x22, 0x25, 0x29, 0x2C, 0x24, 0x29, 0x2D, 0x31, 0x27, 0x2A, 0x2B, 0x31, 0x28, 0x29, 0x2A, 0x30, 0x2B, 0x2F, 0x26, 0x2B, 0x2A, 0x2C, 0x28, 0x2D, 0x2D, 0x31, 0x27, 0x2E, 0x2A, 0x2C, 0x26, 0x2C, 0x2C, 0x30, 0x27, 0x29, 0x2E, 0x32, 0x28, 0x28, 0x23, 0x26, 0x25, 0x28, 0x21, 0x24, 0x26, 0x2A, 0x2C, 0x33, 0x2A, 0x2F, 0x29, 0x2C
    },

    {
        0x18, 0x10, 0x19, 0x10, 0x21, 0x16, 0x2F, 0x1E, 0x49, 0x29, 0x64, 0x33, 0x72, 0x38, 0x77, 0x3A, 0x7C, 0x3C, 0x7E, 0x3D, 0x7C, 0x3D, 0x75, 0x38, 0x5F, 0x2D, 0x3D, 0x1F, 0x29, 0x17, 0x22, 0x15, 0x1F, 0x13, 0x1C, 0x12, 0x1A, 0x11, 0x19, 0x11, 0x18, 0x10, 0x17, 0x10, 0x17, 0x10, 0x16, 0x0F, 0x15, 0x0F, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x17, 0x11, 0x18, 0x11, 0x17, 0x11, 0x17, 0x11, 0x17, 0x11, 0x17, 0x11, 0x17, 0x11, 0x17, 0x10, 0x18, 0x11, 0x1C, 0x15, 0x27, 0x21, 0x44, 0x37, 0x71, 0x56, 0x93, 0x6A, 0x9C, 0x6F, 0xA3, 0x75, 0xA9, 0x78, 0xAB, 0x79, 0xAD, 0x7A, 0xB0, 0x7C, 0xB0, 0x7D, 0xB1, 0x7D, 0xB0, 0x7B, 0xAD, 0x77, 0x9A, 0x64, 0x66, 0x3F, 0x3B, 0x27, 0x2C, 0x1E, 0x26, 0x1A, 0x21, 0x17, 0x1D, 0x15, 0x1A, 0x13, 0x19, 0x12, 0x1A, 0x14, 0x20, 0x1A, 0x3A, 0x31, 0x72, 0x56, 0x94, 0x68, 0xA1, 0x6E, 0xA6, 0x73, 0xA9, 0x75, 0xAF, 0x78, 0xB1, 0x7A, 0xB3, 0x7B, 0xB2, 0x7B, 0xB3, 0x7B, 0xB1, 0x7A, 0xB2, 0x7A, 0xB4, 0x7B, 0xB0, 0x77, 0x9E, 0x67, 0x78, 0x4A, 0x44, 0x2B, 0x2D, 0x1E, 0x25, 0x19, 0x20, 0x17, 0x1D, 0x15, 0x1B, 0x13, 0x19, 0x12, 0x18, 0x12, 0x1D, 0x17, 0x32, 0x2C, 0x68, 0x53, 0x9A, 0x72, 0xAD, 0x7C, 0xB5, 0x81, 0xB7, 0x83, 0xBB, 0x86, 0xC0, 0x89, 0xC1, 0x89, 0xBF, 0x87, 0xBE, 0x87, 0xC0, 0x88, 0xBD, 0x87, 0xBB, 0x86, 0xBD, 0x86, 0xBB, 0x86, 0xBA, 0x82, 0xAD, 0x73, 0x6A, 0x41, 0x33, 0x22, 0x23, 0x18, 0x1C, 0x13, 0x19, 0x11, 0x17, 0x10, 0x16, 0x10, 0x17, 0x11, 0x1A, 0x1A, 0x22, 0x2C, 0x2B, 0x3C, 0x2E, 0x3F, 0x27, 0x2E, 0x1C, 0x1B, 0x18, 0x14, 0x17, 0x11, 0x16, 0x10, 0x17, 0x10, 0x16, 0x0F, 0x18, 0x12, 0x1F, 0x18, 0x29, 0x1F, 0x2E, 0x22, 0x31, 0x24, 0x32, 0x25, 0x31, 0x25, 0x33, 0x26, 0x34, 0x25, 0x32, 0x25, 0x32, 0x25, 0x37, 0x29, 0x3A, 0x2A, 0x37, 0x27, 0x34, 0x27, 0x35, 0x27, 0x34, 0x26, 0x34, 0x26, 0x33, 0x25, 0x32, 0x25, 0x33, 0x25, 0x33, 0x25, 0x2F, 0x20, 0x23, 0x18, 0x1C, 0x13, 0x1B, 0x12, 0x1A, 0x11, 0x1A, 0x12, 0x1B, 0x12, 0x1A, 0x12, 0x1C, 0x13, 0x31, 0x1A, 0x52, 0x21, 0x5F, 0x24, 0x63, 0x24, 0x50, 0x1F, 0x32, 0x19, 0x43, 0x1E, 0x57, 0x21, 0x5E, 0x23, 0x65, 0x24, 0x64, 0x24, 0x64, 0x24, 0x66, 0x26, 0x66, 0x25, 0x64, 0x24, 0x61, 0x23, 0x63, 0x25, 0x67, 0x24, 0x62, 0x24, 0x65, 0x25, 0x64, 0x24, 0x62, 0x24, 0x62, 0x23, 0x64, 0x23, 0x63, 0x24, 0x63, 0x22, 0x62, 0x23, 0x5E, 0x22, 0x61, 0x22, 0x60, 0x22, 0x63, 0x23, 0x62, 0x23, 0x61, 0x23, 0x67, 0x25, 0x68, 0x25, 0x61, 0x23, 0x60, 0x21, 0x61, 0x22, 0x5E, 0x22, 0x61, 0x23, 0x60, 0x23, 0x63, 0x23, 0x61, 0x23, 0x62, 0x24, 0x64, 0x26, 0x62, 0x25, 0x62, 0x25, 0x65, 0x26, 0x63, 0x23, 0x5E, 0x22, 0x5E, 0x22, 0x5D, 0x21, 0x5C, 0x21, 0x5B, 0x21, 0x61, 0x23, 0x5E, 0x21, 0x5E, 0x22, 0x5F, 0x22, 0x5F, 0x23, 0x5F, 0x23, 0x60, 0x22, 0x5B, 0x21, 0x5A, 0x21, 0x5A, 0x20, 0x5C, 0x22, 0x5D, 0x21, 0x5B, 0x21, 0x59, 0x20, 0x5B, 0x21, 0x5A, 0x20, 0x5B, 0x20, 0x5C, 0x21, 0x5C, 0x21, 0x60, 0x22, 0x5E, 0x22, 0x5C, 0x21, 0x5A, 0x20, 0x5A, 0x20, 0x5A, 0x20, 0x58, 0x1F, 0x57, 0x1F, 0x5A, 0x1F, 0x5A, 0x21, 0x5A, 0x20, 0x5A, 0x21, 0x5B, 0x21, 0x59, 0x20, 0x5A, 0x20, 0x57, 0x20, 0x57, 0x20, 0x5B, 0x21, 0x56, 0x20, 0x5B, 0x21, 0x59, 0x21, 0x5D, 0x22, 0x5B, 0x21, 0x5D, 0x22, 0x5C, 0x21, 0x58, 0x20, 0x5D, 0x22, 0x5C, 0x21, 0x5A, 0x22, 0x5A, 0x21, 0x5A, 0x21, 0x59, 0x21, 0x56, 0x20, 0x57, 0x20, 0x58, 0x21, 0x56, 0x1F, 0x55, 0x1F, 0x57, 0x1F, 0x55, 0x1F, 0x56, 0x1F, 0x56, 0x1F, 0x52, 0x1E, 0x3C, 0x1A, 0x2B, 0x18, 0x2E, 0x1B, 0x2F, 0x19, 0x26, 0x16, 0x28, 0x18, 0x2C, 0x19, 0x32, 0x1C, 0x2E, 0x1A, 0x28, 0x19, 0x31, 0x1B, 0x2F, 0x1B, 0x34, 0x1C, 0x2C, 0x19, 0x2E, 0x1B, 0x3A, 0x1F, 0x2F, 0x1A, 0x30, 0x1A, 0x27, 0x17, 0x32, 0x1B, 0x29, 0x18, 0x31, 0x1B, 0x2A, 0x18, 0x2E, 0x1B, 0x29, 0x17, 0x31, 0x1C, 0x2C, 0x19, 0x29, 0x18, 0x2A, 0x18, 0x2B, 0x19, 0x29, 0x17, 0x2D, 0x1A, 0x26, 0x16, 0x29, 0x18, 0x2F, 0x1A, 0x26, 0x17, 0x28, 0x18, 0x24, 0x15, 0x2E, 0x1A, 0x2E, 0x1A, 0x2E, 0x19, 0x2A, 0x18, 0x2B, 0x18, 0x25, 0x16, 0x28, 0x17
    },

    {
        0x15, 0x17, 0x18, 0x1A, 0x1F, 0x24, 0x2E, 0x37, 0x44, 0x52, 0x5E, 0x68, 0x69, 0x71, 0x6E, 0x77, 0x72, 0x7A, 0x73, 0x7A, 0x72, 0x7A, 0x6C, 0x73, 0x5D, 0x5F, 0x41, 0x40, 0x2A, 0x2B, 0x22, 0x24, 0x1D, 0x1F, 0x1A, 0x1D, 0x18, 0x1A, 0x16, 0x19, 0x14, 0x18, 0x14, 0x17, 0x12, 0x16, 0x12, 0x15, 0x11, 0x14, 0x11, 0x15, 0x12, 0x15, 0x12, 0x15, 0x12, 0x15, 0x13, 0x16, 0x13, 0x16, 0x13, 0x17, 0x14, 0x18, 0x13, 0x17, 0x14, 0x17, 0x12, 0x17, 0x12, 0x16, 0x13, 0x17, 0x12, 0x16, 0x13, 0x17, 0x15, 0x1E, 0x1C, 0x2F, 0x29, 0x51, 0x3C, 0x7B, 0x49, 0x94, 0x4E, 0x9B, 0x50, 0x9E, 0x53, 0xA2, 0x55, 0xA5, 0x55, 0xA7, 0x56, 0xA9, 0x57, 0xA8, 0x57, 0xAA, 0x56, 0xA8, 0x54, 0xA5, 0x4F, 0x95, 0x3C, 0x67, 0x27, 0x3B, 0x1E, 0x2C, 0x1B, 0x25, 0x18, 0x20, 0x16, 0x1C, 0x15, 0x1A, 0x14, 0x18, 0x15, 0x19, 0x19, 0x1E, 0x27, 0x34, 0x48, 0x69, 0x68, 0x8D, 0x77, 0x9A, 0x7D, 0xA0, 0x80, 0xA4, 0x84, 0xA9, 0x88, 0xAA, 0x8A, 0xAB, 0x88, 0xAA, 0x88, 0xAC, 0x88, 0xAB, 0x87, 0xAD, 0x87, 0xAD, 0x81, 0xA4, 0x71, 0x8C, 0x53, 0x5F, 0x31, 0x36, 0x22, 0x27, 0x1D, 0x21, 0x19, 0x1D, 0x16, 0x1B, 0x15, 0x19, 0x13, 0x18, 0x14, 0x19, 0x16, 0x20, 0x22, 0x40, 0x3A, 0x79, 0x4E, 0x9F, 0x56, 0xA9, 0x59, 0xB0, 0x5A, 0xB0, 0x5C, 0xB5, 0x5E, 0xB9, 0x5E, 0xB7, 0x5E, 0xB6, 0x5D, 0xB6, 0x5D, 0xB6, 0x5D, 0xB3, 0x5C, 0xB4, 0x5B, 0xB3, 0x5B, 0xB3, 0x5A, 0xB0, 0x56, 0xA9, 0x3E, 0x69, 0x23, 0x33, 0x1A, 0x23, 0x16, 0x1B, 0x14, 0x18, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x14, 0x1C, 0x18, 0x25, 0x1C, 0x2B, 0x1D, 0x2C, 0x1A, 0x26, 0x16, 0x1C, 0x13, 0x17, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x18, 0x16, 0x22, 0x19, 0x2A, 0x1B, 0x2C, 0x1C, 0x2F, 0x1C, 0x2F, 0x1D, 0x30, 0x1D, 0x30, 0x1D, 0x31, 0x1D, 0x30, 0x1D, 0x30, 0x20, 0x37, 0x22, 0x37, 0x20, 0x34, 0x1F, 0x32, 0x1E, 0x33, 0x1E, 0x31, 0x1E, 0x31, 0x1E, 0x31, 0x1E, 0x31, 0x1F, 0x31, 0x1E, 0x31, 0x1D, 0x2E, 0x19, 0x22, 0x16, 0x1C, 0x15, 0x19, 0x15, 0x18, 0x16, 0x19, 0x16, 0x19, 0x16, 0x19, 0x17, 0x19, 0x28, 0x2D, 0x4D, 0x4D, 0x62, 0x5E, 0x69, 0x62, 0x59, 0x4F, 0x37, 0x31, 0x40, 0x3F, 0x58, 0x53, 0x63, 0x5B, 0x6C, 0x63, 0x6E, 0x61, 0x6D, 0x61, 0x6F, 0x65, 0x6E, 0x63, 0x6D, 0x60, 0x68, 0x5D, 0x6C, 0x61, 0x6D, 0x61, 0x6D, 0x61, 0x70, 0x64, 0x6C, 0x61, 0x6C, 0x5F, 0x6E, 0x60, 0x6D, 0x60, 0x6D, 0x63, 0x6B, 0x5F, 0x6C, 0x60, 0x68, 0x5B, 0x6A, 0x5E, 0x6A, 0x5D, 0x6D, 0x60, 0x6E, 0x60, 0x6E, 0x61, 0x72, 0x64, 0x71, 0x62, 0x6D, 0x5E, 0x6B, 0x5D, 0x6B, 0x5F, 0x69, 0x5D, 0x6A, 0x5D, 0x6C, 0x5E, 0x6E, 0x61, 0x6C, 0x5E, 0x6C, 0x61, 0x6D, 0x63, 0x6C, 0x60, 0x6D, 0x5F, 0x6E, 0x62, 0x6D, 0x61, 0x67, 0x5A, 0x67, 0x5C, 0x67, 0x5A, 0x68, 0x59, 0x65, 0x59, 0x6B, 0x5E, 0x6A, 0x5C, 0x67, 0x5C, 0x6A, 0x5D, 0x6B, 0x5D, 0x6A, 0x5F, 0x6A, 0x5E, 0x64, 0x58, 0x64, 0x5A, 0x65, 0x58, 0x68, 0x5C, 0x67, 0x59, 0x65, 0x59, 0x64, 0x57, 0x64, 0x58, 0x64, 0x59, 0x63, 0x57, 0x65, 0x5A, 0x65, 0x5A, 0x69, 0x5D, 0x67, 0x5C, 0x64, 0x59, 0x63, 0x58, 0x64, 0x57, 0x63, 0x56, 0x62, 0x55, 0x61, 0x56, 0x64, 0x58, 0x65, 0x59, 0x64, 0x57, 0x64, 0x57, 0x65, 0x58, 0x63, 0x56, 0x64, 0x57, 0x63, 0x56, 0x62, 0x56, 0x65, 0x57, 0x61, 0x53, 0x63, 0x57, 0x62, 0x56, 0x66, 0x59, 0x65, 0x57, 0x66, 0x5C, 0x67, 0x59, 0x62, 0x55, 0x65, 0x5A, 0x64, 0x59, 0x65, 0x59, 0x62, 0x58, 0x62, 0x58, 0x62, 0x56, 0x5F, 0x53, 0x60, 0x54, 0x60, 0x55, 0x5E, 0x53, 0x5D, 0x54, 0x60, 0x55, 0x5F, 0x54, 0x5F, 0x54, 0x5F, 0x54, 0x59, 0x4D, 0x3E, 0x37, 0x2A, 0x27, 0x2B, 0x2F, 0x29, 0x2A, 0x22, 0x24, 0x27, 0x2B, 0x2A, 0x2C, 0x2B, 0x31, 0x29, 0x2D, 0x25, 0x29, 0x2B, 0x30, 0x28, 0x2E, 0x2E, 0x31, 0x25, 0x29, 0x2A, 0x32, 0x32, 0x34, 0x29, 0x2C, 0x29, 0x2C, 0x23, 0x25, 0x2D, 0x30, 0x24, 0x26, 0x2A, 0x2D, 0x25, 0x25, 0x29, 0x2D, 0x23, 0x24, 0x2B, 0x30, 0x25, 0x26, 0x24, 0x29, 0x25, 0x25, 0x27, 0x2C, 0x24, 0x26, 0x29, 0x2D, 0x21, 0x23, 0x28, 0x2C, 0x2A, 0x2B, 0x24, 0x26, 0x26, 0x29, 0x24, 0x26, 0x2C, 0x32, 0x2C, 0x2F, 0x2A, 0x2F, 0x26, 0x29, 0x26, 0x28, 0x22, 0x26, 0x24, 0x26
    },

    {
        0x1A, 0x11, 0x1F, 0x14, 0x2E, 0x1D, 0x46, 0x28, 0x61, 0x33, 0x70, 0x37, 0x76, 0x3A, 0x7B, 0x3B, 0x7D, 0x3D, 0x7F, 0x3D, 0x7F, 0x3D, 0x7C, 0x3C, 0x77, 0x38, 0x65, 0x2F, 0x44, 0x22, 0x2D, 0x19, 0x24, 0x15, 0x20, 0x14, 0x1D, 0x13, 0x1B, 0x12, 0x19, 0x11, 0x19, 0x11, 0x17, 0x10, 0x16, 0x0F, 0x16, 0x0F, 0x16, 0x0F, 0x16, 0x10, 0x16, 0x10, 0x17, 0x11, 0x19, 0x12, 0x1A, 0x12, 0x1A, 0x12, 0x19, 0x12, 0x1A, 0x12, 0x18, 0x11, 0x18, 0x11, 0x18, 0x12, 0x18, 0x11, 0x18, 0x11, 0x1A, 0x14, 0x26, 0x1F, 0x42, 0x36, 0x6F, 0x54, 0x90, 0x67, 0x9C, 0x6F, 0xA3, 0x73, 0xA8, 0x76, 0xAA, 0x77, 0xAE, 0x7A, 0xAF, 0x7C, 0xB2, 0x7E, 0xB2, 0x7F, 0xB2, 0x7F, 0xB3, 0x7E, 0xB0, 0x7C, 0xAB, 0x78, 0x9D, 0x67, 0x6E, 0x45, 0x40, 0x2A, 0x2D, 0x1F, 0x26, 0x1A, 0x20, 0x18, 0x1E, 0x15, 0x1A, 0x13, 0x18, 0x12, 0x1A, 0x14, 0x21, 0x19, 0x36, 0x2C, 0x69, 0x4F, 0x91, 0x65, 0xA0, 0x6D, 0xA7, 0x72, 0xAA, 0x74, 0xAF, 0x78, 0xB3, 0x7C, 0xB3, 0x7C, 0xB1, 0x7B, 0xB3, 0x7B, 0xB2, 0x79, 0xAE, 0x77, 0xA1, 0x69, 0x7A, 0x4B, 0x48, 0x2E, 0x2E, 0x1F, 0x25, 0x1A, 0x21, 0x17, 0x1E, 0x14, 0x1A, 0x13, 0x19, 0x11, 0x18, 0x12, 0x1B, 0x16, 0x30, 0x2A, 0x62, 0x4F, 0x97, 0x6E, 0xAD, 0x7B, 0xB4, 0x81, 0xBA, 0x84, 0xBC, 0x86, 0xBE, 0x88, 0xC0, 0x88, 0xBD, 0x87, 0xBD, 0x85, 0xBD, 0x86, 0xBB, 0x87, 0xBD, 0x87, 0xBC, 0x86, 0xBC, 0x87, 0xBC, 0x86, 0xBB, 0x84, 0xB7, 0x82, 0xAD, 0x73, 0x6D, 0x44, 0x36, 0x23, 0x23, 0x18, 0x1C, 0x14, 0x19, 0x11, 0x18, 0x12, 0x19, 0x18, 0x22, 0x2C, 0x2C, 0x3D, 0x2E, 0x42, 0x30, 0x44, 0x30, 0x42, 0x28, 0x31, 0x1E, 0x1D, 0x18, 0x14, 0x17, 0x12, 0x16, 0x10, 0x17, 0x11, 0x1D, 0x17, 0x29, 0x1F, 0x2E, 0x22, 0x30, 0x23, 0x31, 0x24, 0x32, 0x24, 0x33, 0x26, 0x32, 0x26, 0x31, 0x24, 0x32, 0x25, 0x31, 0x25, 0x35, 0x26, 0x36, 0x26, 0x34, 0x26, 0x33, 0x25, 0x33, 0x26, 0x32, 0x25, 0x33, 0x25, 0x33, 0x25, 0x34, 0x26, 0x35, 0x26, 0x32, 0x25, 0x34, 0x26, 0x30, 0x21, 0x24, 0x18, 0x1B, 0x12, 0x19, 0x11, 0x18, 0x10, 0x18, 0x10, 0x18, 0x10, 0x18, 0x10, 0x19, 0x11, 0x2D, 0x18, 0x51, 0x21, 0x5F, 0x24, 0x63, 0x24, 0x4E, 0x1E, 0x31, 0x19, 0x40, 0x1D, 0x56, 0x22, 0x60, 0x23, 0x64, 0x24, 0x62, 0x23, 0x65, 0x24, 0x65, 0x24, 0x61, 0x23, 0x5F, 0x22, 0x60, 0x23, 0x64, 0x23, 0x64, 0x25, 0x67, 0x25, 0x65, 0x24, 0x63, 0x23, 0x65, 0x24, 0x65, 0x23, 0x64, 0x23, 0x62, 0x23, 0x63, 0x24, 0x61, 0x23, 0x61, 0x22, 0x61, 0x22, 0x62, 0x23, 0x64, 0x22, 0x64, 0x24, 0x65, 0x25, 0x64, 0x24, 0x60, 0x22, 0x61, 0x22, 0x61, 0x23, 0x62, 0x23, 0x60, 0x22, 0x60, 0x22, 0x62, 0x23, 0x66, 0x25, 0x65, 0x24, 0x62, 0x24, 0x62, 0x24, 0x64, 0x25, 0x61, 0x24, 0x5F, 0x22, 0x5C, 0x21, 0x5C, 0x22, 0x5D, 0x21, 0x5D, 0x20, 0x5B, 0x21, 0x5D, 0x22, 0x5E, 0x21, 0x5E, 0x22, 0x61, 0x23, 0x60, 0x22, 0x5F, 0x23, 0x62, 0x23, 0x5E, 0x21, 0x5C, 0x21, 0x5B, 0x20, 0x5E, 0x21, 0x5C, 0x21, 0x59, 0x21, 0x58, 0x20, 0x58, 0x20, 0x5A, 0x20, 0x5A, 0x20, 0x59, 0x20, 0x5C, 0x21, 0x5D, 0x21, 0x5C, 0x21, 0x5B, 0x20, 0x5A, 0x1F, 0x5A, 0x20, 0x56, 0x1E, 0x57, 0x1F, 0x5A, 0x20, 0x5E, 0x21, 0x5E, 0x21, 0x5A, 0x21, 0x5A, 0x21, 0x5A, 0x20, 0x58, 0x20, 0x58, 0x1F, 0x5B, 0x21, 0x5B, 0x21, 0x5C, 0x21, 0x5A, 0x20, 0x5A, 0x20, 0x57, 0x20, 0x58, 0x20, 0x5B, 0x21, 0x5B, 0x21, 0x59, 0x20, 0x5A, 0x21, 0x5B, 0x21, 0x5D, 0x22, 0x5D, 0x21, 0x5A, 0x20, 0x56, 0x20, 0x59, 0x20, 0x54, 0x1F, 0x58, 0x20, 0x54, 0x1F, 0x55, 0x1F, 0x57, 0x20, 0x58, 0x20, 0x56, 0x20, 0x58, 0x20, 0x56, 0x1F, 0x53, 0x1F, 0x43, 0x1E, 0x31, 0x19, 0x34, 0x1C, 0x2F, 0x19, 0x2B, 0x18, 0x31, 0x1D, 0x31, 0x1B, 0x2A, 0x19, 0x2A, 0x18, 0x27, 0x18, 0x2D, 0x18, 0x29, 0x19, 0x2C, 0x19, 0x26, 0x17, 0x2F, 0x1B, 0x29, 0x18, 0x26, 0x17, 0x23, 0x16, 0x28, 0x18, 0x29, 0x17, 0x26, 0x17, 0x2A, 0x18, 0x26, 0x17, 0x2C, 0x19, 0x29, 0x18, 0x2E, 0x1A, 0x2D, 0x1A, 0x30, 0x1B, 0x2F, 0x1B, 0x2C, 0x19, 0x36, 0x1D, 0x31, 0x1B, 0x2C, 0x19, 0x2C, 0x1A, 0x32, 0x1B, 0x30, 0x1B, 0x33, 0x1B, 0x2D, 0x19, 0x37, 0x1D, 0x2F, 0x1A, 0x28, 0x16, 0x29, 0x18, 0x2F, 0x1A, 0x2E, 0x1B, 0x34, 0x1C
    },

    {
        0x18, 0x1B, 0x1E, 0x23, 0x2C, 0x34, 0x42, 0x50, 0x5B, 0x67, 0x67, 0x6F, 0x6C, 0x74, 0x70, 0x78, 0x71, 0x7A, 0x74, 0x7B, 0x75, 0x7B, 0x73, 0x7A, 0x6E, 0x74, 0x61, 0x66, 0x48, 0x46, 0x2E, 0x2E, 0x23, 0x25, 0x1E, 0x20, 0x1B, 0x1D, 0x18, 0x1B, 0x16, 0x19, 0x14, 0x18, 0x14, 0x17, 0x13, 0x16, 0x12, 0x15, 0x12, 0x16, 0x12, 0x16, 0x13, 0x16, 0x14, 0x16, 0x15, 0x19, 0x17, 0x1B, 0x17, 0x1A, 0x16, 0x19, 0x16, 0x1A, 0x15, 0x18, 0x14, 0x18, 0x14, 0x17, 0x12, 0x17, 0x13, 0x17, 0x15, 0x1C, 0x1A, 0x2C, 0x27, 0x4D, 0x3B, 0x7A, 0x48, 0x90, 0x4E, 0x97, 0x4F, 0x9E, 0x52, 0xA1, 0x53, 0xA3, 0x56, 0xA7, 0x57, 0xA8, 0x57, 0xAA, 0x57, 0xAC, 0x57, 0xAB, 0x57, 0xAB, 0x56, 0xA9, 0x55, 0xA6, 0x51, 0x9A, 0x40, 0x6E, 0x2B, 0x41, 0x20, 0x2E, 0x1B, 0x25, 0x18, 0x21, 0x16, 0x1D, 0x15, 0x19, 0x13, 0x18, 0x15, 0x19, 0x19, 0x1F, 0x24, 0x30, 0x42, 0x5E, 0x65, 0x88, 0x75, 0x96, 0x7B, 0x9E, 0x80, 0xA3, 0x83, 0xA8, 0x89, 0xAE, 0x89, 0xAC, 0x89, 0xAD, 0x86, 0xAB, 0x86, 0xA9, 0x80, 0xA2, 0x73, 0x8F, 0x57, 0x62, 0x34, 0x38, 0x23, 0x28, 0x1D, 0x21, 0x19, 0x1E, 0x16, 0x1B, 0x14, 0x19, 0x14, 0x19, 0x14, 0x19, 0x16, 0x1F, 0x21, 0x3E, 0x37, 0x75, 0x4D, 0x9A, 0x54, 0xA8, 0x58, 0xAE, 0x5A, 0xB1, 0x5B, 0xB2, 0x5D, 0xB5, 0x5D, 0xB7, 0x5D, 0xB5, 0x5D, 0xB3, 0x5D, 0xB3, 0x5C, 0xB2, 0x5C, 0xB3, 0x5C, 0xB3, 0x5C, 0xB4, 0x5C, 0xB4, 0x5C, 0xB1, 0x5A, 0xB1, 0x56, 0xA7, 0x40, 0x6E, 0x26, 0x37, 0x1A, 0x23, 0x16, 0x1B, 0x13, 0x17, 0x13, 0x17, 0x14, 0x1A, 0x18, 0x24, 0x1C, 0x2B, 0x1D, 0x2C, 0x1D, 0x2D, 0x1D, 0x2D, 0x1B, 0x27, 0x16, 0x1C, 0x13, 0x17, 0x12, 0x16, 0x12, 0x15, 0x12, 0x18, 0x15, 0x20, 0x1A, 0x2A, 0x1B, 0x2C, 0x1C, 0x2F, 0x1C, 0x2F, 0x1D, 0x30, 0x1D, 0x30, 0x1D, 0x30, 0x1C, 0x2F, 0x1D, 0x30, 0x1D, 0x31, 0x1F, 0x32, 0x1F, 0x32, 0x1E, 0x31, 0x1D, 0x30, 0x1D, 0x32, 0x1C, 0x2F, 0x1D, 0x30, 0x1D, 0x31, 0x1E, 0x32, 0x1F, 0x32, 0x1E, 0x31, 0x1E, 0x32, 0x1D, 0x2F, 0x19, 0x23, 0x16, 0x1B, 0x14, 0x18, 0x13, 0x16, 0x14, 0x17, 0x14, 0x17, 0x14, 0x17, 0x15, 0x18, 0x25, 0x29, 0x4B, 0x4E, 0x60, 0x5C, 0x68, 0x60, 0x59, 0x4F, 0x37, 0x30, 0x3C, 0x3A, 0x56, 0x54, 0x63, 0x5D, 0x69, 0x5F, 0x69, 0x5F, 0x6E, 0x61, 0x6E, 0x61, 0x6B, 0x5E, 0x69, 0x5D, 0x6B, 0x5F, 0x6C, 0x5F, 0x6E, 0x63, 0x70, 0x63, 0x6F, 0x61, 0x6C, 0x5F, 0x6F, 0x63, 0x6F, 0x61, 0x6B, 0x60, 0x6C, 0x60, 0x6D, 0x61, 0x6D, 0x60, 0x6C, 0x5E, 0x6C, 0x60, 0x6D, 0x60, 0x6D, 0x60, 0x6F, 0x61, 0x6F, 0x62, 0x6F, 0x62, 0x6B, 0x5D, 0x69, 0x5D, 0x6C, 0x5E, 0x6E, 0x5E, 0x6C, 0x5E, 0x6A, 0x5E, 0x6D, 0x60, 0x6F, 0x63, 0x6D, 0x62, 0x6E, 0x5F, 0x6B, 0x5F, 0x6E, 0x62, 0x6A, 0x5E, 0x69, 0x5D, 0x66, 0x5A, 0x66, 0x5B, 0x68, 0x5B, 0x68, 0x59, 0x67, 0x5B, 0x66, 0x5A, 0x68, 0x5A, 0x67, 0x5B, 0x69, 0x5E, 0x6A, 0x5C, 0x6A, 0x5D, 0x6B, 0x5E, 0x67, 0x5A, 0x64, 0x59, 0x65, 0x59, 0x67, 0x5A, 0x65, 0x5B, 0x61, 0x57, 0x62, 0x56, 0x64, 0x57, 0x64, 0x56, 0x64, 0x58, 0x61, 0x57, 0x65, 0x5A, 0x68, 0x5B, 0x66, 0x59, 0x65, 0x58, 0x65, 0x59, 0x63, 0x55, 0x60, 0x54, 0x63, 0x55, 0x65, 0x58, 0x68, 0x5B, 0x69, 0x5B, 0x63, 0x57, 0x65, 0x59, 0x66, 0x57, 0x63, 0x57, 0x64, 0x57, 0x65, 0x58, 0x67, 0x5B, 0x67, 0x59, 0x63, 0x57, 0x63, 0x57, 0x60, 0x55, 0x62, 0x57, 0x65, 0x59, 0x64, 0x59, 0x62, 0x57, 0x62, 0x58, 0x66, 0x58, 0x65, 0x59, 0x67, 0x5A, 0x61, 0x56, 0x5F, 0x53, 0x61, 0x55, 0x5F, 0x54, 0x61, 0x55, 0x5E, 0x54, 0x5F, 0x54, 0x61, 0x56, 0x61, 0x56, 0x5F, 0x53, 0x61, 0x55, 0x5F, 0x54, 0x5D, 0x52, 0x44, 0x40, 0x2F, 0x2F, 0x2E, 0x32, 0x2A, 0x2B, 0x25, 0x28, 0x2C, 0x34, 0x29, 0x29, 0x25, 0x28, 0x26, 0x27, 0x23, 0x28, 0x25, 0x27, 0x25, 0x2B, 0x26, 0x28, 0x22, 0x24, 0x2A, 0x2E, 0x24, 0x25, 0x24, 0x26, 0x22, 0x25, 0x26, 0x2A, 0x26, 0x27, 0x24, 0x27, 0x27, 0x2A, 0x26, 0x2B, 0x27, 0x2C, 0x27, 0x2C, 0x2A, 0x2E, 0x2B, 0x32, 0x2D, 0x31, 0x2E, 0x32, 0x29, 0x2E, 0x32, 0x38, 0x2B, 0x2E, 0x29, 0x2C, 0x29, 0x2D, 0x2E, 0x31, 0x2B, 0x2D, 0x2D, 0x30, 0x2A, 0x2F, 0x30, 0x35, 0x27, 0x2A, 0x21, 0x22, 0x27, 0x2C, 0x2B, 0x2F, 0x2B, 0x30, 0x2F, 0x33
    },

    {
        0x1F, 0x15, 0x2C, 0x1B, 0x44, 0x27, 0x60, 0x31, 0x6E, 0x37, 0x76, 0x3B, 0x79, 0x3B, 0x7C, 0x3C, 0x7E, 0x3D, 0x7F, 0x3E, 0x80, 0x3F, 0x80, 0x3E, 0x7F, 0x3E, 0x79, 0x3A, 0x6B, 0x32, 0x4B, 0x25, 0x2F, 0x1A, 0x25, 0x17, 0x21, 0x15, 0x1D, 0x13, 0x1B, 0x11, 0x19, 0x11, 0x18, 0x10, 0x17, 0x10, 0x17, 0x10, 0x16, 0x10, 0x17, 0x10, 0x19, 0x12, 0x1D, 0x15, 0x21, 0x17, 0x20, 0x17, 0x1F, 0x15, 0x1E, 0x15, 0x1D, 0x14, 0x1B, 0x13, 0x1A, 0x12, 0x19, 0x12, 0x18, 0x12, 0x1A, 0x14, 0x25, 0x1E, 0x3E, 0x34, 0x69, 0x50, 0x8D, 0x66, 0x9C, 0x6F, 0xA1, 0x73, 0xA7, 0x76, 0xAA, 0x78, 0xAC, 0x79, 0xAF, 0x7C, 0xB3, 0x7E, 0xB3, 0x7E, 0xB3, 0x7F, 0xB3, 0x7E, 0xB2, 0x7F, 0xB3, 0x7F, 0xB5, 0x7F, 0xB1, 0x7B, 0xA5, 0x6E, 0x7A, 0x4C, 0x45, 0x2D, 0x2F, 0x20, 0x27, 0x1B, 0x21, 0x17, 0x1E, 0x15, 0x1B, 0x13, 0x19, 0x12, 0x1B, 0x14, 0x20, 0x18, 0x2F, 0x27, 0x5D, 0x4A, 0x8F, 0x65, 0x9F, 0x6F, 0xA5, 0x71, 0xAA, 0x74, 0xAF, 0x79, 0xB4, 0x7C, 0xB4, 0x7E, 0xB3, 0x7C, 0xAF, 0x78, 0xA2, 0x6B, 0x80, 0x50, 0x49, 0x2F, 0x2F, 0x20, 0x26, 0x1A, 0x21, 0x17, 0x1E, 0x15, 0x1B, 0x13, 0x1A, 0x12, 0x19, 0x12, 0x1B, 0x16, 0x2E, 0x29, 0x5E, 0x4C, 0x96, 0x6E, 0xAA, 0x7A, 0xB3, 0x81, 0xB9, 0x83, 0xBA, 0x83, 0xBB, 0x85, 0xBE, 0x87, 0xBF, 0x88, 0xBD, 0x88, 0xBE, 0x85, 0xBC, 0x86, 0xBE, 0x88, 0xBD, 0x87, 0xBD, 0x87, 0xBD, 0x87, 0xBC, 0x87, 0xBB, 0x84, 0xB9, 0x83, 0xB8, 0x83, 0xAF, 0x77, 0x79, 0x4B, 0x3A, 0x25, 0x25, 0x19, 0x1D, 0x15, 0x1A, 0x19, 0x22, 0x2A, 0x2B, 0x3C, 0x2F, 0x42, 0x30, 0x44, 0x30, 0x45, 0x31, 0x46, 0x30, 0x44, 0x2A, 0x34, 0x1E, 0x1E, 0x19, 0x15, 0x18, 0x13, 0x1D, 0x18, 0x28, 0x1E, 0x2E, 0x21, 0x2F, 0x23, 0x31, 0x24, 0x32, 0x25, 0x32, 0x26, 0x32, 0x25, 0x34, 0x26, 0x33, 0x25, 0x32, 0x25, 0x32, 0x24, 0x31, 0x24, 0x32, 0x25, 0x31, 0x24, 0x32, 0x25, 0x32, 0x25, 0x31, 0x25, 0x32, 0x24, 0x32, 0x25, 0x34, 0x26, 0x35, 0x26, 0x34, 0x26, 0x34, 0x26, 0x32, 0x24, 0x32, 0x24, 0x27, 0x1A, 0x1C, 0x13, 0x19, 0x10, 0x17, 0x0F, 0x16, 0x0F, 0x17, 0x10, 0x18, 0x10, 0x1A, 0x12, 0x2C, 0x1A, 0x51, 0x21, 0x5F, 0x24, 0x5F, 0x22, 0x4F, 0x1D, 0x31, 0x18, 0x3A, 0x1C, 0x55, 0x21, 0x5F, 0x22, 0x61, 0x23, 0x62, 0x23, 0x64, 0x24, 0x61, 0x23, 0x61, 0x23, 0x63, 0x23, 0x64, 0x23, 0x62, 0x23, 0x66, 0x24, 0x62, 0x23, 0x61, 0x23, 0x62, 0x23, 0x62, 0x23, 0x60, 0x23, 0x60, 0x22, 0x63, 0x24, 0x62, 0x23, 0x60, 0x22, 0x60, 0x22, 0x63, 0x24, 0x62, 0x23, 0x62, 0x24, 0x66, 0x25, 0x65, 0x25, 0x63, 0x23, 0x60, 0x23, 0x60, 0x22, 0x61, 0x22, 0x60, 0x22, 0x60, 0x23, 0x63, 0x23, 0x61, 0x23, 0x5E, 0x22, 0x61, 0x24, 0x64, 0x24, 0x64, 0x23, 0x62, 0x23, 0x65, 0x25, 0x5D, 0x22, 0x5F, 0x23, 0x5E, 0x22, 0x5E, 0x22, 0x5E, 0x22, 0x5E, 0x22, 0x5B, 0x20, 0x5E, 0x21, 0x5E, 0x21, 0x5E, 0x23, 0x60, 0x24, 0x5F, 0x23, 0x5E, 0x22, 0x5C, 0x21, 0x5C, 0x21, 0x5C, 0x21, 0x5B, 0x21, 0x5C, 0x22, 0x5A, 0x21, 0x5D, 0x21, 0x5A, 0x20, 0x5C, 0x21, 0x5B, 0x20, 0x58, 0x21, 0x5E, 0x21, 0x5A, 0x21, 0x5B, 0x21, 0x5A, 0x20, 0x58, 0x20, 0x57, 0x20, 0x58, 0x20, 0x5A, 0x20, 0x5B, 0x20, 0x5B, 0x20, 0x58, 0x1F, 0x59, 0x1F, 0x56, 0x20, 0x58, 0x20, 0x5A, 0x20, 0x5A, 0x21, 0x59, 0x21, 0x5A, 0x21, 0x5A, 0x21, 0x5B, 0x21, 0x57, 0x20, 0x5A, 0x21, 0x58, 0x20, 0x5C, 0x22, 0x59, 0x21, 0x5D, 0x22, 0x5C, 0x21, 0x5B, 0x21, 0x5A, 0x21, 0x5B, 0x21, 0x5A, 0x21, 0x5A, 0x21, 0x5B, 0x22, 0x59, 0x21, 0x56, 0x20, 0x56, 0x20, 0x57, 0x20, 0x54, 0x1F, 0x55, 0x1F, 0x57, 0x1F, 0x56, 0x1F, 0x54, 0x1F, 0x41, 0x1D, 0x2A, 0x17, 0x2A, 0x18, 0x25, 0x16, 0x23, 0x16, 0x2F, 0x1A, 0x2A, 0x18, 0x2C, 0x19, 0x29, 0x18, 0x2E, 0x1A, 0x2D, 0x1A, 0x31, 0x1D, 0x35, 0x1D, 0x36, 0x1D, 0x31, 0x1B, 0x31, 0x1B, 0x2D, 0x19, 0x37, 0x1E, 0x33, 0x1B, 0x34, 0x1C, 0x2F, 0x1A, 0x34, 0x1D, 0x32, 0x1B, 0x2E, 0x1B, 0x33, 0x1B, 0x36, 0x1D, 0x34, 0x1C, 0x2D, 0x1A, 0x2E, 0x18, 0x31, 0x1C, 0x31, 0x1A, 0x2A, 0x19, 0x2E, 0x19, 0x2D, 0x1A, 0x31, 0x1A, 0x26, 0x17, 0x30, 0x19, 0x2B, 0x19, 0x30, 0x1A, 0x28, 0x17, 0x25, 0x15, 0x2F, 0x1A, 0x2A, 0x17, 0x29, 0x18, 0x29, 0x17
    },

    {
        0x1E, 0x22, 0x2A, 0x33, 0x40, 0x4D, 0x58, 0x65, 0x65, 0x70, 0x6C, 0x75, 0x70, 0x78, 0x71, 0x7A, 0x73, 0x7B, 0x75, 0x7D, 0x75, 0x7D, 0x75, 0x7C, 0x73, 0x7B, 0x6F, 0x77, 0x65, 0x6A, 0x4E, 0x4C, 0x31, 0x31, 0x25, 0x26, 0x1F, 0x21, 0x1B, 0x1D, 0x18, 0x1B, 0x16, 0x19, 0x15, 0x18, 0x13, 0x16, 0x13, 0x16, 0x13, 0x16, 0x14, 0x17, 0x16, 0x1A, 0x1B, 0x21, 0x20, 0x26, 0x1F, 0x24, 0x1D, 0x21, 0x1B, 0x1F, 0x19, 0x1E, 0x18, 0x1C, 0x16, 0x1A, 0x15, 0x19, 0x14, 0x18, 0x15, 0x1C, 0x1A, 0x2B, 0x26, 0x4B, 0x38, 0x75, 0x47, 0x8F, 0x4C, 0x98, 0x4E, 0x9C, 0x52, 0xA1, 0x53, 0xA3, 0x54, 0xA4, 0x56, 0xA8, 0x58, 0xAB, 0x57, 0xAB, 0x57, 0xAB, 0x57, 0xAA, 0x58, 0xAB, 0x57, 0xAD, 0x57, 0xAC, 0x58, 0xA9, 0x53, 0xA1, 0x46, 0x7B, 0x2E, 0x46, 0x20, 0x2F, 0x1B, 0x27, 0x18, 0x21, 0x17, 0x1E, 0x16, 0x1B, 0x14, 0x19, 0x15, 0x1A, 0x19, 0x1E, 0x21, 0x2A, 0x3B, 0x56, 0x62, 0x88, 0x74, 0x9A, 0x7B, 0x9E, 0x7E, 0xA1, 0x83, 0xA7, 0x87, 0xAA, 0x89, 0xAF, 0x88, 0xAD, 0x82, 0xA7, 0x75, 0x93, 0x5B, 0x68, 0x35, 0x39, 0x24, 0x29, 0x1D, 0x21, 0x19, 0x1E, 0x16, 0x1B, 0x15, 0x1A, 0x14, 0x18, 0x14, 0x19, 0x16, 0x1E, 0x20, 0x3C, 0x36, 0x71, 0x4D, 0x9C, 0x53, 0xA7, 0x57, 0xAE, 0x5B, 0xB2, 0x5B, 0xB1, 0x5C, 0xB3, 0x5D, 0xB5, 0x5D, 0xB5, 0x5D, 0xB6, 0x5D, 0xB5, 0x5D, 0xB6, 0x5C, 0xB6, 0x5E, 0xB8, 0x5E, 0xB8, 0x5D, 0xB4, 0x5B, 0xB3, 0x5B, 0xB1, 0x5B, 0xB1, 0x5A, 0xB2, 0x57, 0xAB, 0x45, 0x7A, 0x27, 0x3B, 0x1B, 0x24, 0x16, 0x1C, 0x15, 0x1C, 0x18, 0x24, 0x1B, 0x2A, 0x1C, 0x2D, 0x1D, 0x2D, 0x1D, 0x2E, 0x1E, 0x2E, 0x1D, 0x2E, 0x1B, 0x29, 0x16, 0x1E, 0x13, 0x18, 0x13, 0x18, 0x15, 0x20, 0x19, 0x2A, 0x1C, 0x2D, 0x1B, 0x2F, 0x1C, 0x2F, 0x1D, 0x30, 0x1D, 0x31, 0x1D, 0x31, 0x1E, 0x32, 0x1D, 0x30, 0x1D, 0x30, 0x1D, 0x30, 0x1C, 0x30, 0x1D, 0x31, 0x1D, 0x2F, 0x1D, 0x30, 0x1D, 0x30, 0x1D, 0x2F, 0x1D, 0x30, 0x1D, 0x31, 0x1E, 0x32, 0x1F, 0x32, 0x1F, 0x31, 0x1E, 0x32, 0x1F, 0x31, 0x1E, 0x31, 0x1B, 0x27, 0x17, 0x1D, 0x15, 0x18, 0x13, 0x16, 0x13, 0x16, 0x14, 0x16, 0x14, 0x17, 0x16, 0x18, 0x23, 0x29, 0x46, 0x4B, 0x5E, 0x5B, 0x65, 0x5D, 0x59, 0x4F, 0x39, 0x30, 0x37, 0x37, 0x55, 0x52, 0x63, 0x5B, 0x68, 0x5E, 0x6D, 0x61, 0x6D, 0x60, 0x6A, 0x5E, 0x6B, 0x60, 0x6C, 0x61, 0x6C, 0x61, 0x6A, 0x5F, 0x70, 0x61, 0x6E, 0x5F, 0x6C, 0x5F, 0x6D, 0x60, 0x6D, 0x5F, 0x68, 0x5C, 0x69, 0x5E, 0x6D, 0x60, 0x6B, 0x5D, 0x69, 0x5F, 0x6C, 0x5F, 0x6D, 0x60, 0x6C, 0x60, 0x6D, 0x61, 0x6E, 0x63, 0x70, 0x63, 0x6E, 0x61, 0x6A, 0x5E, 0x6C, 0x5E, 0x6D, 0x5F, 0x6C, 0x5E, 0x6A, 0x5F, 0x6D, 0x61, 0x6B, 0x5D, 0x6C, 0x5D, 0x6E, 0x62, 0x70, 0x63, 0x6D, 0x61, 0x6D, 0x60, 0x6E, 0x63, 0x68, 0x5D, 0x69, 0x5E, 0x69, 0x5D, 0x6A, 0x5D, 0x6A, 0x5C, 0x69, 0x5E, 0x66, 0x5A, 0x67, 0x5B, 0x67, 0x5D, 0x65, 0x5C, 0x66, 0x5E, 0x65, 0x5C, 0x67, 0x5C, 0x66, 0x5B, 0x66, 0x5B, 0x66, 0x5A, 0x64, 0x57, 0x65, 0x59, 0x63, 0x58, 0x66, 0x5B, 0x65, 0x59, 0x65, 0x5A, 0x65, 0x58, 0x62, 0x55, 0x67, 0x5A, 0x63, 0x57, 0x65, 0x59, 0x64, 0x58, 0x62, 0x55, 0x61, 0x56, 0x62, 0x57, 0x63, 0x57, 0x63, 0x58, 0x67, 0x58, 0x62, 0x55, 0x62, 0x53, 0x5F, 0x55, 0x62, 0x57, 0x63, 0x57, 0x63, 0x57, 0x61, 0x55, 0x63, 0x56, 0x64, 0x58, 0x64, 0x58, 0x62, 0x58, 0x64, 0x58, 0x62, 0x57, 0x65, 0x59, 0x63, 0x57, 0x66, 0x5B, 0x65, 0x5A, 0x64, 0x59, 0x64, 0x59, 0x66, 0x5B, 0x64, 0x59, 0x62, 0x58, 0x64, 0x5A, 0x60, 0x56, 0x60, 0x55, 0x60, 0x55, 0x62, 0x57, 0x5E, 0x53, 0x5E, 0x53, 0x62, 0x54, 0x5F, 0x54, 0x5C, 0x50, 0x40, 0x38, 0x27, 0x25, 0x26, 0x28, 0x20, 0x22, 0x22, 0x25, 0x2B, 0x2F, 0x28, 0x2C, 0x28, 0x2C, 0x27, 0x2A, 0x29, 0x2E, 0x29, 0x2F, 0x2C, 0x34, 0x2F, 0x34, 0x2E, 0x33, 0x2C, 0x31, 0x2D, 0x2F, 0x2B, 0x31, 0x32, 0x38, 0x2A, 0x2F, 0x2D, 0x32, 0x2B, 0x31, 0x2D, 0x31, 0x2A, 0x2D, 0x29, 0x2F, 0x2C, 0x2E, 0x2F, 0x35, 0x2B, 0x2E, 0x26, 0x29, 0x26, 0x28, 0x2B, 0x31, 0x28, 0x28, 0x26, 0x2B, 0x28, 0x2A, 0x29, 0x2D, 0x2B, 0x2D, 0x23, 0x25, 0x2A, 0x2E, 0x26, 0x2C, 0x29, 0x2B, 0x24, 0x26, 0x22, 0x26, 0x29, 0x2E, 0x25, 0x26, 0x25, 0x26, 0x24, 0x27
    },

    {
        0x2B, 0x1B, 0x3F, 0x25, 0x5C, 0x30, 0x6C, 0x36, 0x74, 0x39, 0x79, 0x3B, 0x7C, 0x3C, 0x7F, 0x3D, 0x7F, 0x3D, 0x80, 0x3D, 0x7F, 0x3E, 0x80, 0x3E, 0x80, 0x3E, 0x7F, 0x3E, 0x7A, 0x3B, 0x6E, 0x35, 0x51, 0x27, 0x34, 0x1C, 0x27, 0x17, 0x21, 0x14, 0x1E, 0x13, 0x1C, 0x12, 0x1A, 0x11, 0x19, 0x11, 0x18, 0x10, 0x18, 0x11, 0x1A, 0x13, 0x21, 0x19, 0x34, 0x28, 0x4C, 0x35, 0x4A, 0x2D, 0x31, 0x1F, 0x27, 0x1A, 0x23, 0x17, 0x20, 0x16, 0x1D, 0x15, 0x1B, 0x13, 0x1B, 0x15, 0x23, 0x1D, 0x3C, 0x32, 0x66, 0x4F, 0x8C, 0x64, 0x9A, 0x6E, 0xA0, 0x71, 0xA4, 0x74, 0xAC, 0x79, 0xAC, 0x78, 0xAD, 0x7A, 0xAE, 0x7A, 0xB1, 0x7E, 0xB3, 0x7F, 0xB3, 0x7F, 0xB3, 0x7D, 0xB2, 0x7E, 0xB2, 0x80, 0xB4, 0x80, 0xB4, 0x7F, 0xB2, 0x7C, 0xAA, 0x74, 0x86, 0x53, 0x4C, 0x30, 0x30, 0x21, 0x27, 0x1B, 0x23, 0x18, 0x20, 0x16, 0x1C, 0x14, 0x1A, 0x13, 0x1A, 0x13, 0x1E, 0x17, 0x2A, 0x23, 0x58, 0x48, 0x8F, 0x64, 0xA0, 0x6E, 0xA6, 0x73, 0xAA, 0x76, 0xB1, 0x7B, 0xB7, 0x7D, 0xB6, 0x7A, 0xA8, 0x6F, 0x84, 0x54, 0x50, 0x32, 0x31, 0x20, 0x26, 0x1A, 0x21, 0x17, 0x1D, 0x14, 0x1B, 0x14, 0x19, 0x12, 0x18, 0x11, 0x1B, 0x14, 0x2C, 0x27, 0x5C, 0x4B, 0x93, 0x6D, 0xAA, 0x7A, 0xB2, 0x7F, 0xB8, 0x83, 0xBA, 0x82, 0xBB, 0x84, 0xBB, 0x85, 0xBC, 0x86, 0xBD, 0x86, 0xBF, 0x89, 0xC5, 0x8C, 0xC0, 0x89, 0xBF, 0x87, 0xBE, 0x88, 0xBC, 0x88, 0xBD, 0x86, 0xBA, 0x84, 0xBA, 0x85, 0xBB, 0x85, 0xBA, 0x85, 0xB9, 0x83, 0xB1, 0x79, 0x83, 0x51, 0x3E, 0x28, 0x26, 0x1F, 0x25, 0x2B, 0x2B, 0x3C, 0x2E, 0x42, 0x2F, 0x45, 0x31, 0x47, 0x31, 0x47, 0x31, 0x47, 0x31, 0x48, 0x2F, 0x45, 0x2B, 0x37, 0x20, 0x21, 0x1F, 0x1C, 0x28, 0x20, 0x2F, 0x22, 0x30, 0x24, 0x32, 0x24, 0x31, 0x24, 0x33, 0x26, 0x33, 0x25, 0x32, 0x25, 0x32, 0x25, 0x32, 0x24, 0x30, 0x25, 0x32, 0x25, 0x32, 0x24, 0x33, 0x25, 0x33, 0x26, 0x32, 0x25, 0x33, 0x25, 0x32, 0x26, 0x33, 0x25, 0x34, 0x26, 0x34, 0x26, 0x34, 0x26, 0x36, 0x26, 0x34, 0x26, 0x35, 0x27, 0x34, 0x25, 0x34, 0x25, 0x28, 0x1A, 0x1C, 0x12, 0x18, 0x11, 0x17, 0x10, 0x17, 0x10, 0x18, 0x10, 0x17, 0x10, 0x19, 0x11, 0x26, 0x16, 0x4A, 0x1F, 0x5D, 0x22, 0x5D, 0x21, 0x4F, 0x1D, 0x31, 0x19, 0x3C, 0x1D, 0x56, 0x21, 0x5F, 0x22, 0x63, 0x23, 0x64, 0x25, 0x64, 0x25, 0x62, 0x24, 0x62, 0x23, 0x61, 0x23, 0x5E, 0x22, 0x61, 0x23, 0x62, 0x22, 0x5F, 0x21, 0x61, 0x23, 0x60, 0x23, 0x61, 0x22, 0x60, 0x23, 0x63, 0x24, 0x63, 0x23, 0x5F, 0x22, 0x65, 0x24, 0x63, 0x23, 0x61, 0x23, 0x60, 0x22, 0x64, 0x24, 0x65, 0x24, 0x63, 0x23, 0x5F, 0x22, 0x5F, 0x22, 0x62, 0x24, 0x63, 0x24, 0x61, 0x23, 0x61, 0x23, 0x60, 0x22, 0x63, 0x24, 0x65, 0x25, 0x64, 0x23, 0x61, 0x22, 0x5F, 0x22, 0x5F, 0x21, 0x5D, 0x21, 0x5F, 0x23, 0x62, 0x23, 0x64, 0x24, 0x5E, 0x21, 0x5F, 0x22, 0x5B, 0x20, 0x5B, 0x22, 0x5C, 0x23, 0x58, 0x23, 0x58, 0x23, 0x5B, 0x22, 0x5A, 0x21, 0x5B, 0x21, 0x5B, 0x21, 0x5D, 0x21, 0x5D, 0x21, 0x5D, 0x21, 0x5A, 0x20, 0x59, 0x21, 0x5B, 0x20, 0x5A, 0x1F, 0x5A, 0x21, 0x5A, 0x20, 0x59, 0x20, 0x5A, 0x20, 0x5B, 0x20, 0x5B, 0x20, 0x58, 0x20, 0x5D, 0x22, 0x5B, 0x1F, 0x57, 0x20, 0x55, 0x1E, 0x59, 0x1F, 0x58, 0x1F, 0x56, 0x1E, 0x55, 0x1F, 0x56, 0x20, 0x58, 0x20, 0x5A, 0x20, 0x56, 0x1F, 0x57, 0x20, 0x5A, 0x21, 0x5A, 0x21, 0x5B, 0x21, 0x58, 0x20, 0x5C, 0x20, 0x5B, 0x21, 0x5A, 0x21, 0x5C, 0x22, 0x5A, 0x21, 0x5B, 0x21, 0x5A, 0x21, 0x5C, 0x21, 0x5A, 0x21, 0x5B, 0x21, 0x5A, 0x20, 0x59, 0x20, 0x57, 0x20, 0x58, 0x20, 0x56, 0x20, 0x55, 0x1F, 0x53, 0x1E, 0x55, 0x1F, 0x57, 0x20, 0x56, 0x1F, 0x3C, 0x1B, 0x2C, 0x18, 0x2D, 0x1A, 0x30, 0x1A, 0x37, 0x1D, 0x33, 0x1C, 0x31, 0x1A, 0x2F, 0x1A, 0x2D, 0x18, 0x25, 0x17, 0x30, 0x1A, 0x30, 0x1B, 0x30, 0x1B, 0x27, 0x17, 0x2B, 0x1A, 0x2B, 0x18, 0x35, 0x1D, 0x30, 0x1A, 0x25, 0x17, 0x29, 0x17, 0x29, 0x18, 0x2A, 0x19, 0x28, 0x16, 0x2B, 0x19, 0x25, 0x16, 0x2C, 0x19, 0x25, 0x16, 0x26, 0x16, 0x24, 0x16, 0x2A, 0x18, 0x25, 0x16, 0x2A, 0x19, 0x29, 0x17, 0x2F, 0x1A, 0x2C, 0x19, 0x29, 0x18, 0x32, 0x1B, 0x31, 0x1C, 0x2B, 0x18, 0x29, 0x18, 0x2E, 0x1A, 0x2D, 0x19, 0x29, 0x17, 0x2B, 0x19, 0x2A, 0x17
    },

    {
        0x29, 0x32, 0x3C, 0x49, 0x56, 0x63, 0x64, 0x6E, 0x6B, 0x74, 0x70, 0x79, 0x71, 0x79, 0x73, 0x7B, 0x74, 0x7C, 0x75, 0x7C, 0x75, 0x7C, 0x76, 0x7D, 0x75, 0x7E, 0x74, 0x7C, 0x70, 0x78, 0x68, 0x6E, 0x52, 0x53, 0x37, 0x35, 0x26, 0x28, 0x20, 0x21, 0x1B, 0x1E, 0x18, 0x1B, 0x17, 0x1A, 0x15, 0x19, 0x16, 0x18, 0x15, 0x19, 0x17, 0x1C, 0x1E, 0x27, 0x2D, 0x3F, 0x41, 0x5C, 0x46, 0x54, 0x30, 0x34, 0x23, 0x29, 0x1F, 0x23, 0x1C, 0x20, 0x19, 0x1D, 0x18, 0x1C, 0x17, 0x1D, 0x1B, 0x2A, 0x25, 0x48, 0x37, 0x73, 0x46, 0x8D, 0x4B, 0x97, 0x4F, 0x9B, 0x51, 0x9F, 0x53, 0xA5, 0x54, 0xA5, 0x55, 0xA5, 0x56, 0xA7, 0x57, 0xAA, 0x57, 0xAC, 0x58, 0xAC, 0x57, 0xAA, 0x57, 0xAA, 0x58, 0xAB, 0x57, 0xAB, 0x58, 0xAC, 0x58, 0xAB, 0x55, 0xA7, 0x49, 0x84, 0x30, 0x4D, 0x21, 0x30, 0x1B, 0x27, 0x19, 0x23, 0x18, 0x20, 0x16, 0x1C, 0x14, 0x19, 0x15, 0x1A, 0x18, 0x1D, 0x1F, 0x26, 0x37, 0x50, 0x5F, 0x84, 0x74, 0x97, 0x7B, 0x9D, 0x81, 0xA4, 0x85, 0xAC, 0x88, 0xAE, 0x85, 0xAB, 0x78, 0x96, 0x5D, 0x6E, 0x39, 0x3E, 0x25, 0x2A, 0x1E, 0x23, 0x1A, 0x1E, 0x17, 0x1C, 0x14, 0x19, 0x14, 0x18, 0x13, 0x18, 0x16, 0x1D, 0x1F, 0x39, 0x35, 0x71, 0x4C, 0x9A, 0x54, 0xA8, 0x57, 0xAC, 0x58, 0xB1, 0x5B, 0xB1, 0x5B, 0xB2, 0x5C, 0xB4, 0x5C, 0xB4, 0x5C, 0xB6, 0x5D, 0xB7, 0x60, 0xBB, 0x5F, 0xB7, 0x5C, 0xB6, 0x5D, 0xB5, 0x5D, 0xB5, 0x5C, 0xB3, 0x5B, 0xB2, 0x5B, 0xB2, 0x5B, 0xB2, 0x5A, 0xB1, 0x5A, 0xB1, 0x57, 0xA9, 0x48, 0x82, 0x2A, 0x3F, 0x1B, 0x26, 0x1A, 0x27, 0x1C, 0x2C, 0x1D, 0x2D, 0x1D, 0x2E, 0x1D, 0x2F, 0x1E, 0x30, 0x1F, 0x30, 0x1E, 0x2F, 0x1E, 0x2F, 0x1C, 0x2A, 0x17, 0x20, 0x17, 0x21, 0x19, 0x29, 0x1B, 0x2D, 0x1D, 0x2F, 0x1D, 0x2F, 0x1D, 0x30, 0x1D, 0x31, 0x1D, 0x31, 0x1D, 0x31, 0x1C, 0x2F, 0x1D, 0x2F, 0x1D, 0x2F, 0x1D, 0x30, 0x1C, 0x30, 0x1D, 0x31, 0x1E, 0x31, 0x1D, 0x30, 0x1D, 0x31, 0x1D, 0x31, 0x1E, 0x31, 0x1E, 0x34, 0x1F, 0x33, 0x1F, 0x32, 0x20, 0x34, 0x1F, 0x33, 0x1E, 0x32, 0x1E, 0x32, 0x1F, 0x33, 0x1B, 0x27, 0x15, 0x1B, 0x14, 0x18, 0x14, 0x17, 0x14, 0x17, 0x14, 0x17, 0x13, 0x16, 0x15, 0x18, 0x1E, 0x22, 0x44, 0x47, 0x5F, 0x5A, 0x61, 0x59, 0x59, 0x4E, 0x39, 0x32, 0x3B, 0x39, 0x56, 0x52, 0x63, 0x5D, 0x69, 0x5F, 0x6D, 0x64, 0x6C, 0x62, 0x6A, 0x5F, 0x69, 0x5D, 0x6A, 0x5D, 0x68, 0x5D, 0x6A, 0x5F, 0x6C, 0x5D, 0x6A, 0x5C, 0x6C, 0x5F, 0x6D, 0x5D, 0x6B, 0x5F, 0x6A, 0x5E, 0x6E, 0x62, 0x6E, 0x61, 0x6B, 0x5F, 0x6E, 0x63, 0x6A, 0x5F, 0x6A, 0x5F, 0x6B, 0x5F, 0x6E, 0x61, 0x6E, 0x63, 0x6D, 0x60, 0x69, 0x5C, 0x6A, 0x5D, 0x6D, 0x61, 0x6B, 0x61, 0x68, 0x5D, 0x6B, 0x5E, 0x6A, 0x5D, 0x6D, 0x63, 0x6F, 0x62, 0x6F, 0x5E, 0x6D, 0x5F, 0x68, 0x5D, 0x68, 0x5C, 0x69, 0x5C, 0x68, 0x5C, 0x6E, 0x61, 0x6E, 0x61, 0x69, 0x5B, 0x69, 0x5D, 0x65, 0x59, 0x62, 0x58, 0x5D, 0x55, 0x57, 0x52, 0x57, 0x53, 0x5D, 0x55, 0x61, 0x58, 0x62, 0x59, 0x64, 0x58, 0x65, 0x5A, 0x66, 0x5B, 0x67, 0x5B, 0x64, 0x58, 0x63, 0x58, 0x64, 0x57, 0x64, 0x57, 0x65, 0x58, 0x65, 0x57, 0x64, 0x59, 0x64, 0x58, 0x65, 0x58, 0x65, 0x59, 0x63, 0x57, 0x67, 0x5B, 0x65, 0x58, 0x61, 0x55, 0x60, 0x54, 0x64, 0x56, 0x65, 0x56, 0x60, 0x53, 0x5D, 0x53, 0x5F, 0x56, 0x62, 0x57, 0x64, 0x57, 0x61, 0x54, 0x60, 0x55, 0x61, 0x56, 0x62, 0x58, 0x63, 0x57, 0x61, 0x56, 0x65, 0x59, 0x67, 0x5B, 0x63, 0x58, 0x66, 0x5A, 0x64, 0x58, 0x66, 0x59, 0x63, 0x57, 0x65, 0x5B, 0x66, 0x5A, 0x66, 0x5A, 0x63, 0x58, 0x62, 0x57, 0x60, 0x55, 0x60, 0x55, 0x5E, 0x52, 0x5E, 0x53, 0x5C, 0x51, 0x5F, 0x54, 0x61, 0x55, 0x5F, 0x53, 0x3E, 0x39, 0x2A, 0x2B, 0x2B, 0x2F, 0x2D, 0x32, 0x30, 0x35, 0x2A, 0x2F, 0x29, 0x2D, 0x29, 0x2D, 0x27, 0x27, 0x22, 0x27, 0x27, 0x2B, 0x29, 0x2E, 0x28, 0x2B, 0x22, 0x24, 0x27, 0x2C, 0x26, 0x27, 0x30, 0x37, 0x28, 0x29, 0x22, 0x27, 0x25, 0x26, 0x25, 0x2A, 0x28, 0x2D, 0x24, 0x24, 0x28, 0x2A, 0x23, 0x25, 0x27, 0x29, 0x24, 0x25, 0x23, 0x26, 0x25, 0x27, 0x26, 0x29, 0x24, 0x27, 0x27, 0x2C, 0x27, 0x27, 0x2B, 0x30, 0x27, 0x2B, 0x27, 0x2D, 0x2C, 0x2E, 0x2D, 0x35, 0x25, 0x27, 0x27, 0x2C, 0x2A, 0x2F, 0x28, 0x2A, 0x25, 0x29, 0x29, 0x2E, 0x25, 0x28
    },

    {
        0x3F, 0x24, 0x5A, 0x2F, 0x6D, 0x36, 0x74, 0x38, 0x79, 0x3B, 0x7C, 0x3B, 0x7D, 0x3C, 0x7E, 0x3D, 0x7F, 0x3D, 0x80, 0x3D, 0x81, 0x3E, 0x80, 0x3F, 0x82, 0x3F, 0x82, 0x3F, 0x7E, 0x3E, 0x7D, 0x3D, 0x71, 0x38, 0x58, 0x2C, 0x38, 0x1F, 0x29, 0x18, 0x21, 0x15, 0x1E, 0x13, 0x1C, 0x12, 0x1B, 0x12, 0x1B, 0x12, 0x1B, 0x13, 0x23, 0x1A, 0x34, 0x29, 0x59, 0x43, 0x89, 0x5D, 0x94, 0x5B, 0x69, 0x3C, 0x3C, 0x25, 0x2C, 0x1C, 0x26, 0x1A, 0x21, 0x17, 0x21, 0x17, 0x27, 0x1F, 0x3A, 0x30, 0x60, 0x4A, 0x88, 0x61, 0x98, 0x6C, 0xA0, 0x71, 0xA4, 0x75, 0xA8, 0x76, 0xAB, 0x79, 0xAE, 0x7A, 0xAD, 0x7B, 0xB0, 0x7C, 0xB2, 0x7D, 0xB3, 0x80, 0xB3, 0x7F, 0xB5, 0x7F, 0xB5, 0x7F, 0xB5, 0x7F, 0xB4, 0x80, 0xB3, 0x80, 0xB5, 0x7F, 0xB3, 0x7E, 0xAE, 0x77, 0x8F, 0x5A, 0x53, 0x35, 0x32, 0x22, 0x28, 0x1C, 0x23, 0x19, 0x21, 0x16, 0x1C, 0x14, 0x1A, 0x13, 0x1A, 0x13, 0x1E, 0x16, 0x28, 0x21, 0x50, 0x40, 0x85, 0x5F, 0x9D, 0x6B, 0xA6, 0x73, 0xAE, 0x77, 0xB1, 0x78, 0xA6, 0x6E, 0x86, 0x53, 0x55, 0x36, 0x36, 0x23, 0x29, 0x1C, 0x22, 0x18, 0x1E, 0x15, 0x1B, 0x13, 0x19, 0x12, 0x18, 0x12, 0x1A, 0x14, 0x2A, 0x24, 0x55, 0x46, 0x8F, 0x6B, 0xA9, 0x78, 0xB4, 0x7F, 0xB9, 0x83, 0xBB, 0x85, 0xBE, 0x87, 0xBD, 0x85, 0xBF, 0x88, 0xC0, 0x89, 0xBE, 0x87, 0xBD, 0x86, 0xBC, 0x88, 0xC4, 0x8B, 0xBD, 0x88, 0xBB, 0x86, 0xBD, 0x86, 0xBC, 0x85, 0xBB, 0x85, 0xB9, 0x83, 0xB8, 0x84, 0xBA, 0x85, 0xB8, 0x83, 0xB9, 0x84, 0xB2, 0x79, 0x7D, 0x4B, 0x38, 0x30, 0x30, 0x3B, 0x2F, 0x42, 0x2F, 0x43, 0x30, 0x46, 0x31, 0x48, 0x31, 0x48, 0x32, 0x48, 0x31, 0x47, 0x30, 0x47, 0x31, 0x45, 0x2B, 0x36, 0x26, 0x23, 0x2D, 0x23, 0x2F, 0x23, 0x32, 0x25, 0x34, 0x26, 0x32, 0x25, 0x33, 0x26, 0x32, 0x25, 0x31, 0x25, 0x31, 0x24, 0x32, 0x25, 0x33, 0x26, 0x31, 0x25, 0x32, 0x25, 0x32, 0x26, 0x33, 0x25, 0x33, 0x26, 0x34, 0x27, 0x35, 0x27, 0x32, 0x25, 0x33, 0x26, 0x32, 0x27, 0x3B, 0x29, 0x35, 0x26, 0x34, 0x26, 0x34, 0x25, 0x33, 0x25, 0x35, 0x26, 0x31, 0x23, 0x28, 0x1B, 0x1C, 0x14, 0x19, 0x11, 0x17, 0x0F, 0x17, 0x0F, 0x16, 0x0F, 0x16, 0x0F, 0x17, 0x10, 0x22, 0x15, 0x47, 0x1D, 0x55, 0x20, 0x59, 0x20, 0x4F, 0x1D, 0x36, 0x19, 0x39, 0x1E, 0x55, 0x21, 0x5E, 0x23, 0x64, 0x26, 0x62, 0x23, 0x5D, 0x21, 0x5D, 0x22, 0x5F, 0x22, 0x62, 0x23, 0x5F, 0x22, 0x5F, 0x21, 0x60, 0x23, 0x61, 0x22, 0x62, 0x23, 0x63, 0x23, 0x60, 0x22, 0x64, 0x23, 0x61, 0x23, 0x60, 0x23, 0x65, 0x25, 0x67, 0x27, 0x66, 0x26, 0x66, 0x24, 0x62, 0x23, 0x65, 0x24, 0x60, 0x23, 0x5E, 0x24, 0x62, 0x25, 0x65, 0x24, 0x63, 0x23, 0x5D, 0x21, 0x61, 0x23, 0x63, 0x23, 0x62, 0x22, 0x61, 0x22, 0x5E, 0x21, 0x60, 0x22, 0x60, 0x23, 0x5F, 0x22, 0x61, 0x22, 0x5D, 0x22, 0x60, 0x22, 0x5C, 0x21, 0x5E, 0x21, 0x5E, 0x21, 0x5C, 0x22, 0x54, 0x23, 0x4B, 0x23, 0x49, 0x23, 0x49, 0x23, 0x4C, 0x23, 0x53, 0x22, 0x56, 0x20, 0x5A, 0x21, 0x5B, 0x22, 0x5F, 0x22, 0x5C, 0x21, 0x5B, 0x20, 0x59, 0x20, 0x5A, 0x20, 0x5A, 0x20, 0x5B, 0x21, 0x5D, 0x22, 0x5E, 0x22, 0x5A, 0x20, 0x5A, 0x20, 0x5A, 0x21, 0x59, 0x20, 0x58, 0x1F, 0x58, 0x20, 0x56, 0x1F, 0x55, 0x1F, 0x58, 0x1F, 0x59, 0x20, 0x57, 0x20, 0x5A, 0x21, 0x5A, 0x20, 0x56, 0x1F, 0x59, 0x20, 0x57, 0x20, 0x5A, 0x21, 0x58, 0x20, 0x58, 0x21, 0x58, 0x20, 0x55, 0x20, 0x58, 0x20, 0x5B, 0x20, 0x55, 0x1F, 0x5B, 0x21, 0x5B, 0x22, 0x5C, 0x21, 0x59, 0x21, 0x5E, 0x22, 0x5B, 0x21, 0x58, 0x20, 0x58, 0x20, 0x57, 0x1F, 0x57, 0x20, 0x55, 0x1E, 0x53, 0x1E, 0x56, 0x20, 0x55, 0x1F, 0x58, 0x20, 0x58, 0x20, 0x55, 0x1F, 0x3C, 0x1A, 0x2B, 0x18, 0x30, 0x1A, 0x2E, 0x1A, 0x2A, 0x17, 0x29, 0x17, 0x26, 0x16, 0x27, 0x16, 0x21, 0x15, 0x27, 0x18, 0x2B, 0x18, 0x2D, 0x19, 0x2D, 0x19, 0x26, 0x17, 0x2B, 0x19, 0x2B, 0x1A, 0x36, 0x1C, 0x24, 0x16, 0x2A, 0x19, 0x2B, 0x18, 0x32, 0x1C, 0x2A, 0x18, 0x29, 0x18, 0x2C, 0x19, 0x2B, 0x19, 0x2C, 0x18, 0x2E, 0x1B, 0x2E, 0x1A, 0x35, 0x1D, 0x31, 0x1B, 0x2F, 0x1A, 0x2E, 0x1B, 0x2F, 0x1B, 0x38, 0x1E, 0x2F, 0x1B, 0x35, 0x1D, 0x34, 0x1B, 0x31, 0x1A, 0x2E, 0x1A, 0x35, 0x1E, 0x31, 0x1B, 0x31, 0x1B, 0x32, 0x1D, 0x33, 0x1C, 0x2C, 0x1A
    },

    {
        0x3C, 0x48, 0x54, 0x61, 0x64, 0x6E, 0x6B, 0x74, 0x6E, 0x77, 0x71, 0x79, 0x72, 0x79, 0x71, 0x7A, 0x74, 0x7B, 0x75, 0x7C, 0x76, 0x7D, 0x77, 0x7E, 0x76, 0x7D, 0x76, 0x7D, 0x74, 0x7C, 0x71, 0x7A, 0x6A, 0x71, 0x59, 0x5A, 0x3C, 0x3B, 0x29, 0x2A, 0x20, 0x22, 0x1C, 0x1E, 0x19, 0x1C, 0x18, 0x1C, 0x18, 0x1C, 0x19, 0x1C, 0x1F, 0x27, 0x2E, 0x3F, 0x48, 0x6A, 0x6B, 0x95, 0x77, 0x9A, 0x5F, 0x6F, 0x3A, 0x3F, 0x29, 0x2E, 0x22, 0x26, 0x1E, 0x23, 0x1B, 0x22, 0x1E, 0x2C, 0x26, 0x46, 0x36, 0x6D, 0x44, 0x89, 0x4A, 0x94, 0x4E, 0x9A, 0x50, 0x9D, 0x52, 0xA1, 0x53, 0xA5, 0x54, 0xA5, 0x55, 0xA6, 0x57, 0xA9, 0x58, 0xAB, 0x57, 0xAC, 0x59, 0xAD, 0x58, 0xAC, 0x59, 0xAB, 0x58, 0xAC, 0x58, 0xAC, 0x58, 0xAD, 0x58, 0xAC, 0x57, 0xAA, 0x56, 0xA8, 0x4D, 0x8E, 0x35, 0x55, 0x22, 0x32, 0x1C, 0x28, 0x19, 0x23, 0x18, 0x1F, 0x16, 0x1C, 0x15, 0x1A, 0x15, 0x1A, 0x17, 0x1C, 0x1E, 0x25, 0x32, 0x47, 0x59, 0x7B, 0x6F, 0x93, 0x7A, 0x9D, 0x7F, 0xA4, 0x81, 0xA6, 0x78, 0x97, 0x5F, 0x6F, 0x3B, 0x42, 0x28, 0x2E, 0x20, 0x25, 0x1B, 0x1F, 0x17, 0x1B, 0x14, 0x19, 0x13, 0x18, 0x13, 0x18, 0x16, 0x1D, 0x1E, 0x35, 0x31, 0x67, 0x4A, 0x95, 0x53, 0xA4, 0x57, 0xAC, 0x58, 0xB0, 0x5B, 0xB4, 0x5D, 0xB6, 0x5D, 0xB6, 0x5D, 0xB7, 0x5E, 0xB8, 0x5D, 0xB6, 0x5D, 0xB5, 0x5C, 0xB6, 0x60, 0xBC, 0x5D, 0xB6, 0x5C, 0xB4, 0x5C, 0xB6, 0x5C, 0xB3, 0x5C, 0xB5, 0x5B, 0xB1, 0x5A, 0xB1, 0x5C, 0xB2, 0x5B, 0xB2, 0x5A, 0xB1, 0x56, 0xA7, 0x42, 0x6F, 0x23, 0x34, 0x1E, 0x2F, 0x1E, 0x2E, 0x1D, 0x2D, 0x1E, 0x2F, 0x1E, 0x2F, 0x1E, 0x2F, 0x1E, 0x2F, 0x1E, 0x2F, 0x1E, 0x2E, 0x1E, 0x2E, 0x1B, 0x29, 0x18, 0x24, 0x1A, 0x2B, 0x1B, 0x2E, 0x1D, 0x31, 0x1E, 0x31, 0x1E, 0x30, 0x1D, 0x31, 0x1D, 0x2F, 0x1C, 0x30, 0x1C, 0x2F, 0x1C, 0x30, 0x1D, 0x32, 0x1D, 0x31, 0x1D, 0x30, 0x1D, 0x31, 0x1D, 0x31, 0x1E, 0x32, 0x1E, 0x32, 0x1E, 0x32, 0x1E, 0x31, 0x1E, 0x31, 0x1E, 0x32, 0x23, 0x39, 0x1F, 0x33, 0x1E, 0x31, 0x1E, 0x31, 0x1E, 0x31, 0x1F, 0x32, 0x1E, 0x30, 0x1B, 0x28, 0x16, 0x1C, 0x14, 0x17, 0x13, 0x16, 0x13, 0x15, 0x13, 0x15, 0x13, 0x15, 0x14, 0x16, 0x1C, 0x20, 0x40, 0x42, 0x55, 0x52, 0x5D, 0x57, 0x59, 0x50, 0x3D, 0x37, 0x38, 0x37, 0x53, 0x50, 0x62, 0x5B, 0x69, 0x61, 0x69, 0x5E, 0x69, 0x5C, 0x66, 0x5B, 0x67, 0x5D, 0x69, 0x5E, 0x68, 0x5B, 0x6A, 0x5E, 0x6B, 0x5F, 0x6D, 0x5E, 0x6D, 0x60, 0x6F, 0x61, 0x6B, 0x5E, 0x6E, 0x5F, 0x6A, 0x5E, 0x6B, 0x5F, 0x6E, 0x63, 0x6F, 0x66, 0x70, 0x65, 0x70, 0x63, 0x6F, 0x61, 0x6E, 0x61, 0x6C, 0x5E, 0x6A, 0x60, 0x6D, 0x60, 0x6E, 0x60, 0x6D, 0x61, 0x68, 0x5C, 0x6C, 0x60, 0x6D, 0x5F, 0x6D, 0x5E, 0x6D, 0x5D, 0x69, 0x5B, 0x6B, 0x5E, 0x69, 0x5E, 0x69, 0x5D, 0x6C, 0x60, 0x69, 0x5C, 0x6B, 0x5D, 0x68, 0x5A, 0x69, 0x5C, 0x69, 0x5D, 0x62, 0x58, 0x53, 0x4D, 0x48, 0x47, 0x46, 0x46, 0x46, 0x46, 0x47, 0x47, 0x52, 0x4F, 0x5B, 0x54, 0x63, 0x59, 0x65, 0x59, 0x68, 0x5C, 0x67, 0x59, 0x65, 0x59, 0x64, 0x58, 0x64, 0x58, 0x64, 0x56, 0x66, 0x59, 0x67, 0x5A, 0x6A, 0x5C, 0x63, 0x57, 0x66, 0x59, 0x65, 0x58, 0x65, 0x5A, 0x63, 0x56, 0x62, 0x55, 0x60, 0x52, 0x60, 0x53, 0x63, 0x56, 0x61, 0x56, 0x60, 0x55, 0x63, 0x59, 0x63, 0x58, 0x60, 0x54, 0x62, 0x57, 0x60, 0x55, 0x61, 0x57, 0x5F, 0x54, 0x62, 0x57, 0x61, 0x56, 0x5E, 0x53, 0x61, 0x56, 0x63, 0x58, 0x60, 0x54, 0x66, 0x5A, 0x66, 0x5A, 0x64, 0x59, 0x61, 0x57, 0x67, 0x5A, 0x64, 0x57, 0x61, 0x56, 0x62, 0x56, 0x61, 0x56, 0x61, 0x56, 0x5E, 0x52, 0x5D, 0x52, 0x5E, 0x53, 0x5E, 0x54, 0x61, 0x56, 0x62, 0x57, 0x5E, 0x51, 0x3A, 0x32, 0x29, 0x29, 0x29, 0x2A, 0x26, 0x29, 0x24, 0x25, 0x24, 0x27, 0x22, 0x23, 0x23, 0x24, 0x1F, 0x21, 0x26, 0x29, 0x26, 0x29, 0x2A, 0x2D, 0x28, 0x2E, 0x23, 0x25, 0x28, 0x2C, 0x2A, 0x2F, 0x2D, 0x2E, 0x21, 0x25, 0x29, 0x2E, 0x29, 0x2B, 0x2E, 0x33, 0x24, 0x28, 0x27, 0x2B, 0x29, 0x2D, 0x29, 0x2D, 0x2A, 0x2C, 0x2B, 0x30, 0x2A, 0x30, 0x30, 0x34, 0x2C, 0x2F, 0x2B, 0x30, 0x2A, 0x30, 0x2B, 0x30, 0x30, 0x35, 0x2B, 0x30, 0x2F, 0x36, 0x2D, 0x31, 0x29, 0x2D, 0x2B, 0x31, 0x2E, 0x36, 0x29, 0x2F, 0x2B, 0x32, 0x2D, 0x36, 0x2A, 0x31, 0x27, 0x2E
    },

    {
        0x58, 0x2E, 0x6B, 0x36, 0x75, 0x39, 0x79, 0x3A, 0x7B, 0x3C, 0x7F, 0x3D, 0x7E, 0x3D, 0x7F, 0x3E, 0x81, 0x3E, 0x80, 0x3D, 0x81, 0x3F, 0x82, 0x3F, 0x82, 0x3F, 0x82, 0x3F, 0x83, 0x40, 0x81, 0x3F, 0x80, 0x3E, 0x77, 0x3A, 0x5F, 0x2E, 0x3E, 0x20, 0x29, 0x18, 0x23, 0x15, 0x20, 0x14, 0x1F, 0x14, 0x1F, 0x14, 0x23, 0x1A, 0x34, 0x29, 0x59, 0x43, 0x89, 0x5F, 0xA9, 0x6E, 0xB1, 0x73, 0xA9, 0x68, 0x7B, 0x48, 0x48, 0x2C, 0x31, 0x20, 0x2A, 0x1D, 0x2C, 0x21, 0x3E, 0x32, 0x63, 0x4C, 0x87, 0x61, 0x96, 0x6A, 0x9C, 0x6F, 0xA3, 0x74, 0xA8, 0x76, 0xA9, 0x77, 0xAD, 0x79, 0xAD, 0x7A, 0xB0, 0x7B, 0xB2, 0x7D, 0xB5, 0x80, 0xB6, 0x82, 0xB5, 0x7F, 0xB3, 0x7F, 0xB4, 0x7F, 0xB3, 0x80, 0xB4, 0x7F, 0xB4, 0x80, 0xB6, 0x80, 0xB5, 0x80, 0xB3, 0x7F, 0xB1, 0x7C, 0x98, 0x61, 0x5B, 0x39, 0x34, 0x23, 0x2A, 0x1C, 0x24, 0x18, 0x21, 0x17, 0x1E, 0x15, 0x1D, 0x15, 0x1C, 0x14, 0x1D, 0x15, 0x24, 0x1D, 0x44, 0x38, 0x7F, 0x5C, 0x9B, 0x6C, 0xA5, 0x71, 0xA0, 0x6A, 0x85, 0x53, 0x55, 0x35, 0x36, 0x23, 0x2A, 0x1C, 0x24, 0x18, 0x1F, 0x15, 0x1B, 0x13, 0x18, 0x11, 0x18, 0x11, 0x1A, 0x13, 0x27, 0x22, 0x51, 0x43, 0x8B, 0x68, 0xA5, 0x77, 0xB0, 0x7E, 0xB7, 0x82, 0xBA, 0x85, 0xBF, 0x87, 0xBF, 0x87, 0xBF, 0x87, 0xBE, 0x88, 0xBF, 0x89, 0xBF, 0x87, 0xBD, 0x86, 0xBC, 0x86, 0xC0, 0x8B, 0xC3, 0x89, 0xBE, 0x89, 0xBD, 0x88, 0xBE, 0x88, 0xC5, 0x8E, 0xC5, 0x8A, 0xBD, 0x86, 0xB9, 0x84, 0xBB, 0x85, 0xB7, 0x81, 0xA6, 0x6E, 0x6C, 0x42, 0x34, 0x28, 0x2E, 0x35, 0x2F, 0x40, 0x2F, 0x43, 0x31, 0x45, 0x31, 0x48, 0x32, 0x49, 0x33, 0x48, 0x31, 0x46, 0x30, 0x47, 0x2F, 0x41, 0x29, 0x2F, 0x1E, 0x1C, 0x23, 0x1D, 0x2F, 0x23, 0x31, 0x24, 0x33, 0x25, 0x32, 0x25, 0x32, 0x25, 0x31, 0x25, 0x31, 0x25, 0x30, 0x25, 0x32, 0x24, 0x32, 0x25, 0x32, 0x25, 0x32, 0x25, 0x33, 0x25, 0x33, 0x26, 0x33, 0x25, 0x33, 0x25, 0x34, 0x26, 0x32, 0x26, 0x34, 0x26, 0x32, 0x25, 0x3C, 0x2C, 0x37, 0x26, 0x34, 0x25, 0x33, 0x25, 0x33, 0x25, 0x34, 0x25, 0x33, 0x25, 0x33, 0x24, 0x28, 0x1C, 0x1B, 0x13, 0x17, 0x0F, 0x16, 0x0F, 0x16, 0x0F, 0x16, 0x0F, 0x17, 0x0F, 0x16, 0x0F, 0x21, 0x14, 0x42, 0x1C, 0x58, 0x21, 0x5C, 0x21, 0x57, 0x20, 0x37, 0x1A, 0x35, 0x1B, 0x53, 0x23, 0x61, 0x24, 0x60, 0x23, 0x60, 0x22, 0x5F, 0x22, 0x60, 0x23, 0x62, 0x23, 0x60, 0x21, 0x61, 0x21, 0x60, 0x22, 0x62, 0x23, 0x61, 0x22, 0x61, 0x22, 0x5F, 0x22, 0x62, 0x23, 0x60, 0x23, 0x63, 0x23, 0x64, 0x24, 0x66, 0x24, 0x66, 0x27, 0x67, 0x26, 0x63, 0x23, 0x64, 0x25, 0x66, 0x25, 0x6B, 0x28, 0x64, 0x24, 0x62, 0x23, 0x61, 0x23, 0x5E, 0x21, 0x61, 0x22, 0x60, 0x23, 0x5C, 0x21, 0x5F, 0x21, 0x5D, 0x21, 0x5D, 0x21, 0x5E, 0x21, 0x60, 0x22, 0x61, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x5B, 0x20, 0x5F, 0x22, 0x5E, 0x22, 0x55, 0x24, 0x4A, 0x24, 0x48, 0x23, 0x47, 0x23, 0x49, 0x24, 0x47, 0x22, 0x47, 0x21, 0x4B, 0x1E, 0x56, 0x20, 0x59, 0x20, 0x5A, 0x21, 0x5A, 0x21, 0x5B, 0x20, 0x5D, 0x21, 0x59, 0x20, 0x59, 0x20, 0x59, 0x20, 0x5C, 0x21, 0x5B, 0x21, 0x59, 0x20, 0x5B, 0x20, 0x5D, 0x21, 0x5D, 0x21, 0x59, 0x20, 0x57, 0x1F, 0x56, 0x1F, 0x57, 0x1F, 0x58, 0x1F, 0x56, 0x20, 0x58, 0x20, 0x57, 0x20, 0x54, 0x1E, 0x57, 0x20, 0x59, 0x20, 0x58, 0x20, 0x57, 0x20, 0x54, 0x1F, 0x57, 0x20, 0x58, 0x20, 0x58, 0x20, 0x57, 0x20, 0x5B, 0x21, 0x5A, 0x20, 0x5B, 0x21, 0x5A, 0x20, 0x58, 0x20, 0x59, 0x21, 0x58, 0x20, 0x57, 0x20, 0x58, 0x20, 0x59, 0x21, 0x58, 0x20, 0x55, 0x1F, 0x57, 0x1F, 0x54, 0x1E, 0x54, 0x1F, 0x54, 0x1F, 0x56, 0x1F, 0x55, 0x1F, 0x54, 0x1E, 0x34, 0x18, 0x27, 0x16, 0x2A, 0x18, 0x26, 0x16, 0x25, 0x16, 0x27, 0x17, 0x28, 0x17, 0x2E, 0x1A, 0x2E, 0x1A, 0x31, 0x1C, 0x37, 0x1D, 0x38, 0x1D, 0x34, 0x1B, 0x29, 0x18, 0x33, 0x1D, 0x36, 0x1D, 0x30, 0x1A, 0x31, 0x1C, 0x31, 0x1B, 0x33, 0x1C, 0x30, 0x1A, 0x2E, 0x1A, 0x34, 0x1C, 0x31, 0x1C, 0x31, 0x1B, 0x32, 0x1B, 0x34, 0x1C, 0x35, 0x1D, 0x35, 0x1C, 0x32, 0x1D, 0x36, 0x1D, 0x38, 0x20, 0x3A, 0x1F, 0x31, 0x1C, 0x33, 0x1D, 0x32, 0x1C, 0x2C, 0x18, 0x28, 0x19, 0x3D, 0x22, 0x3A, 0x24, 0x3E, 0x26, 0x49, 0x2C, 0x4E, 0x2E, 0x4D, 0x2D, 0x4B, 0x2C
    },

    {
        0x53, 0x5F, 0x63, 0x6D, 0x6A, 0x74, 0x6F, 0x77, 0x72, 0x7B, 0x74, 0x7C, 0x75, 0x7C, 0x75, 0x7C, 0x76, 0x7D, 0x76, 0x7C, 0x77, 0x7E, 0x77, 0x7D, 0x77, 0x7F, 0x78, 0x7E, 0x77, 0x7E, 0x76, 0x7F, 0x74, 0x7D, 0x6E, 0x76, 0x5E, 0x61, 0x41, 0x3F, 0x2A, 0x2B, 0x21, 0x24, 0x1D, 0x20, 0x1C, 0x1F, 0x1C, 0x20, 0x21, 0x28, 0x2E, 0x3F, 0x49, 0x6A, 0x6D, 0x97, 0x82, 0xA9, 0x87, 0xAF, 0x83, 0xA8, 0x6B, 0x7F, 0x44, 0x4B, 0x2D, 0x33, 0x25, 0x2D, 0x24, 0x32, 0x2A, 0x48, 0x37, 0x6E, 0x47, 0x8B, 0x4C, 0x93, 0x4C, 0x99, 0x4F, 0x9E, 0x52, 0xA1, 0x52, 0xA2, 0x53, 0xA4, 0x55, 0xA7, 0x55, 0xA7, 0x57, 0xA9, 0x58, 0xAC, 0x58, 0xAE, 0x58, 0xAC, 0x56, 0xAB, 0x58, 0xAA, 0x57, 0xAD, 0x59, 0xAD, 0x59, 0xAE, 0x5A, 0xAE, 0x5A, 0xAD, 0x58, 0xAC, 0x57, 0xAA, 0x4F, 0x96, 0x38, 0x5D, 0x24, 0x36, 0x1D, 0x29, 0x1A, 0x24, 0x19, 0x21, 0x17, 0x1D, 0x16, 0x1C, 0x16, 0x1C, 0x17, 0x1C, 0x1B, 0x21, 0x2B, 0x3D, 0x53, 0x77, 0x6E, 0x94, 0x76, 0x9B, 0x71, 0x90, 0x5E, 0x6E, 0x3C, 0x42, 0x27, 0x2E, 0x20, 0x26, 0x1B, 0x20, 0x18, 0x1C, 0x15, 0x19, 0x13, 0x17, 0x13, 0x17, 0x15, 0x1C, 0x1C, 0x31, 0x30, 0x65, 0x47, 0x95, 0x51, 0xA2, 0x55, 0xAC, 0x59, 0xB0, 0x59, 0xB2, 0x5C, 0xB6, 0x5D, 0xB6, 0x5D, 0xB7, 0x5C, 0xB6, 0x5D, 0xB9, 0x5D, 0xB6, 0x5B, 0xB3, 0x5C, 0xB3, 0x5D, 0xB6, 0x5F, 0xB8, 0x5D, 0xB8, 0x5D, 0xB6, 0x5C, 0xB7, 0x61, 0xBE, 0x62, 0xBA, 0x5C, 0xB3, 0x5A, 0xB2, 0x5B, 0xB1, 0x58, 0xAB, 0x4E, 0x8E, 0x34, 0x51, 0x1E, 0x2B, 0x1B, 0x2A, 0x1D, 0x2D, 0x1C, 0x2E, 0x1E, 0x2F, 0x1E, 0x2F, 0x1E, 0x30, 0x1F, 0x30, 0x1E, 0x2F, 0x1D, 0x2F, 0x1C, 0x2C, 0x19, 0x23, 0x15, 0x1B, 0x16, 0x21, 0x1A, 0x2B, 0x1C, 0x2E, 0x1C, 0x31, 0x1D, 0x30, 0x1C, 0x30, 0x1D, 0x30, 0x1C, 0x2F, 0x1C, 0x2F, 0x1C, 0x30, 0x1C, 0x30, 0x1D, 0x31, 0x1D, 0x31, 0x1E, 0x32, 0x1E, 0x31, 0x1D, 0x30, 0x1D, 0x31, 0x1E, 0x32, 0x1E, 0x30, 0x1D, 0x32, 0x1E, 0x31, 0x23, 0x3A, 0x20, 0x34, 0x1E, 0x31, 0x1E, 0x32, 0x1E, 0x31, 0x1E, 0x31, 0x1E, 0x32, 0x1E, 0x30, 0x1B, 0x28, 0x15, 0x1B, 0x13, 0x16, 0x12, 0x15, 0x12, 0x14, 0x12, 0x15, 0x12, 0x15, 0x13, 0x15, 0x1A, 0x1E, 0x3A, 0x3F, 0x58, 0x55, 0x61, 0x59, 0x5F, 0x57, 0x40, 0x38, 0x34, 0x32, 0x50, 0x50, 0x63, 0x5D, 0x67, 0x5F, 0x6B, 0x5E, 0x68, 0x5E, 0x69, 0x5D, 0x6B, 0x5F, 0x6B, 0x5D, 0x6B, 0x5F, 0x6B, 0x5D, 0x6E, 0x60, 0x6C, 0x5F, 0x6C, 0x5D, 0x6B, 0x5E, 0x6E, 0x61, 0x6A, 0x5E, 0x6B, 0x61, 0x6E, 0x61, 0x6D, 0x61, 0x6E, 0x62, 0x6F, 0x63, 0x6C, 0x5F, 0x6D, 0x61, 0x6E, 0x64, 0x72, 0x68, 0x6D, 0x61, 0x6D, 0x5F, 0x6C, 0x5F, 0x6A, 0x5C, 0x6D, 0x60, 0x6B, 0x5F, 0x69, 0x5B, 0x69, 0x5B, 0x69, 0x5B, 0x68, 0x5B, 0x68, 0x5A, 0x6A, 0x5F, 0x6C, 0x5E, 0x6A, 0x5C, 0x69, 0x5B, 0x65, 0x59, 0x69, 0x5F, 0x66, 0x5B, 0x55, 0x4E, 0x48, 0x48, 0x46, 0x47, 0x44, 0x46, 0x45, 0x48, 0x43, 0x46, 0x44, 0x43, 0x4C, 0x47, 0x5A, 0x54, 0x61, 0x57, 0x63, 0x57, 0x63, 0x57, 0x65, 0x58, 0x65, 0x59, 0x62, 0x56, 0x63, 0x56, 0x64, 0x59, 0x66, 0x5B, 0x66, 0x59, 0x62, 0x56, 0x63, 0x58, 0x67, 0x5A, 0x67, 0x5A, 0x64, 0x58, 0x60, 0x55, 0x5F, 0x54, 0x60, 0x54, 0x61, 0x54, 0x5F, 0x54, 0x61, 0x55, 0x60, 0x54, 0x5F, 0x53, 0x62, 0x57, 0x63, 0x57, 0x63, 0x57, 0x5F, 0x53, 0x5D, 0x51, 0x5F, 0x55, 0x61, 0x56, 0x61, 0x57, 0x62, 0x59, 0x65, 0x59, 0x63, 0x57, 0x64, 0x59, 0x63, 0x56, 0x61, 0x57, 0x61, 0x58, 0x61, 0x54, 0x60, 0x55, 0x61, 0x56, 0x62, 0x56, 0x61, 0x56, 0x5D, 0x54, 0x60, 0x55, 0x5F, 0x54, 0x61, 0x55, 0x5F, 0x53, 0x5F, 0x51, 0x5F, 0x53, 0x5B, 0x50, 0x35, 0x2F, 0x27, 0x27, 0x28, 0x2B, 0x24, 0x25, 0x22, 0x25, 0x24, 0x29, 0x26, 0x29, 0x2B, 0x2F, 0x2B, 0x32, 0x2C, 0x33, 0x30, 0x36, 0x30, 0x34, 0x2E, 0x30, 0x25, 0x29, 0x30, 0x38, 0x2F, 0x37, 0x2C, 0x2E, 0x2D, 0x33, 0x2A, 0x31, 0x2C, 0x31, 0x28, 0x2C, 0x2A, 0x2F, 0x2C, 0x30, 0x2B, 0x32, 0x2A, 0x2F, 0x2B, 0x31, 0x2C, 0x2F, 0x2F, 0x37, 0x2B, 0x30, 0x2A, 0x34, 0x2B, 0x35, 0x2F, 0x3C, 0x2C, 0x36, 0x27, 0x34, 0x29, 0x35, 0x28, 0x2F, 0x25, 0x27, 0x24, 0x2C, 0x2E, 0x40, 0x28, 0x41, 0x2A, 0x49, 0x2E, 0x50, 0x30, 0x56, 0x2E, 0x52, 0x2C, 0x50
    },

    {
        0x6C, 0x35, 0x73, 0x38, 0x7B, 0x3B, 0x7E, 0x3C, 0x7F, 0x3D, 0x81, 0x3E, 0x81, 0x3E, 0x81, 0x3E, 0x81, 0x3E, 0x81, 0x3E, 0x82, 0x3F, 0x82, 0x40, 0x82, 0x3F, 0x84, 0x40, 0x84, 0x40, 0x85, 0x40, 0x82, 0x40, 0x7F, 0x3E, 0x78, 0x3A, 0x64, 0x2F, 0x43, 0x22, 0x2E, 0x1A, 0x26, 0x17, 0x22, 0x16, 0x24, 0x19, 0x33, 0x27, 0x56, 0x40, 0x89, 0x5F, 0xAD, 0x73, 0xB9, 0x7A, 0xBF, 0x7D, 0xBF, 0x7D, 0xB5, 0x71, 0x8B, 0x51, 0x53, 0x32, 0x3C, 0x29, 0x45, 0x35, 0x65, 0x4B, 0x89, 0x63, 0x98, 0x6C, 0xA2, 0x72, 0xA5, 0x73, 0xA7, 0x77, 0xAB, 0x77, 0xAB, 0x78, 0xAD, 0x7A, 0xAF, 0x7C, 0xAE, 0x7B, 0xB1, 0x7C, 0xB2, 0x7F, 0xB1, 0x7F, 0xB4, 0x80, 0xB4, 0x81, 0xB5, 0x7F, 0xB4, 0x7F, 0xB3, 0x80, 0xB5, 0x81, 0xB7, 0x81, 0xB8, 0x81, 0xB7, 0x82, 0xB8, 0x82, 0xB4, 0x7D, 0x9F, 0x66, 0x64, 0x3E, 0x3A, 0x27, 0x2D, 0x1E, 0x26, 0x1A, 0x22, 0x17, 0x1E, 0x15, 0x1D, 0x14, 0x1C, 0x13, 0x1C, 0x14, 0x21, 0x1A, 0x3B, 0x33, 0x76, 0x58, 0x92, 0x62, 0x80, 0x51, 0x53, 0x33, 0x33, 0x22, 0x2A, 0x1C, 0x24, 0x18, 0x1F, 0x16, 0x1B, 0x14, 0x19, 0x12, 0x18, 0x11, 0x19, 0x13, 0x25, 0x20, 0x4E, 0x41, 0x8A, 0x66, 0xA6, 0x77, 0xAC, 0x7A, 0xB3, 0x7E, 0xB7, 0x82, 0xBA, 0x85, 0xBC, 0x86, 0xBE, 0x87, 0xC0, 0x89, 0xBF, 0x89, 0xBF, 0x8A, 0xBF, 0x87, 0xBC, 0x86, 0xBC, 0x86, 0xBD, 0x88, 0xC0, 0x8B, 0xC3, 0x8B, 0xC1, 0x88, 0xBF, 0x88, 0xC3, 0x8A, 0xBE, 0x87, 0xBC, 0x86, 0xBB, 0x85, 0xB9, 0x84, 0xA7, 0x71, 0x73, 0x47, 0x3B, 0x26, 0x26, 0x1A, 0x21, 0x1D, 0x26, 0x31, 0x2D, 0x3E, 0x2F, 0x43, 0x32, 0x46, 0x32, 0x47, 0x32, 0x48, 0x32, 0x46, 0x30, 0x42, 0x29, 0x30, 0x1F, 0x1D, 0x1A, 0x16, 0x1A, 0x14, 0x21, 0x1A, 0x2D, 0x22, 0x2F, 0x23, 0x32, 0x25, 0x31, 0x25, 0x33, 0x26, 0x33, 0x24, 0x31, 0x24, 0x32, 0x26, 0x32, 0x25, 0x34, 0x26, 0x34, 0x26, 0x34, 0x26, 0x33, 0x25, 0x32, 0x25, 0x33, 0x26, 0x33, 0x25, 0x32, 0x25, 0x32, 0x26, 0x33, 0x27, 0x3B, 0x2B, 0x3A, 0x29, 0x35, 0x27, 0x34, 0x26, 0x33, 0x25, 0x31, 0x24, 0x31, 0x24, 0x33, 0x25, 0x31, 0x23, 0x29, 0x1B, 0x1C, 0x13, 0x17, 0x10, 0x16, 0x0F, 0x16, 0x0F, 0x16, 0x0E, 0x16, 0x0F, 0x16, 0x0F, 0x1E, 0x14, 0x41, 0x1C, 0x57, 0x20, 0x5C, 0x21, 0x59, 0x21, 0x3A, 0x1B, 0x34, 0x1C, 0x51, 0x21, 0x5F, 0x23, 0x64, 0x23, 0x65, 0x23, 0x62, 0x23, 0x60, 0x22, 0x62, 0x23, 0x5E, 0x21, 0x60, 0x22, 0x63, 0x23, 0x5E, 0x22, 0x61, 0x23, 0x62, 0x23, 0x65, 0x24, 0x61, 0x22, 0x62, 0x23, 0x62, 0x23, 0x63, 0x24, 0x68, 0x26, 0x65, 0x26, 0x66, 0x27, 0x67, 0x26, 0x65, 0x25, 0x63, 0x24, 0x62, 0x23, 0x5F, 0x22, 0x61, 0x22, 0x62, 0x22, 0x62, 0x23, 0x65, 0x24, 0x62, 0x22, 0x5F, 0x21, 0x5F, 0x22, 0x5F, 0x22, 0x5E, 0x22, 0x5E, 0x21, 0x5E, 0x21, 0x5D, 0x22, 0x5C, 0x21, 0x5D, 0x20, 0x5C, 0x20, 0x5B, 0x21, 0x4C, 0x23, 0x48, 0x23, 0x47, 0x22, 0x47, 0x22, 0x46, 0x22, 0x46, 0x21, 0x45, 0x20, 0x42, 0x1C, 0x4C, 0x1D, 0x57, 0x20, 0x58, 0x20, 0x5C, 0x22, 0x5B, 0x21, 0x56, 0x1F, 0x57, 0x20, 0x5A, 0x20, 0x5A, 0x21, 0x5E, 0x22, 0x5B, 0x21, 0x5A, 0x21, 0x57, 0x20, 0x59, 0x20, 0x5C, 0x21, 0x59, 0x20, 0x5B, 0x20, 0x58, 0x1F, 0x56, 0x1E, 0x57, 0x20, 0x5B, 0x20, 0x59, 0x20, 0x58, 0x1F, 0x58, 0x1F, 0x59, 0x20, 0x58, 0x20, 0x5B, 0x21, 0x57, 0x20, 0x54, 0x1F, 0x59, 0x20, 0x57, 0x20, 0x5A, 0x21, 0x58, 0x20, 0x57, 0x20, 0x57, 0x1F, 0x56, 0x1F, 0x56, 0x1F, 0x57, 0x20, 0x58, 0x20, 0x56, 0x1F, 0x55, 0x20, 0x56, 0x20, 0x58, 0x20, 0x5A, 0x20, 0x57, 0x21, 0x58, 0x20, 0x59, 0x20, 0x58, 0x20, 0x55, 0x20, 0x53, 0x1F, 0x56, 0x1F, 0x55, 0x1F, 0x39, 0x1A, 0x36, 0x1C, 0x2D, 0x19, 0x29, 0x17, 0x30, 0x1B, 0x31, 0x1B, 0x31, 0x1B, 0x36, 0x1D, 0x35, 0x1D, 0x33, 0x1D, 0x33, 0x1C, 0x30, 0x1B, 0x2B, 0x19, 0x2F, 0x1B, 0x36, 0x1D, 0x2E, 0x19, 0x2C, 0x19, 0x2F, 0x1B, 0x35, 0x1F, 0x31, 0x1D, 0x3A, 0x23, 0x40, 0x24, 0x40, 0x25, 0x41, 0x25, 0x31, 0x1B, 0x31, 0x1A, 0x2D, 0x1A, 0x35, 0x20, 0x46, 0x2A, 0x52, 0x31, 0x51, 0x31, 0x58, 0x35, 0x55, 0x32, 0x5B, 0x37, 0x4B, 0x2A, 0x32, 0x1E, 0x28, 0x18, 0x2E, 0x1C, 0x54, 0x35, 0x64, 0x3C, 0x67, 0x3F, 0x69, 0x3F, 0x69, 0x3E, 0x66, 0x3E, 0x63, 0x3B
    },

    {
        0x63, 0x6E, 0x6A, 0x73, 0x70, 0x78, 0x72, 0x7A, 0x73, 0x7C, 0x76, 0x7D, 0x76, 0x7D, 0x76, 0x7C, 0x77, 0x7D, 0x77, 0x7E, 0x77, 0x7F, 0x79, 0x7F, 0x77, 0x80, 0x78, 0x7E, 0x7A, 0x81, 0x7A, 0x81, 0x78, 0x81, 0x75, 0x7D, 0x6F, 0x76, 0x61, 0x65, 0x46, 0x45, 0x2E, 0x2F, 0x25, 0x27, 0x20, 0x23, 0x22, 0x28, 0x2E, 0x3C, 0x47, 0x66, 0x6C, 0x96, 0x85, 0xAF, 0x8E, 0xB7, 0x91, 0xBA, 0x93, 0xBD, 0x8B, 0xB5, 0x77, 0x8F, 0x4D, 0x56, 0x33, 0x41, 0x31, 0x4F, 0x3B, 0x72, 0x4A, 0x8D, 0x4E, 0x97, 0x50, 0x9D, 0x50, 0x9F, 0x51, 0xA2, 0x54, 0xA4, 0x53, 0xA6, 0x56, 0xA7, 0x55, 0xA8, 0x55, 0xA9, 0x56, 0xA8, 0x57, 0xAB, 0x57, 0xAB, 0x58, 0xAD, 0x58, 0xAD, 0x59, 0xAF, 0x58, 0xAE, 0x59, 0xAE, 0x59, 0xAE, 0x59, 0xB0, 0x5A, 0xB0, 0x5C, 0xB1, 0x5C, 0xB1, 0x5A, 0xAF, 0x53, 0x9C, 0x3C, 0x66, 0x27, 0x3B, 0x1F, 0x2C, 0x1C, 0x25, 0x19, 0x21, 0x17, 0x1E, 0x16, 0x1C, 0x16, 0x1B, 0x17, 0x1B, 0x1A, 0x1F, 0x26, 0x35, 0x49, 0x6B, 0x62, 0x83, 0x58, 0x6A, 0x3A, 0x40, 0x25, 0x2B, 0x20, 0x26, 0x1B, 0x20, 0x17, 0x1C, 0x15, 0x19, 0x14, 0x18, 0x13, 0x17, 0x14, 0x1B, 0x1C, 0x30, 0x2E, 0x62, 0x47, 0x93, 0x52, 0xA4, 0x55, 0xA8, 0x57, 0xAC, 0x59, 0xB1, 0x5A, 0xB2, 0x5C, 0xB4, 0x5D, 0xB5, 0x5D, 0xB7, 0x5D, 0xB7, 0x5D, 0xB7, 0x5C, 0xB5, 0x5B, 0xB3, 0x5B, 0xB5, 0x5D, 0xB5, 0x5E, 0xBB, 0x5F, 0xB9, 0x5F, 0xB7, 0x5E, 0xB6, 0x5F, 0xB8, 0x5E, 0xB6, 0x5C, 0xB5, 0x5C, 0xB3, 0x59, 0xAF, 0x50, 0x93, 0x37, 0x57, 0x21, 0x2F, 0x19, 0x21, 0x16, 0x1E, 0x18, 0x23, 0x1C, 0x2A, 0x1D, 0x2D, 0x1E, 0x30, 0x1F, 0x30, 0x1F, 0x30, 0x1E, 0x30, 0x1D, 0x2D, 0x1A, 0x25, 0x16, 0x1C, 0x14, 0x18, 0x13, 0x18, 0x15, 0x1E, 0x1A, 0x2A, 0x1B, 0x2D, 0x1C, 0x30, 0x1D, 0x30, 0x1D, 0x31, 0x1D, 0x30, 0x1C, 0x2F, 0x1D, 0x31, 0x1E, 0x31, 0x1E, 0x32, 0x1E, 0x33, 0x1E, 0x32, 0x1D, 0x31, 0x1E, 0x31, 0x1D, 0x30, 0x1D, 0x30, 0x1D, 0x31, 0x1E, 0x31, 0x1E, 0x31, 0x23, 0x3A, 0x23, 0x37, 0x1E, 0x33, 0x1E, 0x32, 0x1D, 0x2F, 0x1E, 0x30, 0x1D, 0x31, 0x1E, 0x31, 0x1E, 0x30, 0x1B, 0x29, 0x16, 0x1C, 0x14, 0x17, 0x13, 0x15, 0x13, 0x15, 0x12, 0x15, 0x12, 0x15, 0x14, 0x15, 0x1A, 0x1D, 0x39, 0x3B, 0x57, 0x55, 0x62, 0x59, 0x64, 0x5B, 0x45, 0x3C, 0x35, 0x32, 0x50, 0x4F, 0x63, 0x5C, 0x6B, 0x62, 0x6E, 0x63, 0x6E, 0x60, 0x6B, 0x5F, 0x6E, 0x60, 0x69, 0x5C, 0x6A, 0x5E, 0x6D, 0x5F, 0x6A, 0x5B, 0x6D, 0x60, 0x6B, 0x5F, 0x6F, 0x61, 0x6B, 0x5E, 0x6D, 0x61, 0x6C, 0x5F, 0x6D, 0x61, 0x70, 0x65, 0x6E, 0x62, 0x6E, 0x65, 0x6F, 0x64, 0x6C, 0x60, 0x6B, 0x60, 0x6D, 0x5E, 0x6B, 0x5E, 0x6B, 0x5E, 0x6D, 0x60, 0x6D, 0x60, 0x6E, 0x61, 0x6E, 0x60, 0x6A, 0x5C, 0x6A, 0x5E, 0x6A, 0x5E, 0x6A, 0x5E, 0x68, 0x5C, 0x6A, 0x5B, 0x68, 0x5A, 0x68, 0x5C, 0x68, 0x59, 0x66, 0x59, 0x62, 0x55, 0x4C, 0x49, 0x45, 0x45, 0x44, 0x46, 0x44, 0x45, 0x43, 0x44, 0x44, 0x44, 0x42, 0x42, 0x41, 0x3E, 0x4F, 0x4A, 0x5B, 0x53, 0x61, 0x57, 0x66, 0x5A, 0x65, 0x59, 0x61, 0x54, 0x62, 0x57, 0x65, 0x59, 0x64, 0x59, 0x67, 0x5A, 0x66, 0x59, 0x65, 0x59, 0x63, 0x56, 0x62, 0x57, 0x67, 0x5A, 0x63, 0x57, 0x67, 0x5A, 0x62, 0x56, 0x61, 0x54, 0x63, 0x57, 0x66, 0x58, 0x62, 0x56, 0x62, 0x56, 0x63, 0x56, 0x63, 0x56, 0x62, 0x56, 0x64, 0x59, 0x61, 0x55, 0x5F, 0x54, 0x62, 0x56, 0x62, 0x56, 0x63, 0x58, 0x61, 0x57, 0x5F, 0x55, 0x61, 0x55, 0x61, 0x54, 0x60, 0x55, 0x5F, 0x55, 0x60, 0x56, 0x62, 0x55, 0x61, 0x55, 0x60, 0x55, 0x62, 0x57, 0x64, 0x58, 0x62, 0x57, 0x61, 0x56, 0x60, 0x56, 0x62, 0x56, 0x60, 0x54, 0x5D, 0x52, 0x5E, 0x55, 0x5D, 0x50, 0x3C, 0x37, 0x34, 0x36, 0x2A, 0x2B, 0x26, 0x2B, 0x2D, 0x31, 0x2C, 0x32, 0x2D, 0x33, 0x2D, 0x34, 0x2B, 0x33, 0x2A, 0x32, 0x27, 0x2E, 0x28, 0x31, 0x24, 0x2D, 0x28, 0x31, 0x2A, 0x2F, 0x27, 0x28, 0x27, 0x2A, 0x28, 0x32, 0x2B, 0x3D, 0x27, 0x38, 0x2B, 0x46, 0x2E, 0x48, 0x2C, 0x47, 0x2D, 0x47, 0x26, 0x30, 0x2A, 0x2E, 0x27, 0x2C, 0x28, 0x3B, 0x2C, 0x4E, 0x2F, 0x59, 0x2C, 0x56, 0x2E, 0x5C, 0x2C, 0x5A, 0x2D, 0x5C, 0x29, 0x44, 0x26, 0x2F, 0x23, 0x29, 0x27, 0x33, 0x2D, 0x57, 0x2F, 0x62, 0x30, 0x64, 0x30, 0x65, 0x30, 0x63, 0x2E, 0x62, 0x2D, 0x5B
    },

    {
        0x75, 0x39, 0x78, 0x3A, 0x7B, 0x3C, 0x7D, 0x3C, 0x7E, 0x3C, 0x81, 0x3E, 0x80, 0x3E, 0x82, 0x3F, 0x83, 0x3F, 0x82, 0x3E, 0x84, 0x3F, 0x83, 0x40, 0x84, 0x3F, 0x85, 0x41, 0x86, 0x40, 0x83, 0x40, 0x83, 0x3F, 0x82, 0x40, 0x81, 0x3F, 0x7C, 0x3C, 0x6B, 0x32, 0x48, 0x24, 0x2E, 0x1A, 0x29, 0x1B, 0x33, 0x25, 0x51, 0x3D, 0x85, 0x5D, 0xAC, 0x73, 0xBF, 0x7E, 0xC8, 0x84, 0xCB, 0x86, 0xCE, 0x86, 0xCA, 0x82, 0xBF, 0x76, 0x97, 0x5A, 0x65, 0x41, 0x65, 0x4B, 0x86, 0x61, 0x97, 0x6B, 0x9D, 0x6F, 0xA4, 0x73, 0xA8, 0x76, 0xAA, 0x79, 0xAB, 0x7A, 0xB0, 0x7A, 0xAF, 0x7C, 0xAE, 0x7A, 0xAE, 0x7A, 0xAF, 0x7D, 0xB2, 0x7D, 0xB3, 0x80, 0xB4, 0x7F, 0xB3, 0x7E, 0xB5, 0x80, 0xB6, 0x80, 0xB4, 0x81, 0xB6, 0x82, 0xB9, 0x83, 0xB9, 0x81, 0xB9, 0x84, 0xBC, 0x85, 0xBC, 0x84, 0xB6, 0x7F, 0xA5, 0x6D, 0x70, 0x45, 0x41, 0x29, 0x2E, 0x1F, 0x27, 0x1A, 0x22, 0x17, 0x1F, 0x15, 0x1C, 0x13, 0x1B, 0x13, 0x1B, 0x14, 0x1F, 0x18, 0x33, 0x2B, 0x58, 0x3D, 0x4A, 0x2E, 0x2E, 0x1F, 0x27, 0x1B, 0x24, 0x19, 0x1F, 0x16, 0x1C, 0x13, 0x19, 0x12, 0x18, 0x12, 0x1A, 0x13, 0x23, 0x20, 0x4A, 0x3E, 0x84, 0x64, 0xA6, 0x77, 0xAC, 0x7C, 0xB5, 0x81, 0xB6, 0x82, 0xBB, 0x83, 0xBB, 0x85, 0xBD, 0x86, 0xBE, 0x88, 0xBD, 0x86, 0xBC, 0x87, 0xBE, 0x88, 0xBC, 0x86, 0xBC, 0x85, 0xBE, 0x87, 0xBD, 0x87, 0xBF, 0x88, 0xC3, 0x89, 0xBF, 0x89, 0xBC, 0x86, 0xBF, 0x89, 0xBF, 0x89, 0xBF, 0x86, 0xB8, 0x83, 0xAB, 0x74, 0x7B, 0x4C, 0x3F, 0x28, 0x29, 0x1C, 0x20, 0x16, 0x1B, 0x14, 0x1A, 0x18, 0x24, 0x2D, 0x2D, 0x3D, 0x30, 0x44, 0x31, 0x46, 0x33, 0x48, 0x31, 0x44, 0x2B, 0x33, 0x20, 0x1E, 0x1B, 0x16, 0x19, 0x13, 0x18, 0x11, 0x19, 0x12, 0x1F, 0x19, 0x2D, 0x21, 0x31, 0x24, 0x32, 0x25, 0x33, 0x25, 0x32, 0x25, 0x33, 0x26, 0x34, 0x26, 0x33, 0x26, 0x33, 0x26, 0x33, 0x25, 0x33, 0x26, 0x32, 0x25, 0x32, 0x25, 0x30, 0x24, 0x30, 0x24, 0x33, 0x25, 0x34, 0x25, 0x35, 0x27, 0x39, 0x2A, 0x3B, 0x29, 0x35, 0x27, 0x34, 0x25, 0x33, 0x25, 0x31, 0x24, 0x32, 0x24, 0x32, 0x24, 0x32, 0x25, 0x33, 0x25, 0x2B, 0x1C, 0x1D, 0x13, 0x18, 0x10, 0x17, 0x0F, 0x16, 0x0E, 0x16, 0x0F, 0x16, 0x0F, 0x17, 0x0F, 0x1C, 0x13, 0x3F, 0x1C, 0x58, 0x21, 0x60, 0x24, 0x5E, 0x22, 0x3D, 0x1B, 0x30, 0x1A, 0x4F, 0x20, 0x60, 0x23, 0x64, 0x23, 0x66, 0x24, 0x62, 0x23, 0x60, 0x22, 0x62, 0x22, 0x5F, 0x23, 0x62, 0x23, 0x62, 0x22, 0x61, 0x22, 0x60, 0x22, 0x5F, 0x23, 0x61, 0x22, 0x63, 0x23, 0x62, 0x23, 0x64, 0x24, 0x66, 0x25, 0x67, 0x25, 0x63, 0x24, 0x63, 0x24, 0x63, 0x23, 0x62, 0x23, 0x63, 0x23, 0x60, 0x22, 0x5E, 0x22, 0x5F, 0x22, 0x60, 0x22, 0x62, 0x23, 0x61, 0x22, 0x60, 0x22, 0x62, 0x23, 0x60, 0x22, 0x63, 0x25, 0x5F, 0x23, 0x5D, 0x21, 0x5D, 0x22, 0x61, 0x23, 0x5C, 0x20, 0x5A, 0x20, 0x53, 0x1F, 0x44, 0x21, 0x47, 0x22, 0x48, 0x23, 0x4A, 0x23, 0x48, 0x23, 0x49, 0x23, 0x44, 0x1F, 0x34, 0x17, 0x40, 0x1B, 0x57, 0x1F, 0x5A, 0x20, 0x5D, 0x21, 0x5A, 0x20, 0x5A, 0x21, 0x59, 0x20, 0x5A, 0x20, 0x5B, 0x21, 0x59, 0x20, 0x5A, 0x20, 0x5A, 0x20, 0x58, 0x1F, 0x58, 0x20, 0x5B, 0x21, 0x59, 0x20, 0x59, 0x20, 0x59, 0x20, 0x5B, 0x20, 0x58, 0x1F, 0x57, 0x1F, 0x5A, 0x20, 0x59, 0x20, 0x58, 0x20, 0x59, 0x1F, 0x58, 0x20, 0x58, 0x20, 0x59, 0x20, 0x56, 0x20, 0x5A, 0x21, 0x5B, 0x21, 0x59, 0x20, 0x58, 0x20, 0x58, 0x1F, 0x57, 0x20, 0x59, 0x20, 0x57, 0x20, 0x57, 0x20, 0x59, 0x1F, 0x59, 0x20, 0x59, 0x21, 0x56, 0x1F, 0x59, 0x20, 0x57, 0x20, 0x58, 0x20, 0x58, 0x20, 0x58, 0x20, 0x55, 0x1F, 0x57, 0x20, 0x55, 0x1F, 0x55, 0x1F, 0x51, 0x1E, 0x40, 0x1E, 0x39, 0x1C, 0x2E, 0x1A, 0x33, 0x1C, 0x32, 0x1B, 0x34, 0x1E, 0x3F, 0x24, 0x48, 0x29, 0x48, 0x2A, 0x49, 0x2C, 0x4B, 0x2D, 0x53, 0x30, 0x51, 0x30, 0x3E, 0x21, 0x25, 0x17, 0x24, 0x16, 0x2C, 0x1B, 0x4B, 0x2D, 0x5C, 0x36, 0x5F, 0x38, 0x61, 0x38, 0x63, 0x39, 0x61, 0x38, 0x59, 0x30, 0x2E, 0x1B, 0x29, 0x18, 0x31, 0x1C, 0x3E, 0x27, 0x5C, 0x36, 0x62, 0x39, 0x62, 0x3A, 0x61, 0x3A, 0x61, 0x38, 0x60, 0x37, 0x44, 0x25, 0x26, 0x19, 0x2E, 0x1A, 0x34, 0x1E, 0x53, 0x32, 0x5B, 0x36, 0x5B, 0x37, 0x5B, 0x36, 0x57, 0x34, 0x52, 0x32, 0x4E, 0x2E
    },

    {
        0x6A, 0x72, 0x6F, 0x76, 0x71, 0x7A, 0x72, 0x7A, 0x73, 0x7C, 0x74, 0x7D, 0x75, 0x7E, 0x77, 0x7E, 0x77, 0x7E, 0x77, 0x7E, 0x78, 0x7F, 0x78, 0x7F, 0x79, 0x80, 0x7B, 0x82, 0x7B, 0x80, 0x7A, 0x81, 0x7A, 0x80, 0x79, 0x80, 0x77, 0x7F, 0x72, 0x79, 0x65, 0x6B, 0x4B, 0x4A, 0x30, 0x30, 0x28, 0x2C, 0x2E, 0x3C, 0x43, 0x61, 0x68, 0x93, 0x83, 0xB0, 0x90, 0xBC, 0x97, 0xC2, 0x9A, 0xC7, 0x9D, 0xC7, 0x9A, 0xC4, 0x92, 0xBA, 0x79, 0x97, 0x54, 0x6B, 0x43, 0x6E, 0x49, 0x89, 0x4E, 0x94, 0x4F, 0x98, 0x50, 0x9E, 0x52, 0xA3, 0x54, 0xA4, 0x54, 0xA6, 0x55, 0xA6, 0x56, 0xA7, 0x56, 0xA7, 0x54, 0xA7, 0x56, 0xA7, 0x56, 0xAA, 0x57, 0xAC, 0x57, 0xAB, 0x57, 0xAB, 0x57, 0xAD, 0x58, 0xAC, 0x58, 0xAD, 0x5A, 0xAF, 0x5A, 0xB0, 0x5B, 0xB1, 0x5B, 0xB3, 0x5C, 0xB2, 0x5D, 0xB3, 0x5A, 0xB0, 0x54, 0xA2, 0x41, 0x72, 0x2A, 0x40, 0x1F, 0x2D, 0x1B, 0x27, 0x1A, 0x22, 0x17, 0x1E, 0x16, 0x1B, 0x15, 0x19, 0x15, 0x1A, 0x18, 0x1D, 0x21, 0x2C, 0x34, 0x46, 0x31, 0x37, 0x21, 0x26, 0x1D, 0x23, 0x1B, 0x20, 0x17, 0x1D, 0x15, 0x1A, 0x14, 0x18, 0x13, 0x18, 0x15, 0x1B, 0x1B, 0x2D, 0x2C, 0x5C, 0x45, 0x8F, 0x51, 0xA3, 0x54, 0xA9, 0x58, 0xAE, 0x58, 0xB1, 0x5A, 0xB2, 0x5B, 0xB3, 0x5C, 0xB7, 0x5C, 0xB6, 0x5D, 0xB4, 0x5D, 0xB6, 0x5E, 0xB8, 0x5C, 0xB2, 0x5B, 0xB2, 0x5C, 0xB4, 0x5C, 0xB5, 0x5D, 0xB7, 0x5F, 0xB9, 0x5E, 0xB8, 0x5C, 0xB5, 0x5E, 0xB6, 0x5D, 0xB7, 0x5C, 0xB4, 0x59, 0xAF, 0x50, 0x97, 0x3A, 0x5E, 0x22, 0x31, 0x1A, 0x22, 0x15, 0x1C, 0x13, 0x18, 0x13, 0x19, 0x17, 0x22, 0x1C, 0x2A, 0x1D, 0x2E, 0x1E, 0x2F, 0x20, 0x31, 0x1E, 0x2F, 0x1A, 0x26, 0x16, 0x1D, 0x14, 0x19, 0x13, 0x17, 0x12, 0x16, 0x13, 0x18, 0x16, 0x1E, 0x19, 0x2A, 0x1C, 0x30, 0x1E, 0x32, 0x1D, 0x30, 0x1D, 0x31, 0x1E, 0x32, 0x1E, 0x32, 0x1E, 0x32, 0x1D, 0x31, 0x1D, 0x31, 0x1C, 0x31, 0x1C, 0x30, 0x1C, 0x2F, 0x1C, 0x2F, 0x1C, 0x2F, 0x1E, 0x32, 0x1E, 0x31, 0x1E, 0x33, 0x21, 0x38, 0x22, 0x35, 0x1F, 0x33, 0x1E, 0x31, 0x1E, 0x31, 0x1D, 0x30, 0x1D, 0x2F, 0x1D, 0x2F, 0x1D, 0x30, 0x1F, 0x32, 0x1D, 0x2A, 0x16, 0x1C, 0x14, 0x17, 0x13, 0x16, 0x13, 0x15, 0x13, 0x16, 0x13, 0x15, 0x13, 0x16, 0x19, 0x1B, 0x37, 0x3C, 0x58, 0x56, 0x67, 0x5F, 0x68, 0x5D, 0x48, 0x3C, 0x30, 0x2E, 0x4D, 0x4C, 0x65, 0x5D, 0x6B, 0x61, 0x6F, 0x63, 0x6E, 0x60, 0x6C, 0x5D, 0x6B, 0x60, 0x6A, 0x5D, 0x6C, 0x60, 0x6E, 0x62, 0x6B, 0x5F, 0x6A, 0x5E, 0x6A, 0x5E, 0x6C, 0x60, 0x6D, 0x60, 0x6C, 0x60, 0x6D, 0x62, 0x6E, 0x62, 0x70, 0x64, 0x6E, 0x61, 0x6F, 0x61, 0x6C, 0x5E, 0x6E, 0x60, 0x6E, 0x62, 0x6A, 0x5E, 0x68, 0x5C, 0x69, 0x5E, 0x6A, 0x5F, 0x6E, 0x61, 0x6D, 0x5E, 0x6C, 0x5E, 0x6C, 0x5E, 0x6C, 0x5F, 0x6E, 0x63, 0x68, 0x5C, 0x68, 0x5C, 0x68, 0x5B, 0x6B, 0x5F, 0x68, 0x59, 0x66, 0x58, 0x5C, 0x4D, 0x47, 0x43, 0x45, 0x46, 0x44, 0x47, 0x46, 0x48, 0x44, 0x46, 0x45, 0x47, 0x40, 0x3F, 0x33, 0x2F, 0x46, 0x45, 0x5F, 0x56, 0x65, 0x58, 0x66, 0x5A, 0x63, 0x58, 0x63, 0x58, 0x61, 0x56, 0x63, 0x57, 0x65, 0x59, 0x64, 0x58, 0x64, 0x57, 0x63, 0x56, 0x62, 0x56, 0x61, 0x55, 0x63, 0x58, 0x61, 0x55, 0x62, 0x56, 0x63, 0x58, 0x64, 0x57, 0x61, 0x55, 0x63, 0x58, 0x66, 0x58, 0x64, 0x57, 0x61, 0x57, 0x64, 0x59, 0x61, 0x54, 0x61, 0x56, 0x62, 0x56, 0x60, 0x54, 0x63, 0x57, 0x64, 0x58, 0x63, 0x58, 0x64, 0x58, 0x64, 0x57, 0x62, 0x55, 0x63, 0x56, 0x62, 0x56, 0x62, 0x56, 0x64, 0x58, 0x64, 0x58, 0x63, 0x58, 0x5F, 0x56, 0x62, 0x58, 0x60, 0x54, 0x61, 0x57, 0x61, 0x56, 0x60, 0x55, 0x5F, 0x53, 0x5E, 0x55, 0x5F, 0x54, 0x5F, 0x53, 0x5B, 0x50, 0x3F, 0x3A, 0x34, 0x35, 0x29, 0x2B, 0x2D, 0x33, 0x2B, 0x2D, 0x2D, 0x35, 0x2E, 0x42, 0x2F, 0x4E, 0x2B, 0x4E, 0x2C, 0x50, 0x2C, 0x53, 0x2F, 0x57, 0x2E, 0x56, 0x28, 0x36, 0x20, 0x25, 0x22, 0x24, 0x28, 0x31, 0x2C, 0x51, 0x2E, 0x5C, 0x2F, 0x60, 0x2E, 0x5F, 0x2E, 0x60, 0x2E, 0x5E, 0x2B, 0x50, 0x1F, 0x29, 0x23, 0x29, 0x2C, 0x33, 0x28, 0x41, 0x2D, 0x58, 0x2D, 0x5B, 0x2E, 0x5C, 0x2E, 0x5D, 0x2C, 0x5A, 0x2C, 0x59, 0x23, 0x36, 0x1D, 0x27, 0x26, 0x2C, 0x2A, 0x37, 0x2B, 0x4F, 0x2A, 0x51, 0x29, 0x4F, 0x28, 0x4C, 0x25, 0x45, 0x23, 0x43, 0x21, 0x3B
    },

    {
        0x7C, 0x3A, 0x7A, 0x3B, 0x7D, 0x3C, 0x7E, 0x3D, 0x7F, 0x3D, 0x80, 0x3E, 0x81, 0x3F, 0x80, 0x3E, 0x82, 0x3E, 0x81, 0x3E, 0x82, 0x3F, 0x83, 0x3F, 0x83, 0x40, 0x86, 0x41, 0x86, 0x41, 0x85, 0x41, 0x85, 0x41, 0x83, 0x41, 0x85, 0x40, 0x82, 0x3F, 0x7C, 0x3D, 0x6C, 0x34, 0x4C, 0x28, 0x3B, 0x27, 0x50, 0x3B, 0x7E, 0x58, 0xA9, 0x70, 0xB8, 0x79, 0xC3, 0x7F, 0xC8, 0x84, 0xCC, 0x87, 0xCF, 0x89, 0xD1, 0x87, 0xC6, 0x7F, 0xB1, 0x6E, 0x8E, 0x57, 0x76, 0x51, 0x89, 0x5F, 0x97, 0x6A, 0x9D, 0x6F, 0xA3, 0x73, 0xA6, 0x76, 0xAA, 0x79, 0xAB, 0x79, 0xAB, 0x7A, 0xB0, 0x7C, 0xB0, 0x7C, 0xB0, 0x7C, 0xB1, 0x7D, 0xB1, 0x7D, 0xB3, 0x7E, 0xB2, 0x7E, 0xB1, 0x7E, 0xB3, 0x7E, 0xB3, 0x81, 0xB6, 0x82, 0xB8, 0x82, 0xB7, 0x81, 0xB9, 0x83, 0xBB, 0x84, 0xBB, 0x85, 0xBC, 0x84, 0xB9, 0x83, 0xB7, 0x80, 0xAC, 0x72, 0x7A, 0x4B, 0x43, 0x2C, 0x2F, 0x20, 0x27, 0x1B, 0x22, 0x17, 0x1E, 0x15, 0x1B, 0x13, 0x19, 0x12, 0x1A, 0x13, 0x1E, 0x17, 0x24, 0x1B, 0x25, 0x19, 0x21, 0x18, 0x20, 0x17, 0x1F, 0x16, 0x1C, 0x14, 0x1A, 0x12, 0x19, 0x12, 0x18, 0x12, 0x22, 0x1E, 0x46, 0x3B, 0x80, 0x61, 0xA2, 0x75, 0xAD, 0x7C, 0xB5, 0x80, 0xBA, 0x84, 0xBA, 0x85, 0xBC, 0x86, 0xBA, 0x85, 0xBC, 0x87, 0xBC, 0x88, 0xBC, 0x87, 0xBE, 0x88, 0xBC, 0x86, 0xBB, 0x85, 0xBA, 0x85, 0xBD, 0x87, 0xBE, 0x88, 0xC0, 0x89, 0xC4, 0x8C, 0xC3, 0x8A, 0xBF, 0x88, 0xC0, 0x89, 0xBE, 0x89, 0xBD, 0x87, 0xAF, 0x78, 0x7E, 0x50, 0x42, 0x2B, 0x2A, 0x1C, 0x20, 0x17, 0x1B, 0x13, 0x18, 0x11, 0x18, 0x11, 0x19, 0x17, 0x21, 0x29, 0x2B, 0x3D, 0x2F, 0x44, 0x31, 0x44, 0x2B, 0x33, 0x21, 0x1F, 0x1B, 0x16, 0x19, 0x13, 0x18, 0x11, 0x17, 0x11, 0x18, 0x11, 0x19, 0x13, 0x20, 0x19, 0x2E, 0x21, 0x31, 0x25, 0x32, 0x25, 0x34, 0x26, 0x35, 0x27, 0x32, 0x25, 0x34, 0x26, 0x32, 0x25, 0x32, 0x26, 0x32, 0x25, 0x30, 0x25, 0x31, 0x25, 0x31, 0x24, 0x30, 0x23, 0x32, 0x25, 0x32, 0x25, 0x32, 0x25, 0x34, 0x26, 0x35, 0x27, 0x33, 0x27, 0x34, 0x26, 0x33, 0x25, 0x32, 0x25, 0x32, 0x24, 0x31, 0x24, 0x32, 0x25, 0x34, 0x25, 0x31, 0x24, 0x2C, 0x1C, 0x1A, 0x12, 0x17, 0x10, 0x16, 0x0F, 0x17, 0x0F, 0x16, 0x0F, 0x17, 0x0F, 0x18, 0x10, 0x1D, 0x13, 0x43, 0x1E, 0x5D, 0x23, 0x65, 0x25, 0x56, 0x1F, 0x2E, 0x17, 0x31, 0x1A, 0x57, 0x22, 0x60, 0x22, 0x65, 0x23, 0x62, 0x23, 0x60, 0x22, 0x5E, 0x22, 0x61, 0x23, 0x5D, 0x21, 0x61, 0x22, 0x60, 0x22, 0x61, 0x22, 0x60, 0x23, 0x61, 0x22, 0x60, 0x22, 0x62, 0x24, 0x63, 0x24, 0x63, 0x24, 0x63, 0x22, 0x64, 0x23, 0x65, 0x24, 0x62, 0x22, 0x63, 0x23, 0x61, 0x22, 0x5D, 0x22, 0x64, 0x24, 0x63, 0x23, 0x61, 0x22, 0x62, 0x23, 0x5F, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x6D, 0x2D, 0x62, 0x23, 0x5B, 0x20, 0x5D, 0x21, 0x5A, 0x20, 0x5B, 0x21, 0x5F, 0x21, 0x53, 0x1F, 0x3F, 0x1D, 0x46, 0x21, 0x47, 0x23, 0x49, 0x24, 0x47, 0x23, 0x49, 0x23, 0x3E, 0x1C, 0x29, 0x14, 0x3F, 0x1B, 0x58, 0x21, 0x5C, 0x21, 0x5A, 0x21, 0x57, 0x20, 0x5A, 0x20, 0x5A, 0x20, 0x58, 0x20, 0x59, 0x20, 0x5C, 0x21, 0x59, 0x20, 0x58, 0x20, 0x56, 0x1F, 0x57, 0x1F, 0x57, 0x20, 0x55, 0x1F, 0x58, 0x20, 0x57, 0x20, 0x5A, 0x20, 0x55, 0x1F, 0x59, 0x21, 0x5A, 0x20, 0x58, 0x20, 0x58, 0x20, 0x5A, 0x20, 0x59, 0x20, 0x56, 0x20, 0x56, 0x20, 0x52, 0x1E, 0x53, 0x1F, 0x57, 0x21, 0x58, 0x20, 0x59, 0x20, 0x5B, 0x20, 0x58, 0x1F, 0x56, 0x20, 0x57, 0x20, 0x57, 0x20, 0x57, 0x20, 0x58, 0x20, 0x58, 0x20, 0x58, 0x20, 0x57, 0x20, 0x57, 0x20, 0x58, 0x20, 0x57, 0x20, 0x58, 0x21, 0x56, 0x20, 0x54, 0x1F, 0x56, 0x1F, 0x55, 0x1F, 0x52, 0x1E, 0x3A, 0x1B, 0x2E, 0x18, 0x28, 0x18, 0x2B, 0x18, 0x25, 0x16, 0x2B, 0x19, 0x41, 0x2A, 0x60, 0x37, 0x64, 0x3A, 0x64, 0x39, 0x63, 0x39, 0x64, 0x39, 0x5E, 0x34, 0x35, 0x1E, 0x27, 0x18, 0x2E, 0x1B, 0x39, 0x1F, 0x4D, 0x2F, 0x5F, 0x36, 0x5F, 0x37, 0x5F, 0x36, 0x5E, 0x37, 0x59, 0x34, 0x50, 0x2C, 0x25, 0x17, 0x33, 0x1D, 0x33, 0x1D, 0x3A, 0x22, 0x46, 0x29, 0x41, 0x28, 0x40, 0x27, 0x3B, 0x24, 0x38, 0x22, 0x32, 0x1F, 0x28, 0x19, 0x27, 0x19, 0x27, 0x17, 0x2A, 0x1A, 0x2F, 0x1B, 0x27, 0x1A, 0x22, 0x17, 0x20, 0x16, 0x1F, 0x15, 0x1E, 0x14, 0x1D, 0x13
    },

    {
        0x6E, 0x76, 0x70, 0x79, 0x72, 0x7A, 0x73, 0x7B, 0x74, 0x7D, 0x75, 0x7D, 0x76, 0x7E, 0x75, 0x7D, 0x76, 0x7D, 0x76, 0x7E, 0x77, 0x7E, 0x79, 0x7F, 0x78, 0x81, 0x7B, 0x82, 0x7A, 0x82, 0x7A, 0x82, 0x7B, 0x82, 0x79, 0x82, 0x79, 0x82, 0x78, 0x7E, 0x72, 0x7A, 0x65, 0x6C, 0x4D, 0x50, 0x38, 0x42, 0x41, 0x5C, 0x63, 0x8B, 0x7F, 0xA8, 0x8B, 0xB6, 0x93, 0xBC, 0x96, 0xC1, 0x9B, 0xC5, 0x9D, 0xC8, 0x9E, 0xC7, 0x94, 0xBC, 0x81, 0xA4, 0x67, 0x81, 0x49, 0x6A, 0x46, 0x82, 0x4C, 0x91, 0x4D, 0x97, 0x4F, 0x9C, 0x51, 0x9F, 0x53, 0xA4, 0x54, 0xA4, 0x54, 0xA6, 0x56, 0xA8, 0x56, 0xA9, 0x56, 0xA7, 0x57, 0xA9, 0x58, 0xA9, 0x58, 0xAB, 0x56, 0xAD, 0x56, 0xAA, 0x57, 0xAC, 0x58, 0xAE, 0x59, 0xAE, 0x59, 0xB0, 0x5A, 0xAF, 0x5B, 0xB0, 0x5B, 0xB3, 0x5D, 0xB3, 0x5D, 0xB4, 0x5B, 0xB3, 0x5A, 0xB0, 0x57, 0xA8, 0x46, 0x7A, 0x2D, 0x44, 0x21, 0x30, 0x1C, 0x27, 0x19, 0x21, 0x16, 0x1D, 0x15, 0x1A, 0x14, 0x19, 0x15, 0x19, 0x17, 0x1C, 0x19, 0x1F, 0x1A, 0x1F, 0x19, 0x1E, 0x18, 0x1D, 0x18, 0x1D, 0x16, 0x1A, 0x14, 0x18, 0x13, 0x18, 0x14, 0x1A, 0x19, 0x2A, 0x2B, 0x58, 0x43, 0x8B, 0x4F, 0xA0, 0x54, 0xA9, 0x58, 0xB0, 0x5A, 0xB3, 0x5B, 0xB5, 0x5B, 0xB5, 0x5B, 0xB4, 0x5C, 0xB4, 0x5D, 0xB3, 0x5C, 0xB5, 0x5C, 0xB6, 0x5B, 0xB4, 0x5A, 0xB2, 0x5B, 0xB4, 0x5B, 0xB7, 0x5C, 0xB8, 0x5E, 0xB8, 0x60, 0xBB, 0x5F, 0xBB, 0x5D, 0xB6, 0x5D, 0xB7, 0x5D, 0xB7, 0x5C, 0xB4, 0x53, 0x9B, 0x3C, 0x61, 0x24, 0x33, 0x1A, 0x24, 0x16, 0x1C, 0x13, 0x18, 0x12, 0x16, 0x13, 0x17, 0x13, 0x18, 0x16, 0x20, 0x1B, 0x2A, 0x1D, 0x2D, 0x1E, 0x2D, 0x1B, 0x26, 0x16, 0x1D, 0x14, 0x19, 0x13, 0x17, 0x13, 0x17, 0x13, 0x16, 0x13, 0x18, 0x14, 0x18, 0x16, 0x1E, 0x1B, 0x2B, 0x1D, 0x30, 0x1E, 0x32, 0x1F, 0x33, 0x1F, 0x32, 0x1E, 0x32, 0x1E, 0x31, 0x1D, 0x31, 0x1D, 0x30, 0x1C, 0x2F, 0x1D, 0x2F, 0x1D, 0x30, 0x1D, 0x30, 0x1C, 0x2F, 0x1D, 0x31, 0x1C, 0x31, 0x1E, 0x30, 0x1E, 0x32, 0x1E, 0x32, 0x1E, 0x32, 0x1E, 0x31, 0x1E, 0x31, 0x1E, 0x30, 0x1C, 0x30, 0x1D, 0x2F, 0x1D, 0x31, 0x1E, 0x31, 0x1D, 0x2F, 0x1B, 0x29, 0x14, 0x18, 0x13, 0x16, 0x12, 0x15, 0x14, 0x16, 0x14, 0x16, 0x14, 0x17, 0x15, 0x17, 0x1C, 0x1D, 0x44, 0x47, 0x64, 0x5C, 0x6C, 0x62, 0x5C, 0x51, 0x31, 0x2A, 0x36, 0x37, 0x5D, 0x57, 0x68, 0x5E, 0x6E, 0x61, 0x6E, 0x60, 0x6C, 0x5E, 0x69, 0x5D, 0x6A, 0x5F, 0x69, 0x5D, 0x6B, 0x5F, 0x6C, 0x5D, 0x6A, 0x5F, 0x6A, 0x5E, 0x6C, 0x5E, 0x6C, 0x5F, 0x6A, 0x5F, 0x6B, 0x60, 0x6C, 0x61, 0x6E, 0x5F, 0x71, 0x63, 0x70, 0x65, 0x6C, 0x5E, 0x6F, 0x61, 0x6C, 0x5E, 0x67, 0x5B, 0x6E, 0x62, 0x6C, 0x61, 0x6D, 0x5E, 0x6E, 0x5F, 0x6C, 0x5D, 0x69, 0x5E, 0x68, 0x5B, 0x6B, 0x5F, 0x74, 0x6C, 0x69, 0x5D, 0x65, 0x58, 0x67, 0x5B, 0x65, 0x58, 0x66, 0x5B, 0x6B, 0x5E, 0x5B, 0x4D, 0x41, 0x3C, 0x42, 0x43, 0x43, 0x45, 0x44, 0x46, 0x43, 0x46, 0x42, 0x45, 0x37, 0x35, 0x2B, 0x29, 0x45, 0x42, 0x5F, 0x59, 0x67, 0x5B, 0x62, 0x57, 0x60, 0x55, 0x63, 0x58, 0x64, 0x57, 0x60, 0x56, 0x62, 0x57, 0x64, 0x59, 0x63, 0x56, 0x61, 0x56, 0x61, 0x54, 0x5F, 0x56, 0x61, 0x55, 0x60, 0x55, 0x61, 0x56, 0x60, 0x56, 0x63, 0x58, 0x61, 0x55, 0x63, 0x57, 0x63, 0x56, 0x61, 0x55, 0x62, 0x58, 0x65, 0x58, 0x62, 0x56, 0x5F, 0x53, 0x60, 0x54, 0x5D, 0x4F, 0x5D, 0x52, 0x5F, 0x54, 0x62, 0x58, 0x62, 0x58, 0x64, 0x59, 0x63, 0x56, 0x62, 0x55, 0x61, 0x56, 0x60, 0x56, 0x60, 0x55, 0x62, 0x57, 0x61, 0x55, 0x5F, 0x56, 0x60, 0x54, 0x62, 0x57, 0x62, 0x56, 0x5F, 0x55, 0x62, 0x57, 0x5F, 0x55, 0x5E, 0x52, 0x5E, 0x53, 0x5C, 0x52, 0x59, 0x4E, 0x39, 0x34, 0x2A, 0x28, 0x25, 0x27, 0x26, 0x27, 0x22, 0x24, 0x25, 0x27, 0x26, 0x48, 0x2F, 0x5D, 0x2F, 0x62, 0x2F, 0x5F, 0x2D, 0x5F, 0x2F, 0x5E, 0x2C, 0x58, 0x1E, 0x2A, 0x21, 0x28, 0x2A, 0x31, 0x2F, 0x37, 0x2B, 0x50, 0x2D, 0x57, 0x2C, 0x58, 0x2B, 0x56, 0x2A, 0x52, 0x27, 0x4D, 0x24, 0x3E, 0x1A, 0x23, 0x2B, 0x35, 0x28, 0x2E, 0x27, 0x38, 0x24, 0x39, 0x20, 0x33, 0x1E, 0x32, 0x1D, 0x2D, 0x1C, 0x2A, 0x1B, 0x27, 0x18, 0x1F, 0x21, 0x28, 0x20, 0x24, 0x24, 0x28, 0x25, 0x2A, 0x1C, 0x21, 0x19, 0x1E, 0x19, 0x1F, 0x18, 0x1D, 0x18, 0x1E, 0x19, 0x1D
    },

    {
        0x7B, 0x3B, 0x7B, 0x3C, 0x7F, 0x3D, 0x80, 0x3D, 0x7F, 0x3E, 0x80, 0x3E, 0x7F, 0x3D, 0x81, 0x3F, 0x82, 0x3F, 0x83, 0x40, 0x84, 0x40, 0x84, 0x40, 0x84, 0x40, 0x85, 0x40, 0x85, 0x41, 0x84, 0x41, 0x85, 0x41, 0x85, 0x41, 0x86, 0x41, 0x85, 0x41, 0x82, 0x3F, 0x77, 0x3A, 0x67, 0x33, 0x52, 0x32, 0x67, 0x48, 0x99, 0x67, 0xB2, 0x75, 0xBE, 0x7C, 0xC5, 0x81, 0xC6, 0x82, 0xC9, 0x85, 0xCF, 0x88, 0xCE, 0x84, 0xBE, 0x78, 0x9D, 0x5E, 0x69, 0x3E, 0x44, 0x30, 0x59, 0x46, 0x84, 0x5F, 0x97, 0x6B, 0x9E, 0x70, 0xA4, 0x74, 0xA8, 0x77, 0xAC, 0x79, 0xAF, 0x7A, 0xB1, 0x7C, 0xAF, 0x7C, 0xB2, 0x7D, 0xB2, 0x7D, 0xB2, 0x7D, 0xB0, 0x7D, 0xB3, 0x7F, 0xB3, 0x80, 0xB4, 0x7F, 0xB5, 0x7F, 0xB5, 0x80, 0xB6, 0x82, 0xB6, 0x82, 0xB6, 0x82, 0xBA, 0x83, 0xBC, 0x86, 0xBC, 0x85, 0xBA, 0x86, 0xBC, 0x86, 0xBB, 0x83, 0xAF, 0x78, 0x84, 0x53, 0x4A, 0x2F, 0x2F, 0x20, 0x27, 0x1A, 0x22, 0x18, 0x1E, 0x15, 0x1A, 0x13, 0x19, 0x12, 0x19, 0x13, 0x1B, 0x13, 0x1C, 0x14, 0x1C, 0x14, 0x1C, 0x14, 0x1D, 0x14, 0x1B, 0x13, 0x19, 0x12, 0x19, 0x13, 0x21, 0x1B, 0x40, 0x37, 0x7B, 0x5E, 0x9F, 0x73, 0xAC, 0x7A, 0xB3, 0x80, 0xB7, 0x83, 0xBB, 0x86, 0xBC, 0x87, 0xBE, 0x89, 0xBF, 0x88, 0xBC, 0x86, 0xBD, 0x88, 0xBD, 0x86, 0xBC, 0x87, 0xBB, 0x86, 0xBB, 0x86, 0xBC, 0x88, 0xBE, 0x87, 0xBF, 0x89, 0xC0, 0x8A, 0xBF, 0x88, 0xC1, 0x89, 0xBE, 0x88, 0xBF, 0x89, 0xBC, 0x86, 0xB2, 0x7B, 0x84, 0x53, 0x44, 0x2C, 0x2B, 0x1E, 0x22, 0x17, 0x1C, 0x14, 0x18, 0x11, 0x17, 0x10, 0x17, 0x11, 0x17, 0x11, 0x18, 0x14, 0x20, 0x28, 0x2B, 0x3A, 0x2A, 0x32, 0x1F, 0x1F, 0x1A, 0x15, 0x1A, 0x14, 0x18, 0x12, 0x17, 0x10, 0x18, 0x11, 0x18, 0x10, 0x19, 0x11, 0x19, 0x12, 0x1F, 0x18, 0x2E, 0x23, 0x33, 0x25, 0x35, 0x27, 0x35, 0x27, 0x33, 0x25, 0x34, 0x26, 0x35, 0x27, 0x33, 0x26, 0x32, 0x25, 0x31, 0x25, 0x35, 0x28, 0x3C, 0x2B, 0x39, 0x29, 0x35, 0x26, 0x35, 0x26, 0x32, 0x26, 0x33, 0x25, 0x34, 0x26, 0x34, 0x26, 0x34, 0x26, 0x33, 0x25, 0x33, 0x25, 0x31, 0x24, 0x32, 0x25, 0x33, 0x25, 0x32, 0x24, 0x30, 0x23, 0x26, 0x18, 0x19, 0x11, 0x17, 0x10, 0x16, 0x0F, 0x16, 0x0F, 0x18, 0x11, 0x18, 0x10, 0x1A, 0x11, 0x24, 0x16, 0x4B, 0x20, 0x5C, 0x23, 0x61, 0x23, 0x49, 0x1E, 0x2D, 0x17, 0x45, 0x1E, 0x5C, 0x22, 0x61, 0x23, 0x62, 0x22, 0x64, 0x23, 0x63, 0x24, 0x60, 0x22, 0x61, 0x22, 0x60, 0x22, 0x5F, 0x21, 0x5E, 0x21, 0x62, 0x22, 0x5D, 0x22, 0x5F, 0x22, 0x65, 0x23, 0x63, 0x23, 0x61, 0x23, 0x63, 0x23, 0x60, 0x22, 0x62, 0x23, 0x66, 0x23, 0x65, 0x23, 0x63, 0x23, 0x61, 0x22, 0x5B, 0x21, 0x62, 0x23, 0x60, 0x22, 0x5E, 0x22, 0x60, 0x23, 0x5F, 0x22, 0x5E, 0x21, 0x5D, 0x21, 0x5E, 0x22, 0x60, 0x23, 0x5D, 0x21, 0x5B, 0x21, 0x5D, 0x21, 0x5A, 0x20, 0x5D, 0x21, 0x61, 0x22, 0x58, 0x1F, 0x38, 0x18, 0x3C, 0x1E, 0x44, 0x21, 0x45, 0x22, 0x46, 0x22, 0x3F, 0x1D, 0x29, 0x13, 0x27, 0x14, 0x44, 0x1C, 0x59, 0x21, 0x5E, 0x22, 0x5B, 0x21, 0x56, 0x20, 0x57, 0x1F, 0x5A, 0x20, 0x5A, 0x21, 0x5A, 0x21, 0x59, 0x21, 0x5C, 0x21, 0x59, 0x21, 0x58, 0x20, 0x54, 0x1E, 0x58, 0x20, 0x55, 0x1F, 0x57, 0x1F, 0x55, 0x1F, 0x59, 0x20, 0x57, 0x1F, 0x57, 0x1F, 0x5A, 0x21, 0x5C, 0x22, 0x5B, 0x22, 0x5A, 0x21, 0x58, 0x20, 0x58, 0x20, 0x58, 0x20, 0x57, 0x1F, 0x56, 0x20, 0x58, 0x20, 0x59, 0x20, 0x59, 0x20, 0x59, 0x21, 0x57, 0x1F, 0x58, 0x1F, 0x58, 0x1F, 0x5A, 0x21, 0x5A, 0x22, 0x58, 0x20, 0x59, 0x20, 0x58, 0x20, 0x57, 0x20, 0x58, 0x20, 0x59, 0x20, 0x55, 0x1F, 0x59, 0x20, 0x56, 0x20, 0x56, 0x1F, 0x54, 0x1F, 0x54, 0x20, 0x53, 0x1E, 0x35, 0x19, 0x25, 0x15, 0x27, 0x16, 0x24, 0x14, 0x29, 0x17, 0x2B, 0x19, 0x45, 0x2A, 0x5A, 0x32, 0x54, 0x30, 0x52, 0x2F, 0x4D, 0x2D, 0x48, 0x2B, 0x43, 0x28, 0x27, 0x17, 0x28, 0x19, 0x2D, 0x1A, 0x2F, 0x1B, 0x3A, 0x20, 0x2F, 0x1E, 0x2B, 0x1B, 0x29, 0x1B, 0x25, 0x18, 0x21, 0x16, 0x1F, 0x15, 0x1E, 0x14, 0x2B, 0x18, 0x25, 0x17, 0x2E, 0x19, 0x22, 0x15, 0x21, 0x15, 0x21, 0x16, 0x23, 0x15, 0x23, 0x16, 0x23, 0x15, 0x22, 0x16, 0x27, 0x17, 0x2B, 0x1A, 0x30, 0x1A, 0x34, 0x1C, 0x30, 0x1A, 0x2A, 0x18, 0x30, 0x1A, 0x27, 0x17, 0x29, 0x18, 0x2B, 0x18
    },

    {
        0x70, 0x78, 0x71, 0x79, 0x73, 0x7B, 0x74, 0x7C, 0x74, 0x7C, 0x75, 0x7D, 0x75, 0x7C, 0x76, 0x7E, 0x77, 0x7F, 0x77, 0x7F, 0x79, 0x82, 0x79, 0x7F, 0x7A, 0x81, 0x7A, 0x81, 0x7B, 0x82, 0x79, 0x81, 0x7B, 0x82, 0x7B, 0x82, 0x7A, 0x83, 0x7A, 0x81, 0x75, 0x7D, 0x6B, 0x73, 0x5C, 0x62, 0x48, 0x50, 0x4B, 0x6B, 0x6E, 0x97, 0x84, 0xAE, 0x8E, 0xB8, 0x94, 0xBF, 0x97, 0xBF, 0x98, 0xC1, 0x9C, 0xC6, 0x9B, 0xC3, 0x8D, 0xB1, 0x72, 0x88, 0x4A, 0x53, 0x2E, 0x39, 0x2F, 0x50, 0x40, 0x7B, 0x4B, 0x90, 0x4D, 0x97, 0x50, 0x9D, 0x52, 0xA0, 0x53, 0xA3, 0x54, 0xA6, 0x57, 0xA8, 0x56, 0xA8, 0x57, 0xA8, 0x57, 0xAA, 0x57, 0xA8, 0x56, 0xA9, 0x57, 0xAC, 0x58, 0xAC, 0x58, 0xAD, 0x58, 0xAE, 0x59, 0xAD, 0x5A, 0xB0, 0x5A, 0xB0, 0x5A, 0xB0, 0x5B, 0xB2, 0x5C, 0xB5, 0x5D, 0xB3, 0x5C, 0xB5, 0x5C, 0xB5, 0x5C, 0xB2, 0x59, 0xAB, 0x4B, 0x84, 0x30, 0x4B, 0x21, 0x30, 0x1C, 0x27, 0x19, 0x21, 0x17, 0x1D, 0x15, 0x19, 0x14, 0x18, 0x14, 0x17, 0x14, 0x19, 0x15, 0x1A, 0x16, 0x1B, 0x16, 0x1B, 0x16, 0x1B, 0x14, 0x19, 0x14, 0x18, 0x15, 0x19, 0x19, 0x27, 0x28, 0x51, 0x41, 0x89, 0x4F, 0x9D, 0x53, 0xA6, 0x56, 0xAD, 0x59, 0xB0, 0x5B, 0xB4, 0x5B, 0xB5, 0x5C, 0xB6, 0x5D, 0xB6, 0x5B, 0xB5, 0x5C, 0xB6, 0x5C, 0xB5, 0x5C, 0xB5, 0x5C, 0xB3, 0x5B, 0xB4, 0x5C, 0xB6, 0x5C, 0xB6, 0x5C, 0xB6, 0x5D, 0xB7, 0x5E, 0xB6, 0x5E, 0xBA, 0x5D, 0xB6, 0x5D, 0xB6, 0x5B, 0xB0, 0x53, 0x9F, 0x3E, 0x67, 0x24, 0x34, 0x1B, 0x25, 0x17, 0x1E, 0x15, 0x19, 0x13, 0x16, 0x12, 0x16, 0x12, 0x16, 0x13, 0x16, 0x13, 0x17, 0x16, 0x1F, 0x1B, 0x27, 0x1B, 0x25, 0x16, 0x1C, 0x14, 0x19, 0x14, 0x19, 0x13, 0x17, 0x13, 0x16, 0x13, 0x17, 0x13, 0x18, 0x14, 0x17, 0x14, 0x18, 0x16, 0x1E, 0x1B, 0x2C, 0x1D, 0x31, 0x1E, 0x32, 0x1E, 0x32, 0x1D, 0x31, 0x1E, 0x32, 0x1F, 0x33, 0x1E, 0x32, 0x1D, 0x30, 0x1D, 0x30, 0x20, 0x35, 0x23, 0x3C, 0x24, 0x39, 0x20, 0x34, 0x1F, 0x33, 0x1E, 0x32, 0x1E, 0x31, 0x1F, 0x33, 0x1E, 0x33, 0x1F, 0x32, 0x1E, 0x31, 0x1E, 0x30, 0x1E, 0x31, 0x1D, 0x31, 0x1D, 0x32, 0x1E, 0x30, 0x1C, 0x2C, 0x18, 0x1F, 0x14, 0x17, 0x14, 0x17, 0x13, 0x15, 0x14, 0x16, 0x14, 0x18, 0x15, 0x18, 0x1A, 0x1C, 0x2C, 0x2F, 0x52, 0x51, 0x61, 0x5A, 0x61, 0x59, 0x44, 0x3A, 0x34, 0x30, 0x50, 0x50, 0x65, 0x5C, 0x6A, 0x5E, 0x6C, 0x60, 0x6F, 0x63, 0x6E, 0x62, 0x6B, 0x5F, 0x6B, 0x5E, 0x6C, 0x5F, 0x6B, 0x5C, 0x6A, 0x5D, 0x6C, 0x5E, 0x68, 0x5C, 0x6A, 0x5F, 0x70, 0x63, 0x6C, 0x60, 0x6C, 0x61, 0x6D, 0x60, 0x6D, 0x5F, 0x6C, 0x5F, 0x6F, 0x62, 0x71, 0x63, 0x6E, 0x61, 0x6B, 0x5C, 0x67, 0x5B, 0x6D, 0x5F, 0x6A, 0x5E, 0x6B, 0x5C, 0x6A, 0x5E, 0x6A, 0x5D, 0x69, 0x5B, 0x68, 0x5A, 0x67, 0x5A, 0x66, 0x5B, 0x69, 0x5C, 0x67, 0x5A, 0x67, 0x5A, 0x67, 0x5A, 0x67, 0x5C, 0x6C, 0x5F, 0x63, 0x55, 0x3E, 0x33, 0x3A, 0x39, 0x3E, 0x41, 0x3F, 0x41, 0x3F, 0x41, 0x36, 0x36, 0x25, 0x22, 0x2B, 0x2B, 0x4B, 0x47, 0x62, 0x59, 0x64, 0x59, 0x65, 0x59, 0x5F, 0x54, 0x61, 0x55, 0x63, 0x58, 0x63, 0x59, 0x62, 0x58, 0x62, 0x59, 0x65, 0x59, 0x65, 0x59, 0x61, 0x56, 0x5E, 0x53, 0x61, 0x56, 0x5F, 0x53, 0x61, 0x54, 0x60, 0x55, 0x62, 0x57, 0x61, 0x54, 0x60, 0x55, 0x63, 0x58, 0x65, 0x59, 0x65, 0x58, 0x65, 0x57, 0x63, 0x57, 0x63, 0x56, 0x63, 0x56, 0x63, 0x57, 0x5F, 0x54, 0x60, 0x56, 0x62, 0x56, 0x61, 0x56, 0x62, 0x58, 0x61, 0x56, 0x63, 0x56, 0x63, 0x56, 0x64, 0x59, 0x64, 0x59, 0x63, 0x57, 0x63, 0x58, 0x62, 0x58, 0x60, 0x55, 0x60, 0x57, 0x62, 0x55, 0x5F, 0x55, 0x62, 0x57, 0x5F, 0x55, 0x62, 0x56, 0x5F, 0x53, 0x5D, 0x54, 0x58, 0x4C, 0x34, 0x2E, 0x25, 0x24, 0x25, 0x27, 0x21, 0x21, 0x28, 0x2D, 0x28, 0x2C, 0x2A, 0x47, 0x2B, 0x4B, 0x26, 0x44, 0x25, 0x41, 0x24, 0x3F, 0x22, 0x3A, 0x1F, 0x33, 0x18, 0x1E, 0x22, 0x29, 0x24, 0x27, 0x29, 0x31, 0x27, 0x2E, 0x1C, 0x23, 0x19, 0x20, 0x19, 0x1F, 0x18, 0x1D, 0x17, 0x1C, 0x18, 0x1B, 0x1A, 0x1F, 0x24, 0x26, 0x22, 0x26, 0x28, 0x2A, 0x1E, 0x21, 0x1E, 0x22, 0x1E, 0x23, 0x22, 0x26, 0x21, 0x27, 0x21, 0x25, 0x21, 0x25, 0x25, 0x2B, 0x28, 0x2D, 0x2A, 0x2F, 0x2E, 0x33, 0x2B, 0x2F, 0x26, 0x2C, 0x29, 0x2D, 0x21, 0x24, 0x24, 0x2A, 0x25, 0x28
    },

    {
        0x7C, 0x3C, 0x7D, 0x3C, 0x7D, 0x3D, 0x7F, 0x3D, 0x7E, 0x3D, 0x7F, 0x3D, 0x80, 0x3D, 0x81, 0x3E, 0x82, 0x3F, 0x82, 0x3F, 0x82, 0x40, 0x84, 0x40, 0x83, 0x40, 0x83, 0x3F, 0x82, 0x41, 0x85, 0x41, 0x86, 0x41, 0x86, 0x41, 0x85, 0x42, 0x84, 0x40, 0x7F, 0x3F, 0x71, 0x37, 0x59, 0x2C, 0x3E, 0x24, 0x44, 0x32, 0x74, 0x53, 0xA3, 0x6D, 0xB8, 0x7B, 0xC4, 0x82, 0xC9, 0x84, 0xC9, 0x84, 0xCA, 0x83, 0xC2, 0x7A, 0xA5, 0x63, 0x72, 0x42, 0x42, 0x28, 0x2F, 0x20, 0x30, 0x24, 0x4B, 0x3D, 0x7B, 0x5A, 0x94, 0x69, 0x9D, 0x70, 0xA4, 0x75, 0xA6, 0x75, 0xAA, 0x78, 0xAD, 0x7B, 0xB1, 0x7C, 0xB0, 0x7D, 0xB1, 0x7D, 0xB1, 0x7D, 0xAF, 0x7C, 0xB0, 0x7D, 0xB4, 0x7F, 0xB5, 0x7F, 0xB6, 0x81, 0xB6, 0x80, 0xB7, 0x81, 0xB9, 0x83, 0xBB, 0x83, 0xBB, 0x84, 0xBB, 0x85, 0xBD, 0x87, 0xBD, 0x87, 0xBD, 0x87, 0xBC, 0x86, 0xBC, 0x84, 0xB2, 0x79, 0x8A, 0x57, 0x4E, 0x32, 0x30, 0x20, 0x27, 0x1A, 0x22, 0x17, 0x1D, 0x14, 0x1A, 0x12, 0x18, 0x12, 0x18, 0x11, 0x19, 0x12, 0x19, 0x12, 0x1A, 0x12, 0x1B, 0x13, 0x1B, 0x13, 0x1A, 0x13, 0x21, 0x1B, 0x3E, 0x36, 0x75, 0x59, 0x9D, 0x71, 0xAB, 0x7A, 0xAF, 0x7B, 0xB4, 0x81, 0xBB, 0x84, 0xBB, 0x86, 0xBE, 0x87, 0xBF, 0x88, 0xBD, 0x87, 0xBC, 0x86, 0xBF, 0x88, 0xBE, 0x86, 0xBC, 0x87, 0xBE, 0x87, 0xBE, 0x88, 0xBE, 0x87, 0xBE, 0x88, 0xBC, 0x87, 0xBE, 0x88, 0xC0, 0x88, 0xC1, 0x89, 0xBF, 0x89, 0xBD, 0x87, 0xB7, 0x7F, 0x8F, 0x5A, 0x4D, 0x31, 0x2D, 0x1F, 0x23, 0x19, 0x1C, 0x14, 0x19, 0x12, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x11, 0x18, 0x13, 0x1E, 0x1F, 0x1F, 0x1D, 0x1A, 0x15, 0x1A, 0x14, 0x19, 0x12, 0x18, 0x11, 0x17, 0x10, 0x17, 0x10, 0x18, 0x11, 0x19, 0x12, 0x1A, 0x12, 0x1C, 0x15, 0x28, 0x1F, 0x31, 0x25, 0x32, 0x25, 0x33, 0x25, 0x33, 0x26, 0x35, 0x28, 0x39, 0x29, 0x36, 0x27, 0x35, 0x26, 0x34, 0x26, 0x35, 0x27, 0x34, 0x26, 0x3C, 0x2C, 0x3E, 0x2C, 0x36, 0x27, 0x35, 0x27, 0x34, 0x26, 0x34, 0x27, 0x35, 0x26, 0x34, 0x25, 0x33, 0x25, 0x34, 0x25, 0x33, 0x25, 0x33, 0x25, 0x31, 0x24, 0x30, 0x23, 0x27, 0x1A, 0x1B, 0x12, 0x17, 0x10, 0x16, 0x10, 0x18, 0x10, 0x18, 0x11, 0x18, 0x11, 0x19, 0x10, 0x23, 0x15, 0x46, 0x1E, 0x5B, 0x22, 0x5D, 0x22, 0x47, 0x1D, 0x2E, 0x18, 0x45, 0x1E, 0x59, 0x21, 0x5E, 0x22, 0x5F, 0x22, 0x60, 0x22, 0x5E, 0x22, 0x63, 0x22, 0x60, 0x22, 0x61, 0x23, 0x61, 0x23, 0x61, 0x22, 0x61, 0x22, 0x60, 0x22, 0x60, 0x23, 0x61, 0x22, 0x62, 0x23, 0x62, 0x23, 0x61, 0x22, 0x62, 0x23, 0x60, 0x21, 0x5F, 0x22, 0x61, 0x22, 0x63, 0x23, 0x60, 0x22, 0x5F, 0x21, 0x61, 0x22, 0x5E, 0x22, 0x61, 0x22, 0x5F, 0x21, 0x62, 0x23, 0x60, 0x22, 0x5C, 0x21, 0x5B, 0x20, 0x5C, 0x21, 0x5F, 0x22, 0x5F, 0x22, 0x60, 0x22, 0x5D, 0x21, 0x5B, 0x20, 0x5E, 0x21, 0x5C, 0x21, 0x5A, 0x20, 0x44, 0x1A, 0x29, 0x14, 0x2D, 0x17, 0x2E, 0x17, 0x2C, 0x16, 0x24, 0x12, 0x21, 0x11, 0x33, 0x17, 0x4D, 0x1D, 0x58, 0x20, 0x5B, 0x21, 0x5C, 0x22, 0x58, 0x20, 0x59, 0x20, 0x57, 0x20, 0x58, 0x20, 0x57, 0x20, 0x57, 0x20, 0x58, 0x20, 0x59, 0x20, 0x5A, 0x20, 0x58, 0x20, 0x55, 0x20, 0x58, 0x20, 0x58, 0x20, 0x57, 0x20, 0x55, 0x1E, 0x56, 0x20, 0x5A, 0x21, 0x58, 0x20, 0x5A, 0x21, 0x5C, 0x22, 0x5B, 0x21, 0x58, 0x20, 0x59, 0x20, 0x58, 0x20, 0x59, 0x20, 0x59, 0x20, 0x59, 0x21, 0x57, 0x20, 0x56, 0x20, 0x58, 0x20, 0x56, 0x1F, 0x56, 0x21, 0x58, 0x21, 0x5A, 0x21, 0x5F, 0x22, 0x59, 0x20, 0x57, 0x20, 0x59, 0x20, 0x56, 0x20, 0x57, 0x20, 0x58, 0x20, 0x59, 0x21, 0x59, 0x20, 0x58, 0x21, 0x58, 0x20, 0x58, 0x20, 0x58, 0x20, 0x52, 0x1E, 0x32, 0x18, 0x29, 0x17, 0x2F, 0x1B, 0x2D, 0x19, 0x37, 0x1D, 0x31, 0x1B, 0x36, 0x1D, 0x24, 0x16, 0x20, 0x15, 0x1F, 0x16, 0x1F, 0x14, 0x1E, 0x14, 0x1E, 0x15, 0x1B, 0x13, 0x25, 0x16, 0x25, 0x16, 0x2F, 0x1A, 0x24, 0x15, 0x26, 0x16, 0x24, 0x16, 0x25, 0x15, 0x22, 0x15, 0x22, 0x15, 0x26, 0x16, 0x2F, 0x1A, 0x2B, 0x18, 0x2E, 0x1A, 0x2A, 0x18, 0x2E, 0x1B, 0x34, 0x1C, 0x2C, 0x19, 0x34, 0x1D, 0x32, 0x1C, 0x2E, 0x1A, 0x2F, 0x1A, 0x33, 0x1C, 0x2A, 0x18, 0x2E, 0x1A, 0x2A, 0x18, 0x25, 0x17, 0x27, 0x17, 0x28, 0x17, 0x25, 0x16, 0x2B, 0x18, 0x27, 0x17
    },

    {
        0x71, 0x79, 0x72, 0x7A, 0x72, 0x7B, 0x73, 0x7C, 0x73, 0x7B, 0x75, 0x7C, 0x76, 0x7C, 0x77, 0x7C, 0x76, 0x7E, 0x78, 0x7F, 0x79, 0x7F, 0x79, 0x80, 0x79, 0x80, 0x79, 0x7E, 0x77, 0x81, 0x7A, 0x82, 0x7B, 0x82, 0x7C, 0x82, 0x7A, 0x81, 0x78, 0x80, 0x72, 0x79, 0x64, 0x68, 0x4D, 0x4D, 0x33, 0x34, 0x2F, 0x3D, 0x4A, 0x6C, 0x70, 0x9C, 0x87, 0xB1, 0x91, 0xBB, 0x97, 0xC1, 0x97, 0xC1, 0x95, 0xC0, 0x8D, 0xB2, 0x77, 0x8D, 0x51, 0x5A, 0x30, 0x36, 0x23, 0x2A, 0x21, 0x2B, 0x28, 0x43, 0x38, 0x73, 0x47, 0x8C, 0x4C, 0x97, 0x50, 0x9E, 0x51, 0xA0, 0x54, 0xA3, 0x55, 0xA7, 0x56, 0xA9, 0x56, 0xAA, 0x56, 0xA8, 0x56, 0xA9, 0x56, 0xA8, 0x56, 0xA9, 0x58, 0xAB, 0x58, 0xAC, 0x58, 0xAF, 0x59, 0xAD, 0x59, 0xAE, 0x5B, 0xB0, 0x5C, 0xB3, 0x5C, 0xB4, 0x5C, 0xB5, 0x5E, 0xB6, 0x5E, 0xB7, 0x5E, 0xB6, 0x5D, 0xB6, 0x5C, 0xB3, 0x59, 0xAC, 0x4C, 0x8B, 0x33, 0x51, 0x22, 0x31, 0x1C, 0x27, 0x18, 0x21, 0x16, 0x1C, 0x14, 0x19, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x13, 0x19, 0x15, 0x1A, 0x14, 0x1A, 0x15, 0x1A, 0x1A, 0x26, 0x27, 0x4F, 0x3E, 0x84, 0x4D, 0x9D, 0x53, 0xA6, 0x55, 0xA8, 0x57, 0xAE, 0x5A, 0xB2, 0x5C, 0xB3, 0x5C, 0xB5, 0x5C, 0xB6, 0x5C, 0xB7, 0x5B, 0xB6, 0x5D, 0xB6, 0x5D, 0xB4, 0x5C, 0xB6, 0x5D, 0xB6, 0x5D, 0xB6, 0x5D, 0xB5, 0x5C, 0xB7, 0x5C, 0xB6, 0x5B, 0xB6, 0x5E, 0xB7, 0x5D, 0xB7, 0x5D, 0xB7, 0x5C, 0xB4, 0x57, 0xA9, 0x44, 0x74, 0x29, 0x3B, 0x1C, 0x27, 0x18, 0x1F, 0x15, 0x1A, 0x13, 0x17, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x13, 0x16, 0x13, 0x16, 0x14, 0x18, 0x19, 0x1E, 0x19, 0x1C, 0x16, 0x19, 0x14, 0x19, 0x13, 0x17, 0x13, 0x17, 0x13, 0x16, 0x13, 0x16, 0x13, 0x17, 0x15, 0x19, 0x14, 0x19, 0x16, 0x1D, 0x19, 0x29, 0x1D, 0x2F, 0x1D, 0x30, 0x1D, 0x31, 0x1D, 0x31, 0x1E, 0x34, 0x21, 0x36, 0x20, 0x33, 0x1F, 0x33, 0x1E, 0x33, 0x1F, 0x32, 0x1E, 0x30, 0x22, 0x38, 0x25, 0x3B, 0x20, 0x33, 0x20, 0x32, 0x1F, 0x33, 0x1F, 0x33, 0x1E, 0x33, 0x1E, 0x32, 0x1E, 0x31, 0x1E, 0x31, 0x1E, 0x30, 0x1E, 0x30, 0x1D, 0x2F, 0x1C, 0x2C, 0x18, 0x20, 0x14, 0x18, 0x13, 0x16, 0x13, 0x16, 0x14, 0x17, 0x15, 0x17, 0x15, 0x17, 0x18, 0x18, 0x2A, 0x2D, 0x50, 0x50, 0x61, 0x5B, 0x5F, 0x57, 0x44, 0x3A, 0x34, 0x30, 0x4E, 0x4D, 0x61, 0x59, 0x66, 0x5D, 0x67, 0x5D, 0x6A, 0x5E, 0x69, 0x5C, 0x6E, 0x60, 0x6C, 0x5E, 0x6E, 0x60, 0x6D, 0x60, 0x6C, 0x5F, 0x6A, 0x5E, 0x6A, 0x5F, 0x6A, 0x5F, 0x6C, 0x5D, 0x6D, 0x5E, 0x6C, 0x5E, 0x6C, 0x5F, 0x6F, 0x60, 0x6D, 0x5F, 0x6A, 0x5E, 0x6D, 0x5F, 0x6D, 0x60, 0x6C, 0x5E, 0x6B, 0x5E, 0x6D, 0x5E, 0x69, 0x5D, 0x6D, 0x60, 0x6B, 0x5F, 0x6C, 0x5F, 0x69, 0x5D, 0x67, 0x5B, 0x66, 0x59, 0x66, 0x5A, 0x6A, 0x60, 0x6B, 0x5F, 0x6A, 0x5D, 0x67, 0x5B, 0x65, 0x58, 0x65, 0x5A, 0x64, 0x58, 0x63, 0x55, 0x4E, 0x41, 0x30, 0x28, 0x2B, 0x28, 0x29, 0x25, 0x27, 0x24, 0x22, 0x1F, 0x27, 0x24, 0x3B, 0x3A, 0x56, 0x50, 0x62, 0x59, 0x65, 0x59, 0x67, 0x5B, 0x63, 0x56, 0x63, 0x56, 0x60, 0x56, 0x61, 0x55, 0x61, 0x55, 0x60, 0x56, 0x63, 0x58, 0x61, 0x56, 0x64, 0x58, 0x63, 0x58, 0x61, 0x56, 0x64, 0x59, 0x62, 0x56, 0x61, 0x55, 0x60, 0x54, 0x61, 0x57, 0x62, 0x57, 0x63, 0x57, 0x63, 0x57, 0x64, 0x59, 0x65, 0x58, 0x62, 0x56, 0x62, 0x56, 0x61, 0x57, 0x64, 0x58, 0x64, 0x58, 0x63, 0x57, 0x60, 0x55, 0x5E, 0x52, 0x61, 0x56, 0x5E, 0x53, 0x5E, 0x56, 0x63, 0x59, 0x65, 0x5A, 0x68, 0x5B, 0x63, 0x57, 0x62, 0x56, 0x60, 0x56, 0x5F, 0x55, 0x60, 0x55, 0x62, 0x58, 0x62, 0x58, 0x60, 0x55, 0x60, 0x56, 0x63, 0x56, 0x62, 0x56, 0x60, 0x56, 0x58, 0x4C, 0x35, 0x2F, 0x28, 0x28, 0x2B, 0x2F, 0x2B, 0x2F, 0x31, 0x35, 0x2C, 0x31, 0x2C, 0x2F, 0x1D, 0x1F, 0x19, 0x1C, 0x1A, 0x1F, 0x19, 0x1D, 0x1B, 0x1F, 0x1A, 0x1D, 0x19, 0x1C, 0x22, 0x25, 0x23, 0x26, 0x27, 0x2A, 0x20, 0x23, 0x23, 0x27, 0x23, 0x26, 0x22, 0x25, 0x20, 0x23, 0x20, 0x25, 0x24, 0x27, 0x2B, 0x30, 0x28, 0x2D, 0x28, 0x2C, 0x26, 0x2A, 0x2A, 0x2F, 0x2E, 0x32, 0x25, 0x29, 0x2D, 0x33, 0x29, 0x2E, 0x27, 0x2C, 0x28, 0x2A, 0x2E, 0x33, 0x24, 0x25, 0x2A, 0x30, 0x25, 0x26, 0x23, 0x27, 0x23, 0x27, 0x23, 0x29, 0x23, 0x26, 0x27, 0x2B, 0x24, 0x28
    },

    {
        0x7E, 0x3D, 0x7F, 0x3D, 0x7E, 0x3D, 0x7F, 0x3E, 0x7F, 0x3D, 0x80, 0x3E, 0x81, 0x3E, 0x82, 0x3F, 0x82, 0x3F, 0x83, 0x3F, 0x83, 0x40, 0x83, 0x40, 0x84, 0x40, 0x83, 0x40, 0x82, 0x40, 0x87, 0x42, 0x87, 0x43, 0x86, 0x42, 0x85, 0x41, 0x7F, 0x3E, 0x78, 0x38, 0x5F, 0x2D, 0x40, 0x21, 0x2B, 0x1A, 0x28, 0x1B, 0x3A, 0x2E, 0x6F, 0x51, 0xA1, 0x6D, 0xB9, 0x7B, 0xC5, 0x81, 0xC5, 0x81, 0xBE, 0x79, 0xA6, 0x64, 0x76, 0x44, 0x45, 0x2B, 0x32, 0x20, 0x29, 0x1B, 0x24, 0x1A, 0x27, 0x1F, 0x40, 0x36, 0x74, 0x56, 0x92, 0x68, 0x9F, 0x71, 0xA4, 0x75, 0xA7, 0x76, 0xAB, 0x7B, 0xB0, 0x7C, 0xB1, 0x7C, 0xB1, 0x7D, 0xB0, 0x7D, 0xB0, 0x7D, 0xB3, 0x7E, 0xB2, 0x7E, 0xB4, 0x7F, 0xB2, 0x7F, 0xB5, 0x80, 0xB9, 0x83, 0xB9, 0x82, 0xBA, 0x85, 0xBA, 0x85, 0xBC, 0x85, 0xBC, 0x86, 0xBE, 0x86, 0xBB, 0x85, 0xBC, 0x86, 0xBB, 0x85, 0xBB, 0x83, 0xB4, 0x7B, 0x94, 0x5E, 0x58, 0x37, 0x33, 0x22, 0x27, 0x1B, 0x20, 0x16, 0x1B, 0x13, 0x19, 0x12, 0x17, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x1B, 0x13, 0x19, 0x12, 0x1E, 0x19, 0x38, 0x33, 0x72, 0x58, 0x9E, 0x71, 0xA8, 0x77, 0xB0, 0x7D, 0xB4, 0x80, 0xB5, 0x82, 0xBB, 0x85, 0xBB, 0x87, 0xBC, 0x86, 0xBD, 0x88, 0xBF, 0x87, 0xBE, 0x88, 0xBD, 0x85, 0xBD, 0x86, 0xBE, 0x89, 0xBF, 0x88, 0xBE, 0x88, 0xBE, 0x88, 0xBE, 0x88, 0xBF, 0x89, 0xC0, 0x89, 0xC2, 0x8C, 0xC1, 0x8A, 0xBF, 0x88, 0xBE, 0x86, 0xB7, 0x7F, 0x7E, 0x4E, 0x3D, 0x29, 0x2B, 0x1E, 0x21, 0x17, 0x1A, 0x13, 0x18, 0x11, 0x17, 0x11, 0x17, 0x11, 0x17, 0x11, 0x17, 0x10, 0x17, 0x11, 0x1A, 0x13, 0x20, 0x17, 0x23, 0x17, 0x1A, 0x13, 0x19, 0x12, 0x19, 0x11, 0x18, 0x10, 0x17, 0x11, 0x17, 0x11, 0x19, 0x11, 0x19, 0x12, 0x1A, 0x14, 0x24, 0x1D, 0x2E, 0x23, 0x32, 0x25, 0x33, 0x26, 0x33, 0x26, 0x33, 0x26, 0x34, 0x27, 0x35, 0x27, 0x35, 0x26, 0x34, 0x27, 0x34, 0x26, 0x34, 0x26, 0x31, 0x24, 0x34, 0x27, 0x38, 0x29, 0x38, 0x27, 0x34, 0x27, 0x36, 0x27, 0x35, 0x26, 0x34, 0x27, 0x34, 0x26, 0x34, 0x25, 0x33, 0x26, 0x30, 0x24, 0x34, 0x25, 0x32, 0x24, 0x27, 0x1A, 0x1B, 0x13, 0x18, 0x10, 0x17, 0x10, 0x17, 0x10, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x21, 0x13, 0x42, 0x1D, 0x5A, 0x22, 0x5C, 0x21, 0x4B, 0x1E, 0x2E, 0x18, 0x42, 0x1E, 0x58, 0x22, 0x5E, 0x22, 0x60, 0x23, 0x61, 0x23, 0x61, 0x23, 0x5F, 0x22, 0x5F, 0x22, 0x61, 0x22, 0x61, 0x23, 0x68, 0x27, 0x63, 0x23, 0x5F, 0x23, 0x63, 0x23, 0x64, 0x25, 0x63, 0x23, 0x60, 0x22, 0x5E, 0x22, 0x60, 0x22, 0x61, 0x22, 0x60, 0x22, 0x5D, 0x21, 0x60, 0x22, 0x61, 0x22, 0x5D, 0x23, 0x62, 0x22, 0x5F, 0x22, 0x60, 0x22, 0x65, 0x23, 0x62, 0x23, 0x5F, 0x22, 0x60, 0x21, 0x5B, 0x20, 0x5C, 0x22, 0x61, 0x22, 0x61, 0x23, 0x5C, 0x21, 0x5C, 0x21, 0x5F, 0x22, 0x5B, 0x20, 0x59, 0x20, 0x59, 0x20, 0x5B, 0x21, 0x56, 0x1F, 0x42, 0x19, 0x2E, 0x14, 0x26, 0x13, 0x25, 0x12, 0x2A, 0x13, 0x36, 0x17, 0x48, 0x1C, 0x58, 0x21, 0x5B, 0x20, 0x59, 0x20, 0x5A, 0x21, 0x5B, 0x20, 0x5B, 0x21, 0x5B, 0x21, 0x59, 0x20, 0x54, 0x1F, 0x56, 0x20, 0x59, 0x20, 0x58, 0x1F, 0x57, 0x1F, 0x5A, 0x20, 0x58, 0x20, 0x58, 0x20, 0x58, 0x20, 0x57, 0x20, 0x57, 0x20, 0x59, 0x20, 0x58, 0x20, 0x59, 0x21, 0x59, 0x20, 0x58, 0x20, 0x5A, 0x21, 0x58, 0x20, 0x57, 0x20, 0x56, 0x20, 0x59, 0x21, 0x58, 0x20, 0x56, 0x20, 0x58, 0x20, 0x55, 0x1F, 0x56, 0x20, 0x56, 0x1F, 0x56, 0x20, 0x5B, 0x21, 0x5B, 0x21, 0x5B, 0x22, 0x59, 0x21, 0x5B, 0x22, 0x5A, 0x21, 0x5A, 0x22, 0x58, 0x21, 0x59, 0x21, 0x5A, 0x21, 0x58, 0x20, 0x5A, 0x21, 0x5B, 0x21, 0x5A, 0x21, 0x57, 0x20, 0x51, 0x1F, 0x36, 0x1A, 0x28, 0x17, 0x37, 0x1D, 0x2F, 0x19, 0x27, 0x16, 0x2A, 0x17, 0x27, 0x17, 0x26, 0x16, 0x22, 0x15, 0x26, 0x17, 0x27, 0x18, 0x2C, 0x1A, 0x2A, 0x19, 0x28, 0x18, 0x2D, 0x19, 0x2D, 0x1A, 0x29, 0x17, 0x30, 0x1B, 0x30, 0x1B, 0x2C, 0x19, 0x2A, 0x19, 0x2C, 0x19, 0x29, 0x18, 0x2E, 0x1A, 0x2F, 0x1B, 0x2F, 0x1A, 0x2A, 0x18, 0x31, 0x1A, 0x27, 0x19, 0x35, 0x1D, 0x28, 0x17, 0x33, 0x1C, 0x25, 0x16, 0x2D, 0x19, 0x26, 0x17, 0x2D, 0x19, 0x27, 0x17, 0x30, 0x1A, 0x2C, 0x19, 0x35, 0x1C, 0x2B, 0x18, 0x32, 0x1C, 0x2C, 0x19, 0x30, 0x1A, 0x33, 0x1B
    },

    {
        0x73, 0x7B, 0x74, 0x7C, 0x73, 0x7C, 0x74, 0x7D, 0x75, 0x7C, 0x75, 0x7E, 0x76, 0x7D, 0x76, 0x7E, 0x77, 0x7F, 0x77, 0x7E, 0x78, 0x7F, 0x79, 0x7F, 0x79, 0x7F, 0x7A, 0x7F, 0x78, 0x80, 0x7A, 0x83, 0x7C, 0x84, 0x7B, 0x82, 0x78, 0x7F, 0x72, 0x7A, 0x69, 0x6C, 0x52, 0x52, 0x35, 0x34, 0x24, 0x26, 0x21, 0x25, 0x28, 0x35, 0x44, 0x66, 0x6D, 0x98, 0x85, 0xB0, 0x8F, 0xBA, 0x90, 0xBC, 0x8A, 0xB0, 0x76, 0x8E, 0x53, 0x5C, 0x32, 0x37, 0x25, 0x2B, 0x1E, 0x24, 0x1B, 0x21, 0x1A, 0x24, 0x21, 0x3A, 0x35, 0x6A, 0x46, 0x8A, 0x4D, 0x95, 0x4F, 0x9D, 0x51, 0xA1, 0x53, 0xA3, 0x56, 0xA6, 0x55, 0xA7, 0x57, 0xA9, 0x56, 0xA9, 0x57, 0xAA, 0x57, 0xAB, 0x57, 0xAA, 0x57, 0xAA, 0x58, 0xAD, 0x58, 0xAD, 0x5A, 0xB0, 0x5B, 0xB2, 0x5A, 0xB3, 0x5B, 0xB1, 0x5C, 0xB3, 0x5C, 0xB5, 0x5C, 0xB4, 0x5C, 0xB3, 0x5C, 0xB4, 0x5C, 0xB4, 0x5C, 0xB6, 0x5A, 0xAD, 0x50, 0x95, 0x37, 0x5B, 0x23, 0x34, 0x1B, 0x27, 0x17, 0x1F, 0x15, 0x1B, 0x14, 0x18, 0x13, 0x17, 0x12, 0x16, 0x12, 0x17, 0x13, 0x18, 0x14, 0x1A, 0x14, 0x19, 0x17, 0x23, 0x25, 0x48, 0x3E, 0x80, 0x4E, 0x9C, 0x52, 0xA4, 0x55, 0xAA, 0x57, 0xAE, 0x58, 0xB2, 0x5B, 0xB4, 0x5C, 0xB5, 0x5C, 0xB4, 0x5C, 0xB6, 0x5C, 0xB6, 0x5C, 0xB5, 0x5B, 0xB3, 0x5B, 0xB5, 0x5D, 0xB8, 0x5E, 0xB8, 0x5D, 0xB6, 0x5C, 0xB6, 0x5C, 0xB6, 0x5D, 0xB7, 0x5E, 0xBA, 0x5F, 0xBB, 0x5E, 0xB9, 0x5D, 0xB7, 0x5C, 0xB4, 0x5A, 0xAF, 0x44, 0x73, 0x27, 0x3A, 0x1D, 0x28, 0x18, 0x1D, 0x14, 0x18, 0x14, 0x17, 0x12, 0x16, 0x12, 0x16, 0x12, 0x17, 0x12, 0x16, 0x14, 0x17, 0x18, 0x1A, 0x20, 0x23, 0x23, 0x24, 0x1A, 0x1A, 0x16, 0x19, 0x15, 0x18, 0x14, 0x16, 0x12, 0x16, 0x13, 0x17, 0x13, 0x18, 0x14, 0x19, 0x15, 0x1C, 0x19, 0x28, 0x1C, 0x2F, 0x1D, 0x30, 0x1E, 0x31, 0x1D, 0x32, 0x1D, 0x31, 0x1E, 0x33, 0x1F, 0x33, 0x1F, 0x34, 0x1F, 0x33, 0x1E, 0x33, 0x1E, 0x32, 0x1D, 0x30, 0x1E, 0x30, 0x20, 0x34, 0x20, 0x35, 0x1E, 0x32, 0x1F, 0x34, 0x1E, 0x32, 0x1E, 0x33, 0x1E, 0x32, 0x1E, 0x32, 0x1E, 0x32, 0x1C, 0x2F, 0x1F, 0x34, 0x1E, 0x2E, 0x18, 0x21, 0x15, 0x19, 0x14, 0x17, 0x13, 0x16, 0x14, 0x17, 0x14, 0x18, 0x15, 0x18, 0x18, 0x19, 0x26, 0x2A, 0x4C, 0x4D, 0x61, 0x5B, 0x5E, 0x57, 0x48, 0x3D, 0x34, 0x31, 0x4C, 0x4B, 0x60, 0x59, 0x69, 0x65, 0x6B, 0x60, 0x6A, 0x60, 0x6B, 0x5F, 0x69, 0x5D, 0x69, 0x5D, 0x6B, 0x5F, 0x6C, 0x5E, 0x6E, 0x63, 0x6E, 0x5F, 0x69, 0x5E, 0x6D, 0x61, 0x6D, 0x62, 0x6D, 0x61, 0x6B, 0x5D, 0x69, 0x5B, 0x6B, 0x5D, 0x6E, 0x5F, 0x6B, 0x5D, 0x69, 0x5C, 0x6C, 0x5E, 0x6C, 0x5D, 0x6A, 0x5C, 0x6F, 0x60, 0x6A, 0x5D, 0x6D, 0x60, 0x6E, 0x61, 0x6B, 0x5F, 0x69, 0x5C, 0x6C, 0x5E, 0x67, 0x59, 0x68, 0x5C, 0x6C, 0x60, 0x6B, 0x5F, 0x66, 0x59, 0x68, 0x5B, 0x67, 0x5B, 0x65, 0x58, 0x67, 0x5A, 0x65, 0x59, 0x65, 0x59, 0x61, 0x55, 0x4D, 0x43, 0x3A, 0x31, 0x30, 0x2B, 0x2D, 0x29, 0x32, 0x30, 0x3E, 0x3C, 0x53, 0x4E, 0x60, 0x57, 0x64, 0x58, 0x63, 0x58, 0x64, 0x58, 0x65, 0x59, 0x67, 0x59, 0x66, 0x57, 0x63, 0x56, 0x5E, 0x51, 0x5F, 0x55, 0x64, 0x58, 0x62, 0x55, 0x5F, 0x53, 0x64, 0x55, 0x62, 0x57, 0x63, 0x57, 0x61, 0x57, 0x61, 0x56, 0x60, 0x57, 0x63, 0x56, 0x61, 0x56, 0x64, 0x57, 0x65, 0x57, 0x62, 0x56, 0x62, 0x57, 0x62, 0x57, 0x62, 0x57, 0x5F, 0x55, 0x61, 0x57, 0x63, 0x57, 0x61, 0x56, 0x65, 0x58, 0x61, 0x53, 0x61, 0x55, 0x61, 0x54, 0x60, 0x55, 0x63, 0x58, 0x67, 0x5B, 0x65, 0x59, 0x63, 0x58, 0x65, 0x59, 0x63, 0x5A, 0x64, 0x5B, 0x60, 0x55, 0x61, 0x57, 0x62, 0x57, 0x62, 0x57, 0x64, 0x59, 0x65, 0x58, 0x62, 0x57, 0x60, 0x56, 0x57, 0x4B, 0x35, 0x30, 0x26, 0x26, 0x31, 0x37, 0x2A, 0x2B, 0x22, 0x26, 0x25, 0x28, 0x23, 0x27, 0x24, 0x25, 0x20, 0x24, 0x23, 0x27, 0x25, 0x2A, 0x27, 0x29, 0x27, 0x2C, 0x24, 0x29, 0x29, 0x30, 0x29, 0x2D, 0x25, 0x29, 0x2E, 0x33, 0x29, 0x30, 0x28, 0x2A, 0x27, 0x2C, 0x28, 0x2C, 0x25, 0x29, 0x2A, 0x2E, 0x2A, 0x30, 0x29, 0x2B, 0x27, 0x2B, 0x2C, 0x2E, 0x24, 0x29, 0x2E, 0x32, 0x24, 0x26, 0x2C, 0x2F, 0x22, 0x26, 0x29, 0x2D, 0x23, 0x27, 0x29, 0x2C, 0x25, 0x29, 0x2B, 0x30, 0x2A, 0x30, 0x2E, 0x31, 0x26, 0x29, 0x2D, 0x33, 0x28, 0x2D, 0x2A, 0x2E, 0x2D, 0x33
    },

    {
        0x7D, 0x3D, 0x7E, 0x3D, 0x7F, 0x3E, 0x80, 0x3D, 0x7F, 0x3D, 0x81, 0x3E, 0x81, 0x3E, 0x80, 0x3E, 0x82, 0x3E, 0x81, 0x3E, 0x81, 0x3E, 0x82, 0x3F, 0x83, 0x40, 0x84, 0x40, 0x83, 0x41, 0x86, 0x42, 0x88, 0x43, 0x86, 0x41, 0x83, 0x40, 0x78, 0x3A, 0x65, 0x30, 0x45, 0x22, 0x2D, 0x1A, 0x25, 0x16, 0x21, 0x15, 0x23, 0x19, 0x34, 0x2A, 0x66, 0x4B, 0x9C, 0x6A, 0xB7, 0x78, 0xBA, 0x75, 0xA6, 0x65, 0x7A, 0x47, 0x47, 0x2B, 0x31, 0x20, 0x28, 0x1B, 0x23, 0x18, 0x1F, 0x16, 0x1E, 0x16, 0x23, 0x1B, 0x38, 0x2F, 0x69, 0x51, 0x8F, 0x67, 0x9B, 0x6E, 0xA4, 0x75, 0xAA, 0x79, 0xAD, 0x7C, 0xAE, 0x7A, 0xAF, 0x7C, 0xB0, 0x7C, 0xB0, 0x7D, 0xB3, 0x7F, 0xB2, 0x7E, 0xB3, 0x7E, 0xB4, 0x80, 0xB6, 0x80, 0xB5, 0x81, 0xB7, 0x81, 0xB7, 0x83, 0xB8, 0x83, 0xBA, 0x84, 0xBC, 0x86, 0xBC, 0x85, 0xBB, 0x85, 0xBB, 0x85, 0xBC, 0x85, 0xBB, 0x84, 0xBC, 0x84, 0xB4, 0x7D, 0xA1, 0x65, 0x5E, 0x39, 0x33, 0x1F, 0x23, 0x17, 0x1E, 0x15, 0x1B, 0x13, 0x18, 0x11, 0x17, 0x11, 0x17, 0x11, 0x18, 0x11, 0x19, 0x12, 0x1A, 0x14, 0x2F, 0x29, 0x65, 0x50, 0x95, 0x6B, 0xA2, 0x73, 0xAB, 0x79, 0xB1, 0x7E, 0xB6, 0x81, 0xB9, 0x83, 0xB9, 0x85, 0xB9, 0x85, 0xBA, 0x85, 0xBB, 0x85, 0xBA, 0x84, 0xB9, 0x84, 0xBD, 0x86, 0xBE, 0x87, 0xBE, 0x87, 0xBE, 0x87, 0xBB, 0x86, 0xBB, 0x86, 0xBB, 0x86, 0xBE, 0x88, 0xC0, 0x8A, 0xC1, 0x89, 0xC1, 0x89, 0xC0, 0x89, 0xBB, 0x85, 0xBE, 0x85, 0xB2, 0x77, 0x72, 0x46, 0x37, 0x24, 0x25, 0x19, 0x1C, 0x14, 0x18, 0x11, 0x16, 0x10, 0x17, 0x10, 0x17, 0x10, 0x18, 0x10, 0x19, 0x12, 0x20, 0x16, 0x28, 0x19, 0x2A, 0x1B, 0x25, 0x17, 0x1C, 0x12, 0x19, 0x11, 0x17, 0x10, 0x19, 0x12, 0x19, 0x11, 0x18, 0x11, 0x1B, 0x15, 0x24, 0x1C, 0x31, 0x23, 0x32, 0x25, 0x32, 0x25, 0x33, 0x25, 0x33, 0x25, 0x36, 0x28, 0x36, 0x27, 0x34, 0x26, 0x33, 0x25, 0x33, 0x26, 0x33, 0x25, 0x33, 0x25, 0x34, 0x25, 0x32, 0x25, 0x33, 0x26, 0x32, 0x25, 0x33, 0x25, 0x35, 0x27, 0x34, 0x25, 0x31, 0x25, 0x34, 0x25, 0x33, 0x25, 0x34, 0x25, 0x31, 0x23, 0x31, 0x23, 0x29, 0x1B, 0x1B, 0x13, 0x18, 0x10, 0x17, 0x10, 0x18, 0x10, 0x18, 0x10, 0x19, 0x11, 0x19, 0x10, 0x20, 0x14, 0x42, 0x1C, 0x58, 0x21, 0x5F, 0x22, 0x4C, 0x1E, 0x2F, 0x18, 0x43, 0x1E, 0x5A, 0x22, 0x5F, 0x23, 0x64, 0x23, 0x64, 0x23, 0x64, 0x24, 0x64, 0x23, 0x5F, 0x22, 0x5E, 0x22, 0x63, 0x22, 0x60, 0x22, 0x5F, 0x22, 0x61, 0x22, 0x5E, 0x21, 0x61, 0x22, 0x61, 0x22, 0x60, 0x21, 0x62, 0x22, 0x5F, 0x21, 0x61, 0x22, 0x61, 0x23, 0x5D, 0x21, 0x60, 0x21, 0x5F, 0x21, 0x5E, 0x21, 0x5E, 0x21, 0x61, 0x22, 0x61, 0x23, 0x62, 0x23, 0x60, 0x22, 0x5C, 0x21, 0x5F, 0x23, 0x62, 0x23, 0x5D, 0x21, 0x5B, 0x21, 0x60, 0x22, 0x62, 0x23, 0x5E, 0x21, 0x5D, 0x21, 0x5D, 0x21, 0x5D, 0x22, 0x5C, 0x21, 0x5E, 0x21, 0x5C, 0x21, 0x59, 0x20, 0x55, 0x1F, 0x4B, 0x1C, 0x44, 0x1A, 0x42, 0x1A, 0x45, 0x1B, 0x4F, 0x1D, 0x57, 0x20, 0x59, 0x21, 0x5B, 0x20, 0x57, 0x1F, 0x5B, 0x21, 0x59, 0x20, 0x5A, 0x20, 0x59, 0x20, 0x59, 0x20, 0x58, 0x1F, 0x57, 0x20, 0x58, 0x20, 0x57, 0x1F, 0x54, 0x1E, 0x55, 0x1F, 0x59, 0x1F, 0x58, 0x1F, 0x55, 0x1F, 0x58, 0x20, 0x5A, 0x20, 0x59, 0x20, 0x58, 0x20, 0x57, 0x20, 0x59, 0x20, 0x59, 0x20, 0x57, 0x1F, 0x59, 0x21, 0x57, 0x1F, 0x59, 0x21, 0x56, 0x20, 0x5A, 0x21, 0x59, 0x20, 0x59, 0x20, 0x55, 0x1E, 0x57, 0x1F, 0x58, 0x1F, 0x55, 0x1F, 0x57, 0x20, 0x5A, 0x20, 0x5B, 0x21, 0x57, 0x20, 0x5A, 0x20, 0x58, 0x20, 0x58, 0x21, 0x58, 0x20, 0x57, 0x20, 0x58, 0x20, 0x56, 0x1F, 0x57, 0x1F, 0x58, 0x21, 0x5B, 0x21, 0x5B, 0x20, 0x4E, 0x1D, 0x2D, 0x16, 0x27, 0x16, 0x2E, 0x19, 0x28, 0x17, 0x26, 0x16, 0x2B, 0x18, 0x2C, 0x19, 0x2E, 0x1A, 0x2B, 0x18, 0x30, 0x1B, 0x30, 0x1B, 0x2F, 0x1B, 0x31, 0x1B, 0x29, 0x17, 0x3A, 0x1F, 0x2E, 0x1A, 0x33, 0x1C, 0x37, 0x1D, 0x2F, 0x1C, 0x2A, 0x18, 0x2E, 0x1A, 0x2B, 0x18, 0x2B, 0x19, 0x2E, 0x18, 0x2E, 0x1A, 0x28, 0x16, 0x27, 0x17, 0x27, 0x16, 0x2C, 0x19, 0x30, 0x19, 0x28, 0x17, 0x2E, 0x19, 0x29, 0x18, 0x32, 0x1B, 0x2E, 0x19, 0x33, 0x1C, 0x2D, 0x19, 0x32, 0x1C, 0x2E, 0x19, 0x28, 0x16, 0x28, 0x17, 0x2B, 0x18, 0x28, 0x16, 0x2C, 0x19, 0x2B, 0x17
    },

    {
        0x72, 0x7B, 0x74, 0x7B, 0x74, 0x7D, 0x75, 0x7D, 0x75, 0x7D, 0x75, 0x7D, 0x76, 0x7D, 0x77, 0x7E, 0x78, 0x7E, 0x77, 0x7C, 0x78, 0x7D, 0x77, 0x7D, 0x78, 0x7F, 0x79, 0x80, 0x78, 0x80, 0x7A, 0x82, 0x7C, 0x83, 0x7B, 0x82, 0x75, 0x7C, 0x69, 0x70, 0x57, 0x57, 0x39, 0x38, 0x26, 0x29, 0x1F, 0x22, 0x1C, 0x1F, 0x1C, 0x21, 0x25, 0x2F, 0x3F, 0x5D, 0x68, 0x91, 0x7F, 0xAB, 0x83, 0xAB, 0x75, 0x91, 0x55, 0x60, 0x32, 0x38, 0x24, 0x2B, 0x1E, 0x24, 0x1A, 0x1F, 0x18, 0x1D, 0x16, 0x1C, 0x17, 0x20, 0x1E, 0x32, 0x30, 0x5F, 0x42, 0x86, 0x4C, 0x95, 0x51, 0xA0, 0x54, 0xA5, 0x55, 0xA8, 0x55, 0xA6, 0x56, 0xA9, 0x56, 0xA8, 0x56, 0xAA, 0x57, 0xAB, 0x57, 0xAC, 0x58, 0xAC, 0x57, 0xAC, 0x59, 0xAD, 0x58, 0xAF, 0x59, 0xAF, 0x59, 0xAF, 0x5A, 0xB2, 0x5B, 0xB2, 0x5B, 0xB4, 0x5C, 0xB4, 0x5C, 0xB2, 0x5B, 0xB3, 0x5C, 0xB2, 0x5C, 0xB3, 0x5C, 0xB2, 0x59, 0xAE, 0x52, 0x9C, 0x39, 0x5E, 0x21, 0x2F, 0x18, 0x22, 0x15, 0x1C, 0x14, 0x19, 0x12, 0x17, 0x12, 0x16, 0x12, 0x17, 0x12, 0x18, 0x14, 0x19, 0x15, 0x1B, 0x1E, 0x39, 0x37, 0x73, 0x49, 0x95, 0x4F, 0x9E, 0x53, 0xA7, 0x57, 0xAB, 0x58, 0xB0, 0x5A, 0xB2, 0x5A, 0xB2, 0x5B, 0xB1, 0x5B, 0xB4, 0x5C, 0xB3, 0x5B, 0xB2, 0x5A, 0xB1, 0x5B, 0xB3, 0x5C, 0xB6, 0x5C, 0xB6, 0x5C, 0xB6, 0x5C, 0xB4, 0x5C, 0xB3, 0x5B, 0xB4, 0x5C, 0xB7, 0x5D, 0xB9, 0x5D, 0xB8, 0x5D, 0xB8, 0x5D, 0xB6, 0x5C, 0xB4, 0x5C, 0xB4, 0x58, 0xAC, 0x41, 0x72, 0x25, 0x37, 0x1A, 0x24, 0x16, 0x1C, 0x13, 0x17, 0x12, 0x16, 0x12, 0x17, 0x12, 0x17, 0x14, 0x17, 0x17, 0x1A, 0x1F, 0x22, 0x28, 0x28, 0x2B, 0x2A, 0x27, 0x26, 0x1C, 0x1C, 0x17, 0x18, 0x15, 0x17, 0x15, 0x18, 0x14, 0x19, 0x13, 0x17, 0x15, 0x1C, 0x19, 0x28, 0x1D, 0x2F, 0x1E, 0x31, 0x1D, 0x31, 0x1D, 0x32, 0x1D, 0x30, 0x1F, 0x35, 0x20, 0x34, 0x1E, 0x32, 0x1E, 0x32, 0x1E, 0x32, 0x1E, 0x32, 0x1D, 0x31, 0x1E, 0x32, 0x1D, 0x30, 0x1E, 0x31, 0x1D, 0x31, 0x1E, 0x31, 0x1F, 0x33, 0x1E, 0x31, 0x1C, 0x30, 0x1E, 0x31, 0x1E, 0x31, 0x1E, 0x32, 0x1D, 0x2E, 0x1C, 0x2D, 0x19, 0x21, 0x14, 0x19, 0x13, 0x17, 0x14, 0x16, 0x14, 0x17, 0x15, 0x19, 0x16, 0x18, 0x17, 0x19, 0x27, 0x2A, 0x4C, 0x4D, 0x5E, 0x5B, 0x60, 0x5A, 0x47, 0x3E, 0x34, 0x30, 0x4E, 0x4F, 0x62, 0x5C, 0x69, 0x60, 0x6E, 0x61, 0x6F, 0x63, 0x6E, 0x62, 0x6E, 0x60, 0x6A, 0x5D, 0x68, 0x5C, 0x6D, 0x60, 0x6C, 0x5E, 0x6C, 0x5F, 0x6C, 0x5F, 0x69, 0x5E, 0x6C, 0x5E, 0x6C, 0x5F, 0x6A, 0x5E, 0x6D, 0x5F, 0x6A, 0x5C, 0x6C, 0x60, 0x6C, 0x5F, 0x6B, 0x5D, 0x6D, 0x5F, 0x6B, 0x5E, 0x69, 0x5B, 0x69, 0x5D, 0x6A, 0x5D, 0x6F, 0x60, 0x6C, 0x60, 0x6B, 0x5C, 0x66, 0x5B, 0x69, 0x5E, 0x6D, 0x5E, 0x68, 0x5C, 0x66, 0x5A, 0x6B, 0x5E, 0x6C, 0x60, 0x67, 0x5C, 0x6A, 0x5D, 0x67, 0x5B, 0x67, 0x5C, 0x67, 0x5B, 0x68, 0x5B, 0x67, 0x5B, 0x64, 0x58, 0x61, 0x55, 0x57, 0x4D, 0x50, 0x47, 0x4F, 0x48, 0x52, 0x4A, 0x58, 0x52, 0x60, 0x58, 0x64, 0x59, 0x65, 0x58, 0x61, 0x57, 0x65, 0x58, 0x64, 0x58, 0x64, 0x59, 0x64, 0x58, 0x62, 0x57, 0x63, 0x56, 0x61, 0x55, 0x62, 0x56, 0x61, 0x54, 0x60, 0x54, 0x61, 0x55, 0x63, 0x57, 0x61, 0x54, 0x5F, 0x54, 0x62, 0x56, 0x63, 0x57, 0x64, 0x58, 0x62, 0x57, 0x61, 0x56, 0x64, 0x57, 0x61, 0x56, 0x60, 0x54, 0x63, 0x58, 0x60, 0x54, 0x64, 0x59, 0x61, 0x56, 0x63, 0x57, 0x61, 0x57, 0x65, 0x58, 0x61, 0x54, 0x64, 0x58, 0x64, 0x56, 0x60, 0x55, 0x63, 0x56, 0x65, 0x59, 0x65, 0x57, 0x61, 0x56, 0x64, 0x58, 0x60, 0x55, 0x60, 0x56, 0x5F, 0x55, 0x61, 0x57, 0x62, 0x57, 0x60, 0x54, 0x62, 0x56, 0x65, 0x58, 0x64, 0x59, 0x62, 0x57, 0x55, 0x49, 0x2F, 0x2A, 0x27, 0x28, 0x29, 0x2A, 0x27, 0x29, 0x23, 0x26, 0x29, 0x2D, 0x28, 0x2D, 0x2C, 0x31, 0x26, 0x28, 0x2D, 0x33, 0x29, 0x2E, 0x2A, 0x2F, 0x2B, 0x2E, 0x24, 0x28, 0x31, 0x38, 0x27, 0x2B, 0x2C, 0x33, 0x2D, 0x2E, 0x2A, 0x2F, 0x26, 0x28, 0x2A, 0x2E, 0x25, 0x27, 0x27, 0x2D, 0x26, 0x28, 0x29, 0x2E, 0x23, 0x25, 0x24, 0x27, 0x25, 0x28, 0x29, 0x2E, 0x2C, 0x2D, 0x26, 0x2C, 0x2A, 0x2E, 0x26, 0x2A, 0x2F, 0x35, 0x28, 0x2B, 0x2D, 0x34, 0x26, 0x28, 0x2C, 0x32, 0x27, 0x28, 0x22, 0x24, 0x25, 0x29, 0x26, 0x28, 0x24, 0x26, 0x2A, 0x2F, 0x28, 0x2B
    },

    {
        0x7E, 0x3D, 0x7E, 0x3B, 0x80, 0x3D, 0x7F, 0x3D, 0x81, 0x3E, 0x80, 0x3D, 0x81, 0x3E, 0x81, 0x3E, 0x83, 0x3E, 0x82, 0x3F, 0x82, 0x3F, 0x83, 0x3F, 0x82, 0x40, 0x83, 0x40, 0x85, 0x40, 0x83, 0x40, 0x85, 0x41, 0x84, 0x41, 0x7C, 0x3C, 0x68, 0x31, 0x49, 0x24, 0x31, 0x1B, 0x27, 0x17, 0x24, 0x17, 0x20, 0x14, 0x1E, 0x14, 0x21, 0x17, 0x2F, 0x25, 0x5A, 0x44, 0x8E, 0x60, 0x99, 0x5F, 0x78, 0x46, 0x48, 0x2C, 0x31, 0x20, 0x29, 0x1C, 0x23, 0x17, 0x1F, 0x16, 0x1C, 0x14, 0x1B, 0x13, 0x1B, 0x14, 0x20, 0x19, 0x32, 0x2C, 0x65, 0x4E, 0x8F, 0x67, 0xA1, 0x72, 0xA9, 0x78, 0xB0, 0x7C, 0xB1, 0x7D, 0xAF, 0x7C, 0xB0, 0x7C, 0xB1, 0x7C, 0xB2, 0x7F, 0xB4, 0x7F, 0xB5, 0x80, 0xB3, 0x7E, 0xB2, 0x7E, 0xB5, 0x81, 0xB5, 0x81, 0xB5, 0x81, 0xB6, 0x82, 0xB9, 0x82, 0xB8, 0x83, 0xB9, 0x84, 0xB9, 0x83, 0xB8, 0x82, 0xB9, 0x82, 0xB9, 0x84, 0xB9, 0x82, 0xB9, 0x81, 0xB0, 0x77, 0x8D, 0x55, 0x48, 0x2A, 0x27, 0x19, 0x1E, 0x15, 0x1B, 0x13, 0x19, 0x12, 0x18, 0x11, 0x18, 0x11, 0x1A, 0x14, 0x1E, 0x16, 0x1C, 0x14, 0x2A, 0x27, 0x6A, 0x52, 0x98, 0x6C, 0xA4, 0x75, 0xAD, 0x7A, 0xAF, 0x7E, 0xB4, 0x82, 0xB7, 0x84, 0xBA, 0x84, 0xB7, 0x82, 0xB8, 0x84, 0xBA, 0x85, 0xBB, 0x85, 0xBC, 0x85, 0xBB, 0x84, 0xBB, 0x87, 0xBB, 0x86, 0xBB, 0x87, 0xBE, 0x86, 0xBF, 0x87, 0xBB, 0x86, 0xBE, 0x88, 0xBE, 0x88, 0xC1, 0x89, 0xBD, 0x87, 0xC0, 0x88, 0xC0, 0x87, 0xBC, 0x86, 0xBC, 0x86, 0xB7, 0x7C, 0x7B, 0x4B, 0x38, 0x25, 0x25, 0x19, 0x1D, 0x15, 0x18, 0x11, 0x17, 0x11, 0x17, 0x11, 0x19, 0x12, 0x20, 0x16, 0x29, 0x1A, 0x2A, 0x1B, 0x2C, 0x1C, 0x2C, 0x1B, 0x27, 0x17, 0x1E, 0x13, 0x1A, 0x11, 0x18, 0x11, 0x18, 0x12, 0x1A, 0x13, 0x25, 0x1C, 0x2D, 0x22, 0x31, 0x24, 0x31, 0x24, 0x32, 0x25, 0x32, 0x26, 0x33, 0x25, 0x33, 0x25, 0x33, 0x27, 0x35, 0x26, 0x35, 0x26, 0x34, 0x27, 0x33, 0x25, 0x33, 0x25, 0x33, 0x26, 0x32, 0x25, 0x33, 0x25, 0x32, 0x25, 0x33, 0x26, 0x35, 0x26, 0x33, 0x25, 0x32, 0x24, 0x31, 0x24, 0x33, 0x24, 0x32, 0x24, 0x31, 0x23, 0x29, 0x1C, 0x1D, 0x14, 0x18, 0x10, 0x16, 0x0F, 0x16, 0x10, 0x17, 0x10, 0x19, 0x11, 0x19, 0x11, 0x1F, 0x13, 0x3E, 0x1C, 0x57, 0x21, 0x5F, 0x22, 0x4F, 0x1F, 0x30, 0x19, 0x42, 0x1F, 0x5D, 0x24, 0x65, 0x25, 0x65, 0x25, 0x64, 0x23, 0x63, 0x23, 0x63, 0x23, 0x60, 0x22, 0x60, 0x22, 0x5E, 0x22, 0x62, 0x22, 0x62, 0x23, 0x60, 0x23, 0x61, 0x22, 0x61, 0x22, 0x60, 0x22, 0x62, 0x22, 0x5F, 0x21, 0x5F, 0x21, 0x5F, 0x21, 0x61, 0x22, 0x60, 0x22, 0x62, 0x22, 0x62, 0x23, 0x61, 0x21, 0x5D, 0x22, 0x5F, 0x22, 0x61, 0x22, 0x63, 0x22, 0x5E, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x5D, 0x22, 0x60, 0x23, 0x60, 0x21, 0x5F, 0x22, 0x5C, 0x21, 0x5D, 0x21, 0x5D, 0x21, 0x5F, 0x22, 0x5F, 0x22, 0x5E, 0x21, 0x5E, 0x21, 0x5C, 0x20, 0x5A, 0x21, 0x5B, 0x21, 0x5A, 0x21, 0x5A, 0x21, 0x58, 0x21, 0x5A, 0x21, 0x5B, 0x20, 0x59, 0x1F, 0x5C, 0x20, 0x5B, 0x20, 0x5B, 0x20, 0x5A, 0x21, 0x5C, 0x22, 0x5B, 0x21, 0x59, 0x20, 0x59, 0x20, 0x57, 0x1F, 0x57, 0x20, 0x59, 0x20, 0x58, 0x20, 0x59, 0x1F, 0x59, 0x20, 0x56, 0x1F, 0x59, 0x21, 0x57, 0x1F, 0x53, 0x1E, 0x55, 0x1F, 0x57, 0x1F, 0x58, 0x21, 0x5A, 0x20, 0x55, 0x20, 0x57, 0x1F, 0x55, 0x1F, 0x54, 0x1E, 0x57, 0x20, 0x56, 0x1F, 0x58, 0x20, 0x58, 0x20, 0x57, 0x1F, 0x58, 0x20, 0x58, 0x1F, 0x58, 0x1F, 0x57, 0x1F, 0x59, 0x20, 0x54, 0x1F, 0x55, 0x1F, 0x56, 0x1F, 0x59, 0x20, 0x58, 0x20, 0x57, 0x1F, 0x56, 0x1F, 0x57, 0x1F, 0x58, 0x20, 0x59, 0x20, 0x57, 0x1F, 0x57, 0x20, 0x57, 0x20, 0x59, 0x20, 0x58, 0x21, 0x57, 0x20, 0x51, 0x1E, 0x36, 0x1A, 0x2F, 0x1A, 0x2D, 0x19, 0x37, 0x1E, 0x2C, 0x19, 0x3A, 0x1E, 0x2C, 0x19, 0x30, 0x1A, 0x25, 0x16, 0x30, 0x1A, 0x2B, 0x18, 0x31, 0x1B, 0x26, 0x16, 0x29, 0x1A, 0x2E, 0x19, 0x27, 0x18, 0x31, 0x1C, 0x2D, 0x18, 0x2C, 0x19, 0x29, 0x1A, 0x2E, 0x1A, 0x2D, 0x18, 0x2C, 0x18, 0x2E, 0x19, 0x2E, 0x1A, 0x30, 0x1A, 0x2D, 0x1A, 0x32, 0x1A, 0x2D, 0x1B, 0x35, 0x1B, 0x2C, 0x19, 0x30, 0x1A, 0x27, 0x17, 0x33, 0x1B, 0x26, 0x16, 0x2C, 0x19, 0x24, 0x16, 0x2F, 0x1A, 0x2D, 0x19, 0x2E, 0x19, 0x2B, 0x19, 0x2E, 0x1A, 0x2F, 0x1A, 0x34, 0x1C, 0x2F, 0x19
    },

    {
        0x72, 0x7B, 0x72, 0x7C, 0x75, 0x7C, 0x74, 0x7C, 0x75, 0x7D, 0x75, 0x7C, 0x76, 0x7E, 0x77, 0x7E, 0x77, 0x7F, 0x78, 0x7F, 0x79, 0x80, 0x79, 0x7F, 0x78, 0x81, 0x79, 0x80, 0x7A, 0x81, 0x79, 0x81, 0x7A, 0x82, 0x78, 0x7E, 0x6E, 0x72, 0x5C, 0x5A, 0x3E, 0x3C, 0x29, 0x2B, 0x22, 0x24, 0x1E, 0x21, 0x1A, 0x1E, 0x18, 0x1C, 0x1A, 0x1F, 0x22, 0x2A, 0x37, 0x50, 0x58, 0x80, 0x67, 0x86, 0x51, 0x5F, 0x31, 0x38, 0x24, 0x2B, 0x1F, 0x25, 0x1A, 0x21, 0x18, 0x1D, 0x16, 0x1B, 0x14, 0x1A, 0x14, 0x1A, 0x15, 0x1D, 0x1C, 0x2E, 0x30, 0x5E, 0x45, 0x89, 0x4F, 0x9B, 0x52, 0xA1, 0x55, 0xA7, 0x57, 0xAA, 0x57, 0xAB, 0x56, 0xAA, 0x57, 0xA9, 0x56, 0xAB, 0x57, 0xAD, 0x57, 0xAB, 0x58, 0xAC, 0x57, 0xAB, 0x58, 0xAD, 0x58, 0xAE, 0x59, 0xB0, 0x59, 0xAF, 0x58, 0xB0, 0x5A, 0xAE, 0x5A, 0xB1, 0x5A, 0xB0, 0x5B, 0xB1, 0x59, 0xB2, 0x5C, 0xB2, 0x5B, 0xB1, 0x5B, 0xAF, 0x55, 0xA4, 0x46, 0x7C, 0x2A, 0x3E, 0x1A, 0x23, 0x16, 0x1D, 0x14, 0x1A, 0x13, 0x17, 0x12, 0x17, 0x12, 0x18, 0x14, 0x1B, 0x17, 0x1E, 0x16, 0x1B, 0x19, 0x2A, 0x32, 0x66, 0x48, 0x92, 0x4F, 0x9F, 0x53, 0xA5, 0x56, 0xAA, 0x57, 0xAE, 0x59, 0xB0, 0x5A, 0xB1, 0x5A, 0xAF, 0x5A, 0xB0, 0x5B, 0xB2, 0x5B, 0xB4, 0x5B, 0xB5, 0x5D, 0xB4, 0x5B, 0xB4, 0x5B, 0xB6, 0x5B, 0xB5, 0x5C, 0xB7, 0x5D, 0xB6, 0x5C, 0xB4, 0x5D, 0xB8, 0x5D, 0xB8, 0x5E, 0xBA, 0x5B, 0xB6, 0x5C, 0xB7, 0x5E, 0xB5, 0x5D, 0xB4, 0x5B, 0xB5, 0x5B, 0xB1, 0x47, 0x7B, 0x27, 0x3A, 0x1B, 0x25, 0x16, 0x1D, 0x14, 0x18, 0x13, 0x17, 0x14, 0x17, 0x17, 0x1A, 0x20, 0x22, 0x29, 0x28, 0x2C, 0x2A, 0x2E, 0x2C, 0x2D, 0x2C, 0x29, 0x28, 0x1E, 0x1E, 0x17, 0x19, 0x15, 0x17, 0x14, 0x17, 0x15, 0x1B, 0x18, 0x28, 0x1B, 0x2E, 0x1D, 0x30, 0x1D, 0x30, 0x1D, 0x30, 0x1D, 0x30, 0x1E, 0x31, 0x1E, 0x31, 0x1E, 0x32, 0x1E, 0x32, 0x1E, 0x33, 0x1D, 0x32, 0x1D, 0x31, 0x1D, 0x31, 0x1E, 0x31, 0x1D, 0x30, 0x1D, 0x31, 0x1C, 0x31, 0x1E, 0x32, 0x1F, 0x31, 0x1E, 0x32, 0x1D, 0x30, 0x1D, 0x2F, 0x1D, 0x30, 0x1D, 0x30, 0x1D, 0x2E, 0x19, 0x23, 0x16, 0x1B, 0x13, 0x16, 0x13, 0x16, 0x13, 0x16, 0x14, 0x17, 0x16, 0x19, 0x18, 0x1A, 0x24, 0x27, 0x47, 0x4A, 0x5D, 0x57, 0x60, 0x5B, 0x4B, 0x40, 0x33, 0x30, 0x4B, 0x4B, 0x65, 0x5F, 0x6C, 0x63, 0x6D, 0x64, 0x6F, 0x61, 0x6C, 0x60, 0x6D, 0x60, 0x6C, 0x5D, 0x6C, 0x5E, 0x69, 0x5D, 0x6D, 0x5E, 0x6D, 0x61, 0x6C, 0x5F, 0x6B, 0x5E, 0x6C, 0x5F, 0x6A, 0x5E, 0x6F, 0x60, 0x6C, 0x5E, 0x6C, 0x5E, 0x6B, 0x5E, 0x6E, 0x61, 0x6C, 0x5E, 0x6E, 0x5F, 0x6E, 0x5F, 0x6B, 0x5E, 0x6C, 0x5E, 0x6C, 0x5D, 0x6C, 0x5F, 0x6F, 0x60, 0x69, 0x5B, 0x6A, 0x5E, 0x68, 0x5C, 0x67, 0x5C, 0x69, 0x5E, 0x6B, 0x5E, 0x69, 0x5D, 0x68, 0x5B, 0x67, 0x5B, 0x65, 0x5A, 0x6B, 0x5F, 0x6C, 0x5E, 0x67, 0x5B, 0x69, 0x5C, 0x67, 0x59, 0x66, 0x59, 0x64, 0x59, 0x62, 0x58, 0x65, 0x5A, 0x63, 0x59, 0x64, 0x5B, 0x66, 0x59, 0x63, 0x57, 0x65, 0x5B, 0x66, 0x5A, 0x65, 0x58, 0x65, 0x5B, 0x66, 0x5B, 0x65, 0x59, 0x61, 0x55, 0x61, 0x57, 0x62, 0x54, 0x60, 0x57, 0x63, 0x57, 0x61, 0x54, 0x64, 0x56, 0x64, 0x57, 0x60, 0x56, 0x64, 0x58, 0x61, 0x55, 0x5E, 0x53, 0x5E, 0x53, 0x61, 0x55, 0x62, 0x56, 0x63, 0x56, 0x60, 0x55, 0x61, 0x55, 0x5E, 0x53, 0x61, 0x54, 0x62, 0x56, 0x5F, 0x54, 0x61, 0x56, 0x60, 0x56, 0x62, 0x55, 0x61, 0x56, 0x60, 0x54, 0x62, 0x55, 0x61, 0x55, 0x65, 0x58, 0x60, 0x54, 0x63, 0x55, 0x62, 0x55, 0x62, 0x56, 0x64, 0x56, 0x62, 0x55, 0x61, 0x57, 0x62, 0x57, 0x63, 0x59, 0x63, 0x57, 0x5F, 0x55, 0x5F, 0x54, 0x62, 0x56, 0x62, 0x56, 0x62, 0x57, 0x62, 0x56, 0x56, 0x4A, 0x36, 0x33, 0x2E, 0x31, 0x2B, 0x2E, 0x33, 0x38, 0x28, 0x2E, 0x32, 0x36, 0x26, 0x29, 0x2A, 0x2C, 0x23, 0x25, 0x2B, 0x2F, 0x26, 0x2B, 0x2A, 0x2C, 0x24, 0x26, 0x27, 0x2F, 0x29, 0x2C, 0x23, 0x27, 0x2D, 0x34, 0x28, 0x2B, 0x27, 0x2C, 0x26, 0x29, 0x2B, 0x2F, 0x2A, 0x2E, 0x28, 0x2C, 0x2B, 0x2F, 0x29, 0x30, 0x2C, 0x30, 0x29, 0x2D, 0x2D, 0x2F, 0x29, 0x2F, 0x2E, 0x30, 0x26, 0x2A, 0x2A, 0x2C, 0x23, 0x26, 0x2A, 0x2E, 0x22, 0x24, 0x27, 0x29, 0x24, 0x28, 0x2C, 0x31, 0x2B, 0x30, 0x2B, 0x2E, 0x29, 0x2D, 0x2C, 0x31, 0x28, 0x2C, 0x2D, 0x32, 0x29, 0x2A
    },

    {
        0x7D, 0x3C, 0x7E, 0x3D, 0x7F, 0x3D, 0x80, 0x3E, 0x81, 0x3E, 0x82, 0x3F, 0x81, 0x3E, 0x82, 0x3F, 0x82, 0x3E, 0x84, 0x3F, 0x82, 0x40, 0x83, 0x3F, 0x84, 0x40, 0x84, 0x40, 0x85, 0x3F, 0x85, 0x41, 0x83, 0x40, 0x7E, 0x3C, 0x6A, 0x33, 0x4D, 0x26, 0x33, 0x1D, 0x2A, 0x19, 0x24, 0x16, 0x20, 0x14, 0x1C, 0x13, 0x1B, 0x12, 0x1B, 0x13, 0x1E, 0x16, 0x2A, 0x22, 0x48, 0x36, 0x5C, 0x3C, 0x45, 0x2A, 0x30, 0x20, 0x29, 0x1C, 0x25, 0x19, 0x21, 0x17, 0x1E, 0x16, 0x1C, 0x13, 0x19, 0x12, 0x19, 0x12, 0x1A, 0x14, 0x24, 0x1E, 0x42, 0x3A, 0x7C, 0x60, 0x9E, 0x72, 0xA6, 0x76, 0xAD, 0x7A, 0xAF, 0x7C, 0xB3, 0x7F, 0xB2, 0x7F, 0xB2, 0x80, 0xB2, 0x80, 0xB3, 0x7F, 0xB4, 0x80, 0xB3, 0x7E, 0xB3, 0x7E, 0xB4, 0x80, 0xB6, 0x81, 0xB7, 0x82, 0xB8, 0x82, 0xB6, 0x81, 0xB6, 0x82, 0xB8, 0x82, 0xB7, 0x82, 0xB4, 0x80, 0xB5, 0x81, 0xB9, 0x83, 0xB9, 0x80, 0xB0, 0x7C, 0xA1, 0x6A, 0x73, 0x46, 0x3B, 0x25, 0x26, 0x1A, 0x1F, 0x15, 0x1B, 0x13, 0x1A, 0x12, 0x19, 0x12, 0x18, 0x11, 0x1A, 0x14, 0x20, 0x17, 0x1D, 0x14, 0x1A, 0x15, 0x2D, 0x2A, 0x6A, 0x53, 0x99, 0x6F, 0xAC, 0x7A, 0xAF, 0x7C, 0xB3, 0x80, 0xB6, 0x81, 0xB5, 0x80, 0xB4, 0x81, 0xB9, 0x84, 0xB9, 0x84, 0xBB, 0x85, 0xBE, 0x86, 0xBC, 0x87, 0xBD, 0x87, 0xBE, 0x87, 0xBF, 0x87, 0xBD, 0x87, 0xBD, 0x89, 0xBD, 0x86, 0xBD, 0x87, 0xC0, 0x89, 0xC0, 0x8A, 0xBE, 0x87, 0xBC, 0x86, 0xBD, 0x86, 0xBC, 0x86, 0xB9, 0x84, 0xBB, 0x84, 0xB7, 0x7C, 0x83, 0x51, 0x3D, 0x27, 0x25, 0x19, 0x1C, 0x14, 0x19, 0x12, 0x1A, 0x13, 0x20, 0x16, 0x28, 0x1A, 0x2B, 0x1C, 0x2C, 0x1B, 0x2E, 0x1C, 0x2D, 0x1C, 0x2D, 0x1B, 0x28, 0x19, 0x1E, 0x13, 0x19, 0x12, 0x19, 0x13, 0x22, 0x1B, 0x2D, 0x23, 0x31, 0x24, 0x32, 0x26, 0x33, 0x26, 0x32, 0x26, 0x33, 0x26, 0x32, 0x26, 0x32, 0x25, 0x33, 0x25, 0x32, 0x25, 0x32, 0x26, 0x33, 0x26, 0x32, 0x25, 0x32, 0x25, 0x32, 0x24, 0x32, 0x25, 0x34, 0x26, 0x32, 0x25, 0x33, 0x25, 0x34, 0x26, 0x34, 0x25, 0x34, 0x25, 0x33, 0x25, 0x33, 0x25, 0x32, 0x24, 0x2C, 0x1E, 0x1D, 0x14, 0x19, 0x11, 0x17, 0x0F, 0x16, 0x10, 0x17, 0x0F, 0x17, 0x0F, 0x18, 0x11, 0x1E, 0x13, 0x3E, 0x1C, 0x59, 0x21, 0x5C, 0x21, 0x4F, 0x1F, 0x31, 0x18, 0x3E, 0x1D, 0x56, 0x22, 0x62, 0x25, 0x67, 0x26, 0x63, 0x23, 0x63, 0x24, 0x61, 0x24, 0x63, 0x24, 0x60, 0x22, 0x5F, 0x23, 0x5F, 0x22, 0x5E, 0x22, 0x5F, 0x22, 0x62, 0x23, 0x62, 0x22, 0x62, 0x22, 0x60, 0x22, 0x61, 0x23, 0x62, 0x22, 0x61, 0x22, 0x60, 0x23, 0x63, 0x23, 0x62, 0x22, 0x5F, 0x21, 0x60, 0x21, 0x5E, 0x22, 0x5E, 0x21, 0x5D, 0x21, 0x60, 0x22, 0x62, 0x22, 0x60, 0x22, 0x61, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x5F, 0x21, 0x60, 0x22, 0x5D, 0x21, 0x5D, 0x21, 0x61, 0x24, 0x5D, 0x21, 0x5C, 0x21, 0x5B, 0x21, 0x5D, 0x22, 0x5D, 0x21, 0x5B, 0x21, 0x59, 0x21, 0x5C, 0x21, 0x5B, 0x21, 0x5E, 0x23, 0x5C, 0x22, 0x5E, 0x21, 0x59, 0x20, 0x58, 0x20, 0x55, 0x1F, 0x5A, 0x21, 0x5A, 0x20, 0x5C, 0x22, 0x5A, 0x20, 0x57, 0x20, 0x58, 0x20, 0x59, 0x21, 0x5A, 0x20, 0x59, 0x20, 0x56, 0x1F, 0x55, 0x1F, 0x57, 0x1F, 0x58, 0x20, 0x58, 0x20, 0x5A, 0x21, 0x57, 0x20, 0x53, 0x1E, 0x57, 0x20, 0x56, 0x21, 0x55, 0x20, 0x5A, 0x20, 0x57, 0x1F, 0x55, 0x1F, 0x59, 0x20, 0x54, 0x20, 0x58, 0x20, 0x5B, 0x21, 0x58, 0x21, 0x58, 0x21, 0x59, 0x1F, 0x58, 0x20, 0x55, 0x1F, 0x56, 0x20, 0x56, 0x20, 0x58, 0x20, 0x59, 0x20, 0x56, 0x1F, 0x54, 0x20, 0x59, 0x20, 0x56, 0x20, 0x57, 0x1F, 0x57, 0x1F, 0x58, 0x21, 0x5B, 0x21, 0x58, 0x1F, 0x54, 0x1F, 0x57, 0x1F, 0x56, 0x1F, 0x55, 0x1F, 0x54, 0x1E, 0x4F, 0x1E, 0x39, 0x1B, 0x2F, 0x19, 0x34, 0x1C, 0x2B, 0x19, 0x2F, 0x1B, 0x2D, 0x19, 0x28, 0x18, 0x35, 0x1C, 0x2C, 0x1A, 0x35, 0x1C, 0x2E, 0x1A, 0x35, 0x1D, 0x36, 0x1D, 0x33, 0x1C, 0x34, 0x1C, 0x2B, 0x19, 0x39, 0x1E, 0x2C, 0x18, 0x29, 0x18, 0x26, 0x17, 0x30, 0x1B, 0x2C, 0x18, 0x2B, 0x1A, 0x31, 0x1A, 0x2C, 0x1A, 0x2D, 0x19, 0x28, 0x19, 0x2D, 0x19, 0x2D, 0x1A, 0x2C, 0x18, 0x26, 0x16, 0x28, 0x17, 0x29, 0x17, 0x2E, 0x19, 0x2A, 0x18, 0x30, 0x1B, 0x34, 0x1C, 0x32, 0x1B, 0x30, 0x1B, 0x2F, 0x1A, 0x34, 0x1C, 0x2F, 0x1A, 0x2C, 0x19, 0x29, 0x17, 0x27, 0x16
    },

    {
        0x72, 0x79, 0x74, 0x7C, 0x74, 0x7C, 0x75, 0x7D, 0x75, 0x7E, 0x77, 0x7E, 0x76, 0x7F, 0x78, 0x7F, 0x79, 0x80, 0x79, 0x80, 0x78, 0x81, 0x78, 0x7F, 0x79, 0x81, 0x79, 0x80, 0x79, 0x81, 0x7A, 0x81, 0x79, 0x7F, 0x71, 0x76, 0x60, 0x5F, 0x43, 0x40, 0x2D, 0x2D, 0x24, 0x27, 0x1F, 0x22, 0x1B, 0x1E, 0x18, 0x1C, 0x17, 0x1A, 0x16, 0x1A, 0x18, 0x1D, 0x1F, 0x28, 0x2C, 0x3F, 0x39, 0x4E, 0x2E, 0x37, 0x22, 0x2B, 0x1E, 0x26, 0x1B, 0x22, 0x18, 0x1F, 0x17, 0x1C, 0x15, 0x1A, 0x14, 0x19, 0x13, 0x18, 0x14, 0x1B, 0x19, 0x27, 0x26, 0x49, 0x3D, 0x7F, 0x4E, 0x9B, 0x51, 0xA3, 0x54, 0xA5, 0x55, 0xA7, 0x58, 0xAD, 0x58, 0xAE, 0x58, 0xAD, 0x57, 0xAD, 0x58, 0xAC, 0x57, 0xAD, 0x58, 0xAC, 0x57, 0xAB, 0x57, 0xAB, 0x58, 0xAE, 0x5A, 0xB1, 0x59, 0xB0, 0x59, 0xB0, 0x59, 0xB0, 0x59, 0xAF, 0x59, 0xAF, 0x59, 0xAE, 0x58, 0xAD, 0x5A, 0xB0, 0x5B, 0xAF, 0x57, 0xA5, 0x4E, 0x8D, 0x39, 0x5C, 0x22, 0x30, 0x19, 0x23, 0x16, 0x1D, 0x15, 0x1A, 0x13, 0x19, 0x13, 0x18, 0x13, 0x17, 0x14, 0x1A, 0x17, 0x1E, 0x15, 0x1B, 0x14, 0x1A, 0x1A, 0x29, 0x2F, 0x61, 0x48, 0x92, 0x51, 0xA3, 0x55, 0xA6, 0x56, 0xAB, 0x58, 0xAF, 0x5A, 0xAF, 0x59, 0xAE, 0x5A, 0xB2, 0x5B, 0xB2, 0x5C, 0xB3, 0x5C, 0xB4, 0x5D, 0xB7, 0x5D, 0xB6, 0x5E, 0xB7, 0x5E, 0xB8, 0x5E, 0xB8, 0x5D, 0xB7, 0x5D, 0xB6, 0x5C, 0xB5, 0x5D, 0xB9, 0x5D, 0xB9, 0x5A, 0xB7, 0x5A, 0xB6, 0x5B, 0xB4, 0x5C, 0xB3, 0x5B, 0xB1, 0x5B, 0xB4, 0x58, 0xAE, 0x4A, 0x84, 0x2A, 0x3F, 0x1B, 0x25, 0x16, 0x1C, 0x15, 0x18, 0x18, 0x1B, 0x20, 0x23, 0x29, 0x28, 0x2B, 0x2A, 0x2D, 0x2C, 0x2E, 0x2D, 0x2E, 0x2C, 0x2D, 0x2C, 0x2B, 0x2A, 0x1E, 0x1E, 0x17, 0x19, 0x15, 0x1A, 0x17, 0x26, 0x1C, 0x2E, 0x1D, 0x30, 0x1D, 0x32, 0x1E, 0x32, 0x1E, 0x32, 0x1E, 0x32, 0x1E, 0x32, 0x1D, 0x30, 0x1D, 0x31, 0x1E, 0x32, 0x1E, 0x31, 0x1E, 0x31, 0x1D, 0x31, 0x1D, 0x30, 0x1D, 0x30, 0x1D, 0x31, 0x1E, 0x31, 0x1D, 0x31, 0x1E, 0x31, 0x1E, 0x32, 0x1E, 0x33, 0x1E, 0x32, 0x1E, 0x32, 0x1F, 0x31, 0x1E, 0x30, 0x1C, 0x27, 0x15, 0x1A, 0x14, 0x18, 0x13, 0x16, 0x13, 0x16, 0x13, 0x16, 0x14, 0x16, 0x17, 0x19, 0x24, 0x27, 0x48, 0x4A, 0x5F, 0x5B, 0x61, 0x59, 0x4C, 0x41, 0x32, 0x2E, 0x48, 0x48, 0x60, 0x59, 0x6B, 0x62, 0x6F, 0x63, 0x6D, 0x60, 0x6E, 0x62, 0x6F, 0x60, 0x6D, 0x61, 0x6C, 0x5E, 0x6C, 0x5E, 0x6B, 0x5E, 0x69, 0x5D, 0x6B, 0x5D, 0x6C, 0x62, 0x6B, 0x5D, 0x6C, 0x5F, 0x6D, 0x60, 0x6D, 0x5F, 0x6C, 0x5E, 0x6C, 0x5F, 0x6C, 0x5F, 0x6F, 0x62, 0x6D, 0x5F, 0x6A, 0x5D, 0x6C, 0x5D, 0x6A, 0x5E, 0x6B, 0x5E, 0x68, 0x5B, 0x6B, 0x5E, 0x70, 0x60, 0x6D, 0x60, 0x6B, 0x5F, 0x6B, 0x5C, 0x6A, 0x5E, 0x6A, 0x5D, 0x6A, 0x5D, 0x6B, 0x5E, 0x69, 0x5B, 0x68, 0x5D, 0x6B, 0x60, 0x67, 0x5B, 0x67, 0x5B, 0x68, 0x5B, 0x68, 0x5C, 0x69, 0x5C, 0x66, 0x59, 0x63, 0x59, 0x64, 0x59, 0x65, 0x5B, 0x67, 0x5C, 0x67, 0x5B, 0x68, 0x5C, 0x65, 0x58, 0x61, 0x55, 0x60, 0x53, 0x62, 0x56, 0x64, 0x57, 0x65, 0x5A, 0x63, 0x58, 0x61, 0x54, 0x63, 0x57, 0x62, 0x54, 0x61, 0x57, 0x63, 0x58, 0x60, 0x54, 0x61, 0x55, 0x61, 0x54, 0x64, 0x57, 0x61, 0x55, 0x64, 0x59, 0x62, 0x56, 0x60, 0x52, 0x60, 0x57, 0x62, 0x57, 0x60, 0x55, 0x63, 0x58, 0x61, 0x54, 0x60, 0x56, 0x62, 0x57, 0x60, 0x53, 0x61, 0x57, 0x63, 0x59, 0x62, 0x58, 0x60, 0x58, 0x63, 0x57, 0x63, 0x59, 0x5E, 0x51, 0x5F, 0x54, 0x5E, 0x53, 0x63, 0x58, 0x64, 0x57, 0x61, 0x55, 0x5F, 0x54, 0x64, 0x58, 0x61, 0x55, 0x62, 0x56, 0x63, 0x55, 0x63, 0x58, 0x66, 0x5B, 0x62, 0x56, 0x61, 0x54, 0x60, 0x54, 0x60, 0x54, 0x60, 0x55, 0x5F, 0x53, 0x56, 0x4C, 0x37, 0x34, 0x2A, 0x2B, 0x30, 0x32, 0x26, 0x28, 0x2E, 0x33, 0x28, 0x29, 0x26, 0x2C, 0x2F, 0x33, 0x2A, 0x2F, 0x2E, 0x34, 0x29, 0x2D, 0x31, 0x37, 0x2F, 0x34, 0x28, 0x2D, 0x2B, 0x31, 0x26, 0x29, 0x31, 0x36, 0x25, 0x25, 0x27, 0x2B, 0x24, 0x25, 0x2A, 0x2E, 0x25, 0x25, 0x28, 0x2F, 0x2A, 0x2A, 0x28, 0x2D, 0x27, 0x29, 0x25, 0x2A, 0x28, 0x2A, 0x2A, 0x2E, 0x26, 0x27, 0x24, 0x27, 0x25, 0x28, 0x28, 0x2D, 0x2A, 0x2D, 0x28, 0x2C, 0x2E, 0x34, 0x2E, 0x32, 0x2A, 0x2E, 0x2A, 0x2F, 0x2A, 0x2D, 0x2B, 0x32, 0x29, 0x2D, 0x2B, 0x2F, 0x26, 0x26, 0x25, 0x29
    },

    {
        0x7D, 0x3C, 0x7E, 0x3C, 0x7E, 0x3D, 0x7F, 0x3E, 0x80, 0x3E, 0x82, 0x3F, 0x82, 0x3F, 0x82, 0x40, 0x84, 0x3F, 0x83, 0x3F, 0x84, 0x40, 0x82, 0x40, 0x83, 0x3F, 0x83, 0x3F, 0x82, 0x40, 0x84, 0x40, 0x85, 0x3F, 0x7A, 0x39, 0x5C, 0x2C, 0x3C, 0x20, 0x2E, 0x1B, 0x28, 0x17, 0x23, 0x16, 0x1F, 0x14, 0x1D, 0x12, 0x1A, 0x12, 0x1A, 0x12, 0x1B, 0x14, 0x25, 0x1D, 0x3A, 0x2D, 0x48, 0x33, 0x3B, 0x27, 0x2D, 0x1E, 0x27, 0x1A, 0x23, 0x18, 0x20, 0x16, 0x1E, 0x15, 0x1B, 0x13, 0x1A, 0x12, 0x19, 0x12, 0x1D, 0x16, 0x2F, 0x27, 0x59, 0x49, 0x8B, 0x67, 0xA1, 0x73, 0xA7, 0x78, 0xAC, 0x7A, 0xAF, 0x7C, 0xB2, 0x7E, 0xB7, 0x81, 0xB9, 0x83, 0xB6, 0x80, 0xB3, 0x7F, 0xB2, 0x7E, 0xB2, 0x7F, 0xB3, 0x7E, 0xB3, 0x7E, 0xB4, 0x80, 0xB6, 0x82, 0xB7, 0x80, 0xB5, 0x80, 0xB5, 0x81, 0xB5, 0x81, 0xB5, 0x80, 0xB3, 0x7F, 0xB5, 0x80, 0xB6, 0x80, 0xB5, 0x7E, 0xA3, 0x6E, 0x7A, 0x4D, 0x48, 0x2E, 0x2D, 0x1E, 0x24, 0x18, 0x1E, 0x15, 0x1B, 0x13, 0x19, 0x11, 0x18, 0x11, 0x18, 0x11, 0x19, 0x13, 0x1B, 0x14, 0x1A, 0x12, 0x19, 0x12, 0x1B, 0x15, 0x2A, 0x26, 0x64, 0x50, 0x99, 0x6E, 0xA4, 0x75, 0xAD, 0x7C, 0xB3, 0x80, 0xB5, 0x80, 0xB6, 0x82, 0xBA, 0x84, 0xBB, 0x85, 0xBC, 0x86, 0xBD, 0x86, 0xBB, 0x87, 0xBE, 0x88, 0xC0, 0x8A, 0xC1, 0x8A, 0xC1, 0x89, 0xC0, 0x89, 0xBF, 0x88, 0xBB, 0x86, 0xBB, 0x86, 0xBC, 0x86, 0xBA, 0x85, 0xBB, 0x86, 0xBC, 0x86, 0xBC, 0x85, 0xBB, 0x85, 0xBC, 0x86, 0xBB, 0x83, 0xB5, 0x7E, 0x8B, 0x55, 0x41, 0x2A, 0x27, 0x1A, 0x1E, 0x16, 0x20, 0x17, 0x2A, 0x1A, 0x2C, 0x1B, 0x2C, 0x1C, 0x2E, 0x1D, 0x2F, 0x1D, 0x2E, 0x1C, 0x2D, 0x1C, 0x2D, 0x1C, 0x2A, 0x1A, 0x21, 0x16, 0x21, 0x1A, 0x2D, 0x21, 0x31, 0x24, 0x32, 0x25, 0x32, 0x25, 0x33, 0x25, 0x33, 0x26, 0x34, 0x27, 0x34, 0x26, 0x32, 0x24, 0x32, 0x25, 0x31, 0x24, 0x33, 0x26, 0x33, 0x26, 0x31, 0x25, 0x32, 0x25, 0x31, 0x24, 0x32, 0x24, 0x31, 0x24, 0x31, 0x24, 0x31, 0x25, 0x32, 0x26, 0x34, 0x26, 0x33, 0x25, 0x32, 0x24, 0x31, 0x24, 0x2B, 0x1D, 0x1D, 0x14, 0x1A, 0x11, 0x18, 0x10, 0x17, 0x10, 0x17, 0x0F, 0x18, 0x0F, 0x17, 0x10, 0x1E, 0x13, 0x3B, 0x1A, 0x5B, 0x21, 0x5E, 0x21, 0x52, 0x1E, 0x31, 0x18, 0x39, 0x1B, 0x57, 0x21, 0x5C, 0x22, 0x61, 0x23, 0x64, 0x24, 0x64, 0x23, 0x65, 0x25, 0x66, 0x25, 0x65, 0x25, 0x63, 0x25, 0x65, 0x24, 0x62, 0x23, 0x5D, 0x21, 0x5F, 0x22, 0x60, 0x22, 0x60, 0x22, 0x60, 0x22, 0x61, 0x23, 0x62, 0x24, 0x61, 0x23, 0x61, 0x23, 0x62, 0x23, 0x63, 0x22, 0x62, 0x21, 0x5E, 0x21, 0x60, 0x22, 0x60, 0x22, 0x5F, 0x22, 0x61, 0x22, 0x61, 0x22, 0x63, 0x23, 0x60, 0x22, 0x5F, 0x22, 0x61, 0x23, 0x63, 0x23, 0x62, 0x23, 0x5F, 0x22, 0x61, 0x23, 0x5E, 0x22, 0x5D, 0x21, 0x5D, 0x21, 0x5E, 0x22, 0x5D, 0x22, 0x5B, 0x21, 0x5C, 0x21, 0x5E, 0x22, 0x5B, 0x22, 0x5E, 0x23, 0x5C, 0x22, 0x5C, 0x21, 0x5A, 0x21, 0x5C, 0x21, 0x5E, 0x21, 0x5C, 0x20, 0x59, 0x20, 0x59, 0x20, 0x58, 0x1F, 0x59, 0x20, 0x5A, 0x20, 0x57, 0x1F, 0x56, 0x1F, 0x55, 0x1F, 0x53, 0x1F, 0x55, 0x1F, 0x58, 0x1F, 0x57, 0x1F, 0x55, 0x1F, 0x57, 0x1F, 0x5A, 0x1F, 0x59, 0x21, 0x5B, 0x20, 0x5C, 0x21, 0x5C, 0x21, 0x5B, 0x22, 0x5C, 0x22, 0x5A, 0x22, 0x5B, 0x21, 0x55, 0x1F, 0x57, 0x1F, 0x56, 0x1F, 0x57, 0x20, 0x55, 0x1F, 0x59, 0x21, 0x59, 0x20, 0x59, 0x20, 0x57, 0x20, 0x59, 0x20, 0x56, 0x20, 0x55, 0x1F, 0x53, 0x1E, 0x56, 0x1F, 0x57, 0x20, 0x58, 0x20, 0x57, 0x20, 0x5A, 0x21, 0x5B, 0x21, 0x58, 0x20, 0x59, 0x20, 0x5A, 0x20, 0x58, 0x20, 0x58, 0x20, 0x56, 0x20, 0x58, 0x20, 0x57, 0x1F, 0x58, 0x20, 0x56, 0x20, 0x4E, 0x1E, 0x35, 0x1A, 0x2A, 0x19, 0x39, 0x1E, 0x31, 0x1B, 0x32, 0x1A, 0x2D, 0x19, 0x30, 0x1B, 0x35, 0x1C, 0x28, 0x17, 0x2C, 0x19, 0x29, 0x18, 0x35, 0x1B, 0x26, 0x16, 0x28, 0x18, 0x2C, 0x1A, 0x2B, 0x1A, 0x2C, 0x19, 0x29, 0x19, 0x30, 0x1A, 0x2D, 0x19, 0x2C, 0x19, 0x2D, 0x19, 0x2E, 0x19, 0x2D, 0x19, 0x2D, 0x19, 0x2F, 0x1A, 0x32, 0x1C, 0x32, 0x1B, 0x2D, 0x18, 0x30, 0x1B, 0x32, 0x1B, 0x31, 0x1B, 0x32, 0x1B, 0x2C, 0x18, 0x34, 0x1B, 0x30, 0x1A, 0x2F, 0x19, 0x29, 0x17, 0x31, 0x1B, 0x2C, 0x19, 0x27, 0x17, 0x2C, 0x18, 0x2E, 0x19, 0x2A, 0x19, 0x33, 0x1B
    },

    {
        0x73, 0x7A, 0x73, 0x7C, 0x73, 0x7B, 0x74, 0x7C, 0x74, 0x7E, 0x76, 0x7F, 0x78, 0x7F, 0x78, 0x80, 0x78, 0x80, 0x79, 0x80, 0x7A, 0x80, 0x79, 0x7F, 0x78, 0x7F, 0x78, 0x7F, 0x78, 0x7F, 0x79, 0x7F, 0x79, 0x80, 0x72, 0x74, 0x59, 0x56, 0x38, 0x37, 0x2B, 0x2D, 0x24, 0x26, 0x1F, 0x21, 0x1B, 0x1E, 0x1B, 0x1C, 0x16, 0x1A, 0x15, 0x1A, 0x16, 0x1C, 0x1A, 0x28, 0x22, 0x3E, 0x2A, 0x4A, 0x24, 0x38, 0x1E, 0x2A, 0x1B, 0x25, 0x19, 0x22, 0x17, 0x1F, 0x15, 0x1B, 0x14, 0x1A, 0x13, 0x19, 0x14, 0x19, 0x16, 0x20, 0x1F, 0x39, 0x32, 0x67, 0x47, 0x8E, 0x50, 0x9D, 0x53, 0xA2, 0x55, 0xA5, 0x56, 0xA8, 0x58, 0xAB, 0x5A, 0xAE, 0x5B, 0xB0, 0x59, 0xAF, 0x58, 0xAB, 0x57, 0xAB, 0x57, 0xAB, 0x57, 0xAB, 0x58, 0xAC, 0x58, 0xAC, 0x5A, 0xB0, 0x59, 0xAD, 0x59, 0xAD, 0x59, 0xAD, 0x59, 0xB0, 0x58, 0xAE, 0x58, 0xAD, 0x59, 0xAD, 0x59, 0xAC, 0x57, 0xA9, 0x4F, 0x8F, 0x3C, 0x62, 0x26, 0x38, 0x1D, 0x27, 0x19, 0x20, 0x16, 0x1D, 0x15, 0x19, 0x13, 0x18, 0x13, 0x17, 0x14, 0x17, 0x14, 0x18, 0x16, 0x1A, 0x14, 0x18, 0x14, 0x18, 0x15, 0x1A, 0x19, 0x27, 0x2D, 0x5B, 0x48, 0x90, 0x4F, 0x9C, 0x53, 0xA7, 0x57, 0xAC, 0x58, 0xAE, 0x5A, 0xB0, 0x5B, 0xB2, 0x5C, 0xB4, 0x5D, 0xB6, 0x5D, 0xB5, 0x5C, 0xB4, 0x5D, 0xB7, 0x5D, 0xB9, 0x5E, 0xB8, 0x5E, 0xB8, 0x5E, 0xB8, 0x5E, 0xB6, 0x5C, 0xB5, 0x5C, 0xB3, 0x5C, 0xB4, 0x5C, 0xB4, 0x5B, 0xB5, 0x5B, 0xB3, 0x5B, 0xB3, 0x5C, 0xB3, 0x5C, 0xB4, 0x5B, 0xB2, 0x59, 0xAD, 0x4B, 0x88, 0x2C, 0x43, 0x1D, 0x27, 0x1A, 0x20, 0x20, 0x24, 0x29, 0x2A, 0x2C, 0x2B, 0x2D, 0x2C, 0x2F, 0x2D, 0x2F, 0x2D, 0x2F, 0x2C, 0x2F, 0x2C, 0x2E, 0x2C, 0x2A, 0x2A, 0x1F, 0x21, 0x19, 0x25, 0x1C, 0x2D, 0x1E, 0x30, 0x1E, 0x31, 0x1E, 0x31, 0x1E, 0x30, 0x1D, 0x30, 0x1D, 0x31, 0x1E, 0x33, 0x1D, 0x30, 0x1D, 0x30, 0x1D, 0x30, 0x1D, 0x31, 0x1D, 0x32, 0x1D, 0x30, 0x1C, 0x2F, 0x1C, 0x2F, 0x1D, 0x30, 0x1D, 0x30, 0x1D, 0x30, 0x1D, 0x2F, 0x1D, 0x31, 0x1E, 0x32, 0x1E, 0x31, 0x1D, 0x30, 0x1D, 0x30, 0x1A, 0x24, 0x15, 0x1A, 0x15, 0x19, 0x14, 0x17, 0x13, 0x16, 0x13, 0x16, 0x15, 0x17, 0x17, 0x17, 0x22, 0x24, 0x46, 0x48, 0x62, 0x5B, 0x62, 0x5A, 0x4F, 0x42, 0x34, 0x2C, 0x44, 0x44, 0x5E, 0x59, 0x65, 0x5B, 0x6C, 0x60, 0x6C, 0x61, 0x6E, 0x61, 0x6E, 0x63, 0x6F, 0x63, 0x70, 0x62, 0x6F, 0x64, 0x70, 0x65, 0x6D, 0x60, 0x6A, 0x5D, 0x69, 0x5D, 0x6B, 0x5F, 0x6D, 0x5E, 0x6D, 0x60, 0x6C, 0x5F, 0x6D, 0x62, 0x6D, 0x5F, 0x6C, 0x60, 0x6D, 0x61, 0x6E, 0x5F, 0x6C, 0x5D, 0x6A, 0x5C, 0x6C, 0x5F, 0x6B, 0x5E, 0x6A, 0x5C, 0x6D, 0x5F, 0x6C, 0x5F, 0x6D, 0x60, 0x6C, 0x5E, 0x6B, 0x5F, 0x6C, 0x61, 0x6D, 0x60, 0x6B, 0x5F, 0x6A, 0x5E, 0x6C, 0x5E, 0x69, 0x5B, 0x68, 0x5C, 0x6A, 0x5C, 0x68, 0x5E, 0x67, 0x5B, 0x65, 0x58, 0x67, 0x5A, 0x69, 0x5C, 0x65, 0x5B, 0x68, 0x5D, 0x65, 0x5C, 0x68, 0x5B, 0x62, 0x57, 0x65, 0x59, 0x69, 0x5C, 0x67, 0x5B, 0x64, 0x58, 0x65, 0x58, 0x61, 0x54, 0x61, 0x55, 0x64, 0x57, 0x61, 0x54, 0x61, 0x55, 0x5F, 0x53, 0x5D, 0x54, 0x5F, 0x55, 0x61, 0x55, 0x60, 0x56, 0x61, 0x54, 0x61, 0x55, 0x61, 0x57, 0x62, 0x58, 0x66, 0x5A, 0x66, 0x5B, 0x64, 0x59, 0x65, 0x5A, 0x66, 0x5B, 0x63, 0x58, 0x66, 0x59, 0x60, 0x54, 0x61, 0x54, 0x5F, 0x54, 0x63, 0x57, 0x62, 0x57, 0x65, 0x57, 0x62, 0x57, 0x62, 0x57, 0x62, 0x54, 0x62, 0x56, 0x60, 0x56, 0x60, 0x53, 0x60, 0x53, 0x60, 0x55, 0x60, 0x56, 0x61, 0x55, 0x60, 0x54, 0x65, 0x59, 0x63, 0x58, 0x61, 0x56, 0x63, 0x58, 0x62, 0x56, 0x61, 0x56, 0x63, 0x57, 0x61, 0x56, 0x62, 0x57, 0x61, 0x55, 0x60, 0x54, 0x5D, 0x54, 0x53, 0x48, 0x36, 0x34, 0x2D, 0x2F, 0x34, 0x38, 0x2C, 0x30, 0x28, 0x2A, 0x27, 0x2A, 0x2B, 0x32, 0x2D, 0x2F, 0x24, 0x25, 0x28, 0x2C, 0x25, 0x2B, 0x2D, 0x30, 0x23, 0x24, 0x27, 0x2C, 0x29, 0x2E, 0x29, 0x30, 0x28, 0x2A, 0x2A, 0x2F, 0x2D, 0x32, 0x2B, 0x2E, 0x28, 0x2D, 0x2A, 0x2D, 0x2B, 0x30, 0x2B, 0x30, 0x29, 0x2C, 0x2C, 0x32, 0x30, 0x35, 0x2D, 0x31, 0x29, 0x2B, 0x2D, 0x33, 0x2E, 0x31, 0x2E, 0x31, 0x2C, 0x2D, 0x28, 0x2D, 0x2E, 0x33, 0x2A, 0x2C, 0x29, 0x2C, 0x24, 0x26, 0x2C, 0x2F, 0x26, 0x28, 0x23, 0x25, 0x28, 0x2D, 0x27, 0x2A, 0x26, 0x2B, 0x2B, 0x2E
    },

    {
        0x7F, 0x3D, 0x7E, 0x3C, 0x7F, 0x3D, 0x7F, 0x3C, 0x80, 0x3D, 0x81, 0x3E, 0x82, 0x3E, 0x82, 0x3F, 0x83, 0x3F, 0x82, 0x3F, 0x82, 0x3F, 0x80, 0x3F, 0x82, 0x3F, 0x83, 0x3F, 0x83, 0x3F, 0x82, 0x40, 0x84, 0x3F, 0x80, 0x3D, 0x6D, 0x33, 0x4C, 0x25, 0x32, 0x1C, 0x29, 0x18, 0x23, 0x16, 0x20, 0x14, 0x1D, 0x13, 0x1B, 0x12, 0x1B, 0x13, 0x21, 0x1A, 0x32, 0x29, 0x53, 0x40, 0x69, 0x4A, 0x5C, 0x3C, 0x3B, 0x27, 0x2A, 0x1D, 0x25, 0x1A, 0x21, 0x16, 0x1D, 0x15, 0x1B, 0x14, 0x1B, 0x13, 0x1D, 0x17, 0x2B, 0x24, 0x4E, 0x3F, 0x7F, 0x5E, 0x98, 0x6E, 0xA3, 0x76, 0xA9, 0x78, 0xAC, 0x7B, 0xAE, 0x7C, 0xB3, 0x7F, 0xB3, 0x7E, 0xB2, 0x7E, 0xB5, 0x81, 0xB6, 0x80, 0xB4, 0x80, 0xB2, 0x7E, 0xB3, 0x7E, 0xB4, 0x7F, 0xB5, 0x80, 0xB3, 0x80, 0xB6, 0x82, 0xB9, 0x83, 0xB7, 0x82, 0xB6, 0x80, 0xB3, 0x7F, 0xB4, 0x7E, 0xB2, 0x7E, 0xB1, 0x7C, 0xA5, 0x6D, 0x7C, 0x4D, 0x49, 0x2F, 0x30, 0x20, 0x27, 0x1B, 0x21, 0x17, 0x1D, 0x14, 0x1A, 0x12, 0x19, 0x11, 0x19, 0x12, 0x1A, 0x13, 0x1D, 0x15, 0x1E, 0x15, 0x1B, 0x13, 0x1A, 0x12, 0x19, 0x12, 0x1B, 0x14, 0x27, 0x22, 0x5A, 0x49, 0x93, 0x6B, 0xA6, 0x76, 0xAE, 0x7A, 0xB4, 0x7F, 0xBB, 0x85, 0xBC, 0x83, 0xB9, 0x84, 0xBB, 0x86, 0xBC, 0x86, 0xBE, 0x87, 0xBD, 0x88, 0xBF, 0x89, 0xC0, 0x89, 0xBE, 0x87, 0xBC, 0x85, 0xBB, 0x84, 0xBC, 0x86, 0xBB, 0x85, 0xBB, 0x86, 0xBC, 0x86, 0xBE, 0x86, 0xBB, 0x85, 0xB9, 0x85, 0xB9, 0x83, 0xBA, 0x85, 0xBA, 0x82, 0xB8, 0x82, 0xB5, 0x7C, 0x96, 0x5D, 0x45, 0x2B, 0x2A, 0x1D, 0x2B, 0x1C, 0x2B, 0x1B, 0x2C, 0x1C, 0x2D, 0x1C, 0x2D, 0x1C, 0x2E, 0x1D, 0x2E, 0x1D, 0x2F, 0x1E, 0x2F, 0x1D, 0x2C, 0x1B, 0x26, 0x1A, 0x2C, 0x20, 0x2F, 0x23, 0x31, 0x24, 0x32, 0x24, 0x32, 0x25, 0x32, 0x24, 0x31, 0x24, 0x31, 0x24, 0x31, 0x24, 0x31, 0x24, 0x32, 0x25, 0x32, 0x25, 0x33, 0x25, 0x32, 0x25, 0x32, 0x26, 0x31, 0x24, 0x31, 0x24, 0x31, 0x24, 0x31, 0x24, 0x32, 0x24, 0x31, 0x25, 0x33, 0x25, 0x33, 0x26, 0x34, 0x26, 0x33, 0x25, 0x2B, 0x1E, 0x1E, 0x15, 0x1A, 0x11, 0x18, 0x10, 0x17, 0x0F, 0x16, 0x0F, 0x17, 0x0F, 0x19, 0x11, 0x1D, 0x12, 0x3B, 0x1B, 0x58, 0x20, 0x5C, 0x21, 0x53, 0x1E, 0x30, 0x18, 0x3B, 0x1B, 0x54, 0x21, 0x62, 0x23, 0x62, 0x23, 0x63, 0x23, 0x5F, 0x22, 0x64, 0x24, 0x61, 0x24, 0x66, 0x24, 0x69, 0x26, 0x69, 0x26, 0x65, 0x25, 0x61, 0x23, 0x64, 0x23, 0x61, 0x22, 0x5D, 0x22, 0x62, 0x22, 0x62, 0x23, 0x61, 0x22, 0x65, 0x24, 0x63, 0x24, 0x64, 0x24, 0x63, 0x22, 0x5F, 0x22, 0x5E, 0x21, 0x5E, 0x21, 0x5D, 0x21, 0x62, 0x23, 0x61, 0x22, 0x60, 0x22, 0x60, 0x22, 0x60, 0x21, 0x5C, 0x20, 0x60, 0x22, 0x5E, 0x22, 0x61, 0x22, 0x5D, 0x21, 0x60, 0x22, 0x5F, 0x21, 0x5E, 0x22, 0x5C, 0x21, 0x5E, 0x22, 0x5F, 0x23, 0x5B, 0x21, 0x58, 0x20, 0x59, 0x1F, 0x5B, 0x21, 0x5E, 0x21, 0x5F, 0x23, 0x5F, 0x22, 0x5D, 0x21, 0x59, 0x20, 0x58, 0x20, 0x5B, 0x20, 0x5D, 0x21, 0x5D, 0x21, 0x59, 0x21, 0x5A, 0x20, 0x5A, 0x20, 0x5A, 0x20, 0x5A, 0x20, 0x59, 0x20, 0x59, 0x20, 0x58, 0x20, 0x56, 0x1F, 0x57, 0x1F, 0x57, 0x1E, 0x57, 0x20, 0x57, 0x1F, 0x57, 0x20, 0x58, 0x20, 0x59, 0x20, 0x59, 0x1F, 0x59, 0x20, 0x5C, 0x21, 0x5C, 0x21, 0x5A, 0x21, 0x57, 0x1F, 0x59, 0x20, 0x5A, 0x21, 0x5B, 0x21, 0x5A, 0x20, 0x58, 0x20, 0x59, 0x20, 0x55, 0x1F, 0x58, 0x1F, 0x58, 0x20, 0x58, 0x1F, 0x58, 0x20, 0x54, 0x1F, 0x54, 0x1F, 0x55, 0x1F, 0x53, 0x1E, 0x55, 0x1E, 0x56, 0x1F, 0x58, 0x20, 0x56, 0x1F, 0x57, 0x1F, 0x57, 0x20, 0x55, 0x1F, 0x58, 0x1F, 0x5B, 0x21, 0x57, 0x20, 0x55, 0x1F, 0x54, 0x1F, 0x53, 0x1E, 0x55, 0x20, 0x50, 0x20, 0x3C, 0x1D, 0x2E, 0x1A, 0x31, 0x19, 0x28, 0x16, 0x2A, 0x19, 0x2F, 0x18, 0x2D, 0x19, 0x29, 0x18, 0x2D, 0x19, 0x34, 0x1C, 0x33, 0x1C, 0x2D, 0x19, 0x36, 0x1D, 0x39, 0x1E, 0x35, 0x1E, 0x36, 0x1D, 0x30, 0x1B, 0x3C, 0x1E, 0x36, 0x1C, 0x31, 0x1B, 0x2B, 0x18, 0x32, 0x1B, 0x32, 0x1B, 0x35, 0x1D, 0x2A, 0x18, 0x38, 0x1E, 0x2E, 0x19, 0x2C, 0x19, 0x31, 0x1B, 0x31, 0x1B, 0x29, 0x17, 0x2C, 0x19, 0x2C, 0x18, 0x2F, 0x1A, 0x2A, 0x18, 0x22, 0x15, 0x29, 0x17, 0x26, 0x17, 0x2D, 0x18, 0x28, 0x18, 0x2A, 0x17, 0x2F, 0x1A, 0x29, 0x17, 0x28, 0x18, 0x2E, 0x19
    },

    {
        0x73, 0x7C, 0x73, 0x7B, 0x74, 0x7C, 0x74, 0x7C, 0x75, 0x7D, 0x76, 0x7D, 0x77, 0x7E, 0x78, 0x7F, 0x78, 0x80, 0x77, 0x7E, 0x76, 0x7F, 0x77, 0x7E, 0x78, 0x7E, 0x78, 0x7F, 0x79, 0x7F, 0x79, 0x7F, 0x7A, 0x80, 0x77, 0x7C, 0x6A, 0x6C, 0x4E, 0x4B, 0x33, 0x32, 0x27, 0x28, 0x20, 0x23, 0x1D, 0x1F, 0x19, 0x1C, 0x18, 0x1C, 0x17, 0x1C, 0x18, 0x25, 0x1E, 0x3C, 0x2A, 0x5C, 0x30, 0x6A, 0x2D, 0x5A, 0x22, 0x3B, 0x1B, 0x2A, 0x19, 0x23, 0x17, 0x20, 0x15, 0x1D, 0x14, 0x1B, 0x14, 0x1B, 0x16, 0x20, 0x1D, 0x33, 0x2D, 0x5B, 0x42, 0x86, 0x4C, 0x96, 0x50, 0x9F, 0x53, 0xA3, 0x55, 0xA5, 0x56, 0xA8, 0x58, 0xAA, 0x58, 0xAD, 0x57, 0xAA, 0x57, 0xAC, 0x5A, 0xB0, 0x59, 0xAD, 0x58, 0xAB, 0x56, 0xAB, 0x58, 0xAD, 0x59, 0xAD, 0x59, 0xAD, 0x58, 0xB0, 0x59, 0xB1, 0x59, 0xB0, 0x59, 0xAD, 0x57, 0xAB, 0x58, 0xAB, 0x57, 0xAC, 0x56, 0xA5, 0x4E, 0x91, 0x3C, 0x63, 0x28, 0x39, 0x1E, 0x2A, 0x1A, 0x23, 0x16, 0x1E, 0x15, 0x1B, 0x14, 0x19, 0x14, 0x17, 0x16, 0x19, 0x17, 0x1B, 0x19, 0x1E, 0x19, 0x1E, 0x16, 0x1A, 0x15, 0x18, 0x14, 0x18, 0x15, 0x1A, 0x19, 0x24, 0x2A, 0x51, 0x43, 0x8C, 0x4F, 0x9E, 0x54, 0xA7, 0x58, 0xAC, 0x5B, 0xB2, 0x5B, 0xB2, 0x5B, 0xB2, 0x5B, 0xB2, 0x5B, 0xB4, 0x5D, 0xB6, 0x5D, 0xB8, 0x5E, 0xB8, 0x5E, 0xB8, 0x5E, 0xB7, 0x5C, 0xB4, 0x5B, 0xB1, 0x5B, 0xB2, 0x5C, 0xB4, 0x5C, 0xB6, 0x5D, 0xB7, 0x5C, 0xB5, 0x5B, 0xB2, 0x5B, 0xB2, 0x5B, 0xAF, 0x5C, 0xB4, 0x5B, 0xB0, 0x5B, 0xB1, 0x5A, 0xAF, 0x50, 0x92, 0x2E, 0x41, 0x23, 0x2C, 0x29, 0x2C, 0x2B, 0x29, 0x2C, 0x2B, 0x2D, 0x2C, 0x2E, 0x2B, 0x2F, 0x2D, 0x2F, 0x2D, 0x30, 0x2F, 0x2F, 0x2E, 0x29, 0x29, 0x20, 0x24, 0x1D, 0x2C, 0x1C, 0x2F, 0x1E, 0x30, 0x1D, 0x30, 0x1D, 0x30, 0x1D, 0x30, 0x1D, 0x2E, 0x1C, 0x30, 0x1C, 0x2F, 0x1C, 0x2F, 0x1D, 0x31, 0x1D, 0x31, 0x1D, 0x30, 0x1D, 0x30, 0x1C, 0x2F, 0x1C, 0x2F, 0x1C, 0x2F, 0x1C, 0x30, 0x1D, 0x30, 0x1C, 0x2F, 0x1D, 0x31, 0x1E, 0x31, 0x1E, 0x32, 0x1F, 0x33, 0x1E, 0x30, 0x1A, 0x25, 0x16, 0x1B, 0x14, 0x18, 0x14, 0x17, 0x14, 0x16, 0x13, 0x16, 0x14, 0x16, 0x17, 0x19, 0x20, 0x22, 0x43, 0x46, 0x5E, 0x58, 0x61, 0x58, 0x50, 0x45, 0x33, 0x2D, 0x45, 0x45, 0x5F, 0x58, 0x6A, 0x5F, 0x6D, 0x61, 0x6C, 0x61, 0x6A, 0x5E, 0x6D, 0x62, 0x6C, 0x60, 0x70, 0x63, 0x74, 0x67, 0x73, 0x67, 0x70, 0x63, 0x6E, 0x5F, 0x6F, 0x61, 0x6D, 0x5F, 0x69, 0x5C, 0x6E, 0x5F, 0x6F, 0x61, 0x6B, 0x5F, 0x6F, 0x64, 0x6F, 0x61, 0x6E, 0x61, 0x6D, 0x61, 0x6C, 0x5E, 0x6B, 0x5D, 0x68, 0x5B, 0x68, 0x5B, 0x6D, 0x61, 0x6D, 0x5E, 0x6B, 0x5F, 0x6C, 0x5F, 0x6A, 0x5D, 0x67, 0x5A, 0x6C, 0x60, 0x6A, 0x5E, 0x6C, 0x5E, 0x68, 0x5C, 0x6A, 0x5D, 0x69, 0x5C, 0x6B, 0x5C, 0x67, 0x5A, 0x6A, 0x5E, 0x68, 0x5D, 0x65, 0x58, 0x63, 0x57, 0x63, 0x56, 0x65, 0x5A, 0x68, 0x5D, 0x68, 0x5D, 0x69, 0x5C, 0x66, 0x5A, 0x65, 0x57, 0x63, 0x56, 0x65, 0x59, 0x67, 0x5B, 0x67, 0x5B, 0x64, 0x5A, 0x64, 0x58, 0x63, 0x5A, 0x64, 0x59, 0x63, 0x57, 0x62, 0x58, 0x64, 0x59, 0x62, 0x58, 0x60, 0x54, 0x60, 0x55, 0x60, 0x56, 0x62, 0x56, 0x60, 0x55, 0x60, 0x56, 0x61, 0x56, 0x61, 0x55, 0x63, 0x56, 0x61, 0x55, 0x64, 0x5A, 0x66, 0x5A, 0x65, 0x59, 0x61, 0x54, 0x64, 0x58, 0x63, 0x5A, 0x62, 0x58, 0x63, 0x57, 0x63, 0x57, 0x64, 0x57, 0x61, 0x56, 0x62, 0x56, 0x64, 0x58, 0x63, 0x56, 0x61, 0x57, 0x5C, 0x4F, 0x5F, 0x53, 0x60, 0x54, 0x5E, 0x52, 0x60, 0x53, 0x5F, 0x55, 0x62, 0x56, 0x60, 0x54, 0x61, 0x55, 0x62, 0x56, 0x5D, 0x53, 0x60, 0x54, 0x65, 0x5A, 0x62, 0x55, 0x5F, 0x53, 0x5E, 0x53, 0x5D, 0x52, 0x5E, 0x53, 0x54, 0x4C, 0x36, 0x34, 0x2B, 0x2F, 0x28, 0x2A, 0x24, 0x25, 0x2A, 0x31, 0x2C, 0x30, 0x28, 0x2B, 0x26, 0x2A, 0x2B, 0x30, 0x2E, 0x34, 0x2C, 0x2F, 0x29, 0x2E, 0x30, 0x35, 0x30, 0x36, 0x2D, 0x32, 0x2F, 0x31, 0x2C, 0x32, 0x33, 0x37, 0x2C, 0x2F, 0x2A, 0x2E, 0x27, 0x2B, 0x2E, 0x33, 0x2A, 0x2D, 0x2D, 0x31, 0x26, 0x28, 0x31, 0x37, 0x26, 0x28, 0x27, 0x2D, 0x2B, 0x2E, 0x2A, 0x2E, 0x24, 0x24, 0x29, 0x2E, 0x27, 0x29, 0x2A, 0x2F, 0x24, 0x26, 0x20, 0x22, 0x25, 0x28, 0x26, 0x2B, 0x29, 0x2C, 0x27, 0x2D, 0x27, 0x2A, 0x29, 0x2E, 0x28, 0x2A, 0x27, 0x2C, 0x2B, 0x30
    },

    {
        0x7F, 0x3D, 0x7F, 0x3D, 0x7F, 0x3E, 0x7F, 0x3D, 0x80, 0x3E, 0x81, 0x3E, 0x80, 0x3F, 0x81, 0x3F, 0x82, 0x3E, 0x81, 0x3E, 0x84, 0x3F, 0x81, 0x3F, 0x82, 0x3F, 0x82, 0x3F, 0x82, 0x40, 0x83, 0x40, 0x84, 0x40, 0x83, 0x3F, 0x7D, 0x3E, 0x6F, 0x36, 0x4F, 0x27, 0x33, 0x1C, 0x28, 0x17, 0x21, 0x15, 0x1F, 0x14, 0x1E, 0x14, 0x22, 0x19, 0x30, 0x27, 0x4D, 0x3D, 0x6C, 0x4F, 0x75, 0x55, 0x73, 0x52, 0x62, 0x41, 0x41, 0x2A, 0x2C, 0x1E, 0x24, 0x1A, 0x1F, 0x17, 0x1D, 0x15, 0x1F, 0x18, 0x2A, 0x24, 0x49, 0x3D, 0x7A, 0x5C, 0x95, 0x6C, 0x9F, 0x72, 0xA6, 0x76, 0xAA, 0x79, 0xAC, 0x7A, 0xAD, 0x7C, 0xB1, 0x7D, 0xB2, 0x7F, 0xB2, 0x7F, 0xB2, 0x7E, 0xB4, 0x80, 0xB7, 0x80, 0xB3, 0x81, 0xB4, 0x7F, 0xB3, 0x7E, 0xB4, 0x80, 0xB4, 0x81, 0xB4, 0x80, 0xB5, 0x80, 0xB4, 0x81, 0xB2, 0x7F, 0xB3, 0x7F, 0xB4, 0x7E, 0xB1, 0x7C, 0xA4, 0x6F, 0x7F, 0x50, 0x4B, 0x30, 0x32, 0x21, 0x28, 0x1B, 0x22, 0x18, 0x1E, 0x15, 0x1B, 0x13, 0x19, 0x12, 0x1B, 0x15, 0x26, 0x1E, 0x2B, 0x1F, 0x25, 0x1A, 0x24, 0x19, 0x1F, 0x15, 0x1B, 0x13, 0x19, 0x12, 0x19, 0x12, 0x1B, 0x13, 0x23, 0x1E, 0x50, 0x44, 0x8F, 0x69, 0xA7, 0x76, 0xAE, 0x7C, 0xB3, 0x80, 0xB9, 0x84, 0xBA, 0x84, 0xBA, 0x86, 0xBC, 0x85, 0xBD, 0x86, 0xBF, 0x88, 0xBC, 0x86, 0xBE, 0x87, 0xBE, 0x88, 0xBE, 0x87, 0xBC, 0x86, 0xBA, 0x85, 0xBB, 0x86, 0xBC, 0x86, 0xBD, 0x87, 0xBC, 0x86, 0xBB, 0x86, 0xB9, 0x86, 0xBA, 0x83, 0xB9, 0x85, 0xBA, 0x85, 0xBA, 0x83, 0xB9, 0x82, 0xA4, 0x6A, 0x59, 0x35, 0x2F, 0x20, 0x2F, 0x1E, 0x2C, 0x1C, 0x2C, 0x1C, 0x2C, 0x1C, 0x2E, 0x1C, 0x2F, 0x1D, 0x2F, 0x1D, 0x32, 0x1F, 0x30, 0x1D, 0x26, 0x18, 0x1E, 0x15, 0x23, 0x1B, 0x2D, 0x20, 0x30, 0x23, 0x31, 0x25, 0x32, 0x25, 0x33, 0x25, 0x32, 0x25, 0x31, 0x24, 0x31, 0x24, 0x31, 0x25, 0x32, 0x25, 0x33, 0x24, 0x32, 0x25, 0x31, 0x24, 0x31, 0x24, 0x31, 0x24, 0x33, 0x25, 0x32, 0x24, 0x30, 0x24, 0x31, 0x24, 0x34, 0x27, 0x36, 0x26, 0x32, 0x25, 0x33, 0x25, 0x2E, 0x1F, 0x20, 0x16, 0x19, 0x11, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x0F, 0x17, 0x10, 0x1B, 0x12, 0x3A, 0x1A, 0x56, 0x21, 0x5E, 0x22, 0x51, 0x1F, 0x32, 0x18, 0x3A, 0x1B, 0x54, 0x20, 0x60, 0x22, 0x60, 0x23, 0x61, 0x23, 0x63, 0x24, 0x63, 0x24, 0x65, 0x25, 0x66, 0x25, 0x67, 0x25, 0x66, 0x24, 0x68, 0x25, 0x63, 0x24, 0x66, 0x24, 0x61, 0x22, 0x60, 0x22, 0x5F, 0x22, 0x60, 0x22, 0x61, 0x22, 0x62, 0x22, 0x64, 0x24, 0x64, 0x23, 0x65, 0x23, 0x63, 0x23, 0x60, 0x22, 0x61, 0x22, 0x5F, 0x22, 0x61, 0x22, 0x61, 0x24, 0x62, 0x23, 0x60, 0x23, 0x62, 0x22, 0x60, 0x22, 0x5D, 0x21, 0x63, 0x24, 0x60, 0x22, 0x62, 0x23, 0x61, 0x22, 0x5E, 0x21, 0x5D, 0x21, 0x5F, 0x22, 0x60, 0x23, 0x61, 0x23, 0x5D, 0x21, 0x5A, 0x20, 0x59, 0x21, 0x56, 0x20, 0x5B, 0x21, 0x5E, 0x21, 0x5A, 0x21, 0x5D, 0x22, 0x5E, 0x22, 0x5C, 0x21, 0x5B, 0x20, 0x59, 0x20, 0x5F, 0x22, 0x5E, 0x21, 0x5E, 0x21, 0x5C, 0x21, 0x5E, 0x21, 0x5B, 0x20, 0x59, 0x20, 0x5B, 0x21, 0x5C, 0x21, 0x5A, 0x21, 0x57, 0x20, 0x56, 0x1F, 0x59, 0x21, 0x5A, 0x20, 0x57, 0x20, 0x58, 0x1F, 0x56, 0x1F, 0x54, 0x1E, 0x58, 0x20, 0x59, 0x20, 0x58, 0x20, 0x5A, 0x21, 0x5E, 0x21, 0x58, 0x1F, 0x56, 0x20, 0x5C, 0x21, 0x59, 0x20, 0x58, 0x22, 0x5B, 0x22, 0x5A, 0x22, 0x58, 0x20, 0x57, 0x20, 0x5B, 0x21, 0x59, 0x20, 0x56, 0x1F, 0x54, 0x1F, 0x54, 0x1F, 0x56, 0x20, 0x56, 0x1F, 0x56, 0x1F, 0x54, 0x1F, 0x57, 0x20, 0x57, 0x20, 0x59, 0x20, 0x58, 0x20, 0x55, 0x20, 0x56, 0x1F, 0x58, 0x20, 0x56, 0x1F, 0x56, 0x20, 0x54, 0x1E, 0x54, 0x1E, 0x55, 0x1F, 0x4E, 0x1E, 0x37, 0x1B, 0x33, 0x1A, 0x2C, 0x1A, 0x35, 0x1C, 0x35, 0x1D, 0x33, 0x1B, 0x30, 0x1A, 0x32, 0x1C, 0x33, 0x1B, 0x2B, 0x1A, 0x2E, 0x19, 0x2F, 0x1B, 0x32, 0x1B, 0x2C, 0x19, 0x29, 0x19, 0x31, 0x1A, 0x2B, 0x18, 0x2B, 0x18, 0x24, 0x16, 0x29, 0x17, 0x29, 0x18, 0x2F, 0x19, 0x24, 0x16, 0x2A, 0x18, 0x24, 0x16, 0x32, 0x1A, 0x28, 0x17, 0x2F, 0x1A, 0x2A, 0x18, 0x2F, 0x1A, 0x2B, 0x18, 0x30, 0x1B, 0x2D, 0x1A, 0x2C, 0x18, 0x29, 0x18, 0x2B, 0x18, 0x33, 0x1B, 0x32, 0x1B, 0x30, 0x1A, 0x34, 0x1D, 0x2A, 0x17, 0x30, 0x1B, 0x35, 0x1C, 0x2E, 0x19, 0x32, 0x1A
    },

    {
        0x73, 0x7A, 0x72, 0x7C, 0x73, 0x7D, 0x75, 0x7D, 0x75, 0x7E, 0x76, 0x7E, 0x77, 0x7E, 0x76, 0x7D, 0x76, 0x7E, 0x77, 0x7D, 0x77, 0x7F, 0x78, 0x7F, 0x77, 0x7F, 0x78, 0x7F, 0x78, 0x80, 0x79, 0x80, 0x79, 0x80, 0x79, 0x7F, 0x74, 0x7C, 0x69, 0x6F, 0x52, 0x51, 0x34, 0x33, 0x25, 0x27, 0x1F, 0x21, 0x1C, 0x1F, 0x19, 0x1E, 0x1A, 0x26, 0x1E, 0x38, 0x27, 0x57, 0x30, 0x6D, 0x33, 0x72, 0x32, 0x71, 0x2E, 0x62, 0x24, 0x41, 0x1C, 0x2B, 0x17, 0x23, 0x15, 0x1F, 0x15, 0x1D, 0x17, 0x22, 0x1D, 0x33, 0x2B, 0x59, 0x40, 0x82, 0x4A, 0x94, 0x4F, 0x9D, 0x52, 0xA1, 0x53, 0xA4, 0x55, 0xA6, 0x55, 0xA7, 0x56, 0xA9, 0x57, 0xAB, 0x58, 0xAB, 0x58, 0xAA, 0x58, 0xAD, 0x5A, 0xAE, 0x59, 0xAE, 0x59, 0xAD, 0x58, 0xAC, 0x59, 0xAE, 0x58, 0xAC, 0x58, 0xAD, 0x59, 0xAD, 0x5A, 0xB0, 0x58, 0xAC, 0x58, 0xAC, 0x59, 0xAC, 0x56, 0xA7, 0x4E, 0x92, 0x3D, 0x68, 0x28, 0x3A, 0x1F, 0x2B, 0x1A, 0x23, 0x17, 0x1E, 0x15, 0x1B, 0x14, 0x19, 0x15, 0x18, 0x18, 0x1D, 0x22, 0x2F, 0x2B, 0x33, 0x22, 0x27, 0x1E, 0x23, 0x1A, 0x1D, 0x17, 0x1B, 0x16, 0x19, 0x14, 0x18, 0x14, 0x1A, 0x17, 0x20, 0x25, 0x49, 0x41, 0x87, 0x50, 0x9F, 0x55, 0xA5, 0x59, 0xAD, 0x5A, 0xB2, 0x5B, 0xB4, 0x5C, 0xB4, 0x5C, 0xB6, 0x5C, 0xB5, 0x5D, 0xB6, 0x5C, 0xB5, 0x5D, 0xB5, 0x5C, 0xB8, 0x5C, 0xB5, 0x5C, 0xB4, 0x5C, 0xB3, 0x5C, 0xB4, 0x5D, 0xB5, 0x5C, 0xB5, 0x5B, 0xB6, 0x5B, 0xB4, 0x5B, 0xB3, 0x5B, 0xB1, 0x5B, 0xB2, 0x5B, 0xB2, 0x5A, 0xB0, 0x59, 0xAC, 0x4E, 0x8B, 0x2F, 0x43, 0x22, 0x2B, 0x28, 0x2C, 0x2A, 0x2A, 0x2C, 0x2B, 0x2D, 0x2C, 0x2E, 0x2C, 0x2F, 0x2E, 0x2F, 0x2D, 0x2F, 0x30, 0x2B, 0x2C, 0x22, 0x21, 0x19, 0x1B, 0x18, 0x20, 0x1B, 0x2A, 0x1D, 0x2F, 0x1C, 0x2F, 0x1D, 0x31, 0x1D, 0x31, 0x1D, 0x30, 0x1C, 0x2F, 0x1C, 0x2F, 0x1C, 0x30, 0x1D, 0x31, 0x1D, 0x31, 0x1D, 0x30, 0x1D, 0x30, 0x1D, 0x2F, 0x1D, 0x31, 0x1D, 0x30, 0x1C, 0x2F, 0x1C, 0x2F, 0x1C, 0x30, 0x1D, 0x32, 0x1F, 0x33, 0x1D, 0x31, 0x1E, 0x31, 0x1C, 0x29, 0x16, 0x1B, 0x14, 0x18, 0x13, 0x16, 0x13, 0x16, 0x14, 0x16, 0x14, 0x16, 0x16, 0x17, 0x1F, 0x21, 0x43, 0x47, 0x5D, 0x58, 0x63, 0x5A, 0x50, 0x44, 0x33, 0x2D, 0x43, 0x45, 0x5F, 0x58, 0x6B, 0x60, 0x6C, 0x5F, 0x6D, 0x60, 0x6F, 0x62, 0x6F, 0x62, 0x70, 0x64, 0x71, 0x64, 0x73, 0x65, 0x71, 0x63, 0x72, 0x64, 0x6C, 0x61, 0x70, 0x63, 0x6D, 0x5E, 0x6B, 0x5E, 0x6C, 0x5E, 0x6C, 0x5F, 0x6D, 0x60, 0x6E, 0x61, 0x6E, 0x63, 0x6F, 0x62, 0x6F, 0x61, 0x6E, 0x61, 0x6E, 0x60, 0x6C, 0x5E, 0x6B, 0x60, 0x6C, 0x60, 0x6D, 0x62, 0x6F, 0x62, 0x6A, 0x60, 0x6C, 0x5F, 0x6B, 0x5E, 0x68, 0x5C, 0x6F, 0x61, 0x6C, 0x5E, 0x6E, 0x60, 0x6C, 0x5F, 0x6C, 0x5E, 0x69, 0x5C, 0x6C, 0x5D, 0x6C, 0x5E, 0x6B, 0x5E, 0x66, 0x59, 0x63, 0x58, 0x63, 0x57, 0x60, 0x55, 0x64, 0x5A, 0x69, 0x5D, 0x64, 0x58, 0x69, 0x5C, 0x69, 0x5D, 0x67, 0x5B, 0x66, 0x59, 0x62, 0x59, 0x69, 0x5F, 0x66, 0x5A, 0x69, 0x5D, 0x65, 0x5A, 0x68, 0x5B, 0x66, 0x5A, 0x66, 0x59, 0x68, 0x5B, 0x67, 0x5A, 0x63, 0x57, 0x61, 0x55, 0x62, 0x55, 0x64, 0x59, 0x66, 0x59, 0x61, 0x56, 0x60, 0x55, 0x5F, 0x53, 0x5C, 0x53, 0x65, 0x57, 0x64, 0x58, 0x60, 0x57, 0x64, 0x59, 0x66, 0x5B, 0x63, 0x55, 0x60, 0x56, 0x63, 0x58, 0x60, 0x55, 0x60, 0x57, 0x62, 0x59, 0x63, 0x56, 0x63, 0x57, 0x62, 0x57, 0x67, 0x5C, 0x65, 0x5A, 0x63, 0x55, 0x60, 0x55, 0x5F, 0x54, 0x60, 0x55, 0x5F, 0x54, 0x5F, 0x54, 0x5D, 0x53, 0x63, 0x58, 0x61, 0x56, 0x61, 0x56, 0x61, 0x56, 0x60, 0x54, 0x61, 0x54, 0x61, 0x57, 0x5F, 0x54, 0x5E, 0x53, 0x5E, 0x53, 0x5F, 0x54, 0x5F, 0x55, 0x53, 0x48, 0x35, 0x36, 0x2E, 0x2F, 0x2A, 0x30, 0x30, 0x35, 0x2C, 0x30, 0x2C, 0x30, 0x29, 0x2D, 0x2C, 0x32, 0x2C, 0x2D, 0x26, 0x2D, 0x26, 0x28, 0x2A, 0x31, 0x2C, 0x2E, 0x26, 0x29, 0x25, 0x2B, 0x2C, 0x2D, 0x27, 0x29, 0x26, 0x27, 0x21, 0x24, 0x25, 0x27, 0x26, 0x2B, 0x2A, 0x2A, 0x22, 0x26, 0x27, 0x29, 0x23, 0x27, 0x2C, 0x31, 0x26, 0x29, 0x2A, 0x2F, 0x26, 0x2A, 0x2C, 0x32, 0x29, 0x2C, 0x2E, 0x33, 0x2A, 0x2C, 0x26, 0x28, 0x28, 0x2E, 0x28, 0x2C, 0x2E, 0x34, 0x2A, 0x2E, 0x29, 0x2E, 0x2B, 0x30, 0x23, 0x27, 0x2A, 0x32, 0x2B, 0x30, 0x26, 0x2C, 0x2B, 0x2F
    },

    {
        0x7F, 0x3C, 0x7E, 0x3C, 0x7E, 0x3E, 0x80, 0x3D, 0x81, 0x3D, 0x82, 0x3E, 0x82, 0x3E, 0x82, 0x3F, 0x81, 0x3E, 0x80, 0x3E, 0x81, 0x3F, 0x82, 0x3F, 0x83, 0x3F, 0x83, 0x40, 0x84, 0x41, 0x86, 0x40, 0x85, 0x41, 0x84, 0x40, 0x83, 0x3F, 0x7D, 0x3D, 0x71, 0x35, 0x52, 0x27, 0x33, 0x1B, 0x25, 0x17, 0x21, 0x15, 0x23, 0x19, 0x30, 0x26, 0x4B, 0x3B, 0x67, 0x4C, 0x72, 0x54, 0x77, 0x56, 0x78, 0x56, 0x76, 0x54, 0x69, 0x46, 0x47, 0x2E, 0x2E, 0x1F, 0x24, 0x19, 0x23, 0x1A, 0x2D, 0x24, 0x4C, 0x3D, 0x78, 0x5A, 0x93, 0x6A, 0x9B, 0x70, 0xA4, 0x74, 0xA7, 0x77, 0xAB, 0x7B, 0xAE, 0x7B, 0xAE, 0x7B, 0xAE, 0x7C, 0xB0, 0x7E, 0xB2, 0x7F, 0xB1, 0x7E, 0xB3, 0x7D, 0xB4, 0x80, 0xB4, 0x81, 0xB5, 0x7F, 0xB3, 0x7E, 0xB4, 0x7E, 0xB3, 0x7F, 0xB3, 0x7F, 0xB4, 0x7E, 0xB4, 0x80, 0xB4, 0x7F, 0xB2, 0x7D, 0xAF, 0x7B, 0xA6, 0x70, 0x85, 0x54, 0x50, 0x32, 0x32, 0x21, 0x28, 0x1B, 0x22, 0x17, 0x1E, 0x14, 0x1B, 0x13, 0x19, 0x12, 0x1B, 0x14, 0x28, 0x22, 0x51, 0x41, 0x76, 0x4D, 0x4F, 0x30, 0x2C, 0x1D, 0x23, 0x18, 0x1F, 0x16, 0x1D, 0x14, 0x1A, 0x12, 0x1A, 0x12, 0x1A, 0x13, 0x22, 0x1B, 0x43, 0x3B, 0x87, 0x65, 0xA8, 0x77, 0xB1, 0x7E, 0xB8, 0x83, 0xBC, 0x86, 0xBC, 0x84, 0xBB, 0x86, 0xBC, 0x86, 0xBA, 0x84, 0xBB, 0x86, 0xBD, 0x86, 0xBE, 0x87, 0xBD, 0x86, 0xBB, 0x86, 0xBB, 0x86, 0xBC, 0x85, 0xBA, 0x85, 0xBB, 0x85, 0xBD, 0x84, 0xBC, 0x85, 0xBA, 0x84, 0xBA, 0x84, 0xBA, 0x84, 0xBC, 0x85, 0xB8, 0x81, 0xA7, 0x6E, 0x6D, 0x44, 0x34, 0x22, 0x25, 0x1A, 0x26, 0x1A, 0x2B, 0x1C, 0x2C, 0x1B, 0x2D, 0x1C, 0x2E, 0x1C, 0x2D, 0x1D, 0x2E, 0x1C, 0x2C, 0x1B, 0x27, 0x17, 0x1C, 0x12, 0x1A, 0x12, 0x19, 0x12, 0x21, 0x19, 0x2C, 0x21, 0x30, 0x23, 0x30, 0x23, 0x31, 0x24, 0x32, 0x25, 0x32, 0x24, 0x30, 0x25, 0x33, 0x25, 0x34, 0x26, 0x33, 0x26, 0x32, 0x25, 0x32, 0x24, 0x31, 0x24, 0x30, 0x24, 0x32, 0x23, 0x31, 0x24, 0x31, 0x24, 0x31, 0x24, 0x31, 0x25, 0x33, 0x26, 0x33, 0x24, 0x2D, 0x1E, 0x1E, 0x15, 0x19, 0x12, 0x17, 0x0F, 0x16, 0x10, 0x18, 0x10, 0x17, 0x10, 0x17, 0x0F, 0x1A, 0x11, 0x35, 0x1A, 0x57, 0x21, 0x60, 0x23, 0x52, 0x1F, 0x33, 0x19, 0x35, 0x1A, 0x56, 0x20, 0x5E, 0x21, 0x5F, 0x22, 0x60, 0x22, 0x60, 0x24, 0x65, 0x27, 0x68, 0x27, 0x64, 0x24, 0x62, 0x23, 0x61, 0x23, 0x63, 0x23, 0x61, 0x23, 0x63, 0x23, 0x62, 0x22, 0x60, 0x21, 0x5E, 0x21, 0x62, 0x23, 0x61, 0x22, 0x60, 0x22, 0x61, 0x22, 0x61, 0x22, 0x62, 0x22, 0x60, 0x22, 0x61, 0x23, 0x61, 0x23, 0x5E, 0x21, 0x60, 0x21, 0x5F, 0x22, 0x65, 0x23, 0x63, 0x23, 0x60, 0x22, 0x60, 0x22, 0x60, 0x22, 0x5F, 0x22, 0x60, 0x22, 0x5B, 0x21, 0x5F, 0x22, 0x5F, 0x22, 0x60, 0x22, 0x5F, 0x21, 0x5E, 0x21, 0x60, 0x21, 0x5B, 0x21, 0x5B, 0x21, 0x5B, 0x21, 0x59, 0x20, 0x58, 0x20, 0x5A, 0x20, 0x5C, 0x20, 0x5C, 0x21, 0x5E, 0x22, 0x5D, 0x21, 0x5D, 0x22, 0x5D, 0x20, 0x57, 0x1F, 0x5B, 0x20, 0x58, 0x1F, 0x5D, 0x21, 0x5B, 0x20, 0x58, 0x1F, 0x5A, 0x20, 0x5A, 0x20, 0x5A, 0x20, 0x5B, 0x20, 0x57, 0x1F, 0x5B, 0x21, 0x5A, 0x21, 0x5D, 0x20, 0x58, 0x20, 0x57, 0x20, 0x58, 0x21, 0x56, 0x20, 0x57, 0x1F, 0x5A, 0x20, 0x59, 0x20, 0x58, 0x1F, 0x57, 0x20, 0x5B, 0x21, 0x59, 0x20, 0x56, 0x1F, 0x58, 0x20, 0x56, 0x1F, 0x57, 0x20, 0x57, 0x1F, 0x59, 0x21, 0x5A, 0x22, 0x5E, 0x22, 0x5B, 0x22, 0x5C, 0x22, 0x5C, 0x21, 0x56, 0x1F, 0x57, 0x1F, 0x58, 0x20, 0x58, 0x1F, 0x53, 0x1E, 0x54, 0x1F, 0x57, 0x1F, 0x56, 0x1F, 0x56, 0x20, 0x57, 0x1F, 0x55, 0x1F, 0x55, 0x1F, 0x55, 0x1F, 0x55, 0x1F, 0x55, 0x1F, 0x54, 0x1F, 0x55, 0x1F, 0x55, 0x1F, 0x49, 0x1D, 0x35, 0x1A, 0x28, 0x17, 0x29, 0x18, 0x2A, 0x18, 0x24, 0x16, 0x29, 0x17, 0x25, 0x16, 0x29, 0x18, 0x27, 0x16, 0x2B, 0x19, 0x27, 0x17, 0x33, 0x1D, 0x30, 0x1A, 0x2A, 0x18, 0x2B, 0x19, 0x33, 0x1B, 0x31, 0x1B, 0x34, 0x1B, 0x2E, 0x1A, 0x30, 0x1A, 0x2F, 0x1A, 0x37, 0x1D, 0x2B, 0x17, 0x35, 0x1C, 0x2F, 0x1A, 0x36, 0x1C, 0x2F, 0x1A, 0x2F, 0x1A, 0x30, 0x1A, 0x30, 0x1A, 0x2B, 0x18, 0x35, 0x1C, 0x2C, 0x19, 0x2E, 0x19, 0x33, 0x1B, 0x27, 0x17, 0x2F, 0x19, 0x26, 0x16, 0x2F, 0x1A, 0x29, 0x18, 0x2D, 0x1A, 0x3B, 0x21, 0x34, 0x1C, 0x35, 0x1E, 0x31, 0x1A
    },

    {
        0x73, 0x7B, 0x72, 0x7A, 0x73, 0x7D, 0x74, 0x7D, 0x76, 0x7E, 0x77, 0x7F, 0x77, 0x7F, 0x76, 0x7E, 0x77, 0x7E, 0x76, 0x7D, 0x77, 0x7E, 0x77, 0x7E, 0x78, 0x80, 0x78, 0x80, 0x79, 0x81, 0x7A, 0x82, 0x7A, 0x82, 0x7A, 0x81, 0x78, 0x7E, 0x73, 0x7B, 0x69, 0x70, 0x53, 0x54, 0x36, 0x35, 0x25, 0x27, 0x1E, 0x23, 0x1C, 0x26, 0x1F, 0x38, 0x27, 0x55, 0x2F, 0x6B, 0x31, 0x71, 0x33, 0x73, 0x32, 0x73, 0x32, 0x73, 0x30, 0x68, 0x26, 0x49, 0x1C, 0x2E, 0x18, 0x25, 0x18, 0x25, 0x1E, 0x35, 0x2C, 0x5A, 0x3F, 0x83, 0x49, 0x93, 0x4D, 0x9B, 0x51, 0x9F, 0x52, 0xA3, 0x54, 0xA5, 0x55, 0xA7, 0x55, 0xA6, 0x55, 0xA8, 0x56, 0xAA, 0x58, 0xAC, 0x57, 0xAB, 0x57, 0xAA, 0x59, 0xAE, 0x59, 0xAE, 0x59, 0xAE, 0x58, 0xAD, 0x57, 0xAB, 0x57, 0xAD, 0x58, 0xAC, 0x57, 0xAC, 0x57, 0xAB, 0x57, 0xAC, 0x57, 0xA8, 0x56, 0xA7, 0x50, 0x96, 0x40, 0x6D, 0x2A, 0x3E, 0x1E, 0x2B, 0x1A, 0x24, 0x18, 0x1F, 0x16, 0x1C, 0x14, 0x19, 0x15, 0x19, 0x19, 0x1D, 0x26, 0x33, 0x43, 0x63, 0x5F, 0x80, 0x4B, 0x55, 0x2C, 0x2E, 0x20, 0x24, 0x1C, 0x1F, 0x18, 0x1C, 0x15, 0x19, 0x14, 0x19, 0x15, 0x1A, 0x17, 0x1F, 0x21, 0x3C, 0x3D, 0x7D, 0x4F, 0xA0, 0x55, 0xAA, 0x58, 0xAE, 0x5C, 0xB5, 0x5B, 0xB2, 0x5B, 0xB4, 0x5C, 0xB4, 0x5B, 0xB3, 0x5A, 0xB3, 0x5C, 0xB5, 0x5C, 0xB3, 0x5C, 0xB4, 0x5B, 0xB3, 0x5B, 0xB5, 0x5C, 0xB4, 0x5B, 0xB4, 0x5B, 0xB5, 0x5B, 0xB4, 0x5B, 0xB2, 0x5A, 0xB2, 0x5C, 0xB3, 0x5B, 0xB3, 0x5C, 0xB3, 0x5A, 0xAE, 0x4F, 0x8F, 0x35, 0x52, 0x1F, 0x2A, 0x1A, 0x21, 0x1D, 0x22, 0x26, 0x29, 0x2A, 0x2A, 0x2C, 0x2C, 0x2E, 0x2C, 0x2F, 0x2E, 0x2E, 0x2C, 0x2B, 0x2B, 0x22, 0x21, 0x18, 0x19, 0x15, 0x17, 0x14, 0x18, 0x15, 0x1E, 0x1A, 0x2B, 0x1B, 0x2E, 0x1C, 0x2F, 0x1C, 0x2E, 0x1C, 0x31, 0x1D, 0x30, 0x1C, 0x2F, 0x1D, 0x31, 0x1E, 0x32, 0x1E, 0x32, 0x1E, 0x30, 0x1D, 0x31, 0x1D, 0x30, 0x1D, 0x2F, 0x1D, 0x2F, 0x1D, 0x30, 0x1D, 0x30, 0x1C, 0x2F, 0x1D, 0x30, 0x1E, 0x31, 0x1E, 0x30, 0x1A, 0x26, 0x15, 0x1A, 0x14, 0x17, 0x13, 0x16, 0x13, 0x16, 0x14, 0x17, 0x14, 0x16, 0x15, 0x16, 0x1F, 0x20, 0x3F, 0x45, 0x5C, 0x59, 0x63, 0x5D, 0x4F, 0x45, 0x34, 0x2C, 0x3F, 0x40, 0x5D, 0x58, 0x67, 0x5C, 0x6B, 0x5E, 0x6C, 0x5F, 0x6C, 0x60, 0x6F, 0x63, 0x71, 0x67, 0x6E, 0x61, 0x6F, 0x61, 0x6D, 0x60, 0x6F, 0x61, 0x6E, 0x5F, 0x6D, 0x60, 0x6C, 0x5E, 0x6C, 0x5E, 0x69, 0x5C, 0x6E, 0x62, 0x6C, 0x5D, 0x6D, 0x5E, 0x6B, 0x60, 0x6D, 0x60, 0x6D, 0x60, 0x6A, 0x5F, 0x6C, 0x5E, 0x6C, 0x60, 0x6B, 0x5D, 0x6C, 0x5F, 0x6A, 0x5E, 0x6C, 0x61, 0x6B, 0x5F, 0x6C, 0x60, 0x6B, 0x5D, 0x6B, 0x5F, 0x69, 0x5D, 0x6A, 0x5D, 0x69, 0x5C, 0x6B, 0x5B, 0x69, 0x5E, 0x6D, 0x5E, 0x6B, 0x5E, 0x6A, 0x5D, 0x6C, 0x5E, 0x67, 0x5B, 0x67, 0x5B, 0x65, 0x59, 0x65, 0x58, 0x63, 0x57, 0x64, 0x5A, 0x65, 0x58, 0x68, 0x5B, 0x67, 0x5C, 0x68, 0x5C, 0x68, 0x5C, 0x68, 0x5A, 0x62, 0x56, 0x64, 0x59, 0x63, 0x58, 0x68, 0x5B, 0x63, 0x58, 0x62, 0x55, 0x63, 0x57, 0x64, 0x59, 0x64, 0x58, 0x65, 0x59, 0x63, 0x56, 0x63, 0x57, 0x65, 0x5A, 0x67, 0x5A, 0x64, 0x57, 0x63, 0x57, 0x60, 0x57, 0x61, 0x55, 0x60, 0x55, 0x63, 0x58, 0x64, 0x57, 0x62, 0x57, 0x60, 0x57, 0x64, 0x59, 0x63, 0x58, 0x60, 0x55, 0x61, 0x56, 0x61, 0x56, 0x63, 0x57, 0x62, 0x55, 0x64, 0x59, 0x63, 0x59, 0x66, 0x59, 0x62, 0x58, 0x64, 0x5A, 0x64, 0x59, 0x5F, 0x54, 0x60, 0x56, 0x62, 0x57, 0x60, 0x55, 0x5E, 0x50, 0x5E, 0x53, 0x61, 0x55, 0x61, 0x54, 0x60, 0x56, 0x60, 0x54, 0x5F, 0x53, 0x60, 0x54, 0x5F, 0x55, 0x60, 0x54, 0x5D, 0x54, 0x5E, 0x54, 0x5E, 0x54, 0x5E, 0x54, 0x4F, 0x46, 0x35, 0x33, 0x25, 0x25, 0x24, 0x28, 0x27, 0x29, 0x23, 0x23, 0x27, 0x2B, 0x22, 0x23, 0x25, 0x29, 0x24, 0x26, 0x27, 0x2C, 0x26, 0x2B, 0x2E, 0x36, 0x2C, 0x2F, 0x29, 0x2E, 0x29, 0x2E, 0x2F, 0x33, 0x2D, 0x34, 0x2F, 0x35, 0x29, 0x2E, 0x2D, 0x32, 0x29, 0x30, 0x30, 0x35, 0x26, 0x29, 0x2F, 0x36, 0x27, 0x2C, 0x2F, 0x34, 0x28, 0x2C, 0x2A, 0x30, 0x29, 0x2B, 0x28, 0x2D, 0x24, 0x28, 0x2C, 0x33, 0x26, 0x2A, 0x28, 0x2E, 0x2B, 0x2E, 0x22, 0x27, 0x28, 0x2A, 0x22, 0x28, 0x28, 0x31, 0x22, 0x2B, 0x25, 0x34, 0x2E, 0x41, 0x27, 0x36, 0x29, 0x3D, 0x24, 0x2F
    },

    {
        0x7F, 0x3D, 0x7E, 0x3C, 0x80, 0x3E, 0x81, 0x3E, 0x81, 0x3E, 0x82, 0x3E, 0x83, 0x3F, 0x82, 0x3F, 0x83, 0x3E, 0x80, 0x3E, 0x81, 0x3F, 0x82, 0x3F, 0x82, 0x40, 0x83, 0x3F, 0x84, 0x40, 0x85, 0x40, 0x84, 0x40, 0x85, 0x41, 0x85, 0x41, 0x82, 0x3E, 0x7D, 0x3C, 0x72, 0x37, 0x58, 0x29, 0x35, 0x1D, 0x29, 0x1B, 0x30, 0x24, 0x49, 0x39, 0x67, 0x4C, 0x73, 0x54, 0x76, 0x55, 0x78, 0x58, 0x7A, 0x59, 0x7B, 0x58, 0x78, 0x56, 0x6F, 0x4B, 0x4D, 0x33, 0x31, 0x23, 0x31, 0x26, 0x48, 0x3B, 0x75, 0x58, 0x93, 0x68, 0x9C, 0x6F, 0xA2, 0x74, 0xA6, 0x75, 0xA9, 0x78, 0xAD, 0x7A, 0xAF, 0x7C, 0xB0, 0x7D, 0xB0, 0x7D, 0xB1, 0x7E, 0xB1, 0x7E, 0xB2, 0x7E, 0xB3, 0x7E, 0xB2, 0x7F, 0xB5, 0x82, 0xB8, 0x82, 0xB6, 0x80, 0xB5, 0x81, 0xB4, 0x7F, 0xB4, 0x80, 0xB5, 0x80, 0xB4, 0x7F, 0xB6, 0x7F, 0xB1, 0x7C, 0xA6, 0x70, 0x85, 0x54, 0x52, 0x33, 0x33, 0x22, 0x28, 0x1C, 0x23, 0x17, 0x1E, 0x15, 0x1B, 0x14, 0x1A, 0x12, 0x1B, 0x14, 0x28, 0x22, 0x50, 0x41, 0x85, 0x5F, 0x99, 0x6A, 0x93, 0x5E, 0x5F, 0x3A, 0x33, 0x22, 0x26, 0x19, 0x20, 0x17, 0x1D, 0x15, 0x1B, 0x13, 0x1A, 0x13, 0x1C, 0x14, 0x1E, 0x19, 0x3A, 0x34, 0x80, 0x61, 0xA6, 0x76, 0xAD, 0x7B, 0xB5, 0x80, 0xB9, 0x84, 0xBB, 0x83, 0xBB, 0x84, 0xBA, 0x84, 0xB7, 0x83, 0xBA, 0x85, 0xBC, 0x85, 0xBB, 0x87, 0xBB, 0x86, 0xBB, 0x86, 0xBB, 0x86, 0xBB, 0x85, 0xBC, 0x86, 0xBD, 0x86, 0xB9, 0x85, 0xBB, 0x84, 0xB9, 0x83, 0xB9, 0x84, 0xB8, 0x83, 0xA9, 0x70, 0x71, 0x46, 0x3A, 0x25, 0x25, 0x1A, 0x1E, 0x15, 0x1C, 0x14, 0x21, 0x18, 0x29, 0x1A, 0x2B, 0x1B, 0x2F, 0x1C, 0x2D, 0x1C, 0x2C, 0x1B, 0x25, 0x17, 0x1D, 0x13, 0x19, 0x11, 0x18, 0x11, 0x18, 0x11, 0x19, 0x12, 0x1D, 0x18, 0x2B, 0x21, 0x30, 0x22, 0x31, 0x23, 0x31, 0x24, 0x31, 0x24, 0x32, 0x25, 0x34, 0x26, 0x34, 0x27, 0x35, 0x26, 0x34, 0x27, 0x34, 0x26, 0x31, 0x24, 0x32, 0x24, 0x31, 0x24, 0x32, 0x24, 0x32, 0x24, 0x31, 0x24, 0x32, 0x25, 0x32, 0x25, 0x2D, 0x20, 0x1F, 0x16, 0x19, 0x11, 0x17, 0x10, 0x17, 0x10, 0x16, 0x0F, 0x17, 0x10, 0x17, 0x10, 0x19, 0x11, 0x35, 0x19, 0x58, 0x22, 0x5E, 0x21, 0x58, 0x20, 0x36, 0x19, 0x35, 0x1B, 0x52, 0x20, 0x5A, 0x21, 0x5E, 0x22, 0x60, 0x23, 0x61, 0x23, 0x62, 0x26, 0x63, 0x24, 0x66, 0x25, 0x61, 0x22, 0x64, 0x23, 0x62, 0x23, 0x64, 0x24, 0x64, 0x23, 0x61, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x5E, 0x21, 0x63, 0x22, 0x60, 0x22, 0x5E, 0x21, 0x62, 0x22, 0x63, 0x23, 0x61, 0x22, 0x61, 0x22, 0x5D, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x60, 0x22, 0x60, 0x21, 0x5D, 0x22, 0x5D, 0x21, 0x5E, 0x22, 0x5F, 0x22, 0x61, 0x22, 0x5C, 0x23, 0x61, 0x22, 0x60, 0x23, 0x61, 0x23, 0x5E, 0x22, 0x61, 0x23, 0x5F, 0x22, 0x5E, 0x21, 0x5F, 0x21, 0x5F, 0x21, 0x5D, 0x22, 0x5B, 0x21, 0x5A, 0x21, 0x5B, 0x21, 0x59, 0x20, 0x56, 0x1F, 0x5A, 0x21, 0x59, 0x20, 0x59, 0x20, 0x5C, 0x21, 0x5E, 0x21, 0x5B, 0x20, 0x5B, 0x21, 0x5C, 0x21, 0x5B, 0x21, 0x58, 0x20, 0x57, 0x1F, 0x5A, 0x20, 0x5A, 0x21, 0x5B, 0x20, 0x57, 0x1F, 0x5B, 0x21, 0x5D, 0x21, 0x5C, 0x21, 0x5B, 0x20, 0x59, 0x20, 0x5B, 0x21, 0x5A, 0x21, 0x59, 0x20, 0x55, 0x1F, 0x59, 0x21, 0x58, 0x20, 0x59, 0x20, 0x59, 0x20, 0x5E, 0x23, 0x57, 0x20, 0x53, 0x20, 0x5D, 0x23, 0x5A, 0x21, 0x5D, 0x21, 0x59, 0x21, 0x59, 0x21, 0x5A, 0x22, 0x57, 0x20, 0x58, 0x21, 0x59, 0x21, 0x5B, 0x22, 0x59, 0x21, 0x5A, 0x21, 0x5A, 0x22, 0x56, 0x21, 0x56, 0x20, 0x55, 0x20, 0x57, 0x1F, 0x55, 0x1F, 0x57, 0x20, 0x56, 0x1F, 0x57, 0x20, 0x59, 0x20, 0x58, 0x20, 0x57, 0x1F, 0x53, 0x1F, 0x59, 0x20, 0x58, 0x20, 0x55, 0x1F, 0x4C, 0x1E, 0x38, 0x1C, 0x31, 0x1A, 0x33, 0x1C, 0x38, 0x1D, 0x29, 0x17, 0x34, 0x1D, 0x34, 0x1B, 0x32, 0x1C, 0x31, 0x1B, 0x33, 0x1C, 0x36, 0x1D, 0x36, 0x1D, 0x34, 0x1C, 0x30, 0x19, 0x2E, 0x1B, 0x36, 0x1E, 0x2A, 0x19, 0x2C, 0x18, 0x29, 0x18, 0x31, 0x1B, 0x2B, 0x19, 0x32, 0x1B, 0x2C, 0x1A, 0x31, 0x1B, 0x27, 0x18, 0x33, 0x1B, 0x28, 0x18, 0x30, 0x1B, 0x2E, 0x1B, 0x39, 0x20, 0x36, 0x1F, 0x41, 0x24, 0x3D, 0x22, 0x3D, 0x20, 0x2A, 0x19, 0x31, 0x1B, 0x2E, 0x1A, 0x35, 0x20, 0x4F, 0x2C, 0x4D, 0x2A, 0x54, 0x2D, 0x54, 0x2E, 0x55, 0x2E, 0x52, 0x2C, 0x42, 0x23
    },

    {
        0x73, 0x7C, 0x74, 0x7D, 0x76, 0x7E, 0x76, 0x7E, 0x76, 0x7E, 0x77, 0x7E, 0x78, 0x7E, 0x78, 0x80, 0x77, 0x80, 0x7F, 0x7D, 0x78, 0x7E, 0x78, 0x7F, 0x79, 0x80, 0x7A, 0x81, 0x7B, 0x82, 0x7A, 0x82, 0x7B, 0x83, 0x7B, 0x81, 0x7A, 0x81, 0x78, 0x7F, 0x74, 0x7B, 0x6C, 0x71, 0x57, 0x59, 0x38, 0x37, 0x25, 0x2D, 0x22, 0x37, 0x29, 0x52, 0x30, 0x6A, 0x32, 0x72, 0x32, 0x74, 0x32, 0x75, 0x34, 0x76, 0x33, 0x76, 0x33, 0x75, 0x32, 0x6B, 0x28, 0x4F, 0x1E, 0x34, 0x1E, 0x37, 0x2A, 0x56, 0x3C, 0x7D, 0x48, 0x90, 0x4C, 0x98, 0x4F, 0x9D, 0x51, 0xA0, 0x52, 0xA3, 0x55, 0xA6, 0x56, 0xA9, 0x56, 0xA9, 0x56, 0xA8, 0x58, 0xA8, 0x58, 0xA9, 0x57, 0xAB, 0x57, 0xAC, 0x58, 0xAD, 0x59, 0xAF, 0x5C, 0xB1, 0x5A, 0xAE, 0x59, 0xAE, 0x59, 0xAD, 0x58, 0xAC, 0x59, 0xAF, 0x59, 0xAE, 0x59, 0xAD, 0x57, 0xA9, 0x51, 0x98, 0x41, 0x6D, 0x2B, 0x40, 0x1F, 0x2C, 0x1A, 0x24, 0x18, 0x20, 0x17, 0x1C, 0x15, 0x1A, 0x15, 0x19, 0x19, 0x1C, 0x25, 0x31, 0x43, 0x63, 0x68, 0x8D, 0x76, 0x9A, 0x74, 0x94, 0x58, 0x63, 0x32, 0x35, 0x23, 0x27, 0x1D, 0x21, 0x19, 0x1C, 0x16, 0x1A, 0x16, 0x1A, 0x16, 0x1A, 0x16, 0x1D, 0x1F, 0x35, 0x3A, 0x76, 0x4F, 0x9E, 0x54, 0xA4, 0x57, 0xAB, 0x5B, 0xB2, 0x5C, 0xB3, 0x5C, 0xB1, 0x5B, 0xB2, 0x5B, 0xB2, 0x5B, 0xB3, 0x5A, 0xB4, 0x5B, 0xB5, 0x5C, 0xB6, 0x5B, 0xB4, 0x5B, 0xB4, 0x5B, 0xB2, 0x5C, 0xB6, 0x5C, 0xB4, 0x5B, 0xB2, 0x5B, 0xB2, 0x5B, 0xB3, 0x5A, 0xB2, 0x5A, 0xAF, 0x50, 0x92, 0x37, 0x53, 0x21, 0x2C, 0x19, 0x21, 0x16, 0x1C, 0x16, 0x1A, 0x1B, 0x20, 0x26, 0x27, 0x2A, 0x2B, 0x2D, 0x2C, 0x2C, 0x2B, 0x2A, 0x29, 0x22, 0x21, 0x18, 0x1A, 0x15, 0x17, 0x14, 0x17, 0x14, 0x18, 0x14, 0x18, 0x15, 0x1B, 0x19, 0x2A, 0x1C, 0x2E, 0x1C, 0x30, 0x1D, 0x30, 0x1D, 0x2F, 0x1D, 0x30, 0x1E, 0x33, 0x1F, 0x33, 0x1F, 0x34, 0x20, 0x35, 0x1F, 0x33, 0x1D, 0x30, 0x1D, 0x2F, 0x1D, 0x30, 0x1D, 0x2F, 0x1D, 0x30, 0x1C, 0x30, 0x1D, 0x30, 0x1E, 0x30, 0x1B, 0x27, 0x16, 0x1C, 0x14, 0x17, 0x14, 0x17, 0x13, 0x17, 0x13, 0x16, 0x14, 0x16, 0x16, 0x16, 0x1D, 0x1F, 0x3E, 0x44, 0x60, 0x5B, 0x63, 0x5B, 0x55, 0x4A, 0x37, 0x30, 0x41, 0x41, 0x5D, 0x57, 0x64, 0x59, 0x67, 0x5B, 0x6A, 0x5F, 0x6C, 0x5E, 0x6D, 0x63, 0x6E, 0x62, 0x70, 0x61, 0x6D, 0x60, 0x71, 0x62, 0x6F, 0x62, 0x6E, 0x61, 0x6F, 0x61, 0x6D, 0x5E, 0x6A, 0x5D, 0x6B, 0x5D, 0x6A, 0x5D, 0x6F, 0x61, 0x6D, 0x5F, 0x6A, 0x5E, 0x6E, 0x61, 0x6F, 0x61, 0x6D, 0x5F, 0x6B, 0x5F, 0x6C, 0x5D, 0x6C, 0x5E, 0x6B, 0x5D, 0x6C, 0x5E, 0x6B, 0x5D, 0x68, 0x5B, 0x6A, 0x5B, 0x6B, 0x5D, 0x69, 0x5E, 0x6A, 0x5D, 0x66, 0x5D, 0x69, 0x5D, 0x6B, 0x5F, 0x6D, 0x61, 0x6B, 0x5D, 0x6D, 0x5F, 0x6B, 0x5F, 0x69, 0x5B, 0x6B, 0x5C, 0x6A, 0x5D, 0x6A, 0x5D, 0x64, 0x58, 0x65, 0x5A, 0x64, 0x59, 0x63, 0x58, 0x61, 0x54, 0x66, 0x59, 0x64, 0x57, 0x63, 0x57, 0x68, 0x5A, 0x6A, 0x5D, 0x64, 0x58, 0x65, 0x5A, 0x68, 0x59, 0x66, 0x58, 0x63, 0x56, 0x62, 0x55, 0x62, 0x58, 0x64, 0x58, 0x65, 0x58, 0x64, 0x55, 0x66, 0x59, 0x67, 0x5B, 0x66, 0x5A, 0x65, 0x56, 0x62, 0x57, 0x64, 0x5B, 0x65, 0x58, 0x64, 0x58, 0x5F, 0x53, 0x64, 0x58, 0x64, 0x58, 0x64, 0x58, 0x65, 0x59, 0x67, 0x5C, 0x60, 0x54, 0x5B, 0x52, 0x66, 0x5C, 0x65, 0x59, 0x67, 0x5C, 0x63, 0x57, 0x62, 0x57, 0x62, 0x58, 0x62, 0x57, 0x66, 0x59, 0x66, 0x5A, 0x65, 0x59, 0x63, 0x59, 0x66, 0x5A, 0x64, 0x59, 0x62, 0x57, 0x61, 0x56, 0x62, 0x55, 0x65, 0x58, 0x62, 0x56, 0x63, 0x57, 0x60, 0x53, 0x63, 0x57, 0x64, 0x58, 0x62, 0x57, 0x60, 0x54, 0x5D, 0x53, 0x61, 0x56, 0x60, 0x56, 0x5D, 0x52, 0x50, 0x46, 0x37, 0x38, 0x30, 0x32, 0x31, 0x37, 0x31, 0x34, 0x26, 0x29, 0x2E, 0x36, 0x2E, 0x32, 0x2C, 0x32, 0x29, 0x2E, 0x2E, 0x37, 0x2C, 0x31, 0x2E, 0x34, 0x2C, 0x30, 0x28, 0x2B, 0x29, 0x30, 0x2C, 0x2D, 0x25, 0x29, 0x25, 0x27, 0x22, 0x2A, 0x29, 0x2E, 0x25, 0x2E, 0x29, 0x2F, 0x25, 0x31, 0x27, 0x2D, 0x24, 0x2A, 0x2A, 0x2D, 0x25, 0x29, 0x27, 0x34, 0x24, 0x36, 0x27, 0x3D, 0x26, 0x3E, 0x2A, 0x46, 0x27, 0x43, 0x26, 0x3F, 0x22, 0x2A, 0x2D, 0x32, 0x29, 0x2F, 0x26, 0x3D, 0x2B, 0x52, 0x2A, 0x52, 0x2A, 0x53, 0x2A, 0x53, 0x2B, 0x54, 0x2A, 0x50, 0x26, 0x39
    },

    {
        0x7D, 0x3D, 0x7E, 0x3C, 0x7F, 0x3E, 0x7F, 0x3D, 0x81, 0x3E, 0x81, 0x3E, 0x81, 0x3F, 0x82, 0x3E, 0x82, 0x3E, 0x81, 0x3E, 0x80, 0x3F, 0x81, 0x3F, 0x83, 0x3F, 0x83, 0x40, 0x84, 0x40, 0x85, 0x41, 0x84, 0x41, 0x85, 0x41, 0x84, 0x41, 0x85, 0x40, 0x82, 0x3F, 0x7D, 0x3D, 0x74, 0x38, 0x5B, 0x2C, 0x3F, 0x28, 0x47, 0x36, 0x63, 0x48, 0x71, 0x51, 0x75, 0x54, 0x7A, 0x57, 0x7B, 0x59, 0x7C, 0x5A, 0x7E, 0x5B, 0x7E, 0x5B, 0x7B, 0x59, 0x72, 0x4E, 0x59, 0x3D, 0x50, 0x3F, 0x70, 0x55, 0x90, 0x67, 0x9A, 0x6D, 0x9F, 0x71, 0xA4, 0x75, 0xA7, 0x76, 0xAC, 0x78, 0xAF, 0x7C, 0xB0, 0x7D, 0xB0, 0x7C, 0xB1, 0x7D, 0xB2, 0x7E, 0xB4, 0x80, 0xB1, 0x7F, 0xB4, 0x7F, 0xB3, 0x80, 0xB3, 0x7F, 0xB5, 0x81, 0xB8, 0x82, 0xB5, 0x80, 0xB3, 0x7F, 0xB2, 0x7E, 0xB4, 0x80, 0xB7, 0x81, 0xB5, 0x80, 0xAB, 0x75, 0x8D, 0x5A, 0x56, 0x36, 0x34, 0x23, 0x2A, 0x1C, 0x22, 0x18, 0x1F, 0x15, 0x1B, 0x13, 0x1A, 0x13, 0x1A, 0x14, 0x25, 0x1F, 0x4B, 0x3D, 0x83, 0x5F, 0x9E, 0x6E, 0xA6, 0x72, 0xA9, 0x74, 0xA0, 0x67, 0x6D, 0x42, 0x3A, 0x26, 0x28, 0x1C, 0x22, 0x17, 0x1E, 0x15, 0x1A, 0x13, 0x1A, 0x13, 0x1A, 0x13, 0x1D, 0x17, 0x33, 0x2E, 0x78, 0x5C, 0xA2, 0x73, 0xAD, 0x7B, 0xB2, 0x7F, 0xB7, 0x83, 0xBA, 0x83, 0xB9, 0x86, 0xB9, 0x84, 0xBB, 0x85, 0xBC, 0x86, 0xBD, 0x87, 0xBB, 0x86, 0xBA, 0x85, 0xBA, 0x86, 0xBD, 0x86, 0xBC, 0x86, 0xBC, 0x87, 0xBA, 0x85, 0xBA, 0x85, 0xB7, 0x84, 0xB7, 0x83, 0xAA, 0x73, 0x73, 0x48, 0x39, 0x26, 0x26, 0x1A, 0x1F, 0x15, 0x1B, 0x13, 0x1A, 0x12, 0x1A, 0x13, 0x20, 0x17, 0x28, 0x1A, 0x2B, 0x1B, 0x2A, 0x1A, 0x25, 0x17, 0x1D, 0x13, 0x19, 0x11, 0x18, 0x11, 0x18, 0x10, 0x17, 0x10, 0x18, 0x11, 0x18, 0x12, 0x1E, 0x17, 0x2B, 0x20, 0x2F, 0x22, 0x31, 0x24, 0x30, 0x25, 0x32, 0x25, 0x32, 0x25, 0x34, 0x26, 0x34, 0x27, 0x36, 0x28, 0x35, 0x26, 0x31, 0x24, 0x31, 0x24, 0x31, 0x24, 0x32, 0x25, 0x33, 0x25, 0x31, 0x24, 0x31, 0x25, 0x30, 0x21, 0x20, 0x16, 0x1A, 0x12, 0x18, 0x11, 0x17, 0x10, 0x19, 0x11, 0x16, 0x0F, 0x17, 0x10, 0x19, 0x10, 0x31, 0x19, 0x54, 0x20, 0x5F, 0x22, 0x56, 0x20, 0x37, 0x19, 0x35, 0x1A, 0x55, 0x21, 0x5C, 0x22, 0x60, 0x22, 0x5F, 0x22, 0x5D, 0x22, 0x60, 0x23, 0x67, 0x27, 0x63, 0x24, 0x60, 0x22, 0x62, 0x24, 0x63, 0x23, 0x63, 0x24, 0x64, 0x23, 0x63, 0x23, 0x64, 0x24, 0x61, 0x23, 0x62, 0x22, 0x62, 0x22, 0x60, 0x22, 0x63, 0x23, 0x61, 0x21, 0x60, 0x22, 0x63, 0x23, 0x60, 0x22, 0x61, 0x22, 0x5E, 0x22, 0x61, 0x23, 0x60, 0x21, 0x5C, 0x20, 0x5E, 0x21, 0x5D, 0x23, 0x5E, 0x22, 0x5E, 0x22, 0x5E, 0x22, 0x5F, 0x22, 0x5E, 0x21, 0x5E, 0x21, 0x60, 0x23, 0x63, 0x23, 0x61, 0x22, 0x5E, 0x21, 0x5C, 0x22, 0x5E, 0x21, 0x5D, 0x21, 0x5C, 0x21, 0x5E, 0x21, 0x5D, 0x21, 0x58, 0x20, 0x5A, 0x21, 0x57, 0x20, 0x5B, 0x21, 0x5C, 0x21, 0x5B, 0x20, 0x57, 0x20, 0x5B, 0x21, 0x5D, 0x21, 0x5B, 0x21, 0x5C, 0x21, 0x5A, 0x20, 0x5C, 0x21, 0x5A, 0x21, 0x59, 0x1F, 0x5A, 0x20, 0x57, 0x1F, 0x57, 0x20, 0x57, 0x20, 0x59, 0x20, 0x5A, 0x20, 0x58, 0x20, 0x58, 0x20, 0x59, 0x20, 0x59, 0x20, 0x5A, 0x20, 0x5C, 0x21, 0x5B, 0x21, 0x5C, 0x21, 0x5A, 0x21, 0x5B, 0x21, 0x5B, 0x20, 0x5D, 0x22, 0x59, 0x20, 0x55, 0x20, 0x5C, 0x23, 0x5A, 0x21, 0x5B, 0x22, 0x5A, 0x21, 0x59, 0x20, 0x59, 0x21, 0x5B, 0x22, 0x59, 0x21, 0x5D, 0x22, 0x5C, 0x22, 0x57, 0x21, 0x56, 0x20, 0x59, 0x21, 0x57, 0x20, 0x58, 0x20, 0x55, 0x20, 0x5A, 0x21, 0x5C, 0x22, 0x5B, 0x20, 0x5A, 0x21, 0x5B, 0x21, 0x59, 0x21, 0x58, 0x20, 0x58, 0x20, 0x55, 0x1F, 0x55, 0x1F, 0x54, 0x1F, 0x53, 0x1F, 0x4A, 0x1E, 0x41, 0x1F, 0x2C, 0x18, 0x31, 0x1B, 0x2F, 0x1A, 0x2A, 0x18, 0x36, 0x1C, 0x2D, 0x19, 0x30, 0x1B, 0x2F, 0x1A, 0x35, 0x1D, 0x2E, 0x1A, 0x3A, 0x21, 0x30, 0x1B, 0x27, 0x18, 0x2E, 0x1A, 0x26, 0x16, 0x2E, 0x1C, 0x3B, 0x20, 0x40, 0x23, 0x45, 0x27, 0x47, 0x28, 0x4D, 0x2A, 0x4A, 0x28, 0x3D, 0x20, 0x2C, 0x19, 0x2D, 0x1A, 0x38, 0x20, 0x4C, 0x2A, 0x53, 0x2D, 0x56, 0x2F, 0x55, 0x2D, 0x54, 0x2E, 0x55, 0x2E, 0x4F, 0x29, 0x2C, 0x1B, 0x35, 0x1C, 0x33, 0x1C, 0x3B, 0x22, 0x54, 0x2E, 0x58, 0x30, 0x57, 0x2F, 0x55, 0x2E, 0x54, 0x2E, 0x52, 0x2C, 0x32, 0x1A
    },

    {
        0x71, 0x7B, 0x72, 0x7B, 0x73, 0x7C, 0x74, 0x7D, 0x75, 0x7F, 0x76, 0x7E, 0x76, 0x7E, 0x77, 0x7F, 0x77, 0x7E, 0x77, 0x7F, 0x78, 0x7E, 0x78, 0x7F, 0x79, 0x7F, 0x79, 0x80, 0x79, 0x80, 0x7A, 0x81, 0x7B, 0x81, 0x7C, 0x82, 0x7B, 0x81, 0x79, 0x81, 0x79, 0x80, 0x74, 0x7C, 0x6B, 0x73, 0x55, 0x5B, 0x37, 0x42, 0x2B, 0x4F, 0x30, 0x67, 0x32, 0x6F, 0x33, 0x72, 0x32, 0x76, 0x33, 0x77, 0x34, 0x78, 0x35, 0x7A, 0x35, 0x7B, 0x36, 0x79, 0x31, 0x6F, 0x2D, 0x5B, 0x2C, 0x5B, 0x3A, 0x79, 0x47, 0x8E, 0x4B, 0x96, 0x4E, 0x9B, 0x50, 0x9F, 0x52, 0xA2, 0x54, 0xA5, 0x56, 0xA8, 0x58, 0xAA, 0x56, 0xA8, 0x57, 0xAA, 0x57, 0xAC, 0x59, 0xAD, 0x58, 0xAD, 0x58, 0xAB, 0x57, 0xAC, 0x57, 0xAB, 0x58, 0xAD, 0x5A, 0xB1, 0x5A, 0xAF, 0x59, 0xAD, 0x58, 0xAC, 0x58, 0xAD, 0x59, 0xAE, 0x58, 0xAE, 0x53, 0x9C, 0x44, 0x76, 0x2D, 0x43, 0x1F, 0x2E, 0x1B, 0x26, 0x18, 0x1F, 0x15, 0x1C, 0x14, 0x1A, 0x15, 0x19, 0x18, 0x1C, 0x24, 0x2F, 0x41, 0x5E, 0x67, 0x8C, 0x78, 0x9C, 0x7E, 0xA4, 0x81, 0xA7, 0x7D, 0x9D, 0x61, 0x72, 0x39, 0x3B, 0x25, 0x29, 0x1E, 0x22, 0x1A, 0x1E, 0x16, 0x1B, 0x15, 0x1A, 0x14, 0x19, 0x15, 0x1B, 0x1C, 0x2F, 0x36, 0x6E, 0x4C, 0x99, 0x53, 0xA4, 0x56, 0xAB, 0x5A, 0xAF, 0x5B, 0xB1, 0x5B, 0xB3, 0x5B, 0xB5, 0x5B, 0xB5, 0x5C, 0xB6, 0x5C, 0xB5, 0x5C, 0xB5, 0x5C, 0xB3, 0x5B, 0xB4, 0x5D, 0xB8, 0x5C, 0xB6, 0x5B, 0xB5, 0x5A, 0xB2, 0x5B, 0xB1, 0x5A, 0xB3, 0x58, 0xAF, 0x51, 0x95, 0x38, 0x57, 0x21, 0x2E, 0x19, 0x21, 0x16, 0x1B, 0x14, 0x19, 0x15, 0x19, 0x15, 0x19, 0x19, 0x1E, 0x23, 0x26, 0x29, 0x2A, 0x28, 0x28, 0x22, 0x21, 0x19, 0x1A, 0x15, 0x17, 0x14, 0x18, 0x13, 0x16, 0x12, 0x16, 0x12, 0x16, 0x14, 0x18, 0x14, 0x1C, 0x19, 0x28, 0x1B, 0x2E, 0x1D, 0x2F, 0x1C, 0x30, 0x1D, 0x2F, 0x1D, 0x31, 0x1E, 0x32, 0x1E, 0x35, 0x1F, 0x33, 0x1E, 0x32, 0x1D, 0x30, 0x1C, 0x30, 0x1D, 0x30, 0x1D, 0x30, 0x1E, 0x32, 0x1D, 0x2F, 0x1D, 0x30, 0x1C, 0x29, 0x16, 0x1C, 0x14, 0x19, 0x13, 0x16, 0x13, 0x17, 0x14, 0x17, 0x14, 0x16, 0x15, 0x17, 0x1C, 0x1D, 0x3B, 0x3F, 0x5B, 0x57, 0x64, 0x5C, 0x55, 0x4A, 0x37, 0x2E, 0x40, 0x41, 0x5F, 0x59, 0x66, 0x5C, 0x6A, 0x5F, 0x6A, 0x5C, 0x69, 0x5C, 0x6C, 0x60, 0x71, 0x65, 0x6D, 0x5F, 0x6A, 0x5E, 0x6C, 0x60, 0x6D, 0x62, 0x6D, 0x61, 0x6C, 0x60, 0x6E, 0x63, 0x6F, 0x61, 0x6D, 0x60, 0x6E, 0x61, 0x6E, 0x60, 0x6D, 0x60, 0x6E, 0x60, 0x6D, 0x5E, 0x6D, 0x5F, 0x6E, 0x61, 0x6D, 0x5F, 0x6C, 0x5F, 0x6B, 0x5C, 0x6C, 0x60, 0x6B, 0x5D, 0x68, 0x5C, 0x69, 0x5C, 0x68, 0x5D, 0x69, 0x5D, 0x6A, 0x5C, 0x66, 0x5A, 0x66, 0x5C, 0x68, 0x5C, 0x69, 0x5D, 0x6C, 0x61, 0x6E, 0x60, 0x6A, 0x5D, 0x69, 0x5C, 0x67, 0x5B, 0x69, 0x5D, 0x6A, 0x5D, 0x69, 0x5B, 0x6A, 0x5E, 0x67, 0x5A, 0x62, 0x57, 0x65, 0x5A, 0x63, 0x56, 0x65, 0x59, 0x67, 0x5B, 0x66, 0x5A, 0x60, 0x57, 0x66, 0x5A, 0x67, 0x5B, 0x65, 0x5A, 0x66, 0x5A, 0x66, 0x58, 0x64, 0x5A, 0x65, 0x59, 0x63, 0x57, 0x64, 0x57, 0x61, 0x56, 0x60, 0x58, 0x62, 0x56, 0x64, 0x57, 0x63, 0x58, 0x63, 0x57, 0x62, 0x57, 0x66, 0x58, 0x63, 0x57, 0x66, 0x59, 0x65, 0x5A, 0x65, 0x5C, 0x67, 0x5C, 0x63, 0x58, 0x65, 0x5A, 0x66, 0x5A, 0x66, 0x5C, 0x63, 0x57, 0x61, 0x56, 0x66, 0x5C, 0x64, 0x59, 0x64, 0x5A, 0x62, 0x59, 0x63, 0x56, 0x64, 0x59, 0x66, 0x5B, 0x62, 0x57, 0x66, 0x5A, 0x63, 0x57, 0x5E, 0x55, 0x60, 0x54, 0x62, 0x57, 0x62, 0x57, 0x63, 0x56, 0x62, 0x56, 0x64, 0x58, 0x66, 0x5A, 0x67, 0x59, 0x65, 0x5A, 0x65, 0x59, 0x63, 0x58, 0x61, 0x55, 0x61, 0x56, 0x5F, 0x53, 0x5D, 0x51, 0x5F, 0x53, 0x60, 0x54, 0x4F, 0x47, 0x3E, 0x3F, 0x27, 0x28, 0x2D, 0x32, 0x2A, 0x2C, 0x25, 0x27, 0x2F, 0x35, 0x26, 0x2D, 0x28, 0x33, 0x25, 0x31, 0x2A, 0x39, 0x23, 0x32, 0x2C, 0x42, 0x26, 0x33, 0x24, 0x2A, 0x29, 0x2D, 0x23, 0x25, 0x26, 0x34, 0x27, 0x42, 0x27, 0x47, 0x29, 0x4C, 0x28, 0x4E, 0x2A, 0x51, 0x29, 0x4F, 0x27, 0x38, 0x25, 0x2D, 0x27, 0x2D, 0x2F, 0x3E, 0x2B, 0x4E, 0x2A, 0x52, 0x2A, 0x54, 0x2A, 0x52, 0x2A, 0x54, 0x2A, 0x52, 0x28, 0x46, 0x1F, 0x29, 0x29, 0x30, 0x2A, 0x30, 0x25, 0x3F, 0x2B, 0x51, 0x2B, 0x54, 0x29, 0x51, 0x28, 0x4F, 0x27, 0x4C, 0x26, 0x4A, 0x1C, 0x27
    },

    {
        0x7E, 0x3D, 0x7E, 0x3D, 0x7F, 0x3D, 0x80, 0x3D, 0x80, 0x3E, 0x81, 0x3E, 0x82, 0x3E, 0x82, 0x3F, 0x83, 0x3F, 0x83, 0x3F, 0x83, 0x3F, 0x83, 0x3F, 0x82, 0x40, 0x83, 0x40, 0x84, 0x40, 0x84, 0x40, 0x84, 0x40, 0x86, 0x41, 0x86, 0x42, 0x84, 0x40, 0x83, 0x41, 0x82, 0x3F, 0x7A, 0x3A, 0x65, 0x31, 0x49, 0x2B, 0x4B, 0x38, 0x64, 0x49, 0x6E, 0x50, 0x73, 0x53, 0x77, 0x56, 0x79, 0x58, 0x7C, 0x5B, 0x7F, 0x5D, 0x81, 0x5D, 0x80, 0x5B, 0x74, 0x51, 0x66, 0x48, 0x6D, 0x50, 0x86, 0x61, 0x91, 0x68, 0x9A, 0x6D, 0xA0, 0x71, 0xA4, 0x76, 0xA8, 0x77, 0xAA, 0x79, 0xAE, 0x7C, 0xB1, 0x7E, 0xB2, 0x7E, 0xB0, 0x7D, 0xB2, 0x7F, 0xB5, 0x80, 0xB4, 0x7E, 0xB2, 0x7E, 0xB1, 0x7D, 0xB1, 0x7E, 0xB3, 0x80, 0xB5, 0x81, 0xB7, 0x81, 0xB3, 0x7E, 0xB3, 0x7F, 0xB4, 0x7F, 0xB2, 0x7E, 0xAD, 0x77, 0x92, 0x5D, 0x5C, 0x39, 0x36, 0x23, 0x2A, 0x1D, 0x23, 0x19, 0x1E, 0x15, 0x1C, 0x14, 0x1B, 0x13, 0x1B, 0x13, 0x24, 0x1E, 0x49, 0x3C, 0x81, 0x5E, 0x9C, 0x6C, 0xA6, 0x73, 0xAD, 0x77, 0xB0, 0x79, 0xB2, 0x78, 0xAA, 0x70, 0x7C, 0x4B, 0x41, 0x29, 0x2A, 0x1C, 0x22, 0x17, 0x21, 0x16, 0x1E, 0x15, 0x1C, 0x13, 0x1B, 0x13, 0x1C, 0x15, 0x2E, 0x29, 0x6B, 0x53, 0x9F, 0x72, 0xAB, 0x79, 0xB1, 0x7E, 0xB5, 0x81, 0xB8, 0x84, 0xBB, 0x85, 0xBB, 0x87, 0xBA, 0x87, 0xBC, 0x86, 0xBB, 0x86, 0xBB, 0x85, 0xBE, 0x87, 0xBD, 0x86, 0xBD, 0x85, 0xBA, 0x83, 0xB8, 0x83, 0xBA, 0x84, 0xBD, 0x85, 0xAE, 0x74, 0x76, 0x4A, 0x3A, 0x27, 0x27, 0x1B, 0x1F, 0x16, 0x1A, 0x12, 0x19, 0x12, 0x19, 0x12, 0x19, 0x12, 0x19, 0x12, 0x1E, 0x16, 0x25, 0x19, 0x23, 0x17, 0x1C, 0x13, 0x19, 0x11, 0x18, 0x11, 0x18, 0x10, 0x17, 0x10, 0x16, 0x10, 0x17, 0x10, 0x18, 0x11, 0x18, 0x11, 0x1C, 0x16, 0x27, 0x1E, 0x2E, 0x22, 0x30, 0x23, 0x33, 0x24, 0x31, 0x25, 0x34, 0x26, 0x34, 0x26, 0x34, 0x27, 0x33, 0x26, 0x30, 0x24, 0x31, 0x24, 0x31, 0x24, 0x32, 0x25, 0x32, 0x25, 0x31, 0x25, 0x2F, 0x20, 0x21, 0x16, 0x19, 0x12, 0x19, 0x10, 0x17, 0x10, 0x17, 0x10, 0x18, 0x10, 0x16, 0x0F, 0x19, 0x11, 0x31, 0x18, 0x52, 0x1F, 0x5C, 0x22, 0x56, 0x1F, 0x37, 0x1A, 0x33, 0x19, 0x50, 0x1F, 0x5D, 0x22, 0x61, 0x22, 0x61, 0x23, 0x5D, 0x21, 0x60, 0x22, 0x63, 0x23, 0x65, 0x23, 0x61, 0x23, 0x61, 0x23, 0x62, 0x23, 0x62, 0x22, 0x5F, 0x22, 0x5D, 0x21, 0x65, 0x25, 0x62, 0x23, 0x60, 0x23, 0x63, 0x22, 0x63, 0x22, 0x64, 0x22, 0x61, 0x21, 0x60, 0x22, 0x62, 0x22, 0x60, 0x21, 0x61, 0x23, 0x60, 0x22, 0x61, 0x22, 0x5B, 0x21, 0x5D, 0x22, 0x61, 0x22, 0x5F, 0x22, 0x61, 0x23, 0x61, 0x24, 0x63, 0x24, 0x5C, 0x21, 0x5B, 0x21, 0x5D, 0x22, 0x5F, 0x22, 0x62, 0x22, 0x60, 0x21, 0x5D, 0x22, 0x5E, 0x22, 0x5F, 0x22, 0x5D, 0x22, 0x5E, 0x21, 0x60, 0x21, 0x5E, 0x22, 0x5C, 0x22, 0x5A, 0x20, 0x57, 0x1F, 0x5A, 0x20, 0x5B, 0x20, 0x5B, 0x21, 0x5B, 0x20, 0x5B, 0x21, 0x5A, 0x20, 0x5B, 0x21, 0x59, 0x20, 0x57, 0x20, 0x5A, 0x21, 0x5B, 0x22, 0x5B, 0x21, 0x59, 0x1F, 0x57, 0x1F, 0x59, 0x20, 0x59, 0x20, 0x57, 0x1F, 0x5B, 0x20, 0x59, 0x1F, 0x5B, 0x20, 0x58, 0x20, 0x5A, 0x20, 0x57, 0x20, 0x58, 0x20, 0x57, 0x20, 0x5E, 0x23, 0x5C, 0x20, 0x5B, 0x21, 0x5C, 0x21, 0x5B, 0x22, 0x5B, 0x22, 0x5B, 0x22, 0x5C, 0x22, 0x5C, 0x22, 0x5D, 0x22, 0x5C, 0x23, 0x59, 0x21, 0x5A, 0x21, 0x5C, 0x22, 0x5D, 0x21, 0x57, 0x20, 0x5A, 0x20, 0x59, 0x20, 0x56, 0x20, 0x55, 0x20, 0x58, 0x20, 0x58, 0x20, 0x5B, 0x22, 0x57, 0x20, 0x57, 0x1F, 0x57, 0x20, 0x59, 0x20, 0x59, 0x20, 0x57, 0x20, 0x58, 0x21, 0x58, 0x20, 0x59, 0x21, 0x55, 0x1F, 0x56, 0x20, 0x56, 0x20, 0x54, 0x1E, 0x4D, 0x20, 0x3C, 0x1E, 0x29, 0x18, 0x35, 0x1D, 0x28, 0x18, 0x2C, 0x1A, 0x37, 0x1E, 0x49, 0x29, 0x55, 0x2E, 0x55, 0x2D, 0x56, 0x2F, 0x57, 0x2F, 0x59, 0x31, 0x50, 0x29, 0x38, 0x1F, 0x2F, 0x1A, 0x33, 0x1B, 0x37, 0x20, 0x51, 0x2C, 0x55, 0x2F, 0x56, 0x2F, 0x56, 0x2F, 0x57, 0x2F, 0x55, 0x2D, 0x36, 0x1C, 0x29, 0x1A, 0x3A, 0x1E, 0x38, 0x1F, 0x4D, 0x2A, 0x51, 0x2C, 0x4E, 0x2B, 0x4D, 0x2A, 0x49, 0x29, 0x46, 0x27, 0x3A, 0x20, 0x1E, 0x13, 0x25, 0x17, 0x29, 0x18, 0x34, 0x1F, 0x39, 0x21, 0x33, 0x1E, 0x2E, 0x1B, 0x2A, 0x19, 0x28, 0x19, 0x23, 0x16, 0x1F, 0x14
    },

    {
        0x71, 0x79, 0x73, 0x7A, 0x74, 0x7C, 0x74, 0x7D, 0x75, 0x7E, 0x76, 0x7D, 0x76, 0x7E, 0x78, 0x7F, 0x78, 0x80, 0x78, 0x7F, 0x79, 0x80, 0x79, 0x80, 0x79, 0x81, 0x79, 0x80, 0x7A, 0x80, 0x7A, 0x81, 0x7B, 0x82, 0x7C, 0x82, 0x7D, 0x83, 0x7B, 0x81, 0x79, 0x80, 0x73, 0x7D, 0x6B, 0x73, 0x57, 0x5C, 0x3A, 0x40, 0x2A, 0x48, 0x2E, 0x5F, 0x30, 0x6B, 0x32, 0x6F, 0x32, 0x73, 0x33, 0x74, 0x34, 0x78, 0x35, 0x7B, 0x36, 0x7C, 0x36, 0x78, 0x30, 0x6B, 0x2C, 0x59, 0x31, 0x68, 0x40, 0x84, 0x48, 0x8F, 0x4B, 0x94, 0x4E, 0x9B, 0x50, 0x9F, 0x53, 0xA2, 0x54, 0xA4, 0x54, 0xA7, 0x57, 0xAB, 0x58, 0xAA, 0x57, 0xA9, 0x57, 0xAB, 0x59, 0xAE, 0x59, 0xAD, 0x59, 0xAB, 0x58, 0xAC, 0x57, 0xAB, 0x59, 0xAF, 0x5A, 0xAF, 0x5B, 0xB1, 0x5A, 0xAE, 0x58, 0xAC, 0x5A, 0xAE, 0x57, 0xAC, 0x54, 0x9F, 0x46, 0x7A, 0x2F, 0x47, 0x21, 0x2E, 0x1B, 0x26, 0x19, 0x21, 0x16, 0x1C, 0x15, 0x1B, 0x15, 0x1A, 0x18, 0x1B, 0x23, 0x2D, 0x3E, 0x5D, 0x67, 0x8C, 0x78, 0x9C, 0x7F, 0xA4, 0x84, 0xAB, 0x87, 0xAA, 0x87, 0xAC, 0x81, 0xA5, 0x6B, 0x7F, 0x40, 0x44, 0x27, 0x2A, 0x1E, 0x23, 0x1B, 0x20, 0x18, 0x1D, 0x17, 0x1B, 0x15, 0x1A, 0x15, 0x1B, 0x1B, 0x2A, 0x30, 0x62, 0x4A, 0x97, 0x53, 0xA3, 0x57, 0xAA, 0x58, 0xAF, 0x5A, 0xB2, 0x5C, 0xB5, 0x5C, 0xB5, 0x5B, 0xB5, 0x5C, 0xB5, 0x5C, 0xB5, 0x5B, 0xB4, 0x5C, 0xB6, 0x5D, 0xB6, 0x5C, 0xB4, 0x5B, 0xB0, 0x5B, 0xB1, 0x5B, 0xB2, 0x5C, 0xB5, 0x53, 0x9A, 0x39, 0x58, 0x22, 0x2E, 0x1A, 0x23, 0x17, 0x1C, 0x14, 0x18, 0x14, 0x18, 0x15, 0x19, 0x14, 0x18, 0x15, 0x18, 0x18, 0x1C, 0x20, 0x22, 0x1F, 0x1F, 0x17, 0x19, 0x15, 0x18, 0x14, 0x17, 0x14, 0x17, 0x12, 0x15, 0x12, 0x16, 0x12, 0x16, 0x13, 0x17, 0x13, 0x18, 0x14, 0x1A, 0x18, 0x26, 0x1B, 0x2D, 0x1C, 0x2E, 0x1E, 0x30, 0x1C, 0x30, 0x1E, 0x31, 0x1D, 0x32, 0x1E, 0x32, 0x1E, 0x32, 0x1D, 0x2F, 0x1D, 0x30, 0x1D, 0x30, 0x1D, 0x30, 0x1E, 0x30, 0x1D, 0x30, 0x1C, 0x29, 0x16, 0x1C, 0x14, 0x18, 0x13, 0x17, 0x13, 0x17, 0x14, 0x17, 0x14, 0x17, 0x15, 0x16, 0x1C, 0x1C, 0x3A, 0x3F, 0x5A, 0x56, 0x60, 0x5A, 0x52, 0x49, 0x36, 0x2E, 0x3D, 0x3D, 0x5A, 0x56, 0x65, 0x5C, 0x69, 0x5E, 0x6C, 0x5F, 0x69, 0x5B, 0x6D, 0x5F, 0x70, 0x62, 0x71, 0x63, 0x6C, 0x5F, 0x6C, 0x5F, 0x6D, 0x61, 0x6B, 0x5E, 0x6A, 0x5E, 0x68, 0x5C, 0x70, 0x63, 0x6D, 0x60, 0x6D, 0x60, 0x70, 0x60, 0x70, 0x61, 0x71, 0x61, 0x6E, 0x5F, 0x6C, 0x60, 0x70, 0x60, 0x6C, 0x5E, 0x6E, 0x60, 0x6D, 0x60, 0x6C, 0x5F, 0x67, 0x59, 0x69, 0x5C, 0x6C, 0x5F, 0x6B, 0x5D, 0x6C, 0x61, 0x6E, 0x61, 0x6F, 0x64, 0x68, 0x5B, 0x66, 0x58, 0x67, 0x5D, 0x69, 0x5D, 0x6D, 0x5F, 0x6A, 0x5E, 0x69, 0x5D, 0x6A, 0x5C, 0x6B, 0x5D, 0x68, 0x5B, 0x6B, 0x5D, 0x6E, 0x5F, 0x6B, 0x5F, 0x69, 0x5C, 0x64, 0x58, 0x62, 0x57, 0x64, 0x59, 0x69, 0x59, 0x68, 0x5A, 0x67, 0x59, 0x66, 0x59, 0x65, 0x58, 0x65, 0x5A, 0x63, 0x57, 0x62, 0x56, 0x64, 0x59, 0x65, 0x5B, 0x65, 0x59, 0x66, 0x58, 0x61, 0x56, 0x65, 0x59, 0x63, 0x58, 0x62, 0x56, 0x66, 0x59, 0x63, 0x58, 0x67, 0x59, 0x63, 0x56, 0x63, 0x58, 0x63, 0x58, 0x65, 0x58, 0x63, 0x55, 0x66, 0x5A, 0x66, 0x59, 0x63, 0x58, 0x65, 0x5A, 0x64, 0x5A, 0x64, 0x5A, 0x65, 0x5C, 0x65, 0x5C, 0x65, 0x5A, 0x68, 0x5C, 0x65, 0x5A, 0x63, 0x58, 0x63, 0x57, 0x65, 0x59, 0x64, 0x59, 0x60, 0x56, 0x65, 0x59, 0x62, 0x57, 0x5F, 0x55, 0x60, 0x56, 0x65, 0x58, 0x62, 0x57, 0x65, 0x59, 0x64, 0x57, 0x62, 0x56, 0x63, 0x55, 0x63, 0x57, 0x62, 0x55, 0x61, 0x56, 0x62, 0x55, 0x62, 0x57, 0x64, 0x59, 0x61, 0x54, 0x61, 0x55, 0x60, 0x55, 0x5F, 0x53, 0x50, 0x47, 0x37, 0x35, 0x28, 0x29, 0x2F, 0x33, 0x27, 0x29, 0x2B, 0x33, 0x2C, 0x38, 0x2B, 0x50, 0x2E, 0x58, 0x2D, 0x58, 0x2D, 0x58, 0x2D, 0x57, 0x2C, 0x58, 0x2C, 0x48, 0x29, 0x32, 0x29, 0x2F, 0x2D, 0x31, 0x28, 0x3D, 0x2A, 0x4F, 0x2A, 0x53, 0x2A, 0x53, 0x2B, 0x53, 0x2B, 0x53, 0x2A, 0x50, 0x1F, 0x2A, 0x22, 0x2D, 0x2F, 0x38, 0x2A, 0x36, 0x2A, 0x4A, 0x27, 0x47, 0x25, 0x44, 0x24, 0x41, 0x22, 0x3D, 0x21, 0x3A, 0x1D, 0x2C, 0x16, 0x1B, 0x23, 0x2A, 0x24, 0x27, 0x27, 0x35, 0x22, 0x2E, 0x1C, 0x27, 0x19, 0x23, 0x1A, 0x23, 0x19, 0x20, 0x18, 0x1E, 0x18, 0x1D
    },

    {
        0x7B, 0x3B, 0x7B, 0x3C, 0x7E, 0x3D, 0x80, 0x3D, 0x81, 0x3E, 0x81, 0x3E, 0x82, 0x3F, 0x84, 0x3F, 0x83, 0x3F, 0x82, 0x3F, 0x83, 0x3F, 0x83, 0x3F, 0x83, 0x40, 0x83, 0x40, 0x82, 0x40, 0x84, 0x40, 0x84, 0x40, 0x86, 0x41, 0x87, 0x41, 0x84, 0x40, 0x82, 0x3F, 0x7C, 0x3B, 0x6C, 0x33, 0x4D, 0x26, 0x2F, 0x1C, 0x2C, 0x21, 0x43, 0x36, 0x61, 0x48, 0x6D, 0x4F, 0x74, 0x54, 0x76, 0x57, 0x7D, 0x5B, 0x81, 0x5D, 0x80, 0x5B, 0x75, 0x52, 0x5D, 0x3D, 0x3E, 0x2A, 0x3E, 0x33, 0x68, 0x4F, 0x8B, 0x64, 0x98, 0x6D, 0x9E, 0x70, 0xA1, 0x73, 0xA4, 0x75, 0xA8, 0x78, 0xAC, 0x79, 0xAF, 0x7C, 0xB0, 0x7C, 0xB2, 0x7E, 0xB2, 0x7E, 0xB2, 0x7F, 0xB3, 0x7E, 0xB2, 0x7E, 0xB3, 0x7E, 0xB2, 0x7F, 0xB4, 0x81, 0xB9, 0x83, 0xB8, 0x82, 0xB6, 0x81, 0xB4, 0x80, 0xB3, 0x7F, 0xAD, 0x76, 0x92, 0x5E, 0x60, 0x3B, 0x39, 0x25, 0x2B, 0x1D, 0x25, 0x19, 0x20, 0x17, 0x1D, 0x14, 0x1B, 0x13, 0x1B, 0x14, 0x23, 0x1C, 0x45, 0x39, 0x7F, 0x5C, 0x9D, 0x6C, 0xA6, 0x73, 0xAD, 0x77, 0xAF, 0x78, 0xB1, 0x7A, 0xB0, 0x78, 0xB1, 0x79, 0xAE, 0x74, 0x88, 0x53, 0x47, 0x2C, 0x2B, 0x1D, 0x24, 0x18, 0x1F, 0x16, 0x1D, 0x15, 0x1C, 0x13, 0x1A, 0x13, 0x1B, 0x14, 0x28, 0x24, 0x5D, 0x4D, 0x9C, 0x6F, 0xAC, 0x7A, 0xB5, 0x82, 0xBB, 0x84, 0xBA, 0x84, 0xBF, 0x86, 0xBD, 0x87, 0xBC, 0x85, 0xB9, 0x85, 0xB8, 0x83, 0xBA, 0x85, 0xB8, 0x84, 0xBC, 0x86, 0xBB, 0x84, 0xB8, 0x84, 0xB6, 0x81, 0xAD, 0x76, 0x7C, 0x4E, 0x3E, 0x28, 0x29, 0x1C, 0x21, 0x17, 0x1C, 0x13, 0x19, 0x12, 0x19, 0x12, 0x19, 0x12, 0x19, 0x11, 0x1A, 0x12, 0x1A, 0x12, 0x1A, 0x13, 0x1A, 0x13, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x17, 0x10, 0x17, 0x10, 0x16, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x11, 0x19, 0x11, 0x1A, 0x14, 0x25, 0x1C, 0x2D, 0x22, 0x30, 0x23, 0x32, 0x23, 0x33, 0x25, 0x32, 0x25, 0x34, 0x25, 0x33, 0x26, 0x32, 0x25, 0x32, 0x24, 0x31, 0x23, 0x32, 0x25, 0x33, 0x25, 0x30, 0x21, 0x23, 0x17, 0x1A, 0x12, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x18, 0x10, 0x18, 0x10, 0x2D, 0x17, 0x4E, 0x1E, 0x5E, 0x22, 0x59, 0x21, 0x39, 0x19, 0x32, 0x1A, 0x51, 0x1F, 0x5B, 0x22, 0x62, 0x23, 0x63, 0x23, 0x61, 0x23, 0x5F, 0x21, 0x5B, 0x21, 0x60, 0x22, 0x62, 0x23, 0x60, 0x22, 0x60, 0x22, 0x62, 0x23, 0x5F, 0x23, 0x5F, 0x22, 0x5C, 0x21, 0x60, 0x22, 0x60, 0x22, 0x60, 0x22, 0x5F, 0x21, 0x5D, 0x21, 0x5E, 0x21, 0x60, 0x22, 0x60, 0x22, 0x5F, 0x21, 0x5F, 0x22, 0x66, 0x25, 0x62, 0x23, 0x60, 0x22, 0x5D, 0x21, 0x5F, 0x21, 0x61, 0x23, 0x61, 0x22, 0x61, 0x22, 0x64, 0x23, 0x62, 0x24, 0x5F, 0x22, 0x5E, 0x22, 0x60, 0x22, 0x62, 0x22, 0x61, 0x21, 0x60, 0x22, 0x5F, 0x22, 0x5E, 0x21, 0x5B, 0x21, 0x5D, 0x21, 0x5D, 0x21, 0x5E, 0x21, 0x5C, 0x21, 0x60, 0x23, 0x5C, 0x21, 0x5A, 0x21, 0x59, 0x20, 0x59, 0x20, 0x59, 0x21, 0x5A, 0x20, 0x57, 0x1F, 0x57, 0x20, 0x5D, 0x21, 0x58, 0x20, 0x5A, 0x22, 0x5A, 0x21, 0x5B, 0x21, 0x5E, 0x22, 0x5F, 0x22, 0x5A, 0x21, 0x5B, 0x20, 0x58, 0x1F, 0x55, 0x1F, 0x59, 0x20, 0x58, 0x20, 0x59, 0x20, 0x59, 0x20, 0x58, 0x20, 0x5A, 0x20, 0x59, 0x20, 0x58, 0x20, 0x5A, 0x21, 0x5A, 0x21, 0x5B, 0x21, 0x5A, 0x20, 0x5E, 0x22, 0x5E, 0x23, 0x5C, 0x22, 0x5D, 0x22, 0x5C, 0x21, 0x5B, 0x20, 0x58, 0x22, 0x59, 0x21, 0x59, 0x21, 0x56, 0x20, 0x58, 0x21, 0x57, 0x21, 0x5A, 0x20, 0x59, 0x20, 0x58, 0x1F, 0x56, 0x1F, 0x59, 0x20, 0x57, 0x1F, 0x59, 0x20, 0x56, 0x1F, 0x58, 0x20, 0x53, 0x1F, 0x53, 0x1F, 0x54, 0x1F, 0x56, 0x20, 0x58, 0x20, 0x59, 0x20, 0x5A, 0x20, 0x56, 0x1F, 0x55, 0x20, 0x57, 0x20, 0x57, 0x21, 0x4B, 0x1F, 0x37, 0x1C, 0x2D, 0x18, 0x35, 0x1D, 0x39, 0x1E, 0x37, 0x1C, 0x30, 0x1D, 0x52, 0x2D, 0x59, 0x2F, 0x5B, 0x31, 0x5D, 0x32, 0x5D, 0x32, 0x5B, 0x31, 0x43, 0x23, 0x21, 0x15, 0x2D, 0x1A, 0x2D, 0x19, 0x3B, 0x22, 0x44, 0x26, 0x40, 0x25, 0x3F, 0x24, 0x3B, 0x22, 0x36, 0x1F, 0x32, 0x1E, 0x23, 0x16, 0x25, 0x17, 0x2E, 0x19, 0x28, 0x18, 0x35, 0x1B, 0x25, 0x18, 0x20, 0x15, 0x1F, 0x15, 0x1E, 0x14, 0x1D, 0x13, 0x1D, 0x12, 0x1F, 0x14, 0x33, 0x1C, 0x32, 0x1B, 0x35, 0x1E, 0x2C, 0x19, 0x25, 0x16, 0x24, 0x16, 0x2A, 0x18, 0x2A, 0x17, 0x2D, 0x1A, 0x2B, 0x17
    },

    {
        0x6E, 0x77, 0x6F, 0x79, 0x72, 0x7B, 0x74, 0x7D, 0x74, 0x7E, 0x76, 0x7E, 0x77, 0x7E, 0x78, 0x7E, 0x78, 0x80, 0x78, 0x80, 0x79, 0x80, 0x79, 0x80, 0x79, 0x80, 0x79, 0x81, 0x79, 0x7F, 0x7A, 0x81, 0x7B, 0x81, 0x7D, 0x82, 0x7C, 0x82, 0x79, 0x81, 0x76, 0x7E, 0x6C, 0x73, 0x5D, 0x60, 0x40, 0x3F, 0x27, 0x29, 0x1E, 0x29, 0x22, 0x3E, 0x2A, 0x5B, 0x2F, 0x69, 0x31, 0x6E, 0x32, 0x74, 0x34, 0x7A, 0x36, 0x7C, 0x35, 0x79, 0x32, 0x6C, 0x28, 0x4D, 0x1F, 0x31, 0x20, 0x38, 0x2F, 0x60, 0x42, 0x86, 0x49, 0x94, 0x4B, 0x97, 0x4E, 0x9B, 0x51, 0x9F, 0x53, 0xA2, 0x54, 0xA5, 0x56, 0xA8, 0x57, 0xAA, 0x58, 0xAA, 0x58, 0xAC, 0x59, 0xAD, 0x59, 0xAD, 0x57, 0xAB, 0x57, 0xAB, 0x57, 0xAB, 0x58, 0xAE, 0x5B, 0xB3, 0x5B, 0xB1, 0x5A, 0xB0, 0x59, 0xAC, 0x57, 0xAB, 0x53, 0x9E, 0x46, 0x7B, 0x31, 0x4A, 0x21, 0x30, 0x1C, 0x27, 0x19, 0x22, 0x17, 0x1E, 0x15, 0x1B, 0x16, 0x1B, 0x18, 0x1C, 0x22, 0x2B, 0x3B, 0x57, 0x65, 0x8B, 0x78, 0x9B, 0x7E, 0xA3, 0x84, 0xA9, 0x87, 0xAB, 0x89, 0xAE, 0x89, 0xAD, 0x89, 0xAD, 0x84, 0xA9, 0x71, 0x89, 0x44, 0x49, 0x28, 0x2C, 0x20, 0x23, 0x1B, 0x1F, 0x18, 0x1C, 0x16, 0x1B, 0x15, 0x19, 0x15, 0x1A, 0x19, 0x26, 0x2C, 0x55, 0x48, 0x93, 0x54, 0xA5, 0x58, 0xAE, 0x5A, 0xB3, 0x5B, 0xB3, 0x5C, 0xB5, 0x5B, 0xB5, 0x5B, 0xB3, 0x5B, 0xB2, 0x5A, 0xB0, 0x5C, 0xB2, 0x5A, 0xB2, 0x5B, 0xB2, 0x5B, 0xB2, 0x5A, 0xB2, 0x59, 0xAC, 0x52, 0x9B, 0x3B, 0x5F, 0x23, 0x30, 0x1B, 0x24, 0x17, 0x1D, 0x15, 0x19, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x14, 0x19, 0x14, 0x19, 0x15, 0x19, 0x16, 0x18, 0x16, 0x18, 0x14, 0x17, 0x13, 0x16, 0x13, 0x17, 0x12, 0x16, 0x12, 0x15, 0x12, 0x16, 0x12, 0x16, 0x13, 0x16, 0x13, 0x18, 0x13, 0x17, 0x14, 0x19, 0x16, 0x22, 0x1B, 0x2C, 0x1C, 0x2E, 0x1D, 0x2F, 0x1D, 0x32, 0x1D, 0x32, 0x1F, 0x32, 0x1E, 0x32, 0x1D, 0x31, 0x1E, 0x31, 0x1D, 0x2E, 0x1D, 0x31, 0x1E, 0x30, 0x1C, 0x2A, 0x17, 0x1D, 0x14, 0x17, 0x13, 0x16, 0x13, 0x16, 0x14, 0x17, 0x14, 0x16, 0x15, 0x17, 0x1A, 0x1B, 0x37, 0x3A, 0x57, 0x53, 0x63, 0x5E, 0x59, 0x4E, 0x37, 0x2F, 0x3B, 0x3C, 0x5B, 0x55, 0x65, 0x5C, 0x6C, 0x62, 0x6D, 0x61, 0x6A, 0x5E, 0x6A, 0x5C, 0x67, 0x59, 0x6A, 0x5F, 0x6C, 0x5F, 0x6A, 0x5E, 0x6C, 0x60, 0x6B, 0x60, 0x6B, 0x5E, 0x6A, 0x5E, 0x65, 0x5B, 0x6B, 0x5F, 0x6B, 0x5D, 0x6D, 0x5E, 0x6B, 0x5D, 0x68, 0x5A, 0x6A, 0x5D, 0x6D, 0x5E, 0x6D, 0x5F, 0x6C, 0x5D, 0x6D, 0x5E, 0x72, 0x65, 0x6B, 0x5F, 0x69, 0x5E, 0x68, 0x5C, 0x6B, 0x5F, 0x6C, 0x61, 0x6D, 0x60, 0x6C, 0x5F, 0x6F, 0x62, 0x6B, 0x5E, 0x6B, 0x5F, 0x6A, 0x5D, 0x6E, 0x61, 0x6D, 0x60, 0x6D, 0x5E, 0x6B, 0x5E, 0x6B, 0x5F, 0x6A, 0x5D, 0x68, 0x5A, 0x6A, 0x5C, 0x6A, 0x5E, 0x6A, 0x5C, 0x68, 0x5A, 0x6A, 0x5E, 0x67, 0x5B, 0x65, 0x5B, 0x65, 0x58, 0x65, 0x57, 0x64, 0x58, 0x64, 0x57, 0x64, 0x55, 0x64, 0x58, 0x66, 0x5A, 0x64, 0x58, 0x65, 0x59, 0x62, 0x56, 0x67, 0x5A, 0x6B, 0x5D, 0x68, 0x5D, 0x65, 0x59, 0x65, 0x58, 0x63, 0x57, 0x60, 0x54, 0x63, 0x58, 0x63, 0x57, 0x64, 0x58, 0x64, 0x57, 0x61, 0x57, 0x62, 0x57, 0x64, 0x57, 0x63, 0x59, 0x66, 0x5A, 0x64, 0x5A, 0x66, 0x5A, 0x64, 0x59, 0x66, 0x5B, 0x68, 0x5D, 0x67, 0x59, 0x67, 0x5A, 0x64, 0x5B, 0x64, 0x57, 0x61, 0x58, 0x64, 0x58, 0x62, 0x57, 0x60, 0x55, 0x63, 0x5A, 0x63, 0x58, 0x64, 0x57, 0x63, 0x58, 0x61, 0x56, 0x61, 0x55, 0x62, 0x57, 0x60, 0x55, 0x63, 0x57, 0x60, 0x54, 0x62, 0x58, 0x5C, 0x51, 0x5D, 0x53, 0x5E, 0x53, 0x63, 0x57, 0x63, 0x57, 0x64, 0x57, 0x65, 0x58, 0x63, 0x57, 0x60, 0x54, 0x60, 0x55, 0x60, 0x55, 0x4E, 0x45, 0x35, 0x36, 0x29, 0x2A, 0x2F, 0x37, 0x32, 0x38, 0x2C, 0x2D, 0x26, 0x36, 0x2C, 0x52, 0x2C, 0x55, 0x2C, 0x58, 0x2C, 0x56, 0x2D, 0x57, 0x2C, 0x52, 0x22, 0x36, 0x1A, 0x20, 0x29, 0x2E, 0x27, 0x2B, 0x2B, 0x3C, 0x25, 0x3B, 0x20, 0x35, 0x1F, 0x31, 0x1D, 0x2F, 0x1C, 0x2B, 0x1A, 0x26, 0x18, 0x1E, 0x21, 0x27, 0x28, 0x2D, 0x24, 0x2A, 0x29, 0x2F, 0x1C, 0x20, 0x1A, 0x1D, 0x18, 0x1E, 0x1A, 0x20, 0x18, 0x1C, 0x1D, 0x22, 0x20, 0x25, 0x2D, 0x34, 0x2B, 0x30, 0x2A, 0x31, 0x27, 0x2A, 0x21, 0x24, 0x21, 0x28, 0x27, 0x2E, 0x26, 0x29, 0x2B, 0x31, 0x27, 0x2B
    },

    {
        0x78, 0x3A, 0x7B, 0x3B, 0x7E, 0x3D, 0x7E, 0x3C, 0x7F, 0x3D, 0x81, 0x3E, 0x81, 0x3E, 0x81, 0x3E, 0x82, 0x3F, 0x82, 0x3F, 0x83, 0x40, 0x83, 0x40, 0x84, 0x40, 0x83, 0x40, 0x83, 0x40, 0x83, 0x3F, 0x84, 0x40, 0x84, 0x41, 0x86, 0x41, 0x83, 0x3F, 0x7C, 0x3B, 0x6D, 0x34, 0x52, 0x28, 0x32, 0x1C, 0x26, 0x17, 0x22, 0x16, 0x26, 0x1E, 0x3D, 0x32, 0x60, 0x47, 0x6F, 0x51, 0x75, 0x57, 0x7A, 0x5A, 0x7D, 0x5B, 0x78, 0x53, 0x60, 0x40, 0x3D, 0x27, 0x29, 0x1D, 0x27, 0x1D, 0x33, 0x2A, 0x5C, 0x48, 0x87, 0x62, 0x99, 0x6B, 0x9E, 0x70, 0xA4, 0x74, 0xA6, 0x76, 0xAA, 0x79, 0xAD, 0x7C, 0xB0, 0x7D, 0xB3, 0x7D, 0xB2, 0x7E, 0xB4, 0x7E, 0xB2, 0x7F, 0xB1, 0x7E, 0xB2, 0x7E, 0xB3, 0x7F, 0xB5, 0x80, 0xB7, 0x82, 0xB8, 0x83, 0xB7, 0x81, 0xB5, 0x80, 0xAB, 0x77, 0x95, 0x61, 0x64, 0x3D, 0x38, 0x26, 0x2C, 0x1E, 0x25, 0x1A, 0x21, 0x17, 0x1E, 0x15, 0x1B, 0x14, 0x1C, 0x14, 0x22, 0x1C, 0x41, 0x37, 0x7B, 0x5B, 0x9C, 0x6C, 0xA6, 0x73, 0xAB, 0x75, 0xAF, 0x7A, 0xB5, 0x7C, 0xB5, 0x7C, 0xB4, 0x7C, 0xB5, 0x7B, 0xB4, 0x7B, 0xAE, 0x74, 0x8F, 0x59, 0x4D, 0x30, 0x2E, 0x1E, 0x24, 0x19, 0x21, 0x17, 0x1E, 0x14, 0x1B, 0x13, 0x1B, 0x13, 0x1D, 0x15, 0x26, 0x20, 0x54, 0x47, 0x97, 0x6D, 0xA7, 0x79, 0xB2, 0x7F, 0xB7, 0x82, 0xB9, 0x84, 0xBA, 0x85, 0xBB, 0x86, 0xBC, 0x86, 0xBD, 0x87, 0xBB, 0x85, 0xB9, 0x84, 0xB9, 0x84, 0xBA, 0x83, 0xB9, 0x84, 0xB0, 0x78, 0x7D, 0x4F, 0x41, 0x2A, 0x28, 0x1C, 0x22, 0x18, 0x1D, 0x14, 0x1B, 0x13, 0x1A, 0x12, 0x1A, 0x12, 0x1A, 0x12, 0x1A, 0x12, 0x19, 0x12, 0x1A, 0x11, 0x18, 0x11, 0x18, 0x11, 0x17, 0x11, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x16, 0x0F, 0x16, 0x10, 0x16, 0x10, 0x17, 0x10, 0x18, 0x11, 0x18, 0x10, 0x17, 0x11, 0x19, 0x13, 0x23, 0x1B, 0x2E, 0x22, 0x2F, 0x24, 0x32, 0x24, 0x35, 0x25, 0x33, 0x26, 0x31, 0x24, 0x32, 0x24, 0x32, 0x25, 0x32, 0x25, 0x31, 0x24, 0x30, 0x22, 0x24, 0x18, 0x1B, 0x12, 0x18, 0x10, 0x17, 0x10, 0x17, 0x10, 0x18, 0x10, 0x17, 0x10, 0x18, 0x11, 0x2B, 0x17, 0x50, 0x1F, 0x5B, 0x21, 0x59, 0x21, 0x3B, 0x1A, 0x35, 0x1B, 0x51, 0x21, 0x5D, 0x22, 0x60, 0x22, 0x63, 0x23, 0x61, 0x23, 0x60, 0x22, 0x5F, 0x22, 0x60, 0x23, 0x5F, 0x23, 0x62, 0x22, 0x5D, 0x22, 0x64, 0x22, 0x60, 0x23, 0x63, 0x23, 0x60, 0x22, 0x5F, 0x21, 0x5F, 0x22, 0x5C, 0x22, 0x5F, 0x21, 0x60, 0x22, 0x5E, 0x21, 0x62, 0x23, 0x62, 0x23, 0x61, 0x21, 0x5E, 0x21, 0x61, 0x23, 0x65, 0x24, 0x63, 0x23, 0x60, 0x22, 0x5E, 0x21, 0x5F, 0x22, 0x61, 0x23, 0x61, 0x23, 0x5F, 0x23, 0x62, 0x23, 0x5F, 0x23, 0x62, 0x24, 0x61, 0x23, 0x5F, 0x23, 0x61, 0x23, 0x5F, 0x22, 0x5C, 0x20, 0x5E, 0x22, 0x60, 0x22, 0x5D, 0x22, 0x60, 0x22, 0x60, 0x22, 0x5B, 0x1F, 0x59, 0x20, 0x5C, 0x22, 0x5D, 0x21, 0x63, 0x25, 0x5E, 0x21, 0x5B, 0x21, 0x5C, 0x20, 0x59, 0x20, 0x5A, 0x20, 0x5B, 0x20, 0x5D, 0x22, 0x5D, 0x22, 0x5B, 0x20, 0x5B, 0x21, 0x59, 0x20, 0x5C, 0x21, 0x5C, 0x20, 0x5B, 0x21, 0x5C, 0x20, 0x59, 0x20, 0x5A, 0x21, 0x58, 0x1F, 0x59, 0x20, 0x58, 0x1F, 0x56, 0x1F, 0x59, 0x20, 0x5A, 0x21, 0x5A, 0x20, 0x5B, 0x21, 0x5B, 0x20, 0x58, 0x20, 0x5A, 0x21, 0x59, 0x21, 0x58, 0x21, 0x5B, 0x21, 0x5A, 0x21, 0x5A, 0x20, 0x59, 0x20, 0x5A, 0x21, 0x5C, 0x23, 0x5C, 0x22, 0x5D, 0x22, 0x60, 0x24, 0x5D, 0x22, 0x59, 0x21, 0x5A, 0x21, 0x59, 0x20, 0x56, 0x1F, 0x56, 0x1F, 0x58, 0x20, 0x56, 0x1F, 0x56, 0x1F, 0x55, 0x1F, 0x57, 0x20, 0x54, 0x1F, 0x55, 0x1F, 0x57, 0x1F, 0x59, 0x20, 0x58, 0x21, 0x58, 0x20, 0x57, 0x20, 0x59, 0x20, 0x55, 0x1F, 0x55, 0x1F, 0x56, 0x1F, 0x45, 0x1C, 0x34, 0x1B, 0x2C, 0x19, 0x32, 0x1C, 0x2D, 0x19, 0x25, 0x17, 0x34, 0x1D, 0x39, 0x20, 0x37, 0x20, 0x34, 0x1E, 0x30, 0x1D, 0x2D, 0x1C, 0x29, 0x1A, 0x21, 0x16, 0x1E, 0x14, 0x2D, 0x1A, 0x2F, 0x1B, 0x37, 0x1D, 0x2A, 0x18, 0x20, 0x15, 0x24, 0x16, 0x23, 0x16, 0x26, 0x16, 0x20, 0x14, 0x29, 0x17, 0x2D, 0x1A, 0x34, 0x1C, 0x2D, 0x19, 0x33, 0x1B, 0x29, 0x18, 0x2B, 0x19, 0x28, 0x18, 0x2F, 0x1A, 0x23, 0x15, 0x32, 0x1B, 0x28, 0x17, 0x2D, 0x19, 0x28, 0x17, 0x2B, 0x19, 0x29, 0x17, 0x23, 0x16, 0x2A, 0x17, 0x31, 0x1A, 0x27, 0x16, 0x2D, 0x18, 0x28, 0x17
    },

    {
        0x6B, 0x74, 0x6D, 0x78, 0x70, 0x7B, 0x72, 0x7B, 0x72, 0x7C, 0x75, 0x7D, 0x76, 0x7D, 0x76, 0x7F, 0x78, 0x7F, 0x78, 0x7F, 0x79, 0x80, 0x79, 0x80, 0x79, 0x81, 0x7B, 0x81, 0x7A, 0x80, 0x79, 0x81, 0x7A, 0x81, 0x7B, 0x81, 0x7A, 0x80, 0x77, 0x7E, 0x6E, 0x75, 0x5F, 0x61, 0x44, 0x43, 0x29, 0x2B, 0x1F, 0x23, 0x1B, 0x20, 0x19, 0x23, 0x1E, 0x38, 0x29, 0x5A, 0x2F, 0x6A, 0x32, 0x71, 0x34, 0x76, 0x33, 0x75, 0x32, 0x6C, 0x2A, 0x51, 0x1E, 0x31, 0x19, 0x25, 0x18, 0x24, 0x1C, 0x2D, 0x2B, 0x53, 0x3E, 0x7E, 0x49, 0x92, 0x4D, 0x98, 0x51, 0x9D, 0x52, 0xA0, 0x53, 0xA5, 0x55, 0xA8, 0x56, 0xAB, 0x57, 0xAC, 0x58, 0xAB, 0x59, 0xAC, 0x59, 0xAC, 0x58, 0xAC, 0x57, 0xAB, 0x58, 0xAD, 0x58, 0xAF, 0x5A, 0xB0, 0x5A, 0xB0, 0x5A, 0xB0, 0x5A, 0xAD, 0x54, 0xA1, 0x49, 0x80, 0x32, 0x4D, 0x22, 0x30, 0x1D, 0x27, 0x1A, 0x22, 0x18, 0x1F, 0x16, 0x1D, 0x16, 0x1B, 0x18, 0x1C, 0x21, 0x29, 0x3A, 0x54, 0x62, 0x88, 0x78, 0x9C, 0x7F, 0xA3, 0x84, 0xA9, 0x87, 0xAC, 0x8A, 0xB2, 0x8B, 0xB1, 0x8B, 0xAF, 0x8A, 0xAF, 0x8B, 0xAF, 0x86, 0xAC, 0x74, 0x8F, 0x4A, 0x50, 0x2B, 0x2F, 0x21, 0x25, 0x1C, 0x20, 0x19, 0x1E, 0x16, 0x1A, 0x16, 0x1B, 0x16, 0x1B, 0x1A, 0x23, 0x29, 0x4D, 0x47, 0x8D, 0x51, 0xA1, 0x56, 0xAA, 0x59, 0xB0, 0x5A, 0xB2, 0x5B, 0xB3, 0x5C, 0xB5, 0x5D, 0xB6, 0x5D, 0xB7, 0x5D, 0xB5, 0x5B, 0xB4, 0x5C, 0xB3, 0x5B, 0xB2, 0x5B, 0xB1, 0x55, 0x9D, 0x3C, 0x61, 0x23, 0x31, 0x1A, 0x23, 0x17, 0x1E, 0x16, 0x1B, 0x16, 0x1B, 0x15, 0x19, 0x14, 0x19, 0x14, 0x19, 0x15, 0x19, 0x14, 0x18, 0x14, 0x18, 0x14, 0x17, 0x14, 0x18, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x13, 0x16, 0x13, 0x16, 0x12, 0x16, 0x12, 0x16, 0x14, 0x17, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x17, 0x22, 0x1B, 0x2D, 0x1C, 0x2E, 0x1E, 0x31, 0x1E, 0x32, 0x1E, 0x32, 0x1E, 0x30, 0x1D, 0x30, 0x1D, 0x30, 0x1D, 0x31, 0x1E, 0x30, 0x1D, 0x2C, 0x18, 0x1E, 0x15, 0x19, 0x14, 0x16, 0x13, 0x16, 0x14, 0x17, 0x14, 0x17, 0x15, 0x16, 0x1A, 0x1C, 0x35, 0x39, 0x59, 0x55, 0x61, 0x5B, 0x57, 0x4D, 0x38, 0x2F, 0x3E, 0x3E, 0x5D, 0x58, 0x66, 0x5D, 0x6C, 0x5F, 0x71, 0x61, 0x6B, 0x5F, 0x6B, 0x5F, 0x6B, 0x5D, 0x6D, 0x60, 0x6A, 0x5E, 0x6D, 0x60, 0x6A, 0x5D, 0x6E, 0x61, 0x6B, 0x5E, 0x6B, 0x60, 0x6D, 0x5F, 0x6A, 0x5E, 0x69, 0x5E, 0x68, 0x5B, 0x6A, 0x5C, 0x6C, 0x5F, 0x6C, 0x5F, 0x6F, 0x61, 0x6D, 0x60, 0x6F, 0x5E, 0x6C, 0x5E, 0x6E, 0x60, 0x70, 0x63, 0x6D, 0x60, 0x6C, 0x60, 0x6C, 0x5E, 0x6B, 0x5F, 0x6D, 0x61, 0x6F, 0x61, 0x6E, 0x60, 0x6D, 0x60, 0x6C, 0x5F, 0x6D, 0x61, 0x6A, 0x5D, 0x6B, 0x5D, 0x6D, 0x60, 0x6A, 0x5D, 0x69, 0x5B, 0x6B, 0x5F, 0x6B, 0x5E, 0x6A, 0x5D, 0x6D, 0x60, 0x6C, 0x5E, 0x67, 0x59, 0x67, 0x59, 0x69, 0x5B, 0x67, 0x5B, 0x6C, 0x63, 0x69, 0x5C, 0x68, 0x5C, 0x65, 0x5A, 0x68, 0x5A, 0x69, 0x5A, 0x67, 0x5A, 0x67, 0x5C, 0x67, 0x5C, 0x67, 0x5B, 0x66, 0x5A, 0x64, 0x58, 0x68, 0x5A, 0x69, 0x5A, 0x65, 0x59, 0x65, 0x5A, 0x62, 0x57, 0x64, 0x59, 0x64, 0x57, 0x64, 0x58, 0x63, 0x56, 0x63, 0x58, 0x65, 0x59, 0x64, 0x58, 0x65, 0x59, 0x64, 0x58, 0x66, 0x59, 0x63, 0x58, 0x65, 0x59, 0x63, 0x58, 0x63, 0x56, 0x66, 0x59, 0x63, 0x57, 0x64, 0x5A, 0x66, 0x5A, 0x62, 0x58, 0x66, 0x5C, 0x65, 0x5C, 0x66, 0x5C, 0x68, 0x62, 0x65, 0x5B, 0x62, 0x58, 0x65, 0x59, 0x62, 0x55, 0x60, 0x55, 0x5F, 0x54, 0x61, 0x57, 0x60, 0x55, 0x61, 0x56, 0x61, 0x55, 0x5F, 0x53, 0x5E, 0x52, 0x5F, 0x54, 0x63, 0x56, 0x64, 0x59, 0x63, 0x57, 0x62, 0x56, 0x61, 0x56, 0x65, 0x57, 0x60, 0x54, 0x60, 0x54, 0x61, 0x54, 0x49, 0x3F, 0x32, 0x30, 0x28, 0x29, 0x2D, 0x31, 0x28, 0x2B, 0x23, 0x26, 0x2B, 0x33, 0x24, 0x32, 0x1F, 0x2A, 0x1D, 0x27, 0x1C, 0x26, 0x1A, 0x22, 0x1C, 0x21, 0x1A, 0x1F, 0x1C, 0x20, 0x29, 0x31, 0x2E, 0x35, 0x31, 0x35, 0x25, 0x27, 0x20, 0x25, 0x22, 0x26, 0x22, 0x26, 0x23, 0x26, 0x1F, 0x24, 0x27, 0x2B, 0x29, 0x2F, 0x2B, 0x2F, 0x28, 0x2C, 0x2E, 0x33, 0x27, 0x2A, 0x27, 0x2A, 0x24, 0x28, 0x28, 0x2A, 0x21, 0x25, 0x2C, 0x2F, 0x22, 0x25, 0x27, 0x2B, 0x21, 0x23, 0x28, 0x2E, 0x24, 0x26, 0x22, 0x26, 0x27, 0x2B, 0x2B, 0x30, 0x24, 0x27, 0x29, 0x2D, 0x26, 0x29
    },

    {
        0x73, 0x38, 0x79, 0x3A, 0x7B, 0x3B, 0x7B, 0x3C, 0x7C, 0x3C, 0x7E, 0x3D, 0x81, 0x3E, 0x80, 0x3E, 0x82, 0x3E, 0x81, 0x3E, 0x84, 0x40, 0x83, 0x3F, 0x83, 0x40, 0x85, 0x40, 0x85, 0x40, 0x85, 0x40, 0x83, 0x40, 0x83, 0x40, 0x83, 0x40, 0x7E, 0x3C, 0x6E, 0x35, 0x52, 0x28, 0x34, 0x1C, 0x27, 0x18, 0x22, 0x15, 0x1F, 0x14, 0x1E, 0x15, 0x22, 0x1A, 0x38, 0x2E, 0x5B, 0x44, 0x6D, 0x51, 0x74, 0x55, 0x70, 0x50, 0x5E, 0x3F, 0x3F, 0x2A, 0x2A, 0x1D, 0x23, 0x19, 0x20, 0x17, 0x21, 0x19, 0x2C, 0x25, 0x52, 0x43, 0x84, 0x60, 0x99, 0x6C, 0x9F, 0x71, 0xA4, 0x75, 0xA5, 0x75, 0xAB, 0x7A, 0xAD, 0x7B, 0xB3, 0x7D, 0xB0, 0x7D, 0xB2, 0x7F, 0xB2, 0x7E, 0xB4, 0x7E, 0xB3, 0x7E, 0xB1, 0x7F, 0xB3, 0x80, 0xB7, 0x82, 0xB7, 0x7F, 0xB5, 0x7F, 0xB1, 0x7B, 0x9A, 0x64, 0x65, 0x40, 0x3B, 0x27, 0x2B, 0x1E, 0x25, 0x19, 0x21, 0x17, 0x1E, 0x16, 0x1C, 0x14, 0x1B, 0x14, 0x22, 0x1B, 0x3D, 0x34, 0x74, 0x57, 0x9A, 0x6B, 0xA6, 0x72, 0xAE, 0x77, 0xB0, 0x7A, 0xB2, 0x7B, 0xB7, 0x7E, 0xB7, 0x7D, 0xB5, 0x7D, 0xB6, 0x7D, 0xB4, 0x7A, 0xB3, 0x7A, 0xAE, 0x76, 0x95, 0x5E, 0x57, 0x36, 0x30, 0x21, 0x27, 0x1B, 0x21, 0x17, 0x1D, 0x14, 0x1A, 0x13, 0x1A, 0x13, 0x1C, 0x14, 0x24, 0x1E, 0x4F, 0x41, 0x8B, 0x66, 0xA7, 0x77, 0xAF, 0x7D, 0xB6, 0x81, 0xBA, 0x85, 0xBB, 0x87, 0xBF, 0x88, 0xBC, 0x86, 0xBC, 0x86, 0xBA, 0x86, 0xB9, 0x83, 0xB9, 0x82, 0xB1, 0x78, 0x85, 0x53, 0x44, 0x2C, 0x29, 0x1C, 0x20, 0x16, 0x1C, 0x14, 0x1C, 0x13, 0x1C, 0x13, 0x1B, 0x12, 0x1A, 0x13, 0x19, 0x11, 0x1A, 0x12, 0x19, 0x11, 0x18, 0x11, 0x18, 0x11, 0x17, 0x11, 0x17, 0x10, 0x16, 0x10, 0x17, 0x10, 0x17, 0x0F, 0x16, 0x10, 0x17, 0x10, 0x16, 0x0F, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x16, 0x10, 0x16, 0x10, 0x17, 0x12, 0x21, 0x1A, 0x2C, 0x21, 0x2F, 0x24, 0x32, 0x24, 0x33, 0x24, 0x34, 0x26, 0x32, 0x25, 0x32, 0x24, 0x32, 0x24, 0x31, 0x22, 0x24, 0x18, 0x1B, 0x12, 0x19, 0x11, 0x17, 0x10, 0x17, 0x10, 0x18, 0x11, 0x18, 0x10, 0x1B, 0x12, 0x2A, 0x17, 0x50, 0x20, 0x5E, 0x22, 0x5A, 0x20, 0x39, 0x19, 0x2E, 0x17, 0x4E, 0x20, 0x5D, 0x22, 0x60, 0x22, 0x62, 0x23, 0x63, 0x23, 0x62, 0x23, 0x61, 0x23, 0x5E, 0x21, 0x64, 0x23, 0x63, 0x23, 0x64, 0x24, 0x62, 0x23, 0x60, 0x22, 0x5F, 0x21, 0x60, 0x22, 0x60, 0x22, 0x60, 0x22, 0x63, 0x23, 0x60, 0x22, 0x60, 0x23, 0x5E, 0x22, 0x60, 0x21, 0x61, 0x23, 0x60, 0x22, 0x5D, 0x20, 0x5E, 0x21, 0x60, 0x23, 0x61, 0x22, 0x64, 0x23, 0x62, 0x23, 0x63, 0x23, 0x65, 0x23, 0x62, 0x23, 0x62, 0x23, 0x64, 0x23, 0x5F, 0x22, 0x5F, 0x23, 0x64, 0x23, 0x60, 0x23, 0x61, 0x23, 0x60, 0x22, 0x61, 0x22, 0x5E, 0x22, 0x5E, 0x22, 0x62, 0x26, 0x62, 0x24, 0x60, 0x22, 0x5F, 0x22, 0x5C, 0x21, 0x5F, 0x21, 0x5E, 0x22, 0x5C, 0x21, 0x5D, 0x22, 0x5A, 0x20, 0x5D, 0x21, 0x5D, 0x21, 0x5C, 0x20, 0x5C, 0x21, 0x5D, 0x22, 0x5C, 0x21, 0x5B, 0x20, 0x59, 0x20, 0x5C, 0x20, 0x5C, 0x21, 0x5B, 0x21, 0x5D, 0x21, 0x5D, 0x22, 0x59, 0x20, 0x5A, 0x20, 0x5B, 0x20, 0x58, 0x20, 0x5B, 0x21, 0x5A, 0x20, 0x5A, 0x20, 0x5A, 0x20, 0x5A, 0x20, 0x5C, 0x21, 0x59, 0x20, 0x59, 0x20, 0x57, 0x20, 0x5B, 0x21, 0x5B, 0x21, 0x58, 0x20, 0x5C, 0x21, 0x5B, 0x21, 0x59, 0x21, 0x5D, 0x23, 0x5B, 0x22, 0x5C, 0x23, 0x60, 0x24, 0x5C, 0x22, 0x5F, 0x23, 0x5C, 0x22, 0x5A, 0x21, 0x59, 0x20, 0x56, 0x1F, 0x5A, 0x20, 0x56, 0x20, 0x59, 0x21, 0x59, 0x20, 0x56, 0x1F, 0x54, 0x1F, 0x57, 0x20, 0x55, 0x1F, 0x55, 0x1F, 0x57, 0x20, 0x58, 0x20, 0x57, 0x20, 0x57, 0x20, 0x58, 0x20, 0x55, 0x1F, 0x55, 0x1F, 0x54, 0x1F, 0x55, 0x1F, 0x46, 0x1C, 0x32, 0x1B, 0x2C, 0x19, 0x35, 0x1D, 0x38, 0x1E, 0x2C, 0x19, 0x37, 0x1E, 0x31, 0x1A, 0x27, 0x18, 0x25, 0x16, 0x2B, 0x1A, 0x27, 0x17, 0x31, 0x1C, 0x2F, 0x1B, 0x29, 0x18, 0x38, 0x1F, 0x33, 0x1C, 0x33, 0x1C, 0x2A, 0x17, 0x31, 0x1C, 0x2C, 0x18, 0x2C, 0x19, 0x27, 0x17, 0x2C, 0x1A, 0x2C, 0x17, 0x2A, 0x18, 0x2A, 0x18, 0x27, 0x17, 0x32, 0x1B, 0x24, 0x15, 0x26, 0x17, 0x25, 0x17, 0x28, 0x18, 0x2A, 0x18, 0x2D, 0x18, 0x2B, 0x19, 0x2D, 0x19, 0x2B, 0x18, 0x32, 0x1A, 0x34, 0x1C, 0x38, 0x1D, 0x2D, 0x19, 0x31, 0x1B, 0x2F, 0x19, 0x36, 0x1D, 0x36, 0x1C
    },

    {
        0x62, 0x6E, 0x69, 0x73, 0x6D, 0x76, 0x6E, 0x78, 0x70, 0x7A, 0x72, 0x7A, 0x73, 0x7D, 0x75, 0x7E, 0x77, 0x7E, 0x79, 0x7E, 0x79, 0x80, 0x7A, 0x7F, 0x7A, 0x81, 0x7A, 0x82, 0x7C, 0x81, 0x7A, 0x80, 0x7A, 0x80, 0x7B, 0x7F, 0x77, 0x7D, 0x6F, 0x76, 0x61, 0x63, 0x45, 0x44, 0x2B, 0x2C, 0x20, 0x23, 0x1C, 0x1F, 0x18, 0x1D, 0x17, 0x1C, 0x17, 0x20, 0x1B, 0x32, 0x26, 0x53, 0x2E, 0x68, 0x30, 0x6D, 0x2F, 0x66, 0x29, 0x50, 0x1F, 0x32, 0x19, 0x25, 0x17, 0x20, 0x16, 0x1E, 0x16, 0x1E, 0x1A, 0x28, 0x27, 0x4B, 0x3C, 0x7C, 0x49, 0x90, 0x4D, 0x99, 0x50, 0x9E, 0x50, 0x9E, 0x53, 0xA4, 0x55, 0xA7, 0x57, 0xA9, 0x58, 0xAA, 0x56, 0xAB, 0x57, 0xAC, 0x58, 0xAC, 0x59, 0xAC, 0x57, 0xAA, 0x57, 0xAD, 0x59, 0xAF, 0x5A, 0xAD, 0x5A, 0xAD, 0x56, 0xA4, 0x4B, 0x85, 0x34, 0x50, 0x22, 0x30, 0x1B, 0x26, 0x19, 0x21, 0x17, 0x1E, 0x17, 0x1C, 0x16, 0x1B, 0x18, 0x1B, 0x20, 0x28, 0x36, 0x4F, 0x5D, 0x84, 0x77, 0x9A, 0x7F, 0xA3, 0x86, 0xA9, 0x87, 0xAC, 0x88, 0xAD, 0x8C, 0xB2, 0x8D, 0xB1, 0x8B, 0xB2, 0x8C, 0xB0, 0x8B, 0xAE, 0x89, 0xAC, 0x85, 0xAA, 0x7A, 0x97, 0x52, 0x5B, 0x2F, 0x32, 0x22, 0x27, 0x1D, 0x20, 0x18, 0x1C, 0x16, 0x1A, 0x15, 0x1A, 0x16, 0x1C, 0x19, 0x23, 0x26, 0x46, 0x40, 0x83, 0x50, 0x9E, 0x53, 0xA6, 0x59, 0xAC, 0x5C, 0xB3, 0x5C, 0xB6, 0x5D, 0xB8, 0x5D, 0xB4, 0x5C, 0xB4, 0x5B, 0xB5, 0x5A, 0xB0, 0x5A, 0xB2, 0x55, 0x9F, 0x3E, 0x66, 0x25, 0x34, 0x1A, 0x23, 0x17, 0x1D, 0x16, 0x1B, 0x16, 0x1C, 0x16, 0x1B, 0x16, 0x19, 0x15, 0x19, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x13, 0x17, 0x13, 0x17, 0x13, 0x16, 0x13, 0x16, 0x12, 0x16, 0x13, 0x17, 0x12, 0x16, 0x12, 0x16, 0x12, 0x15, 0x12, 0x16, 0x13, 0x16, 0x13, 0x16, 0x13, 0x16, 0x13, 0x16, 0x13, 0x16, 0x12, 0x16, 0x15, 0x1E, 0x1A, 0x2A, 0x1C, 0x2E, 0x1D, 0x2F, 0x1E, 0x30, 0x1E, 0x33, 0x1E, 0x32, 0x1D, 0x30, 0x1E, 0x30, 0x1D, 0x2C, 0x17, 0x1E, 0x15, 0x19, 0x14, 0x17, 0x13, 0x16, 0x13, 0x16, 0x15, 0x19, 0x15, 0x18, 0x1B, 0x1C, 0x34, 0x37, 0x58, 0x57, 0x63, 0x5C, 0x5A, 0x50, 0x38, 0x2E, 0x38, 0x37, 0x59, 0x54, 0x68, 0x5D, 0x6B, 0x5F, 0x6F, 0x62, 0x71, 0x64, 0x6F, 0x61, 0x6D, 0x60, 0x6B, 0x5C, 0x6F, 0x62, 0x6E, 0x62, 0x70, 0x63, 0x6F, 0x63, 0x6A, 0x5E, 0x6A, 0x5E, 0x6E, 0x5F, 0x6B, 0x5E, 0x6D, 0x60, 0x6D, 0x61, 0x6D, 0x5F, 0x6B, 0x60, 0x6A, 0x5D, 0x6C, 0x5D, 0x6C, 0x60, 0x6C, 0x5F, 0x6C, 0x5E, 0x6B, 0x5D, 0x6D, 0x60, 0x6D, 0x5E, 0x6C, 0x60, 0x6C, 0x60, 0x6F, 0x64, 0x70, 0x62, 0x6E, 0x60, 0x6E, 0x61, 0x6F, 0x62, 0x6C, 0x5E, 0x6D, 0x60, 0x6F, 0x62, 0x6C, 0x5F, 0x6C, 0x5F, 0x6B, 0x5E, 0x6E, 0x60, 0x6A, 0x5C, 0x69, 0x5D, 0x6B, 0x62, 0x6F, 0x62, 0x6B, 0x5D, 0x6A, 0x5D, 0x6A, 0x5B, 0x6D, 0x5F, 0x6C, 0x5E, 0x66, 0x5C, 0x67, 0x5A, 0x66, 0x59, 0x69, 0x5C, 0x68, 0x5C, 0x69, 0x5D, 0x68, 0x5B, 0x68, 0x5A, 0x68, 0x5B, 0x68, 0x5A, 0x66, 0x58, 0x68, 0x5B, 0x68, 0x5D, 0x68, 0x5A, 0x6A, 0x5E, 0x67, 0x5C, 0x65, 0x59, 0x65, 0x5A, 0x66, 0x59, 0x65, 0x59, 0x66, 0x5A, 0x65, 0x59, 0x65, 0x58, 0x65, 0x59, 0x66, 0x59, 0x67, 0x59, 0x66, 0x58, 0x65, 0x58, 0x61, 0x55, 0x64, 0x59, 0x66, 0x5B, 0x65, 0x58, 0x67, 0x5B, 0x66, 0x59, 0x63, 0x58, 0x68, 0x5E, 0x66, 0x5B, 0x66, 0x5C, 0x68, 0x5E, 0x65, 0x5A, 0x67, 0x5D, 0x64, 0x5A, 0x63, 0x58, 0x63, 0x57, 0x61, 0x57, 0x64, 0x58, 0x62, 0x57, 0x63, 0x58, 0x65, 0x57, 0x60, 0x54, 0x5F, 0x53, 0x61, 0x57, 0x61, 0x56, 0x60, 0x55, 0x62, 0x56, 0x62, 0x56, 0x63, 0x57, 0x62, 0x57, 0x63, 0x56, 0x60, 0x53, 0x60, 0x54, 0x5F, 0x54, 0x60, 0x56, 0x4A, 0x41, 0x32, 0x32, 0x2A, 0x2D, 0x31, 0x39, 0x32, 0x36, 0x28, 0x2A, 0x31, 0x37, 0x2B, 0x2D, 0x26, 0x2B, 0x22, 0x25, 0x2A, 0x31, 0x24, 0x28, 0x2D, 0x34, 0x2B, 0x30, 0x25, 0x27, 0x31, 0x39, 0x29, 0x2C, 0x2C, 0x30, 0x25, 0x27, 0x2D, 0x33, 0x26, 0x26, 0x28, 0x2C, 0x21, 0x23, 0x2A, 0x30, 0x25, 0x26, 0x29, 0x2E, 0x26, 0x28, 0x23, 0x28, 0x2A, 0x2C, 0x22, 0x25, 0x25, 0x27, 0x26, 0x2A, 0x28, 0x2C, 0x28, 0x2C, 0x2C, 0x2F, 0x2A, 0x30, 0x2A, 0x2F, 0x2A, 0x2F, 0x30, 0x35, 0x31, 0x37, 0x2E, 0x31, 0x29, 0x2E, 0x2E, 0x34, 0x2B, 0x2D, 0x32, 0x39, 0x30, 0x34
    },

    {
        0x63, 0x32, 0x71, 0x37, 0x75, 0x38, 0x78, 0x3A, 0x7A, 0x3B, 0x7D, 0x3B, 0x7D, 0x3D, 0x80, 0x3E, 0x81, 0x3F, 0x82, 0x3E, 0x83, 0x3F, 0x83, 0x3F, 0x86, 0x41, 0x84, 0x40, 0x84, 0x40, 0x82, 0x3F, 0x83, 0x3F, 0x81, 0x3F, 0x7D, 0x3D, 0x70, 0x35, 0x57, 0x29, 0x36, 0x1D, 0x27, 0x17, 0x21, 0x14, 0x1E, 0x13, 0x1C, 0x12, 0x1B, 0x12, 0x1B, 0x13, 0x1F, 0x18, 0x30, 0x28, 0x51, 0x40, 0x64, 0x48, 0x5B, 0x3E, 0x3E, 0x29, 0x29, 0x1C, 0x22, 0x18, 0x1F, 0x16, 0x1E, 0x15, 0x1C, 0x14, 0x1E, 0x16, 0x27, 0x21, 0x49, 0x3C, 0x7D, 0x5D, 0x98, 0x6D, 0xA0, 0x72, 0xA5, 0x75, 0xA7, 0x76, 0xAA, 0x78, 0xAD, 0x7A, 0xAE, 0x7B, 0xAF, 0x7C, 0xB1, 0x7E, 0xB2, 0x7E, 0xB3, 0x7F, 0xB1, 0x7E, 0xB2, 0x7E, 0xB2, 0x7E, 0xB2, 0x7D, 0xAD, 0x79, 0x99, 0x64, 0x6D, 0x44, 0x3F, 0x28, 0x2D, 0x1E, 0x26, 0x1A, 0x21, 0x17, 0x1E, 0x14, 0x1D, 0x14, 0x1B, 0x13, 0x20, 0x1A, 0x3D, 0x34, 0x74, 0x57, 0x99, 0x6B, 0xA3, 0x71, 0xAA, 0x74, 0xAF, 0x78, 0xB2, 0x79, 0xB4, 0x7B, 0xB6, 0x7C, 0xB6, 0x7D, 0xB6, 0x7D, 0xB7, 0x7E, 0xB8, 0x7F, 0xB6, 0x7C, 0xB1, 0x79, 0xB3, 0x78, 0xA1, 0x67, 0x65, 0x3D, 0x35, 0x22, 0x27, 0x1A, 0x20, 0x16, 0x1C, 0x14, 0x1B, 0x13, 0x1B, 0x14, 0x1C, 0x15, 0x21, 0x1A, 0x3F, 0x38, 0x85, 0x63, 0xA6, 0x76, 0xAC, 0x7C, 0xB6, 0x81, 0xBA, 0x85, 0xBC, 0x86, 0xBB, 0x86, 0xBC, 0x86, 0xBA, 0x86, 0xB8, 0x83, 0xB5, 0x7A, 0x88, 0x55, 0x44, 0x2B, 0x29, 0x1C, 0x20, 0x16, 0x1B, 0x13, 0x19, 0x12, 0x1B, 0x13, 0x1B, 0x13, 0x19, 0x12, 0x19, 0x11, 0x18, 0x11, 0x19, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x17, 0x10, 0x16, 0x0F, 0x17, 0x10, 0x17, 0x10, 0x16, 0x10, 0x16, 0x10, 0x17, 0x10, 0x17, 0x11, 0x16, 0x10, 0x18, 0x10, 0x17, 0x10, 0x16, 0x0F, 0x17, 0x10, 0x18, 0x11, 0x1F, 0x19, 0x2D, 0x21, 0x31, 0x24, 0x30, 0x24, 0x33, 0x25, 0x33, 0x24, 0x32, 0x24, 0x33, 0x23, 0x26, 0x1A, 0x1B, 0x13, 0x19, 0x11, 0x18, 0x10, 0x18, 0x10, 0x17, 0x10, 0x19, 0x11, 0x18, 0x11, 0x27, 0x16, 0x4F, 0x1F, 0x5D, 0x22, 0x59, 0x20, 0x3C, 0x1A, 0x2E, 0x18, 0x4D, 0x1F, 0x5D, 0x22, 0x64, 0x24, 0x62, 0x23, 0x64, 0x23, 0x65, 0x24, 0x65, 0x24, 0x64, 0x23, 0x60, 0x22, 0x62, 0x23, 0x61, 0x23, 0x64, 0x23, 0x60, 0x22, 0x5F, 0x21, 0x61, 0x22, 0x61, 0x22, 0x60, 0x22, 0x61, 0x22, 0x5E, 0x22, 0x62, 0x23, 0x61, 0x22, 0x5E, 0x22, 0x5E, 0x22, 0x5F, 0x21, 0x60, 0x21, 0x60, 0x21, 0x5D, 0x20, 0x60, 0x22, 0x62, 0x22, 0x5F, 0x21, 0x60, 0x21, 0x5F, 0x22, 0x61, 0x22, 0x5D, 0x21, 0x60, 0x22, 0x61, 0x23, 0x63, 0x23, 0x62, 0x22, 0x64, 0x23, 0x61, 0x24, 0x62, 0x24, 0x62, 0x22, 0x62, 0x22, 0x60, 0x22, 0x5D, 0x22, 0x5E, 0x21, 0x61, 0x23, 0x5E, 0x22, 0x5F, 0x23, 0x5E, 0x20, 0x5C, 0x21, 0x5E, 0x22, 0x5F, 0x22, 0x5E, 0x22, 0x5B, 0x21, 0x5B, 0x21, 0x5A, 0x21, 0x5E, 0x22, 0x5F, 0x22, 0x5C, 0x21, 0x5F, 0x21, 0x5C, 0x20, 0x5A, 0x20, 0x5B, 0x21, 0x60, 0x22, 0x5E, 0x22, 0x5D, 0x21, 0x5C, 0x21, 0x5D, 0x21, 0x5D, 0x21, 0x5B, 0x21, 0x5C, 0x22, 0x5B, 0x21, 0x5A, 0x20, 0x5C, 0x20, 0x57, 0x1F, 0x59, 0x20, 0x5C, 0x20, 0x5C, 0x21, 0x5C, 0x21, 0x5A, 0x21, 0x5B, 0x21, 0x5D, 0x22, 0x5A, 0x21, 0x5D, 0x23, 0x5C, 0x22, 0x5D, 0x24, 0x66, 0x2A, 0x62, 0x24, 0x5C, 0x21, 0x5A, 0x22, 0x5D, 0x23, 0x5B, 0x21, 0x58, 0x20, 0x59, 0x20, 0x5A, 0x20, 0x58, 0x1F, 0x59, 0x20, 0x58, 0x20, 0x58, 0x20, 0x58, 0x1F, 0x56, 0x1F, 0x55, 0x1F, 0x55, 0x1F, 0x5A, 0x20, 0x55, 0x1E, 0x55, 0x1F, 0x58, 0x20, 0x57, 0x1F, 0x56, 0x1F, 0x55, 0x1F, 0x55, 0x1F, 0x57, 0x1F, 0x56, 0x1E, 0x55, 0x21, 0x47, 0x1E, 0x3F, 0x20, 0x2D, 0x19, 0x39, 0x1F, 0x2D, 0x18, 0x24, 0x16, 0x2E, 0x1A, 0x29, 0x19, 0x34, 0x1C, 0x2B, 0x19, 0x35, 0x1D, 0x2A, 0x18, 0x36, 0x1D, 0x2A, 0x19, 0x27, 0x18, 0x32, 0x1B, 0x26, 0x18, 0x2C, 0x19, 0x27, 0x18, 0x2B, 0x1A, 0x27, 0x17, 0x2F, 0x19, 0x2B, 0x19, 0x36, 0x1C, 0x2B, 0x19, 0x39, 0x1E, 0x2D, 0x18, 0x33, 0x1C, 0x31, 0x1A, 0x2F, 0x1A, 0x38, 0x1E, 0x35, 0x1B, 0x36, 0x1D, 0x2E, 0x19, 0x3A, 0x1E, 0x31, 0x1B, 0x34, 0x1C, 0x31, 0x1A, 0x39, 0x1E, 0x2E, 0x18, 0x25, 0x15, 0x2D, 0x18, 0x30, 0x1A, 0x27, 0x16, 0x33, 0x1C, 0x2B, 0x18
    },

    {
        0x4D, 0x5D, 0x60, 0x6C, 0x67, 0x71, 0x6B, 0x74, 0x6E, 0x78, 0x70, 0x79, 0x73, 0x7A, 0x74, 0x7D, 0x77, 0x7F, 0x77, 0x7F, 0x79, 0x80, 0x7A, 0x81, 0x7B, 0x83, 0x7C, 0x83, 0x7B, 0x81, 0x79, 0x80, 0x79, 0x80, 0x76, 0x7C, 0x70, 0x78, 0x63, 0x66, 0x4A, 0x49, 0x2E, 0x2E, 0x21, 0x23, 0x1C, 0x1E, 0x18, 0x1C, 0x16, 0x1A, 0x16, 0x19, 0x14, 0x1A, 0x15, 0x1D, 0x19, 0x2B, 0x22, 0x4A, 0x2A, 0x5A, 0x27, 0x4D, 0x1F, 0x32, 0x19, 0x24, 0x17, 0x20, 0x15, 0x1D, 0x15, 0x1B, 0x15, 0x1A, 0x15, 0x1C, 0x19, 0x23, 0x23, 0x41, 0x39, 0x76, 0x49, 0x90, 0x4E, 0x9A, 0x50, 0x9E, 0x52, 0xA2, 0x53, 0xA3, 0x55, 0xA6, 0x56, 0xA6, 0x56, 0xA9, 0x57, 0xAB, 0x57, 0xAB, 0x58, 0xAB, 0x58, 0xAC, 0x57, 0xAB, 0x56, 0xAB, 0x56, 0xAA, 0x54, 0xA3, 0x4B, 0x85, 0x37, 0x56, 0x25, 0x34, 0x1D, 0x28, 0x1A, 0x23, 0x17, 0x1E, 0x16, 0x1B, 0x16, 0x1B, 0x17, 0x1B, 0x1F, 0x26, 0x36, 0x4F, 0x5D, 0x84, 0x76, 0x9A, 0x7E, 0xA1, 0x84, 0xA8, 0x88, 0xAC, 0x89, 0xAD, 0x8A, 0xAE, 0x8A, 0xAF, 0x8D, 0xAF, 0x8C, 0xB1, 0x8D, 0xB1, 0x8E, 0xB2, 0x8B, 0xAE, 0x88, 0xAC, 0x86, 0xAC, 0x7D, 0xA0, 0x5D, 0x69, 0x34, 0x37, 0x23, 0x27, 0x1C, 0x1F, 0x18, 0x1D, 0x16, 0x1A, 0x15, 0x1B, 0x16, 0x1B, 0x18, 0x1F, 0x20, 0x38, 0x3C, 0x7A, 0x4F, 0x9E, 0x55, 0xA8, 0x5A, 0xAE, 0x5C, 0xB3, 0x5B, 0xB3, 0x5C, 0xB4, 0x5D, 0xB5, 0x5B, 0xB6, 0x59, 0xB0, 0x57, 0xA5, 0x41, 0x6A, 0x25, 0x34, 0x1B, 0x23, 0x16, 0x1D, 0x14, 0x19, 0x14, 0x18, 0x15, 0x1A, 0x15, 0x19, 0x15, 0x18, 0x14, 0x18, 0x13, 0x17, 0x14, 0x17, 0x13, 0x18, 0x14, 0x17, 0x13, 0x17, 0x14, 0x18, 0x13, 0x17, 0x13, 0x17, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x13, 0x16, 0x13, 0x16, 0x13, 0x17, 0x13, 0x16, 0x13, 0x16, 0x13, 0x17, 0x13, 0x17, 0x15, 0x1D, 0x1A, 0x2B, 0x1D, 0x30, 0x1D, 0x30, 0x1E, 0x31, 0x1E, 0x31, 0x1E, 0x32, 0x1E, 0x2E, 0x19, 0x1F, 0x15, 0x1A, 0x14, 0x17, 0x14, 0x16, 0x13, 0x16, 0x13, 0x17, 0x15, 0x18, 0x19, 0x1A, 0x2F, 0x34, 0x59, 0x59, 0x64, 0x5D, 0x5A, 0x51, 0x3C, 0x30, 0x37, 0x37, 0x59, 0x54, 0x66, 0x5E, 0x6F, 0x64, 0x6F, 0x61, 0x6E, 0x61, 0x73, 0x64, 0x72, 0x64, 0x6F, 0x61, 0x6C, 0x60, 0x6D, 0x5F, 0x6D, 0x5F, 0x6F, 0x61, 0x6C, 0x5D, 0x6A, 0x5E, 0x6E, 0x61, 0x6D, 0x5F, 0x6D, 0x61, 0x6B, 0x5E, 0x6A, 0x5C, 0x6C, 0x60, 0x6D, 0x60, 0x6A, 0x5D, 0x69, 0x5D, 0x6D, 0x60, 0x6C, 0x5D, 0x6D, 0x5D, 0x68, 0x5B, 0x6B, 0x5F, 0x6E, 0x5F, 0x6A, 0x5D, 0x6C, 0x5E, 0x69, 0x5C, 0x6C, 0x5F, 0x69, 0x5C, 0x6D, 0x5E, 0x6D, 0x5F, 0x72, 0x62, 0x6F, 0x60, 0x6F, 0x62, 0x70, 0x62, 0x6E, 0x61, 0x6D, 0x5E, 0x70, 0x61, 0x6C, 0x5E, 0x6A, 0x5E, 0x6B, 0x5D, 0x6C, 0x5E, 0x68, 0x5D, 0x6B, 0x60, 0x6B, 0x5C, 0x68, 0x5A, 0x69, 0x5C, 0x6D, 0x5F, 0x69, 0x5D, 0x66, 0x5A, 0x66, 0x5A, 0x65, 0x59, 0x69, 0x5C, 0x6A, 0x5D, 0x67, 0x5B, 0x6B, 0x5C, 0x67, 0x58, 0x66, 0x59, 0x66, 0x5A, 0x6A, 0x5E, 0x69, 0x5D, 0x69, 0x5B, 0x66, 0x5C, 0x67, 0x5B, 0x66, 0x5B, 0x66, 0x5A, 0x69, 0x5D, 0x65, 0x59, 0x64, 0x5A, 0x66, 0x59, 0x62, 0x55, 0x65, 0x59, 0x69, 0x5B, 0x67, 0x59, 0x67, 0x5B, 0x65, 0x5A, 0x66, 0x5B, 0x67, 0x5B, 0x64, 0x59, 0x69, 0x5E, 0x68, 0x5E, 0x6A, 0x5F, 0x6B, 0x63, 0x6C, 0x5F, 0x67, 0x59, 0x63, 0x59, 0x67, 0x5C, 0x65, 0x58, 0x63, 0x57, 0x64, 0x58, 0x66, 0x59, 0x66, 0x58, 0x65, 0x5B, 0x65, 0x58, 0x62, 0x57, 0x64, 0x57, 0x60, 0x55, 0x61, 0x56, 0x63, 0x57, 0x67, 0x59, 0x61, 0x53, 0x61, 0x55, 0x62, 0x56, 0x63, 0x56, 0x61, 0x55, 0x5F, 0x53, 0x61, 0x54, 0x61, 0x54, 0x61, 0x54, 0x5F, 0x55, 0x4A, 0x43, 0x3B, 0x3F, 0x2A, 0x2B, 0x31, 0x36, 0x27, 0x28, 0x20, 0x23, 0x29, 0x2C, 0x27, 0x2B, 0x2D, 0x30, 0x28, 0x2D, 0x2D, 0x31, 0x28, 0x2D, 0x30, 0x35, 0x27, 0x29, 0x27, 0x2D, 0x2B, 0x2D, 0x26, 0x2B, 0x2A, 0x2C, 0x27, 0x2B, 0x29, 0x2D, 0x26, 0x2A, 0x2C, 0x2F, 0x2B, 0x33, 0x31, 0x34, 0x29, 0x2E, 0x31, 0x37, 0x29, 0x2B, 0x2F, 0x37, 0x2E, 0x32, 0x2B, 0x30, 0x32, 0x38, 0x2C, 0x30, 0x30, 0x32, 0x2C, 0x30, 0x30, 0x36, 0x2A, 0x2C, 0x2C, 0x31, 0x2A, 0x2E, 0x32, 0x39, 0x26, 0x27, 0x22, 0x24, 0x28, 0x2C, 0x29, 0x2E, 0x23, 0x26, 0x2E, 0x33, 0x26, 0x29
    },

    {
        0x40, 0x25, 0x5D, 0x30, 0x6B, 0x35, 0x72, 0x38, 0x76, 0x3A, 0x7B, 0x3B, 0x7E, 0x3D, 0x7F, 0x3E, 0x81, 0x3E, 0x81, 0x3E, 0x82, 0x40, 0x83, 0x40, 0x84, 0x40, 0x84, 0x40, 0x84, 0x40, 0x84, 0x40, 0x81, 0x3F, 0x7E, 0x3C, 0x73, 0x36, 0x5A, 0x2B, 0x39, 0x1E, 0x28, 0x18, 0x22, 0x15, 0x1E, 0x13, 0x1C, 0x12, 0x1A, 0x11, 0x19, 0x12, 0x18, 0x11, 0x19, 0x12, 0x1D, 0x16, 0x27, 0x21, 0x3A, 0x2C, 0x37, 0x25, 0x26, 0x1A, 0x20, 0x17, 0x1D, 0x15, 0x1C, 0x14, 0x1C, 0x13, 0x1A, 0x12, 0x1A, 0x13, 0x1B, 0x14, 0x23, 0x1C, 0x41, 0x38, 0x77, 0x59, 0x96, 0x6A, 0x9E, 0x70, 0xA3, 0x74, 0xA8, 0x77, 0xAB, 0x7A, 0xAE, 0x7C, 0xB3, 0x7E, 0xB3, 0x7F, 0xB3, 0x7F, 0xB4, 0x81, 0xB5, 0x7F, 0xB2, 0x7F, 0xB1, 0x7D, 0xAB, 0x77, 0x98, 0x65, 0x6C, 0x45, 0x42, 0x2B, 0x31, 0x21, 0x27, 0x1B, 0x21, 0x17, 0x1F, 0x15, 0x1C, 0x14, 0x1A, 0x13, 0x1F, 0x19, 0x38, 0x30, 0x6E, 0x53, 0x96, 0x69, 0xA2, 0x70, 0xAA, 0x75, 0xAF, 0x79, 0xB3, 0x7A, 0xB2, 0x7A, 0xB4, 0x7B, 0xB6, 0x7C, 0xB7, 0x7C, 0xB3, 0x7B, 0xB5, 0x7D, 0xB5, 0x7E, 0xB7, 0x7E, 0xB4, 0x7D, 0xB5, 0x7D, 0xB4, 0x7B, 0xA7, 0x6C, 0x70, 0x44, 0x39, 0x25, 0x26, 0x1B, 0x21, 0x18, 0x1E, 0x15, 0x1B, 0x13, 0x1B, 0x13, 0x1B, 0x13, 0x1C, 0x17, 0x35, 0x30, 0x7B, 0x60, 0xA4, 0x76, 0xAE, 0x7D, 0xB4, 0x81, 0xB9, 0x83, 0xB9, 0x85, 0xBA, 0x84, 0xBB, 0x85, 0xB3, 0x7D, 0x8D, 0x59, 0x4A, 0x2E, 0x2A, 0x1C, 0x20, 0x17, 0x1B, 0x13, 0x19, 0x12, 0x18, 0x11, 0x19, 0x12, 0x19, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x19, 0x11, 0x1B, 0x12, 0x1A, 0x12, 0x17, 0x10, 0x18, 0x11, 0x19, 0x11, 0x18, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x16, 0x10, 0x17, 0x10, 0x18, 0x11, 0x18, 0x11, 0x17, 0x11, 0x17, 0x10, 0x17, 0x11, 0x19, 0x11, 0x19, 0x11, 0x18, 0x11, 0x21, 0x1B, 0x2D, 0x22, 0x33, 0x25, 0x33, 0x26, 0x33, 0x25, 0x33, 0x24, 0x28, 0x1A, 0x1B, 0x13, 0x1A, 0x12, 0x18, 0x10, 0x17, 0x10, 0x18, 0x10, 0x18, 0x11, 0x1A, 0x11, 0x28, 0x17, 0x4D, 0x1E, 0x5D, 0x22, 0x5D, 0x22, 0x41, 0x1B, 0x2D, 0x19, 0x4E, 0x20, 0x5C, 0x22, 0x62, 0x23, 0x63, 0x24, 0x64, 0x23, 0x64, 0x24, 0x60, 0x22, 0x6D, 0x2A, 0x65, 0x25, 0x62, 0x22, 0x5F, 0x21, 0x60, 0x22, 0x64, 0x22, 0x61, 0x22, 0x5F, 0x23, 0x63, 0x23, 0x62, 0x24, 0x63, 0x22, 0x5E, 0x21, 0x5E, 0x21, 0x5F, 0x23, 0x62, 0x23, 0x62, 0x22, 0x5F, 0x22, 0x61, 0x22, 0x5C, 0x20, 0x5B, 0x21, 0x5E, 0x20, 0x5A, 0x21, 0x60, 0x22, 0x5D, 0x21, 0x5D, 0x21, 0x5C, 0x21, 0x61, 0x22, 0x60, 0x23, 0x61, 0x23, 0x61, 0x24, 0x62, 0x23, 0x61, 0x23, 0x62, 0x23, 0x60, 0x22, 0x5F, 0x22, 0x5D, 0x21, 0x60, 0x23, 0x61, 0x23, 0x62, 0x23, 0x64, 0x24, 0x62, 0x23, 0x5F, 0x23, 0x5D, 0x22, 0x5C, 0x21, 0x5D, 0x22, 0x5E, 0x21, 0x5E, 0x22, 0x5E, 0x22, 0x5E, 0x22, 0x5E, 0x23, 0x60, 0x22, 0x5C, 0x21, 0x5D, 0x21, 0x5D, 0x21, 0x5E, 0x21, 0x5E, 0x21, 0x5D, 0x21, 0x60, 0x22, 0x5E, 0x22, 0x5A, 0x20, 0x5A, 0x21, 0x5C, 0x21, 0x5B, 0x22, 0x5C, 0x22, 0x5C, 0x22, 0x5E, 0x23, 0x58, 0x20, 0x5A, 0x20, 0x58, 0x20, 0x59, 0x20, 0x58, 0x1F, 0x5C, 0x20, 0x5B, 0x20, 0x5C, 0x20, 0x5E, 0x22, 0x5E, 0x22, 0x5D, 0x22, 0x5B, 0x22, 0x5F, 0x23, 0x5E, 0x21, 0x60, 0x23, 0x5A, 0x22, 0x5C, 0x22, 0x5D, 0x24, 0x5E, 0x24, 0x5F, 0x23, 0x5A, 0x21, 0x5B, 0x21, 0x5B, 0x21, 0x5A, 0x21, 0x59, 0x20, 0x5C, 0x21, 0x5A, 0x21, 0x5A, 0x21, 0x58, 0x20, 0x5D, 0x22, 0x5C, 0x22, 0x57, 0x1F, 0x58, 0x20, 0x56, 0x1E, 0x54, 0x20, 0x56, 0x20, 0x54, 0x1F, 0x57, 0x20, 0x56, 0x1F, 0x54, 0x1F, 0x54, 0x1E, 0x55, 0x1F, 0x55, 0x20, 0x46, 0x1D, 0x32, 0x1A, 0x2A, 0x18, 0x33, 0x1C, 0x2D, 0x1A, 0x33, 0x1B, 0x37, 0x1D, 0x33, 0x1D, 0x35, 0x1D, 0x39, 0x1F, 0x37, 0x1F, 0x36, 0x1E, 0x3C, 0x20, 0x39, 0x1F, 0x3D, 0x1F, 0x36, 0x1D, 0x31, 0x1B, 0x39, 0x1F, 0x37, 0x1C, 0x36, 0x1D, 0x34, 0x1C, 0x3B, 0x1E, 0x37, 0x1D, 0x31, 0x1A, 0x2E, 0x1A, 0x31, 0x1B, 0x31, 0x1A, 0x31, 0x1A, 0x2F, 0x19, 0x28, 0x17, 0x2F, 0x19, 0x27, 0x17, 0x30, 0x1A, 0x29, 0x17, 0x29, 0x17, 0x2A, 0x17, 0x2D, 0x19, 0x28, 0x18, 0x31, 0x1A, 0x2E, 0x19, 0x2E, 0x19, 0x2D, 0x19, 0x30, 0x1A, 0x30, 0x1B, 0x34, 0x1C, 0x36, 0x1B
    },

    {
        0x2F, 0x3A, 0x46, 0x56, 0x5C, 0x68, 0x65, 0x6F, 0x69, 0x73, 0x6D, 0x77, 0x71, 0x7A, 0x74, 0x7C, 0x76, 0x7E, 0x77, 0x7E, 0x79, 0x81, 0x7A, 0x81, 0x7A, 0x81, 0x7A, 0x81, 0x7A, 0x81, 0x7A, 0x80, 0x77, 0x7F, 0x70, 0x77, 0x64, 0x68, 0x4C, 0x4B, 0x2F, 0x2F, 0x22, 0x25, 0x1D, 0x20, 0x18, 0x1C, 0x16, 0x1A, 0x15, 0x18, 0x14, 0x18, 0x13, 0x18, 0x13, 0x18, 0x14, 0x1B, 0x17, 0x24, 0x1C, 0x31, 0x1B, 0x2B, 0x17, 0x21, 0x16, 0x1E, 0x14, 0x1C, 0x14, 0x1B, 0x14, 0x1A, 0x14, 0x19, 0x13, 0x18, 0x14, 0x1A, 0x17, 0x20, 0x21, 0x3C, 0x37, 0x6E, 0x47, 0x8D, 0x4D, 0x99, 0x50, 0x9E, 0x53, 0xA1, 0x55, 0xA5, 0x55, 0xA7, 0x58, 0xAD, 0x58, 0xAD, 0x59, 0xAD, 0x59, 0xAE, 0x59, 0xAE, 0x58, 0xAB, 0x57, 0xAC, 0x53, 0xA2, 0x49, 0x84, 0x36, 0x56, 0x26, 0x36, 0x20, 0x2B, 0x1A, 0x23, 0x18, 0x1F, 0x16, 0x1C, 0x16, 0x1B, 0x17, 0x1B, 0x1D, 0x24, 0x32, 0x47, 0x58, 0x7E, 0x75, 0x99, 0x7D, 0xA2, 0x83, 0xA8, 0x86, 0xAB, 0x8A, 0xAE, 0x8B, 0xAE, 0x8B, 0xB1, 0x8E, 0xB5, 0x8C, 0xB1, 0x8B, 0xAE, 0x8C, 0xB1, 0x8B, 0xB0, 0x8C, 0xB0, 0x8B, 0xAF, 0x8B, 0xB1, 0x8A, 0xAE, 0x80, 0xA3, 0x64, 0x72, 0x37, 0x3A, 0x25, 0x28, 0x1E, 0x23, 0x1A, 0x1F, 0x17, 0x1A, 0x15, 0x19, 0x15, 0x1A, 0x16, 0x1B, 0x1D, 0x30, 0x37, 0x73, 0x4E, 0x9D, 0x55, 0xA7, 0x59, 0xAE, 0x5A, 0xB2, 0x5B, 0xB3, 0x5B, 0xB2, 0x5A, 0xB4, 0x55, 0xA4, 0x43, 0x6F, 0x26, 0x37, 0x1B, 0x24, 0x17, 0x1E, 0x15, 0x1A, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x13, 0x17, 0x14, 0x17, 0x14, 0x19, 0x15, 0x1A, 0x15, 0x19, 0x14, 0x18, 0x14, 0x18, 0x13, 0x18, 0x13, 0x18, 0x13, 0x17, 0x13, 0x16, 0x13, 0x17, 0x13, 0x17, 0x13, 0x16, 0x14, 0x18, 0x13, 0x17, 0x14, 0x18, 0x14, 0x17, 0x14, 0x18, 0x15, 0x19, 0x14, 0x18, 0x14, 0x17, 0x17, 0x21, 0x1B, 0x2C, 0x1E, 0x32, 0x1F, 0x34, 0x1F, 0x33, 0x1E, 0x2E, 0x19, 0x20, 0x15, 0x1A, 0x15, 0x18, 0x13, 0x16, 0x14, 0x17, 0x14, 0x17, 0x15, 0x18, 0x19, 0x1B, 0x31, 0x36, 0x57, 0x53, 0x64, 0x5B, 0x5E, 0x55, 0x3F, 0x33, 0x38, 0x37, 0x59, 0x55, 0x68, 0x5D, 0x6C, 0x61, 0x6D, 0x62, 0x6F, 0x63, 0x70, 0x63, 0x6E, 0x60, 0x75, 0x6B, 0x70, 0x62, 0x6E, 0x60, 0x6B, 0x5E, 0x6A, 0x5F, 0x6E, 0x61, 0x6D, 0x5E, 0x6A, 0x5F, 0x6C, 0x61, 0x6F, 0x62, 0x6D, 0x61, 0x6A, 0x5D, 0x6C, 0x5E, 0x6A, 0x60, 0x6D, 0x60, 0x6D, 0x5F, 0x6D, 0x5F, 0x6D, 0x5F, 0x6A, 0x5B, 0x68, 0x5B, 0x6A, 0x5C, 0x66, 0x59, 0x6D, 0x5E, 0x67, 0x5B, 0x69, 0x5C, 0x67, 0x5A, 0x6B, 0x5F, 0x6D, 0x61, 0x6F, 0x62, 0x6D, 0x61, 0x6E, 0x60, 0x6F, 0x61, 0x6B, 0x5F, 0x6B, 0x5E, 0x6B, 0x5D, 0x69, 0x5D, 0x6C, 0x60, 0x6C, 0x61, 0x6E, 0x62, 0x70, 0x63, 0x6F, 0x61, 0x6C, 0x5E, 0x68, 0x5C, 0x66, 0x5C, 0x69, 0x5C, 0x68, 0x5C, 0x69, 0x5D, 0x67, 0x5D, 0x68, 0x5D, 0x68, 0x5F, 0x6B, 0x5F, 0x66, 0x5B, 0x68, 0x5C, 0x6B, 0x5D, 0x68, 0x5C, 0x6C, 0x5E, 0x69, 0x5E, 0x69, 0x5D, 0x69, 0x5C, 0x65, 0x59, 0x67, 0x5B, 0x68, 0x5D, 0x67, 0x5B, 0x68, 0x5A, 0x69, 0x5B, 0x69, 0x5D, 0x62, 0x58, 0x63, 0x59, 0x64, 0x58, 0x63, 0x57, 0x63, 0x57, 0x68, 0x5B, 0x65, 0x5A, 0x66, 0x5A, 0x6B, 0x5F, 0x6A, 0x5D, 0x68, 0x5C, 0x66, 0x5A, 0x6A, 0x5E, 0x69, 0x5C, 0x68, 0x5B, 0x64, 0x5A, 0x6A, 0x5C, 0x66, 0x5A, 0x66, 0x5D, 0x68, 0x5B, 0x64, 0x57, 0x66, 0x5A, 0x67, 0x5B, 0x67, 0x5A, 0x64, 0x58, 0x66, 0x5B, 0x65, 0x59, 0x63, 0x58, 0x64, 0x5A, 0x67, 0x5C, 0x66, 0x5B, 0x63, 0x57, 0x64, 0x57, 0x62, 0x55, 0x5F, 0x54, 0x60, 0x53, 0x5F, 0x53, 0x62, 0x56, 0x62, 0x56, 0x60, 0x54, 0x5F, 0x53, 0x60, 0x55, 0x5F, 0x54, 0x46, 0x3E, 0x2F, 0x2D, 0x28, 0x2A, 0x30, 0x34, 0x2C, 0x31, 0x2F, 0x35, 0x31, 0x38, 0x2D, 0x32, 0x32, 0x38, 0x33, 0x3A, 0x31, 0x39, 0x2F, 0x35, 0x34, 0x3D, 0x34, 0x3B, 0x33, 0x38, 0x30, 0x36, 0x2B, 0x30, 0x34, 0x3C, 0x2F, 0x33, 0x2F, 0x34, 0x2D, 0x31, 0x31, 0x37, 0x2E, 0x31, 0x2A, 0x2F, 0x28, 0x2A, 0x2B, 0x32, 0x2A, 0x2D, 0x2A, 0x2C, 0x29, 0x2A, 0x24, 0x28, 0x28, 0x29, 0x26, 0x29, 0x2D, 0x30, 0x26, 0x29, 0x27, 0x2B, 0x28, 0x2A, 0x2B, 0x2E, 0x26, 0x2C, 0x2D, 0x30, 0x2B, 0x31, 0x29, 0x2C, 0x28, 0x2E, 0x2D, 0x32, 0x2D, 0x32, 0x31, 0x36, 0x31, 0x35
    },

    {
        0x25, 0x18, 0x39, 0x22, 0x56, 0x2E, 0x6A, 0x35, 0x75, 0x39, 0x78, 0x3A, 0x7C, 0x3C, 0x7F, 0x3D, 0x7F, 0x3D, 0x81, 0x3D, 0x82, 0x3E, 0x82, 0x3F, 0x84, 0x40, 0x84, 0x40, 0x84, 0x3F, 0x83, 0x3F, 0x7D, 0x3D, 0x73, 0x37, 0x5C, 0x2C, 0x3B, 0x1E, 0x28, 0x17, 0x22, 0x15, 0x1E, 0x13, 0x1B, 0x12, 0x19, 0x11, 0x18, 0x11, 0x17, 0x10, 0x18, 0x10, 0x17, 0x10, 0x18, 0x11, 0x1A, 0x13, 0x1E, 0x16, 0x1E, 0x16, 0x1D, 0x14, 0x1C, 0x14, 0x1B, 0x13, 0x1B, 0x13, 0x1A, 0x12, 0x19, 0x12, 0x18, 0x11, 0x18, 0x11, 0x19, 0x13, 0x21, 0x1A, 0x39, 0x31, 0x6E, 0x54, 0x93, 0x6A, 0xA1, 0x72, 0xA5, 0x74, 0xA9, 0x78, 0xAC, 0x7A, 0xB0, 0x7D, 0xB0, 0x7D, 0xB3, 0x7F, 0xB2, 0x7F, 0xB3, 0x7E, 0xB1, 0x7D, 0xAC, 0x78, 0x9A, 0x66, 0x6E, 0x45, 0x40, 0x2A, 0x30, 0x20, 0x28, 0x1C, 0x23, 0x18, 0x20, 0x16, 0x1C, 0x14, 0x1B, 0x13, 0x1F, 0x18, 0x34, 0x2C, 0x67, 0x50, 0x94, 0x68, 0xA4, 0x71, 0xAA, 0x75, 0xAF, 0x78, 0xB2, 0x7B, 0xB4, 0x7B, 0xB4, 0x7B, 0xB4, 0x7C, 0xB6, 0x7E, 0xB5, 0x7B, 0xB3, 0x7B, 0xB4, 0x7C, 0xB6, 0x7C, 0xB3, 0x7D, 0xB5, 0x7D, 0xB5, 0x7C, 0xB5, 0x7B, 0xB2, 0x7A, 0xAB, 0x71, 0x7B, 0x4B, 0x3F, 0x28, 0x2B, 0x1D, 0x23, 0x18, 0x1D, 0x15, 0x1A, 0x12, 0x1A, 0x12, 0x1A, 0x12, 0x1B, 0x15, 0x2E, 0x29, 0x70, 0x58, 0xA1, 0x74, 0xAD, 0x7C, 0xB6, 0x80, 0xB7, 0x82, 0xB6, 0x82, 0xB2, 0x7C, 0x8F, 0x5B, 0x4E, 0x30, 0x2B, 0x1D, 0x21, 0x17, 0x1C, 0x13, 0x1A, 0x12, 0x19, 0x12, 0x18, 0x11, 0x18, 0x10, 0x18, 0x10, 0x18, 0x10, 0x18, 0x11, 0x19, 0x12, 0x19, 0x11, 0x19, 0x11, 0x1A, 0x12, 0x19, 0x11, 0x18, 0x11, 0x18, 0x11, 0x17, 0x10, 0x19, 0x11, 0x18, 0x11, 0x19, 0x10, 0x17, 0x10, 0x19, 0x11, 0x19, 0x11, 0x19, 0x11, 0x1A, 0x12, 0x19, 0x12, 0x1C, 0x13, 0x1C, 0x12, 0x1A, 0x12, 0x19, 0x11, 0x19, 0x12, 0x1E, 0x18, 0x2D, 0x22, 0x33, 0x24, 0x34, 0x24, 0x25, 0x19, 0x1B, 0x12, 0x1A, 0x12, 0x1A, 0x11, 0x18, 0x10, 0x17, 0x10, 0x18, 0x10, 0x19, 0x12, 0x26, 0x17, 0x4D, 0x20, 0x5E, 0x21, 0x5C, 0x21, 0x43, 0x1C, 0x2E, 0x18, 0x4D, 0x20, 0x5C, 0x21, 0x5F, 0x22, 0x61, 0x22, 0x61, 0x23, 0x62, 0x22, 0x62, 0x22, 0x60, 0x23, 0x63, 0x23, 0x64, 0x23, 0x61, 0x21, 0x5F, 0x22, 0x61, 0x23, 0x5F, 0x22, 0x62, 0x23, 0x62, 0x23, 0x61, 0x22, 0x62, 0x23, 0x62, 0x23, 0x63, 0x23, 0x61, 0x22, 0x63, 0x23, 0x62, 0x24, 0x5F, 0x21, 0x60, 0x22, 0x60, 0x21, 0x5C, 0x20, 0x5D, 0x22, 0x60, 0x22, 0x5C, 0x22, 0x60, 0x21, 0x61, 0x22, 0x5D, 0x21, 0x5E, 0x22, 0x60, 0x23, 0x65, 0x24, 0x65, 0x23, 0x62, 0x24, 0x61, 0x23, 0x5F, 0x23, 0x61, 0x22, 0x60, 0x22, 0x60, 0x22, 0x60, 0x22, 0x62, 0x23, 0x60, 0x24, 0x63, 0x23, 0x64, 0x23, 0x61, 0x23, 0x5D, 0x20, 0x5D, 0x21, 0x5E, 0x21, 0x5D, 0x22, 0x5D, 0x21, 0x5B, 0x21, 0x5A, 0x21, 0x5B, 0x22, 0x5C, 0x22, 0x5B, 0x21, 0x58, 0x1F, 0x5B, 0x21, 0x5D, 0x22, 0x60, 0x23, 0x5E, 0x22, 0x5F, 0x21, 0x5A, 0x20, 0x5E, 0x22, 0x5D, 0x20, 0x5B, 0x21, 0x60, 0x24, 0x61, 0x24, 0x5F, 0x22, 0x5B, 0x21, 0x5A, 0x21, 0x5C, 0x20, 0x5C, 0x20, 0x5C, 0x21, 0x5A, 0x20, 0x59, 0x20, 0x5C, 0x21, 0x5B, 0x20, 0x5B, 0x20, 0x5D, 0x22, 0x5A, 0x21, 0x5D, 0x22, 0x60, 0x23, 0x5D, 0x22, 0x5C, 0x22, 0x59, 0x20, 0x58, 0x21, 0x5E, 0x22, 0x5A, 0x22, 0x5E, 0x22, 0x5A, 0x22, 0x59, 0x21, 0x59, 0x22, 0x5D, 0x22, 0x57, 0x20, 0x5D, 0x22, 0x5C, 0x21, 0x5A, 0x21, 0x5A, 0x21, 0x5A, 0x21, 0x5E, 0x22, 0x5D, 0x21, 0x5A, 0x20, 0x5C, 0x21, 0x59, 0x20, 0x55, 0x1F, 0x56, 0x20, 0x54, 0x20, 0x59, 0x20, 0x55, 0x1F, 0x55, 0x1F, 0x52, 0x1E, 0x55, 0x1F, 0x55, 0x1F, 0x44, 0x1D, 0x3A, 0x1D, 0x2D, 0x19, 0x3B, 0x1F, 0x32, 0x1B, 0x29, 0x18, 0x32, 0x1B, 0x2D, 0x1B, 0x3A, 0x1F, 0x2D, 0x19, 0x31, 0x1B, 0x2A, 0x18, 0x38, 0x1D, 0x31, 0x1B, 0x26, 0x17, 0x30, 0x1A, 0x28, 0x18, 0x34, 0x1C, 0x27, 0x17, 0x2C, 0x19, 0x27, 0x16, 0x2B, 0x19, 0x2C, 0x18, 0x28, 0x17, 0x29, 0x18, 0x31, 0x1B, 0x2A, 0x17, 0x29, 0x17, 0x29, 0x17, 0x30, 0x1B, 0x2F, 0x19, 0x30, 0x1B, 0x38, 0x1D, 0x30, 0x1B, 0x38, 0x1E, 0x32, 0x1A, 0x31, 0x1A, 0x2E, 0x19, 0x34, 0x1A, 0x29, 0x17, 0x2A, 0x19, 0x2E, 0x19, 0x37, 0x1D, 0x2B, 0x18, 0x34, 0x1C, 0x2B, 0x18
    },

    {
        0x1E, 0x22, 0x29, 0x33, 0x41, 0x50, 0x57, 0x66, 0x65, 0x70, 0x6B, 0x74, 0x70, 0x79, 0x72, 0x7B, 0x73, 0x7C, 0x76, 0x7D, 0x77, 0x7F, 0x78, 0x7F, 0x79, 0x80, 0x78, 0x81, 0x79, 0x81, 0x77, 0x7D, 0x6F, 0x76, 0x64, 0x69, 0x4F, 0x4D, 0x30, 0x30, 0x22, 0x24, 0x1C, 0x1F, 0x19, 0x1B, 0x16, 0x19, 0x15, 0x18, 0x13, 0x17, 0x13, 0x17, 0x12, 0x17, 0x13, 0x17, 0x12, 0x17, 0x13, 0x19, 0x14, 0x1B, 0x15, 0x1C, 0x14, 0x1B, 0x14, 0x1A, 0x13, 0x1A, 0x14, 0x1A, 0x13, 0x19, 0x13, 0x18, 0x13, 0x17, 0x12, 0x17, 0x13, 0x18, 0x16, 0x1E, 0x1E, 0x34, 0x31, 0x65, 0x45, 0x8C, 0x4D, 0x99, 0x50, 0x9E, 0x52, 0xA1, 0x54, 0xA6, 0x56, 0xAA, 0x57, 0xAA, 0x58, 0xAB, 0x58, 0xAC, 0x58, 0xAB, 0x58, 0xAA, 0x54, 0xA4, 0x4B, 0x88, 0x37, 0x59, 0x24, 0x35, 0x1E, 0x2A, 0x1B, 0x24, 0x19, 0x21, 0x17, 0x1D, 0x16, 0x1A, 0x16, 0x1A, 0x1D, 0x23, 0x2F, 0x43, 0x54, 0x79, 0x72, 0x98, 0x7E, 0xA1, 0x82, 0xA6, 0x86, 0xAA, 0x89, 0xAF, 0x8B, 0xAF, 0x8A, 0xAD, 0x8A, 0xAE, 0x8A, 0xB0, 0x8A, 0xAF, 0x8A, 0xAF, 0x8A, 0xB1, 0x8C, 0xB0, 0x8B, 0xAF, 0x8B, 0xAF, 0x8A, 0xAE, 0x8C, 0xB0, 0x8B, 0xAF, 0x85, 0xA8, 0x6C, 0x7E, 0x3E, 0x42, 0x27, 0x2B, 0x1F, 0x23, 0x1A, 0x1D, 0x16, 0x1A, 0x15, 0x19, 0x14, 0x19, 0x14, 0x1A, 0x1A, 0x29, 0x32, 0x66, 0x4B, 0x99, 0x54, 0xA7, 0x59, 0xB0, 0x5A, 0xB2, 0x59, 0xB0, 0x56, 0xA3, 0x43, 0x71, 0x28, 0x39, 0x1B, 0x25, 0x17, 0x1E, 0x15, 0x1A, 0x14, 0x18, 0x13, 0x18, 0x13, 0x18, 0x13, 0x18, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x14, 0x19, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x13, 0x17, 0x13, 0x17, 0x14, 0x17, 0x14, 0x18, 0x14, 0x18, 0x13, 0x17, 0x14, 0x19, 0x15, 0x19, 0x14, 0x19, 0x14, 0x19, 0x14, 0x19, 0x16, 0x1B, 0x15, 0x19, 0x15, 0x19, 0x14, 0x18, 0x14, 0x17, 0x15, 0x1B, 0x1B, 0x2B, 0x1E, 0x30, 0x1D, 0x2F, 0x18, 0x1E, 0x14, 0x18, 0x14, 0x18, 0x15, 0x18, 0x13, 0x17, 0x14, 0x16, 0x15, 0x17, 0x19, 0x1B, 0x2D, 0x32, 0x55, 0x56, 0x66, 0x5D, 0x5F, 0x55, 0x42, 0x36, 0x36, 0x32, 0x56, 0x54, 0x65, 0x5B, 0x6C, 0x5F, 0x6D, 0x5E, 0x6C, 0x5F, 0x6E, 0x60, 0x6E, 0x60, 0x6B, 0x5F, 0x6D, 0x62, 0x70, 0x62, 0x6D, 0x5E, 0x68, 0x5E, 0x6D, 0x5F, 0x6B, 0x5E, 0x6C, 0x5E, 0x6D, 0x63, 0x6B, 0x5F, 0x6D, 0x5F, 0x6B, 0x60, 0x6E, 0x61, 0x6C, 0x5F, 0x6F, 0x61, 0x6A, 0x5F, 0x6D, 0x5E, 0x6B, 0x5E, 0x6C, 0x5E, 0x69, 0x5B, 0x6B, 0x5E, 0x6C, 0x5F, 0x6A, 0x5D, 0x6D, 0x5F, 0x6F, 0x61, 0x6B, 0x5C, 0x6A, 0x5D, 0x6C, 0x5E, 0x70, 0x63, 0x6E, 0x60, 0x6C, 0x60, 0x6E, 0x60, 0x6A, 0x5C, 0x6C, 0x60, 0x6B, 0x60, 0x6C, 0x5F, 0x6A, 0x5E, 0x6C, 0x61, 0x6A, 0x5E, 0x6E, 0x61, 0x6E, 0x60, 0x6C, 0x5E, 0x68, 0x5B, 0x6A, 0x5C, 0x67, 0x5C, 0x6B, 0x5D, 0x6B, 0x5E, 0x65, 0x59, 0x64, 0x58, 0x66, 0x5B, 0x66, 0x5A, 0x65, 0x5A, 0x64, 0x59, 0x69, 0x5C, 0x69, 0x5D, 0x6A, 0x5F, 0x6A, 0x5E, 0x6A, 0x5D, 0x68, 0x5B, 0x6D, 0x5E, 0x6A, 0x5B, 0x68, 0x5B, 0x6C, 0x5F, 0x6B, 0x61, 0x6D, 0x5E, 0x68, 0x5B, 0x65, 0x59, 0x67, 0x5C, 0x67, 0x5B, 0x69, 0x5C, 0x64, 0x5B, 0x65, 0x59, 0x68, 0x5C, 0x67, 0x59, 0x67, 0x59, 0x68, 0x5C, 0x66, 0x59, 0x66, 0x5B, 0x6B, 0x5E, 0x68, 0x5C, 0x66, 0x5B, 0x64, 0x58, 0x61, 0x57, 0x68, 0x5C, 0x63, 0x5A, 0x67, 0x5C, 0x63, 0x59, 0x63, 0x59, 0x64, 0x59, 0x6A, 0x5C, 0x63, 0x58, 0x67, 0x5C, 0x67, 0x5B, 0x63, 0x58, 0x63, 0x59, 0x65, 0x59, 0x67, 0x5B, 0x68, 0x5D, 0x66, 0x59, 0x67, 0x5A, 0x64, 0x59, 0x60, 0x55, 0x61, 0x55, 0x63, 0x58, 0x63, 0x57, 0x5F, 0x55, 0x5F, 0x54, 0x5C, 0x50, 0x60, 0x55, 0x5C, 0x53, 0x45, 0x3E, 0x37, 0x38, 0x29, 0x2B, 0x32, 0x39, 0x2B, 0x2D, 0x24, 0x26, 0x2C, 0x30, 0x29, 0x2F, 0x32, 0x36, 0x26, 0x29, 0x2A, 0x2E, 0x25, 0x29, 0x30, 0x36, 0x2C, 0x2E, 0x24, 0x27, 0x2A, 0x2D, 0x26, 0x2A, 0x2D, 0x31, 0x25, 0x28, 0x28, 0x2D, 0x23, 0x27, 0x29, 0x2D, 0x29, 0x2D, 0x26, 0x29, 0x27, 0x2D, 0x2D, 0x33, 0x27, 0x29, 0x27, 0x2C, 0x29, 0x2C, 0x2E, 0x34, 0x2D, 0x2F, 0x2D, 0x35, 0x32, 0x36, 0x2C, 0x31, 0x32, 0x38, 0x2B, 0x2E, 0x2C, 0x2F, 0x28, 0x2C, 0x2C, 0x2F, 0x23, 0x24, 0x29, 0x2E, 0x2A, 0x2E, 0x32, 0x36, 0x26, 0x2A, 0x2E, 0x32, 0x26, 0x28
    },

    {
        0x1D, 0x13, 0x22, 0x16, 0x32, 0x1F, 0x50, 0x2C, 0x69, 0x35, 0x72, 0x38, 0x76, 0x39, 0x79, 0x3B, 0x7D, 0x3C, 0x7F, 0x3D, 0x81, 0x3E, 0x81, 0x40, 0x82, 0x3F, 0x83, 0x3F, 0x81, 0x3F, 0x80, 0x3E, 0x75, 0x37, 0x5D, 0x2D, 0x3E, 0x1F, 0x29, 0x18, 0x21, 0x15, 0x1D, 0x12, 0x1A, 0x12, 0x19, 0x11, 0x18, 0x10, 0x17, 0x10, 0x17, 0x10, 0x16, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x18, 0x11, 0x19, 0x12, 0x1A, 0x12, 0x1A, 0x12, 0x19, 0x12, 0x19, 0x12, 0x19, 0x12, 0x18, 0x11, 0x17, 0x10, 0x17, 0x10, 0x16, 0x10, 0x19, 0x12, 0x1E, 0x18, 0x32, 0x2B, 0x64, 0x4D, 0x8F, 0x68, 0x9F, 0x71, 0xA4, 0x75, 0xAA, 0x78, 0xAC, 0x7A, 0xAE, 0x7C, 0xB0, 0x7D, 0xB1, 0x7E, 0xB2, 0x7F, 0xAE, 0x7A, 0x9E, 0x6A, 0x74, 0x48, 0x43, 0x2B, 0x2F, 0x20, 0x27, 0x1B, 0x22, 0x18, 0x20, 0x17, 0x1E, 0x15, 0x1B, 0x13, 0x1E, 0x18, 0x35, 0x2D, 0x66, 0x4E, 0x92, 0x66, 0x9F, 0x6F, 0xA8, 0x73, 0xAC, 0x76, 0xAE, 0x78, 0xB0, 0x7A, 0xB3, 0x7C, 0xB2, 0x7B, 0xB3, 0x7A, 0xB3, 0x7D, 0xB4, 0x7B, 0xB1, 0x7A, 0xB5, 0x7A, 0xB6, 0x7D, 0xB4, 0x7D, 0xB4, 0x7B, 0xB5, 0x7D, 0xB7, 0x7C, 0xB4, 0x7C, 0xB5, 0x7B, 0xAF, 0x76, 0x86, 0x52, 0x44, 0x2B, 0x2B, 0x1D, 0x24, 0x18, 0x1E, 0x15, 0x1B, 0x13, 0x1A, 0x12, 0x18, 0x11, 0x19, 0x13, 0x27, 0x24, 0x67, 0x53, 0xA2, 0x73, 0xAE, 0x7A, 0xB4, 0x7F, 0xB2, 0x7C, 0x92, 0x5D, 0x4E, 0x32, 0x2B, 0x1E, 0x21, 0x17, 0x1B, 0x13, 0x19, 0x12, 0x18, 0x11, 0x19, 0x11, 0x18, 0x11, 0x17, 0x11, 0x18, 0x11, 0x17, 0x11, 0x19, 0x11, 0x1A, 0x12, 0x18, 0x11, 0x17, 0x10, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x10, 0x19, 0x11, 0x18, 0x11, 0x18, 0x10, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x10, 0x17, 0x10, 0x19, 0x12, 0x19, 0x11, 0x18, 0x10, 0x18, 0x11, 0x19, 0x11, 0x18, 0x11, 0x17, 0x10, 0x1C, 0x16, 0x2A, 0x20, 0x26, 0x1A, 0x1A, 0x12, 0x18, 0x11, 0x17, 0x10, 0x18, 0x11, 0x18, 0x10, 0x17, 0x10, 0x17, 0x10, 0x23, 0x16, 0x4A, 0x1F, 0x5A, 0x21, 0x5B, 0x22, 0x47, 0x1D, 0x2F, 0x19, 0x4A, 0x20, 0x5B, 0x22, 0x60, 0x22, 0x62, 0x23, 0x5F, 0x22, 0x62, 0x23, 0x61, 0x24, 0x63, 0x23, 0x61, 0x22, 0x5E, 0x22, 0x60, 0x22, 0x60, 0x22, 0x61, 0x23, 0x60, 0x22, 0x63, 0x22, 0x62, 0x22, 0x5F, 0x22, 0x60, 0x21, 0x61, 0x23, 0x5E, 0x22, 0x62, 0x23, 0x63, 0x23, 0x64, 0x24, 0x60, 0x22, 0x61, 0x22, 0x5E, 0x22, 0x60, 0x22, 0x5E, 0x22, 0x63, 0x22, 0x60, 0x21, 0x5F, 0x22, 0x61, 0x22, 0x61, 0x22, 0x62, 0x23, 0x61, 0x23, 0x5F, 0x22, 0x5F, 0x22, 0x62, 0x24, 0x64, 0x24, 0x63, 0x23, 0x5F, 0x22, 0x62, 0x22, 0x61, 0x23, 0x5E, 0x22, 0x60, 0x22, 0x60, 0x22, 0x60, 0x23, 0x62, 0x23, 0x62, 0x22, 0x5F, 0x22, 0x5D, 0x21, 0x5E, 0x22, 0x5F, 0x22, 0x61, 0x22, 0x60, 0x22, 0x5C, 0x22, 0x5D, 0x23, 0x5E, 0x22, 0x5C, 0x21, 0x5B, 0x22, 0x5F, 0x22, 0x5C, 0x22, 0x5C, 0x22, 0x5F, 0x22, 0x5C, 0x21, 0x5B, 0x20, 0x5C, 0x21, 0x60, 0x23, 0x61, 0x23, 0x61, 0x23, 0x5E, 0x22, 0x61, 0x23, 0x5F, 0x22, 0x61, 0x22, 0x5D, 0x21, 0x5F, 0x23, 0x5F, 0x22, 0x60, 0x22, 0x5C, 0x21, 0x58, 0x20, 0x5A, 0x21, 0x5D, 0x21, 0x5B, 0x21, 0x5C, 0x21, 0x5D, 0x21, 0x5F, 0x23, 0x60, 0x23, 0x60, 0x24, 0x5D, 0x22, 0x5E, 0x22, 0x5B, 0x22, 0x5D, 0x21, 0x5A, 0x22, 0x5B, 0x22, 0x5C, 0x23, 0x5D, 0x23, 0x5C, 0x21, 0x5E, 0x22, 0x5A, 0x21, 0x59, 0x21, 0x5B, 0x22, 0x59, 0x21, 0x5B, 0x21, 0x58, 0x20, 0x5A, 0x21, 0x5C, 0x21, 0x5A, 0x21, 0x5C, 0x22, 0x5B, 0x21, 0x57, 0x1F, 0x57, 0x22, 0x5D, 0x23, 0x59, 0x20, 0x58, 0x20, 0x56, 0x1F, 0x54, 0x1F, 0x57, 0x1F, 0x54, 0x1F, 0x3F, 0x1B, 0x30, 0x19, 0x29, 0x18, 0x34, 0x1C, 0x2E, 0x1A, 0x2C, 0x1A, 0x35, 0x1E, 0x36, 0x1E, 0x3B, 0x1F, 0x30, 0x1A, 0x34, 0x1C, 0x34, 0x1D, 0x3E, 0x20, 0x39, 0x1E, 0x2A, 0x19, 0x37, 0x1D, 0x37, 0x1F, 0x3C, 0x1F, 0x31, 0x1B, 0x36, 0x1D, 0x35, 0x1D, 0x3A, 0x1F, 0x32, 0x1A, 0x2F, 0x1A, 0x35, 0x1C, 0x33, 0x1C, 0x2D, 0x19, 0x2E, 0x1A, 0x3B, 0x1E, 0x32, 0x1B, 0x2D, 0x19, 0x32, 0x1C, 0x2D, 0x19, 0x2A, 0x19, 0x30, 0x1A, 0x25, 0x16, 0x2B, 0x18, 0x27, 0x17, 0x2D, 0x19, 0x28, 0x18, 0x36, 0x1C, 0x2F, 0x1B, 0x32, 0x1A, 0x2C, 0x19, 0x2E, 0x19, 0x28, 0x18
    },

    {
        0x1A, 0x1C, 0x1C, 0x20, 0x26, 0x2F, 0x3C, 0x4C, 0x56, 0x64, 0x63, 0x6E, 0x69, 0x72, 0x6D, 0x76, 0x71, 0x7A, 0x73, 0x7C, 0x76, 0x7E, 0x78, 0x7F, 0x78, 0x80, 0x78, 0x80, 0x76, 0x7E, 0x72, 0x7A, 0x66, 0x6B, 0x50, 0x50, 0x33, 0x32, 0x22, 0x24, 0x1C, 0x1F, 0x19, 0x1B, 0x16, 0x19, 0x15, 0x18, 0x13, 0x17, 0x13, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x17, 0x13, 0x18, 0x13, 0x19, 0x14, 0x19, 0x13, 0x18, 0x13, 0x18, 0x13, 0x18, 0x12, 0x16, 0x11, 0x16, 0x11, 0x16, 0x12, 0x16, 0x12, 0x17, 0x15, 0x1C, 0x1C, 0x2D, 0x2D, 0x5A, 0x43, 0x88, 0x4C, 0x98, 0x4F, 0x9E, 0x53, 0xA2, 0x55, 0xA6, 0x55, 0xA9, 0x56, 0xAB, 0x58, 0xAC, 0x58, 0xAD, 0x57, 0xA5, 0x4D, 0x8C, 0x39, 0x5B, 0x25, 0x35, 0x1D, 0x29, 0x1A, 0x23, 0x18, 0x20, 0x17, 0x1F, 0x17, 0x1D, 0x17, 0x1B, 0x1D, 0x23, 0x30, 0x44, 0x55, 0x79, 0x72, 0x96, 0x7C, 0xA1, 0x82, 0xA6, 0x84, 0xA6, 0x86, 0xA9, 0x87, 0xAC, 0x8B, 0xAD, 0x8B, 0xAF, 0x8A, 0xAD, 0x8A, 0xAE, 0x89, 0xAC, 0x89, 0xAC, 0x8A, 0xAF, 0x8B, 0xAF, 0x8B, 0xB0, 0x8B, 0xAD, 0x8C, 0xB2, 0x8C, 0xB0, 0x8A, 0xAE, 0x89, 0xAD, 0x86, 0xAC, 0x73, 0x88, 0x44, 0x48, 0x29, 0x2D, 0x20, 0x24, 0x1A, 0x1E, 0x16, 0x1A, 0x14, 0x18, 0x14, 0x17, 0x14, 0x19, 0x18, 0x24, 0x2F, 0x60, 0x4B, 0x9A, 0x54, 0xA5, 0x58, 0xAD, 0x56, 0xA5, 0x44, 0x74, 0x28, 0x3A, 0x1B, 0x25, 0x18, 0x1E, 0x15, 0x19, 0x14, 0x18, 0x13, 0x18, 0x14, 0x18, 0x13, 0x17, 0x13, 0x18, 0x13, 0x17, 0x13, 0x17, 0x14, 0x18, 0x15, 0x19, 0x14, 0x17, 0x13, 0x17, 0x13, 0x18, 0x14, 0x18, 0x14, 0x17, 0x13, 0x18, 0x14, 0x19, 0x14, 0x17, 0x14, 0x17, 0x14, 0x17, 0x14, 0x18, 0x14, 0x17, 0x14, 0x18, 0x14, 0x17, 0x14, 0x17, 0x14, 0x19, 0x14, 0x18, 0x14, 0x18, 0x14, 0x19, 0x15, 0x19, 0x14, 0x18, 0x14, 0x17, 0x15, 0x1B, 0x1A, 0x28, 0x18, 0x1F, 0x15, 0x19, 0x14, 0x17, 0x13, 0x16, 0x14, 0x18, 0x14, 0x18, 0x14, 0x17, 0x18, 0x19, 0x2A, 0x30, 0x50, 0x52, 0x63, 0x5B, 0x5F, 0x57, 0x45, 0x3B, 0x38, 0x35, 0x56, 0x55, 0x65, 0x5C, 0x6C, 0x61, 0x6E, 0x60, 0x6A, 0x5E, 0x6D, 0x61, 0x6C, 0x5F, 0x6D, 0x61, 0x6B, 0x5F, 0x69, 0x5E, 0x6B, 0x5E, 0x69, 0x5D, 0x6C, 0x61, 0x6B, 0x5E, 0x6E, 0x62, 0x6D, 0x5F, 0x6B, 0x5D, 0x6C, 0x5E, 0x6C, 0x60, 0x6B, 0x5F, 0x6C, 0x60, 0x6D, 0x60, 0x6F, 0x62, 0x6D, 0x5F, 0x6F, 0x5F, 0x6D, 0x5F, 0x6D, 0x60, 0x6C, 0x60, 0x6E, 0x61, 0x6C, 0x5F, 0x6D, 0x5F, 0x6C, 0x5E, 0x6C, 0x5F, 0x6D, 0x61, 0x6C, 0x5F, 0x6C, 0x5E, 0x6D, 0x5F, 0x6E, 0x62, 0x72, 0x64, 0x70, 0x62, 0x6D, 0x5F, 0x6D, 0x61, 0x6C, 0x5F, 0x68, 0x5C, 0x6A, 0x5F, 0x6C, 0x5E, 0x6D, 0x5F, 0x6D, 0x61, 0x6F, 0x60, 0x6A, 0x5E, 0x69, 0x5E, 0x6A, 0x5D, 0x6A, 0x60, 0x6E, 0x60, 0x6D, 0x5F, 0x68, 0x5C, 0x69, 0x5F, 0x68, 0x5C, 0x68, 0x5B, 0x68, 0x5C, 0x6C, 0x5F, 0x6A, 0x5F, 0x68, 0x5C, 0x69, 0x5D, 0x66, 0x5B, 0x65, 0x59, 0x6A, 0x5D, 0x6C, 0x61, 0x6F, 0x61, 0x6E, 0x61, 0x6A, 0x5C, 0x6D, 0x5F, 0x6B, 0x5D, 0x6D, 0x5F, 0x69, 0x5D, 0x6A, 0x60, 0x69, 0x5D, 0x6A, 0x5E, 0x67, 0x59, 0x64, 0x58, 0x67, 0x5B, 0x68, 0x5C, 0x67, 0x5C, 0x67, 0x5A, 0x69, 0x5D, 0x6B, 0x5F, 0x6B, 0x5F, 0x6B, 0x60, 0x68, 0x5D, 0x68, 0x5D, 0x66, 0x5A, 0x68, 0x5B, 0x63, 0x5A, 0x67, 0x5D, 0x69, 0x5E, 0x66, 0x5C, 0x66, 0x5B, 0x6A, 0x5D, 0x64, 0x59, 0x64, 0x59, 0x64, 0x5A, 0x62, 0x58, 0x66, 0x5A, 0x64, 0x57, 0x62, 0x58, 0x66, 0x5B, 0x65, 0x59, 0x66, 0x5A, 0x63, 0x58, 0x63, 0x56, 0x64, 0x5A, 0x65, 0x5B, 0x62, 0x57, 0x62, 0x57, 0x5F, 0x54, 0x5E, 0x54, 0x62, 0x56, 0x5F, 0x54, 0x41, 0x3A, 0x2E, 0x2D, 0x28, 0x2C, 0x2F, 0x32, 0x2C, 0x31, 0x2A, 0x2E, 0x30, 0x37, 0x30, 0x37, 0x35, 0x3B, 0x2B, 0x30, 0x2F, 0x35, 0x30, 0x3A, 0x35, 0x3E, 0x31, 0x35, 0x28, 0x2C, 0x34, 0x39, 0x32, 0x39, 0x35, 0x3B, 0x2A, 0x2E, 0x32, 0x39, 0x31, 0x36, 0x34, 0x39, 0x2B, 0x2E, 0x2B, 0x32, 0x2D, 0x2E, 0x2C, 0x32, 0x27, 0x2A, 0x2B, 0x31, 0x31, 0x35, 0x2A, 0x2E, 0x26, 0x28, 0x2B, 0x30, 0x26, 0x26, 0x26, 0x2C, 0x2B, 0x2D, 0x24, 0x27, 0x28, 0x2B, 0x26, 0x29, 0x2A, 0x2C, 0x29, 0x2F, 0x2F, 0x33, 0x2C, 0x33, 0x2D, 0x2E, 0x2A, 0x2F, 0x2A, 0x2A, 0x28, 0x2E
    },

    {
        0x1A, 0x11, 0x1B, 0x11, 0x21, 0x15, 0x2E, 0x1D, 0x4A, 0x2A, 0x64, 0x33, 0x70, 0x37, 0x76, 0x39, 0x7B, 0x3B, 0x7D, 0x3C, 0x7E, 0x3D, 0x80, 0x3E, 0x80, 0x3F, 0x82, 0x3F, 0x80, 0x3D, 0x77, 0x39, 0x61, 0x2E, 0x40, 0x20, 0x2B, 0x19, 0x23, 0x15, 0x1E, 0x13, 0x1C, 0x12, 0x19, 0x11, 0x18, 0x11, 0x17, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x17, 0x10, 0x16, 0x0F, 0x16, 0x10, 0x17, 0x10, 0x18, 0x12, 0x19, 0x12, 0x18, 0x11, 0x17, 0x11, 0x18, 0x11, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x17, 0x10, 0x18, 0x12, 0x1D, 0x16, 0x2D, 0x27, 0x5A, 0x4A, 0x8B, 0x65, 0x9A, 0x6F, 0xA2, 0x74, 0xA8, 0x77, 0xAC, 0x7A, 0xAF, 0x7D, 0xB4, 0x7D, 0xB1, 0x7B, 0xA3, 0x6D, 0x78, 0x4C, 0x44, 0x2C, 0x2F, 0x21, 0x28, 0x1B, 0x22, 0x18, 0x1F, 0x16, 0x1E, 0x15, 0x1D, 0x15, 0x1E, 0x18, 0x31, 0x29, 0x63, 0x4C, 0x92, 0x67, 0xA1, 0x6E, 0xA9, 0x75, 0xAE, 0x77, 0xAE, 0x78, 0xAF, 0x78, 0xAF, 0x79, 0xB1, 0x7A, 0xB3, 0x7A, 0xB2, 0x7B, 0xB3, 0x7B, 0xB2, 0x7A, 0xB2, 0x7A, 0xB4, 0x7C, 0xB5, 0x7E, 0xB7, 0x7E, 0xB4, 0x7A, 0xB2, 0x7C, 0xB5, 0x7D, 0xB3, 0x7C, 0xB5, 0x7B, 0xB5, 0x7B, 0xB4, 0x79, 0x93, 0x5B, 0x4D, 0x30, 0x2E, 0x1E, 0x23, 0x18, 0x1E, 0x15, 0x1A, 0x12, 0x18, 0x11, 0x17, 0x11, 0x19, 0x12, 0x24, 0x20, 0x5D, 0x4C, 0x9C, 0x6F, 0xA8, 0x74, 0x8E, 0x5C, 0x51, 0x33, 0x2C, 0x1E, 0x21, 0x17, 0x1C, 0x13, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x19, 0x11, 0x19, 0x11, 0x19, 0x11, 0x19, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x10, 0x18, 0x11, 0x17, 0x11, 0x17, 0x10, 0x17, 0x11, 0x18, 0x11, 0x18, 0x10, 0x17, 0x11, 0x17, 0x10, 0x17, 0x10, 0x18, 0x12, 0x19, 0x11, 0x19, 0x11, 0x19, 0x11, 0x19, 0x11, 0x1C, 0x14, 0x1E, 0x14, 0x1A, 0x11, 0x18, 0x11, 0x18, 0x10, 0x18, 0x11, 0x1B, 0x14, 0x1A, 0x13, 0x19, 0x11, 0x19, 0x11, 0x19, 0x11, 0x18, 0x11, 0x17, 0x10, 0x18, 0x11, 0x22, 0x14, 0x4A, 0x1E, 0x5A, 0x21, 0x5E, 0x22, 0x4C, 0x1F, 0x31, 0x1A, 0x4B, 0x1F, 0x5F, 0x24, 0x62, 0x23, 0x66, 0x25, 0x61, 0x22, 0x5E, 0x21, 0x61, 0x22, 0x5E, 0x21, 0x5E, 0x22, 0x5F, 0x22, 0x63, 0x24, 0x63, 0x23, 0x5E, 0x21, 0x64, 0x24, 0x60, 0x24, 0x5F, 0x23, 0x5F, 0x22, 0x5E, 0x22, 0x62, 0x22, 0x5D, 0x21, 0x61, 0x22, 0x61, 0x23, 0x60, 0x22, 0x5F, 0x24, 0x66, 0x24, 0x64, 0x23, 0x64, 0x24, 0x62, 0x23, 0x64, 0x24, 0x61, 0x23, 0x60, 0x22, 0x61, 0x22, 0x5F, 0x22, 0x62, 0x23, 0x64, 0x23, 0x5E, 0x22, 0x61, 0x23, 0x60, 0x22, 0x61, 0x23, 0x66, 0x25, 0x65, 0x23, 0x61, 0x23, 0x62, 0x24, 0x63, 0x25, 0x5E, 0x22, 0x5D, 0x21, 0x5F, 0x22, 0x60, 0x23, 0x60, 0x22, 0x5F, 0x21, 0x5F, 0x22, 0x5B, 0x21, 0x5D, 0x21, 0x5E, 0x21, 0x5E, 0x22, 0x5D, 0x23, 0x60, 0x23, 0x60, 0x23, 0x63, 0x23, 0x60, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x5E, 0x21, 0x5C, 0x21, 0x59, 0x20, 0x5E, 0x21, 0x5B, 0x21, 0x5C, 0x20, 0x5D, 0x21, 0x5F, 0x22, 0x63, 0x23, 0x5E, 0x22, 0x5E, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x5C, 0x21, 0x5A, 0x20, 0x5A, 0x21, 0x5F, 0x23, 0x5C, 0x21, 0x5C, 0x21, 0x5C, 0x21, 0x5B, 0x21, 0x5D, 0x22, 0x59, 0x20, 0x5B, 0x21, 0x5F, 0x22, 0x5D, 0x21, 0x5E, 0x22, 0x59, 0x21, 0x5B, 0x21, 0x5E, 0x23, 0x5E, 0x24, 0x60, 0x24, 0x5D, 0x24, 0x5F, 0x23, 0x5E, 0x23, 0x5E, 0x23, 0x5A, 0x22, 0x5B, 0x21, 0x5A, 0x21, 0x5B, 0x21, 0x5E, 0x22, 0x5A, 0x22, 0x59, 0x20, 0x5A, 0x21, 0x5B, 0x21, 0x57, 0x21, 0x57, 0x20, 0x57, 0x20, 0x56, 0x20, 0x57, 0x20, 0x57, 0x20, 0x56, 0x1F, 0x54, 0x1F, 0x54, 0x1E, 0x53, 0x1E, 0x53, 0x1E, 0x3E, 0x1B, 0x38, 0x1D, 0x38, 0x1E, 0x38, 0x1E, 0x38, 0x1D, 0x30, 0x1B, 0x40, 0x21, 0x37, 0x1E, 0x37, 0x1D, 0x28, 0x18, 0x34, 0x1D, 0x30, 0x1B, 0x30, 0x1B, 0x2D, 0x19, 0x2B, 0x1A, 0x37, 0x1D, 0x28, 0x17, 0x2B, 0x18, 0x26, 0x17, 0x33, 0x1C, 0x28, 0x18, 0x2D, 0x19, 0x27, 0x16, 0x30, 0x1A, 0x27, 0x16, 0x2D, 0x19, 0x26, 0x16, 0x2C, 0x18, 0x26, 0x15, 0x27, 0x17, 0x26, 0x17, 0x2E, 0x1A, 0x2B, 0x18, 0x2E, 0x1B, 0x2F, 0x19, 0x36, 0x1D, 0x37, 0x1D, 0x30, 0x1A, 0x3C, 0x1F, 0x3A, 0x1E, 0x2F, 0x1A, 0x33, 0x1B, 0x2E, 0x19, 0x2C, 0x19, 0x34, 0x1C, 0x3D, 0x20
    },

    {
        0x18, 0x1A, 0x18, 0x1A, 0x1B, 0x1F, 0x24, 0x2B, 0x37, 0x45, 0x51, 0x60, 0x61, 0x6C, 0x69, 0x73, 0x6E, 0x77, 0x72, 0x79, 0x74, 0x7B, 0x76, 0x7C, 0x77, 0x7D, 0x76, 0x7E, 0x71, 0x7A, 0x68, 0x6E, 0x54, 0x54, 0x36, 0x35, 0x24, 0x26, 0x1C, 0x1F, 0x19, 0x1C, 0x16, 0x1A, 0x15, 0x18, 0x13, 0x17, 0x13, 0x17, 0x13, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x11, 0x16, 0x12, 0x16, 0x13, 0x18, 0x14, 0x18, 0x13, 0x17, 0x13, 0x18, 0x13, 0x17, 0x12, 0x16, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x12, 0x16, 0x13, 0x17, 0x15, 0x1B, 0x1A, 0x29, 0x2A, 0x53, 0x3F, 0x81, 0x4A, 0x94, 0x4F, 0x9B, 0x52, 0xA3, 0x54, 0xA5, 0x55, 0xA9, 0x57, 0xAA, 0x55, 0xA8, 0x50, 0x92, 0x3B, 0x61, 0x25, 0x37, 0x1E, 0x2A, 0x1A, 0x24, 0x18, 0x1F, 0x17, 0x1D, 0x16, 0x1C, 0x18, 0x1C, 0x1C, 0x22, 0x2C, 0x3D, 0x51, 0x73, 0x71, 0x95, 0x7B, 0x9E, 0x82, 0xA7, 0x86, 0xAA, 0x87, 0xAB, 0x87, 0xAC, 0x88, 0xAB, 0x89, 0xAB, 0x8A, 0xAC, 0x89, 0xAD, 0x8A, 0xAE, 0x8A, 0xAE, 0x8A, 0xAD, 0x89, 0xAE, 0x8B, 0xB0, 0x8D, 0xB2, 0x8A, 0xAE, 0x8A, 0xAF, 0x8D, 0xB0, 0x8C, 0xAF, 0x8B, 0xAF, 0x8A, 0xAF, 0x89, 0xAF, 0x78, 0x94, 0x4B, 0x51, 0x2B, 0x2E, 0x1F, 0x23, 0x1A, 0x1E, 0x16, 0x1A, 0x13, 0x18, 0x13, 0x17, 0x14, 0x18, 0x18, 0x22, 0x2A, 0x54, 0x47, 0x91, 0x4F, 0x9A, 0x44, 0x73, 0x2A, 0x3A, 0x1B, 0x26, 0x17, 0x1E, 0x15, 0x19, 0x14, 0x17, 0x13, 0x17, 0x14, 0x18, 0x13, 0x18, 0x14, 0x18, 0x15, 0x19, 0x15, 0x19, 0x14, 0x19, 0x13, 0x18, 0x14, 0x17, 0x13, 0x17, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x13, 0x18, 0x13, 0x18, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x14, 0x18, 0x14, 0x19, 0x15, 0x19, 0x15, 0x19, 0x15, 0x1A, 0x16, 0x1D, 0x1A, 0x1F, 0x15, 0x18, 0x14, 0x17, 0x14, 0x17, 0x14, 0x17, 0x14, 0x18, 0x15, 0x19, 0x15, 0x18, 0x14, 0x19, 0x15, 0x18, 0x15, 0x18, 0x15, 0x17, 0x18, 0x19, 0x2A, 0x2E, 0x51, 0x52, 0x63, 0x5C, 0x5F, 0x5A, 0x47, 0x3C, 0x36, 0x34, 0x56, 0x54, 0x68, 0x5D, 0x6C, 0x61, 0x70, 0x63, 0x6E, 0x5E, 0x69, 0x5D, 0x6C, 0x5F, 0x69, 0x5D, 0x6B, 0x5D, 0x68, 0x5F, 0x6E, 0x62, 0x6C, 0x60, 0x6B, 0x5B, 0x6E, 0x62, 0x6B, 0x61, 0x6A, 0x5E, 0x6B, 0x5E, 0x6D, 0x5F, 0x6D, 0x61, 0x69, 0x5C, 0x6C, 0x5F, 0x6B, 0x5F, 0x6C, 0x60, 0x6D, 0x61, 0x72, 0x64, 0x71, 0x64, 0x71, 0x63, 0x6F, 0x63, 0x70, 0x63, 0x6D, 0x60, 0x6D, 0x5F, 0x6F, 0x60, 0x6D, 0x5F, 0x6F, 0x60, 0x70, 0x61, 0x6A, 0x5E, 0x6E, 0x5F, 0x6D, 0x5E, 0x6D, 0x61, 0x72, 0x66, 0x74, 0x62, 0x6F, 0x61, 0x6D, 0x61, 0x6D, 0x61, 0x6B, 0x5E, 0x6A, 0x5E, 0x6B, 0x5E, 0x6D, 0x60, 0x6E, 0x5E, 0x6D, 0x5F, 0x69, 0x5D, 0x69, 0x5C, 0x69, 0x5E, 0x69, 0x5D, 0x67, 0x5C, 0x6A, 0x5E, 0x6B, 0x5F, 0x6C, 0x61, 0x6C, 0x62, 0x6E, 0x61, 0x6B, 0x5F, 0x6B, 0x5F, 0x69, 0x5D, 0x66, 0x59, 0x63, 0x59, 0x68, 0x5C, 0x69, 0x5D, 0x69, 0x5C, 0x67, 0x5A, 0x6B, 0x5E, 0x6E, 0x61, 0x6C, 0x5E, 0x6B, 0x5F, 0x6D, 0x61, 0x6A, 0x5E, 0x6D, 0x5F, 0x68, 0x5C, 0x67, 0x5A, 0x68, 0x5C, 0x6C, 0x60, 0x68, 0x5B, 0x67, 0x5C, 0x69, 0x5D, 0x66, 0x5A, 0x69, 0x5B, 0x67, 0x5B, 0x67, 0x59, 0x6B, 0x5D, 0x67, 0x5C, 0x69, 0x5C, 0x66, 0x5A, 0x67, 0x5B, 0x68, 0x5E, 0x69, 0x5F, 0x6B, 0x5F, 0x67, 0x5D, 0x68, 0x5C, 0x6A, 0x5E, 0x69, 0x5F, 0x63, 0x59, 0x65, 0x5A, 0x65, 0x58, 0x68, 0x5C, 0x68, 0x5D, 0x64, 0x5A, 0x63, 0x58, 0x65, 0x5A, 0x64, 0x5A, 0x63, 0x56, 0x63, 0x59, 0x61, 0x56, 0x62, 0x57, 0x61, 0x55, 0x63, 0x57, 0x5F, 0x55, 0x62, 0x55, 0x5F, 0x53, 0x5D, 0x51, 0x5C, 0x51, 0x41, 0x3A, 0x37, 0x3B, 0x33, 0x37, 0x32, 0x38, 0x30, 0x33, 0x2A, 0x30, 0x36, 0x3C, 0x2D, 0x33, 0x2D, 0x31, 0x24, 0x27, 0x2D, 0x32, 0x29, 0x2C, 0x2A, 0x2D, 0x27, 0x28, 0x28, 0x2E, 0x2D, 0x2F, 0x25, 0x28, 0x26, 0x26, 0x24, 0x27, 0x2C, 0x2F, 0x25, 0x28, 0x28, 0x2A, 0x25, 0x26, 0x2A, 0x2E, 0x24, 0x26, 0x2A, 0x2D, 0x24, 0x26, 0x29, 0x2C, 0x22, 0x24, 0x25, 0x29, 0x25, 0x29, 0x2D, 0x31, 0x2A, 0x2C, 0x2C, 0x32, 0x2A, 0x2F, 0x33, 0x38, 0x31, 0x37, 0x2B, 0x2F, 0x38, 0x3F, 0x33, 0x36, 0x29, 0x2C, 0x2C, 0x30, 0x2B, 0x2F, 0x27, 0x2C, 0x31, 0x38, 0x35, 0x3B
    },

    {
        0x1A, 0x11, 0x19, 0x10, 0x1B, 0x12, 0x1F, 0x14, 0x2A, 0x1B, 0x44, 0x27, 0x63, 0x33, 0x71, 0x38, 0x77, 0x3A, 0x7A, 0x3B, 0x7E, 0x3D, 0x7E, 0x3D, 0x80, 0x3F, 0x80, 0x3E, 0x79, 0x3A, 0x63, 0x2F, 0x44, 0x22, 0x2C, 0x19, 0x24, 0x16, 0x1F, 0x14, 0x1C, 0x12, 0x1B, 0x12, 0x18, 0x11, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x16, 0x11, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x17, 0x10, 0x16, 0x10, 0x17, 0x10, 0x16, 0x10, 0x16, 0x0F, 0x16, 0x10, 0x17, 0x10, 0x17, 0x11, 0x17, 0x11, 0x18, 0x12, 0x1C, 0x15, 0x27, 0x21, 0x4C, 0x3F, 0x81, 0x60, 0x9B, 0x6F, 0xA5, 0x75, 0xA9, 0x79, 0xAC, 0x79, 0xAA, 0x78, 0xA1, 0x6E, 0x7E, 0x4F, 0x4A, 0x2E, 0x31, 0x21, 0x29, 0x1B, 0x23, 0x18, 0x20, 0x16, 0x1E, 0x15, 0x1B, 0x14, 0x1E, 0x17, 0x30, 0x28, 0x5E, 0x4A, 0x8E, 0x65, 0x9F, 0x6D, 0xA5, 0x72, 0xAB, 0x75, 0xAE, 0x79, 0xB4, 0x7A, 0xB0, 0x79, 0xB1, 0x79, 0xB1, 0x7B, 0xB2, 0x79, 0xB2, 0x7A, 0xB2, 0x79, 0xB1, 0x7A, 0xB5, 0x7B, 0xB4, 0x7D, 0xB4, 0x7C, 0xB4, 0x7D, 0xB4, 0x7B, 0xB6, 0x7C, 0xB4, 0x7C, 0xB5, 0x7D, 0xB4, 0x7D, 0xB6, 0x7D, 0xB6, 0x7E, 0xB6, 0x7C, 0x9C, 0x62, 0x56, 0x34, 0x2F, 0x1F, 0x25, 0x18, 0x1F, 0x15, 0x1B, 0x13, 0x18, 0x11, 0x18, 0x12, 0x1A, 0x12, 0x1F, 0x1B, 0x49, 0x40, 0x77, 0x4F, 0x4B, 0x2F, 0x2A, 0x1C, 0x22, 0x17, 0x1D, 0x14, 0x19, 0x12, 0x18, 0x11, 0x18, 0x11, 0x19, 0x11, 0x19, 0x12, 0x1A, 0x12, 0x1B, 0x13, 0x1A, 0x11, 0x19, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x19, 0x11, 0x19, 0x12, 0x1A, 0x12, 0x18, 0x11, 0x17, 0x10, 0x18, 0x10, 0x18, 0x11, 0x19, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x1A, 0x12, 0x19, 0x12, 0x1A, 0x11, 0x18, 0x11, 0x18, 0x11, 0x1A, 0x13, 0x22, 0x16, 0x19, 0x11, 0x18, 0x10, 0x17, 0x10, 0x18, 0x11, 0x18, 0x11, 0x17, 0x10, 0x19, 0x11, 0x1A, 0x11, 0x19, 0x11, 0x19, 0x11, 0x1A, 0x11, 0x20, 0x15, 0x49, 0x1E, 0x5C, 0x22, 0x60, 0x23, 0x49, 0x1D, 0x2D, 0x18, 0x43, 0x1D, 0x5B, 0x22, 0x60, 0x22, 0x63, 0x23, 0x60, 0x21, 0x60, 0x21, 0x5C, 0x21, 0x5F, 0x21, 0x5C, 0x21, 0x61, 0x22, 0x60, 0x23, 0x62, 0x23, 0x5E, 0x22, 0x60, 0x22, 0x63, 0x23, 0x63, 0x23, 0x5E, 0x22, 0x61, 0x23, 0x63, 0x24, 0x63, 0x23, 0x61, 0x21, 0x61, 0x23, 0x60, 0x22, 0x61, 0x22, 0x62, 0x23, 0x62, 0x23, 0x61, 0x23, 0x64, 0x24, 0x65, 0x24, 0x65, 0x24, 0x61, 0x23, 0x5E, 0x22, 0x61, 0x22, 0x5F, 0x21, 0x60, 0x22, 0x61, 0x23, 0x61, 0x23, 0x61, 0x22, 0x62, 0x22, 0x63, 0x23, 0x63, 0x23, 0x66, 0x24, 0x63, 0x23, 0x63, 0x23, 0x62, 0x23, 0x5E, 0x22, 0x61, 0x23, 0x60, 0x21, 0x5F, 0x23, 0x5F, 0x21, 0x5E, 0x22, 0x62, 0x23, 0x62, 0x23, 0x5E, 0x22, 0x5E, 0x22, 0x5D, 0x22, 0x5E, 0x22, 0x5E, 0x22, 0x5A, 0x21, 0x5A, 0x22, 0x5D, 0x24, 0x5B, 0x22, 0x60, 0x23, 0x5E, 0x21, 0x5C, 0x21, 0x5E, 0x21, 0x5C, 0x22, 0x60, 0x23, 0x5E, 0x22, 0x5E, 0x22, 0x5E, 0x22, 0x5F, 0x22, 0x62, 0x24, 0x62, 0x24, 0x60, 0x23, 0x60, 0x23, 0x61, 0x22, 0x5F, 0x23, 0x5D, 0x22, 0x5D, 0x21, 0x5F, 0x22, 0x5D, 0x21, 0x60, 0x23, 0x5E, 0x22, 0x5B, 0x21, 0x58, 0x20, 0x5B, 0x20, 0x57, 0x20, 0x5A, 0x21, 0x5C, 0x21, 0x5F, 0x24, 0x5A, 0x22, 0x5B, 0x22, 0x5F, 0x23, 0x5D, 0x23, 0x5F, 0x23, 0x5F, 0x23, 0x61, 0x24, 0x60, 0x23, 0x5F, 0x23, 0x5B, 0x23, 0x59, 0x20, 0x59, 0x21, 0x5A, 0x22, 0x5C, 0x22, 0x5C, 0x22, 0x5F, 0x23, 0x5D, 0x22, 0x55, 0x1F, 0x5A, 0x21, 0x59, 0x20, 0x59, 0x20, 0x58, 0x20, 0x56, 0x1F, 0x56, 0x1F, 0x54, 0x1F, 0x57, 0x20, 0x55, 0x20, 0x55, 0x1F, 0x53, 0x1E, 0x43, 0x1E, 0x3D, 0x1E, 0x2B, 0x19, 0x35, 0x1D, 0x27, 0x17, 0x2F, 0x1B, 0x31, 0x1A, 0x28, 0x18, 0x2B, 0x18, 0x30, 0x1B, 0x30, 0x1B, 0x2F, 0x1B, 0x2E, 0x19, 0x2B, 0x19, 0x35, 0x1C, 0x29, 0x18, 0x2B, 0x1A, 0x2C, 0x19, 0x33, 0x1C, 0x2F, 0x1A, 0x2B, 0x18, 0x2E, 0x19, 0x2D, 0x1A, 0x2A, 0x18, 0x2D, 0x19, 0x33, 0x1C, 0x33, 0x1C, 0x33, 0x1B, 0x30, 0x19, 0x34, 0x1C, 0x36, 0x1C, 0x39, 0x1E, 0x2F, 0x19, 0x38, 0x1F, 0x37, 0x1E, 0x30, 0x1A, 0x35, 0x1D, 0x2B, 0x19, 0x39, 0x1E, 0x2A, 0x18, 0x27, 0x17, 0x32, 0x1B, 0x36, 0x1D, 0x2C, 0x19, 0x35, 0x1C, 0x31, 0x1A
    },

    {
        0x18, 0x1A, 0x17, 0x19, 0x17, 0x1A, 0x1A, 0x1D, 0x21, 0x27, 0x32, 0x40, 0x4D, 0x5E, 0x62, 0x6E, 0x6A, 0x75, 0x6D, 0x76, 0x71, 0x7A, 0x73, 0x7B, 0x73, 0x7C, 0x70, 0x7A, 0x6A, 0x70, 0x58, 0x57, 0x38, 0x37, 0x24, 0x27, 0x1D, 0x21, 0x19, 0x1C, 0x17, 0x1A, 0x15, 0x19, 0x13, 0x17, 0x13, 0x17, 0x12, 0x16, 0x12, 0x15, 0x12, 0x16, 0x12, 0x16, 0x12, 0x17, 0x13, 0x17, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x11, 0x16, 0x12, 0x16, 0x12, 0x16, 0x11, 0x15, 0x11, 0x15, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x13, 0x18, 0x13, 0x1A, 0x18, 0x23, 0x24, 0x45, 0x3C, 0x7A, 0x4A, 0x94, 0x4F, 0x9E, 0x52, 0xA0, 0x53, 0xA3, 0x52, 0xA2, 0x4C, 0x90, 0x3E, 0x65, 0x27, 0x3A, 0x1E, 0x2B, 0x1B, 0x24, 0x18, 0x20, 0x17, 0x1E, 0x16, 0x1B, 0x16, 0x1A, 0x1C, 0x21, 0x2B, 0x3D, 0x4D, 0x71, 0x6F, 0x93, 0x7B, 0x9E, 0x7F, 0xA3, 0x83, 0xA6, 0x87, 0xAA, 0x89, 0xAD, 0x89, 0xAC, 0x89, 0xAC, 0x8B, 0xAF, 0x8A, 0xAD, 0x89, 0xAC, 0x89, 0xAC, 0x8A, 0xAD, 0x8B, 0xB0, 0x8B, 0xB0, 0x8C, 0xAF, 0x8C, 0xB0, 0x8A, 0xB0, 0x8A, 0xAF, 0x8B, 0xAE, 0x8B, 0xB0, 0x8C, 0xB1, 0x8C, 0xB0, 0x8C, 0xB5, 0x8A, 0xB1, 0x7C, 0x9A, 0x52, 0x59, 0x2E, 0x31, 0x21, 0x25, 0x1C, 0x1F, 0x17, 0x1B, 0x14, 0x18, 0x14, 0x18, 0x14, 0x19, 0x16, 0x1E, 0x24, 0x41, 0x36, 0x5E, 0x26, 0x35, 0x1A, 0x23, 0x17, 0x1E, 0x15, 0x1B, 0x14, 0x18, 0x13, 0x18, 0x14, 0x18, 0x14, 0x19, 0x14, 0x19, 0x15, 0x1B, 0x15, 0x1B, 0x15, 0x1A, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x14, 0x19, 0x14, 0x19, 0x15, 0x19, 0x14, 0x18, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x13, 0x18, 0x14, 0x17, 0x14, 0x17, 0x13, 0x18, 0x15, 0x1A, 0x14, 0x18, 0x15, 0x18, 0x14, 0x17, 0x14, 0x17, 0x15, 0x19, 0x18, 0x1E, 0x15, 0x19, 0x14, 0x17, 0x13, 0x16, 0x14, 0x18, 0x14, 0x17, 0x13, 0x17, 0x14, 0x18, 0x16, 0x1A, 0x15, 0x18, 0x15, 0x19, 0x18, 0x1B, 0x27, 0x2B, 0x51, 0x52, 0x64, 0x5E, 0x64, 0x5B, 0x45, 0x3B, 0x34, 0x2F, 0x4F, 0x4E, 0x67, 0x5C, 0x6C, 0x5F, 0x6E, 0x61, 0x6D, 0x5E, 0x6D, 0x5F, 0x69, 0x5B, 0x6C, 0x5E, 0x6B, 0x5D, 0x6F, 0x60, 0x6E, 0x5F, 0x6E, 0x61, 0x6C, 0x5E, 0x6E, 0x60, 0x6F, 0x63, 0x6F, 0x61, 0x6B, 0x60, 0x6C, 0x60, 0x6E, 0x62, 0x6D, 0x60, 0x6F, 0x60, 0x6E, 0x61, 0x6D, 0x5F, 0x6E, 0x60, 0x6D, 0x60, 0x6E, 0x60, 0x6C, 0x61, 0x6F, 0x62, 0x71, 0x64, 0x70, 0x62, 0x6C, 0x60, 0x69, 0x5D, 0x6F, 0x60, 0x6C, 0x5E, 0x6C, 0x5D, 0x6D, 0x61, 0x6F, 0x62, 0x70, 0x61, 0x70, 0x62, 0x6F, 0x61, 0x6E, 0x61, 0x73, 0x65, 0x71, 0x61, 0x71, 0x63, 0x71, 0x62, 0x6C, 0x5E, 0x6F, 0x61, 0x6D, 0x5D, 0x69, 0x5D, 0x6B, 0x5E, 0x6C, 0x5F, 0x6C, 0x61, 0x6E, 0x61, 0x69, 0x5C, 0x6C, 0x5E, 0x6A, 0x5D, 0x69, 0x5D, 0x65, 0x5B, 0x5F, 0x56, 0x5B, 0x55, 0x5E, 0x59, 0x63, 0x5A, 0x6A, 0x5F, 0x68, 0x5E, 0x68, 0x5D, 0x69, 0x5E, 0x66, 0x5B, 0x68, 0x5E, 0x68, 0x5D, 0x6A, 0x5E, 0x6C, 0x5F, 0x69, 0x5C, 0x6D, 0x62, 0x6D, 0x61, 0x6C, 0x5F, 0x6D, 0x5F, 0x6C, 0x5E, 0x6A, 0x60, 0x6A, 0x5F, 0x68, 0x5C, 0x67, 0x5D, 0x69, 0x5C, 0x6C, 0x61, 0x69, 0x5C, 0x66, 0x59, 0x65, 0x58, 0x67, 0x5B, 0x64, 0x58, 0x66, 0x5A, 0x67, 0x5C, 0x66, 0x5C, 0x66, 0x5A, 0x66, 0x5D, 0x68, 0x5E, 0x66, 0x5C, 0x69, 0x5E, 0x6A, 0x5F, 0x6A, 0x5F, 0x6B, 0x60, 0x6B, 0x5E, 0x65, 0x59, 0x63, 0x57, 0x63, 0x58, 0x64, 0x5A, 0x67, 0x5B, 0x66, 0x5C, 0x69, 0x5F, 0x67, 0x5A, 0x61, 0x56, 0x65, 0x59, 0x64, 0x58, 0x63, 0x56, 0x63, 0x56, 0x61, 0x55, 0x5F, 0x53, 0x5F, 0x54, 0x63, 0x58, 0x62, 0x56, 0x61, 0x55, 0x5D, 0x52, 0x44, 0x42, 0x35, 0x35, 0x28, 0x2C, 0x2F, 0x31, 0x24, 0x25, 0x2B, 0x31, 0x28, 0x29, 0x26, 0x2A, 0x28, 0x2B, 0x30, 0x35, 0x2B, 0x2F, 0x2C, 0x32, 0x2B, 0x2F, 0x2C, 0x32, 0x31, 0x34, 0x28, 0x2C, 0x28, 0x2D, 0x2A, 0x2D, 0x30, 0x37, 0x2B, 0x2F, 0x2B, 0x2E, 0x2C, 0x30, 0x29, 0x2F, 0x27, 0x2B, 0x2B, 0x2F, 0x2F, 0x36, 0x2E, 0x35, 0x2E, 0x34, 0x2D, 0x31, 0x30, 0x38, 0x2F, 0x36, 0x30, 0x37, 0x29, 0x2C, 0x32, 0x3A, 0x30, 0x34, 0x27, 0x2B, 0x2E, 0x33, 0x26, 0x2D, 0x2F, 0x33, 0x24, 0x27, 0x23, 0x27, 0x2C, 0x33, 0x2E, 0x33, 0x28, 0x2C, 0x2F, 0x34, 0x2A, 0x2D
    },

    {
        0x1B, 0x11, 0x19, 0x10, 0x19, 0x10, 0x1B, 0x11, 0x1E, 0x14, 0x27, 0x19, 0x3F, 0x26, 0x5F, 0x32, 0x72, 0x37, 0x76, 0x3A, 0x79, 0x3B, 0x7C, 0x3C, 0x7D, 0x3D, 0x77, 0x38, 0x65, 0x30, 0x45, 0x22, 0x2C, 0x19, 0x24, 0x16, 0x1F, 0x14, 0x1C, 0x12, 0x19, 0x11, 0x18, 0x11, 0x17, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x0F, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x17, 0x11, 0x17, 0x10, 0x17, 0x11, 0x18, 0x11, 0x18, 0x11, 0x1A, 0x14, 0x23, 0x1D, 0x44, 0x3A, 0x7B, 0x5D, 0x99, 0x6E, 0xA2, 0x73, 0xA4, 0x73, 0x99, 0x66, 0x78, 0x4C, 0x49, 0x2E, 0x30, 0x21, 0x28, 0x1C, 0x22, 0x19, 0x1F, 0x16, 0x1C, 0x15, 0x1B, 0x13, 0x1C, 0x15, 0x2C, 0x26, 0x5C, 0x49, 0x8F, 0x65, 0x9F, 0x6E, 0xA7, 0x73, 0xA8, 0x73, 0xAD, 0x76, 0xAE, 0x79, 0xB2, 0x7A, 0xB4, 0x7B, 0xB6, 0x7C, 0xB4, 0x7B, 0xB2, 0x7A, 0xB1, 0x7A, 0xB3, 0x7B, 0xB4, 0x7B, 0xB4, 0x7C, 0xB5, 0x7D, 0xB6, 0x7B, 0xB3, 0x7C, 0xB3, 0x7D, 0xB3, 0x7C, 0xB4, 0x7D, 0xB5, 0x7D, 0xB7, 0x7D, 0xB9, 0x7D, 0xB6, 0x7D, 0xB5, 0x7C, 0xB1, 0x79, 0xA2, 0x67, 0x60, 0x3A, 0x31, 0x20, 0x25, 0x19, 0x1F, 0x15, 0x1B, 0x13, 0x19, 0x12, 0x18, 0x12, 0x19, 0x12, 0x1D, 0x17, 0x27, 0x1E, 0x24, 0x19, 0x1E, 0x16, 0x1C, 0x14, 0x1B, 0x13, 0x1A, 0x12, 0x1A, 0x13, 0x1A, 0x12, 0x19, 0x12, 0x19, 0x11, 0x19, 0x11, 0x1A, 0x12, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x17, 0x11, 0x1A, 0x12, 0x1A, 0x12, 0x19, 0x12, 0x18, 0x11, 0x18, 0x11, 0x17, 0x11, 0x18, 0x11, 0x17, 0x11, 0x18, 0x11, 0x18, 0x11, 0x1A, 0x12, 0x17, 0x10, 0x16, 0x10, 0x17, 0x10, 0x17, 0x10, 0x18, 0x11, 0x19, 0x11, 0x1A, 0x12, 0x18, 0x11, 0x17, 0x10, 0x18, 0x11, 0x18, 0x10, 0x18, 0x11, 0x19, 0x11, 0x18, 0x11, 0x1A, 0x12, 0x19, 0x11, 0x21, 0x15, 0x44, 0x1D, 0x5A, 0x22, 0x60, 0x23, 0x49, 0x1D, 0x31, 0x19, 0x40, 0x1D, 0x58, 0x21, 0x5F, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x5F, 0x21, 0x5F, 0x22, 0x5D, 0x21, 0x5E, 0x21, 0x5F, 0x23, 0x61, 0x22, 0x61, 0x24, 0x64, 0x24, 0x62, 0x23, 0x63, 0x22, 0x60, 0x22, 0x64, 0x23, 0x62, 0x23, 0x63, 0x23, 0x62, 0x23, 0x63, 0x24, 0x60, 0x23, 0x62, 0x23, 0x65, 0x23, 0x65, 0x24, 0x62, 0x23, 0x63, 0x23, 0x61, 0x23, 0x61, 0x22, 0x62, 0x23, 0x63, 0x24, 0x63, 0x23, 0x5E, 0x21, 0x61, 0x23, 0x62, 0x23, 0x64, 0x23, 0x67, 0x25, 0x63, 0x24, 0x65, 0x24, 0x63, 0x23, 0x61, 0x22, 0x61, 0x23, 0x62, 0x22, 0x61, 0x22, 0x63, 0x22, 0x62, 0x23, 0x64, 0x23, 0x63, 0x23, 0x5F, 0x22, 0x61, 0x22, 0x62, 0x23, 0x5F, 0x22, 0x63, 0x23, 0x62, 0x23, 0x60, 0x24, 0x5D, 0x22, 0x5D, 0x22, 0x5D, 0x23, 0x52, 0x22, 0x49, 0x23, 0x49, 0x23, 0x4A, 0x23, 0x4F, 0x21, 0x5B, 0x23, 0x5E, 0x29, 0x60, 0x2C, 0x5C, 0x27, 0x5A, 0x22, 0x5E, 0x22, 0x5F, 0x22, 0x61, 0x23, 0x5F, 0x22, 0x5E, 0x21, 0x5D, 0x23, 0x5E, 0x22, 0x60, 0x22, 0x63, 0x24, 0x5F, 0x22, 0x61, 0x23, 0x5F, 0x22, 0x5D, 0x21, 0x5F, 0x22, 0x5D, 0x22, 0x61, 0x22, 0x5C, 0x22, 0x5A, 0x20, 0x5A, 0x20, 0x5A, 0x21, 0x5B, 0x20, 0x5B, 0x22, 0x5E, 0x23, 0x5A, 0x22, 0x5B, 0x22, 0x5C, 0x22, 0x5F, 0x24, 0x5F, 0x25, 0x62, 0x27, 0x60, 0x24, 0x59, 0x21, 0x5C, 0x21, 0x5D, 0x22, 0x57, 0x20, 0x59, 0x21, 0x5B, 0x21, 0x5D, 0x22, 0x56, 0x20, 0x5B, 0x22, 0x5B, 0x21, 0x5C, 0x22, 0x5D, 0x22, 0x5B, 0x21, 0x5B, 0x21, 0x58, 0x20, 0x56, 0x20, 0x54, 0x1F, 0x57, 0x20, 0x5A, 0x21, 0x58, 0x21, 0x5B, 0x21, 0x58, 0x22, 0x58, 0x20, 0x47, 0x1F, 0x34, 0x1B, 0x30, 0x1B, 0x30, 0x1B, 0x2E, 0x1B, 0x39, 0x1D, 0x2C, 0x19, 0x31, 0x1C, 0x3B, 0x1F, 0x36, 0x1D, 0x34, 0x1E, 0x32, 0x1C, 0x3F, 0x20, 0x36, 0x1D, 0x32, 0x1B, 0x37, 0x1D, 0x30, 0x1B, 0x39, 0x1D, 0x35, 0x1C, 0x35, 0x1E, 0x31, 0x1A, 0x3A, 0x1F, 0x31, 0x1A, 0x39, 0x1E, 0x33, 0x1C, 0x39, 0x1F, 0x2E, 0x19, 0x2F, 0x1B, 0x2A, 0x18, 0x30, 0x1B, 0x2F, 0x1A, 0x2D, 0x19, 0x28, 0x18, 0x2B, 0x1A, 0x2B, 0x18, 0x27, 0x18, 0x2D, 0x19, 0x2D, 0x1A, 0x32, 0x1C, 0x36, 0x1D, 0x31, 0x1C, 0x37, 0x1E, 0x35, 0x1B, 0x30, 0x1C, 0x37, 0x1D, 0x2E, 0x18
    },

    {
        0x1A, 0x1C, 0x17, 0x18, 0x17, 0x19, 0x17, 0x1A, 0x1A, 0x1E, 0x1F, 0x24, 0x2E, 0x39, 0x49, 0x59, 0x60, 0x6B, 0x69, 0x71, 0x6C, 0x76, 0x6F, 0x78, 0x6F, 0x78, 0x67, 0x6E, 0x56, 0x58, 0x39, 0x37, 0x24, 0x27, 0x1E, 0x20, 0x1A, 0x1D, 0x17, 0x1A, 0x15, 0x19, 0x14, 0x18, 0x13, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x15, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x13, 0x17, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x15, 0x12, 0x15, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x11, 0x16, 0x12, 0x17, 0x12, 0x16, 0x12, 0x16, 0x12, 0x17, 0x12, 0x17, 0x14, 0x18, 0x17, 0x20, 0x22, 0x3E, 0x38, 0x73, 0x49, 0x92, 0x4D, 0x9C, 0x4F, 0x9A, 0x49, 0x8A, 0x3B, 0x61, 0x27, 0x39, 0x1E, 0x2A, 0x1A, 0x24, 0x18, 0x20, 0x16, 0x1C, 0x15, 0x1B, 0x16, 0x1A, 0x1B, 0x1F, 0x29, 0x38, 0x4C, 0x6E, 0x6F, 0x94, 0x7A, 0x9E, 0x7F, 0xA4, 0x82, 0xA7, 0x85, 0xA9, 0x89, 0xAD, 0x8A, 0xAD, 0x8B, 0xAF, 0x8B, 0xAF, 0x8B, 0xAC, 0x8A, 0xAE, 0x89, 0xAD, 0x8B, 0xB0, 0x8C, 0xB0, 0x8B, 0xAF, 0x8A, 0xAF, 0x8A, 0xAF, 0x8C, 0xB0, 0x8B, 0xB0, 0x8B, 0xAE, 0x8B, 0xB1, 0x8D, 0xB2, 0x8D, 0xB1, 0x8C, 0xAF, 0x8B, 0xB2, 0x8B, 0xB0, 0x89, 0xAF, 0x81, 0xA1, 0x5A, 0x64, 0x30, 0x33, 0x22, 0x26, 0x1B, 0x1E, 0x17, 0x1A, 0x15, 0x19, 0x14, 0x18, 0x14, 0x18, 0x15, 0x1B, 0x19, 0x21, 0x18, 0x1F, 0x16, 0x1C, 0x15, 0x1B, 0x15, 0x1A, 0x15, 0x19, 0x16, 0x1B, 0x16, 0x1A, 0x14, 0x19, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x14, 0x19, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x14, 0x17, 0x14, 0x18, 0x15, 0x19, 0x14, 0x19, 0x15, 0x19, 0x14, 0x18, 0x14, 0x18, 0x13, 0x16, 0x14, 0x18, 0x13, 0x17, 0x14, 0x18, 0x14, 0x18, 0x14, 0x19, 0x13, 0x16, 0x13, 0x17, 0x13, 0x17, 0x13, 0x16, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x13, 0x17, 0x14, 0x17, 0x14, 0x18, 0x14, 0x17, 0x14, 0x17, 0x15, 0x18, 0x16, 0x19, 0x18, 0x19, 0x26, 0x2B, 0x50, 0x50, 0x63, 0x5D, 0x63, 0x5A, 0x46, 0x3D, 0x34, 0x31, 0x4D, 0x4B, 0x64, 0x5B, 0x6C, 0x5F, 0x6D, 0x5F, 0x6D, 0x5E, 0x6C, 0x5E, 0x6A, 0x5E, 0x69, 0x5C, 0x6B, 0x5E, 0x6B, 0x5F, 0x6E, 0x60, 0x6E, 0x61, 0x71, 0x63, 0x6F, 0x63, 0x6F, 0x60, 0x6D, 0x5F, 0x6F, 0x63, 0x6D, 0x60, 0x6F, 0x62, 0x70, 0x62, 0x6D, 0x61, 0x6D, 0x5E, 0x6F, 0x62, 0x72, 0x64, 0x72, 0x64, 0x6F, 0x60, 0x70, 0x63, 0x6E, 0x60, 0x6E, 0x62, 0x6E, 0x62, 0x6E, 0x61, 0x6D, 0x60, 0x69, 0x5D, 0x6F, 0x63, 0x70, 0x62, 0x70, 0x64, 0x72, 0x66, 0x72, 0x64, 0x70, 0x64, 0x72, 0x64, 0x6F, 0x60, 0x6F, 0x61, 0x6E, 0x60, 0x6D, 0x60, 0x70, 0x60, 0x6E, 0x60, 0x70, 0x63, 0x70, 0x63, 0x6D, 0x5F, 0x6E, 0x5F, 0x6F, 0x62, 0x6D, 0x60, 0x6E, 0x62, 0x6D, 0x60, 0x6A, 0x5F, 0x67, 0x5A, 0x69, 0x5C, 0x67, 0x5D, 0x54, 0x4F, 0x4A, 0x4A, 0x49, 0x49, 0x48, 0x48, 0x50, 0x4D, 0x5E, 0x5A, 0x60, 0x61, 0x5F, 0x5D, 0x5A, 0x57, 0x5A, 0x53, 0x66, 0x5E, 0x69, 0x5E, 0x6D, 0x61, 0x6A, 0x5E, 0x6B, 0x5E, 0x6A, 0x5D, 0x6B, 0x5F, 0x6C, 0x60, 0x6E, 0x62, 0x6C, 0x5E, 0x6D, 0x60, 0x69, 0x5D, 0x68, 0x5C, 0x6B, 0x5E, 0x68, 0x5C, 0x6C, 0x60, 0x6B, 0x5C, 0x67, 0x58, 0x65, 0x59, 0x65, 0x59, 0x65, 0x59, 0x66, 0x5D, 0x66, 0x5C, 0x63, 0x5A, 0x65, 0x5A, 0x67, 0x5B, 0x6A, 0x60, 0x6C, 0x62, 0x6D, 0x65, 0x6B, 0x5D, 0x64, 0x59, 0x68, 0x5B, 0x69, 0x5C, 0x64, 0x57, 0x66, 0x5B, 0x66, 0x5A, 0x68, 0x5B, 0x62, 0x55, 0x67, 0x5B, 0x63, 0x59, 0x67, 0x5C, 0x67, 0x5B, 0x66, 0x5A, 0x68, 0x5B, 0x64, 0x57, 0x60, 0x55, 0x60, 0x55, 0x60, 0x58, 0x63, 0x58, 0x63, 0x57, 0x67, 0x5A, 0x63, 0x58, 0x62, 0x56, 0x46, 0x42, 0x30, 0x30, 0x2D, 0x32, 0x2C, 0x2D, 0x2D, 0x34, 0x31, 0x35, 0x2A, 0x2E, 0x2D, 0x35, 0x35, 0x3B, 0x2E, 0x32, 0x2F, 0x34, 0x2C, 0x32, 0x36, 0x3B, 0x2E, 0x33, 0x2C, 0x30, 0x31, 0x35, 0x2C, 0x31, 0x34, 0x3A, 0x2D, 0x31, 0x30, 0x37, 0x2B, 0x2E, 0x34, 0x3B, 0x2B, 0x30, 0x33, 0x39, 0x28, 0x2D, 0x32, 0x38, 0x27, 0x2A, 0x2B, 0x2F, 0x26, 0x27, 0x29, 0x30, 0x27, 0x2A, 0x27, 0x2C, 0x24, 0x27, 0x26, 0x2B, 0x27, 0x2C, 0x24, 0x29, 0x29, 0x2B, 0x28, 0x30, 0x2E, 0x37, 0x30, 0x3A, 0x2A, 0x35, 0x2E, 0x3B, 0x2A, 0x36, 0x28, 0x36, 0x2D, 0x38, 0x27, 0x2B
    },

    {
        0x1E, 0x11, 0x1A, 0x10, 0x1A, 0x10, 0x19, 0x10, 0x1A, 0x11, 0x1C, 0x12, 0x25, 0x18, 0x38, 0x23, 0x58, 0x2F, 0x6D, 0x36, 0x73, 0x3A, 0x77, 0x39, 0x73, 0x38, 0x65, 0x2F, 0x46, 0x22, 0x2C, 0x18, 0x23, 0x15, 0x1F, 0x14, 0x1D, 0x12, 0x1A, 0x11, 0x18, 0x11, 0x18, 0x11, 0x17, 0x11, 0x17, 0x10, 0x16, 0x10, 0x16, 0x10, 0x17, 0x10, 0x16, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x0F, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x15, 0x10, 0x16, 0x10, 0x16, 0x10, 0x17, 0x11, 0x18, 0x11, 0x18, 0x11, 0x17, 0x11, 0x18, 0x11, 0x19, 0x13, 0x20, 0x1A, 0x3A, 0x32, 0x71, 0x59, 0x96, 0x6A, 0x96, 0x65, 0x79, 0x4C, 0x48, 0x2D, 0x2E, 0x1F, 0x27, 0x1B, 0x22, 0x18, 0x1F, 0x16, 0x1D, 0x14, 0x1B, 0x13, 0x1C, 0x15, 0x2A, 0x24, 0x56, 0x44, 0x8C, 0x64, 0x9F, 0x6F, 0xA6, 0x73, 0xAA, 0x76, 0xAE, 0x78, 0xB1, 0x78, 0xB2, 0x7A, 0xB3, 0x7B, 0xB4, 0x7C, 0xB5, 0x7C, 0xB4, 0x7C, 0xB4, 0x7B, 0xB6, 0x7C, 0xB5, 0x7C, 0xB7, 0x7D, 0xB4, 0x7C, 0xB5, 0x7C, 0xB5, 0x7F, 0xB7, 0x7F, 0xB8, 0x7E, 0xB6, 0x7C, 0xB6, 0x7E, 0xB7, 0x7E, 0xB6, 0x7E, 0xB6, 0x7E, 0xB7, 0x7D, 0xB6, 0x7D, 0xB7, 0x7D, 0xB6, 0x7B, 0xA5, 0x6C, 0x6B, 0x41, 0x35, 0x23, 0x26, 0x1A, 0x1F, 0x15, 0x1B, 0x13, 0x19, 0x11, 0x19, 0x11, 0x18, 0x11, 0x19, 0x12, 0x1A, 0x13, 0x1A, 0x13, 0x1A, 0x12, 0x1C, 0x13, 0x1A, 0x13, 0x1A, 0x12, 0x19, 0x11, 0x19, 0x12, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x19, 0x12, 0x19, 0x11, 0x19, 0x11, 0x19, 0x11, 0x18, 0x11, 0x17, 0x11, 0x1A, 0x12, 0x1A, 0x12, 0x1A, 0x12, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x10, 0x18, 0x11, 0x17, 0x10, 0x18, 0x11, 0x18, 0x10, 0x17, 0x10, 0x16, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x19, 0x11, 0x18, 0x10, 0x19, 0x11, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x18, 0x11, 0x19, 0x11, 0x19, 0x11, 0x1A, 0x12, 0x21, 0x15, 0x46, 0x1E, 0x5F, 0x23, 0x60, 0x23, 0x4D, 0x1F, 0x2F, 0x18, 0x46, 0x1F, 0x5C, 0x23, 0x61, 0x23, 0x63, 0x23, 0x64, 0x23, 0x60, 0x22, 0x5E, 0x22, 0x61, 0x23, 0x5D, 0x21, 0x60, 0x22, 0x5D, 0x22, 0x62, 0x23, 0x64, 0x24, 0x63, 0x23, 0x61, 0x23, 0x5F, 0x22, 0x61, 0x23, 0x61, 0x23, 0x63, 0x24, 0x61, 0x23, 0x65, 0x24, 0x67, 0x25, 0x63, 0x23, 0x63, 0x23, 0x64, 0x23, 0x63, 0x23, 0x65, 0x24, 0x63, 0x23, 0x63, 0x24, 0x64, 0x23, 0x63, 0x23, 0x63, 0x23, 0x62, 0x22, 0x60, 0x22, 0x62, 0x23, 0x66, 0x23, 0x63, 0x23, 0x64, 0x24, 0x64, 0x24, 0x61, 0x23, 0x63, 0x23, 0x63, 0x23, 0x64, 0x23, 0x64, 0x24, 0x63, 0x23, 0x61, 0x22, 0x60, 0x23, 0x64, 0x24, 0x66, 0x25, 0x63, 0x23, 0x64, 0x24, 0x65, 0x24, 0x63, 0x23, 0x60, 0x24, 0x63, 0x24, 0x5F, 0x23, 0x60, 0x23, 0x60, 0x23, 0x57, 0x23, 0x4A, 0x23, 0x4A, 0x24, 0x4A, 0x24, 0x49, 0x24, 0x48, 0x23, 0x51, 0x2C, 0x5F, 0x36, 0x52, 0x2D, 0x41, 0x24, 0x38, 0x1C, 0x4D, 0x1F, 0x5C, 0x22, 0x5E, 0x23, 0x64, 0x25, 0x5E, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x61, 0x23, 0x5D, 0x21, 0x5F, 0x22, 0x5D, 0x21, 0x5C, 0x21, 0x62, 0x23, 0x5F, 0x22, 0x60, 0x22, 0x60, 0x22, 0x5B, 0x21, 0x59, 0x20, 0x5E, 0x22, 0x5D, 0x21, 0x59, 0x21, 0x58, 0x21, 0x5B, 0x22, 0x5C, 0x23, 0x5C, 0x24, 0x60, 0x25, 0x60, 0x24, 0x5C, 0x23, 0x59, 0x22, 0x5E, 0x23, 0x5D, 0x21, 0x5B, 0x22, 0x5B, 0x21, 0x5A, 0x21, 0x5F, 0x23, 0x59, 0x20, 0x5A, 0x21, 0x5A, 0x20, 0x59, 0x21, 0x5C, 0x21, 0x58, 0x20, 0x5A, 0x20, 0x5B, 0x21, 0x5B, 0x22, 0x59, 0x21, 0x56, 0x21, 0x57, 0x20, 0x59, 0x20, 0x58, 0x21, 0x57, 0x20, 0x56, 0x20, 0x58, 0x21, 0x3E, 0x1B, 0x36, 0x1C, 0x2D, 0x1A, 0x3A, 0x1F, 0x3D, 0x20, 0x31, 0x1A, 0x33, 0x1C, 0x33, 0x1D, 0x39, 0x1E, 0x2E, 0x1C, 0x34, 0x1C, 0x31, 0x1B, 0x36, 0x1D, 0x2C, 0x19, 0x2D, 0x1A, 0x31, 0x1B, 0x2E, 0x1B, 0x36, 0x1C, 0x2B, 0x19, 0x33, 0x1C, 0x2A, 0x19, 0x32, 0x1A, 0x27, 0x17, 0x30, 0x1A, 0x27, 0x17, 0x2C, 0x18, 0x27, 0x17, 0x38, 0x1F, 0x34, 0x1C, 0x3B, 0x20, 0x35, 0x1D, 0x38, 0x20, 0x3B, 0x21, 0x45, 0x25, 0x43, 0x22, 0x2F, 0x1A, 0x3A, 0x1F, 0x33, 0x1D, 0x4D, 0x29, 0x51, 0x2C, 0x51, 0x2C, 0x52, 0x2C, 0x54, 0x2D, 0x52, 0x2D, 0x4A, 0x28, 0x32, 0x1C
    },

    {
        0x1E, 0x1F, 0x19, 0x1A, 0x18, 0x19, 0x16, 0x18, 0x16, 0x19, 0x18, 0x1B, 0x1D, 0x21, 0x29, 0x33, 0x43, 0x52, 0x5B, 0x68, 0x65, 0x6F, 0x67, 0x71, 0x64, 0x6B, 0x55, 0x58, 0x3A, 0x39, 0x24, 0x26, 0x1D, 0x20, 0x19, 0x1C, 0x18, 0x1B, 0x15, 0x18, 0x14, 0x17, 0x13, 0x17, 0x13, 0x16, 0x12, 0x16, 0x12, 0x16, 0x13, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x17, 0x12, 0x16, 0x11, 0x15, 0x12, 0x16, 0x12, 0x17, 0x12, 0x16, 0x12, 0x15, 0x12, 0x16, 0x11, 0x15, 0x11, 0x15, 0x11, 0x15, 0x11, 0x16, 0x12, 0x16, 0x12, 0x17, 0x12, 0x17, 0x12, 0x17, 0x12, 0x16, 0x13, 0x17, 0x13, 0x18, 0x16, 0x1E, 0x1E, 0x34, 0x33, 0x69, 0x46, 0x8C, 0x47, 0x87, 0x3B, 0x63, 0x26, 0x37, 0x1D, 0x28, 0x19, 0x23, 0x18, 0x20, 0x17, 0x1D, 0x15, 0x1B, 0x16, 0x1A, 0x1A, 0x1F, 0x27, 0x36, 0x48, 0x69, 0x6F, 0x95, 0x7C, 0xA0, 0x82, 0xA3, 0x83, 0xA7, 0x86, 0xA9, 0x88, 0xAC, 0x89, 0xAD, 0x8B, 0xAF, 0x8C, 0xB1, 0x8C, 0xB2, 0x8D, 0xAF, 0x8A, 0xAE, 0x8C, 0xB0, 0x8B, 0xB0, 0x8C, 0xB1, 0x8B, 0xB0, 0x8B, 0xB2, 0x8C, 0xB2, 0x8D, 0xB3, 0x8C, 0xB1, 0x8B, 0xAF, 0x8B, 0xB1, 0x8E, 0xB3, 0x8E, 0xB2, 0x8E, 0xB4, 0x8E, 0xB0, 0x8C, 0xB0, 0x8C, 0xB1, 0x8C, 0xB0, 0x83, 0xA5, 0x61, 0x70, 0x35, 0x38, 0x23, 0x27, 0x1C, 0x20, 0x17, 0x1B, 0x15, 0x19, 0x14, 0x19, 0x14, 0x18, 0x14, 0x19, 0x14, 0x19, 0x14, 0x19, 0x14, 0x19, 0x16, 0x1A, 0x15, 0x1A, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x14, 0x17, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x13, 0x18, 0x14, 0x18, 0x13, 0x17, 0x15, 0x1A, 0x15, 0x19, 0x15, 0x19, 0x14, 0x18, 0x13, 0x17, 0x14, 0x18, 0x14, 0x18, 0x13, 0x17, 0x13, 0x16, 0x13, 0x17, 0x13, 0x16, 0x13, 0x17, 0x13, 0x16, 0x12, 0x17, 0x13, 0x16, 0x14, 0x17, 0x14, 0x18, 0x14, 0x17, 0x14, 0x17, 0x13, 0x16, 0x14, 0x17, 0x13, 0x16, 0x14, 0x17, 0x15, 0x18, 0x16, 0x19, 0x18, 0x1A, 0x26, 0x2A, 0x50, 0x51, 0x66, 0x5F, 0x65, 0x5D, 0x49, 0x3E, 0x32, 0x2F, 0x54, 0x51, 0x66, 0x5C, 0x6A, 0x60, 0x6F, 0x62, 0x70, 0x62, 0x6C, 0x5F, 0x6C, 0x5D, 0x6D, 0x60, 0x6A, 0x5F, 0x6C, 0x5F, 0x69, 0x5C, 0x6E, 0x62, 0x70, 0x64, 0x6E, 0x61, 0x6B, 0x5F, 0x6C, 0x5E, 0x6B, 0x60, 0x6B, 0x60, 0x6F, 0x62, 0x6D, 0x61, 0x70, 0x64, 0x72, 0x66, 0x70, 0x62, 0x70, 0x62, 0x72, 0x62, 0x72, 0x62, 0x74, 0x64, 0x70, 0x63, 0x6E, 0x60, 0x6E, 0x62, 0x70, 0x62, 0x6D, 0x60, 0x6E, 0x62, 0x6B, 0x5F, 0x6E, 0x62, 0x70, 0x63, 0x6F, 0x62, 0x71, 0x62, 0x72, 0x64, 0x6C, 0x60, 0x6E, 0x5F, 0x70, 0x63, 0x6F, 0x63, 0x71, 0x63, 0x6F, 0x5F, 0x6E, 0x60, 0x6E, 0x5E, 0x71, 0x64, 0x73, 0x67, 0x6F, 0x60, 0x6F, 0x62, 0x71, 0x63, 0x6F, 0x61, 0x6C, 0x60, 0x6E, 0x63, 0x6B, 0x5E, 0x6B, 0x60, 0x6A, 0x5D, 0x59, 0x4F, 0x4A, 0x48, 0x49, 0x4A, 0x47, 0x4A, 0x46, 0x49, 0x46, 0x48, 0x4B, 0x50, 0x4B, 0x52, 0x47, 0x48, 0x3D, 0x3A, 0x38, 0x33, 0x4C, 0x4A, 0x66, 0x5C, 0x67, 0x5D, 0x6E, 0x64, 0x6C, 0x5E, 0x6D, 0x5F, 0x6C, 0x60, 0x6D, 0x5F, 0x6D, 0x5E, 0x6A, 0x5D, 0x6B, 0x5E, 0x68, 0x5C, 0x68, 0x5B, 0x6D, 0x60, 0x69, 0x5E, 0x6C, 0x5F, 0x6B, 0x5E, 0x65, 0x5B, 0x65, 0x5A, 0x67, 0x5D, 0x6A, 0x5A, 0x63, 0x58, 0x65, 0x5A, 0x66, 0x5A, 0x66, 0x5C, 0x65, 0x5B, 0x68, 0x5F, 0x68, 0x5E, 0x68, 0x5B, 0x65, 0x5B, 0x67, 0x5C, 0x68, 0x5B, 0x67, 0x5B, 0x67, 0x5C, 0x68, 0x5D, 0x6A, 0x5E, 0x67, 0x58, 0x65, 0x5C, 0x65, 0x58, 0x63, 0x5A, 0x66, 0x5B, 0x63, 0x57, 0x66, 0x59, 0x66, 0x5A, 0x67, 0x5C, 0x65, 0x5A, 0x61, 0x57, 0x61, 0x57, 0x63, 0x59, 0x63, 0x58, 0x61, 0x57, 0x62, 0x56, 0x60, 0x55, 0x3F, 0x38, 0x35, 0x37, 0x2A, 0x2E, 0x34, 0x3B, 0x35, 0x3A, 0x2B, 0x2E, 0x2C, 0x30, 0x2B, 0x33, 0x30, 0x33, 0x29, 0x2E, 0x2D, 0x31, 0x2B, 0x32, 0x2B, 0x2F, 0x26, 0x29, 0x29, 0x2F, 0x2B, 0x2B, 0x2A, 0x2F, 0x2D, 0x31, 0x26, 0x2B, 0x2B, 0x31, 0x25, 0x2D, 0x28, 0x2E, 0x22, 0x26, 0x29, 0x2F, 0x24, 0x28, 0x28, 0x2C, 0x25, 0x2A, 0x30, 0x3C, 0x2B, 0x3A, 0x2E, 0x40, 0x29, 0x3C, 0x29, 0x3F, 0x2B, 0x43, 0x30, 0x4B, 0x31, 0x40, 0x29, 0x2F, 0x33, 0x3A, 0x27, 0x33, 0x2C, 0x50, 0x2D, 0x53, 0x2B, 0x55, 0x2A, 0x52, 0x2B, 0x53, 0x2A, 0x53, 0x29, 0x44, 0x25, 0x2E
    },

    {
        0x25, 0x13, 0x1E, 0x11, 0x1B, 0x11, 0x19, 0x10, 0x18, 0x10, 0x19, 0x10, 0x1A, 0x12, 0x20, 0x16, 0x31, 0x1F, 0x51, 0x2C, 0x6A, 0x35, 0x6E, 0x35, 0x62, 0x2F, 0x46, 0x22, 0x2D, 0x18, 0x23, 0x15, 0x1F, 0x13, 0x1C, 0x13, 0x19, 0x11, 0x19, 0x10, 0x18, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x18, 0x10, 0x17, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x0F, 0x16, 0x10, 0x16, 0x10, 0x17, 0x10, 0x16, 0x10, 0x16, 0x0F, 0x15, 0x10, 0x16, 0x10, 0x16, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x18, 0x11, 0x16, 0x10, 0x17, 0x11, 0x17, 0x10, 0x18, 0x11, 0x18, 0x11, 0x19, 0x12, 0x1E, 0x18, 0x31, 0x2C, 0x60, 0x49, 0x6E, 0x47, 0x47, 0x2C, 0x2C, 0x1E, 0x25, 0x1A, 0x21, 0x17, 0x1E, 0x15, 0x1C, 0x14, 0x1B, 0x13, 0x1C, 0x15, 0x28, 0x22, 0x4F, 0x42, 0x88, 0x61, 0xA0, 0x6F, 0xA8, 0x73, 0xAA, 0x75, 0xAC, 0x77, 0xAD, 0x78, 0xB0, 0x7A, 0xB1, 0x7B, 0xB5, 0x7C, 0xB6, 0x7D, 0xB6, 0x7C, 0xB5, 0x7D, 0xB5, 0x7C, 0xB3, 0x7B, 0xB5, 0x7D, 0xB6, 0x7C, 0xB5, 0x7C, 0xB5, 0x7C, 0xB5, 0x7C, 0xB6, 0x7E, 0xB5, 0x7D, 0xB6, 0x7E, 0xB6, 0x7D, 0xB6, 0x7B, 0xB6, 0x7D, 0xB7, 0x7F, 0xB8, 0x7F, 0xB6, 0x7F, 0xB6, 0x7D, 0xB7, 0x7D, 0xB5, 0x7B, 0xAA, 0x71, 0x78, 0x48, 0x3A, 0x25, 0x26, 0x1A, 0x1F, 0x15, 0x1B, 0x13, 0x19, 0x12, 0x18, 0x11, 0x19, 0x11, 0x17, 0x11, 0x17, 0x11, 0x17, 0x10, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x17, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x19, 0x12, 0x19, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x10, 0x18, 0x10, 0x18, 0x11, 0x1A, 0x12, 0x1A, 0x12, 0x19, 0x11, 0x18, 0x11, 0x17, 0x11, 0x19, 0x11, 0x18, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x11, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x18, 0x10, 0x1A, 0x12, 0x19, 0x11, 0x17, 0x10, 0x17, 0x10, 0x18, 0x10, 0x19, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x1A, 0x12, 0x21, 0x15, 0x45, 0x1F, 0x60, 0x24, 0x61, 0x23, 0x51, 0x20, 0x2F, 0x18, 0x3F, 0x1C, 0x5A, 0x21, 0x5D, 0x21, 0x5F, 0x23, 0x61, 0x23, 0x60, 0x23, 0x62, 0x23, 0x60, 0x22, 0x63, 0x23, 0x63, 0x23, 0x62, 0x23, 0x62, 0x23, 0x61, 0x23, 0x65, 0x24, 0x65, 0x24, 0x5E, 0x22, 0x62, 0x23, 0x61, 0x22, 0x64, 0x25, 0x66, 0x24, 0x63, 0x23, 0x64, 0x24, 0x65, 0x24, 0x62, 0x22, 0x64, 0x24, 0x62, 0x23, 0x63, 0x22, 0x66, 0x24, 0x62, 0x23, 0x5F, 0x21, 0x62, 0x24, 0x62, 0x23, 0x61, 0x22, 0x63, 0x22, 0x5F, 0x22, 0x60, 0x23, 0x61, 0x24, 0x60, 0x23, 0x62, 0x23, 0x61, 0x23, 0x65, 0x23, 0x64, 0x24, 0x65, 0x24, 0x61, 0x23, 0x61, 0x23, 0x60, 0x22, 0x61, 0x22, 0x5F, 0x22, 0x65, 0x24, 0x66, 0x24, 0x61, 0x23, 0x63, 0x24, 0x63, 0x25, 0x64, 0x26, 0x62, 0x23, 0x60, 0x22, 0x61, 0x22, 0x5F, 0x22, 0x5D, 0x22, 0x4E, 0x24, 0x4A, 0x25, 0x49, 0x24, 0x49, 0x25, 0x4A, 0x25, 0x47, 0x23, 0x45, 0x22, 0x32, 0x1C, 0x2C, 0x19, 0x2C, 0x19, 0x2B, 0x17, 0x2B, 0x17, 0x52, 0x20, 0x62, 0x23, 0x65, 0x23, 0x60, 0x21, 0x5F, 0x23, 0x5E, 0x22, 0x5D, 0x22, 0x5F, 0x22, 0x5C, 0x22, 0x5D, 0x22, 0x5F, 0x22, 0x5F, 0x23, 0x60, 0x23, 0x5F, 0x22, 0x61, 0x22, 0x5E, 0x21, 0x5B, 0x21, 0x5B, 0x21, 0x5A, 0x21, 0x5E, 0x21, 0x5C, 0x21, 0x5E, 0x23, 0x63, 0x24, 0x60, 0x25, 0x5C, 0x22, 0x5E, 0x24, 0x61, 0x26, 0x5F, 0x25, 0x5F, 0x23, 0x5A, 0x22, 0x5A, 0x21, 0x5C, 0x22, 0x5F, 0x24, 0x60, 0x23, 0x5C, 0x22, 0x5C, 0x22, 0x5C, 0x23, 0x5B, 0x22, 0x58, 0x21, 0x5B, 0x21, 0x5A, 0x20, 0x5B, 0x21, 0x5B, 0x22, 0x5E, 0x23, 0x5E, 0x23, 0x59, 0x21, 0x59, 0x21, 0x58, 0x21, 0x5A, 0x21, 0x58, 0x20, 0x59, 0x20, 0x53, 0x1F, 0x3F, 0x1D, 0x36, 0x1C, 0x2D, 0x1A, 0x35, 0x1E, 0x30, 0x1A, 0x29, 0x18, 0x2C, 0x19, 0x2A, 0x19, 0x2E, 0x1C, 0x2C, 0x1A, 0x2E, 0x1B, 0x30, 0x1C, 0x31, 0x1B, 0x2F, 0x1B, 0x2E, 0x1A, 0x2A, 0x18, 0x33, 0x1D, 0x35, 0x1E, 0x3D, 0x23, 0x40, 0x24, 0x44, 0x27, 0x43, 0x25, 0x46, 0x27, 0x46, 0x25, 0x37, 0x1E, 0x3B, 0x20, 0x35, 0x1C, 0x41, 0x25, 0x51, 0x2D, 0x57, 0x2F, 0x58, 0x30, 0x57, 0x30, 0x57, 0x30, 0x57, 0x2E, 0x39, 0x1E, 0x2B, 0x19, 0x2F, 0x19, 0x32, 0x1F, 0x54, 0x2F, 0x59, 0x30, 0x58, 0x30, 0x56, 0x2F, 0x53, 0x2E, 0x53, 0x2D, 0x43, 0x23, 0x24, 0x17
    },

    {
        0x2B, 0x27, 0x1E, 0x1E, 0x1A, 0x1B, 0x17, 0x19, 0x16, 0x18, 0x16, 0x18, 0x17, 0x1A, 0x1B, 0x1E, 0x25, 0x2D, 0x3C, 0x4B, 0x54, 0x65, 0x5C, 0x65, 0x53, 0x55, 0x39, 0x39, 0x25, 0x26, 0x1D, 0x1F, 0x19, 0x1C, 0x17, 0x1A, 0x16, 0x19, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x12, 0x16, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x12, 0x16, 0x12, 0x15, 0x12, 0x16, 0x11, 0x16, 0x12, 0x15, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x13, 0x16, 0x12, 0x16, 0x12, 0x15, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x17, 0x12, 0x16, 0x12, 0x17, 0x12, 0x15, 0x12, 0x16, 0x12, 0x16, 0x13, 0x17, 0x12, 0x16, 0x13, 0x17, 0x15, 0x1C, 0x1C, 0x2C, 0x2C, 0x53, 0x33, 0x58, 0x25, 0x35, 0x1B, 0x26, 0x19, 0x21, 0x17, 0x1E, 0x16, 0x1D, 0x15, 0x1A, 0x16, 0x1A, 0x1A, 0x1E, 0x26, 0x33, 0x44, 0x62, 0x6B, 0x90, 0x7A, 0x9C, 0x81, 0xA4, 0x83, 0xA6, 0x86, 0xA8, 0x86, 0xA8, 0x88, 0xAD, 0x89, 0xAE, 0x8B, 0xAE, 0x8C, 0xAE, 0x8C, 0xB0, 0x8D, 0xB1, 0x8C, 0xB0, 0x8B, 0xAF, 0x8C, 0xB2, 0x8B, 0xAF, 0x8C, 0xAF, 0x8A, 0xAD, 0x8C, 0xAF, 0x8D, 0xB2, 0x8C, 0xB1, 0x8C, 0xB3, 0x8C, 0xB2, 0x8B, 0xB1, 0x8C, 0xAF, 0x8D, 0xB4, 0x8D, 0xB4, 0x8C, 0xB6, 0x8D, 0xB3, 0x8C, 0xB3, 0x8A, 0xAE, 0x83, 0xA8, 0x69, 0x7A, 0x3A, 0x3C, 0x23, 0x26, 0x1B, 0x1E, 0x16, 0x19, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x14, 0x17, 0x13, 0x17, 0x13, 0x16, 0x14, 0x18, 0x13, 0x17, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x14, 0x17, 0x14, 0x17, 0x13, 0x18, 0x14, 0x19, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x13, 0x17, 0x14, 0x18, 0x14, 0x19, 0x15, 0x1A, 0x14, 0x18, 0x14, 0x18, 0x13, 0x17, 0x14, 0x18, 0x13, 0x17, 0x13, 0x17, 0x13, 0x16, 0x13, 0x17, 0x13, 0x16, 0x13, 0x16, 0x13, 0x16, 0x14, 0x17, 0x15, 0x1A, 0x14, 0x18, 0x14, 0x17, 0x14, 0x16, 0x14, 0x18, 0x15, 0x18, 0x14, 0x17, 0x14, 0x17, 0x15, 0x18, 0x18, 0x1B, 0x26, 0x2A, 0x4E, 0x52, 0x66, 0x60, 0x67, 0x5C, 0x4C, 0x41, 0x33, 0x2E, 0x4C, 0x4B, 0x63, 0x5A, 0x69, 0x5C, 0x6B, 0x5F, 0x6E, 0x5F, 0x6B, 0x5E, 0x6D, 0x62, 0x6D, 0x60, 0x6E, 0x61, 0x70, 0x63, 0x6F, 0x60, 0x6F, 0x61, 0x6E, 0x61, 0x72, 0x66, 0x70, 0x64, 0x6C, 0x5F, 0x6E, 0x62, 0x6E, 0x60, 0x70, 0x66, 0x70, 0x63, 0x71, 0x63, 0x70, 0x63, 0x71, 0x64, 0x70, 0x61, 0x70, 0x64, 0x6F, 0x62, 0x70, 0x61, 0x73, 0x64, 0x6F, 0x60, 0x6C, 0x5E, 0x6F, 0x62, 0x6D, 0x62, 0x6D, 0x60, 0x70, 0x62, 0x6C, 0x5E, 0x6D, 0x60, 0x6A, 0x60, 0x6E, 0x61, 0x6D, 0x60, 0x6D, 0x60, 0x71, 0x64, 0x72, 0x67, 0x71, 0x63, 0x6D, 0x60, 0x6D, 0x60, 0x6D, 0x61, 0x6D, 0x60, 0x6C, 0x60, 0x72, 0x64, 0x70, 0x64, 0x6E, 0x61, 0x72, 0x65, 0x6E, 0x62, 0x6D, 0x64, 0x6D, 0x5F, 0x6D, 0x60, 0x6E, 0x5F, 0x6B, 0x61, 0x68, 0x5C, 0x51, 0x4D, 0x49, 0x49, 0x46, 0x48, 0x46, 0x49, 0x47, 0x4A, 0x46, 0x47, 0x3F, 0x3E, 0x2D, 0x2A, 0x2E, 0x2A, 0x2D, 0x2A, 0x2B, 0x27, 0x2C, 0x2C, 0x5A, 0x55, 0x6C, 0x61, 0x71, 0x62, 0x6B, 0x5D, 0x6A, 0x5D, 0x69, 0x5E, 0x69, 0x5E, 0x6A, 0x5D, 0x68, 0x5D, 0x69, 0x5D, 0x6C, 0x60, 0x6B, 0x5F, 0x6C, 0x60, 0x66, 0x5D, 0x6C, 0x60, 0x69, 0x5C, 0x67, 0x5A, 0x65, 0x5A, 0x66, 0x5A, 0x6B, 0x5C, 0x68, 0x5B, 0x68, 0x5F, 0x6E, 0x62, 0x6B, 0x5E, 0x67, 0x5C, 0x68, 0x5E, 0x6A, 0x60, 0x68, 0x5E, 0x6A, 0x5F, 0x66, 0x5A, 0x66, 0x59, 0x67, 0x5C, 0x69, 0x5F, 0x69, 0x5F, 0x67, 0x5B, 0x6A, 0x5E, 0x68, 0x5D, 0x65, 0x5B, 0x64, 0x59, 0x65, 0x59, 0x66, 0x5B, 0x6A, 0x5C, 0x6B, 0x5F, 0x68, 0x5B, 0x66, 0x5B, 0x63, 0x59, 0x64, 0x59, 0x62, 0x58, 0x65, 0x5A, 0x63, 0x57, 0x64, 0x57, 0x5C, 0x51, 0x41, 0x3B, 0x32, 0x32, 0x2A, 0x2C, 0x30, 0x34, 0x2A, 0x2B, 0x25, 0x2A, 0x27, 0x29, 0x27, 0x2B, 0x27, 0x2F, 0x26, 0x2D, 0x27, 0x31, 0x2A, 0x34, 0x29, 0x35, 0x2A, 0x30, 0x28, 0x2F, 0x28, 0x2B, 0x2F, 0x36, 0x2A, 0x3C, 0x2A, 0x43, 0x2A, 0x46, 0x2B, 0x4E, 0x2A, 0x4A, 0x2A, 0x4C, 0x2C, 0x49, 0x2D, 0x36, 0x32, 0x3C, 0x2B, 0x2F, 0x29, 0x47, 0x2B, 0x53, 0x2C, 0x57, 0x2C, 0x58, 0x2B, 0x58, 0x2C, 0x57, 0x2A, 0x53, 0x21, 0x2E, 0x23, 0x2C, 0x28, 0x2A, 0x25, 0x38, 0x2B, 0x53, 0x2C, 0x55, 0x2A, 0x53, 0x29, 0x51, 0x28, 0x4F, 0x28, 0x4F, 0x22, 0x36, 0x1C, 0x24
    },

    {
        0x3B, 0x17, 0x28, 0x13, 0x1E, 0x11, 0x1B, 0x10, 0x19, 0x10, 0x18, 0x0F, 0x18, 0x10, 0x1A, 0x11, 0x1F, 0x14, 0x2D, 0x1D, 0x49, 0x29, 0x58, 0x2C, 0x45, 0x22, 0x2C, 0x18, 0x23, 0x14, 0x1E, 0x13, 0x1B, 0x12, 0x1A, 0x11, 0x19, 0x11, 0x17, 0x10, 0x16, 0x0F, 0x17, 0x10, 0x17, 0x10, 0x16, 0x10, 0x17, 0x10, 0x16, 0x0F, 0x17, 0x10, 0x17, 0x0F, 0x16, 0x10, 0x16, 0x0F, 0x15, 0x0F, 0x16, 0x0F, 0x16, 0x10, 0x17, 0x10, 0x17, 0x11, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x17, 0x11, 0x19, 0x11, 0x18, 0x11, 0x17, 0x11, 0x16, 0x10, 0x16, 0x10, 0x17, 0x10, 0x17, 0x11, 0x18, 0x10, 0x17, 0x11, 0x18, 0x12, 0x1C, 0x15, 0x25, 0x1E, 0x2D, 0x20, 0x26, 0x1A, 0x22, 0x17, 0x1F, 0x16, 0x1E, 0x15, 0x1C, 0x14, 0x1A, 0x13, 0x1B, 0x14, 0x27, 0x21, 0x52, 0x41, 0x86, 0x61, 0x9A, 0x6B, 0xA1, 0x70, 0xA9, 0x76, 0xAD, 0x78, 0xB0, 0x77, 0xB0, 0x79, 0xB1, 0x79, 0xB1, 0x7B, 0xB1, 0x7B, 0xB1, 0x7A, 0xB3, 0x7B, 0xB5, 0x7C, 0xB7, 0x7C, 0xB6, 0x7B, 0xB4, 0x7D, 0xB4, 0x7D, 0xB4, 0x7C, 0xB4, 0x7B, 0xB4, 0x7B, 0xB3, 0x7C, 0xB6, 0x7E, 0xB6, 0x7E, 0xB4, 0x7D, 0xB8, 0x7F, 0xBA, 0x80, 0xBA, 0x81, 0xBC, 0x80, 0xB8, 0x7F, 0xB9, 0x7E, 0xB5, 0x7E, 0xB6, 0x7E, 0xB5, 0x7A, 0xAB, 0x72, 0x81, 0x4F, 0x3E, 0x27, 0x25, 0x19, 0x1D, 0x14, 0x19, 0x12, 0x18, 0x11, 0x18, 0x11, 0x17, 0x10, 0x17, 0x10, 0x19, 0x11, 0x19, 0x11, 0x18, 0x11, 0x19, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x19, 0x11, 0x18, 0x11, 0x19, 0x12, 0x19, 0x11, 0x19, 0x12, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x19, 0x12, 0x19, 0x12, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x19, 0x10, 0x18, 0x11, 0x18, 0x10, 0x17, 0x10, 0x18, 0x10, 0x16, 0x10, 0x18, 0x11, 0x19, 0x11, 0x1B, 0x13, 0x1B, 0x12, 0x19, 0x11, 0x19, 0x11, 0x19, 0x11, 0x19, 0x11, 0x19, 0x11, 0x18, 0x11, 0x19, 0x12, 0x1A, 0x12, 0x20, 0x13, 0x42, 0x1E, 0x5D, 0x23, 0x60, 0x24, 0x50, 0x1F, 0x2F, 0x18, 0x41, 0x1E, 0x58, 0x21, 0x5C, 0x22, 0x60, 0x23, 0x62, 0x23, 0x60, 0x22, 0x62, 0x24, 0x62, 0x23, 0x62, 0x21, 0x5F, 0x22, 0x62, 0x23, 0x62, 0x23, 0x65, 0x24, 0x63, 0x24, 0x67, 0x24, 0x65, 0x25, 0x62, 0x23, 0x66, 0x24, 0x65, 0x24, 0x65, 0x25, 0x64, 0x24, 0x64, 0x24, 0x65, 0x23, 0x62, 0x23, 0x64, 0x22, 0x66, 0x24, 0x64, 0x23, 0x64, 0x23, 0x63, 0x23, 0x61, 0x22, 0x5E, 0x22, 0x62, 0x23, 0x5F, 0x21, 0x61, 0x21, 0x62, 0x22, 0x63, 0x23, 0x62, 0x24, 0x62, 0x24, 0x60, 0x23, 0x61, 0x22, 0x63, 0x23, 0x62, 0x23, 0x67, 0x26, 0x64, 0x23, 0x62, 0x24, 0x5D, 0x21, 0x63, 0x22, 0x61, 0x22, 0x5E, 0x21, 0x61, 0x22, 0x60, 0x22, 0x61, 0x24, 0x66, 0x27, 0x65, 0x25, 0x62, 0x23, 0x5D, 0x22, 0x61, 0x23, 0x63, 0x23, 0x62, 0x23, 0x5B, 0x22, 0x4E, 0x25, 0x4C, 0x25, 0x49, 0x24, 0x4A, 0x24, 0x48, 0x24, 0x49, 0x24, 0x3D, 0x1D, 0x21, 0x12, 0x22, 0x14, 0x26, 0x15, 0x25, 0x14, 0x21, 0x13, 0x4B, 0x1E, 0x5B, 0x22, 0x61, 0x23, 0x5E, 0x22, 0x5F, 0x22, 0x5E, 0x21, 0x5F, 0x23, 0x5E, 0x22, 0x5E, 0x22, 0x5F, 0x22, 0x60, 0x22, 0x5F, 0x22, 0x63, 0x23, 0x5D, 0x21, 0x5E, 0x22, 0x5C, 0x21, 0x5D, 0x21, 0x59, 0x21, 0x5C, 0x21, 0x5C, 0x21, 0x5D, 0x22, 0x5E, 0x22, 0x61, 0x23, 0x60, 0x23, 0x5D, 0x23, 0x5D, 0x23, 0x61, 0x26, 0x61, 0x24, 0x5F, 0x24, 0x5E, 0x23, 0x5E, 0x24, 0x61, 0x26, 0x60, 0x24, 0x5F, 0x24, 0x5D, 0x23, 0x61, 0x24, 0x5F, 0x23, 0x5B, 0x22, 0x5C, 0x22, 0x5B, 0x22, 0x5F, 0x22, 0x5C, 0x22, 0x5C, 0x21, 0x5B, 0x22, 0x5C, 0x22, 0x56, 0x20, 0x58, 0x21, 0x5B, 0x23, 0x57, 0x21, 0x5A, 0x21, 0x5B, 0x21, 0x5B, 0x21, 0x43, 0x1F, 0x31, 0x19, 0x2C, 0x1A, 0x33, 0x1C, 0x2E, 0x1A, 0x2C, 0x1A, 0x41, 0x26, 0x51, 0x2C, 0x51, 0x2D, 0x52, 0x2D, 0x56, 0x2F, 0x53, 0x2D, 0x56, 0x2E, 0x3A, 0x1E, 0x31, 0x1D, 0x3A, 0x1F, 0x31, 0x1C, 0x4C, 0x2B, 0x59, 0x31, 0x58, 0x30, 0x5C, 0x33, 0x5F, 0x34, 0x59, 0x32, 0x4E, 0x29, 0x29, 0x19, 0x32, 0x1B, 0x27, 0x18, 0x45, 0x27, 0x56, 0x2F, 0x57, 0x2F, 0x55, 0x2F, 0x55, 0x2E, 0x52, 0x2E, 0x4F, 0x2B, 0x2B, 0x18, 0x2D, 0x1A, 0x34, 0x1C, 0x35, 0x1F, 0x42, 0x25, 0x39, 0x21, 0x33, 0x1F, 0x2F, 0x1D, 0x2C, 0x1B, 0x29, 0x19, 0x20, 0x14, 0x22, 0x16
    },

    {
        0x43, 0x3D, 0x2F, 0x29, 0x20, 0x1F, 0x1A, 0x1B, 0x18, 0x19, 0x16, 0x18, 0x16, 0x18, 0x17, 0x19, 0x1A, 0x1E, 0x22, 0x2A, 0x33, 0x42, 0x43, 0x4C, 0x38, 0x37, 0x23, 0x24, 0x1C, 0x1F, 0x1A, 0x1C, 0x17, 0x1A, 0x15, 0x18, 0x15, 0x18, 0x13, 0x16, 0x12, 0x16, 0x12, 0x16, 0x13, 0x17, 0x12, 0x16, 0x13, 0x16, 0x13, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x15, 0x11, 0x15, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x13, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x13, 0x18, 0x12, 0x17, 0x13, 0x17, 0x12, 0x16, 0x12, 0x16, 0x12, 0x17, 0x13, 0x17, 0x12, 0x16, 0x13, 0x17, 0x14, 0x17, 0x14, 0x1A, 0x18, 0x20, 0x1A, 0x24, 0x19, 0x21, 0x17, 0x1F, 0x16, 0x1D, 0x15, 0x1B, 0x15, 0x1A, 0x15, 0x1A, 0x19, 0x1C, 0x24, 0x31, 0x45, 0x66, 0x69, 0x8E, 0x77, 0x9A, 0x7D, 0x9F, 0x83, 0xA8, 0x87, 0xAA, 0x88, 0xAC, 0x88, 0xAA, 0x8A, 0xAB, 0x88, 0xAD, 0x8B, 0xAE, 0x8C, 0xAE, 0x8B, 0xAF, 0x8B, 0xAF, 0x8C, 0xAF, 0x8C, 0xB0, 0x8C, 0xB2, 0x8C, 0xB2, 0x8B, 0xB0, 0x8B, 0xB0, 0x8B, 0xAE, 0x8B, 0xAE, 0x8B, 0xAF, 0x8B, 0xB2, 0x8D, 0xB2, 0x8F, 0xB6, 0x90, 0xB4, 0x8F, 0xB6, 0x90, 0xB4, 0x8F, 0xB3, 0x8E, 0xB1, 0x8C, 0xB2, 0x8B, 0xB1, 0x8A, 0xAF, 0x82, 0xA5, 0x6D, 0x83, 0x3D, 0x40, 0x21, 0x25, 0x19, 0x1C, 0x15, 0x19, 0x14, 0x17, 0x13, 0x17, 0x13, 0x16, 0x13, 0x17, 0x13, 0x18, 0x14, 0x18, 0x13, 0x17, 0x14, 0x18, 0x14, 0x18, 0x13, 0x17, 0x14, 0x18, 0x14, 0x18, 0x13, 0x18, 0x14, 0x19, 0x15, 0x19, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x13, 0x17, 0x13, 0x17, 0x14, 0x18, 0x15, 0x18, 0x13, 0x18, 0x13, 0x17, 0x14, 0x18, 0x14, 0x18, 0x13, 0x17, 0x13, 0x17, 0x13, 0x16, 0x14, 0x17, 0x13, 0x16, 0x14, 0x17, 0x14, 0x19, 0x16, 0x1A, 0x16, 0x19, 0x15, 0x18, 0x15, 0x19, 0x16, 0x1A, 0x14, 0x18, 0x14, 0x17, 0x14, 0x18, 0x16, 0x1A, 0x18, 0x1A, 0x24, 0x26, 0x4C, 0x4F, 0x64, 0x5C, 0x65, 0x5C, 0x4F, 0x43, 0x33, 0x2D, 0x4C, 0x4E, 0x63, 0x5A, 0x67, 0x5C, 0x6D, 0x5F, 0x70, 0x61, 0x6F, 0x60, 0x6F, 0x60, 0x6D, 0x60, 0x70, 0x61, 0x6C, 0x5F, 0x70, 0x62, 0x6F, 0x61, 0x71, 0x63, 0x6F, 0x63, 0x72, 0x65, 0x71, 0x63, 0x6D, 0x61, 0x72, 0x64, 0x71, 0x64, 0x70, 0x63, 0x6E, 0x63, 0x6F, 0x62, 0x72, 0x64, 0x6F, 0x62, 0x73, 0x63, 0x72, 0x65, 0x70, 0x63, 0x70, 0x62, 0x6E, 0x62, 0x6E, 0x5F, 0x6C, 0x60, 0x6F, 0x61, 0x6C, 0x5F, 0x70, 0x61, 0x6F, 0x61, 0x70, 0x62, 0x70, 0x62, 0x6F, 0x61, 0x6C, 0x5E, 0x6E, 0x62, 0x6F, 0x62, 0x71, 0x61, 0x70, 0x63, 0x72, 0x62, 0x6E, 0x60, 0x6A, 0x5D, 0x6D, 0x60, 0x6F, 0x60, 0x6D, 0x5F, 0x6D, 0x5F, 0x6D, 0x60, 0x6E, 0x62, 0x72, 0x66, 0x71, 0x63, 0x6E, 0x61, 0x6C, 0x5E, 0x6E, 0x61, 0x6F, 0x62, 0x6E, 0x60, 0x62, 0x56, 0x4F, 0x4C, 0x4A, 0x4C, 0x47, 0x49, 0x47, 0x49, 0x45, 0x48, 0x45, 0x47, 0x38, 0x36, 0x22, 0x1F, 0x25, 0x23, 0x2A, 0x26, 0x27, 0x23, 0x22, 0x22, 0x51, 0x51, 0x66, 0x5C, 0x6D, 0x61, 0x6A, 0x5D, 0x6A, 0x5E, 0x69, 0x5D, 0x6C, 0x5E, 0x69, 0x5C, 0x6A, 0x5E, 0x6B, 0x5D, 0x6C, 0x5E, 0x6B, 0x5E, 0x6F, 0x61, 0x69, 0x5D, 0x6A, 0x5D, 0x67, 0x5C, 0x68, 0x5B, 0x64, 0x5A, 0x68, 0x5D, 0x69, 0x5D, 0x68, 0x5D, 0x69, 0x5E, 0x6C, 0x60, 0x69, 0x5B, 0x66, 0x5D, 0x65, 0x5B, 0x69, 0x60, 0x6C, 0x5F, 0x69, 0x5F, 0x6B, 0x5F, 0x68, 0x5F, 0x6A, 0x64, 0x6A, 0x5E, 0x6A, 0x5F, 0x69, 0x5F, 0x6C, 0x5E, 0x68, 0x5C, 0x67, 0x5C, 0x66, 0x5B, 0x63, 0x59, 0x68, 0x5F, 0x69, 0x5C, 0x68, 0x5B, 0x65, 0x5A, 0x66, 0x5A, 0x60, 0x55, 0x63, 0x58, 0x66, 0x5C, 0x65, 0x59, 0x67, 0x5B, 0x65, 0x5A, 0x64, 0x57, 0x43, 0x40, 0x2F, 0x2D, 0x29, 0x2D, 0x2D, 0x30, 0x2A, 0x2D, 0x29, 0x2F, 0x30, 0x4B, 0x32, 0x55, 0x30, 0x57, 0x2E, 0x55, 0x2D, 0x58, 0x2C, 0x55, 0x2C, 0x54, 0x25, 0x31, 0x2A, 0x35, 0x30, 0x35, 0x28, 0x2F, 0x2B, 0x50, 0x2D, 0x59, 0x2C, 0x56, 0x2E, 0x5B, 0x2E, 0x5B, 0x2C, 0x57, 0x27, 0x42, 0x1D, 0x26, 0x2A, 0x2F, 0x22, 0x27, 0x27, 0x47, 0x2B, 0x52, 0x2A, 0x4F, 0x28, 0x4C, 0x27, 0x4A, 0x25, 0x46, 0x23, 0x40, 0x1A, 0x22, 0x26, 0x30, 0x2C, 0x33, 0x29, 0x37, 0x28, 0x37, 0x1E, 0x2D, 0x1B, 0x29, 0x19, 0x25, 0x19, 0x22, 0x18, 0x1F, 0x17, 0x1B, 0x1D, 0x23
    },

    {
        0x48, 0x1B, 0x3E, 0x17, 0x2C, 0x13, 0x1F, 0x11, 0x1B, 0x10, 0x19, 0x10, 0x18, 0x10, 0x18, 0x10, 0x1A, 0x11, 0x1E, 0x12, 0x25, 0x18, 0x2E, 0x1B, 0x27, 0x17, 0x20, 0x14, 0x1E, 0x13, 0x1B, 0x12, 0x19, 0x11, 0x18, 0x11, 0x17, 0x10, 0x16, 0x10, 0x16, 0x10, 0x17, 0x10, 0x17, 0x11, 0x17, 0x10, 0x16, 0x0F, 0x16, 0x10, 0x16, 0x0F, 0x16, 0x0F, 0x16, 0x0F, 0x16, 0x10, 0x16, 0x10, 0x16, 0x0F, 0x15, 0x0F, 0x16, 0x0F, 0x16, 0x10, 0x16, 0x10, 0x17, 0x10, 0x17, 0x11, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x18, 0x10, 0x17, 0x10, 0x16, 0x11, 0x18, 0x11, 0x17, 0x11, 0x17, 0x11, 0x17, 0x10, 0x17, 0x10, 0x17, 0x11, 0x18, 0x11, 0x19, 0x13, 0x1C, 0x15, 0x1D, 0x14, 0x1C, 0x14, 0x1B, 0x13, 0x1B, 0x13, 0x1A, 0x13, 0x1A, 0x14, 0x23, 0x1E, 0x47, 0x3B, 0x80, 0x5D, 0x9B, 0x6B, 0xA1, 0x70, 0xA7, 0x72, 0xAC, 0x75, 0xB0, 0x7B, 0xB0, 0x79, 0xB3, 0x7C, 0xB3, 0x7A, 0xB5, 0x7B, 0xB6, 0x7D, 0xB6, 0x7D, 0xB3, 0x7B, 0xB3, 0x7D, 0xB4, 0x7B, 0xB5, 0x7B, 0xB7, 0x7D, 0xB8, 0x7E, 0xB7, 0x7E, 0xB4, 0x7B, 0xB4, 0x7C, 0xB3, 0x7D, 0xB5, 0x7D, 0xB5, 0x7B, 0xB6, 0x7D, 0xB7, 0x7E, 0xB8, 0x80, 0xB7, 0x7F, 0xBB, 0x80, 0xB9, 0x7F, 0xB7, 0x7E, 0xB9, 0x7E, 0xB5, 0x7D, 0xB4, 0x7D, 0xAF, 0x79, 0xA9, 0x73, 0x80, 0x4A, 0x35, 0x20, 0x1F, 0x15, 0x1A, 0x12, 0x17, 0x10, 0x16, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x18, 0x11, 0x17, 0x10, 0x18, 0x11, 0x18, 0x11, 0x17, 0x10, 0x17, 0x10, 0x18, 0x11, 0x19, 0x11, 0x1A, 0x12, 0x19, 0x12, 0x19, 0x12, 0x19, 0x11, 0x18, 0x11, 0x18, 0x11, 0x19, 0x11, 0x1A, 0x12, 0x19, 0x12, 0x19, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x17, 0x10, 0x17, 0x0F, 0x17, 0x10, 0x16, 0x10, 0x18, 0x11, 0x19, 0x11, 0x1A, 0x12, 0x19, 0x11, 0x19, 0x11, 0x19, 0x12, 0x1C, 0x13, 0x18, 0x11, 0x18, 0x11, 0x1A, 0x12, 0x1B, 0x12, 0x1D, 0x13, 0x3D, 0x1B, 0x59, 0x22, 0x60, 0x24, 0x54, 0x20, 0x31, 0x19, 0x3E, 0x1C, 0x57, 0x21, 0x5E, 0x23, 0x62, 0x23, 0x60, 0x22, 0x62, 0x23, 0x65, 0x24, 0x64, 0x24, 0x61, 0x23, 0x62, 0x22, 0x62, 0x22, 0x62, 0x23, 0x63, 0x23, 0x63, 0x24, 0x65, 0x24, 0x64, 0x24, 0x62, 0x25, 0x67, 0x26, 0x68, 0x26, 0x64, 0x24, 0x61, 0x23, 0x60, 0x24, 0x61, 0x23, 0x64, 0x23, 0x64, 0x23, 0x67, 0x24, 0x64, 0x23, 0x61, 0x22, 0x60, 0x22, 0x63, 0x23, 0x61, 0x22, 0x62, 0x22, 0x61, 0x22, 0x5E, 0x21, 0x62, 0x23, 0x61, 0x22, 0x5E, 0x21, 0x61, 0x23, 0x62, 0x23, 0x5F, 0x22, 0x63, 0x24, 0x63, 0x22, 0x61, 0x22, 0x60, 0x22, 0x62, 0x23, 0x60, 0x22, 0x60, 0x22, 0x5D, 0x22, 0x61, 0x22, 0x66, 0x23, 0x61, 0x24, 0x63, 0x25, 0x65, 0x25, 0x64, 0x24, 0x63, 0x23, 0x63, 0x24, 0x68, 0x25, 0x64, 0x24, 0x5E, 0x22, 0x5F, 0x21, 0x57, 0x1F, 0x4B, 0x22, 0x4A, 0x25, 0x4B, 0x25, 0x4C, 0x25, 0x4A, 0x25, 0x49, 0x23, 0x34, 0x1A, 0x1F, 0x12, 0x23, 0x15, 0x29, 0x16, 0x22, 0x13, 0x1F, 0x13, 0x4E, 0x1F, 0x5B, 0x22, 0x60, 0x23, 0x60, 0x24, 0x61, 0x22, 0x60, 0x22, 0x5F, 0x22, 0x5E, 0x21, 0x5E, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x5E, 0x21, 0x5F, 0x22, 0x5F, 0x22, 0x60, 0x22, 0x5F, 0x22, 0x5C, 0x22, 0x5C, 0x22, 0x5E, 0x22, 0x5E, 0x22, 0x5F, 0x23, 0x5C, 0x23, 0x5C, 0x22, 0x5E, 0x23, 0x5D, 0x23, 0x5E, 0x23, 0x5D, 0x23, 0x5F, 0x24, 0x5F, 0x24, 0x60, 0x25, 0x62, 0x26, 0x61, 0x25, 0x5E, 0x23, 0x5E, 0x22, 0x5E, 0x22, 0x5B, 0x21, 0x5B, 0x22, 0x5D, 0x22, 0x5A, 0x21, 0x59, 0x21, 0x59, 0x21, 0x5C, 0x21, 0x5A, 0x21, 0x5B, 0x21, 0x57, 0x20, 0x56, 0x1F, 0x57, 0x20, 0x5A, 0x22, 0x5B, 0x22, 0x5A, 0x20, 0x57, 0x1F, 0x57, 0x1F, 0x46, 0x20, 0x34, 0x1C, 0x32, 0x1C, 0x36, 0x1D, 0x34, 0x1C, 0x2E, 0x1B, 0x4D, 0x2B, 0x5C, 0x32, 0x60, 0x34, 0x5F, 0x34, 0x5F, 0x34, 0x5E, 0x33, 0x59, 0x30, 0x2E, 0x1A, 0x2C, 0x1A, 0x2C, 0x1A, 0x2D, 0x1C, 0x50, 0x2D, 0x52, 0x2E, 0x4E, 0x2C, 0x4E, 0x2D, 0x48, 0x2A, 0x42, 0x27, 0x34, 0x1C, 0x20, 0x15, 0x33, 0x1C, 0x2F, 0x1A, 0x3E, 0x22, 0x31, 0x1C, 0x27, 0x1A, 0x22, 0x16, 0x1F, 0x15, 0x1D, 0x14, 0x1C, 0x13, 0x1A, 0x11, 0x2A, 0x19, 0x2B, 0x18, 0x2F, 0x1A, 0x28, 0x16, 0x1E, 0x13, 0x22, 0x15, 0x26, 0x17, 0x29, 0x17, 0x28, 0x19, 0x28, 0x16, 0x24, 0x15
    },

    {
        0x4E, 0x49, 0x47, 0x3F, 0x34, 0x2D, 0x22, 0x20, 0x1B, 0x1C, 0x18, 0x1A, 0x16, 0x18, 0x16, 0x18, 0x17, 0x19, 0x19, 0x1B, 0x1C, 0x21, 0x21, 0x26, 0x1F, 0x21, 0x1A, 0x1D, 0x18, 0x1B, 0x17, 0x1A, 0x15, 0x18, 0x14, 0x17, 0x14, 0x17, 0x12, 0x16, 0x12, 0x16, 0x13, 0x16, 0x13, 0x16, 0x13, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x15, 0x12, 0x16, 0x12, 0x15, 0x11, 0x16, 0x12, 0x15, 0x12, 0x15, 0x12, 0x15, 0x12, 0x16, 0x13, 0x16, 0x12, 0x16, 0x12, 0x17, 0x13, 0x17, 0x12, 0x17, 0x12, 0x17, 0x13, 0x17, 0x12, 0x17, 0x12, 0x17, 0x12, 0x17, 0x12, 0x16, 0x12, 0x16, 0x14, 0x18, 0x14, 0x18, 0x15, 0x1B, 0x15, 0x1B, 0x14, 0x1A, 0x14, 0x19, 0x14, 0x19, 0x14, 0x19, 0x18, 0x1B, 0x21, 0x2C, 0x3E, 0x59, 0x65, 0x8A, 0x79, 0x9B, 0x7C, 0xA0, 0x81, 0xA3, 0x84, 0xA7, 0x89, 0xAC, 0x8B, 0xAD, 0x8B, 0xAF, 0x8B, 0xAF, 0x8B, 0xAE, 0x8D, 0xB2, 0x8D, 0xB1, 0x8C, 0xB0, 0x8C, 0xB1, 0x8C, 0xAF, 0x8C, 0xAF, 0x8D, 0xB1, 0x8D, 0xB2, 0x8C, 0xB1, 0x8B, 0xB0, 0x8B, 0xAE, 0x8D, 0xB3, 0x8A, 0xB0, 0x8B, 0xB0, 0x8A, 0xAF, 0x8D, 0xB2, 0x8E, 0xB3, 0x8E, 0xB4, 0x8E, 0xB5, 0x8F, 0xB4, 0x8D, 0xB2, 0x8D, 0xB2, 0x8B, 0xAF, 0x8A, 0xAF, 0x86, 0xAC, 0x80, 0xA7, 0x65, 0x76, 0x2F, 0x2F, 0x1B, 0x1E, 0x16, 0x19, 0x14, 0x17, 0x13, 0x17, 0x13, 0x16, 0x13, 0x17, 0x13, 0x16, 0x13, 0x17, 0x13, 0x17, 0x13, 0x18, 0x14, 0x18, 0x13, 0x17, 0x13, 0x17, 0x14, 0x18, 0x14, 0x18, 0x14, 0x19, 0x14, 0x19, 0x14, 0x19, 0x14, 0x18, 0x13, 0x17, 0x13, 0x17, 0x14, 0x18, 0x14, 0x18, 0x14, 0x19, 0x13, 0x17, 0x13, 0x18, 0x13, 0x17, 0x14, 0x18, 0x14, 0x18, 0x14, 0x17, 0x12, 0x16, 0x13, 0x17, 0x13, 0x17, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x15, 0x18, 0x15, 0x18, 0x15, 0x19, 0x17, 0x1B, 0x14, 0x17, 0x15, 0x19, 0x17, 0x1A, 0x18, 0x1A, 0x21, 0x24, 0x47, 0x49, 0x63, 0x5B, 0x65, 0x5B, 0x50, 0x45, 0x34, 0x2E, 0x47, 0x48, 0x60, 0x58, 0x68, 0x5F, 0x6F, 0x64, 0x6E, 0x60, 0x70, 0x61, 0x71, 0x64, 0x72, 0x63, 0x6E, 0x61, 0x70, 0x62, 0x6F, 0x60, 0x6E, 0x62, 0x70, 0x61, 0x70, 0x62, 0x71, 0x64, 0x70, 0x64, 0x70, 0x63, 0x72, 0x66, 0x72, 0x66, 0x70, 0x62, 0x6F, 0x60, 0x6C, 0x60, 0x6F, 0x61, 0x73, 0x63, 0x6F, 0x61, 0x72, 0x64, 0x70, 0x62, 0x6C, 0x5E, 0x6D, 0x5E, 0x6F, 0x61, 0x6C, 0x60, 0x70, 0x61, 0x71, 0x61, 0x69, 0x5C, 0x6E, 0x61, 0x6D, 0x5E, 0x6A, 0x5E, 0x6D, 0x60, 0x6F, 0x61, 0x6D, 0x5F, 0x71, 0x63, 0x6F, 0x61, 0x6D, 0x5F, 0x6F, 0x61, 0x6F, 0x61, 0x6D, 0x5F, 0x6E, 0x60, 0x6B, 0x5E, 0x6D, 0x61, 0x72, 0x63, 0x6E, 0x62, 0x6E, 0x64, 0x72, 0x67, 0x70, 0x63, 0x6E, 0x61, 0x70, 0x63, 0x73, 0x67, 0x71, 0x62, 0x6D, 0x5D, 0x6D, 0x5E, 0x60, 0x52, 0x4B, 0x48, 0x49, 0x4B, 0x49, 0x4B, 0x49, 0x4B, 0x47, 0x49, 0x45, 0x46, 0x2E, 0x2A, 0x20, 0x1E, 0x26, 0x24, 0x29, 0x27, 0x21, 0x1F, 0x23, 0x25, 0x55, 0x53, 0x67, 0x5C, 0x69, 0x5E, 0x6C, 0x61, 0x6E, 0x60, 0x6E, 0x61, 0x6D, 0x60, 0x6B, 0x5E, 0x6C, 0x60, 0x6B, 0x5E, 0x6D, 0x60, 0x68, 0x5D, 0x6A, 0x5F, 0x6C, 0x5F, 0x6D, 0x5F, 0x6B, 0x5E, 0x68, 0x5B, 0x68, 0x5C, 0x68, 0x5E, 0x6B, 0x5F, 0x6B, 0x5E, 0x66, 0x5B, 0x67, 0x5D, 0x6B, 0x5E, 0x67, 0x5D, 0x67, 0x5E, 0x65, 0x5C, 0x67, 0x5F, 0x69, 0x5E, 0x69, 0x60, 0x6A, 0x61, 0x69, 0x5E, 0x69, 0x5E, 0x69, 0x5C, 0x68, 0x5D, 0x68, 0x5A, 0x67, 0x5E, 0x69, 0x5D, 0x64, 0x5A, 0x65, 0x59, 0x62, 0x57, 0x67, 0x5C, 0x67, 0x5C, 0x65, 0x5A, 0x63, 0x56, 0x63, 0x57, 0x62, 0x56, 0x66, 0x5B, 0x67, 0x5B, 0x66, 0x59, 0x61, 0x56, 0x60, 0x52, 0x45, 0x44, 0x32, 0x31, 0x30, 0x34, 0x30, 0x36, 0x2C, 0x30, 0x28, 0x30, 0x2E, 0x4C, 0x2F, 0x5A, 0x2F, 0x5C, 0x2E, 0x5C, 0x2D, 0x5B, 0x2C, 0x59, 0x29, 0x4F, 0x1B, 0x24, 0x23, 0x2A, 0x27, 0x2D, 0x28, 0x31, 0x2C, 0x4C, 0x28, 0x47, 0x24, 0x42, 0x24, 0x41, 0x22, 0x3A, 0x1F, 0x35, 0x1C, 0x27, 0x1A, 0x22, 0x2D, 0x34, 0x2A, 0x30, 0x2F, 0x3B, 0x1E, 0x24, 0x18, 0x1E, 0x17, 0x1B, 0x16, 0x1A, 0x17, 0x1B, 0x19, 0x1C, 0x17, 0x1A, 0x25, 0x2D, 0x26, 0x2A, 0x2A, 0x2F, 0x22, 0x24, 0x1C, 0x20, 0x21, 0x27, 0x26, 0x2A, 0x24, 0x27, 0x28, 0x2E, 0x25, 0x28, 0x23, 0x27
    },

    {
        0x4B, 0x1C, 0x4B, 0x1B, 0x41, 0x19, 0x30, 0x15, 0x21, 0x12, 0x1C, 0x10, 0x1A, 0x10, 0x19, 0x0F, 0x18, 0x0F, 0x19, 0x10, 0x1B, 0x12, 0x1D, 0x12, 0x1D, 0x12, 0x1C, 0x12, 0x1A, 0x11, 0x19, 0x11, 0x18, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x0F, 0x16, 0x0F, 0x17, 0x10, 0x17, 0x0F, 0x17, 0x0F, 0x16, 0x0F, 0x16, 0x10, 0x16, 0x10, 0x16, 0x0F, 0x17, 0x10, 0x17, 0x10, 0x16, 0x0F, 0x16, 0x0F, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x17, 0x10, 0x17, 0x11, 0x17, 0x10, 0x16, 0x10, 0x17, 0x10, 0x17, 0x10, 0x18, 0x11, 0x18, 0x10, 0x18, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x11, 0x18, 0x11, 0x18, 0x11, 0x19, 0x12, 0x19, 0x12, 0x18, 0x12, 0x18, 0x12, 0x19, 0x13, 0x22, 0x1C, 0x41, 0x38, 0x7A, 0x59, 0x96, 0x69, 0xA1, 0x6F, 0xA8, 0x74, 0xAC, 0x77, 0xB1, 0x78, 0xB5, 0x7D, 0xB7, 0x7C, 0xB5, 0x7B, 0xB5, 0x7C, 0xB3, 0x7D, 0xB5, 0x7D, 0xB4, 0x7B, 0xB5, 0x7B, 0xB4, 0x7A, 0xB5, 0x7C, 0xB4, 0x7C, 0xB6, 0x7D, 0xB5, 0x7C, 0xB5, 0x7D, 0xB5, 0x7A, 0xB1, 0x78, 0xB1, 0x7A, 0xB1, 0x79, 0xB0, 0x7A, 0xB4, 0x7B, 0xB6, 0x7C, 0xB6, 0x7C, 0xB5, 0x7C, 0xB5, 0x7C, 0xB6, 0x7F, 0xB6, 0x7D, 0xB4, 0x7E, 0xB6, 0x7C, 0xB3, 0x79, 0xB2, 0x78, 0xA7, 0x6B, 0x6B, 0x3F, 0x31, 0x1F, 0x20, 0x15, 0x1B, 0x12, 0x18, 0x11, 0x17, 0x10, 0x17, 0x10, 0x17, 0x11, 0x18, 0x10, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x17, 0x10, 0x17, 0x11, 0x18, 0x11, 0x19, 0x12, 0x19, 0x11, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x18, 0x11, 0x18, 0x12, 0x1A, 0x11, 0x18, 0x11, 0x17, 0x10, 0x17, 0x10, 0x19, 0x11, 0x18, 0x11, 0x18, 0x10, 0x17, 0x10, 0x16, 0x10, 0x18, 0x11, 0x18, 0x10, 0x18, 0x10, 0x17, 0x10, 0x17, 0x11, 0x19, 0x11, 0x19, 0x11, 0x19, 0x11, 0x1A, 0x12, 0x1C, 0x14, 0x1F, 0x14, 0x1C, 0x12, 0x1E, 0x14, 0x39, 0x1C, 0x5A, 0x22, 0x5D, 0x23, 0x52, 0x20, 0x30, 0x19, 0x39, 0x1B, 0x58, 0x21, 0x5E, 0x23, 0x62, 0x23, 0x68, 0x26, 0x66, 0x24, 0x65, 0x25, 0x65, 0x24, 0x65, 0x24, 0x64, 0x24, 0x66, 0x23, 0x61, 0x22, 0x60, 0x21, 0x60, 0x22, 0x60, 0x23, 0x67, 0x24, 0x65, 0x25, 0x67, 0x26, 0x67, 0x24, 0x63, 0x23, 0x66, 0x26, 0x66, 0x27, 0x69, 0x27, 0x64, 0x24, 0x63, 0x23, 0x61, 0x22, 0x62, 0x23, 0x63, 0x23, 0x60, 0x21, 0x61, 0x22, 0x63, 0x23, 0x60, 0x22, 0x62, 0x22, 0x5F, 0x21, 0x62, 0x23, 0x61, 0x22, 0x5E, 0x22, 0x5E, 0x22, 0x62, 0x22, 0x5F, 0x22, 0x62, 0x23, 0x61, 0x22, 0x65, 0x24, 0x62, 0x23, 0x61, 0x22, 0x63, 0x22, 0x62, 0x22, 0x63, 0x23, 0x63, 0x22, 0x62, 0x23, 0x65, 0x24, 0x63, 0x25, 0x65, 0x25, 0x64, 0x24, 0x63, 0x23, 0x61, 0x24, 0x63, 0x23, 0x62, 0x22, 0x61, 0x22, 0x61, 0x22, 0x61, 0x22, 0x52, 0x1E, 0x45, 0x1E, 0x47, 0x22, 0x48, 0x23, 0x4B, 0x25, 0x48, 0x24, 0x40, 0x1E, 0x22, 0x12, 0x1D, 0x11, 0x22, 0x14, 0x22, 0x13, 0x1B, 0x10, 0x2B, 0x17, 0x58, 0x22, 0x60, 0x22, 0x61, 0x22, 0x61, 0x22, 0x62, 0x22, 0x62, 0x23, 0x62, 0x23, 0x63, 0x24, 0x62, 0x23, 0x5F, 0x22, 0x5F, 0x22, 0x5D, 0x21, 0x5D, 0x22, 0x5D, 0x21, 0x5E, 0x22, 0x5E, 0x22, 0x5D, 0x21, 0x5C, 0x21, 0x5D, 0x22, 0x62, 0x23, 0x61, 0x24, 0x5F, 0x23, 0x5F, 0x23, 0x61, 0x24, 0x60, 0x25, 0x61, 0x26, 0x60, 0x24, 0x5E, 0x25, 0x61, 0x25, 0x61, 0x24, 0x59, 0x21, 0x5E, 0x22, 0x5D, 0x23, 0x5F, 0x23, 0x59, 0x21, 0x5C, 0x21, 0x5F, 0x22, 0x5D, 0x21, 0x5C, 0x21, 0x59, 0x21, 0x56, 0x20, 0x56, 0x1F, 0x58, 0x20, 0x5B, 0x21, 0x58, 0x20, 0x59, 0x21, 0x58, 0x20, 0x58, 0x20, 0x59, 0x20, 0x5A, 0x21, 0x57, 0x20, 0x53, 0x1F, 0x45, 0x20, 0x2F, 0x1A, 0x2F, 0x1B, 0x30, 0x1A, 0x25, 0x17, 0x2A, 0x19, 0x3E, 0x24, 0x49, 0x29, 0x42, 0x28, 0x41, 0x25, 0x3B, 0x22, 0x36, 0x20, 0x2E, 0x1C, 0x1E, 0x14, 0x2B, 0x1A, 0x35, 0x1C, 0x32, 0x1C, 0x3A, 0x1E, 0x21, 0x14, 0x1C, 0x13, 0x1B, 0x13, 0x1D, 0x13, 0x1B, 0x12, 0x1F, 0x13, 0x1F, 0x14, 0x34, 0x1C, 0x27, 0x17, 0x31, 0x1A, 0x24, 0x16, 0x27, 0x17, 0x23, 0x15, 0x28, 0x17, 0x26, 0x18, 0x29, 0x17, 0x26, 0x16, 0x2D, 0x1A, 0x2E, 0x1A, 0x30, 0x1B, 0x33, 0x1D, 0x37, 0x1D, 0x2B, 0x18, 0x2D, 0x19, 0x27, 0x17, 0x31, 0x1B, 0x32, 0x1B, 0x30, 0x1A
    },

    {
        0x4D, 0x4A, 0x51, 0x4A, 0x4A, 0x43, 0x38, 0x32, 0x25, 0x22, 0x1C, 0x1D, 0x19, 0x1A, 0x17, 0x19, 0x16, 0x18, 0x16, 0x18, 0x17, 0x1A, 0x18, 0x1A, 0x18, 0x1A, 0x17, 0x1A, 0x16, 0x19, 0x15, 0x18, 0x14, 0x17, 0x13, 0x16, 0x13, 0x17, 0x13, 0x16, 0x12, 0x16, 0x12, 0x16, 0x13, 0x16, 0x12, 0x17, 0x12, 0x16, 0x12, 0x15, 0x13, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x15, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x13, 0x16, 0x12, 0x16, 0x13, 0x16, 0x12, 0x16, 0x13, 0x16, 0x12, 0x16, 0x12, 0x17, 0x13, 0x17, 0x13, 0x18, 0x13, 0x17, 0x13, 0x17, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x13, 0x16, 0x13, 0x17, 0x13, 0x17, 0x14, 0x18, 0x13, 0x18, 0x13, 0x17, 0x13, 0x17, 0x14, 0x17, 0x16, 0x1A, 0x20, 0x29, 0x38, 0x53, 0x60, 0x85, 0x75, 0x97, 0x7D, 0xA1, 0x83, 0xA8, 0x86, 0xA9, 0x89, 0xAC, 0x8C, 0xB1, 0x8D, 0xB0, 0x8C, 0xB1, 0x8C, 0xB0, 0x8B, 0xB0, 0x8C, 0xAF, 0x8B, 0xAF, 0x8A, 0xAE, 0x8A, 0xAD, 0x8C, 0xAF, 0x8E, 0xB1, 0x8D, 0xB3, 0x8E, 0xB1, 0x8C, 0xB0, 0x8B, 0xAE, 0x89, 0xAA, 0x88, 0xAD, 0x88, 0xAC, 0x89, 0xAE, 0x8A, 0xB0, 0x8B, 0xAF, 0x8A, 0xAE, 0x8B, 0xB0, 0x8A, 0xAF, 0x8C, 0xB1, 0x8C, 0xB2, 0x8B, 0xB0, 0x8C, 0xB2, 0x87, 0xAA, 0x83, 0xAA, 0x77, 0x92, 0x4A, 0x50, 0x27, 0x28, 0x1A, 0x1E, 0x16, 0x1A, 0x14, 0x18, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x13, 0x18, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x14, 0x17, 0x14, 0x18, 0x14, 0x19, 0x14, 0x19, 0x14, 0x18, 0x14, 0x17, 0x14, 0x17, 0x13, 0x17, 0x14, 0x18, 0x15, 0x19, 0x15, 0x18, 0x14, 0x18, 0x13, 0x17, 0x13, 0x17, 0x15, 0x19, 0x14, 0x17, 0x13, 0x17, 0x13, 0x17, 0x13, 0x16, 0x14, 0x18, 0x13, 0x17, 0x14, 0x17, 0x13, 0x17, 0x14, 0x18, 0x15, 0x19, 0x15, 0x19, 0x15, 0x18, 0x17, 0x1C, 0x19, 0x1E, 0x19, 0x1E, 0x19, 0x1A, 0x21, 0x25, 0x42, 0x45, 0x60, 0x5C, 0x63, 0x5C, 0x50, 0x45, 0x33, 0x2C, 0x47, 0x45, 0x63, 0x5B, 0x68, 0x5F, 0x6E, 0x62, 0x73, 0x68, 0x72, 0x64, 0x72, 0x62, 0x6F, 0x62, 0x72, 0x64, 0x71, 0x60, 0x74, 0x64, 0x6F, 0x60, 0x6D, 0x5F, 0x6D, 0x60, 0x6D, 0x60, 0x72, 0x65, 0x71, 0x65, 0x71, 0x65, 0x73, 0x65, 0x72, 0x62, 0x71, 0x66, 0x72, 0x67, 0x74, 0x69, 0x6F, 0x62, 0x70, 0x63, 0x6D, 0x5F, 0x6D, 0x60, 0x71, 0x61, 0x6D, 0x5F, 0x6E, 0x62, 0x6E, 0x61, 0x6C, 0x5F, 0x70, 0x62, 0x6D, 0x5E, 0x6E, 0x62, 0x6D, 0x5F, 0x6D, 0x5F, 0x6B, 0x5E, 0x70, 0x62, 0x6D, 0x5F, 0x6F, 0x60, 0x6E, 0x62, 0x72, 0x65, 0x6F, 0x61, 0x6E, 0x60, 0x70, 0x61, 0x6E, 0x61, 0x6D, 0x60, 0x6F, 0x62, 0x6F, 0x62, 0x71, 0x63, 0x6D, 0x62, 0x70, 0x64, 0x71, 0x62, 0x70, 0x62, 0x6F, 0x62, 0x72, 0x63, 0x6F, 0x60, 0x6E, 0x60, 0x70, 0x62, 0x6D, 0x5E, 0x5E, 0x51, 0x4A, 0x44, 0x45, 0x46, 0x45, 0x47, 0x46, 0x4A, 0x43, 0x46, 0x39, 0x36, 0x20, 0x1D, 0x1D, 0x1C, 0x21, 0x21, 0x21, 0x1E, 0x1E, 0x1B, 0x36, 0x38, 0x62, 0x5B, 0x6A, 0x5F, 0x6E, 0x61, 0x6E, 0x61, 0x70, 0x60, 0x70, 0x62, 0x70, 0x60, 0x6F, 0x63, 0x6E, 0x62, 0x69, 0x5E, 0x6A, 0x5F, 0x69, 0x5C, 0x68, 0x5F, 0x69, 0x5C, 0x6B, 0x5E, 0x6A, 0x5F, 0x67, 0x5C, 0x66, 0x5C, 0x68, 0x5E, 0x6C, 0x61, 0x6B, 0x61, 0x6D, 0x60, 0x6D, 0x61, 0x6A, 0x5F, 0x69, 0x5F, 0x6A, 0x62, 0x6B, 0x60, 0x66, 0x5E, 0x6C, 0x62, 0x69, 0x60, 0x63, 0x58, 0x6A, 0x5E, 0x68, 0x5D, 0x69, 0x5D, 0x67, 0x5B, 0x69, 0x5C, 0x6C, 0x5E, 0x67, 0x5B, 0x67, 0x5B, 0x66, 0x5A, 0x62, 0x57, 0x60, 0x56, 0x64, 0x59, 0x65, 0x59, 0x64, 0x58, 0x66, 0x5A, 0x64, 0x57, 0x64, 0x57, 0x68, 0x5A, 0x65, 0x59, 0x65, 0x59, 0x5F, 0x52, 0x41, 0x3E, 0x2D, 0x2C, 0x2A, 0x2D, 0x2A, 0x2A, 0x25, 0x27, 0x28, 0x2E, 0x2A, 0x3E, 0x26, 0x3C, 0x20, 0x35, 0x1F, 0x32, 0x1D, 0x2E, 0x1C, 0x29, 0x19, 0x23, 0x16, 0x1B, 0x27, 0x2F, 0x2C, 0x30, 0x2C, 0x33, 0x2D, 0x30, 0x1A, 0x1D, 0x18, 0x1A, 0x18, 0x1C, 0x1B, 0x1F, 0x1A, 0x1E, 0x1D, 0x20, 0x1E, 0x24, 0x2C, 0x2F, 0x23, 0x26, 0x2A, 0x2D, 0x22, 0x2A, 0x25, 0x28, 0x21, 0x26, 0x26, 0x2A, 0x26, 0x2B, 0x28, 0x2B, 0x26, 0x2B, 0x2A, 0x2F, 0x2A, 0x30, 0x2A, 0x2E, 0x2F, 0x38, 0x30, 0x35, 0x27, 0x2B, 0x2A, 0x2E, 0x25, 0x29, 0x2E, 0x33, 0x2F, 0x36, 0x2B, 0x2D
    },

    {
        0x3E, 0x1A, 0x49, 0x1C, 0x4A, 0x1B, 0x44, 0x1A, 0x35, 0x15, 0x23, 0x12, 0x1D, 0x11, 0x1A, 0x10, 0x19, 0x10, 0x18, 0x10, 0x19, 0x10, 0x1A, 0x11, 0x1A, 0x11, 0x19, 0x11, 0x18, 0x10, 0x18, 0x10, 0x17, 0x0F, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x16, 0x0F, 0x16, 0x0F, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x0F, 0x16, 0x0F, 0x16, 0x0F, 0x16, 0x0F, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x17, 0x10, 0x16, 0x10, 0x17, 0x10, 0x17, 0x11, 0x18, 0x11, 0x17, 0x10, 0x17, 0x10, 0x18, 0x11, 0x19, 0x11, 0x18, 0x10, 0x17, 0x10, 0x16, 0x10, 0x16, 0x10, 0x17, 0x10, 0x17, 0x10, 0x16, 0x10, 0x18, 0x11, 0x17, 0x11, 0x17, 0x10, 0x17, 0x11, 0x17, 0x11, 0x17, 0x11, 0x18, 0x11, 0x1E, 0x19, 0x3B, 0x32, 0x71, 0x54, 0x91, 0x65, 0x9B, 0x6B, 0xA4, 0x71, 0xA9, 0x74, 0xAF, 0x78, 0xB1, 0x79, 0xB3, 0x7C, 0xB5, 0x7D, 0xB5, 0x7C, 0xB6, 0x7C, 0xB5, 0x7C, 0xB4, 0x7C, 0xB2, 0x7A, 0xB3, 0x7C, 0xB4, 0x7B, 0xB4, 0x7A, 0xB4, 0x7C, 0xB6, 0x7D, 0xB6, 0x7C, 0xB3, 0x7C, 0xB2, 0x7D, 0xB5, 0x7C, 0xB2, 0x7A, 0xB0, 0x79, 0xB2, 0x7A, 0xB2, 0x7A, 0xB0, 0x7A, 0xB0, 0x7B, 0xB3, 0x7C, 0xB5, 0x7C, 0xB4, 0x7C, 0xB3, 0x7A, 0xB0, 0x7A, 0xB0, 0x7A, 0xAE, 0x78, 0xA3, 0x6A, 0x72, 0x45, 0x38, 0x24, 0x27, 0x19, 0x1E, 0x15, 0x1A, 0x12, 0x19, 0x11, 0x17, 0x10, 0x17, 0x10, 0x16, 0x10, 0x17, 0x10, 0x18, 0x10, 0x17, 0x11, 0x19, 0x12, 0x18, 0x11, 0x18, 0x11, 0x19, 0x12, 0x18, 0x11, 0x19, 0x12, 0x1A, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x1A, 0x11, 0x1A, 0x12, 0x19, 0x11, 0x18, 0x11, 0x17, 0x10, 0x18, 0x11, 0x18, 0x10, 0x17, 0x10, 0x18, 0x11, 0x17, 0x10, 0x18, 0x11, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x1A, 0x12, 0x1B, 0x12, 0x19, 0x11, 0x1A, 0x13, 0x20, 0x16, 0x1F, 0x14, 0x19, 0x11, 0x1E, 0x13, 0x3A, 0x1B, 0x5A, 0x23, 0x60, 0x23, 0x55, 0x21, 0x34, 0x1A, 0x3C, 0x1E, 0x5E, 0x23, 0x61, 0x23, 0x64, 0x24, 0x65, 0x24, 0x62, 0x24, 0x63, 0x24, 0x66, 0x24, 0x62, 0x23, 0x63, 0x23, 0x61, 0x22, 0x64, 0x24, 0x66, 0x25, 0x64, 0x23, 0x60, 0x23, 0x62, 0x23, 0x64, 0x24, 0x65, 0x25, 0x65, 0x25, 0x64, 0x24, 0x66, 0x25, 0x68, 0x26, 0x66, 0x25, 0x63, 0x24, 0x68, 0x25, 0x64, 0x23, 0x63, 0x24, 0x62, 0x23, 0x62, 0x23, 0x61, 0x21, 0x61, 0x23, 0x61, 0x24, 0x5E, 0x21, 0x63, 0x23, 0x61, 0x22, 0x60, 0x23, 0x63, 0x25, 0x67, 0x24, 0x64, 0x23, 0x62, 0x23, 0x63, 0x24, 0x64, 0x24, 0x62, 0x24, 0x63, 0x24, 0x66, 0x25, 0x61, 0x22, 0x60, 0x22, 0x60, 0x23, 0x61, 0x22, 0x61, 0x23, 0x62, 0x24, 0x64, 0x24, 0x5F, 0x22, 0x61, 0x22, 0x5F, 0x23, 0x63, 0x23, 0x5F, 0x23, 0x60, 0x23, 0x63, 0x23, 0x61, 0x22, 0x61, 0x23, 0x60, 0x21, 0x5C, 0x21, 0x46, 0x1B, 0x36, 0x19, 0x3A, 0x1B, 0x3A, 0x1A, 0x34, 0x18, 0x22, 0x12, 0x1C, 0x10, 0x1B, 0x10, 0x1C, 0x12, 0x1D, 0x11, 0x2A, 0x16, 0x4F, 0x1F, 0x5E, 0x22, 0x5E, 0x22, 0x61, 0x22, 0x60, 0x21, 0x62, 0x22, 0x61, 0x23, 0x60, 0x21, 0x5F, 0x22, 0x5F, 0x22, 0x5C, 0x21, 0x5B, 0x20, 0x5A, 0x21, 0x5C, 0x23, 0x60, 0x22, 0x5C, 0x21, 0x5B, 0x21, 0x58, 0x21, 0x5C, 0x22, 0x5B, 0x22, 0x5C, 0x23, 0x62, 0x24, 0x5F, 0x23, 0x63, 0x24, 0x5E, 0x24, 0x5C, 0x23, 0x5F, 0x24, 0x5E, 0x24, 0x63, 0x25, 0x62, 0x25, 0x5E, 0x23, 0x5B, 0x22, 0x5E, 0x22, 0x5F, 0x23, 0x5C, 0x22, 0x5C, 0x22, 0x5E, 0x21, 0x5C, 0x21, 0x5A, 0x20, 0x55, 0x20, 0x59, 0x21, 0x58, 0x1F, 0x57, 0x21, 0x5A, 0x21, 0x5B, 0x21, 0x59, 0x21, 0x5C, 0x22, 0x59, 0x20, 0x5A, 0x21, 0x59, 0x20, 0x56, 0x1F, 0x56, 0x1F, 0x52, 0x1E, 0x37, 0x1A, 0x2F, 0x1A, 0x2C, 0x1A, 0x37, 0x1D, 0x37, 0x1D, 0x34, 0x1D, 0x30, 0x19, 0x23, 0x16, 0x1C, 0x12, 0x1C, 0x13, 0x21, 0x15, 0x2A, 0x19, 0x20, 0x14, 0x22, 0x15, 0x31, 0x1C, 0x2B, 0x1A, 0x30, 0x1A, 0x2A, 0x18, 0x28, 0x17, 0x26, 0x16, 0x27, 0x17, 0x2B, 0x18, 0x26, 0x17, 0x29, 0x18, 0x2B, 0x19, 0x31, 0x1B, 0x2B, 0x18, 0x33, 0x1B, 0x31, 0x1B, 0x38, 0x1E, 0x2F, 0x1B, 0x36, 0x1D, 0x30, 0x1B, 0x36, 0x1D, 0x35, 0x1B, 0x33, 0x1D, 0x30, 0x19, 0x32, 0x1B, 0x2E, 0x1A, 0x29, 0x17, 0x2D, 0x1A, 0x3A, 0x1F, 0x33, 0x1C, 0x34, 0x1C, 0x36, 0x1D, 0x2B, 0x18
    },

    {
        0x3D, 0x3C, 0x4A, 0x46, 0x4F, 0x4A, 0x4B, 0x45, 0x3D, 0x37, 0x29, 0x26, 0x1E, 0x1D, 0x19, 0x1B, 0x18, 0x1A, 0x17, 0x19, 0x16, 0x18, 0x16, 0x19, 0x16, 0x19, 0x16, 0x18, 0x15, 0x17, 0x13, 0x16, 0x13, 0x16, 0x13, 0x16, 0x13, 0x17, 0x12, 0x16, 0x12, 0x16, 0x12, 0x17, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x15, 0x12, 0x15, 0x12, 0x15, 0x12, 0x16, 0x13, 0x16, 0x12, 0x16, 0x13, 0x16, 0x12, 0x17, 0x13, 0x17, 0x13, 0x17, 0x12, 0x17, 0x13, 0x17, 0x14, 0x18, 0x13, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x12, 0x16, 0x12, 0x16, 0x12, 0x17, 0x13, 0x18, 0x19, 0x22, 0x30, 0x4A, 0x59, 0x7E, 0x6E, 0x90, 0x77, 0x9A, 0x7D, 0x9F, 0x81, 0xA5, 0x86, 0xAA, 0x89, 0xAC, 0x8C, 0xAF, 0x8C, 0xAF, 0x8B, 0xB1, 0x8D, 0xAF, 0x8D, 0xB1, 0x8B, 0xB0, 0x8B, 0xAF, 0x8D, 0xB0, 0x8C, 0xAF, 0x8C, 0xAF, 0x8B, 0xB0, 0x8B, 0xAF, 0x8D, 0xB1, 0x8C, 0xAF, 0x8B, 0xB2, 0x8C, 0xB1, 0x8B, 0xAF, 0x88, 0xAB, 0x88, 0xAB, 0x88, 0xAD, 0x89, 0xAD, 0x8A, 0xB0, 0x8B, 0xB0, 0x8B, 0xAF, 0x8B, 0xAD, 0x89, 0xAC, 0x87, 0xAA, 0x87, 0xAC, 0x84, 0xAA, 0x77, 0x92, 0x4E, 0x56, 0x29, 0x2E, 0x1E, 0x23, 0x18, 0x1C, 0x15, 0x19, 0x14, 0x18, 0x13, 0x17, 0x13, 0x16, 0x12, 0x16, 0x13, 0x16, 0x13, 0x17, 0x13, 0x18, 0x13, 0x18, 0x13, 0x17, 0x14, 0x19, 0x15, 0x19, 0x14, 0x18, 0x15, 0x19, 0x15, 0x19, 0x13, 0x18, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x14, 0x18, 0x15, 0x19, 0x15, 0x19, 0x14, 0x18, 0x13, 0x18, 0x13, 0x17, 0x14, 0x18, 0x14, 0x17, 0x13, 0x17, 0x13, 0x18, 0x13, 0x17, 0x14, 0x17, 0x13, 0x17, 0x13, 0x17, 0x14, 0x18, 0x16, 0x1A, 0x16, 0x1A, 0x15, 0x19, 0x16, 0x1A, 0x19, 0x1F, 0x18, 0x1B, 0x17, 0x18, 0x21, 0x23, 0x44, 0x49, 0x64, 0x5E, 0x67, 0x5F, 0x55, 0x48, 0x35, 0x2F, 0x49, 0x4B, 0x67, 0x61, 0x6F, 0x63, 0x6F, 0x62, 0x6D, 0x62, 0x6C, 0x60, 0x6F, 0x64, 0x72, 0x63, 0x70, 0x61, 0x71, 0x63, 0x71, 0x62, 0x6F, 0x63, 0x73, 0x66, 0x70, 0x61, 0x6B, 0x60, 0x6E, 0x60, 0x70, 0x63, 0x70, 0x63, 0x72, 0x65, 0x72, 0x63, 0x75, 0x64, 0x74, 0x68, 0x72, 0x66, 0x70, 0x62, 0x74, 0x66, 0x72, 0x63, 0x71, 0x65, 0x6F, 0x61, 0x6E, 0x60, 0x6E, 0x5F, 0x6F, 0x5F, 0x6E, 0x60, 0x6D, 0x5D, 0x70, 0x61, 0x70, 0x62, 0x6E, 0x5F, 0x6E, 0x63, 0x74, 0x65, 0x73, 0x64, 0x70, 0x63, 0x6E, 0x63, 0x6F, 0x62, 0x6E, 0x62, 0x71, 0x63, 0x73, 0x66, 0x6F, 0x5F, 0x6F, 0x60, 0x6C, 0x61, 0x6E, 0x62, 0x6F, 0x61, 0x6E, 0x62, 0x6F, 0x62, 0x69, 0x5E, 0x6D, 0x5F, 0x6B, 0x5F, 0x71, 0x63, 0x6E, 0x60, 0x6E, 0x61, 0x71, 0x61, 0x6F, 0x61, 0x70, 0x61, 0x6C, 0x5E, 0x67, 0x5A, 0x50, 0x42, 0x3A, 0x34, 0x36, 0x33, 0x33, 0x30, 0x2D, 0x2A, 0x22, 0x1F, 0x20, 0x1C, 0x1F, 0x1C, 0x21, 0x1E, 0x23, 0x20, 0x38, 0x38, 0x5D, 0x5A, 0x69, 0x5E, 0x6A, 0x5F, 0x6C, 0x5F, 0x6D, 0x5F, 0x6F, 0x60, 0x6D, 0x60, 0x6D, 0x5F, 0x6A, 0x5E, 0x6B, 0x5C, 0x6A, 0x5C, 0x65, 0x58, 0x67, 0x5A, 0x68, 0x5D, 0x69, 0x5F, 0x68, 0x5A, 0x67, 0x5A, 0x62, 0x58, 0x68, 0x5D, 0x67, 0x5C, 0x68, 0x5D, 0x6B, 0x5F, 0x6A, 0x5F, 0x6E, 0x63, 0x6A, 0x5E, 0x67, 0x5C, 0x67, 0x5C, 0x66, 0x5D, 0x6C, 0x63, 0x6D, 0x61, 0x6A, 0x5E, 0x67, 0x5C, 0x69, 0x5C, 0x68, 0x5E, 0x65, 0x5A, 0x69, 0x5D, 0x6A, 0x5C, 0x69, 0x5D, 0x65, 0x57, 0x5F, 0x55, 0x63, 0x58, 0x62, 0x56, 0x5F, 0x55, 0x64, 0x5A, 0x67, 0x5A, 0x65, 0x59, 0x68, 0x5C, 0x65, 0x59, 0x64, 0x5A, 0x64, 0x57, 0x61, 0x55, 0x62, 0x55, 0x5B, 0x4F, 0x37, 0x31, 0x2F, 0x32, 0x2A, 0x2E, 0x34, 0x3A, 0x2F, 0x33, 0x2E, 0x34, 0x27, 0x29, 0x23, 0x25, 0x1B, 0x1C, 0x1C, 0x21, 0x20, 0x26, 0x29, 0x2E, 0x20, 0x24, 0x24, 0x28, 0x2C, 0x33, 0x28, 0x2E, 0x2C, 0x2F, 0x28, 0x2D, 0x28, 0x2B, 0x25, 0x28, 0x27, 0x2C, 0x29, 0x2B, 0x25, 0x29, 0x28, 0x2D, 0x2B, 0x31, 0x2E, 0x34, 0x29, 0x2E, 0x30, 0x36, 0x2D, 0x33, 0x33, 0x3A, 0x2A, 0x31, 0x31, 0x35, 0x2B, 0x2F, 0x2F, 0x36, 0x2C, 0x2F, 0x2F, 0x36, 0x2A, 0x2C, 0x2E, 0x33, 0x29, 0x2C, 0x24, 0x28, 0x2B, 0x31, 0x34, 0x3C, 0x2C, 0x30, 0x2E, 0x34, 0x2D, 0x31, 0x26, 0x2A
    },

    {
        0x36, 0x18, 0x3B, 0x19, 0x47, 0x1B, 0x49, 0x1B, 0x48, 0x1A, 0x39, 0x17, 0x27, 0x13, 0x1F, 0x11, 0x1C, 0x10, 0x1A, 0x10, 0x19, 0x10, 0x19, 0x10, 0x19, 0x11, 0x19, 0x11, 0x18, 0x10, 0x17, 0x10, 0x16, 0x0F, 0x16, 0x0F, 0x17, 0x10, 0x17, 0x10, 0x17, 0x0F, 0x17, 0x10, 0x16, 0x0F, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x0F, 0x16, 0x0F, 0x16, 0x0F, 0x16, 0x0F, 0x16, 0x0F, 0x16, 0x0F, 0x16, 0x10, 0x17, 0x10, 0x17, 0x11, 0x17, 0x10, 0x17, 0x10, 0x17, 0x11, 0x18, 0x11, 0x18, 0x10, 0x18, 0x11, 0x18, 0x11, 0x19, 0x12, 0x18, 0x11, 0x18, 0x11, 0x17, 0x10, 0x18, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x18, 0x11, 0x18, 0x11, 0x18, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x11, 0x19, 0x11, 0x21, 0x1C, 0x4F, 0x3F, 0x82, 0x5C, 0x92, 0x66, 0x9B, 0x6C, 0xA3, 0x71, 0xA8, 0x74, 0xAE, 0x78, 0xB2, 0x78, 0xB1, 0x7A, 0xB4, 0x7D, 0xB8, 0x7E, 0xB6, 0x7D, 0xB6, 0x7E, 0xB6, 0x7D, 0xB6, 0x7C, 0xB4, 0x7A, 0xB2, 0x7B, 0xB4, 0x7C, 0xB2, 0x7C, 0xB5, 0x7C, 0xB5, 0x7C, 0xB3, 0x7B, 0xB5, 0x7C, 0xB4, 0x7D, 0xB5, 0x7D, 0xB1, 0x7C, 0xB4, 0x7C, 0xB3, 0x7C, 0xB2, 0x7A, 0xB1, 0x7A, 0xB4, 0x7B, 0xB1, 0x7C, 0xB5, 0x7D, 0xB2, 0x7B, 0xB1, 0x79, 0xAE, 0x78, 0xA4, 0x6C, 0x75, 0x47, 0x3B, 0x25, 0x26, 0x1A, 0x20, 0x16, 0x1D, 0x14, 0x19, 0x12, 0x18, 0x11, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x16, 0x10, 0x19, 0x12, 0x1A, 0x12, 0x19, 0x11, 0x18, 0x11, 0x19, 0x11, 0x18, 0x11, 0x18, 0x10, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x1A, 0x12, 0x1B, 0x12, 0x19, 0x11, 0x18, 0x11, 0x19, 0x12, 0x18, 0x11, 0x19, 0x11, 0x18, 0x11, 0x18, 0x10, 0x17, 0x10, 0x18, 0x11, 0x17, 0x10, 0x18, 0x11, 0x1A, 0x12, 0x1B, 0x12, 0x1B, 0x13, 0x1B, 0x12, 0x1B, 0x12, 0x19, 0x12, 0x1A, 0x12, 0x1E, 0x13, 0x38, 0x1B, 0x58, 0x22, 0x5F, 0x22, 0x56, 0x20, 0x34, 0x19, 0x3B, 0x1D, 0x5B, 0x23, 0x65, 0x26, 0x68, 0x26, 0x6A, 0x26, 0x64, 0x24, 0x65, 0x25, 0x67, 0x26, 0x67, 0x25, 0x62, 0x22, 0x66, 0x25, 0x67, 0x24, 0x65, 0x23, 0x65, 0x24, 0x62, 0x23, 0x60, 0x23, 0x63, 0x24, 0x65, 0x24, 0x65, 0x25, 0x66, 0x25, 0x66, 0x24, 0x62, 0x23, 0x64, 0x25, 0x66, 0x25, 0x66, 0x25, 0x65, 0x25, 0x6B, 0x26, 0x68, 0x25, 0x64, 0x24, 0x60, 0x21, 0x62, 0x23, 0x61, 0x23, 0x62, 0x23, 0x5F, 0x22, 0x60, 0x22, 0x64, 0x24, 0x64, 0x23, 0x61, 0x23, 0x63, 0x23, 0x63, 0x23, 0x63, 0x25, 0x62, 0x24, 0x63, 0x24, 0x60, 0x23, 0x67, 0x24, 0x63, 0x23, 0x67, 0x25, 0x69, 0x26, 0x65, 0x24, 0x64, 0x23, 0x66, 0x24, 0x61, 0x23, 0x64, 0x24, 0x63, 0x24, 0x61, 0x23, 0x62, 0x24, 0x62, 0x23, 0x63, 0x24, 0x62, 0x23, 0x5E, 0x22, 0x61, 0x21, 0x5E, 0x21, 0x5C, 0x20, 0x5D, 0x21, 0x59, 0x20, 0x40, 0x19, 0x2D, 0x13, 0x24, 0x12, 0x22, 0x11, 0x28, 0x13, 0x38, 0x17, 0x3C, 0x19, 0x40, 0x1B, 0x47, 0x1D, 0x58, 0x21, 0x60, 0x23, 0x62, 0x23, 0x61, 0x22, 0x5D, 0x22, 0x61, 0x23, 0x5E, 0x22, 0x5A, 0x21, 0x5D, 0x21, 0x5E, 0x21, 0x5E, 0x22, 0x60, 0x22, 0x5C, 0x21, 0x5D, 0x21, 0x5F, 0x23, 0x61, 0x22, 0x5E, 0x21, 0x5D, 0x22, 0x5B, 0x21, 0x5D, 0x22, 0x5D, 0x22, 0x5D, 0x23, 0x5E, 0x23, 0x60, 0x23, 0x5F, 0x23, 0x63, 0x25, 0x61, 0x23, 0x60, 0x24, 0x5C, 0x22, 0x5E, 0x23, 0x63, 0x24, 0x61, 0x23, 0x5A, 0x21, 0x5C, 0x21, 0x5C, 0x22, 0x5D, 0x22, 0x5F, 0x22, 0x5C, 0x21, 0x5B, 0x21, 0x57, 0x20, 0x55, 0x1F, 0x56, 0x1F, 0x57, 0x1F, 0x55, 0x1F, 0x54, 0x1F, 0x59, 0x21, 0x58, 0x21, 0x5A, 0x21, 0x5B, 0x21, 0x5B, 0x21, 0x58, 0x20, 0x55, 0x1F, 0x58, 0x20, 0x56, 0x20, 0x39, 0x1C, 0x39, 0x1D, 0x34, 0x1D, 0x36, 0x1C, 0x28, 0x17, 0x2E, 0x1A, 0x29, 0x18, 0x32, 0x1C, 0x2C, 0x19, 0x2E, 0x1A, 0x37, 0x1E, 0x37, 0x1D, 0x34, 0x1D, 0x30, 0x1B, 0x3A, 0x1F, 0x3B, 0x1F, 0x35, 0x1D, 0x39, 0x1F, 0x2E, 0x1A, 0x3A, 0x1E, 0x32, 0x1B, 0x3B, 0x1E, 0x33, 0x1C, 0x3D, 0x1F, 0x36, 0x1D, 0x3A, 0x1D, 0x2A, 0x18, 0x38, 0x1D, 0x2F, 0x1A, 0x33, 0x1B, 0x2A, 0x19, 0x31, 0x1B, 0x2F, 0x1A, 0x32, 0x1A, 0x26, 0x16, 0x2E, 0x1A, 0x2A, 0x18, 0x38, 0x1E, 0x33, 0x1B, 0x34, 0x1C, 0x34, 0x1C, 0x30, 0x1A, 0x28, 0x18, 0x35, 0x1C, 0x2D, 0x19, 0x2E, 0x1A
    },

    {
        0x3B, 0x36, 0x39, 0x39, 0x47, 0x46, 0x4F, 0x4A, 0x4D, 0x48, 0x43, 0x3C, 0x2E, 0x29, 0x1F, 0x1F, 0x1B, 0x1C, 0x18, 0x1A, 0x17, 0x1A, 0x16, 0x18, 0x16, 0x19, 0x16, 0x19, 0x14, 0x17, 0x13, 0x16, 0x12, 0x16, 0x13, 0x16, 0x13, 0x17, 0x14, 0x17, 0x13, 0x16, 0x13, 0x17, 0x13, 0x16, 0x13, 0x16, 0x12, 0x16, 0x12, 0x15, 0x12, 0x16, 0x12, 0x16, 0x12, 0x15, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x13, 0x17, 0x12, 0x16, 0x13, 0x16, 0x12, 0x16, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x14, 0x18, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x13, 0x16, 0x13, 0x17, 0x13, 0x18, 0x13, 0x17, 0x14, 0x18, 0x13, 0x18, 0x13, 0x17, 0x13, 0x16, 0x12, 0x16, 0x13, 0x17, 0x14, 0x18, 0x1A, 0x22, 0x34, 0x51, 0x5B, 0x7F, 0x6C, 0x8F, 0x76, 0x99, 0x7D, 0xA1, 0x81, 0xA6, 0x86, 0xA9, 0x88, 0xAB, 0x88, 0xAB, 0x89, 0xB0, 0x8D, 0xB3, 0x8E, 0xB2, 0x8E, 0xB1, 0x8B, 0xB0, 0x8B, 0xAD, 0x8A, 0xAC, 0x8A, 0xAF, 0x8C, 0xAE, 0x8B, 0xAF, 0x8B, 0xB0, 0x8D, 0xAF, 0x8A, 0xAE, 0x8B, 0xAD, 0x8B, 0xB0, 0x8B, 0xB0, 0x8B, 0xB0, 0x8B, 0xB0, 0x8A, 0xB0, 0x8A, 0xAC, 0x88, 0xAB, 0x89, 0xAD, 0x89, 0xB0, 0x8C, 0xB3, 0x89, 0xAE, 0x86, 0xA9, 0x81, 0xA8, 0x74, 0x91, 0x51, 0x59, 0x2C, 0x2E, 0x1F, 0x22, 0x19, 0x1E, 0x17, 0x1B, 0x15, 0x19, 0x13, 0x17, 0x13, 0x17, 0x12, 0x17, 0x13, 0x16, 0x13, 0x16, 0x13, 0x17, 0x13, 0x17, 0x13, 0x16, 0x13, 0x17, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x14, 0x17, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x13, 0x18, 0x13, 0x18, 0x15, 0x19, 0x15, 0x1A, 0x15, 0x19, 0x13, 0x17, 0x14, 0x19, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x13, 0x17, 0x13, 0x17, 0x14, 0x18, 0x13, 0x17, 0x14, 0x18, 0x15, 0x19, 0x16, 0x1A, 0x17, 0x1C, 0x16, 0x1A, 0x16, 0x19, 0x16, 0x1A, 0x18, 0x1A, 0x20, 0x24, 0x43, 0x48, 0x60, 0x5B, 0x63, 0x5B, 0x53, 0x4B, 0x36, 0x2E, 0x46, 0x47, 0x64, 0x5E, 0x6F, 0x65, 0x74, 0x69, 0x77, 0x69, 0x70, 0x64, 0x70, 0x66, 0x73, 0x67, 0x74, 0x64, 0x71, 0x62, 0x72, 0x65, 0x71, 0x66, 0x70, 0x64, 0x73, 0x63, 0x71, 0x61, 0x6E, 0x61, 0x70, 0x64, 0x70, 0x63, 0x6E, 0x63, 0x74, 0x65, 0x74, 0x64, 0x6F, 0x62, 0x70, 0x66, 0x71, 0x63, 0x72, 0x66, 0x73, 0x67, 0x76, 0x68, 0x73, 0x66, 0x6F, 0x62, 0x6C, 0x5F, 0x71, 0x64, 0x6E, 0x61, 0x6D, 0x60, 0x6E, 0x5E, 0x6D, 0x60, 0x72, 0x64, 0x73, 0x64, 0x6D, 0x60, 0x70, 0x61, 0x70, 0x61, 0x6E, 0x63, 0x6D, 0x61, 0x6F, 0x61, 0x6D, 0x61, 0x73, 0x65, 0x6F, 0x62, 0x74, 0x68, 0x75, 0x69, 0x73, 0x64, 0x72, 0x64, 0x71, 0x66, 0x6F, 0x61, 0x70, 0x63, 0x70, 0x64, 0x6F, 0x63, 0x70, 0x64, 0x70, 0x62, 0x70, 0x63, 0x6E, 0x60, 0x6B, 0x5D, 0x70, 0x61, 0x6B, 0x5C, 0x69, 0x5B, 0x6A, 0x5E, 0x66, 0x5A, 0x4C, 0x42, 0x37, 0x2F, 0x2C, 0x26, 0x2A, 0x26, 0x32, 0x30, 0x45, 0x42, 0x4B, 0x47, 0x52, 0x4D, 0x57, 0x51, 0x64, 0x5C, 0x69, 0x60, 0x6C, 0x60, 0x6D, 0x60, 0x6A, 0x5E, 0x6D, 0x5F, 0x6B, 0x5C, 0x66, 0x5B, 0x68, 0x5C, 0x69, 0x5E, 0x6C, 0x5D, 0x6C, 0x60, 0x67, 0x5B, 0x67, 0x5D, 0x68, 0x5F, 0x6C, 0x5F, 0x6B, 0x5E, 0x67, 0x5C, 0x66, 0x5C, 0x69, 0x5C, 0x69, 0x5C, 0x69, 0x60, 0x69, 0x5F, 0x6C, 0x61, 0x68, 0x5D, 0x6C, 0x64, 0x6D, 0x61, 0x6D, 0x62, 0x67, 0x5C, 0x68, 0x5D, 0x6E, 0x63, 0x6D, 0x60, 0x66, 0x5B, 0x68, 0x5C, 0x64, 0x5B, 0x68, 0x5D, 0x69, 0x5C, 0x68, 0x5C, 0x67, 0x5B, 0x63, 0x57, 0x63, 0x57, 0x62, 0x55, 0x62, 0x56, 0x63, 0x56, 0x62, 0x55, 0x65, 0x58, 0x64, 0x58, 0x64, 0x58, 0x66, 0x5A, 0x67, 0x5B, 0x65, 0x59, 0x5F, 0x54, 0x62, 0x58, 0x5E, 0x51, 0x3A, 0x39, 0x32, 0x32, 0x2F, 0x36, 0x2C, 0x2E, 0x26, 0x28, 0x2B, 0x2E, 0x2A, 0x2F, 0x2D, 0x32, 0x29, 0x2F, 0x2B, 0x32, 0x32, 0x3A, 0x2D, 0x32, 0x31, 0x39, 0x28, 0x2D, 0x33, 0x3C, 0x34, 0x39, 0x30, 0x34, 0x32, 0x37, 0x2A, 0x30, 0x32, 0x37, 0x2D, 0x33, 0x35, 0x3A, 0x2C, 0x33, 0x33, 0x38, 0x2E, 0x34, 0x31, 0x33, 0x25, 0x29, 0x2F, 0x32, 0x28, 0x2C, 0x2B, 0x2D, 0x26, 0x2C, 0x2A, 0x2D, 0x2B, 0x31, 0x2B, 0x2E, 0x23, 0x25, 0x2B, 0x30, 0x27, 0x2C, 0x34, 0x3B, 0x31, 0x36, 0x31, 0x36, 0x2B, 0x31, 0x29, 0x2B, 0x25, 0x2A, 0x30, 0x34, 0x2A, 0x2E, 0x2B, 0x30
    },

    {
        0x43, 0x1B, 0x39, 0x18, 0x3A, 0x1A, 0x46, 0x1B, 0x4C, 0x1C, 0x4A, 0x1B, 0x3E, 0x18, 0x2B, 0x14, 0x1F, 0x11, 0x1C, 0x10, 0x1A, 0x10, 0x19, 0x10, 0x18, 0x10, 0x18, 0x10, 0x17, 0x0F, 0x17, 0x10, 0x17, 0x0F, 0x16, 0x10, 0x18, 0x11, 0x18, 0x10, 0x18, 0x11, 0x17, 0x10, 0x16, 0x10, 0x17, 0x10, 0x17, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x0F, 0x15, 0x0F, 0x16, 0x0F, 0x16, 0x10, 0x16, 0x10, 0x17, 0x10, 0x16, 0x10, 0x17, 0x10, 0x17, 0x10, 0x16, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x11, 0x17, 0x10, 0x17, 0x10, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x1A, 0x12, 0x19, 0x11, 0x19, 0x12, 0x1A, 0x12, 0x18, 0x11, 0x18, 0x10, 0x17, 0x10, 0x17, 0x10, 0x18, 0x11, 0x1A, 0x14, 0x27, 0x22, 0x58, 0x44, 0x87, 0x5F, 0x98, 0x68, 0xA1, 0x6F, 0xA8, 0x73, 0xAC, 0x77, 0xAC, 0x77, 0xB0, 0x78, 0xAF, 0x77, 0xB3, 0x7A, 0xB5, 0x7C, 0xB6, 0x7F, 0xB6, 0x7C, 0xB3, 0x7C, 0xB2, 0x7A, 0xB1, 0x79, 0xB3, 0x7A, 0xB1, 0x79, 0xAF, 0x78, 0xB0, 0x7A, 0xB1, 0x7A, 0xB2, 0x7A, 0xB2, 0x7A, 0xB4, 0x7B, 0xB1, 0x7A, 0xB3, 0x7A, 0xB4, 0x7B, 0xB1, 0x7A, 0xB0, 0x7A, 0xB4, 0x7B, 0xB5, 0x7D, 0xB5, 0x7D, 0xB0, 0x79, 0xAC, 0x77, 0xA5, 0x6D, 0x74, 0x45, 0x3A, 0x25, 0x27, 0x1B, 0x1F, 0x15, 0x1C, 0x13, 0x19, 0x12, 0x19, 0x11, 0x18, 0x11, 0x17, 0x10, 0x16, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x12, 0x18, 0x11, 0x1A, 0x11, 0x19, 0x11, 0x19, 0x12, 0x19, 0x11, 0x18, 0x11, 0x1A, 0x12, 0x1A, 0x12, 0x1C, 0x13, 0x1A, 0x12, 0x19, 0x11, 0x19, 0x11, 0x19, 0x11, 0x18, 0x10, 0x19, 0x11, 0x19, 0x11, 0x19, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x19, 0x11, 0x1D, 0x14, 0x1D, 0x14, 0x1A, 0x11, 0x18, 0x11, 0x1B, 0x13, 0x1D, 0x14, 0x34, 0x1A, 0x5B, 0x23, 0x62, 0x23, 0x59, 0x22, 0x39, 0x1C, 0x3C, 0x1D, 0x59, 0x23, 0x62, 0x25, 0x69, 0x26, 0x6B, 0x26, 0x6A, 0x26, 0x67, 0x26, 0x69, 0x26, 0x68, 0x25, 0x67, 0x24, 0x65, 0x24, 0x67, 0x25, 0x64, 0x24, 0x65, 0x24, 0x66, 0x25, 0x66, 0x25, 0x65, 0x25, 0x67, 0x26, 0x65, 0x25, 0x66, 0x25, 0x66, 0x25, 0x69, 0x26, 0x6A, 0x26, 0x69, 0x27, 0x68, 0x25, 0x63, 0x24, 0x65, 0x25, 0x64, 0x25, 0x66, 0x24, 0x60, 0x23, 0x64, 0x24, 0x66, 0x25, 0x65, 0x24, 0x63, 0x23, 0x62, 0x23, 0x64, 0x23, 0x65, 0x23, 0x63, 0x24, 0x62, 0x23, 0x61, 0x23, 0x64, 0x24, 0x67, 0x27, 0x65, 0x24, 0x63, 0x25, 0x62, 0x23, 0x64, 0x23, 0x63, 0x25, 0x69, 0x26, 0x69, 0x27, 0x66, 0x24, 0x65, 0x24, 0x65, 0x24, 0x66, 0x24, 0x64, 0x23, 0x64, 0x24, 0x65, 0x24, 0x67, 0x25, 0x63, 0x23, 0x5F, 0x23, 0x62, 0x24, 0x5F, 0x22, 0x61, 0x23, 0x5E, 0x21, 0x61, 0x22, 0x5F, 0x22, 0x62, 0x23, 0x57, 0x1F, 0x4B, 0x1C, 0x42, 0x1A, 0x41, 0x1A, 0x48, 0x1C, 0x53, 0x1F, 0x5B, 0x21, 0x5F, 0x23, 0x60, 0x22, 0x63, 0x23, 0x61, 0x23, 0x5F, 0x23, 0x61, 0x23, 0x62, 0x23, 0x62, 0x23, 0x61, 0x23, 0x61, 0x22, 0x60, 0x21, 0x5D, 0x21, 0x5E, 0x22, 0x5D, 0x21, 0x5F, 0x22, 0x60, 0x23, 0x5E, 0x22, 0x61, 0x22, 0x60, 0x22, 0x5D, 0x23, 0x59, 0x20, 0x59, 0x21, 0x5A, 0x21, 0x5E, 0x22, 0x5E, 0x22, 0x5D, 0x22, 0x5E, 0x22, 0x62, 0x24, 0x60, 0x22, 0x5E, 0x22, 0x5D, 0x22, 0x5D, 0x23, 0x61, 0x23, 0x5F, 0x22, 0x5C, 0x21, 0x5B, 0x21, 0x5D, 0x21, 0x5C, 0x21, 0x59, 0x20, 0x5B, 0x22, 0x5A, 0x20, 0x59, 0x20, 0x56, 0x20, 0x58, 0x20, 0x59, 0x20, 0x58, 0x20, 0x57, 0x1F, 0x56, 0x1F, 0x57, 0x20, 0x58, 0x1F, 0x56, 0x1F, 0x58, 0x21, 0x59, 0x20, 0x54, 0x1F, 0x58, 0x20, 0x51, 0x1E, 0x3A, 0x1D, 0x2C, 0x19, 0x36, 0x1D, 0x33, 0x1D, 0x36, 0x1D, 0x35, 0x1D, 0x3C, 0x1F, 0x35, 0x1C, 0x33, 0x1A, 0x34, 0x1D, 0x34, 0x1C, 0x33, 0x1B, 0x34, 0x1B, 0x28, 0x18, 0x3D, 0x21, 0x2D, 0x19, 0x30, 0x1B, 0x30, 0x19, 0x2C, 0x19, 0x2C, 0x17, 0x30, 0x1B, 0x32, 0x1B, 0x29, 0x17, 0x2A, 0x18, 0x28, 0x18, 0x2B, 0x18, 0x28, 0x17, 0x2E, 0x19, 0x2C, 0x18, 0x31, 0x1B, 0x30, 0x1B, 0x36, 0x1D, 0x33, 0x1C, 0x39, 0x1F, 0x32, 0x1B, 0x3D, 0x20, 0x31, 0x1B, 0x3A, 0x1F, 0x34, 0x1C, 0x2C, 0x19, 0x2B, 0x19, 0x35, 0x1C, 0x2E, 0x1A, 0x3C, 0x20, 0x38, 0x1D, 0x2C, 0x18
    },

    {
        0x4E, 0x45, 0x40, 0x39, 0x39, 0x38, 0x45, 0x44, 0x51, 0x4D, 0x51, 0x4B, 0x48, 0x3F, 0x32, 0x2C, 0x21, 0x20, 0x1B, 0x1C, 0x19, 0x1A, 0x17, 0x19, 0x16, 0x18, 0x15, 0x17, 0x14, 0x16, 0x13, 0x16, 0x13, 0x16, 0x13, 0x17, 0x14, 0x18, 0x14, 0x18, 0x13, 0x17, 0x13, 0x17, 0x13, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x15, 0x12, 0x16, 0x12, 0x15, 0x11, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x13, 0x16, 0x13, 0x16, 0x13, 0x16, 0x12, 0x16, 0x12, 0x15, 0x12, 0x16, 0x13, 0x16, 0x12, 0x16, 0x13, 0x17, 0x12, 0x17, 0x13, 0x17, 0x13, 0x18, 0x14, 0x18, 0x14, 0x18, 0x14, 0x19, 0x14, 0x19, 0x13, 0x17, 0x13, 0x17, 0x12, 0x16, 0x12, 0x16, 0x13, 0x17, 0x16, 0x19, 0x1C, 0x24, 0x36, 0x51, 0x5D, 0x81, 0x6F, 0x92, 0x79, 0x9C, 0x80, 0xA4, 0x85, 0xAA, 0x86, 0xA8, 0x88, 0xAA, 0x88, 0xAA, 0x88, 0xAC, 0x8C, 0xAF, 0x8D, 0xB2, 0x8D, 0xB2, 0x8D, 0xB0, 0x8B, 0xAD, 0x89, 0xAB, 0x88, 0xAC, 0x88, 0xAB, 0x87, 0xAC, 0x8A, 0xAD, 0x8A, 0xAE, 0x8B, 0xAF, 0x8A, 0xAD, 0x8A, 0xAC, 0x89, 0xAB, 0x89, 0xAE, 0x8B, 0xB0, 0x8A, 0xB0, 0x88, 0xAD, 0x89, 0xAE, 0x8A, 0xAF, 0x89, 0xAE, 0x88, 0xAE, 0x84, 0xAA, 0x79, 0x99, 0x54, 0x59, 0x2C, 0x2F, 0x1F, 0x23, 0x19, 0x1D, 0x16, 0x19, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x13, 0x17, 0x13, 0x16, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x13, 0x16, 0x13, 0x16, 0x14, 0x18, 0x13, 0x17, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x15, 0x1A, 0x16, 0x1A, 0x16, 0x1B, 0x15, 0x19, 0x14, 0x18, 0x14, 0x18, 0x14, 0x19, 0x13, 0x18, 0x14, 0x17, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x14, 0x17, 0x15, 0x19, 0x18, 0x1C, 0x16, 0x1A, 0x15, 0x18, 0x15, 0x18, 0x18, 0x1C, 0x1E, 0x22, 0x3E, 0x42, 0x62, 0x5E, 0x69, 0x61, 0x57, 0x4E, 0x38, 0x32, 0x46, 0x48, 0x63, 0x5E, 0x6E, 0x64, 0x75, 0x69, 0x76, 0x68, 0x75, 0x68, 0x71, 0x66, 0x73, 0x68, 0x72, 0x64, 0x74, 0x65, 0x72, 0x65, 0x76, 0x66, 0x73, 0x65, 0x72, 0x64, 0x73, 0x65, 0x70, 0x64, 0x71, 0x65, 0x71, 0x66, 0x72, 0x64, 0x71, 0x65, 0x71, 0x65, 0x75, 0x68, 0x76, 0x67, 0x73, 0x69, 0x75, 0x66, 0x70, 0x62, 0x72, 0x64, 0x71, 0x65, 0x73, 0x65, 0x6D, 0x5F, 0x73, 0x67, 0x72, 0x65, 0x72, 0x65, 0x6F, 0x62, 0x6E, 0x5F, 0x70, 0x63, 0x72, 0x64, 0x6F, 0x62, 0x71, 0x62, 0x6F, 0x62, 0x6F, 0x64, 0x71, 0x67, 0x71, 0x64, 0x6E, 0x62, 0x6F, 0x62, 0x73, 0x64, 0x71, 0x63, 0x73, 0x68, 0x74, 0x68, 0x6F, 0x63, 0x72, 0x65, 0x72, 0x63, 0x74, 0x68, 0x72, 0x62, 0x72, 0x66, 0x73, 0x65, 0x72, 0x66, 0x70, 0x62, 0x6D, 0x61, 0x6F, 0x60, 0x6D, 0x60, 0x6C, 0x60, 0x6C, 0x60, 0x71, 0x63, 0x6C, 0x61, 0x6E, 0x60, 0x65, 0x58, 0x59, 0x4E, 0x50, 0x48, 0x4D, 0x49, 0x56, 0x4F, 0x60, 0x56, 0x67, 0x5C, 0x6C, 0x5F, 0x6B, 0x5F, 0x6B, 0x5F, 0x6F, 0x62, 0x6E, 0x61, 0x70, 0x61, 0x6F, 0x63, 0x6E, 0x61, 0x6E, 0x61, 0x6C, 0x5F, 0x6C, 0x5E, 0x6B, 0x5E, 0x6D, 0x60, 0x6C, 0x5D, 0x6A, 0x5F, 0x6C, 0x61, 0x69, 0x5D, 0x6B, 0x60, 0x6B, 0x5F, 0x67, 0x5D, 0x63, 0x59, 0x64, 0x59, 0x66, 0x5A, 0x67, 0x5C, 0x6A, 0x5E, 0x67, 0x5C, 0x6B, 0x5F, 0x6B, 0x61, 0x6B, 0x5E, 0x6A, 0x5D, 0x68, 0x5D, 0x67, 0x5D, 0x6C, 0x5E, 0x6B, 0x5D, 0x67, 0x5B, 0x67, 0x5A, 0x67, 0x5E, 0x67, 0x5D, 0x65, 0x5A, 0x67, 0x5B, 0x66, 0x58, 0x64, 0x58, 0x63, 0x57, 0x63, 0x59, 0x63, 0x57, 0x63, 0x55, 0x63, 0x57, 0x61, 0x55, 0x63, 0x56, 0x63, 0x57, 0x62, 0x56, 0x63, 0x57, 0x66, 0x59, 0x61, 0x57, 0x63, 0x57, 0x58, 0x4E, 0x3A, 0x39, 0x2C, 0x2E, 0x31, 0x38, 0x31, 0x39, 0x30, 0x34, 0x30, 0x39, 0x34, 0x37, 0x2E, 0x34, 0x2B, 0x2B, 0x2E, 0x37, 0x2B, 0x2D, 0x2E, 0x34, 0x2C, 0x2E, 0x25, 0x29, 0x34, 0x3B, 0x26, 0x28, 0x2F, 0x34, 0x2A, 0x2A, 0x27, 0x2C, 0x25, 0x27, 0x2A, 0x31, 0x2A, 0x2D, 0x25, 0x28, 0x27, 0x28, 0x24, 0x2A, 0x27, 0x2B, 0x27, 0x2D, 0x2A, 0x2E, 0x2A, 0x2F, 0x2E, 0x33, 0x2C, 0x32, 0x30, 0x36, 0x2F, 0x36, 0x35, 0x3D, 0x2F, 0x34, 0x35, 0x3D, 0x2C, 0x30, 0x33, 0x38, 0x2B, 0x30, 0x28, 0x2B, 0x29, 0x2E, 0x31, 0x37, 0x29, 0x2F, 0x37, 0x3E, 0x31, 0x34, 0x26, 0x2A
    },

    {
        0x4E, 0x1D, 0x46, 0x1A, 0x3A, 0x1A, 0x38, 0x1A, 0x45, 0x1C, 0x4D, 0x1D, 0x4D, 0x1C, 0x43, 0x1A, 0x30, 0x15, 0x21, 0x12, 0x1D, 0x11, 0x1A, 0x10, 0x19, 0x10, 0x19, 0x10, 0x18, 0x10, 0x17, 0x10, 0x17, 0x10, 0x18, 0x11, 0x19, 0x12, 0x19, 0x11, 0x18, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x16, 0x10, 0x16, 0x0F, 0x16, 0x0F, 0x16, 0x10, 0x16, 0x0F, 0x16, 0x0F, 0x15, 0x0F, 0x16, 0x10, 0x16, 0x0F, 0x17, 0x11, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x16, 0x10, 0x17, 0x10, 0x17, 0x10, 0x16, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x16, 0x10, 0x17, 0x10, 0x17, 0x10, 0x18, 0x11, 0x19, 0x12, 0x1B, 0x13, 0x19, 0x12, 0x18, 0x11, 0x17, 0x11, 0x17, 0x10, 0x16, 0x10, 0x17, 0x11, 0x17, 0x11, 0x19, 0x13, 0x26, 0x21, 0x52, 0x41, 0x81, 0x5E, 0x99, 0x6B, 0xA0, 0x6F, 0xA8, 0x73, 0xAA, 0x75, 0xAE, 0x78, 0xAE, 0x78, 0xB1, 0x7B, 0xB6, 0x7C, 0xB5, 0x7B, 0xB6, 0x7D, 0xB7, 0x7C, 0xB2, 0x7B, 0xB0, 0x7A, 0xAE, 0x79, 0xB2, 0x7A, 0xB2, 0x7A, 0xB1, 0x78, 0xB2, 0x78, 0xB2, 0x7A, 0xB0, 0x79, 0xB0, 0x7B, 0xB1, 0x7A, 0xB2, 0x7A, 0xB4, 0x7B, 0xB0, 0x79, 0xAF, 0x78, 0xAF, 0x7A, 0xAF, 0x79, 0xB1, 0x7B, 0xB2, 0x79, 0xAB, 0x72, 0x7E, 0x4C, 0x40, 0x28, 0x28, 0x1B, 0x20, 0x17, 0x1C, 0x14, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x19, 0x11, 0x19, 0x11, 0x17, 0x10, 0x17, 0x11, 0x18, 0x11, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x1A, 0x12, 0x19, 0x11, 0x19, 0x11, 0x1A, 0x12, 0x19, 0x11, 0x18, 0x10, 0x18, 0x11, 0x18, 0x11, 0x1A, 0x12, 0x1A, 0x13, 0x1C, 0x13, 0x1A, 0x13, 0x1A, 0x12, 0x19, 0x12, 0x19, 0x11, 0x19, 0x11, 0x19, 0x11, 0x18, 0x11, 0x18, 0x11, 0x17, 0x10, 0x17, 0x10, 0x18, 0x11, 0x19, 0x12, 0x1C, 0x13, 0x1B, 0x12, 0x19, 0x12, 0x19, 0x11, 0x19, 0x11, 0x19, 0x11, 0x1B, 0x12, 0x32, 0x1A, 0x55, 0x21, 0x61, 0x24, 0x5C, 0x23, 0x37, 0x1B, 0x37, 0x1C, 0x59, 0x24, 0x65, 0x26, 0x66, 0x26, 0x65, 0x25, 0x65, 0x26, 0x68, 0x26, 0x68, 0x26, 0x65, 0x25, 0x66, 0x25, 0x65, 0x25, 0x68, 0x26, 0x69, 0x26, 0x68, 0x27, 0x66, 0x25, 0x65, 0x24, 0x65, 0x25, 0x64, 0x25, 0x65, 0x26, 0x67, 0x25, 0x66, 0x26, 0x65, 0x24, 0x64, 0x26, 0x66, 0x25, 0x69, 0x26, 0x6A, 0x26, 0x66, 0x25, 0x67, 0x25, 0x66, 0x24, 0x63, 0x23, 0x63, 0x24, 0x69, 0x27, 0x67, 0x25, 0x6A, 0x27, 0x63, 0x24, 0x61, 0x22, 0x60, 0x22, 0x61, 0x24, 0x61, 0x23, 0x62, 0x23, 0x64, 0x24, 0x62, 0x24, 0x64, 0x25, 0x62, 0x24, 0x63, 0x23, 0x63, 0x23, 0x63, 0x24, 0x67, 0x25, 0x68, 0x26, 0x68, 0x25, 0x61, 0x24, 0x60, 0x22, 0x66, 0x25, 0x68, 0x24, 0x62, 0x23, 0x67, 0x25, 0x65, 0x24, 0x67, 0x24, 0x66, 0x24, 0x63, 0x23, 0x60, 0x22, 0x61, 0x23, 0x64, 0x24, 0x61, 0x23, 0x61, 0x23, 0x62, 0x23, 0x61, 0x23, 0x60, 0x23, 0x5F, 0x22, 0x5B, 0x22, 0x5D, 0x22, 0x5D, 0x22, 0x5D, 0x21, 0x5E, 0x22, 0x60, 0x22, 0x5D, 0x21, 0x5D, 0x22, 0x60, 0x22, 0x63, 0x23, 0x62, 0x24, 0x62, 0x23, 0x5D, 0x22, 0x5E, 0x22, 0x5C, 0x21, 0x5E, 0x22, 0x60, 0x22, 0x61, 0x23, 0x61, 0x23, 0x5C, 0x21, 0x61, 0x22, 0x60, 0x22, 0x5E, 0x22, 0x5C, 0x21, 0x5E, 0x22, 0x5F, 0x23, 0x5D, 0x23, 0x5B, 0x21, 0x5D, 0x22, 0x5C, 0x22, 0x5F, 0x23, 0x5D, 0x21, 0x60, 0x23, 0x60, 0x22, 0x5D, 0x22, 0x5F, 0x23, 0x5D, 0x23, 0x5D, 0x22, 0x5F, 0x22, 0x58, 0x21, 0x5F, 0x22, 0x5E, 0x22, 0x5C, 0x21, 0x5C, 0x22, 0x5A, 0x21, 0x57, 0x20, 0x59, 0x20, 0x58, 0x20, 0x57, 0x20, 0x55, 0x1F, 0x56, 0x1F, 0x58, 0x1F, 0x5A, 0x21, 0x59, 0x21, 0x59, 0x21, 0x59, 0x20, 0x58, 0x21, 0x5A, 0x21, 0x59, 0x20, 0x58, 0x21, 0x52, 0x20, 0x47, 0x22, 0x34, 0x1B, 0x34, 0x1D, 0x38, 0x1E, 0x2B, 0x19, 0x34, 0x1D, 0x28, 0x18, 0x2F, 0x1A, 0x28, 0x17, 0x30, 0x1A, 0x2B, 0x18, 0x36, 0x1D, 0x2B, 0x19, 0x32, 0x1C, 0x35, 0x1E, 0x2A, 0x18, 0x3C, 0x20, 0x2F, 0x1A, 0x2F, 0x1B, 0x2F, 0x1A, 0x32, 0x1C, 0x36, 0x1D, 0x35, 0x1C, 0x37, 0x1D, 0x2E, 0x1B, 0x3B, 0x1E, 0x31, 0x1B, 0x36, 0x1D, 0x34, 0x1C, 0x37, 0x1D, 0x2E, 0x1B, 0x35, 0x1B, 0x35, 0x1F, 0x37, 0x1D, 0x2A, 0x18, 0x32, 0x1B, 0x2D, 0x1B, 0x36, 0x1D, 0x35, 0x1D, 0x2F, 0x1A, 0x2F, 0x1B, 0x32, 0x1A, 0x2D, 0x1A, 0x38, 0x1D, 0x2B, 0x17, 0x29, 0x18
    },

    {
        0x58, 0x4E, 0x50, 0x47, 0x43, 0x3A, 0x39, 0x37, 0x43, 0x44, 0x51, 0x4D, 0x54, 0x4C, 0x4D, 0x45, 0x39, 0x32, 0x25, 0x22, 0x1D, 0x1D, 0x19, 0x1A, 0x17, 0x19, 0x17, 0x19, 0x16, 0x18, 0x15, 0x18, 0x13, 0x17, 0x14, 0x17, 0x14, 0x18, 0x14, 0x18, 0x14, 0x17, 0x13, 0x17, 0x13, 0x16, 0x13, 0x17, 0x12, 0x16, 0x13, 0x16, 0x12, 0x16, 0x12, 0x15, 0x12, 0x16, 0x13, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x15, 0x12, 0x16, 0x13, 0x16, 0x12, 0x16, 0x13, 0x16, 0x12, 0x16, 0x13, 0x16, 0x13, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x13, 0x16, 0x13, 0x17, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x13, 0x17, 0x14, 0x1A, 0x17, 0x1C, 0x15, 0x19, 0x14, 0x18, 0x13, 0x17, 0x12, 0x16, 0x13, 0x17, 0x13, 0x16, 0x13, 0x17, 0x16, 0x18, 0x1C, 0x23, 0x32, 0x4A, 0x59, 0x7D, 0x71, 0x94, 0x78, 0x9B, 0x7E, 0xA0, 0x82, 0xA6, 0x87, 0xAA, 0x88, 0xAD, 0x89, 0xAD, 0x8B, 0xB1, 0x8B, 0xAF, 0x8A, 0xB2, 0x8C, 0xB0, 0x8C, 0xB0, 0x8B, 0xAE, 0x8A, 0xAD, 0x8A, 0xAF, 0x89, 0xAE, 0x89, 0xAB, 0x89, 0xAC, 0x8A, 0xAF, 0x8A, 0xAE, 0x8A, 0xAF, 0x8B, 0xAD, 0x89, 0xAD, 0x88, 0xAC, 0x88, 0xAC, 0x87, 0xAA, 0x89, 0xAD, 0x8A, 0xAE, 0x88, 0xAC, 0x84, 0xAA, 0x7B, 0x9B, 0x58, 0x61, 0x2E, 0x31, 0x20, 0x23, 0x1A, 0x1E, 0x17, 0x1A, 0x15, 0x18, 0x14, 0x18, 0x14, 0x17, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x13, 0x17, 0x14, 0x18, 0x14, 0x17, 0x13, 0x17, 0x13, 0x17, 0x15, 0x19, 0x15, 0x18, 0x15, 0x19, 0x16, 0x1A, 0x14, 0x18, 0x14, 0x17, 0x14, 0x18, 0x14, 0x17, 0x16, 0x1A, 0x16, 0x1B, 0x17, 0x1C, 0x16, 0x1A, 0x15, 0x19, 0x15, 0x19, 0x14, 0x19, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x13, 0x16, 0x13, 0x17, 0x14, 0x18, 0x15, 0x19, 0x17, 0x1C, 0x16, 0x19, 0x15, 0x18, 0x15, 0x18, 0x16, 0x19, 0x17, 0x18, 0x1C, 0x1D, 0x39, 0x40, 0x5D, 0x58, 0x67, 0x61, 0x59, 0x4F, 0x38, 0x30, 0x43, 0x42, 0x63, 0x5E, 0x6F, 0x64, 0x71, 0x65, 0x71, 0x63, 0x73, 0x67, 0x75, 0x66, 0x72, 0x66, 0x73, 0x67, 0x73, 0x65, 0x70, 0x64, 0x74, 0x68, 0x76, 0x67, 0x72, 0x68, 0x71, 0x63, 0x71, 0x63, 0x70, 0x65, 0x6E, 0x61, 0x70, 0x66, 0x74, 0x65, 0x71, 0x65, 0x6F, 0x62, 0x70, 0x63, 0x75, 0x67, 0x74, 0x69, 0x77, 0x69, 0x71, 0x65, 0x73, 0x64, 0x74, 0x65, 0x6F, 0x61, 0x72, 0x63, 0x76, 0x6A, 0x75, 0x65, 0x76, 0x6A, 0x6F, 0x63, 0x6F, 0x60, 0x6B, 0x5F, 0x6F, 0x61, 0x6E, 0x5F, 0x6E, 0x60, 0x71, 0x62, 0x6F, 0x63, 0x71, 0x64, 0x6F, 0x62, 0x71, 0x63, 0x72, 0x62, 0x70, 0x63, 0x74, 0x66, 0x76, 0x69, 0x75, 0x66, 0x6E, 0x62, 0x6D, 0x5F, 0x75, 0x67, 0x75, 0x65, 0x6D, 0x60, 0x74, 0x65, 0x71, 0x64, 0x72, 0x66, 0x71, 0x64, 0x6F, 0x61, 0x6B, 0x5F, 0x6D, 0x61, 0x70, 0x62, 0x6C, 0x61, 0x6C, 0x60, 0x6D, 0x61, 0x6E, 0x62, 0x6D, 0x61, 0x6C, 0x5F, 0x69, 0x60, 0x68, 0x5D, 0x6C, 0x60, 0x67, 0x5C, 0x6A, 0x5E, 0x6D, 0x60, 0x6C, 0x5D, 0x69, 0x5E, 0x6D, 0x60, 0x6F, 0x61, 0x70, 0x62, 0x6D, 0x60, 0x6A, 0x5B, 0x6C, 0x5E, 0x69, 0x5E, 0x6A, 0x60, 0x6D, 0x60, 0x6E, 0x61, 0x70, 0x61, 0x68, 0x5C, 0x6E, 0x61, 0x6B, 0x5F, 0x69, 0x5D, 0x69, 0x5B, 0x69, 0x5E, 0x6A, 0x5E, 0x67, 0x5C, 0x65, 0x5A, 0x69, 0x5E, 0x66, 0x5D, 0x69, 0x5E, 0x68, 0x5D, 0x69, 0x60, 0x69, 0x5E, 0x6A, 0x5D, 0x6A, 0x5F, 0x67, 0x5D, 0x69, 0x5E, 0x6A, 0x5E, 0x65, 0x5B, 0x6D, 0x5E, 0x69, 0x5C, 0x69, 0x5C, 0x69, 0x5D, 0x66, 0x5A, 0x64, 0x57, 0x66, 0x5A, 0x63, 0x58, 0x64, 0x58, 0x63, 0x55, 0x62, 0x55, 0x65, 0x59, 0x65, 0x5A, 0x65, 0x5A, 0x64, 0x59, 0x63, 0x57, 0x63, 0x59, 0x65, 0x5A, 0x66, 0x5A, 0x63, 0x57, 0x59, 0x51, 0x46, 0x46, 0x2F, 0x30, 0x30, 0x35, 0x30, 0x32, 0x26, 0x29, 0x2E, 0x31, 0x27, 0x28, 0x2B, 0x2F, 0x27, 0x2B, 0x2E, 0x32, 0x2A, 0x2D, 0x31, 0x36, 0x2A, 0x30, 0x2D, 0x32, 0x2F, 0x36, 0x28, 0x2B, 0x36, 0x3C, 0x2B, 0x2F, 0x2D, 0x33, 0x2B, 0x2E, 0x30, 0x35, 0x32, 0x37, 0x2F, 0x35, 0x30, 0x33, 0x2B, 0x32, 0x34, 0x38, 0x2A, 0x2E, 0x31, 0x35, 0x2D, 0x34, 0x2F, 0x31, 0x2B, 0x31, 0x2C, 0x30, 0x2E, 0x37, 0x2F, 0x31, 0x27, 0x2A, 0x2C, 0x30, 0x2A, 0x32, 0x32, 0x38, 0x31, 0x36, 0x2B, 0x2F, 0x2A, 0x30, 0x2A, 0x2E, 0x29, 0x31, 0x2F, 0x33, 0x27, 0x29, 0x26, 0x2C
    },

    {
        0x52, 0x1E, 0x50, 0x1C, 0x49, 0x1B, 0x3C, 0x19, 0x37, 0x19, 0x43, 0x1C, 0x4F, 0x1E, 0x4D, 0x1D, 0x47, 0x1B, 0x34, 0x16, 0x24, 0x13, 0x1D, 0x11, 0x1B, 0x10, 0x1A, 0x10, 0x19, 0x10, 0x19, 0x11, 0x18, 0x10, 0x18, 0x11, 0x18, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x0F, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x16, 0x0F, 0x16, 0x0F, 0x16, 0x0F, 0x16, 0x10, 0x16, 0x0F, 0x15, 0x0F, 0x16, 0x0F, 0x16, 0x10, 0x17, 0x10, 0x16, 0x0F, 0x16, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x16, 0x0F, 0x16, 0x10, 0x17, 0x10, 0x16, 0x10, 0x18, 0x10, 0x17, 0x10, 0x16, 0x10, 0x17, 0x10, 0x17, 0x11, 0x1A, 0x13, 0x1F, 0x15, 0x1C, 0x14, 0x19, 0x12, 0x18, 0x11, 0x17, 0x11, 0x16, 0x10, 0x17, 0x10, 0x17, 0x11, 0x18, 0x11, 0x19, 0x13, 0x22, 0x1C, 0x45, 0x39, 0x7B, 0x59, 0x94, 0x68, 0xA1, 0x6D, 0xA6, 0x73, 0xAB, 0x75, 0xB0, 0x77, 0xB1, 0x79, 0xB1, 0x7B, 0xB3, 0x7C, 0xB4, 0x7C, 0xB5, 0x7D, 0xB6, 0x7C, 0xB4, 0x7B, 0xB3, 0x7B, 0xB3, 0x7B, 0xB1, 0x7B, 0xB2, 0x7A, 0xB0, 0x79, 0xB0, 0x79, 0xB1, 0x79, 0xB2, 0x7A, 0xB2, 0x7B, 0xB0, 0x7B, 0xB1, 0x7B, 0xB3, 0x79, 0xB0, 0x79, 0xB1, 0x79, 0xB2, 0x79, 0xAD, 0x79, 0xAA, 0x73, 0x85, 0x50, 0x43, 0x29, 0x2A, 0x1C, 0x22, 0x17, 0x1D, 0x14, 0x1A, 0x12, 0x19, 0x12, 0x18, 0x10, 0x17, 0x10, 0x17, 0x11, 0x17, 0x11, 0x17, 0x11, 0x19, 0x11, 0x18, 0x11, 0x17, 0x10, 0x17, 0x10, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x19, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x19, 0x12, 0x1A, 0x13, 0x1D, 0x14, 0x1D, 0x14, 0x1B, 0x13, 0x1A, 0x12, 0x19, 0x12, 0x1A, 0x12, 0x1A, 0x11, 0x19, 0x11, 0x19, 0x11, 0x19, 0x11, 0x19, 0x11, 0x18, 0x10, 0x19, 0x12, 0x1B, 0x12, 0x1A, 0x12, 0x18, 0x10, 0x19, 0x12, 0x1A, 0x12, 0x19, 0x11, 0x1C, 0x12, 0x31, 0x1A, 0x50, 0x1F, 0x5D, 0x23, 0x5A, 0x22, 0x3A, 0x1C, 0x37, 0x1D, 0x58, 0x23, 0x64, 0x24, 0x67, 0x26, 0x65, 0x26, 0x67, 0x26, 0x6B, 0x27, 0x67, 0x26, 0x67, 0x25, 0x67, 0x26, 0x67, 0x25, 0x66, 0x26, 0x68, 0x26, 0x64, 0x24, 0x61, 0x24, 0x64, 0x25, 0x63, 0x24, 0x65, 0x25, 0x66, 0x25, 0x64, 0x24, 0x61, 0x23, 0x62, 0x23, 0x63, 0x24, 0x63, 0x23, 0x66, 0x25, 0x66, 0x25, 0x66, 0x25, 0x65, 0x25, 0x63, 0x24, 0x63, 0x24, 0x66, 0x24, 0x67, 0x26, 0x6A, 0x27, 0x67, 0x25, 0x67, 0x25, 0x61, 0x24, 0x62, 0x23, 0x62, 0x23, 0x63, 0x24, 0x63, 0x23, 0x65, 0x24, 0x65, 0x24, 0x61, 0x23, 0x63, 0x25, 0x66, 0x25, 0x64, 0x24, 0x63, 0x24, 0x64, 0x24, 0x61, 0x24, 0x66, 0x24, 0x63, 0x23, 0x65, 0x24, 0x63, 0x23, 0x64, 0x23, 0x63, 0x23, 0x61, 0x24, 0x63, 0x24, 0x5F, 0x23, 0x61, 0x23, 0x5F, 0x23, 0x5F, 0x23, 0x5F, 0x22, 0x61, 0x23, 0x65, 0x23, 0x62, 0x23, 0x60, 0x23, 0x64, 0x24, 0x66, 0x26, 0x61, 0x23, 0x5F, 0x22, 0x60, 0x23, 0x5E, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x5E, 0x22, 0x5F, 0x23, 0x60, 0x22, 0x5B, 0x20, 0x5C, 0x21, 0x5E, 0x22, 0x60, 0x23, 0x61, 0x23, 0x62, 0x23, 0x5E, 0x22, 0x60, 0x22, 0x61, 0x23, 0x5F, 0x22, 0x5C, 0x21, 0x5B, 0x21, 0x5C, 0x22, 0x5F, 0x22, 0x5E, 0x22, 0x5C, 0x21, 0x5B, 0x21, 0x5C, 0x23, 0x5D, 0x22, 0x5E, 0x23, 0x5B, 0x22, 0x5D, 0x22, 0x5F, 0x23, 0x5F, 0x23, 0x5A, 0x21, 0x5E, 0x22, 0x59, 0x22, 0x5F, 0x23, 0x5F, 0x24, 0x5E, 0x24, 0x5D, 0x22, 0x5D, 0x22, 0x5A, 0x22, 0x5D, 0x22, 0x58, 0x20, 0x5D, 0x22, 0x5C, 0x21, 0x5A, 0x21, 0x57, 0x20, 0x57, 0x20, 0x56, 0x20, 0x5B, 0x21, 0x58, 0x1F, 0x56, 0x1F, 0x56, 0x20, 0x57, 0x20, 0x57, 0x20, 0x58, 0x20, 0x54, 0x20, 0x59, 0x21, 0x58, 0x20, 0x58, 0x20, 0x56, 0x21, 0x52, 0x20, 0x35, 0x1A, 0x26, 0x17, 0x36, 0x1D, 0x2E, 0x1A, 0x34, 0x1D, 0x36, 0x1E, 0x34, 0x1D, 0x3F, 0x22, 0x40, 0x22, 0x3A, 0x1F, 0x33, 0x1C, 0x3F, 0x21, 0x36, 0x1D, 0x2A, 0x19, 0x39, 0x1F, 0x2E, 0x1A, 0x39, 0x1F, 0x2E, 0x19, 0x36, 0x1D, 0x2C, 0x19, 0x3A, 0x20, 0x33, 0x1B, 0x2B, 0x19, 0x2F, 0x19, 0x32, 0x1C, 0x2F, 0x19, 0x29, 0x17, 0x31, 0x1A, 0x2A, 0x19, 0x31, 0x1B, 0x30, 0x1C, 0x31, 0x1A, 0x35, 0x1E, 0x39, 0x1F, 0x31, 0x1A, 0x36, 0x1D, 0x3F, 0x21, 0x39, 0x1E, 0x34, 0x1C, 0x2C, 0x19, 0x33, 0x1C, 0x38, 0x1D, 0x39, 0x1F, 0x35, 0x1C, 0x2E, 0x1A, 0x31, 0x1B
    },

    {
        0x5D, 0x52, 0x59, 0x50, 0x53, 0x49, 0x46, 0x3C, 0x3A, 0x37, 0x42, 0x42, 0x51, 0x4D, 0x53, 0x4D, 0x4E, 0x48, 0x3D, 0x35, 0x29, 0x25, 0x1E, 0x1E, 0x1A, 0x1B, 0x18, 0x1A, 0x16, 0x19, 0x16, 0x18, 0x15, 0x18, 0x15, 0x18, 0x14, 0x18, 0x14, 0x17, 0x13, 0x17, 0x12, 0x17, 0x13, 0x16, 0x12, 0x17, 0x13, 0x17, 0x12, 0x16, 0x12, 0x16, 0x13, 0x16, 0x13, 0x16, 0x12, 0x16, 0x12, 0x15, 0x11, 0x15, 0x11, 0x15, 0x12, 0x15, 0x12, 0x16, 0x12, 0x16, 0x13, 0x16, 0x12, 0x16, 0x13, 0x16, 0x12, 0x16, 0x12, 0x15, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x13, 0x17, 0x13, 0x17, 0x12, 0x16, 0x13, 0x17, 0x13, 0x17, 0x15, 0x19, 0x17, 0x1D, 0x17, 0x1B, 0x14, 0x18, 0x13, 0x17, 0x13, 0x17, 0x12, 0x16, 0x13, 0x17, 0x13, 0x16, 0x14, 0x17, 0x15, 0x18, 0x1A, 0x20, 0x2C, 0x3E, 0x51, 0x74, 0x6F, 0x91, 0x78, 0x9B, 0x7E, 0xA2, 0x83, 0xA6, 0x86, 0xAA, 0x89, 0xAC, 0x8A, 0xAE, 0x8B, 0xB0, 0x8C, 0xAF, 0x8C, 0xAF, 0x8B, 0xAF, 0x8B, 0xAE, 0x8B, 0xAF, 0x8A, 0xAF, 0x8B, 0xAF, 0x8A, 0xAE, 0x88, 0xAD, 0x88, 0xAA, 0x88, 0xAD, 0x8B, 0xAF, 0x8C, 0xB0, 0x8A, 0xB0, 0x8B, 0xAF, 0x8A, 0xAE, 0x88, 0xAB, 0x87, 0xAB, 0x88, 0xAA, 0x84, 0xAA, 0x7E, 0xA0, 0x5D, 0x6A, 0x31, 0x35, 0x21, 0x26, 0x1C, 0x1F, 0x18, 0x1C, 0x16, 0x1A, 0x14, 0x18, 0x14, 0x17, 0x13, 0x17, 0x13, 0x18, 0x13, 0x17, 0x13, 0x17, 0x14, 0x18, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x14, 0x18, 0x14, 0x18, 0x14, 0x19, 0x14, 0x19, 0x14, 0x18, 0x14, 0x18, 0x14, 0x17, 0x14, 0x18, 0x15, 0x1A, 0x16, 0x1A, 0x17, 0x1C, 0x17, 0x1B, 0x16, 0x1A, 0x15, 0x18, 0x15, 0x19, 0x16, 0x1A, 0x15, 0x19, 0x14, 0x18, 0x14, 0x18, 0x14, 0x19, 0x15, 0x18, 0x14, 0x18, 0x15, 0x19, 0x15, 0x1A, 0x15, 0x18, 0x14, 0x17, 0x15, 0x18, 0x16, 0x1A, 0x17, 0x19, 0x1D, 0x1F, 0x3A, 0x40, 0x59, 0x57, 0x64, 0x5D, 0x59, 0x4F, 0x38, 0x30, 0x42, 0x42, 0x64, 0x5E, 0x70, 0x65, 0x74, 0x68, 0x73, 0x67, 0x74, 0x66, 0x76, 0x6B, 0x74, 0x66, 0x74, 0x66, 0x73, 0x65, 0x73, 0x65, 0x72, 0x67, 0x72, 0x67, 0x70, 0x61, 0x6D, 0x62, 0x6E, 0x63, 0x6E, 0x62, 0x70, 0x64, 0x70, 0x65, 0x70, 0x64, 0x6F, 0x61, 0x71, 0x61, 0x70, 0x63, 0x72, 0x62, 0x71, 0x66, 0x72, 0x64, 0x70, 0x63, 0x71, 0x64, 0x6F, 0x60, 0x70, 0x63, 0x73, 0x65, 0x72, 0x65, 0x76, 0x6A, 0x76, 0x67, 0x76, 0x66, 0x6D, 0x60, 0x6F, 0x62, 0x6F, 0x62, 0x71, 0x64, 0x6E, 0x62, 0x71, 0x64, 0x72, 0x63, 0x6F, 0x62, 0x70, 0x64, 0x71, 0x64, 0x73, 0x64, 0x72, 0x63, 0x70, 0x63, 0x6E, 0x61, 0x73, 0x65, 0x72, 0x64, 0x71, 0x64, 0x6F, 0x61, 0x70, 0x63, 0x71, 0x62, 0x6F, 0x61, 0x70, 0x63, 0x6B, 0x5F, 0x6F, 0x62, 0x6C, 0x5E, 0x6A, 0x5E, 0x6E, 0x60, 0x6E, 0x60, 0x73, 0x65, 0x6C, 0x60, 0x6B, 0x60, 0x71, 0x65, 0x73, 0x66, 0x6E, 0x60, 0x6C, 0x5F, 0x6D, 0x62, 0x6B, 0x5F, 0x6D, 0x5F, 0x6C, 0x5F, 0x68, 0x5C, 0x6A, 0x5D, 0x6B, 0x5E, 0x67, 0x59, 0x69, 0x5C, 0x6B, 0x5E, 0x6D, 0x60, 0x6E, 0x61, 0x71, 0x64, 0x6C, 0x5E, 0x6C, 0x61, 0x6B, 0x60, 0x6B, 0x5F, 0x69, 0x5A, 0x65, 0x5B, 0x69, 0x5B, 0x6A, 0x5D, 0x6A, 0x5D, 0x68, 0x5B, 0x67, 0x5A, 0x63, 0x58, 0x67, 0x5D, 0x6A, 0x5F, 0x67, 0x5B, 0x69, 0x5D, 0x6B, 0x5F, 0x69, 0x5D, 0x65, 0x5A, 0x69, 0x5E, 0x65, 0x5B, 0x6A, 0x5F, 0x67, 0x5F, 0x66, 0x5E, 0x66, 0x5B, 0x67, 0x5C, 0x66, 0x5C, 0x69, 0x5B, 0x65, 0x5A, 0x66, 0x5C, 0x66, 0x5A, 0x63, 0x59, 0x61, 0x55, 0x5F, 0x56, 0x63, 0x57, 0x69, 0x5C, 0x65, 0x58, 0x60, 0x55, 0x61, 0x55, 0x61, 0x56, 0x62, 0x55, 0x63, 0x56, 0x61, 0x55, 0x64, 0x58, 0x62, 0x57, 0x61, 0x56, 0x63, 0x56, 0x5A, 0x4D, 0x33, 0x2E, 0x27, 0x28, 0x31, 0x34, 0x2C, 0x30, 0x2F, 0x36, 0x30, 0x38, 0x2F, 0x35, 0x3A, 0x43, 0x36, 0x3B, 0x33, 0x3A, 0x2A, 0x2E, 0x35, 0x3D, 0x2D, 0x30, 0x26, 0x2B, 0x33, 0x39, 0x28, 0x2E, 0x31, 0x36, 0x2A, 0x2C, 0x31, 0x37, 0x26, 0x29, 0x33, 0x3C, 0x2B, 0x2C, 0x2A, 0x2E, 0x2A, 0x2C, 0x2E, 0x37, 0x28, 0x2B, 0x27, 0x2D, 0x2B, 0x2D, 0x27, 0x2B, 0x2C, 0x32, 0x2B, 0x33, 0x2D, 0x2F, 0x2F, 0x37, 0x34, 0x3B, 0x2C, 0x31, 0x33, 0x3A, 0x33, 0x39, 0x30, 0x34, 0x2C, 0x2E, 0x26, 0x2A, 0x2F, 0x37, 0x31, 0x36, 0x33, 0x39, 0x2E, 0x33, 0x29, 0x2C, 0x2D, 0x34
    },

    {
        0x55, 0x1E, 0x53, 0x1D, 0x50, 0x1D, 0x4D, 0x1C, 0x42, 0x1A, 0x37, 0x19, 0x3F, 0x1B, 0x4C, 0x1E, 0x4E, 0x1D, 0x48, 0x1B, 0x39, 0x17, 0x26, 0x13, 0x1E, 0x11, 0x1B, 0x11, 0x1A, 0x11, 0x19, 0x10, 0x19, 0x11, 0x19, 0x11, 0x1B, 0x12, 0x1A, 0x11, 0x18, 0x10, 0x17, 0x10, 0x17, 0x10, 0x18, 0x10, 0x18, 0x11, 0x17, 0x10, 0x17, 0x11, 0x17, 0x10, 0x16, 0x0F, 0x16, 0x0F, 0x16, 0x0F, 0x16, 0x10, 0x16, 0x0F, 0x16, 0x0F, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x17, 0x10, 0x17, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x17, 0x10, 0x17, 0x10, 0x16, 0x10, 0x17, 0x10, 0x18, 0x11, 0x17, 0x11, 0x18, 0x11, 0x19, 0x12, 0x19, 0x11, 0x18, 0x10, 0x17, 0x11, 0x17, 0x11, 0x18, 0x11, 0x18, 0x12, 0x18, 0x11, 0x19, 0x11, 0x19, 0x12, 0x20, 0x1A, 0x3C, 0x33, 0x77, 0x58, 0x98, 0x68, 0x9E, 0x6D, 0xA7, 0x74, 0xAD, 0x78, 0xB1, 0x79, 0xB4, 0x7B, 0xB5, 0x7C, 0xB8, 0x7E, 0xB4, 0x7E, 0xB2, 0x7B, 0xB3, 0x7B, 0xB3, 0x7A, 0xB4, 0x7B, 0xB2, 0x7A, 0xAF, 0x78, 0xAD, 0x77, 0xAE, 0x79, 0xB1, 0x7A, 0xB3, 0x7C, 0xB5, 0x7C, 0xB5, 0x7C, 0xB6, 0x7D, 0xB2, 0x7C, 0xB1, 0x7B, 0xB1, 0x79, 0xB0, 0x78, 0xA8, 0x70, 0x85, 0x51, 0x46, 0x2B, 0x2C, 0x1E, 0x25, 0x19, 0x1E, 0x15, 0x1A, 0x12, 0x18, 0x11, 0x18, 0x11, 0x18, 0x10, 0x18, 0x11, 0x18, 0x11, 0x17, 0x10, 0x17, 0x10, 0x17, 0x11, 0x18, 0x11, 0x17, 0x10, 0x18, 0x10, 0x19, 0x12, 0x19, 0x11, 0x1A, 0x12, 0x19, 0x11, 0x19, 0x11, 0x1C, 0x13, 0x1B, 0x13, 0x1A, 0x12, 0x1A, 0x11, 0x1A, 0x12, 0x1C, 0x13, 0x1B, 0x12, 0x1B, 0x13, 0x1B, 0x13, 0x1B, 0x12, 0x1B, 0x13, 0x1B, 0x12, 0x1A, 0x11, 0x19, 0x11, 0x1A, 0x12, 0x1C, 0x13, 0x1C, 0x12, 0x19, 0x11, 0x19, 0x11, 0x19, 0x11, 0x19, 0x11, 0x1A, 0x12, 0x1B, 0x12, 0x1B, 0x12, 0x2E, 0x18, 0x52, 0x21, 0x5C, 0x22, 0x5A, 0x22, 0x3B, 0x1B, 0x33, 0x1B, 0x55, 0x22, 0x62, 0x25, 0x65, 0x25, 0x68, 0x27, 0x67, 0x26, 0x67, 0x26, 0x6C, 0x27, 0x67, 0x27, 0x69, 0x27, 0x66, 0x25, 0x66, 0x25, 0x6A, 0x27, 0x66, 0x26, 0x65, 0x25, 0x65, 0x24, 0x62, 0x23, 0x63, 0x24, 0x65, 0x25, 0x63, 0x24, 0x66, 0x26, 0x66, 0x24, 0x62, 0x23, 0x63, 0x24, 0x67, 0x26, 0x66, 0x25, 0x63, 0x24, 0x66, 0x24, 0x65, 0x24, 0x65, 0x24, 0x66, 0x26, 0x6A, 0x26, 0x67, 0x24, 0x65, 0x24, 0x65, 0x24, 0x63, 0x24, 0x64, 0x24, 0x66, 0x24, 0x62, 0x23, 0x65, 0x24, 0x64, 0x24, 0x66, 0x24, 0x65, 0x24, 0x65, 0x24, 0x69, 0x27, 0x66, 0x25, 0x68, 0x25, 0x65, 0x24, 0x62, 0x24, 0x63, 0x24, 0x66, 0x25, 0x68, 0x26, 0x66, 0x25, 0x65, 0x24, 0x64, 0x24, 0x69, 0x25, 0x63, 0x23, 0x63, 0x24, 0x64, 0x24, 0x64, 0x24, 0x64, 0x24, 0x5F, 0x22, 0x5F, 0x22, 0x60, 0x23, 0x64, 0x24, 0x63, 0x24, 0x62, 0x25, 0x65, 0x26, 0x66, 0x25, 0x62, 0x23, 0x61, 0x23, 0x62, 0x23, 0x61, 0x23, 0x61, 0x22, 0x5E, 0x22, 0x5E, 0x22, 0x5C, 0x22, 0x5E, 0x22, 0x5E, 0x22, 0x5B, 0x21, 0x5E, 0x22, 0x60, 0x23, 0x5C, 0x21, 0x5F, 0x22, 0x5F, 0x22, 0x5D, 0x22, 0x5E, 0x22, 0x60, 0x23, 0x5F, 0x22, 0x5E, 0x22, 0x5F, 0x22, 0x5E, 0x22, 0x5F, 0x22, 0x5E, 0x22, 0x5D, 0x21, 0x58, 0x21, 0x5F, 0x22, 0x5F, 0x23, 0x5C, 0x21, 0x5D, 0x21, 0x5F, 0x23, 0x5C, 0x22, 0x5B, 0x22, 0x5C, 0x22, 0x5E, 0x23, 0x60, 0x24, 0x5D, 0x23, 0x60, 0x24, 0x5F, 0x24, 0x5B, 0x21, 0x5D, 0x23, 0x5F, 0x23, 0x5B, 0x22, 0x59, 0x21, 0x59, 0x21, 0x57, 0x20, 0x59, 0x21, 0x58, 0x21, 0x5A, 0x21, 0x5C, 0x21, 0x56, 0x20, 0x56, 0x20, 0x57, 0x20, 0x57, 0x20, 0x5A, 0x21, 0x58, 0x20, 0x55, 0x1F, 0x54, 0x1F, 0x57, 0x20, 0x58, 0x20, 0x56, 0x20, 0x53, 0x20, 0x3C, 0x1D, 0x2F, 0x1A, 0x3D, 0x20, 0x3D, 0x1F, 0x31, 0x1B, 0x37, 0x1E, 0x32, 0x1C, 0x3F, 0x21, 0x2C, 0x19, 0x34, 0x1C, 0x2B, 0x18, 0x37, 0x1D, 0x2D, 0x1A, 0x2E, 0x1B, 0x34, 0x1B, 0x33, 0x1C, 0x37, 0x1E, 0x2E, 0x1A, 0x32, 0x1C, 0x2E, 0x1A, 0x3A, 0x20, 0x31, 0x1A, 0x32, 0x1C, 0x31, 0x19, 0x35, 0x1C, 0x34, 0x1B, 0x2E, 0x1A, 0x34, 0x1B, 0x31, 0x1B, 0x32, 0x1B, 0x32, 0x1C, 0x30, 0x1B, 0x2D, 0x1A, 0x34, 0x1B, 0x2A, 0x18, 0x2E, 0x1A, 0x29, 0x19, 0x33, 0x1C, 0x2E, 0x1A, 0x2D, 0x19, 0x31, 0x1B, 0x30, 0x1A, 0x2D, 0x1A, 0x29, 0x18, 0x27, 0x17, 0x31, 0x1B
    },

    {
        0x5F, 0x55, 0x5D, 0x53, 0x5B, 0x52, 0x57, 0x4D, 0x4B, 0x42, 0x3C, 0x37, 0x3C, 0x3D, 0x4D, 0x4B, 0x52, 0x4F, 0x50, 0x4A, 0x42, 0x3B, 0x2C, 0x27, 0x20, 0x1F, 0x1A, 0x1C, 0x18, 0x1A, 0x17, 0x19, 0x17, 0x19, 0x16, 0x19, 0x16, 0x1B, 0x16, 0x1B, 0x15, 0x19, 0x14, 0x18, 0x14, 0x17, 0x14, 0x18, 0x14, 0x18, 0x13, 0x17, 0x13, 0x17, 0x13, 0x16, 0x12, 0x16, 0x12, 0x16, 0x11, 0x15, 0x12, 0x15, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x17, 0x13, 0x17, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x15, 0x12, 0x16, 0x12, 0x16, 0x13, 0x16, 0x12, 0x16, 0x13, 0x18, 0x13, 0x17, 0x13, 0x18, 0x13, 0x18, 0x14, 0x18, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x13, 0x18, 0x13, 0x17, 0x14, 0x18, 0x14, 0x18, 0x15, 0x18, 0x1A, 0x1D, 0x28, 0x38, 0x4D, 0x70, 0x6C, 0x90, 0x77, 0x9B, 0x80, 0xA5, 0x86, 0xAA, 0x87, 0xAC, 0x89, 0xAD, 0x8C, 0xB1, 0x8E, 0xB2, 0x8D, 0xB1, 0x8D, 0xB0, 0x8C, 0xB0, 0x8A, 0xAE, 0x8A, 0xAE, 0x87, 0xAC, 0x86, 0xAB, 0x86, 0xA9, 0x86, 0xAD, 0x89, 0xAD, 0x8A, 0xB0, 0x8B, 0xAF, 0x8A, 0xAE, 0x8B, 0xB1, 0x8B, 0xB0, 0x89, 0xB0, 0x89, 0xAE, 0x85, 0xAA, 0x7A, 0x9B, 0x5D, 0x69, 0x33, 0x36, 0x23, 0x27, 0x1D, 0x22, 0x18, 0x1C, 0x15, 0x19, 0x14, 0x18, 0x14, 0x17, 0x13, 0x17, 0x13, 0x17, 0x14, 0x17, 0x12, 0x16, 0x13, 0x17, 0x14, 0x18, 0x13, 0x17, 0x13, 0x16, 0x14, 0x17, 0x14, 0x19, 0x15, 0x19, 0x15, 0x1A, 0x15, 0x19, 0x15, 0x19, 0x16, 0x1B, 0x16, 0x1B, 0x16, 0x1A, 0x15, 0x18, 0x16, 0x1A, 0x19, 0x1C, 0x16, 0x1A, 0x16, 0x1B, 0x16, 0x1B, 0x16, 0x1B, 0x16, 0x1C, 0x16, 0x1A, 0x15, 0x19, 0x15, 0x18, 0x16, 0x1B, 0x17, 0x1D, 0x16, 0x1B, 0x15, 0x19, 0x15, 0x18, 0x15, 0x19, 0x15, 0x19, 0x16, 0x1A, 0x17, 0x1B, 0x1B, 0x1E, 0x37, 0x3B, 0x5A, 0x57, 0x61, 0x5C, 0x59, 0x50, 0x39, 0x31, 0x3E, 0x3E, 0x60, 0x5D, 0x6D, 0x63, 0x6F, 0x63, 0x73, 0x66, 0x73, 0x67, 0x74, 0x67, 0x78, 0x6B, 0x73, 0x69, 0x75, 0x6A, 0x73, 0x67, 0x73, 0x66, 0x74, 0x69, 0x72, 0x66, 0x72, 0x64, 0x72, 0x65, 0x6E, 0x60, 0x6D, 0x63, 0x72, 0x66, 0x70, 0x62, 0x72, 0x66, 0x75, 0x65, 0x6F, 0x60, 0x71, 0x62, 0x74, 0x66, 0x72, 0x64, 0x70, 0x62, 0x72, 0x65, 0x72, 0x64, 0x71, 0x64, 0x73, 0x67, 0x75, 0x68, 0x72, 0x64, 0x70, 0x64, 0x72, 0x65, 0x70, 0x63, 0x72, 0x64, 0x73, 0x65, 0x6F, 0x60, 0x73, 0x65, 0x71, 0x63, 0x73, 0x65, 0x72, 0x65, 0x72, 0x64, 0x75, 0x69, 0x73, 0x65, 0x76, 0x68, 0x74, 0x64, 0x70, 0x64, 0x71, 0x64, 0x76, 0x67, 0x75, 0x68, 0x74, 0x65, 0x73, 0x64, 0x71, 0x63, 0x77, 0x68, 0x71, 0x63, 0x70, 0x65, 0x72, 0x63, 0x74, 0x65, 0x70, 0x61, 0x6B, 0x5E, 0x6D, 0x60, 0x6D, 0x61, 0x72, 0x64, 0x6F, 0x63, 0x6D, 0x63, 0x71, 0x65, 0x74, 0x65, 0x6F, 0x61, 0x6F, 0x62, 0x70, 0x62, 0x6E, 0x61, 0x6F, 0x60, 0x6D, 0x5F, 0x6C, 0x5F, 0x6A, 0x5E, 0x68, 0x5C, 0x69, 0x5D, 0x68, 0x5B, 0x69, 0x5D, 0x6C, 0x5F, 0x6A, 0x5C, 0x6B, 0x5F, 0x6A, 0x5D, 0x6A, 0x5E, 0x6D, 0x5F, 0x6C, 0x60, 0x6C, 0x61, 0x6B, 0x5F, 0x6B, 0x5F, 0x6B, 0x60, 0x6B, 0x60, 0x6A, 0x5E, 0x69, 0x5D, 0x65, 0x5B, 0x6C, 0x60, 0x6D, 0x5F, 0x68, 0x5C, 0x69, 0x5D, 0x6B, 0x5F, 0x68, 0x5B, 0x65, 0x5A, 0x67, 0x5A, 0x65, 0x5C, 0x6A, 0x5E, 0x67, 0x5D, 0x6B, 0x61, 0x69, 0x5E, 0x67, 0x5A, 0x67, 0x5D, 0x6B, 0x5F, 0x65, 0x5A, 0x63, 0x5A, 0x62, 0x58, 0x61, 0x58, 0x64, 0x5A, 0x63, 0x58, 0x63, 0x58, 0x67, 0x5B, 0x63, 0x57, 0x63, 0x58, 0x61, 0x57, 0x63, 0x58, 0x67, 0x5B, 0x65, 0x59, 0x60, 0x55, 0x60, 0x54, 0x63, 0x57, 0x62, 0x56, 0x61, 0x56, 0x5A, 0x4E, 0x3C, 0x3C, 0x2D, 0x2E, 0x38, 0x40, 0x34, 0x38, 0x28, 0x2C, 0x30, 0x35, 0x2B, 0x32, 0x34, 0x37, 0x27, 0x2A, 0x2E, 0x34, 0x2B, 0x2E, 0x31, 0x38, 0x2B, 0x30, 0x2A, 0x30, 0x30, 0x33, 0x30, 0x36, 0x32, 0x38, 0x29, 0x2D, 0x2D, 0x33, 0x2C, 0x2F, 0x33, 0x3A, 0x2D, 0x30, 0x2E, 0x36, 0x2B, 0x2E, 0x2F, 0x37, 0x2F, 0x31, 0x2B, 0x31, 0x2F, 0x30, 0x2B, 0x32, 0x2C, 0x2E, 0x2E, 0x35, 0x29, 0x2B, 0x2A, 0x30, 0x2D, 0x2F, 0x26, 0x28, 0x28, 0x2A, 0x26, 0x2C, 0x2F, 0x35, 0x2E, 0x33, 0x2D, 0x31, 0x2D, 0x31, 0x29, 0x2B, 0x28, 0x2D, 0x26, 0x28, 0x27, 0x2C, 0x30, 0x35
    },

    {
        0x57, 0x1F, 0x57, 0x1E, 0x56, 0x1E, 0x53, 0x1E, 0x4F, 0x1D, 0x44, 0x1A, 0x37, 0x19, 0x3C, 0x1B, 0x4B, 0x1D, 0x4E, 0x1D, 0x4C, 0x1D, 0x3E, 0x18, 0x2B, 0x15, 0x21, 0x13, 0x1D, 0x11, 0x1B, 0x11, 0x19, 0x10, 0x18, 0x10, 0x18, 0x10, 0x18, 0x11, 0x1B, 0x12, 0x1D, 0x13, 0x1A, 0x11, 0x19, 0x11, 0x19, 0x12, 0x18, 0x11, 0x18, 0x10, 0x17, 0x10, 0x16, 0x0F, 0x16, 0x0F, 0x15, 0x0F, 0x16, 0x0F, 0x16, 0x0F, 0x16, 0x10, 0x16, 0x10, 0x16, 0x0F, 0x17, 0x10, 0x17, 0x10, 0x17, 0x11, 0x18, 0x11, 0x17, 0x10, 0x16, 0x0F, 0x17, 0x10, 0x16, 0x10, 0x16, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x16, 0x10, 0x17, 0x10, 0x17, 0x11, 0x17, 0x10, 0x17, 0x11, 0x18, 0x10, 0x17, 0x10, 0x18, 0x11, 0x19, 0x12, 0x19, 0x11, 0x19, 0x12, 0x19, 0x12, 0x18, 0x11, 0x19, 0x12, 0x1E, 0x18, 0x36, 0x2E, 0x6F, 0x52, 0x94, 0x67, 0xA3, 0x71, 0xAA, 0x74, 0xAB, 0x76, 0xAE, 0x78, 0xB2, 0x7B, 0xB6, 0x7D, 0xB6, 0x7C, 0xB6, 0x7C, 0xB7, 0x7D, 0xB6, 0x7D, 0xB3, 0x7B, 0xB0, 0x77, 0xAB, 0x75, 0xAD, 0x76, 0xB0, 0x79, 0xB2, 0x7B, 0xB1, 0x7C, 0xB4, 0x7C, 0xB3, 0x7C, 0xB7, 0x7D, 0xB4, 0x7B, 0xB0, 0x7A, 0xB1, 0x7A, 0xA9, 0x73, 0x88, 0x54, 0x47, 0x2D, 0x2C, 0x1D, 0x22, 0x18, 0x1E, 0x15, 0x1A, 0x12, 0x18, 0x12, 0x1A, 0x12, 0x19, 0x11, 0x18, 0x11, 0x17, 0x10, 0x17, 0x10, 0x16, 0x10, 0x17, 0x11, 0x18, 0x11, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x19, 0x12, 0x1B, 0x13, 0x1B, 0x12, 0x1A, 0x12, 0x1A, 0x12, 0x1C, 0x14, 0x1D, 0x14, 0x1B, 0x13, 0x19, 0x11, 0x1A, 0x12, 0x1C, 0x13, 0x1C, 0x13, 0x1E, 0x15, 0x1D, 0x14, 0x1B, 0x13, 0x1A, 0x13, 0x1B, 0x13, 0x1B, 0x12, 0x1B, 0x13, 0x1C, 0x14, 0x1C, 0x14, 0x1B, 0x12, 0x19, 0x12, 0x19, 0x11, 0x1A, 0x11, 0x19, 0x11, 0x1A, 0x12, 0x1B, 0x13, 0x2D, 0x19, 0x51, 0x20, 0x5E, 0x24, 0x5F, 0x22, 0x3D, 0x1C, 0x32, 0x1A, 0x55, 0x22, 0x61, 0x24, 0x62, 0x24, 0x63, 0x24, 0x64, 0x26, 0x6A, 0x27, 0x68, 0x27, 0x6C, 0x27, 0x6B, 0x27, 0x68, 0x27, 0x6D, 0x28, 0x68, 0x26, 0x63, 0x25, 0x66, 0x25, 0x64, 0x24, 0x64, 0x25, 0x63, 0x24, 0x65, 0x26, 0x69, 0x26, 0x66, 0x25, 0x63, 0x24, 0x65, 0x25, 0x63, 0x24, 0x60, 0x23, 0x65, 0x25, 0x63, 0x24, 0x64, 0x25, 0x62, 0x23, 0x65, 0x24, 0x64, 0x23, 0x65, 0x25, 0x67, 0x25, 0x61, 0x23, 0x61, 0x23, 0x62, 0x24, 0x63, 0x24, 0x65, 0x24, 0x64, 0x24, 0x63, 0x24, 0x64, 0x23, 0x62, 0x23, 0x64, 0x24, 0x66, 0x24, 0x66, 0x25, 0x68, 0x26, 0x66, 0x26, 0x66, 0x25, 0x65, 0x24, 0x64, 0x24, 0x65, 0x24, 0x66, 0x24, 0x63, 0x23, 0x65, 0x24, 0x64, 0x24, 0x62, 0x23, 0x63, 0x23, 0x61, 0x22, 0x63, 0x23, 0x60, 0x23, 0x64, 0x23, 0x60, 0x23, 0x61, 0x22, 0x64, 0x22, 0x62, 0x23, 0x69, 0x25, 0x64, 0x24, 0x62, 0x24, 0x65, 0x26, 0x67, 0x26, 0x61, 0x23, 0x61, 0x23, 0x5E, 0x22, 0x60, 0x23, 0x61, 0x22, 0x62, 0x23, 0x62, 0x22, 0x5F, 0x22, 0x5C, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x61, 0x22, 0x5C, 0x22, 0x60, 0x23, 0x61, 0x22, 0x5D, 0x22, 0x5D, 0x22, 0x60, 0x22, 0x5D, 0x22, 0x5E, 0x22, 0x60, 0x23, 0x62, 0x23, 0x60, 0x23, 0x61, 0x23, 0x5F, 0x23, 0x60, 0x23, 0x60, 0x23, 0x61, 0x24, 0x61, 0x23, 0x5F, 0x22, 0x5F, 0x23, 0x5E, 0x22, 0x5E, 0x23, 0x5B, 0x22, 0x59, 0x22, 0x5B, 0x22, 0x5F, 0x24, 0x5F, 0x24, 0x61, 0x24, 0x5E, 0x23, 0x5A, 0x22, 0x5B, 0x21, 0x5E, 0x22, 0x5B, 0x21, 0x55, 0x1F, 0x59, 0x20, 0x5A, 0x21, 0x5C, 0x22, 0x5A, 0x22, 0x56, 0x20, 0x5B, 0x21, 0x5A, 0x21, 0x58, 0x20, 0x55, 0x1F, 0x57, 0x20, 0x58, 0x20, 0x56, 0x1E, 0x53, 0x1E, 0x57, 0x20, 0x58, 0x20, 0x58, 0x20, 0x57, 0x20, 0x4E, 0x1D, 0x36, 0x1B, 0x2B, 0x1A, 0x3B, 0x1F, 0x2E, 0x1A, 0x29, 0x19, 0x38, 0x1E, 0x37, 0x1F, 0x38, 0x1E, 0x30, 0x1B, 0x36, 0x1E, 0x33, 0x1C, 0x3A, 0x1F, 0x34, 0x1C, 0x2E, 0x1B, 0x42, 0x21, 0x31, 0x1B, 0x33, 0x1D, 0x2B, 0x19, 0x34, 0x1D, 0x29, 0x19, 0x32, 0x1C, 0x29, 0x18, 0x2E, 0x1A, 0x28, 0x17, 0x33, 0x1C, 0x29, 0x17, 0x2C, 0x19, 0x29, 0x17, 0x30, 0x1A, 0x2F, 0x1B, 0x32, 0x1B, 0x2A, 0x19, 0x31, 0x1C, 0x33, 0x1B, 0x34, 0x1C, 0x36, 0x1E, 0x34, 0x1D, 0x3F, 0x20, 0x3A, 0x1E, 0x30, 0x1A, 0x33, 0x1D, 0x32, 0x1B, 0x36, 0x1D, 0x38, 0x1E, 0x3C, 0x20, 0x35, 0x1D
    },

    {
        0x60, 0x55, 0x63, 0x58, 0x60, 0x55, 0x5D, 0x53, 0x59, 0x4F, 0x50, 0x45, 0x3F, 0x37, 0x3B, 0x3C, 0x49, 0x48, 0x55, 0x4F, 0x54, 0x4C, 0x4A, 0x40, 0x33, 0x2C, 0x22, 0x22, 0x1D, 0x1E, 0x1A, 0x1B, 0x17, 0x1A, 0x17, 0x18, 0x15, 0x18, 0x14, 0x18, 0x16, 0x1B, 0x17, 0x1C, 0x16, 0x1A, 0x15, 0x19, 0x15, 0x19, 0x14, 0x18, 0x14, 0x17, 0x13, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x15, 0x12, 0x15, 0x12, 0x15, 0x13, 0x16, 0x12, 0x16, 0x13, 0x16, 0x13, 0x17, 0x13, 0x17, 0x13, 0x16, 0x13, 0x17, 0x12, 0x16, 0x13, 0x16, 0x13, 0x16, 0x12, 0x16, 0x12, 0x16, 0x13, 0x17, 0x13, 0x17, 0x13, 0x16, 0x13, 0x16, 0x13, 0x17, 0x12, 0x16, 0x13, 0x17, 0x14, 0x17, 0x13, 0x17, 0x13, 0x17, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x15, 0x18, 0x18, 0x1C, 0x25, 0x31, 0x46, 0x68, 0x6A, 0x8F, 0x79, 0x9D, 0x7F, 0xA3, 0x84, 0xA9, 0x86, 0xAC, 0x88, 0xAF, 0x8B, 0xAF, 0x8B, 0xAF, 0x8C, 0xB0, 0x8E, 0xB3, 0x8D, 0xB3, 0x8B, 0xAF, 0x84, 0xA7, 0x7D, 0xA1, 0x7F, 0xA4, 0x85, 0xAB, 0x87, 0xAC, 0x8B, 0xB0, 0x8D, 0xB2, 0x8B, 0xB1, 0x8C, 0xB1, 0x89, 0xAD, 0x87, 0xAD, 0x87, 0xAD, 0x7E, 0xA1, 0x61, 0x6E, 0x36, 0x37, 0x23, 0x28, 0x1D, 0x20, 0x19, 0x1C, 0x16, 0x19, 0x15, 0x19, 0x15, 0x19, 0x14, 0x19, 0x14, 0x18, 0x13, 0x17, 0x13, 0x17, 0x13, 0x16, 0x14, 0x17, 0x14, 0x18, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x15, 0x19, 0x16, 0x1B, 0x16, 0x1A, 0x15, 0x19, 0x16, 0x1A, 0x17, 0x1D, 0x18, 0x1D, 0x16, 0x1A, 0x15, 0x19, 0x16, 0x1A, 0x17, 0x1B, 0x17, 0x1C, 0x17, 0x1D, 0x16, 0x1B, 0x16, 0x1A, 0x15, 0x19, 0x17, 0x1C, 0x16, 0x1A, 0x16, 0x1C, 0x17, 0x1B, 0x16, 0x1A, 0x15, 0x19, 0x15, 0x19, 0x15, 0x18, 0x15, 0x19, 0x15, 0x19, 0x17, 0x19, 0x1B, 0x1E, 0x35, 0x3B, 0x5C, 0x59, 0x67, 0x61, 0x5F, 0x54, 0x3B, 0x31, 0x3B, 0x3A, 0x5F, 0x5C, 0x6A, 0x5F, 0x6D, 0x61, 0x6F, 0x62, 0x70, 0x64, 0x74, 0x69, 0x75, 0x67, 0x75, 0x69, 0x77, 0x68, 0x74, 0x68, 0x79, 0x6C, 0x74, 0x65, 0x6F, 0x63, 0x73, 0x65, 0x71, 0x64, 0x72, 0x65, 0x71, 0x62, 0x71, 0x65, 0x77, 0x69, 0x75, 0x64, 0x70, 0x61, 0x73, 0x64, 0x71, 0x63, 0x6D, 0x61, 0x72, 0x65, 0x71, 0x63, 0x72, 0x64, 0x6F, 0x61, 0x72, 0x65, 0x71, 0x64, 0x73, 0x65, 0x74, 0x67, 0x6E, 0x60, 0x6E, 0x5F, 0x6E, 0x60, 0x71, 0x63, 0x73, 0x66, 0x6F, 0x62, 0x71, 0x65, 0x70, 0x63, 0x6F, 0x63, 0x72, 0x64, 0x72, 0x65, 0x72, 0x67, 0x75, 0x68, 0x72, 0x65, 0x74, 0x66, 0x75, 0x66, 0x73, 0x65, 0x73, 0x64, 0x73, 0x64, 0x70, 0x62, 0x72, 0x65, 0x72, 0x63, 0x72, 0x61, 0x6F, 0x63, 0x6F, 0x60, 0x71, 0x61, 0x6E, 0x60, 0x71, 0x62, 0x6C, 0x5F, 0x6C, 0x61, 0x72, 0x63, 0x71, 0x63, 0x77, 0x67, 0x73, 0x62, 0x6D, 0x62, 0x71, 0x66, 0x74, 0x65, 0x6C, 0x60, 0x6D, 0x62, 0x6D, 0x5F, 0x6E, 0x61, 0x6E, 0x61, 0x70, 0x61, 0x6E, 0x5E, 0x6B, 0x5D, 0x68, 0x5C, 0x68, 0x5D, 0x6A, 0x5F, 0x6D, 0x61, 0x69, 0x5C, 0x6C, 0x61, 0x6F, 0x5F, 0x69, 0x5C, 0x6A, 0x5D, 0x6C, 0x5E, 0x69, 0x5C, 0x6B, 0x5F, 0x6E, 0x60, 0x70, 0x65, 0x6E, 0x62, 0x6D, 0x61, 0x6A, 0x5E, 0x6A, 0x5F, 0x6E, 0x61, 0x6D, 0x61, 0x6C, 0x5E, 0x6A, 0x5F, 0x6B, 0x5F, 0x6B, 0x5E, 0x6C, 0x61, 0x69, 0x5D, 0x69, 0x5C, 0x68, 0x5B, 0x68, 0x5D, 0x6B, 0x61, 0x6B, 0x60, 0x6A, 0x5E, 0x65, 0x5B, 0x66, 0x5B, 0x69, 0x5D, 0x66, 0x5C, 0x61, 0x56, 0x65, 0x59, 0x66, 0x59, 0x68, 0x5C, 0x65, 0x5B, 0x62, 0x56, 0x67, 0x5B, 0x64, 0x5A, 0x63, 0x58, 0x62, 0x56, 0x62, 0x56, 0x64, 0x58, 0x61, 0x55, 0x5F, 0x55, 0x62, 0x58, 0x62, 0x57, 0x64, 0x58, 0x62, 0x57, 0x54, 0x49, 0x36, 0x34, 0x2A, 0x2D, 0x33, 0x37, 0x2B, 0x2D, 0x27, 0x2B, 0x32, 0x38, 0x34, 0x3B, 0x33, 0x38, 0x2C, 0x2F, 0x30, 0x37, 0x2D, 0x31, 0x33, 0x3A, 0x2B, 0x2D, 0x29, 0x31, 0x37, 0x3B, 0x2A, 0x2D, 0x2B, 0x2D, 0x26, 0x28, 0x2D, 0x31, 0x27, 0x29, 0x2A, 0x2E, 0x24, 0x26, 0x29, 0x2D, 0x25, 0x28, 0x2D, 0x31, 0x26, 0x28, 0x2A, 0x2E, 0x28, 0x2B, 0x2C, 0x31, 0x2D, 0x32, 0x2D, 0x30, 0x28, 0x2D, 0x2F, 0x34, 0x2F, 0x34, 0x30, 0x37, 0x32, 0x38, 0x30, 0x37, 0x38, 0x3E, 0x32, 0x36, 0x29, 0x2C, 0x2E, 0x35, 0x2E, 0x32, 0x31, 0x39, 0x33, 0x3A, 0x34, 0x3B, 0x2D, 0x34
    },

    {
        0x54, 0x1E, 0x55, 0x1E, 0x57, 0x1E, 0x56, 0x1E, 0x55, 0x1E, 0x52, 0x1E, 0x48, 0x1B, 0x39, 0x19, 0x3B, 0x19, 0x49, 0x1C, 0x50, 0x1E, 0x4D, 0x1C, 0x42, 0x19, 0x2D, 0x14, 0x21, 0x12, 0x1E, 0x12, 0x1C, 0x12, 0x1B, 0x11, 0x1A, 0x11, 0x18, 0x10, 0x18, 0x11, 0x18, 0x11, 0x19, 0x12, 0x1A, 0x11, 0x1B, 0x12, 0x19, 0x11, 0x18, 0x10, 0x16, 0x10, 0x16, 0x0F, 0x17, 0x0F, 0x16, 0x10, 0x16, 0x0F, 0x16, 0x0F, 0x16, 0x10, 0x16, 0x10, 0x17, 0x10, 0x17, 0x11, 0x18, 0x11, 0x17, 0x11, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x16, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x17, 0x10, 0x17, 0x11, 0x17, 0x10, 0x18, 0x11, 0x18, 0x11, 0x17, 0x10, 0x18, 0x11, 0x1A, 0x13, 0x1A, 0x12, 0x19, 0x12, 0x19, 0x12, 0x19, 0x11, 0x19, 0x12, 0x1A, 0x12, 0x1D, 0x16, 0x2F, 0x27, 0x66, 0x4E, 0x94, 0x68, 0xA2, 0x6E, 0xA9, 0x73, 0xAD, 0x77, 0xAF, 0x79, 0xB4, 0x7C, 0xB5, 0x7D, 0xB5, 0x7B, 0xB6, 0x7D, 0xB9, 0x7C, 0xB1, 0x76, 0x8F, 0x5B, 0x6C, 0x4E, 0x8F, 0x68, 0xA8, 0x75, 0xAF, 0x78, 0xAE, 0x7A, 0xB5, 0x7D, 0xB5, 0x7D, 0xB3, 0x7B, 0xB1, 0x7A, 0xB2, 0x7B, 0xB1, 0x78, 0x90, 0x5A, 0x4D, 0x30, 0x2D, 0x1E, 0x25, 0x19, 0x20, 0x16, 0x1C, 0x14, 0x1A, 0x13, 0x19, 0x11, 0x19, 0x12, 0x19, 0x12, 0x19, 0x11, 0x18, 0x10, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x10, 0x17, 0x10, 0x18, 0x11, 0x19, 0x11, 0x1C, 0x13, 0x1C, 0x13, 0x1B, 0x12, 0x1C, 0x13, 0x1E, 0x14, 0x1C, 0x13, 0x19, 0x12, 0x1A, 0x13, 0x1C, 0x13, 0x1C, 0x13, 0x1B, 0x12, 0x1B, 0x12, 0x1A, 0x12, 0x1B, 0x12, 0x1B, 0x13, 0x1E, 0x15, 0x1F, 0x15, 0x1E, 0x14, 0x1B, 0x13, 0x1A, 0x11, 0x19, 0x11, 0x1A, 0x12, 0x19, 0x11, 0x1A, 0x12, 0x1B, 0x13, 0x1B, 0x12, 0x2D, 0x19, 0x51, 0x21, 0x61, 0x24, 0x61, 0x24, 0x3F, 0x1B, 0x31, 0x1A, 0x4F, 0x20, 0x5E, 0x23, 0x64, 0x24, 0x62, 0x23, 0x62, 0x25, 0x68, 0x27, 0x66, 0x26, 0x6A, 0x27, 0x68, 0x27, 0x69, 0x27, 0x6A, 0x26, 0x6A, 0x26, 0x65, 0x25, 0x65, 0x26, 0x67, 0x25, 0x66, 0x25, 0x64, 0x25, 0x69, 0x26, 0x6C, 0x27, 0x6B, 0x26, 0x6A, 0x26, 0x68, 0x26, 0x65, 0x25, 0x67, 0x25, 0x5F, 0x23, 0x60, 0x22, 0x65, 0x23, 0x62, 0x24, 0x66, 0x24, 0x67, 0x25, 0x66, 0x25, 0x66, 0x25, 0x68, 0x25, 0x65, 0x24, 0x62, 0x23, 0x60, 0x23, 0x66, 0x24, 0x63, 0x24, 0x66, 0x23, 0x62, 0x23, 0x64, 0x23, 0x60, 0x23, 0x63, 0x25, 0x66, 0x24, 0x63, 0x24, 0x67, 0x25, 0x64, 0x24, 0x67, 0x24, 0x65, 0x24, 0x63, 0x23, 0x62, 0x23, 0x64, 0x24, 0x64, 0x23, 0x65, 0x23, 0x65, 0x23, 0x63, 0x23, 0x64, 0x24, 0x65, 0x24, 0x65, 0x24, 0x65, 0x23, 0x62, 0x23, 0x61, 0x24, 0x61, 0x22, 0x61, 0x22, 0x62, 0x23, 0x64, 0x23, 0x66, 0x25, 0x63, 0x24, 0x67, 0x25, 0x5F, 0x23, 0x61, 0x24, 0x62, 0x24, 0x62, 0x24, 0x63, 0x24, 0x60, 0x22, 0x60, 0x23, 0x5E, 0x21, 0x5D, 0x23, 0x59, 0x21, 0x59, 0x21, 0x5E, 0x21, 0x5F, 0x22, 0x60, 0x22, 0x64, 0x23, 0x5F, 0x22, 0x5E, 0x23, 0x5C, 0x21, 0x5D, 0x22, 0x5F, 0x22, 0x5F, 0x23, 0x5F, 0x22, 0x5F, 0x23, 0x5E, 0x22, 0x60, 0x22, 0x5E, 0x22, 0x5D, 0x21, 0x60, 0x23, 0x60, 0x23, 0x5B, 0x21, 0x5C, 0x22, 0x5C, 0x21, 0x61, 0x23, 0x66, 0x27, 0x67, 0x26, 0x66, 0x25, 0x65, 0x26, 0x61, 0x25, 0x63, 0x25, 0x64, 0x26, 0x5C, 0x23, 0x5E, 0x23, 0x5C, 0x22, 0x5E, 0x23, 0x5C, 0x23, 0x5A, 0x20, 0x57, 0x20, 0x5B, 0x21, 0x5D, 0x22, 0x5C, 0x23, 0x5B, 0x21, 0x58, 0x21, 0x59, 0x21, 0x59, 0x20, 0x57, 0x1F, 0x55, 0x1F, 0x56, 0x1F, 0x56, 0x20, 0x56, 0x20, 0x54, 0x1F, 0x55, 0x20, 0x55, 0x1F, 0x55, 0x20, 0x4F, 0x1E, 0x42, 0x1F, 0x36, 0x1E, 0x38, 0x1E, 0x33, 0x1C, 0x2C, 0x1A, 0x3C, 0x1F, 0x2F, 0x1A, 0x30, 0x1B, 0x28, 0x18, 0x31, 0x1B, 0x2A, 0x19, 0x33, 0x1B, 0x27, 0x18, 0x2E, 0x1A, 0x2B, 0x19, 0x2B, 0x19, 0x2B, 0x19, 0x34, 0x1C, 0x2F, 0x1A, 0x2F, 0x1A, 0x36, 0x1D, 0x37, 0x1D, 0x34, 0x1C, 0x37, 0x1D, 0x39, 0x1D, 0x3E, 0x20, 0x3C, 0x1F, 0x38, 0x1D, 0x36, 0x1D, 0x3D, 0x1F, 0x33, 0x1C, 0x34, 0x1C, 0x35, 0x1E, 0x39, 0x1E, 0x2E, 0x1A, 0x35, 0x1D, 0x34, 0x1E, 0x35, 0x1D, 0x2F, 0x1B, 0x2D, 0x1B, 0x3A, 0x1F, 0x33, 0x1B, 0x35, 0x1E, 0x35, 0x1D, 0x31, 0x1B, 0x2F, 0x1B
    },

    {
        0x60, 0x55, 0x60, 0x54, 0x61, 0x56, 0x60, 0x56, 0x5E, 0x55, 0x5D, 0x53, 0x53, 0x49, 0x43, 0x3A, 0x3A, 0x39, 0x47, 0x47, 0x55, 0x4F, 0x56, 0x4E, 0x4D, 0x43, 0x37, 0x2F, 0x23, 0x22, 0x1D, 0x1E, 0x1A, 0x1D, 0x19, 0x1B, 0x17, 0x1A, 0x16, 0x18, 0x15, 0x18, 0x14, 0x18, 0x14, 0x18, 0x15, 0x19, 0x16, 0x1B, 0x16, 0x19, 0x14, 0x18, 0x13, 0x17, 0x13, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x13, 0x17, 0x13, 0x17, 0x12, 0x17, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x12, 0x16, 0x13, 0x17, 0x13, 0x17, 0x12, 0x17, 0x13, 0x17, 0x12, 0x16, 0x13, 0x16, 0x13, 0x16, 0x12, 0x16, 0x13, 0x16, 0x12, 0x16, 0x12, 0x17, 0x13, 0x16, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x14, 0x19, 0x15, 0x19, 0x14, 0x18, 0x14, 0x19, 0x14, 0x18, 0x14, 0x19, 0x15, 0x19, 0x18, 0x1C, 0x21, 0x2B, 0x40, 0x5E, 0x68, 0x8E, 0x77, 0x9A, 0x7E, 0xA1, 0x84, 0xA8, 0x88, 0xAD, 0x8B, 0xB0, 0x8D, 0xB1, 0x8C, 0xB1, 0x8C, 0xAE, 0x89, 0xAE, 0x82, 0xA2, 0x67, 0x75, 0x49, 0x59, 0x60, 0x87, 0x7B, 0xA2, 0x81, 0xA6, 0x84, 0xA8, 0x8A, 0xB0, 0x8B, 0xB0, 0x8C, 0xB0, 0x8A, 0xAF, 0x88, 0xAF, 0x81, 0xA4, 0x66, 0x76, 0x38, 0x3A, 0x23, 0x28, 0x1D, 0x22, 0x1A, 0x1E, 0x16, 0x1B, 0x16, 0x1A, 0x14, 0x19, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x14, 0x17, 0x14, 0x17, 0x14, 0x18, 0x14, 0x18, 0x14, 0x19, 0x13, 0x17, 0x14, 0x17, 0x13, 0x17, 0x15, 0x19, 0x16, 0x1B, 0x17, 0x1D, 0x17, 0x1C, 0x16, 0x1B, 0x17, 0x1D, 0x17, 0x1B, 0x15, 0x19, 0x15, 0x1B, 0x17, 0x1B, 0x17, 0x1C, 0x15, 0x1A, 0x15, 0x1A, 0x16, 0x19, 0x16, 0x1A, 0x17, 0x1C, 0x18, 0x1F, 0x18, 0x1E, 0x17, 0x1C, 0x17, 0x1B, 0x16, 0x1A, 0x15, 0x1A, 0x16, 0x1A, 0x16, 0x1A, 0x16, 0x1A, 0x17, 0x1B, 0x1B, 0x1D, 0x34, 0x3B, 0x58, 0x58, 0x68, 0x64, 0x63, 0x58, 0x3C, 0x32, 0x3B, 0x3C, 0x5B, 0x57, 0x69, 0x5F, 0x6F, 0x65, 0x6E, 0x61, 0x6F, 0x62, 0x73, 0x67, 0x73, 0x67, 0x76, 0x6A, 0x75, 0x67, 0x75, 0x68, 0x77, 0x6A, 0x74, 0x67, 0x73, 0x64, 0x74, 0x68, 0x73, 0x66, 0x70, 0x65, 0x6F, 0x62, 0x76, 0x6A, 0x7C, 0x70, 0x79, 0x69, 0x77, 0x69, 0x74, 0x68, 0x73, 0x66, 0x73, 0x65, 0x6C, 0x60, 0x6D, 0x61, 0x71, 0x62, 0x70, 0x62, 0x71, 0x64, 0x71, 0x64, 0x73, 0x66, 0x75, 0x67, 0x76, 0x69, 0x73, 0x64, 0x71, 0x63, 0x6D, 0x61, 0x72, 0x63, 0x6F, 0x61, 0x72, 0x63, 0x70, 0x62, 0x70, 0x62, 0x6C, 0x61, 0x6F, 0x62, 0x72, 0x64, 0x6F, 0x64, 0x73, 0x67, 0x71, 0x64, 0x74, 0x64, 0x72, 0x63, 0x70, 0x61, 0x6E, 0x61, 0x6F, 0x64, 0x71, 0x63, 0x70, 0x63, 0x72, 0x63, 0x74, 0x63, 0x72, 0x65, 0x73, 0x67, 0x71, 0x66, 0x71, 0x64, 0x6F, 0x62, 0x70, 0x62, 0x6E, 0x60, 0x70, 0x61, 0x6E, 0x61, 0x70, 0x63, 0x72, 0x65, 0x6F, 0x61, 0x72, 0x66, 0x6D, 0x62, 0x6F, 0x62, 0x6F, 0x63, 0x70, 0x63, 0x71, 0x62, 0x6C, 0x5D, 0x6C, 0x60, 0x6A, 0x5E, 0x69, 0x5D, 0x66, 0x5A, 0x69, 0x5B, 0x6A, 0x5E, 0x6D, 0x60, 0x6D, 0x5E, 0x70, 0x60, 0x6B, 0x60, 0x6C, 0x5F, 0x69, 0x5D, 0x6C, 0x5E, 0x6C, 0x60, 0x6C, 0x60, 0x6C, 0x5E, 0x6A, 0x5E, 0x69, 0x5D, 0x6B, 0x5E, 0x6B, 0x5D, 0x68, 0x5C, 0x6B, 0x5F, 0x6B, 0x5F, 0x69, 0x5C, 0x68, 0x5C, 0x68, 0x5D, 0x6D, 0x61, 0x71, 0x68, 0x72, 0x67, 0x72, 0x67, 0x70, 0x64, 0x6B, 0x61, 0x6E, 0x63, 0x6D, 0x63, 0x69, 0x5D, 0x6A, 0x5E, 0x66, 0x5E, 0x69, 0x5E, 0x67, 0x5C, 0x66, 0x5B, 0x64, 0x58, 0x68, 0x5B, 0x69, 0x5E, 0x67, 0x5D, 0x67, 0x5A, 0x63, 0x59, 0x65, 0x5A, 0x66, 0x59, 0x63, 0x56, 0x61, 0x57, 0x61, 0x55, 0x63, 0x58, 0x5F, 0x56, 0x5E, 0x53, 0x5F, 0x55, 0x61, 0x54, 0x5E, 0x55, 0x56, 0x4E, 0x3E, 0x3E, 0x32, 0x37, 0x32, 0x37, 0x2C, 0x2F, 0x28, 0x2E, 0x33, 0x39, 0x2A, 0x2D, 0x2B, 0x2C, 0x24, 0x28, 0x2B, 0x2E, 0x28, 0x2F, 0x2E, 0x30, 0x26, 0x2B, 0x2D, 0x31, 0x2A, 0x2D, 0x29, 0x2E, 0x2A, 0x31, 0x33, 0x39, 0x2D, 0x33, 0x2E, 0x32, 0x33, 0x3A, 0x34, 0x3B, 0x30, 0x36, 0x32, 0x38, 0x34, 0x3C, 0x36, 0x3D, 0x33, 0x3A, 0x2F, 0x34, 0x30, 0x39, 0x33, 0x36, 0x2E, 0x35, 0x2E, 0x31, 0x30, 0x38, 0x30, 0x34, 0x28, 0x2F, 0x2F, 0x32, 0x2F, 0x37, 0x2E, 0x33, 0x2A, 0x30, 0x2A, 0x32, 0x32, 0x3B, 0x2B, 0x35, 0x2C, 0x36, 0x2D, 0x38, 0x2A, 0x2E, 0x29, 0x31
    },

    {
        0x56, 0x1F, 0x56, 0x1F, 0x57, 0x1F, 0x57, 0x1F, 0x56, 0x1F, 0x55, 0x1E, 0x51, 0x1E, 0x4A, 0x1C, 0x3B, 0x19, 0x37, 0x19, 0x44, 0x1D, 0x4E, 0x1D, 0x4D, 0x1C, 0x44, 0x1A, 0x30, 0x16, 0x22, 0x12, 0x1E, 0x12, 0x1C, 0x12, 0x1C, 0x12, 0x1B, 0x12, 0x1A, 0x11, 0x19, 0x11, 0x18, 0x11, 0x18, 0x10, 0x18, 0x11, 0x1A, 0x12, 0x1B, 0x13, 0x1B, 0x13, 0x19, 0x12, 0x18, 0x11, 0x17, 0x10, 0x16, 0x10, 0x16, 0x0F, 0x16, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x11, 0x17, 0x11, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x16, 0x10, 0x17, 0x10, 0x17, 0x11, 0x18, 0x10, 0x17, 0x10, 0x17, 0x11, 0x18, 0x12, 0x18, 0x11, 0x17, 0x11, 0x18, 0x11, 0x19, 0x11, 0x19, 0x12, 0x19, 0x12, 0x19, 0x12, 0x19, 0x11, 0x19, 0x12, 0x19, 0x12, 0x1A, 0x12, 0x1D, 0x16, 0x2A, 0x23, 0x58, 0x47, 0x8D, 0x64, 0x9C, 0x6D, 0xA7, 0x73, 0xAC, 0x76, 0xAE, 0x77, 0xB5, 0x7D, 0xB6, 0x7D, 0xB2, 0x7B, 0xAD, 0x76, 0x8F, 0x5A, 0x52, 0x33, 0x34, 0x26, 0x43, 0x38, 0x81, 0x61, 0xA0, 0x71, 0xA8, 0x76, 0xB1, 0x7A, 0xB6, 0x7C, 0xB5, 0x7C, 0xB1, 0x7B, 0xAF, 0x78, 0x96, 0x5D, 0x52, 0x33, 0x30, 0x1F, 0x24, 0x19, 0x1F, 0x16, 0x1E, 0x15, 0x1D, 0x13, 0x1B, 0x12, 0x19, 0x12, 0x19, 0x12, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x19, 0x11, 0x18, 0x11, 0x17, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x1A, 0x13, 0x1D, 0x14, 0x1D, 0x14, 0x1B, 0x12, 0x19, 0x12, 0x1A, 0x12, 0x1A, 0x12, 0x19, 0x12, 0x1A, 0x13, 0x1C, 0x14, 0x1D, 0x14, 0x1B, 0x13, 0x1B, 0x13, 0x1A, 0x12, 0x1C, 0x14, 0x21, 0x16, 0x1F, 0x15, 0x1B, 0x13, 0x1C, 0x12, 0x1B, 0x13, 0x1C, 0x13, 0x1A, 0x11, 0x1B, 0x13, 0x1A, 0x12, 0x1A, 0x12, 0x1C, 0x13, 0x2A, 0x18, 0x51, 0x21, 0x61, 0x28, 0x63, 0x26, 0x48, 0x20, 0x32, 0x1B, 0x53, 0x22, 0x61, 0x25, 0x64, 0x25, 0x66, 0x25, 0x64, 0x25, 0x66, 0x25, 0x65, 0x26, 0x69, 0x26, 0x67, 0x27, 0x6B, 0x27, 0x68, 0x26, 0x67, 0x26, 0x67, 0x27, 0x69, 0x27, 0x6B, 0x27, 0x64, 0x26, 0x64, 0x26, 0x64, 0x25, 0x65, 0x26, 0x68, 0x27, 0x6D, 0x29, 0x66, 0x27, 0x66, 0x25, 0x66, 0x25, 0x66, 0x25, 0x64, 0x24, 0x63, 0x23, 0x65, 0x24, 0x67, 0x25, 0x61, 0x23, 0x60, 0x23, 0x63, 0x24, 0x69, 0x26, 0x67, 0x25, 0x66, 0x25, 0x64, 0x24, 0x66, 0x26, 0x64, 0x24, 0x62, 0x23, 0x62, 0x24, 0x65, 0x24, 0x61, 0x23, 0x64, 0x24, 0x63, 0x23, 0x63, 0x24, 0x67, 0x25, 0x69, 0x27, 0x66, 0x25, 0x63, 0x23, 0x63, 0x23, 0x60, 0x22, 0x5E, 0x22, 0x5D, 0x22, 0x5D, 0x21, 0x60, 0x22, 0x62, 0x23, 0x63, 0x23, 0x63, 0x23, 0x61, 0x22, 0x62, 0x23, 0x62, 0x23, 0x62, 0x23, 0x62, 0x23, 0x63, 0x23, 0x60, 0x23, 0x63, 0x23, 0x65, 0x24, 0x64, 0x24, 0x63, 0x24, 0x65, 0x26, 0x65, 0x26, 0x66, 0x25, 0x65, 0x25, 0x69, 0x25, 0x60, 0x22, 0x60, 0x22, 0x61, 0x23, 0x60, 0x24, 0x5F, 0x23, 0x5C, 0x22, 0x5E, 0x22, 0x5F, 0x22, 0x5E, 0x22, 0x5E, 0x23, 0x61, 0x23, 0x60, 0x23, 0x5F, 0x23, 0x61, 0x23, 0x5F, 0x22, 0x60, 0x23, 0x5E, 0x22, 0x60, 0x23, 0x5F, 0x23, 0x61, 0x23, 0x5F, 0x23, 0x5D, 0x22, 0x5C, 0x21, 0x5D, 0x23, 0x63, 0x23, 0x5E, 0x22, 0x60, 0x23, 0x5E, 0x22, 0x5E, 0x22, 0x5F, 0x23, 0x65, 0x25, 0x62, 0x24, 0x63, 0x24, 0x62, 0x25, 0x61, 0x25, 0x61, 0x24, 0x5E, 0x24, 0x5A, 0x21, 0x5C, 0x21, 0x5E, 0x22, 0x5F, 0x22, 0x5C, 0x21, 0x5A, 0x20, 0x59, 0x20, 0x5A, 0x20, 0x5D, 0x22, 0x5E, 0x22, 0x5B, 0x21, 0x59, 0x22, 0x59, 0x21, 0x55, 0x20, 0x57, 0x20, 0x58, 0x20, 0x59, 0x20, 0x56, 0x20, 0x57, 0x21, 0x55, 0x20, 0x54, 0x1F, 0x52, 0x1F, 0x4D, 0x1D, 0x36, 0x1B, 0x2B, 0x19, 0x2C, 0x19, 0x27, 0x17, 0x2D, 0x1B, 0x35, 0x1D, 0x35, 0x1D, 0x37, 0x1D, 0x34, 0x1D, 0x38, 0x1E, 0x36, 0x1E, 0x3E, 0x1F, 0x3A, 0x1F, 0x33, 0x1D, 0x39, 0x1E, 0x35, 0x1E, 0x45, 0x24, 0x36, 0x1C, 0x36, 0x1D, 0x32, 0x1C, 0x35, 0x1D, 0x35, 0x1C, 0x30, 0x1B, 0x32, 0x1B, 0x39, 0x1F, 0x2E, 0x1A, 0x2B, 0x1A, 0x30, 0x1B, 0x34, 0x1E, 0x2F, 0x1B, 0x3A, 0x20, 0x35, 0x1D, 0x3F, 0x24, 0x38, 0x1E, 0x2D, 0x1A, 0x32, 0x1C, 0x36, 0x1F, 0x44, 0x27, 0x51, 0x2D, 0x55, 0x2F, 0x5A, 0x30, 0x59, 0x31, 0x5A, 0x30, 0x53, 0x2C, 0x32, 0x1B, 0x2F, 0x1B
    },

    {
        0x61, 0x57, 0x60, 0x56, 0x61, 0x56, 0x60, 0x56, 0x5E, 0x56, 0x5F, 0x55, 0x5B, 0x52, 0x55, 0x4A, 0x46, 0x3D, 0x3A, 0x36, 0x44, 0x43, 0x52, 0x4D, 0x55, 0x4D, 0x4D, 0x45, 0x3A, 0x33, 0x27, 0x23, 0x1E, 0x1E, 0x1B, 0x1D, 0x1A, 0x1C, 0x18, 0x1B, 0x17, 0x1A, 0x16, 0x19, 0x15, 0x18, 0x15, 0x18, 0x14, 0x17, 0x14, 0x19, 0x15, 0x1B, 0x16, 0x1C, 0x15, 0x1A, 0x14, 0x18, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x12, 0x16, 0x13, 0x16, 0x13, 0x16, 0x13, 0x17, 0x13, 0x18, 0x13, 0x17, 0x13, 0x17, 0x13, 0x16, 0x13, 0x16, 0x12, 0x16, 0x12, 0x16, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x12, 0x16, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x13, 0x18, 0x14, 0x18, 0x14, 0x19, 0x15, 0x19, 0x14, 0x19, 0x15, 0x19, 0x14, 0x19, 0x14, 0x18, 0x15, 0x19, 0x17, 0x1C, 0x1F, 0x26, 0x37, 0x51, 0x60, 0x88, 0x75, 0x99, 0x7E, 0xA2, 0x82, 0xA5, 0x86, 0xA9, 0x89, 0xB0, 0x8D, 0xB2, 0x88, 0xAF, 0x81, 0xA6, 0x68, 0x78, 0x3D, 0x41, 0x29, 0x2E, 0x2F, 0x3C, 0x52, 0x77, 0x74, 0x9E, 0x7E, 0xA5, 0x85, 0xAD, 0x88, 0xAE, 0x88, 0xAF, 0x87, 0xAC, 0x82, 0xA8, 0x6C, 0x7E, 0x3C, 0x3F, 0x25, 0x2A, 0x1D, 0x23, 0x1A, 0x1F, 0x18, 0x1E, 0x16, 0x1C, 0x16, 0x1B, 0x15, 0x1A, 0x15, 0x19, 0x14, 0x18, 0x13, 0x17, 0x14, 0x18, 0x14, 0x19, 0x14, 0x18, 0x13, 0x17, 0x13, 0x18, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x16, 0x1B, 0x18, 0x1C, 0x17, 0x1B, 0x16, 0x1A, 0x16, 0x19, 0x15, 0x1A, 0x16, 0x1A, 0x16, 0x1A, 0x16, 0x1A, 0x17, 0x1C, 0x17, 0x1C, 0x17, 0x1B, 0x16, 0x1B, 0x16, 0x1A, 0x17, 0x1C, 0x1A, 0x21, 0x19, 0x1E, 0x16, 0x1A, 0x16, 0x1C, 0x17, 0x1B, 0x16, 0x1B, 0x16, 0x1A, 0x17, 0x1A, 0x16, 0x1A, 0x17, 0x1B, 0x1C, 0x1E, 0x32, 0x39, 0x58, 0x58, 0x67, 0x66, 0x61, 0x5B, 0x41, 0x38, 0x3B, 0x3A, 0x5F, 0x5C, 0x6C, 0x61, 0x6E, 0x63, 0x71, 0x66, 0x72, 0x64, 0x73, 0x68, 0x72, 0x66, 0x75, 0x67, 0x73, 0x67, 0x76, 0x69, 0x75, 0x66, 0x73, 0x65, 0x76, 0x69, 0x73, 0x67, 0x77, 0x6B, 0x70, 0x63, 0x70, 0x63, 0x71, 0x63, 0x72, 0x67, 0x72, 0x65, 0x77, 0x6F, 0x71, 0x65, 0x73, 0x66, 0x73, 0x65, 0x70, 0x66, 0x70, 0x63, 0x6E, 0x63, 0x73, 0x65, 0x74, 0x67, 0x70, 0x61, 0x6F, 0x61, 0x6E, 0x62, 0x75, 0x68, 0x73, 0x66, 0x74, 0x65, 0x71, 0x64, 0x74, 0x68, 0x72, 0x63, 0x6F, 0x62, 0x71, 0x62, 0x72, 0x63, 0x6F, 0x61, 0x71, 0x64, 0x72, 0x64, 0x72, 0x66, 0x75, 0x68, 0x76, 0x68, 0x73, 0x64, 0x71, 0x63, 0x72, 0x63, 0x6F, 0x5F, 0x6C, 0x5F, 0x6A, 0x5C, 0x6D, 0x5D, 0x6D, 0x60, 0x70, 0x63, 0x72, 0x63, 0x6D, 0x5F, 0x70, 0x61, 0x6E, 0x62, 0x70, 0x62, 0x70, 0x63, 0x70, 0x63, 0x74, 0x65, 0x6F, 0x60, 0x73, 0x64, 0x72, 0x66, 0x72, 0x63, 0x71, 0x64, 0x6F, 0x65, 0x70, 0x66, 0x72, 0x64, 0x73, 0x66, 0x77, 0x69, 0x6E, 0x61, 0x6F, 0x62, 0x71, 0x63, 0x6C, 0x60, 0x6B, 0x5D, 0x68, 0x5D, 0x69, 0x5E, 0x6B, 0x60, 0x6B, 0x5F, 0x6B, 0x60, 0x6F, 0x62, 0x6D, 0x61, 0x69, 0x5F, 0x6E, 0x61, 0x70, 0x60, 0x6E, 0x61, 0x6B, 0x5E, 0x6D, 0x60, 0x6F, 0x62, 0x6F, 0x63, 0x6A, 0x60, 0x6C, 0x5E, 0x68, 0x5B, 0x69, 0x5D, 0x6E, 0x62, 0x6B, 0x60, 0x6D, 0x60, 0x69, 0x5E, 0x69, 0x5D, 0x6C, 0x60, 0x71, 0x64, 0x6E, 0x62, 0x70, 0x62, 0x6E, 0x63, 0x6C, 0x61, 0x6B, 0x5F, 0x6C, 0x60, 0x65, 0x5A, 0x67, 0x5D, 0x6A, 0x5E, 0x6B, 0x60, 0x65, 0x5A, 0x66, 0x5A, 0x64, 0x5A, 0x66, 0x5B, 0x69, 0x5E, 0x68, 0x5D, 0x67, 0x5C, 0x66, 0x5B, 0x63, 0x58, 0x60, 0x57, 0x62, 0x57, 0x64, 0x5A, 0x67, 0x5A, 0x61, 0x56, 0x62, 0x57, 0x60, 0x57, 0x5E, 0x53, 0x5E, 0x53, 0x54, 0x49, 0x32, 0x31, 0x29, 0x2C, 0x27, 0x2B, 0x26, 0x29, 0x2E, 0x34, 0x30, 0x36, 0x30, 0x36, 0x33, 0x3A, 0x30, 0x35, 0x35, 0x3D, 0x31, 0x37, 0x37, 0x3C, 0x31, 0x36, 0x2B, 0x32, 0x31, 0x35, 0x30, 0x39, 0x3C, 0x40, 0x2D, 0x30, 0x31, 0x35, 0x2D, 0x32, 0x2E, 0x33, 0x30, 0x32, 0x2F, 0x34, 0x2B, 0x2F, 0x2F, 0x35, 0x27, 0x2A, 0x26, 0x2C, 0x2B, 0x31, 0x30, 0x3B, 0x2B, 0x33, 0x33, 0x43, 0x31, 0x3C, 0x35, 0x49, 0x30, 0x39, 0x29, 0x31, 0x2C, 0x30, 0x33, 0x3C, 0x36, 0x4F, 0x3A, 0x59, 0x39, 0x5D, 0x3B, 0x5F, 0x3A, 0x60, 0x39, 0x5D, 0x34, 0x4F, 0x24, 0x2E, 0x2A, 0x31
    },

    {
        0x57, 0x1F, 0x57, 0x20, 0x58, 0x1F, 0x56, 0x1F, 0x57, 0x1F, 0x56, 0x1E, 0x56, 0x1E, 0x53, 0x1E, 0x4D, 0x1D, 0x40, 0x1A, 0x37, 0x1A, 0x41, 0x1B, 0x4C, 0x1D, 0x4D, 0x1D, 0x4A, 0x1B, 0x37, 0x17, 0x25, 0x13, 0x20, 0x13, 0x1F, 0x13, 0x1C, 0x12, 0x1B, 0x11, 0x1A, 0x11, 0x18, 0x10, 0x18, 0x10, 0x17, 0x10, 0x17, 0x10, 0x18, 0x12, 0x1A, 0x12, 0x1C, 0x14, 0x1E, 0x14, 0x1B, 0x12, 0x19, 0x11, 0x19, 0x11, 0x1A, 0x11, 0x18, 0x11, 0x18, 0x10, 0x17, 0x11, 0x17, 0x10, 0x17, 0x10, 0x18, 0x11, 0x17, 0x10, 0x18, 0x10, 0x18, 0x11, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x11, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x11, 0x17, 0x10, 0x17, 0x10, 0x18, 0x11, 0x19, 0x11, 0x19, 0x12, 0x1A, 0x13, 0x1A, 0x12, 0x19, 0x12, 0x1A, 0x13, 0x1A, 0x12, 0x19, 0x12, 0x19, 0x12, 0x1B, 0x13, 0x26, 0x1F, 0x4D, 0x3F, 0x86, 0x5F, 0x9C, 0x6D, 0xA2, 0x72, 0xA8, 0x75, 0xB0, 0x79, 0xB4, 0x7A, 0xAF, 0x75, 0x93, 0x5C, 0x57, 0x33, 0x31, 0x20, 0x27, 0x1A, 0x24, 0x1B, 0x35, 0x2D, 0x6F, 0x54, 0x9B, 0x6D, 0xA7, 0x75, 0xAC, 0x77, 0xAD, 0x79, 0xAE, 0x76, 0x93, 0x5C, 0x56, 0x33, 0x2F, 0x1F, 0x24, 0x18, 0x1E, 0x15, 0x1C, 0x14, 0x1D, 0x14, 0x1B, 0x12, 0x1A, 0x12, 0x19, 0x12, 0x1A, 0x12, 0x19, 0x11, 0x18, 0x11, 0x19, 0x12, 0x19, 0x11, 0x18, 0x10, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x10, 0x18, 0x11, 0x1A, 0x12, 0x1A, 0x12, 0x1B, 0x13, 0x1D, 0x14, 0x1A, 0x12, 0x19, 0x12, 0x1B, 0x13, 0x1B, 0x13, 0x1A, 0x12, 0x1B, 0x13, 0x1C, 0x13, 0x1C, 0x14, 0x1C, 0x14, 0x1E, 0x14, 0x1D, 0x14, 0x1C, 0x13, 0x1B, 0x12, 0x1A, 0x12, 0x1A, 0x12, 0x1B, 0x12, 0x1B, 0x13, 0x1B, 0x12, 0x1B, 0x13, 0x1B, 0x13, 0x1E, 0x14, 0x2C, 0x19, 0x54, 0x22, 0x60, 0x24, 0x62, 0x26, 0x45, 0x1E, 0x33, 0x1C, 0x50, 0x22, 0x60, 0x25, 0x68, 0x26, 0x64, 0x26, 0x69, 0x26, 0x67, 0x26, 0x68, 0x27, 0x67, 0x25, 0x68, 0x27, 0x68, 0x27, 0x67, 0x26, 0x68, 0x26, 0x64, 0x25, 0x67, 0x26, 0x64, 0x25, 0x68, 0x26, 0x67, 0x26, 0x66, 0x26, 0x69, 0x27, 0x6C, 0x27, 0x72, 0x2A, 0x6D, 0x29, 0x69, 0x27, 0x6A, 0x27, 0x67, 0x25, 0x65, 0x25, 0x62, 0x24, 0x63, 0x24, 0x67, 0x24, 0x67, 0x25, 0x69, 0x26, 0x67, 0x24, 0x68, 0x25, 0x64, 0x25, 0x65, 0x23, 0x62, 0x24, 0x63, 0x23, 0x64, 0x25, 0x65, 0x25, 0x67, 0x25, 0x65, 0x23, 0x63, 0x23, 0x61, 0x22, 0x60, 0x22, 0x63, 0x23, 0x65, 0x24, 0x64, 0x24, 0x65, 0x25, 0x66, 0x25, 0x64, 0x24, 0x63, 0x23, 0x65, 0x24, 0x60, 0x23, 0x65, 0x25, 0x65, 0x25, 0x61, 0x23, 0x63, 0x23, 0x60, 0x23, 0x62, 0x25, 0x64, 0x23, 0x5F, 0x22, 0x63, 0x23, 0x63, 0x24, 0x61, 0x24, 0x63, 0x24, 0x62, 0x23, 0x65, 0x25, 0x67, 0x25, 0x65, 0x24, 0x65, 0x24, 0x61, 0x23, 0x62, 0x25, 0x62, 0x24, 0x66, 0x25, 0x65, 0x25, 0x66, 0x25, 0x63, 0x23, 0x62, 0x23, 0x5F, 0x23, 0x5D, 0x22, 0x61, 0x24, 0x5E, 0x22, 0x5E, 0x21, 0x62, 0x24, 0x62, 0x23, 0x5E, 0x22, 0x60, 0x22, 0x60, 0x22, 0x5E, 0x22, 0x62, 0x23, 0x61, 0x23, 0x61, 0x23, 0x5F, 0x23, 0x60, 0x23, 0x61, 0x24, 0x5E, 0x22, 0x5E, 0x22, 0x5D, 0x23, 0x5D, 0x23, 0x5E, 0x23, 0x5E, 0x23, 0x5E, 0x22, 0x5E, 0x22, 0x5C, 0x23, 0x5F, 0x22, 0x5E, 0x23, 0x60, 0x24, 0x64, 0x25, 0x60, 0x23, 0x5F, 0x23, 0x61, 0x24, 0x5F, 0x24, 0x64, 0x25, 0x5E, 0x22, 0x5E, 0x23, 0x5D, 0x22, 0x57, 0x20, 0x58, 0x21, 0x57, 0x20, 0x59, 0x21, 0x5B, 0x21, 0x5D, 0x23, 0x5A, 0x22, 0x5A, 0x20, 0x59, 0x23, 0x67, 0x2A, 0x59, 0x21, 0x58, 0x21, 0x57, 0x1F, 0x55, 0x20, 0x59, 0x21, 0x58, 0x21, 0x58, 0x20, 0x57, 0x20, 0x4D, 0x1E, 0x3A, 0x1C, 0x34, 0x1C, 0x3B, 0x20, 0x3F, 0x21, 0x38, 0x1E, 0x39, 0x1F, 0x36, 0x1D, 0x36, 0x1D, 0x2B, 0x19, 0x37, 0x1E, 0x2E, 0x1B, 0x34, 0x1C, 0x2C, 0x18, 0x2C, 0x1A, 0x2F, 0x1A, 0x3A, 0x1F, 0x36, 0x1D, 0x35, 0x21, 0x3F, 0x21, 0x44, 0x26, 0x4D, 0x29, 0x4A, 0x26, 0x4A, 0x26, 0x35, 0x1B, 0x2F, 0x1A, 0x2D, 0x19, 0x37, 0x21, 0x57, 0x2E, 0x5F, 0x33, 0x61, 0x33, 0x63, 0x34, 0x66, 0x35, 0x63, 0x34, 0x4D, 0x27, 0x34, 0x1D, 0x35, 0x1D, 0x3A, 0x20, 0x59, 0x30, 0x64, 0x36, 0x66, 0x37, 0x63, 0x36, 0x62, 0x34, 0x60, 0x34, 0x55, 0x2C, 0x27, 0x17, 0x34, 0x1D
    },

    {
        0x61, 0x56, 0x61, 0x55, 0x61, 0x57, 0x60, 0x56, 0x61, 0x55, 0x61, 0x56, 0x61, 0x56, 0x5E, 0x54, 0x57, 0x4C, 0x4A, 0x40, 0x3B, 0x37, 0x3E, 0x3F, 0x4E, 0x4B, 0x54, 0x4F, 0x52, 0x4A, 0x42, 0x3A, 0x2B, 0x27, 0x20, 0x20, 0x1D, 0x1E, 0x1A, 0x1C, 0x18, 0x1A, 0x16, 0x19, 0x15, 0x18, 0x14, 0x17, 0x14, 0x17, 0x13, 0x17, 0x14, 0x18, 0x14, 0x18, 0x16, 0x1C, 0x18, 0x1E, 0x17, 0x1C, 0x15, 0x19, 0x15, 0x1A, 0x15, 0x1A, 0x14, 0x18, 0x14, 0x18, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x14, 0x17, 0x13, 0x17, 0x13, 0x17, 0x13, 0x16, 0x13, 0x16, 0x12, 0x16, 0x12, 0x17, 0x13, 0x17, 0x12, 0x16, 0x12, 0x16, 0x13, 0x17, 0x12, 0x17, 0x13, 0x17, 0x12, 0x17, 0x13, 0x16, 0x13, 0x17, 0x13, 0x18, 0x14, 0x18, 0x14, 0x18, 0x15, 0x1A, 0x14, 0x19, 0x14, 0x19, 0x14, 0x19, 0x14, 0x19, 0x15, 0x18, 0x14, 0x19, 0x16, 0x1A, 0x1C, 0x22, 0x31, 0x45, 0x5A, 0x7F, 0x72, 0x97, 0x7C, 0xA0, 0x80, 0xA6, 0x85, 0xAB, 0x85, 0xAB, 0x81, 0xA1, 0x68, 0x7B, 0x3F, 0x41, 0x26, 0x2A, 0x1F, 0x23, 0x1D, 0x21, 0x24, 0x2F, 0x44, 0x65, 0x6C, 0x96, 0x7E, 0xA5, 0x82, 0xA9, 0x84, 0xAC, 0x7F, 0xA3, 0x68, 0x7A, 0x3C, 0x3F, 0x25, 0x29, 0x1D, 0x21, 0x18, 0x1C, 0x16, 0x1A, 0x16, 0x1B, 0x16, 0x1A, 0x15, 0x19, 0x14, 0x19, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x14, 0x19, 0x14, 0x18, 0x13, 0x17, 0x13, 0x18, 0x14, 0x18, 0x13, 0x18, 0x14, 0x17, 0x14, 0x18, 0x15, 0x19, 0x15, 0x1A, 0x17, 0x1C, 0x18, 0x1C, 0x15, 0x19, 0x15, 0x19, 0x16, 0x1B, 0x16, 0x1A, 0x15, 0x19, 0x17, 0x1C, 0x17, 0x1C, 0x17, 0x1C, 0x18, 0x1D, 0x19, 0x1E, 0x17, 0x1C, 0x16, 0x1B, 0x16, 0x1A, 0x16, 0x1A, 0x16, 0x19, 0x17, 0x1A, 0x17, 0x1C, 0x16, 0x1B, 0x17, 0x1B, 0x17, 0x1B, 0x1C, 0x1E, 0x33, 0x3A, 0x5B, 0x5C, 0x66, 0x61, 0x5F, 0x5A, 0x43, 0x39, 0x3A, 0x3C, 0x59, 0x58, 0x6B, 0x62, 0x72, 0x67, 0x71, 0x66, 0x72, 0x65, 0x72, 0x65, 0x73, 0x68, 0x73, 0x65, 0x73, 0x68, 0x74, 0x67, 0x73, 0x65, 0x75, 0x67, 0x6E, 0x63, 0x72, 0x65, 0x71, 0x65, 0x74, 0x68, 0x74, 0x67, 0x76, 0x68, 0x76, 0x6A, 0x77, 0x6B, 0x7B, 0x71, 0x75, 0x69, 0x76, 0x69, 0x74, 0x68, 0x74, 0x67, 0x72, 0x65, 0x6F, 0x62, 0x6F, 0x63, 0x73, 0x66, 0x74, 0x67, 0x78, 0x69, 0x75, 0x68, 0x77, 0x68, 0x72, 0x64, 0x72, 0x64, 0x6F, 0x61, 0x6F, 0x62, 0x72, 0x65, 0x75, 0x67, 0x74, 0x67, 0x75, 0x65, 0x73, 0x63, 0x71, 0x62, 0x6D, 0x60, 0x72, 0x62, 0x72, 0x63, 0x70, 0x63, 0x72, 0x66, 0x72, 0x66, 0x72, 0x63, 0x74, 0x64, 0x73, 0x66, 0x6F, 0x61, 0x72, 0x67, 0x72, 0x65, 0x70, 0x62, 0x6F, 0x62, 0x6E, 0x60, 0x6F, 0x64, 0x72, 0x62, 0x70, 0x61, 0x72, 0x63, 0x6F, 0x61, 0x6E, 0x62, 0x71, 0x63, 0x73, 0x64, 0x74, 0x66, 0x74, 0x66, 0x72, 0x64, 0x71, 0x63, 0x6D, 0x60, 0x6E, 0x62, 0x6E, 0x63, 0x73, 0x65, 0x72, 0x65, 0x70, 0x64, 0x70, 0x61, 0x6E, 0x61, 0x6E, 0x60, 0x6B, 0x5F, 0x6E, 0x60, 0x6A, 0x5E, 0x6A, 0x5C, 0x6E, 0x62, 0x6C, 0x61, 0x6B, 0x5D, 0x6B, 0x60, 0x6D, 0x5F, 0x69, 0x5E, 0x70, 0x63, 0x6F, 0x62, 0x70, 0x62, 0x6C, 0x5F, 0x6D, 0x60, 0x6D, 0x61, 0x6B, 0x5E, 0x69, 0x5C, 0x6C, 0x5F, 0x69, 0x5E, 0x6A, 0x5E, 0x69, 0x5D, 0x6B, 0x60, 0x6A, 0x5E, 0x6B, 0x5E, 0x6B, 0x5F, 0x6A, 0x5F, 0x6D, 0x61, 0x6D, 0x62, 0x6A, 0x5F, 0x6C, 0x61, 0x6C, 0x60, 0x68, 0x5E, 0x6E, 0x63, 0x6B, 0x5F, 0x69, 0x5F, 0x66, 0x5B, 0x63, 0x57, 0x65, 0x59, 0x61, 0x58, 0x63, 0x59, 0x66, 0x5B, 0x65, 0x5A, 0x64, 0x59, 0x67, 0x5A, 0x61, 0x5A, 0x6B, 0x66, 0x64, 0x5A, 0x63, 0x58, 0x62, 0x57, 0x63, 0x58, 0x65, 0x5A, 0x63, 0x58, 0x62, 0x57, 0x61, 0x55, 0x52, 0x49, 0x37, 0x37, 0x32, 0x37, 0x35, 0x3D, 0x37, 0x3E, 0x2E, 0x34, 0x31, 0x38, 0x2E, 0x33, 0x2D, 0x31, 0x27, 0x2B, 0x31, 0x35, 0x2B, 0x31, 0x2F, 0x34, 0x28, 0x2B, 0x28, 0x30, 0x2A, 0x2D, 0x36, 0x3E, 0x2F, 0x34, 0x32, 0x42, 0x39, 0x46, 0x3B, 0x52, 0x41, 0x56, 0x3F, 0x52, 0x3D, 0x50, 0x2F, 0x34, 0x2A, 0x2E, 0x2B, 0x31, 0x2E, 0x41, 0x42, 0x5F, 0x44, 0x65, 0x46, 0x66, 0x44, 0x64, 0x45, 0x65, 0x43, 0x62, 0x34, 0x40, 0x2C, 0x37, 0x2D, 0x34, 0x30, 0x3B, 0x3B, 0x5C, 0x40, 0x64, 0x40, 0x64, 0x3E, 0x62, 0x3A, 0x5D, 0x38, 0x5A, 0x31, 0x48, 0x1D, 0x24, 0x2D, 0x36
    },

    {
        0x56, 0x1F, 0x55, 0x1E, 0x56, 0x1F, 0x57, 0x1E, 0x55, 0x1E, 0x57, 0x1F, 0x56, 0x1F, 0x54, 0x1F, 0x53, 0x1E, 0x4E, 0x1C, 0x42, 0x1A, 0x36, 0x19, 0x3E, 0x1B, 0x4C, 0x1E, 0x51, 0x1F, 0x4D, 0x1E, 0x3C, 0x19, 0x28, 0x15, 0x20, 0x13, 0x1E, 0x12, 0x1B, 0x11, 0x19, 0x11, 0x18, 0x10, 0x17, 0x10, 0x18, 0x11, 0x18, 0x10, 0x18, 0x11, 0x17, 0x11, 0x18, 0x11, 0x1A, 0x13, 0x1E, 0x15, 0x1E, 0x14, 0x1C, 0x14, 0x1A, 0x12, 0x19, 0x12, 0x19, 0x11, 0x18, 0x10, 0x18, 0x11, 0x18, 0x11, 0x17, 0x10, 0x17, 0x10, 0x16, 0x10, 0x17, 0x10, 0x16, 0x10, 0x16, 0x0F, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x17, 0x10, 0x16, 0x10, 0x16, 0x10, 0x17, 0x10, 0x17, 0x11, 0x17, 0x10, 0x18, 0x11, 0x19, 0x12, 0x19, 0x12, 0x19, 0x12, 0x1A, 0x13, 0x1A, 0x12, 0x19, 0x12, 0x19, 0x12, 0x19, 0x12, 0x19, 0x11, 0x19, 0x12, 0x1B, 0x14, 0x21, 0x1B, 0x42, 0x38, 0x81, 0x5C, 0x9B, 0x6B, 0xA0, 0x70, 0xA7, 0x74, 0xA7, 0x74, 0x95, 0x5D, 0x57, 0x34, 0x31, 0x21, 0x25, 0x19, 0x20, 0x16, 0x1D, 0x15, 0x1C, 0x16, 0x29, 0x24, 0x62, 0x4D, 0x99, 0x6A, 0xA5, 0x72, 0xA9, 0x74, 0x92, 0x5F, 0x57, 0x35, 0x31, 0x20, 0x26, 0x19, 0x1F, 0x16, 0x1B, 0x13, 0x19, 0x12, 0x19, 0x12, 0x1A, 0x12, 0x1A, 0x13, 0x18, 0x12, 0x18, 0x11, 0x19, 0x12, 0x19, 0x11, 0x18, 0x11, 0x18, 0x11, 0x17, 0x11, 0x18, 0x11, 0x18, 0x12, 0x18, 0x10, 0x17, 0x10, 0x19, 0x12, 0x19, 0x12, 0x1A, 0x13, 0x1C, 0x13, 0x1C, 0x13, 0x1B, 0x13, 0x1A, 0x13, 0x1C, 0x13, 0x1A, 0x13, 0x1A, 0x12, 0x1B, 0x13, 0x1E, 0x14, 0x1C, 0x14, 0x1F, 0x15, 0x1C, 0x14, 0x1B, 0x13, 0x1A, 0x12, 0x1A, 0x12, 0x1B, 0x12, 0x1B, 0x13, 0x1D, 0x13, 0x1B, 0x12, 0x1C, 0x12, 0x1C, 0x13, 0x1B, 0x13, 0x2A, 0x19, 0x51, 0x21, 0x5F, 0x24, 0x5F, 0x23, 0x46, 0x1E, 0x33, 0x1C, 0x52, 0x23, 0x5E, 0x26, 0x69, 0x27, 0x6A, 0x28, 0x65, 0x25, 0x63, 0x25, 0x64, 0x25, 0x64, 0x26, 0x68, 0x28, 0x67, 0x26, 0x68, 0x27, 0x68, 0x27, 0x67, 0x27, 0x68, 0x27, 0x66, 0x25, 0x6C, 0x29, 0x6E, 0x28, 0x6C, 0x28, 0x6B, 0x28, 0x6A, 0x28, 0x68, 0x25, 0x5E, 0x25, 0x69, 0x27, 0x6A, 0x28, 0x67, 0x26, 0x68, 0x27, 0x68, 0x26, 0x66, 0x26, 0x68, 0x26, 0x66, 0x25, 0x66, 0x26, 0x68, 0x26, 0x65, 0x25, 0x66, 0x25, 0x64, 0x24, 0x66, 0x25, 0x65, 0x24, 0x62, 0x24, 0x65, 0x24, 0x65, 0x24, 0x64, 0x24, 0x66, 0x24, 0x65, 0x24, 0x62, 0x23, 0x63, 0x23, 0x63, 0x22, 0x63, 0x23, 0x67, 0x24, 0x65, 0x25, 0x66, 0x24, 0x63, 0x23, 0x65, 0x24, 0x64, 0x24, 0x64, 0x24, 0x66, 0x26, 0x67, 0x25, 0x64, 0x25, 0x62, 0x24, 0x62, 0x24, 0x61, 0x24, 0x65, 0x23, 0x64, 0x23, 0x65, 0x25, 0x67, 0x26, 0x66, 0x26, 0x65, 0x24, 0x65, 0x24, 0x62, 0x23, 0x65, 0x24, 0x61, 0x23, 0x63, 0x24, 0x62, 0x24, 0x64, 0x25, 0x62, 0x24, 0x65, 0x24, 0x65, 0x24, 0x60, 0x23, 0x5E, 0x21, 0x63, 0x23, 0x61, 0x23, 0x62, 0x24, 0x62, 0x24, 0x60, 0x22, 0x5D, 0x23, 0x5F, 0x23, 0x5F, 0x24, 0x5E, 0x22, 0x5C, 0x22, 0x5F, 0x23, 0x5F, 0x23, 0x65, 0x24, 0x64, 0x24, 0x62, 0x23, 0x5D, 0x22, 0x61, 0x23, 0x5C, 0x22, 0x5B, 0x21, 0x60, 0x23, 0x62, 0x24, 0x5E, 0x23, 0x60, 0x22, 0x5C, 0x22, 0x60, 0x23, 0x5C, 0x21, 0x5F, 0x23, 0x61, 0x23, 0x5D, 0x22, 0x5D, 0x22, 0x5F, 0x23, 0x61, 0x24, 0x62, 0x26, 0x62, 0x25, 0x5E, 0x23, 0x5E, 0x23, 0x5F, 0x23, 0x5F, 0x23, 0x5D, 0x22, 0x5D, 0x22, 0x58, 0x20, 0x58, 0x21, 0x58, 0x20, 0x58, 0x20, 0x5A, 0x21, 0x5A, 0x22, 0x58, 0x20, 0x56, 0x22, 0x55, 0x22, 0x57, 0x20, 0x5A, 0x21, 0x58, 0x20, 0x58, 0x20, 0x58, 0x21, 0x5A, 0x21, 0x57, 0x21, 0x59, 0x20, 0x4C, 0x1E, 0x32, 0x1A, 0x32, 0x1C, 0x32, 0x1D, 0x2F, 0x1B, 0x2B, 0x1A, 0x33, 0x1E, 0x3C, 0x22, 0x44, 0x25, 0x4A, 0x29, 0x53, 0x2C, 0x56, 0x2F, 0x5C, 0x30, 0x49, 0x25, 0x31, 0x1D, 0x37, 0x1E, 0x3D, 0x20, 0x44, 0x28, 0x66, 0x37, 0x6E, 0x39, 0x6E, 0x3A, 0x6C, 0x39, 0x6B, 0x39, 0x66, 0x35, 0x35, 0x1D, 0x31, 0x1C, 0x3B, 0x1F, 0x41, 0x25, 0x62, 0x34, 0x66, 0x35, 0x62, 0x34, 0x61, 0x33, 0x5E, 0x32, 0x5A, 0x30, 0x3F, 0x21, 0x2C, 0x1A, 0x2E, 0x19, 0x33, 0x1E, 0x48, 0x27, 0x42, 0x25, 0x3D, 0x25, 0x37, 0x22, 0x31, 0x1E, 0x2C, 0x1B, 0x26, 0x19, 0x1F, 0x14, 0x36, 0x1D
    },

    {
        0x60, 0x55, 0x5E, 0x54, 0x60, 0x56, 0x61, 0x56, 0x60, 0x55, 0x60, 0x56, 0x60, 0x55, 0x5F, 0x54, 0x5C, 0x53, 0x57, 0x4E, 0x4E, 0x43, 0x3D, 0x37, 0x3C, 0x3C, 0x4C, 0x4A, 0x58, 0x51, 0x55, 0x4E, 0x47, 0x3F, 0x2F, 0x2A, 0x21, 0x21, 0x1C, 0x1D, 0x19, 0x1B, 0x17, 0x1A, 0x16, 0x18, 0x14, 0x17, 0x15, 0x18, 0x14, 0x18, 0x14, 0x17, 0x14, 0x18, 0x14, 0x18, 0x14, 0x19, 0x16, 0x1C, 0x17, 0x1E, 0x18, 0x1E, 0x16, 0x1B, 0x16, 0x19, 0x14, 0x18, 0x15, 0x18, 0x14, 0x18, 0x13, 0x17, 0x13, 0x17, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x15, 0x12, 0x15, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x17, 0x13, 0x18, 0x14, 0x19, 0x13, 0x18, 0x14, 0x19, 0x15, 0x19, 0x14, 0x19, 0x14, 0x19, 0x14, 0x19, 0x14, 0x19, 0x14, 0x19, 0x14, 0x18, 0x17, 0x1A, 0x1A, 0x1F, 0x2A, 0x3C, 0x51, 0x78, 0x70, 0x94, 0x79, 0x9E, 0x7D, 0xA4, 0x7C, 0xA2, 0x69, 0x7E, 0x40, 0x43, 0x27, 0x2B, 0x1E, 0x22, 0x19, 0x1E, 0x18, 0x1C, 0x18, 0x1B, 0x1F, 0x26, 0x3D, 0x59, 0x67, 0x8E, 0x76, 0x9E, 0x7A, 0xA0, 0x67, 0x7C, 0x3D, 0x42, 0x26, 0x2B, 0x1E, 0x22, 0x19, 0x1D, 0x16, 0x1A, 0x15, 0x19, 0x15, 0x19, 0x15, 0x1A, 0x15, 0x19, 0x15, 0x19, 0x14, 0x19, 0x14, 0x19, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x13, 0x18, 0x14, 0x18, 0x14, 0x18, 0x14, 0x17, 0x13, 0x17, 0x15, 0x19, 0x16, 0x1A, 0x16, 0x1B, 0x16, 0x1B, 0x16, 0x1B, 0x17, 0x1B, 0x15, 0x1A, 0x17, 0x1C, 0x16, 0x1A, 0x16, 0x1A, 0x17, 0x1C, 0x18, 0x1D, 0x18, 0x1E, 0x18, 0x1E, 0x16, 0x1B, 0x16, 0x1B, 0x15, 0x1A, 0x16, 0x1A, 0x16, 0x1A, 0x16, 0x1B, 0x17, 0x1C, 0x16, 0x1A, 0x17, 0x1C, 0x18, 0x1B, 0x1B, 0x1C, 0x32, 0x39, 0x5B, 0x59, 0x65, 0x5F, 0x61, 0x5A, 0x41, 0x39, 0x38, 0x3A, 0x5B, 0x5B, 0x66, 0x60, 0x71, 0x6A, 0x76, 0x6A, 0x72, 0x64, 0x6F, 0x63, 0x6F, 0x62, 0x70, 0x66, 0x72, 0x67, 0x72, 0x67, 0x74, 0x67, 0x75, 0x68, 0x72, 0x66, 0x74, 0x69, 0x74, 0x67, 0x79, 0x6E, 0x7A, 0x6E, 0x77, 0x6B, 0x79, 0x6C, 0x76, 0x69, 0x74, 0x65, 0x69, 0x5D, 0x74, 0x69, 0x78, 0x6A, 0x75, 0x67, 0x76, 0x6B, 0x74, 0x66, 0x72, 0x67, 0x72, 0x67, 0x72, 0x66, 0x73, 0x67, 0x74, 0x66, 0x71, 0x66, 0x74, 0x66, 0x70, 0x63, 0x72, 0x66, 0x73, 0x64, 0x6E, 0x62, 0x72, 0x64, 0x72, 0x66, 0x73, 0x64, 0x75, 0x64, 0x71, 0x64, 0x6E, 0x61, 0x70, 0x64, 0x70, 0x62, 0x6F, 0x64, 0x72, 0x66, 0x72, 0x64, 0x74, 0x65, 0x70, 0x64, 0x71, 0x63, 0x72, 0x63, 0x6E, 0x64, 0x71, 0x65, 0x73, 0x66, 0x72, 0x65, 0x72, 0x63, 0x71, 0x64, 0x6F, 0x62, 0x73, 0x65, 0x72, 0x64, 0x73, 0x67, 0x75, 0x67, 0x74, 0x65, 0x72, 0x64, 0x72, 0x64, 0x72, 0x63, 0x72, 0x63, 0x6F, 0x61, 0x6F, 0x63, 0x6F, 0x63, 0x71, 0x66, 0x6F, 0x61, 0x6D, 0x63, 0x72, 0x65, 0x6D, 0x60, 0x6D, 0x60, 0x71, 0x63, 0x6E, 0x60, 0x71, 0x64, 0x6E, 0x61, 0x6E, 0x5F, 0x6C, 0x60, 0x6B, 0x60, 0x6C, 0x60, 0x6A, 0x5E, 0x69, 0x5E, 0x6A, 0x5F, 0x6D, 0x60, 0x6F, 0x64, 0x70, 0x63, 0x6E, 0x61, 0x6C, 0x61, 0x6E, 0x5F, 0x69, 0x5B, 0x66, 0x59, 0x6C, 0x61, 0x6E, 0x64, 0x6B, 0x5F, 0x6E, 0x5F, 0x6A, 0x5E, 0x6B, 0x5E, 0x69, 0x5B, 0x6E, 0x61, 0x6D, 0x61, 0x6B, 0x5D, 0x66, 0x5A, 0x6A, 0x61, 0x6C, 0x61, 0x6E, 0x63, 0x6D, 0x61, 0x6B, 0x60, 0x66, 0x5C, 0x6A, 0x5F, 0x69, 0x5F, 0x68, 0x5D, 0x69, 0x5C, 0x63, 0x58, 0x65, 0x5A, 0x65, 0x59, 0x63, 0x57, 0x65, 0x58, 0x66, 0x59, 0x63, 0x58, 0x60, 0x57, 0x60, 0x57, 0x63, 0x58, 0x66, 0x5A, 0x64, 0x59, 0x65, 0x59, 0x64, 0x59, 0x66, 0x5A, 0x61, 0x57, 0x64, 0x57, 0x52, 0x47, 0x30, 0x2D, 0x2C, 0x2F, 0x2B, 0x2F, 0x29, 0x2D, 0x27, 0x2C, 0x2B, 0x33, 0x36, 0x48, 0x3C, 0x4F, 0x41, 0x56, 0x45, 0x5D, 0x46, 0x61, 0x48, 0x64, 0x39, 0x45, 0x2D, 0x34, 0x33, 0x3A, 0x35, 0x3A, 0x39, 0x4D, 0x4B, 0x69, 0x4F, 0x6E, 0x4E, 0x6D, 0x4F, 0x6C, 0x4E, 0x6A, 0x47, 0x5F, 0x27, 0x2D, 0x2A, 0x34, 0x34, 0x3B, 0x33, 0x46, 0x44, 0x5F, 0x44, 0x5F, 0x41, 0x5C, 0x3F, 0x59, 0x3C, 0x55, 0x38, 0x4E, 0x29, 0x30, 0x25, 0x2D, 0x27, 0x2A, 0x2D, 0x38, 0x32, 0x3F, 0x28, 0x36, 0x24, 0x30, 0x20, 0x2A, 0x1D, 0x25, 0x1C, 0x22, 0x1A, 0x1E, 0x1A, 0x20, 0x2E, 0x36
    },

    {
        0x55, 0x1F, 0x55, 0x1D, 0x56, 0x1E, 0x56, 0x1E, 0x55, 0x1E, 0x56, 0x1D, 0x55, 0x1E, 0x55, 0x1E, 0x55, 0x1E, 0x55, 0x1E, 0x51, 0x1D, 0x45, 0x1B, 0x37, 0x19, 0x3A, 0x1B, 0x4B, 0x1E, 0x52, 0x1F, 0x50, 0x1E, 0x41, 0x19, 0x2C, 0x15, 0x1F, 0x12, 0x1C, 0x11, 0x1A, 0x10, 0x19, 0x11, 0x17, 0x0F, 0x17, 0x10, 0x17, 0x10, 0x17, 0x0F, 0x16, 0x10, 0x16, 0x0F, 0x17, 0x10, 0x17, 0x10, 0x1A, 0x12, 0x1E, 0x15, 0x20, 0x15, 0x1F, 0x15, 0x1A, 0x12, 0x18, 0x11, 0x18, 0x11, 0x17, 0x10, 0x17, 0x0F, 0x17, 0x0F, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x15, 0x0F, 0x17, 0x11, 0x17, 0x10, 0x17, 0x10, 0x16, 0x10, 0x17, 0x10, 0x18, 0x11, 0x17, 0x10, 0x17, 0x10, 0x18, 0x11, 0x19, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x19, 0x12, 0x1A, 0x12, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x19, 0x12, 0x1B, 0x14, 0x20, 0x19, 0x39, 0x30, 0x74, 0x56, 0x99, 0x69, 0x9F, 0x6C, 0x8D, 0x5B, 0x57, 0x36, 0x32, 0x20, 0x25, 0x1A, 0x20, 0x16, 0x1D, 0x14, 0x1A, 0x13, 0x1A, 0x12, 0x1B, 0x14, 0x26, 0x20, 0x58, 0x47, 0x92, 0x67, 0x91, 0x5B, 0x55, 0x34, 0x2F, 0x1F, 0x26, 0x1A, 0x1F, 0x15, 0x1B, 0x14, 0x19, 0x11, 0x19, 0x11, 0x1A, 0x12, 0x1A, 0x12, 0x19, 0x11, 0x19, 0x12, 0x1B, 0x13, 0x1B, 0x13, 0x19, 0x11, 0x18, 0x11, 0x19, 0x12, 0x19, 0x11, 0x17, 0x10, 0x18, 0x10, 0x17, 0x11, 0x18, 0x11, 0x1B, 0x14, 0x1D, 0x15, 0x1E, 0x14, 0x1E, 0x14, 0x1B, 0x13, 0x1D, 0x14, 0x1D, 0x14, 0x1C, 0x14, 0x1C, 0x14, 0x1C, 0x14, 0x1D, 0x15, 0x20, 0x15, 0x1C, 0x13, 0x1C, 0x14, 0x1C, 0x13, 0x1B, 0x12, 0x1A, 0x12, 0x1A, 0x12, 0x1B, 0x13, 0x1D, 0x14, 0x1B, 0x13, 0x1C, 0x13, 0x1B, 0x13, 0x1E, 0x14, 0x26, 0x18, 0x50, 0x21, 0x62, 0x25, 0x61, 0x24, 0x48, 0x20, 0x31, 0x1B, 0x50, 0x22, 0x61, 0x26, 0x65, 0x26, 0x67, 0x26, 0x6C, 0x28, 0x68, 0x26, 0x65, 0x26, 0x64, 0x26, 0x69, 0x27, 0x66, 0x26, 0x68, 0x26, 0x67, 0x27, 0x6B, 0x28, 0x6A, 0x28, 0x6B, 0x27, 0x6E, 0x28, 0x6D, 0x28, 0x6D, 0x29, 0x68, 0x26, 0x69, 0x28, 0x6E, 0x29, 0x69, 0x27, 0x66, 0x27, 0x69, 0x27, 0x6A, 0x27, 0x6A, 0x28, 0x6B, 0x27, 0x69, 0x27, 0x6A, 0x27, 0x66, 0x25, 0x64, 0x25, 0x69, 0x26, 0x69, 0x27, 0x69, 0x27, 0x68, 0x27, 0x67, 0x26, 0x66, 0x24, 0x63, 0x23, 0x62, 0x23, 0x66, 0x25, 0x67, 0x24, 0x67, 0x25, 0x67, 0x25, 0x67, 0x25, 0x60, 0x22, 0x62, 0x23, 0x61, 0x23, 0x5E, 0x23, 0x62, 0x23, 0x62, 0x24, 0x64, 0x23, 0x61, 0x23, 0x63, 0x23, 0x62, 0x23, 0x63, 0x24, 0x65, 0x24, 0x6A, 0x28, 0x6A, 0x26, 0x68, 0x26, 0x61, 0x23, 0x63, 0x24, 0x67, 0x24, 0x63, 0x23, 0x66, 0x24, 0x67, 0x24, 0x64, 0x23, 0x60, 0x22, 0x62, 0x23, 0x63, 0x23, 0x63, 0x24, 0x67, 0x24, 0x61, 0x23, 0x60, 0x23, 0x61, 0x25, 0x61, 0x23, 0x5F, 0x22, 0x60, 0x23, 0x5F, 0x22, 0x5F, 0x22, 0x60, 0x23, 0x61, 0x24, 0x63, 0x23, 0x5F, 0x23, 0x61, 0x23, 0x64, 0x24, 0x63, 0x24, 0x62, 0x25, 0x5F, 0x23, 0x60, 0x23, 0x60, 0x23, 0x62, 0x23, 0x60, 0x23, 0x62, 0x23, 0x61, 0x24, 0x5E, 0x23, 0x60, 0x22, 0x5B, 0x22, 0x5D, 0x23, 0x61, 0x23, 0x63, 0x24, 0x5D, 0x22, 0x5B, 0x21, 0x5C, 0x22, 0x5D, 0x21, 0x5C, 0x21, 0x5F, 0x22, 0x5D, 0x21, 0x5D, 0x22, 0x5D, 0x21, 0x5C, 0x22, 0x5F, 0x23, 0x61, 0x24, 0x5D, 0x23, 0x5B, 0x23, 0x5B, 0x22, 0x5F, 0x22, 0x5C, 0x21, 0x5D, 0x22, 0x5C, 0x21, 0x57, 0x20, 0x55, 0x20, 0x56, 0x20, 0x57, 0x20, 0x58, 0x20, 0x58, 0x20, 0x59, 0x22, 0x5D, 0x23, 0x5B, 0x21, 0x5A, 0x21, 0x58, 0x21, 0x5A, 0x21, 0x57, 0x20, 0x59, 0x21, 0x57, 0x20, 0x55, 0x1F, 0x57, 0x20, 0x4C, 0x1D, 0x31, 0x19, 0x2F, 0x1B, 0x30, 0x1A, 0x2D, 0x1B, 0x2B, 0x19, 0x3A, 0x21, 0x63, 0x36, 0x6F, 0x3B, 0x74, 0x3D, 0x72, 0x3C, 0x72, 0x3B, 0x6D, 0x38, 0x4E, 0x27, 0x2F, 0x1D, 0x3C, 0x1F, 0x3A, 0x1F, 0x4D, 0x2C, 0x69, 0x36, 0x66, 0x36, 0x61, 0x34, 0x5E, 0x32, 0x57, 0x2F, 0x4E, 0x28, 0x27, 0x18, 0x32, 0x1D, 0x32, 0x1C, 0x34, 0x1D, 0x36, 0x1E, 0x2F, 0x1C, 0x2A, 0x1A, 0x27, 0x19, 0x22, 0x16, 0x20, 0x15, 0x1F, 0x14, 0x25, 0x17, 0x29, 0x17, 0x33, 0x1C, 0x30, 0x1A, 0x2D, 0x1A, 0x26, 0x17, 0x2C, 0x19, 0x24, 0x15, 0x26, 0x17, 0x23, 0x15, 0x25, 0x16, 0x29, 0x17
    },

    {
        0x60, 0x55, 0x5F, 0x55, 0x5F, 0x55, 0x61, 0x55, 0x60, 0x54, 0x60, 0x54, 0x5F, 0x54, 0x61, 0x54, 0x61, 0x56, 0x5F, 0x54, 0x5B, 0x50, 0x52, 0x46, 0x41, 0x38, 0x3C, 0x39, 0x4B, 0x4A, 0x58, 0x52, 0x57, 0x50, 0x4C, 0x42, 0x35, 0x2D, 0x22, 0x21, 0x1D, 0x1D, 0x19, 0x1A, 0x17, 0x19, 0x16, 0x17, 0x15, 0x17, 0x14, 0x17, 0x13, 0x16, 0x13, 0x16, 0x12, 0x16, 0x13, 0x16, 0x13, 0x17, 0x14, 0x18, 0x17, 0x1D, 0x18, 0x1E, 0x19, 0x1F, 0x17, 0x1B, 0x15, 0x18, 0x14, 0x17, 0x14, 0x17, 0x13, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x15, 0x11, 0x15, 0x12, 0x15, 0x12, 0x15, 0x12, 0x15, 0x12, 0x16, 0x12, 0x16, 0x13, 0x16, 0x12, 0x16, 0x13, 0x17, 0x13, 0x17, 0x12, 0x16, 0x13, 0x16, 0x13, 0x17, 0x14, 0x18, 0x14, 0x18, 0x14, 0x17, 0x13, 0x17, 0x14, 0x18, 0x14, 0x18, 0x14, 0x17, 0x13, 0x18, 0x14, 0x18, 0x15, 0x19, 0x17, 0x1A, 0x1A, 0x1E, 0x25, 0x32, 0x48, 0x6A, 0x6D, 0x92, 0x73, 0x93, 0x64, 0x76, 0x3E, 0x41, 0x26, 0x2A, 0x1E, 0x22, 0x1A, 0x1E, 0x17, 0x1C, 0x16, 0x1A, 0x16, 0x19, 0x16, 0x1A, 0x1E, 0x23, 0x36, 0x50, 0x5E, 0x89, 0x61, 0x78, 0x3B, 0x3F, 0x24, 0x28, 0x1E, 0x22, 0x19, 0x1C, 0x16, 0x19, 0x14, 0x18, 0x14, 0x19, 0x15, 0x1A, 0x15, 0x19, 0x15, 0x19, 0x15, 0x19, 0x16, 0x1B, 0x16, 0x1B, 0x14, 0x19, 0x14, 0x18, 0x14, 0x18, 0x15, 0x18, 0x14, 0x17, 0x14, 0x17, 0x13, 0x17, 0x14, 0x18, 0x16, 0x1C, 0x18, 0x1D, 0x17, 0x1D, 0x17, 0x1C, 0x16, 0x1B, 0x18, 0x1C, 0x17, 0x1C, 0x17, 0x1C, 0x18, 0x1D, 0x18, 0x1C, 0x18, 0x1D, 0x19, 0x1F, 0x17, 0x1B, 0x16, 0x1B, 0x16, 0x1B, 0x16, 0x19, 0x15, 0x1A, 0x15, 0x1A, 0x16, 0x1B, 0x18, 0x1C, 0x16, 0x1A, 0x17, 0x1B, 0x17, 0x1C, 0x1C, 0x1E, 0x2D, 0x33, 0x59, 0x5A, 0x69, 0x63, 0x63, 0x5B, 0x42, 0x3B, 0x38, 0x36, 0x5B, 0x5B, 0x6A, 0x64, 0x6C, 0x65, 0x71, 0x68, 0x77, 0x6A, 0x74, 0x69, 0x72, 0x65, 0x70, 0x63, 0x73, 0x68, 0x72, 0x65, 0x73, 0x68, 0x73, 0x68, 0x77, 0x6C, 0x76, 0x69, 0x78, 0x6C, 0x7B, 0x6E, 0x79, 0x6C, 0x78, 0x6A, 0x74, 0x67, 0x73, 0x6A, 0x79, 0x6D, 0x77, 0x69, 0x75, 0x68, 0x72, 0x67, 0x76, 0x6A, 0x78, 0x6A, 0x77, 0x6A, 0x75, 0x6A, 0x77, 0x69, 0x73, 0x66, 0x73, 0x66, 0x75, 0x68, 0x78, 0x6A, 0x74, 0x69, 0x76, 0x68, 0x76, 0x68, 0x75, 0x66, 0x72, 0x63, 0x71, 0x65, 0x75, 0x66, 0x75, 0x67, 0x75, 0x67, 0x72, 0x66, 0x72, 0x66, 0x6C, 0x5F, 0x6D, 0x62, 0x6E, 0x60, 0x6B, 0x5D, 0x70, 0x62, 0x71, 0x65, 0x70, 0x62, 0x6E, 0x61, 0x71, 0x63, 0x71, 0x62, 0x6E, 0x62, 0x70, 0x64, 0x76, 0x6A, 0x77, 0x69, 0x79, 0x6A, 0x6E, 0x60, 0x71, 0x64, 0x74, 0x65, 0x73, 0x63, 0x72, 0x64, 0x76, 0x66, 0x72, 0x63, 0x6D, 0x60, 0x71, 0x62, 0x72, 0x61, 0x6F, 0x63, 0x74, 0x64, 0x6E, 0x61, 0x6E, 0x60, 0x6E, 0x62, 0x6B, 0x60, 0x69, 0x5E, 0x6A, 0x5E, 0x6A, 0x5D, 0x6D, 0x61, 0x6C, 0x61, 0x6B, 0x60, 0x6F, 0x62, 0x6C, 0x5F, 0x6E, 0x60, 0x71, 0x64, 0x71, 0x63, 0x6B, 0x62, 0x69, 0x5F, 0x6B, 0x60, 0x6F, 0x62, 0x6B, 0x60, 0x6D, 0x60, 0x70, 0x63, 0x71, 0x61, 0x6B, 0x5F, 0x6D, 0x5E, 0x68, 0x5D, 0x6A, 0x5F, 0x6F, 0x63, 0x6E, 0x62, 0x6B, 0x5F, 0x67, 0x5B, 0x6A, 0x5C, 0x6A, 0x5C, 0x69, 0x5C, 0x6D, 0x60, 0x68, 0x5A, 0x6A, 0x5E, 0x6A, 0x5D, 0x68, 0x5C, 0x6D, 0x61, 0x6E, 0x61, 0x68, 0x5D, 0x66, 0x5A, 0x66, 0x5C, 0x6A, 0x5C, 0x68, 0x5C, 0x68, 0x5D, 0x6B, 0x5D, 0x62, 0x57, 0x60, 0x56, 0x61, 0x57, 0x65, 0x59, 0x65, 0x59, 0x65, 0x59, 0x63, 0x59, 0x68, 0x5B, 0x69, 0x5D, 0x65, 0x59, 0x66, 0x5A, 0x64, 0x59, 0x63, 0x58, 0x65, 0x5A, 0x61, 0x56, 0x62, 0x56, 0x64, 0x57, 0x51, 0x47, 0x32, 0x31, 0x2F, 0x33, 0x2B, 0x2E, 0x29, 0x2F, 0x29, 0x2D, 0x33, 0x41, 0x49, 0x68, 0x51, 0x72, 0x52, 0x72, 0x50, 0x70, 0x51, 0x6F, 0x4E, 0x6B, 0x37, 0x42, 0x27, 0x30, 0x32, 0x39, 0x30, 0x37, 0x3E, 0x53, 0x49, 0x5F, 0x44, 0x5B, 0x40, 0x54, 0x3C, 0x4E, 0x36, 0x48, 0x30, 0x3C, 0x1D, 0x22, 0x2B, 0x33, 0x2C, 0x2F, 0x2B, 0x30, 0x24, 0x29, 0x1E, 0x25, 0x1D, 0x21, 0x1C, 0x1F, 0x1A, 0x1D, 0x1A, 0x1E, 0x1E, 0x22, 0x24, 0x29, 0x26, 0x29, 0x2F, 0x36, 0x2C, 0x30, 0x2C, 0x31, 0x24, 0x2A, 0x2B, 0x2F, 0x22, 0x26, 0x24, 0x29, 0x23, 0x25, 0x26, 0x2A, 0x26, 0x29
    },

    {
        0x57, 0x1F, 0x56, 0x1E, 0x56, 0x1E, 0x56, 0x1E, 0x54, 0x1D, 0x54, 0x1E, 0x56, 0x1E, 0x56, 0x1E, 0x58, 0x1E, 0x57, 0x1F, 0x55, 0x1F, 0x51, 0x1D, 0x48, 0x1C, 0x3B, 0x1A, 0x39, 0x1A, 0x47, 0x1D, 0x4F, 0x1E, 0x4D, 0x1D, 0x42, 0x19, 0x2F, 0x15, 0x21, 0x12, 0x1D, 0x11, 0x1A, 0x10, 0x18, 0x10, 0x18, 0x0F, 0x17, 0x10, 0x17, 0x10, 0x16, 0x0F, 0x16, 0x0F, 0x16, 0x0F, 0x17, 0x10, 0x18, 0x11, 0x1A, 0x12, 0x1A, 0x12, 0x1B, 0x14, 0x1F, 0x16, 0x1F, 0x15, 0x1B, 0x12, 0x18, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x16, 0x0F, 0x16, 0x10, 0x16, 0x0F, 0x16, 0x0F, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x12, 0x17, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x10, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x19, 0x12, 0x1A, 0x12, 0x1A, 0x12, 0x1D, 0x16, 0x30, 0x29, 0x68, 0x50, 0x81, 0x53, 0x55, 0x34, 0x30, 0x20, 0x26, 0x1A, 0x21, 0x17, 0x1E, 0x15, 0x1C, 0x14, 0x1A, 0x12, 0x1A, 0x12, 0x1A, 0x13, 0x1B, 0x13, 0x22, 0x1D, 0x46, 0x37, 0x4B, 0x2F, 0x2B, 0x1D, 0x23, 0x18, 0x1F, 0x15, 0x1B, 0x13, 0x19, 0x12, 0x19, 0x11, 0x19, 0x11, 0x1A, 0x12, 0x1A, 0x12, 0x1A, 0x13, 0x1D, 0x13, 0x1C, 0x13, 0x1B, 0x13, 0x1A, 0x12, 0x1A, 0x12, 0x19, 0x11, 0x19, 0x11, 0x18, 0x11, 0x18, 0x11, 0x17, 0x10, 0x18, 0x11, 0x19, 0x11, 0x19, 0x11, 0x19, 0x11, 0x1A, 0x13, 0x1C, 0x12, 0x1B, 0x13, 0x1C, 0x13, 0x1C, 0x13, 0x20, 0x16, 0x20, 0x15, 0x1C, 0x13, 0x1E, 0x14, 0x1C, 0x13, 0x1C, 0x13, 0x1B, 0x12, 0x1B, 0x13, 0x1B, 0x12, 0x1A, 0x12, 0x1B, 0x12, 0x1B, 0x12, 0x1B, 0x13, 0x1C, 0x13, 0x1D, 0x14, 0x28, 0x18, 0x4D, 0x21, 0x63, 0x25, 0x61, 0x27, 0x51, 0x23, 0x32, 0x1C, 0x4A, 0x21, 0x62, 0x25, 0x67, 0x28, 0x65, 0x26, 0x67, 0x26, 0x67, 0x26, 0x67, 0x26, 0x6C, 0x2A, 0x68, 0x27, 0x69, 0x27, 0x69, 0x27, 0x69, 0x26, 0x68, 0x27, 0x69, 0x26, 0x67, 0x26, 0x6B, 0x27, 0x6A, 0x27, 0x6A, 0x27, 0x6E, 0x29, 0x6A, 0x27, 0x67, 0x27, 0x6B, 0x28, 0x69, 0x27, 0x6C, 0x29, 0x6A, 0x27, 0x6A, 0x28, 0x6A, 0x28, 0x67, 0x27, 0x6B, 0x29, 0x66, 0x26, 0x68, 0x27, 0x69, 0x26, 0x68, 0x25, 0x67, 0x27, 0x68, 0x27, 0x68, 0x26, 0x69, 0x28, 0x6C, 0x29, 0x6C, 0x27, 0x6A, 0x26, 0x66, 0x25, 0x68, 0x25, 0x65, 0x24, 0x62, 0x23, 0x62, 0x23, 0x63, 0x23, 0x5F, 0x23, 0x62, 0x23, 0x5E, 0x22, 0x63, 0x24, 0x62, 0x23, 0x62, 0x23, 0x61, 0x23, 0x62, 0x23, 0x65, 0x25, 0x68, 0x26, 0x65, 0x24, 0x67, 0x25, 0x64, 0x25, 0x6C, 0x26, 0x63, 0x23, 0x66, 0x23, 0x62, 0x22, 0x61, 0x23, 0x64, 0x24, 0x63, 0x24, 0x63, 0x24, 0x63, 0x23, 0x5F, 0x22, 0x60, 0x22, 0x5E, 0x21, 0x60, 0x22, 0x62, 0x23, 0x63, 0x23, 0x64, 0x24, 0x5F, 0x22, 0x5F, 0x21, 0x5D, 0x22, 0x60, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x5F, 0x23, 0x60, 0x23, 0x60, 0x23, 0x61, 0x24, 0x62, 0x23, 0x62, 0x24, 0x5E, 0x23, 0x61, 0x24, 0x60, 0x23, 0x62, 0x24, 0x5E, 0x22, 0x60, 0x23, 0x5E, 0x23, 0x61, 0x22, 0x5E, 0x22, 0x5B, 0x21, 0x61, 0x23, 0x61, 0x23, 0x5F, 0x23, 0x5D, 0x22, 0x60, 0x22, 0x5C, 0x21, 0x60, 0x22, 0x5C, 0x21, 0x5C, 0x21, 0x60, 0x22, 0x5A, 0x20, 0x5E, 0x22, 0x60, 0x23, 0x60, 0x23, 0x60, 0x23, 0x61, 0x24, 0x5D, 0x22, 0x5E, 0x23, 0x5E, 0x22, 0x5E, 0x21, 0x5B, 0x21, 0x5C, 0x21, 0x5B, 0x21, 0x59, 0x21, 0x59, 0x20, 0x59, 0x21, 0x59, 0x20, 0x59, 0x22, 0x5D, 0x24, 0x5B, 0x22, 0x58, 0x21, 0x59, 0x20, 0x56, 0x20, 0x55, 0x20, 0x57, 0x21, 0x5A, 0x21, 0x5A, 0x22, 0x58, 0x22, 0x59, 0x21, 0x59, 0x21, 0x4E, 0x1F, 0x3E, 0x1F, 0x3A, 0x1E, 0x32, 0x1D, 0x3D, 0x21, 0x37, 0x1D, 0x42, 0x24, 0x60, 0x34, 0x62, 0x34, 0x5C, 0x32, 0x55, 0x2F, 0x4F, 0x2A, 0x47, 0x28, 0x31, 0x1C, 0x21, 0x16, 0x28, 0x17, 0x2C, 0x1A, 0x37, 0x1F, 0x2E, 0x1A, 0x22, 0x15, 0x1F, 0x15, 0x1E, 0x13, 0x1C, 0x13, 0x1D, 0x13, 0x1D, 0x13, 0x2B, 0x19, 0x2D, 0x1A, 0x2A, 0x18, 0x29, 0x17, 0x2C, 0x19, 0x2F, 0x1A, 0x2B, 0x18, 0x2A, 0x18, 0x30, 0x1C, 0x3C, 0x1F, 0x33, 0x1C, 0x33, 0x1C, 0x3D, 0x20, 0x3A, 0x1F, 0x2F, 0x1B, 0x2F, 0x1B, 0x32, 0x1B, 0x29, 0x18, 0x30, 0x1C, 0x2D, 0x1A, 0x39, 0x1F, 0x36, 0x1D
    },

    {
        0x61, 0x55, 0x60, 0x54, 0x60, 0x54, 0x60, 0x54, 0x5E, 0x53, 0x60, 0x55, 0x61, 0x56, 0x62, 0x57, 0x64, 0x57, 0x62, 0x55, 0x60, 0x55, 0x5B, 0x50, 0x53, 0x4A, 0x45, 0x3B, 0x3A, 0x37, 0x46, 0x45, 0x53, 0x4F, 0x55, 0x4C, 0x4B, 0x43, 0x37, 0x30, 0x25, 0x22, 0x1D, 0x1D, 0x19, 0x1A, 0x17, 0x19, 0x16, 0x18, 0x15, 0x17, 0x15, 0x17, 0x13, 0x17, 0x13, 0x16, 0x12, 0x16, 0x13, 0x17, 0x14, 0x18, 0x15, 0x19, 0x15, 0x19, 0x16, 0x1A, 0x17, 0x1E, 0x19, 0x1F, 0x16, 0x1B, 0x15, 0x18, 0x14, 0x17, 0x13, 0x17, 0x13, 0x16, 0x13, 0x17, 0x12, 0x16, 0x12, 0x15, 0x12, 0x16, 0x12, 0x16, 0x12, 0x15, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x13, 0x16, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x14, 0x17, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x12, 0x17, 0x14, 0x18, 0x14, 0x17, 0x14, 0x18, 0x15, 0x19, 0x15, 0x1A, 0x15, 0x19, 0x18, 0x1C, 0x22, 0x2B, 0x3E, 0x5D, 0x55, 0x6F, 0x3C, 0x40, 0x25, 0x29, 0x1E, 0x23, 0x1B, 0x1F, 0x18, 0x1B, 0x15, 0x1A, 0x15, 0x19, 0x15, 0x19, 0x15, 0x19, 0x16, 0x1A, 0x1A, 0x20, 0x2A, 0x3E, 0x2F, 0x38, 0x20, 0x25, 0x1B, 0x20, 0x18, 0x1D, 0x16, 0x1A, 0x15, 0x19, 0x14, 0x18, 0x14, 0x18, 0x15, 0x19, 0x15, 0x19, 0x16, 0x1B, 0x17, 0x1D, 0x16, 0x1C, 0x16, 0x1B, 0x15, 0x1A, 0x15, 0x19, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x15, 0x19, 0x15, 0x18, 0x14, 0x18, 0x15, 0x19, 0x16, 0x1A, 0x16, 0x1B, 0x16, 0x1B, 0x17, 0x1D, 0x1A, 0x21, 0x19, 0x1E, 0x17, 0x1B, 0x17, 0x1C, 0x16, 0x1A, 0x16, 0x1B, 0x16, 0x1A, 0x17, 0x1B, 0x16, 0x1A, 0x16, 0x1A, 0x16, 0x1B, 0x16, 0x1B, 0x17, 0x1B, 0x18, 0x1C, 0x1A, 0x1E, 0x2E, 0x34, 0x57, 0x58, 0x6A, 0x63, 0x63, 0x5E, 0x4A, 0x42, 0x37, 0x37, 0x55, 0x55, 0x69, 0x62, 0x6F, 0x67, 0x70, 0x66, 0x74, 0x68, 0x73, 0x67, 0x74, 0x66, 0x76, 0x6C, 0x73, 0x67, 0x72, 0x65, 0x73, 0x68, 0x73, 0x68, 0x73, 0x68, 0x76, 0x67, 0x75, 0x67, 0x76, 0x69, 0x76, 0x69, 0x75, 0x68, 0x76, 0x6B, 0x74, 0x67, 0x72, 0x67, 0x76, 0x6A, 0x76, 0x69, 0x77, 0x6B, 0x75, 0x68, 0x77, 0x6A, 0x76, 0x6A, 0x72, 0x67, 0x76, 0x6B, 0x72, 0x66, 0x73, 0x67, 0x76, 0x68, 0x75, 0x64, 0x74, 0x66, 0x74, 0x66, 0x75, 0x68, 0x78, 0x6B, 0x79, 0x6C, 0x7B, 0x6C, 0x77, 0x69, 0x75, 0x67, 0x76, 0x67, 0x73, 0x64, 0x70, 0x60, 0x70, 0x62, 0x72, 0x62, 0x6A, 0x60, 0x6F, 0x62, 0x6B, 0x60, 0x6F, 0x63, 0x6F, 0x61, 0x72, 0x62, 0x6F, 0x62, 0x6E, 0x61, 0x71, 0x66, 0x74, 0x68, 0x73, 0x66, 0x75, 0x67, 0x72, 0x65, 0x7A, 0x6A, 0x70, 0x63, 0x73, 0x65, 0x71, 0x61, 0x70, 0x64, 0x73, 0x66, 0x74, 0x64, 0x72, 0x64, 0x71, 0x62, 0x6D, 0x5E, 0x6E, 0x61, 0x6C, 0x5D, 0x70, 0x61, 0x71, 0x65, 0x71, 0x64, 0x72, 0x64, 0x6B, 0x5F, 0x6C, 0x5E, 0x69, 0x5F, 0x6D, 0x61, 0x6C, 0x5E, 0x6B, 0x5F, 0x6D, 0x61, 0x6D, 0x60, 0x6C, 0x60, 0x6F, 0x63, 0x72, 0x63, 0x6E, 0x62, 0x6A, 0x60, 0x6C, 0x60, 0x6A, 0x5F, 0x6E, 0x63, 0x6A, 0x5E, 0x6B, 0x60, 0x6A, 0x5F, 0x6D, 0x61, 0x6B, 0x5D, 0x68, 0x5E, 0x6E, 0x61, 0x6F, 0x62, 0x6B, 0x5C, 0x69, 0x5F, 0x6A, 0x5E, 0x6A, 0x5F, 0x6D, 0x5F, 0x69, 0x5C, 0x6A, 0x5E, 0x6D, 0x60, 0x68, 0x5B, 0x6C, 0x5F, 0x6E, 0x61, 0x6D, 0x61, 0x6E, 0x62, 0x6C, 0x62, 0x68, 0x5D, 0x6C, 0x5F, 0x6A, 0x5E, 0x6A, 0x5E, 0x67, 0x59, 0x6B, 0x5C, 0x69, 0x5B, 0x66, 0x5B, 0x66, 0x5A, 0x64, 0x5A, 0x66, 0x5B, 0x66, 0x5E, 0x68, 0x5F, 0x64, 0x5B, 0x63, 0x56, 0x65, 0x59, 0x60, 0x56, 0x60, 0x57, 0x63, 0x59, 0x64, 0x59, 0x64, 0x59, 0x65, 0x5A, 0x65, 0x59, 0x63, 0x58, 0x53, 0x4A, 0x3C, 0x41, 0x35, 0x39, 0x2F, 0x35, 0x37, 0x40, 0x31, 0x36, 0x39, 0x44, 0x43, 0x57, 0x3E, 0x51, 0x3A, 0x4A, 0x35, 0x43, 0x31, 0x3D, 0x2C, 0x36, 0x22, 0x25, 0x1C, 0x20, 0x23, 0x26, 0x28, 0x2E, 0x30, 0x37, 0x24, 0x25, 0x1C, 0x1D, 0x1B, 0x1E, 0x1C, 0x1E, 0x1A, 0x1E, 0x1D, 0x1F, 0x1D, 0x22, 0x27, 0x2B, 0x2A, 0x2F, 0x27, 0x2B, 0x28, 0x2B, 0x2B, 0x32, 0x2D, 0x32, 0x29, 0x2E, 0x28, 0x2B, 0x31, 0x39, 0x35, 0x39, 0x2C, 0x32, 0x2D, 0x32, 0x37, 0x40, 0x32, 0x35, 0x28, 0x2A, 0x2A, 0x31, 0x2C, 0x2F, 0x26, 0x2A, 0x2D, 0x34, 0x2C, 0x31, 0x36, 0x3E, 0x33, 0x39
    },

    {
        0x56, 0x1E, 0x56, 0x1E, 0x55, 0x1E, 0x55, 0x1E, 0x55, 0x1E, 0x55, 0x1F, 0x56, 0x1F, 0x58, 0x1F, 0x58, 0x1F, 0x57, 0x1F, 0x57, 0x1F, 0x56, 0x1E, 0x52, 0x1E, 0x4C, 0x1C, 0x3D, 0x19, 0x36, 0x19, 0x42, 0x1C, 0x4E, 0x1E, 0x4D, 0x1D, 0x45, 0x1A, 0x33, 0x16, 0x23, 0x13, 0x1D, 0x11, 0x1B, 0x10, 0x19, 0x10, 0x18, 0x10, 0x18, 0x0F, 0x17, 0x0F, 0x18, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x18, 0x11, 0x18, 0x11, 0x1A, 0x13, 0x1C, 0x14, 0x1D, 0x14, 0x1B, 0x12, 0x18, 0x11, 0x17, 0x10, 0x17, 0x11, 0x17, 0x10, 0x16, 0x0F, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x17, 0x10, 0x17, 0x11, 0x17, 0x10, 0x17, 0x10, 0x17, 0x0F, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x11, 0x17, 0x11, 0x18, 0x11, 0x17, 0x10, 0x18, 0x11, 0x18, 0x10, 0x17, 0x11, 0x18, 0x11, 0x18, 0x11, 0x1A, 0x12, 0x19, 0x12, 0x19, 0x12, 0x19, 0x11, 0x19, 0x12, 0x1C, 0x15, 0x2A, 0x22, 0x3E, 0x29, 0x2E, 0x1E, 0x26, 0x1A, 0x21, 0x17, 0x1F, 0x16, 0x1D, 0x14, 0x1B, 0x13, 0x1A, 0x12, 0x1B, 0x12, 0x19, 0x12, 0x19, 0x13, 0x20, 0x1B, 0x2D, 0x22, 0x2A, 0x1E, 0x22, 0x18, 0x1F, 0x16, 0x1E, 0x15, 0x1C, 0x13, 0x1A, 0x12, 0x19, 0x11, 0x19, 0x11, 0x1A, 0x12, 0x1A, 0x13, 0x20, 0x17, 0x20, 0x16, 0x1F, 0x15, 0x1C, 0x13, 0x1A, 0x12, 0x1B, 0x13, 0x1C, 0x12, 0x19, 0x11, 0x19, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x19, 0x12, 0x19, 0x11, 0x18, 0x11, 0x19, 0x12, 0x1A, 0x13, 0x1C, 0x14, 0x1E, 0x14, 0x1F, 0x16, 0x1F, 0x15, 0x1B, 0x13, 0x1B, 0x13, 0x1B, 0x13, 0x1B, 0x13, 0x1B, 0x13, 0x1C, 0x13, 0x1C, 0x13, 0x1B, 0x12, 0x1B, 0x13, 0x1C, 0x13, 0x1C, 0x13, 0x1B, 0x13, 0x1C, 0x13, 0x25, 0x17, 0x4B, 0x21, 0x61, 0x25, 0x62, 0x25, 0x4B, 0x20, 0x34, 0x1E, 0x4C, 0x22, 0x5D, 0x24, 0x64, 0x27, 0x6B, 0x29, 0x69, 0x27, 0x6A, 0x28, 0x65, 0x26, 0x64, 0x26, 0x67, 0x26, 0x64, 0x24, 0x65, 0x27, 0x68, 0x27, 0x68, 0x26, 0x67, 0x26, 0x66, 0x26, 0x67, 0x25, 0x69, 0x26, 0x69, 0x27, 0x6A, 0x27, 0x67, 0x27, 0x66, 0x27, 0x68, 0x27, 0x6A, 0x28, 0x69, 0x26, 0x6A, 0x28, 0x69, 0x27, 0x68, 0x27, 0x6A, 0x28, 0x68, 0x27, 0x6A, 0x28, 0x6B, 0x28, 0x66, 0x24, 0x66, 0x26, 0x68, 0x26, 0x64, 0x25, 0x67, 0x26, 0x67, 0x25, 0x65, 0x26, 0x6A, 0x26, 0x6B, 0x26, 0x67, 0x25, 0x66, 0x25, 0x64, 0x24, 0x63, 0x24, 0x65, 0x24, 0x61, 0x22, 0x60, 0x23, 0x60, 0x23, 0x64, 0x24, 0x5F, 0x22, 0x5E, 0x22, 0x63, 0x24, 0x64, 0x23, 0x63, 0x24, 0x61, 0x25, 0x66, 0x25, 0x65, 0x25, 0x66, 0x25, 0x64, 0x25, 0x62, 0x23, 0x64, 0x24, 0x66, 0x26, 0x62, 0x24, 0x62, 0x23, 0x65, 0x23, 0x66, 0x25, 0x63, 0x23, 0x63, 0x23, 0x61, 0x22, 0x61, 0x22, 0x64, 0x23, 0x60, 0x22, 0x5F, 0x22, 0x61, 0x23, 0x61, 0x24, 0x64, 0x24, 0x5E, 0x22, 0x60, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x5F, 0x21, 0x5E, 0x22, 0x61, 0x24, 0x63, 0x23, 0x5E, 0x23, 0x61, 0x24, 0x61, 0x24, 0x62, 0x24, 0x5D, 0x22, 0x62, 0x23, 0x60, 0x23, 0x5F, 0x23, 0x5F, 0x24, 0x5F, 0x23, 0x5E, 0x23, 0x5F, 0x23, 0x63, 0x27, 0x63, 0x24, 0x64, 0x24, 0x63, 0x24, 0x5C, 0x21, 0x5D, 0x21, 0x5D, 0x21, 0x60, 0x22, 0x5F, 0x22, 0x5B, 0x20, 0x5C, 0x21, 0x5C, 0x21, 0x5F, 0x22, 0x5F, 0x23, 0x62, 0x23, 0x5F, 0x23, 0x61, 0x24, 0x5F, 0x23, 0x60, 0x23, 0x61, 0x26, 0x5C, 0x22, 0x58, 0x20, 0x56, 0x20, 0x5C, 0x22, 0x5B, 0x21, 0x5B, 0x21, 0x5C, 0x21, 0x5D, 0x22, 0x5D, 0x22, 0x5B, 0x25, 0x5D, 0x24, 0x59, 0x21, 0x54, 0x20, 0x5A, 0x22, 0x57, 0x20, 0x58, 0x21, 0x57, 0x21, 0x58, 0x20, 0x57, 0x20, 0x59, 0x20, 0x57, 0x20, 0x59, 0x20, 0x50, 0x20, 0x42, 0x21, 0x39, 0x1E, 0x38, 0x1F, 0x3D, 0x20, 0x33, 0x1D, 0x3E, 0x20, 0x2E, 0x19, 0x20, 0x15, 0x1F, 0x14, 0x20, 0x14, 0x23, 0x16, 0x20, 0x14, 0x24, 0x15, 0x24, 0x16, 0x2C, 0x19, 0x3A, 0x1F, 0x3B, 0x23, 0x37, 0x1F, 0x27, 0x16, 0x2C, 0x19, 0x2F, 0x19, 0x2D, 0x1A, 0x30, 0x1A, 0x2D, 0x1A, 0x3B, 0x20, 0x3B, 0x1F, 0x37, 0x1D, 0x34, 0x1C, 0x40, 0x21, 0x2E, 0x19, 0x2E, 0x1A, 0x2B, 0x18, 0x3F, 0x21, 0x30, 0x19, 0x34, 0x1D, 0x2D, 0x1A, 0x30, 0x1C, 0x2C, 0x18, 0x2C, 0x1A, 0x33, 0x1D, 0x39, 0x1F, 0x2F, 0x1A, 0x39, 0x1F, 0x3A, 0x1E, 0x36, 0x1D, 0x31, 0x1A
    },

    {
        0x61, 0x55, 0x60, 0x54, 0x61, 0x55, 0x61, 0x56, 0x5F, 0x55, 0x5F, 0x54, 0x61, 0x57, 0x62, 0x58, 0x63, 0x57, 0x62, 0x57, 0x62, 0x57, 0x60, 0x55, 0x5D, 0x52, 0x57, 0x4C, 0x48, 0x3E, 0x3B, 0x35, 0x41, 0x41, 0x54, 0x4D, 0x55, 0x4E, 0x4E, 0x46, 0x3D, 0x34, 0x27, 0x24, 0x1F, 0x1E, 0x1A, 0x1C, 0x18, 0x19, 0x16, 0x18, 0x15, 0x17, 0x14, 0x17, 0x14, 0x17, 0x14, 0x17, 0x13, 0x16, 0x13, 0x16, 0x13, 0x16, 0x12, 0x16, 0x14, 0x17, 0x13, 0x17, 0x14, 0x18, 0x15, 0x1B, 0x17, 0x1D, 0x17, 0x1B, 0x14, 0x18, 0x13, 0x17, 0x13, 0x17, 0x13, 0x16, 0x13, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x13, 0x16, 0x13, 0x16, 0x13, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x16, 0x13, 0x16, 0x13, 0x17, 0x13, 0x16, 0x13, 0x17, 0x13, 0x17, 0x13, 0x16, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x13, 0x18, 0x14, 0x18, 0x14, 0x19, 0x14, 0x18, 0x14, 0x18, 0x14, 0x17, 0x15, 0x19, 0x17, 0x1B, 0x1E, 0x2A, 0x29, 0x37, 0x22, 0x2A, 0x1D, 0x24, 0x1A, 0x20, 0x18, 0x1E, 0x17, 0x1C, 0x16, 0x1A, 0x15, 0x1B, 0x16, 0x1B, 0x15, 0x18, 0x15, 0x1A, 0x19, 0x23, 0x1D, 0x2D, 0x1E, 0x29, 0x1A, 0x20, 0x19, 0x1E, 0x18, 0x1E, 0x16, 0x1B, 0x16, 0x1A, 0x14, 0x18, 0x15, 0x18, 0x15, 0x19, 0x16, 0x1A, 0x19, 0x1F, 0x19, 0x1F, 0x18, 0x1E, 0x17, 0x1B, 0x15, 0x19, 0x16, 0x1C, 0x16, 0x1B, 0x15, 0x1A, 0x14, 0x18, 0x15, 0x18, 0x14, 0x17, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x15, 0x18, 0x15, 0x19, 0x16, 0x1A, 0x17, 0x1D, 0x19, 0x1F, 0x19, 0x1F, 0x18, 0x1C, 0x17, 0x1B, 0x16, 0x1B, 0x16, 0x1C, 0x16, 0x1B, 0x16, 0x1B, 0x16, 0x1B, 0x17, 0x1B, 0x16, 0x1B, 0x16, 0x1A, 0x17, 0x1B, 0x17, 0x1B, 0x18, 0x1B, 0x1A, 0x1C, 0x2A, 0x30, 0x52, 0x54, 0x67, 0x61, 0x64, 0x5C, 0x47, 0x3D, 0x36, 0x36, 0x56, 0x55, 0x68, 0x60, 0x6E, 0x68, 0x75, 0x6A, 0x76, 0x69, 0x76, 0x6A, 0x75, 0x67, 0x73, 0x65, 0x72, 0x64, 0x70, 0x62, 0x71, 0x66, 0x72, 0x66, 0x74, 0x67, 0x71, 0x65, 0x72, 0x65, 0x72, 0x66, 0x72, 0x68, 0x76, 0x6A, 0x77, 0x6A, 0x72, 0x68, 0x74, 0x68, 0x76, 0x6B, 0x78, 0x6B, 0x74, 0x66, 0x76, 0x69, 0x76, 0x69, 0x73, 0x68, 0x77, 0x6D, 0x76, 0x69, 0x77, 0x6A, 0x77, 0x6C, 0x73, 0x64, 0x73, 0x66, 0x76, 0x68, 0x72, 0x63, 0x72, 0x67, 0x77, 0x66, 0x75, 0x68, 0x77, 0x68, 0x7A, 0x69, 0x74, 0x66, 0x71, 0x64, 0x6F, 0x61, 0x72, 0x64, 0x73, 0x66, 0x70, 0x61, 0x6D, 0x5E, 0x6F, 0x62, 0x70, 0x64, 0x6E, 0x60, 0x6B, 0x60, 0x70, 0x64, 0x72, 0x63, 0x70, 0x62, 0x6F, 0x64, 0x74, 0x67, 0x71, 0x65, 0x71, 0x65, 0x70, 0x64, 0x72, 0x63, 0x73, 0x65, 0x73, 0x67, 0x70, 0x61, 0x70, 0x63, 0x73, 0x64, 0x73, 0x65, 0x71, 0x63, 0x71, 0x62, 0x70, 0x61, 0x72, 0x62, 0x70, 0x63, 0x6F, 0x61, 0x6D, 0x5F, 0x6E, 0x61, 0x6E, 0x61, 0x72, 0x64, 0x69, 0x5D, 0x6F, 0x61, 0x6F, 0x5F, 0x6D, 0x5E, 0x6C, 0x5E, 0x6B, 0x60, 0x6D, 0x63, 0x71, 0x65, 0x6B, 0x5E, 0x6C, 0x5F, 0x6D, 0x61, 0x6C, 0x60, 0x69, 0x5D, 0x6E, 0x62, 0x6B, 0x60, 0x6B, 0x5F, 0x6B, 0x61, 0x6D, 0x60, 0x6E, 0x60, 0x6A, 0x60, 0x72, 0x69, 0x71, 0x66, 0x73, 0x64, 0x71, 0x62, 0x69, 0x5A, 0x6A, 0x5E, 0x6B, 0x5E, 0x6F, 0x61, 0x6B, 0x5F, 0x68, 0x5B, 0x69, 0x5C, 0x69, 0x5C, 0x69, 0x5F, 0x6D, 0x61, 0x71, 0x63, 0x6E, 0x62, 0x6F, 0x62, 0x6A, 0x5F, 0x6B, 0x60, 0x6D, 0x63, 0x68, 0x5B, 0x66, 0x59, 0x62, 0x58, 0x68, 0x5C, 0x68, 0x5B, 0x69, 0x5C, 0x65, 0x5B, 0x67, 0x5E, 0x67, 0x5B, 0x65, 0x5A, 0x64, 0x5A, 0x63, 0x58, 0x5E, 0x54, 0x65, 0x5C, 0x62, 0x57, 0x63, 0x58, 0x62, 0x59, 0x63, 0x57, 0x63, 0x58, 0x65, 0x58, 0x65, 0x57, 0x64, 0x58, 0x54, 0x4C, 0x3B, 0x3D, 0x33, 0x36, 0x31, 0x39, 0x32, 0x36, 0x2E, 0x34, 0x31, 0x36, 0x27, 0x28, 0x1E, 0x20, 0x1E, 0x20, 0x20, 0x22, 0x23, 0x27, 0x21, 0x23, 0x27, 0x2A, 0x24, 0x29, 0x2A, 0x30, 0x35, 0x3D, 0x33, 0x3A, 0x33, 0x3A, 0x26, 0x29, 0x2B, 0x30, 0x2E, 0x32, 0x2C, 0x32, 0x2B, 0x2E, 0x2A, 0x31, 0x36, 0x3D, 0x33, 0x39, 0x32, 0x3A, 0x2D, 0x33, 0x36, 0x3E, 0x28, 0x29, 0x2B, 0x30, 0x29, 0x2D, 0x37, 0x3E, 0x28, 0x2B, 0x2E, 0x35, 0x28, 0x2B, 0x2A, 0x2D, 0x28, 0x2A, 0x2B, 0x31, 0x30, 0x38, 0x34, 0x3A, 0x2A, 0x2E, 0x34, 0x3D, 0x33, 0x37, 0x2D, 0x31, 0x2B, 0x2E
    },

    {
        0x56, 0x1E, 0x55, 0x1E, 0x55, 0x1E, 0x55, 0x1E, 0x54, 0x1E, 0x55, 0x1F, 0x57, 0x1F, 0x57, 0x20, 0x56, 0x1E, 0x57, 0x1E, 0x57, 0x1F, 0x58, 0x1F, 0x57, 0x1F, 0x55, 0x1F, 0x4F, 0x1D, 0x42, 0x1B, 0x38, 0x1B, 0x43, 0x1E, 0x4F, 0x1F, 0x4F, 0x1D, 0x4A, 0x1B, 0x38, 0x17, 0x25, 0x13, 0x1F, 0x11, 0x1C, 0x11, 0x19, 0x10, 0x18, 0x10, 0x18, 0x10, 0x18, 0x10, 0x19, 0x10, 0x17, 0x10, 0x16, 0x10, 0x16, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x11, 0x19, 0x12, 0x1C, 0x14, 0x1E, 0x14, 0x1B, 0x13, 0x19, 0x12, 0x17, 0x11, 0x17, 0x11, 0x17, 0x11, 0x17, 0x10, 0x17, 0x10, 0x17, 0x11, 0x17, 0x11, 0x17, 0x11, 0x16, 0x10, 0x17, 0x10, 0x17, 0x10, 0x16, 0x11, 0x16, 0x10, 0x17, 0x11, 0x17, 0x10, 0x17, 0x11, 0x17, 0x11, 0x17, 0x10, 0x18, 0x11, 0x19, 0x12, 0x19, 0x12, 0x19, 0x12, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x12, 0x1A, 0x12, 0x1D, 0x16, 0x33, 0x23, 0x51, 0x2E, 0x3F, 0x23, 0x28, 0x1A, 0x21, 0x16, 0x1F, 0x15, 0x1D, 0x14, 0x1B, 0x13, 0x1B, 0x13, 0x1C, 0x13, 0x1A, 0x13, 0x1F, 0x19, 0x28, 0x20, 0x2E, 0x23, 0x32, 0x24, 0x2B, 0x1E, 0x21, 0x18, 0x1E, 0x15, 0x1B, 0x13, 0x1B, 0x13, 0x1B, 0x13, 0x1B, 0x13, 0x1B, 0x13, 0x1B, 0x13, 0x1A, 0x13, 0x1D, 0x15, 0x1D, 0x14, 0x1C, 0x13, 0x1A, 0x12, 0x18, 0x12, 0x1B, 0x12, 0x1A, 0x12, 0x19, 0x11, 0x19, 0x11, 0x18, 0x11, 0x19, 0x11, 0x18, 0x12, 0x18, 0x11, 0x1A, 0x12, 0x1C, 0x14, 0x1E, 0x15, 0x22, 0x17, 0x20, 0x16, 0x1C, 0x14, 0x1B, 0x13, 0x1B, 0x13, 0x1C, 0x13, 0x1C, 0x14, 0x1C, 0x13, 0x1B, 0x13, 0x1B, 0x13, 0x1B, 0x13, 0x1B, 0x12, 0x1B, 0x13, 0x1B, 0x13, 0x1C, 0x13, 0x1D, 0x14, 0x23, 0x16, 0x48, 0x1F, 0x59, 0x23, 0x61, 0x24, 0x4B, 0x20, 0x31, 0x1B, 0x4A, 0x22, 0x61, 0x25, 0x66, 0x27, 0x68, 0x27, 0x66, 0x27, 0x6B, 0x28, 0x6B, 0x28, 0x6A, 0x27, 0x66, 0x26, 0x64, 0x25, 0x65, 0x26, 0x66, 0x25, 0x66, 0x26, 0x6A, 0x27, 0x67, 0x27, 0x67, 0x26, 0x63, 0x25, 0x69, 0x27, 0x6E, 0x29, 0x6E, 0x28, 0x6C, 0x28, 0x69, 0x27, 0x6C, 0x28, 0x6B, 0x28, 0x6A, 0x28, 0x66, 0x26, 0x68, 0x27, 0x67, 0x26, 0x6A, 0x28, 0x6C, 0x28, 0x6B, 0x28, 0x6B, 0x27, 0x69, 0x28, 0x6A, 0x27, 0x68, 0x26, 0x66, 0x25, 0x69, 0x27, 0x6A, 0x27, 0x69, 0x27, 0x6B, 0x27, 0x65, 0x26, 0x66, 0x26, 0x64, 0x24, 0x62, 0x24, 0x67, 0x25, 0x63, 0x25, 0x65, 0x25, 0x61, 0x24, 0x65, 0x24, 0x64, 0x24, 0x66, 0x24, 0x61, 0x23, 0x60, 0x22, 0x61, 0x23, 0x64, 0x23, 0x63, 0x24, 0x68, 0x25, 0x65, 0x24, 0x67, 0x26, 0x65, 0x25, 0x67, 0x25, 0x65, 0x24, 0x66, 0x25, 0x60, 0x24, 0x62, 0x23, 0x63, 0x24, 0x63, 0x23, 0x62, 0x24, 0x64, 0x26, 0x61, 0x23, 0x61, 0x23, 0x60, 0x23, 0x61, 0x23, 0x5F, 0x23, 0x5F, 0x22, 0x60, 0x23, 0x62, 0x23, 0x60, 0x22, 0x61, 0x22, 0x5D, 0x22, 0x5F, 0x23, 0x62, 0x23, 0x5D, 0x22, 0x5F, 0x23, 0x5F, 0x23, 0x5E, 0x23, 0x62, 0x24, 0x5F, 0x23, 0x60, 0x23, 0x5D, 0x22, 0x61, 0x23, 0x5F, 0x23, 0x60, 0x24, 0x62, 0x24, 0x5D, 0x22, 0x5F, 0x23, 0x5F, 0x23, 0x72, 0x33, 0x75, 0x2E, 0x63, 0x24, 0x62, 0x23, 0x5C, 0x21, 0x5B, 0x20, 0x5D, 0x22, 0x61, 0x22, 0x5D, 0x22, 0x5C, 0x21, 0x5A, 0x21, 0x5D, 0x22, 0x63, 0x24, 0x5D, 0x22, 0x5F, 0x23, 0x60, 0x23, 0x5F, 0x23, 0x60, 0x25, 0x5B, 0x21, 0x5A, 0x22, 0x5D, 0x22, 0x5A, 0x22, 0x5C, 0x21, 0x5A, 0x21, 0x5B, 0x21, 0x5C, 0x21, 0x59, 0x21, 0x5A, 0x20, 0x58, 0x21, 0x56, 0x21, 0x5B, 0x23, 0x57, 0x21, 0x54, 0x20, 0x5D, 0x22, 0x59, 0x21, 0x57, 0x21, 0x59, 0x21, 0x56, 0x1F, 0x54, 0x1F, 0x58, 0x20, 0x56, 0x20, 0x57, 0x20, 0x49, 0x1E, 0x36, 0x1C, 0x2D, 0x1A, 0x31, 0x1B, 0x29, 0x19, 0x2D, 0x1A, 0x2A, 0x19, 0x2E, 0x19, 0x30, 0x1C, 0x35, 0x1D, 0x38, 0x1E, 0x37, 0x1E, 0x37, 0x1E, 0x41, 0x21, 0x3A, 0x1F, 0x39, 0x1E, 0x36, 0x1D, 0x31, 0x1D, 0x33, 0x1E, 0x3A, 0x22, 0x49, 0x2A, 0x48, 0x27, 0x42, 0x25, 0x40, 0x24, 0x37, 0x1F, 0x38, 0x1D, 0x2C, 0x1A, 0x34, 0x1C, 0x2B, 0x19, 0x36, 0x1D, 0x26, 0x17, 0x32, 0x1B, 0x32, 0x1C, 0x34, 0x1C, 0x2C, 0x19, 0x31, 0x1B, 0x33, 0x1D, 0x36, 0x1E, 0x37, 0x1E, 0x39, 0x1F, 0x37, 0x1E, 0x37, 0x1E, 0x2E, 0x1A, 0x38, 0x1E, 0x31, 0x1B, 0x2A, 0x19, 0x2D, 0x19
    },

    {
        0x60, 0x55, 0x60, 0x55, 0x5F, 0x55, 0x5F, 0x54, 0x5E, 0x53, 0x5E, 0x54, 0x62, 0x57, 0x63, 0x57, 0x62, 0x56, 0x61, 0x55, 0x63, 0x57, 0x64, 0x57, 0x62, 0x57, 0x5F, 0x55, 0x5B, 0x50, 0x4F, 0x44, 0x3E, 0x3A, 0x42, 0x43, 0x51, 0x4F, 0x58, 0x51, 0x55, 0x4B, 0x45, 0x3B, 0x2C, 0x27, 0x20, 0x1F, 0x1B, 0x1C, 0x18, 0x1A, 0x17, 0x18, 0x15, 0x18, 0x15, 0x18, 0x14, 0x18, 0x13, 0x17, 0x12, 0x16, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x13, 0x16, 0x13, 0x17, 0x13, 0x17, 0x14, 0x18, 0x16, 0x1B, 0x17, 0x1D, 0x17, 0x1C, 0x15, 0x19, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x14, 0x18, 0x13, 0x17, 0x12, 0x16, 0x12, 0x16, 0x13, 0x16, 0x13, 0x16, 0x12, 0x16, 0x12, 0x16, 0x12, 0x17, 0x12, 0x16, 0x13, 0x17, 0x13, 0x17, 0x12, 0x17, 0x14, 0x19, 0x15, 0x19, 0x14, 0x19, 0x14, 0x18, 0x13, 0x18, 0x14, 0x18, 0x13, 0x18, 0x14, 0x18, 0x15, 0x19, 0x18, 0x22, 0x23, 0x40, 0x30, 0x57, 0x2A, 0x40, 0x1F, 0x29, 0x1A, 0x22, 0x18, 0x1F, 0x17, 0x1D, 0x16, 0x1B, 0x16, 0x1B, 0x17, 0x1D, 0x15, 0x1B, 0x18, 0x22, 0x1B, 0x2A, 0x1D, 0x2F, 0x22, 0x36, 0x1F, 0x2D, 0x1A, 0x22, 0x17, 0x1D, 0x15, 0x1B, 0x16, 0x1B, 0x16, 0x1A, 0x16, 0x1B, 0x16, 0x1C, 0x16, 0x1A, 0x15, 0x19, 0x17, 0x1D, 0x16, 0x1B, 0x16, 0x1B, 0x15, 0x19, 0x14, 0x18, 0x15, 0x19, 0x15, 0x19, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x14, 0x19, 0x14, 0x18, 0x14, 0x18, 0x15, 0x1A, 0x18, 0x1D, 0x19, 0x1F, 0x1B, 0x21, 0x19, 0x1E, 0x18, 0x1C, 0x17, 0x1B, 0x16, 0x1B, 0x16, 0x1B, 0x16, 0x1C, 0x16, 0x1B, 0x16, 0x1B, 0x16, 0x1B, 0x17, 0x1C, 0x16, 0x1A, 0x16, 0x1B, 0x16, 0x1B, 0x17, 0x1C, 0x1A, 0x1D, 0x29, 0x2D, 0x53, 0x53, 0x61, 0x5B, 0x64, 0x5C, 0x45, 0x3C, 0x37, 0x34, 0x54, 0x55, 0x69, 0x63, 0x6F, 0x68, 0x72, 0x67, 0x72, 0x66, 0x78, 0x6B, 0x76, 0x69, 0x76, 0x6A, 0x73, 0x65, 0x6F, 0x63, 0x70, 0x66, 0x72, 0x66, 0x72, 0x65, 0x75, 0x69, 0x75, 0x68, 0x70, 0x65, 0x70, 0x64, 0x75, 0x6A, 0x7A, 0x6D, 0x78, 0x6C, 0x79, 0x6D, 0x76, 0x69, 0x78, 0x6B, 0x78, 0x6B, 0x78, 0x6A, 0x73, 0x66, 0x75, 0x67, 0x73, 0x65, 0x75, 0x6B, 0x78, 0x6C, 0x77, 0x6A, 0x78, 0x6B, 0x76, 0x6A, 0x77, 0x6C, 0x74, 0x68, 0x73, 0x66, 0x74, 0x69, 0x76, 0x6A, 0x77, 0x6A, 0x77, 0x6B, 0x74, 0x66, 0x74, 0x66, 0x72, 0x63, 0x70, 0x63, 0x75, 0x68, 0x71, 0x65, 0x72, 0x65, 0x70, 0x63, 0x71, 0x64, 0x71, 0x65, 0x74, 0x65, 0x6F, 0x61, 0x6D, 0x61, 0x6C, 0x61, 0x71, 0x64, 0x6E, 0x62, 0x76, 0x69, 0x74, 0x65, 0x76, 0x6A, 0x74, 0x65, 0x75, 0x66, 0x74, 0x65, 0x76, 0x66, 0x6F, 0x62, 0x6E, 0x60, 0x6F, 0x62, 0x71, 0x64, 0x71, 0x64, 0x70, 0x65, 0x71, 0x63, 0x70, 0x61, 0x6E, 0x61, 0x70, 0x62, 0x6E, 0x62, 0x6C, 0x60, 0x6C, 0x60, 0x6F, 0x61, 0x6D, 0x5F, 0x6E, 0x60, 0x6C, 0x5F, 0x6D, 0x60, 0x6F, 0x61, 0x6C, 0x5F, 0x6C, 0x60, 0x6C, 0x60, 0x6A, 0x61, 0x6D, 0x61, 0x6E, 0x61, 0x6C, 0x5F, 0x6A, 0x5E, 0x6C, 0x61, 0x6C, 0x60, 0x6F, 0x61, 0x70, 0x64, 0x6C, 0x5E, 0x6B, 0x60, 0x6A, 0x60, 0x78, 0x75, 0x79, 0x6E, 0x71, 0x62, 0x6E, 0x60, 0x69, 0x5C, 0x68, 0x5B, 0x69, 0x5F, 0x6E, 0x60, 0x6B, 0x5E, 0x69, 0x5C, 0x68, 0x5D, 0x6D, 0x5F, 0x6E, 0x62, 0x66, 0x5D, 0x6D, 0x61, 0x6B, 0x60, 0x69, 0x5D, 0x6B, 0x61, 0x65, 0x59, 0x64, 0x5A, 0x69, 0x5C, 0x68, 0x5D, 0x68, 0x5D, 0x66, 0x5C, 0x66, 0x5B, 0x65, 0x5C, 0x65, 0x5A, 0x66, 0x5A, 0x5F, 0x55, 0x61, 0x58, 0x65, 0x5A, 0x62, 0x57, 0x61, 0x57, 0x68, 0x5C, 0x64, 0x59, 0x61, 0x57, 0x65, 0x59, 0x5E, 0x54, 0x5F, 0x53, 0x62, 0x56, 0x61, 0x58, 0x64, 0x58, 0x4D, 0x45, 0x31, 0x32, 0x29, 0x2D, 0x2B, 0x2F, 0x27, 0x2A, 0x2B, 0x2E, 0x27, 0x2B, 0x2B, 0x31, 0x2D, 0x33, 0x33, 0x3D, 0x32, 0x39, 0x31, 0x3B, 0x32, 0x39, 0x39, 0x40, 0x33, 0x3B, 0x31, 0x36, 0x2F, 0x34, 0x2D, 0x32, 0x2C, 0x32, 0x34, 0x3D, 0x41, 0x4F, 0x3E, 0x48, 0x38, 0x40, 0x37, 0x3F, 0x32, 0x38, 0x31, 0x33, 0x27, 0x2C, 0x2C, 0x30, 0x28, 0x2C, 0x30, 0x34, 0x25, 0x28, 0x2C, 0x32, 0x2E, 0x37, 0x2D, 0x30, 0x2A, 0x2D, 0x2E, 0x35, 0x2F, 0x35, 0x32, 0x39, 0x32, 0x38, 0x2F, 0x35, 0x2F, 0x36, 0x2E, 0x32, 0x29, 0x2D, 0x31, 0x38, 0x2A, 0x2D, 0x27, 0x2D, 0x29, 0x2E
    },

    {
        0x58, 0x1F, 0x55, 0x1E, 0x54, 0x1E, 0x54, 0x1D, 0x53, 0x1E, 0x56, 0x1E, 0x57, 0x1F, 0x59, 0x1F, 0x58, 0x1E, 0x57, 0x1E, 0x56, 0x1F, 0x58, 0x1F, 0x57, 0x1F, 0x57, 0x1F, 0x55, 0x1F, 0x51, 0x1F, 0x49, 0x1E, 0x3D, 0x1D, 0x3F, 0x1C, 0x4D, 0x1D, 0x52, 0x1E, 0x4E, 0x1C, 0x3E, 0x18, 0x29, 0x14, 0x1F, 0x12, 0x1C, 0x11, 0x1A, 0x11, 0x19, 0x10, 0x18, 0x10, 0x18, 0x10, 0x17, 0x0F, 0x16, 0x0F, 0x16, 0x10, 0x16, 0x0F, 0x17, 0x10, 0x17, 0x0F, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x1A, 0x12, 0x1C, 0x13, 0x1E, 0x15, 0x1C, 0x13, 0x19, 0x11, 0x18, 0x10, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x17, 0x10, 0x17, 0x10, 0x16, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x11, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x18, 0x10, 0x18, 0x11, 0x1A, 0x12, 0x19, 0x12, 0x19, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x19, 0x12, 0x1D, 0x15, 0x30, 0x22, 0x54, 0x31, 0x62, 0x35, 0x60, 0x32, 0x48, 0x26, 0x2C, 0x1A, 0x22, 0x16, 0x1F, 0x15, 0x1E, 0x15, 0x20, 0x17, 0x20, 0x15, 0x1F, 0x18, 0x29, 0x20, 0x2E, 0x23, 0x31, 0x25, 0x35, 0x28, 0x37, 0x29, 0x33, 0x22, 0x22, 0x17, 0x1C, 0x13, 0x1A, 0x12, 0x1A, 0x12, 0x1A, 0x12, 0x1A, 0x12, 0x1A, 0x12, 0x1A, 0x12, 0x1A, 0x12, 0x1A, 0x12, 0x1A, 0x11, 0x18, 0x11, 0x18, 0x11, 0x19, 0x11, 0x19, 0x12, 0x19, 0x11, 0x18, 0x11, 0x19, 0x11, 0x1A, 0x12, 0x19, 0x11, 0x1A, 0x12, 0x1B, 0x13, 0x20, 0x16, 0x1F, 0x15, 0x1D, 0x15, 0x1D, 0x14, 0x1D, 0x13, 0x1B, 0x12, 0x1B, 0x13, 0x1B, 0x12, 0x1A, 0x13, 0x1B, 0x12, 0x1B, 0x12, 0x1C, 0x13, 0x1D, 0x14, 0x1C, 0x13, 0x1C, 0x12, 0x1C, 0x13, 0x1C, 0x12, 0x22, 0x16, 0x43, 0x1F, 0x61, 0x24, 0x60, 0x26, 0x4E, 0x1F, 0x30, 0x1A, 0x46, 0x21, 0x62, 0x27, 0x66, 0x27, 0x68, 0x27, 0x6B, 0x28, 0x69, 0x27, 0x67, 0x26, 0x6B, 0x28, 0x69, 0x27, 0x69, 0x26, 0x66, 0x26, 0x65, 0x26, 0x67, 0x26, 0x68, 0x25, 0x67, 0x26, 0x68, 0x27, 0x66, 0x26, 0x66, 0x25, 0x68, 0x27, 0x6C, 0x28, 0x69, 0x27, 0x6A, 0x28, 0x68, 0x27, 0x67, 0x27, 0x6B, 0x27, 0x6A, 0x27, 0x69, 0x27, 0x6A, 0x27, 0x68, 0x26, 0x67, 0x26, 0x6B, 0x27, 0x6A, 0x27, 0x6A, 0x26, 0x69, 0x26, 0x69, 0x26, 0x68, 0x26, 0x66, 0x27, 0x67, 0x27, 0x68, 0x26, 0x6A, 0x27, 0x69, 0x26, 0x68, 0x26, 0x66, 0x26, 0x67, 0x26, 0x67, 0x25, 0x65, 0x25, 0x68, 0x26, 0x63, 0x24, 0x62, 0x24, 0x63, 0x24, 0x62, 0x23, 0x62, 0x23, 0x64, 0x23, 0x65, 0x24, 0x64, 0x24, 0x64, 0x24, 0x64, 0x24, 0x68, 0x25, 0x6B, 0x26, 0x6C, 0x26, 0x66, 0x24, 0x66, 0x24, 0x66, 0x25, 0x69, 0x25, 0x64, 0x24, 0x61, 0x23, 0x5F, 0x22, 0x61, 0x24, 0x63, 0x24, 0x65, 0x24, 0x65, 0x24, 0x5E, 0x21, 0x63, 0x23, 0x60, 0x24, 0x64, 0x24, 0x5F, 0x23, 0x5E, 0x22, 0x5F, 0x22, 0x5A, 0x20, 0x5C, 0x22, 0x61, 0x23, 0x5E, 0x23, 0x63, 0x24, 0x5F, 0x23, 0x61, 0x24, 0x61, 0x24, 0x5E, 0x23, 0x61, 0x23, 0x5F, 0x22, 0x60, 0x23, 0x5C, 0x22, 0x5F, 0x23, 0x61, 0x24, 0x5F, 0x23, 0x61, 0x24, 0x64, 0x24, 0x62, 0x23, 0x5B, 0x21, 0x62, 0x24, 0x62, 0x23, 0x61, 0x24, 0x60, 0x23, 0x5C, 0x22, 0x5A, 0x20, 0x5B, 0x21, 0x5A, 0x21, 0x5C, 0x21, 0x5E, 0x22, 0x5F, 0x23, 0x5B, 0x22, 0x5F, 0x22, 0x5D, 0x23, 0x61, 0x24, 0x5C, 0x22, 0x5F, 0x22, 0x5D, 0x22, 0x58, 0x20, 0x5A, 0x21, 0x5B, 0x20, 0x5B, 0x22, 0x5D, 0x22, 0x5C, 0x22, 0x5C, 0x21, 0x59, 0x20, 0x5A, 0x21, 0x59, 0x20, 0x54, 0x1F, 0x56, 0x20, 0x5A, 0x21, 0x59, 0x21, 0x59, 0x21, 0x58, 0x20, 0x5B, 0x22, 0x59, 0x20, 0x5A, 0x20, 0x5A, 0x21, 0x57, 0x1F, 0x57, 0x20, 0x57, 0x20, 0x59, 0x20, 0x47, 0x1D, 0x2E, 0x18, 0x2D, 0x1A, 0x2E, 0x1A, 0x30, 0x1C, 0x3D, 0x20, 0x3C, 0x21, 0x3C, 0x20, 0x3E, 0x20, 0x41, 0x22, 0x3A, 0x1E, 0x39, 0x1E, 0x36, 0x1C, 0x32, 0x1B, 0x2F, 0x1A, 0x2C, 0x18, 0x35, 0x1E, 0x30, 0x1A, 0x31, 0x1C, 0x36, 0x1D, 0x38, 0x1E, 0x32, 0x1B, 0x2A, 0x19, 0x32, 0x1B, 0x34, 0x1D, 0x2F, 0x19, 0x32, 0x1B, 0x30, 0x1B, 0x34, 0x1D, 0x3B, 0x1F, 0x2F, 0x1A, 0x3A, 0x1F, 0x3A, 0x1F, 0x36, 0x1D, 0x33, 0x1C, 0x41, 0x23, 0x2F, 0x1A, 0x37, 0x1E, 0x2C, 0x18, 0x2C, 0x19, 0x2D, 0x1A, 0x2F, 0x1A, 0x2E, 0x1B, 0x32, 0x1B, 0x30, 0x1A, 0x2E, 0x1A, 0x38, 0x1D
    },

    {
        0x62, 0x56, 0x60, 0x55, 0x60, 0x55, 0x5E, 0x53, 0x5E, 0x53, 0x5F, 0x55, 0x62, 0x56, 0x65, 0x57, 0x64, 0x57, 0x63, 0x55, 0x63, 0x55, 0x64, 0x56, 0x62, 0x56, 0x62, 0x57, 0x61, 0x55, 0x5D, 0x52, 0x54, 0x4A, 0x44, 0x3C, 0x3E, 0x3D, 0x4D, 0x4A, 0x5A, 0x53, 0x58, 0x4F, 0x4B, 0x40, 0x31, 0x2B, 0x22, 0x21, 0x1C, 0x1C, 0x18, 0x1A, 0x17, 0x19, 0x16, 0x18, 0x15, 0x18, 0x14, 0x17, 0x14, 0x17, 0x12, 0x16, 0x13, 0x16, 0x13, 0x16, 0x12, 0x16, 0x13, 0x16, 0x13, 0x16, 0x13, 0x17, 0x14, 0x17, 0x14, 0x19, 0x15, 0x1B, 0x18, 0x1E, 0x18, 0x1C, 0x15, 0x19, 0x14, 0x17, 0x14, 0x18, 0x14, 0x18, 0x13, 0x18, 0x13, 0x16, 0x13, 0x16, 0x12, 0x16, 0x13, 0x17, 0x13, 0x17, 0x12, 0x16, 0x13, 0x17, 0x13, 0x16, 0x13, 0x16, 0x13, 0x17, 0x13, 0x17, 0x14, 0x17, 0x14, 0x18, 0x14, 0x19, 0x14, 0x19, 0x14, 0x19, 0x13, 0x18, 0x14, 0x18, 0x14, 0x18, 0x14, 0x19, 0x18, 0x21, 0x21, 0x3D, 0x30, 0x5A, 0x34, 0x62, 0x36, 0x62, 0x2E, 0x4B, 0x21, 0x2E, 0x1A, 0x22, 0x18, 0x1F, 0x18, 0x1F, 0x1B, 0x22, 0x19, 0x1E, 0x18, 0x22, 0x1C, 0x2B, 0x1D, 0x2F, 0x1F, 0x32, 0x20, 0x32, 0x21, 0x36, 0x21, 0x34, 0x1A, 0x22, 0x16, 0x1C, 0x15, 0x1A, 0x15, 0x1A, 0x15, 0x19, 0x15, 0x19, 0x15, 0x19, 0x15, 0x19, 0x15, 0x19, 0x15, 0x19, 0x15, 0x19, 0x14, 0x17, 0x14, 0x18, 0x14, 0x19, 0x15, 0x1A, 0x15, 0x18, 0x14, 0x18, 0x14, 0x18, 0x15, 0x19, 0x15, 0x1A, 0x16, 0x1B, 0x18, 0x1C, 0x1A, 0x21, 0x1A, 0x1F, 0x18, 0x1D, 0x18, 0x1D, 0x18, 0x1C, 0x17, 0x1B, 0x17, 0x1B, 0x16, 0x1A, 0x16, 0x1A, 0x16, 0x1A, 0x17, 0x1B, 0x17, 0x1B, 0x17, 0x1D, 0x17, 0x1D, 0x17, 0x1C, 0x17, 0x1B, 0x1A, 0x1C, 0x27, 0x2A, 0x4B, 0x4F, 0x67, 0x62, 0x67, 0x62, 0x4C, 0x3F, 0x34, 0x32, 0x50, 0x51, 0x69, 0x65, 0x6F, 0x66, 0x74, 0x68, 0x75, 0x69, 0x75, 0x6A, 0x76, 0x68, 0x78, 0x6B, 0x77, 0x6A, 0x75, 0x68, 0x72, 0x66, 0x70, 0x65, 0x72, 0x67, 0x77, 0x69, 0x73, 0x67, 0x75, 0x67, 0x72, 0x66, 0x74, 0x66, 0x73, 0x68, 0x76, 0x6A, 0x75, 0x68, 0x78, 0x6A, 0x75, 0x68, 0x71, 0x67, 0x77, 0x6A, 0x76, 0x69, 0x78, 0x6A, 0x79, 0x6C, 0x77, 0x69, 0x76, 0x69, 0x78, 0x6B, 0x78, 0x6B, 0x77, 0x6A, 0x77, 0x69, 0x77, 0x68, 0x74, 0x67, 0x71, 0x66, 0x75, 0x69, 0x73, 0x67, 0x75, 0x69, 0x75, 0x68, 0x74, 0x68, 0x75, 0x67, 0x76, 0x68, 0x75, 0x68, 0x72, 0x63, 0x76, 0x69, 0x6D, 0x60, 0x70, 0x64, 0x75, 0x64, 0x70, 0x63, 0x71, 0x63, 0x72, 0x63, 0x73, 0x65, 0x71, 0x63, 0x72, 0x65, 0x73, 0x65, 0x75, 0x67, 0x79, 0x6B, 0x7A, 0x6C, 0x76, 0x67, 0x76, 0x66, 0x74, 0x67, 0x76, 0x69, 0x72, 0x64, 0x71, 0x62, 0x6C, 0x5F, 0x6E, 0x60, 0x71, 0x63, 0x73, 0x65, 0x74, 0x64, 0x6F, 0x60, 0x71, 0x63, 0x70, 0x61, 0x6F, 0x62, 0x6D, 0x5F, 0x6B, 0x60, 0x6F, 0x5F, 0x67, 0x5A, 0x69, 0x5E, 0x6C, 0x5F, 0x6C, 0x60, 0x72, 0x64, 0x6B, 0x5E, 0x6E, 0x62, 0x6B, 0x5F, 0x6B, 0x5F, 0x6D, 0x61, 0x6D, 0x60, 0x6D, 0x60, 0x68, 0x5C, 0x6A, 0x60, 0x6E, 0x62, 0x6D, 0x5F, 0x6D, 0x62, 0x6F, 0x63, 0x6F, 0x61, 0x69, 0x5D, 0x6F, 0x61, 0x6C, 0x61, 0x6D, 0x61, 0x6D, 0x61, 0x69, 0x5D, 0x68, 0x5C, 0x66, 0x5B, 0x66, 0x5C, 0x6B, 0x5D, 0x6C, 0x60, 0x6B, 0x60, 0x69, 0x5B, 0x6D, 0x5F, 0x6A, 0x5E, 0x6C, 0x60, 0x66, 0x5B, 0x6B, 0x5E, 0x6A, 0x5E, 0x62, 0x57, 0x6A, 0x5C, 0x66, 0x5A, 0x66, 0x5D, 0x67, 0x5D, 0x67, 0x5C, 0x68, 0x5C, 0x62, 0x58, 0x65, 0x59, 0x63, 0x59, 0x5F, 0x55, 0x63, 0x58, 0x68, 0x5C, 0x66, 0x59, 0x65, 0x59, 0x66, 0x58, 0x66, 0x5C, 0x65, 0x58, 0x65, 0x58, 0x66, 0x5B, 0x65, 0x58, 0x64, 0x57, 0x61, 0x57, 0x61, 0x57, 0x4A, 0x41, 0x2D, 0x2C, 0x2B, 0x2E, 0x2B, 0x30, 0x2F, 0x39, 0x37, 0x3D, 0x39, 0x42, 0x36, 0x3D, 0x35, 0x3B, 0x35, 0x3C, 0x32, 0x37, 0x33, 0x3A, 0x2F, 0x32, 0x2A, 0x2D, 0x28, 0x2D, 0x26, 0x29, 0x30, 0x35, 0x29, 0x2B, 0x2B, 0x31, 0x2F, 0x35, 0x2F, 0x34, 0x2C, 0x2F, 0x27, 0x2B, 0x2D, 0x31, 0x30, 0x38, 0x2E, 0x30, 0x2F, 0x34, 0x2D, 0x33, 0x32, 0x39, 0x36, 0x3D, 0x2C, 0x2F, 0x33, 0x3B, 0x33, 0x39, 0x30, 0x35, 0x2D, 0x31, 0x37, 0x3F, 0x2A, 0x2E, 0x32, 0x37, 0x26, 0x2A, 0x2B, 0x2F, 0x2A, 0x2F, 0x2D, 0x30, 0x2B, 0x31, 0x2B, 0x30, 0x2F, 0x34, 0x2B, 0x30, 0x33, 0x37
    },

    {
        0x56, 0x1F, 0x55, 0x1E, 0x56, 0x1F, 0x57, 0x1F, 0x57, 0x1E, 0x56, 0x1F, 0x56, 0x1E, 0x58, 0x1F, 0x58, 0x1F, 0x57, 0x1E, 0x58, 0x1F, 0x56, 0x1F, 0x57, 0x1F, 0x58, 0x1F, 0x57, 0x20, 0x57, 0x1F, 0x52, 0x1E, 0x49, 0x1D, 0x3A, 0x1A, 0x3A, 0x1B, 0x49, 0x1D, 0x51, 0x1E, 0x4F, 0x1D, 0x41, 0x19, 0x2C, 0x15, 0x20, 0x13, 0x1D, 0x11, 0x1A, 0x10, 0x1A, 0x10, 0x19, 0x10, 0x18, 0x10, 0x17, 0x10, 0x18, 0x11, 0x18, 0x10, 0x17, 0x10, 0x16, 0x0F, 0x16, 0x15, 0x17, 0x10, 0x16, 0x10, 0x16, 0x10, 0x17, 0x10, 0x19, 0x11, 0x19, 0x12, 0x1B, 0x13, 0x1E, 0x14, 0x1C, 0x13, 0x18, 0x11, 0x17, 0x11, 0x17, 0x11, 0x17, 0x10, 0x17, 0x11, 0x16, 0x10, 0x17, 0x11, 0x18, 0x11, 0x16, 0x10, 0x17, 0x10, 0x17, 0x11, 0x17, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x1A, 0x12, 0x1A, 0x12, 0x1A, 0x12, 0x1A, 0x12, 0x19, 0x11, 0x19, 0x11, 0x19, 0x12, 0x1C, 0x14, 0x2D, 0x1F, 0x50, 0x2E, 0x5F, 0x34, 0x66, 0x38, 0x6B, 0x39, 0x6A, 0x37, 0x53, 0x2A, 0x2F, 0x1B, 0x24, 0x17, 0x21, 0x17, 0x23, 0x18, 0x22, 0x19, 0x2A, 0x20, 0x2D, 0x22, 0x2F, 0x24, 0x32, 0x25, 0x32, 0x25, 0x32, 0x25, 0x32, 0x25, 0x2D, 0x1F, 0x22, 0x17, 0x1C, 0x14, 0x1B, 0x13, 0x19, 0x12, 0x19, 0x11, 0x19, 0x12, 0x18, 0x11, 0x18, 0x11, 0x19, 0x13, 0x1A, 0x12, 0x19, 0x12, 0x19, 0x11, 0x19, 0x12, 0x19, 0x12, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x1A, 0x11, 0x19, 0x12, 0x1C, 0x13, 0x1B, 0x13, 0x1E, 0x16, 0x21, 0x16, 0x1D, 0x15, 0x1C, 0x14, 0x1C, 0x14, 0x1B, 0x13, 0x1B, 0x13, 0x1C, 0x13, 0x1B, 0x12, 0x1B, 0x13, 0x1C, 0x13, 0x1B, 0x12, 0x1C, 0x13, 0x1C, 0x13, 0x1C, 0x13, 0x1C, 0x13, 0x20, 0x15, 0x42, 0x1E, 0x5D, 0x24, 0x63, 0x25, 0x54, 0x22, 0x33, 0x1B, 0x45, 0x20, 0x5B, 0x24, 0x66, 0x26, 0x66, 0x26, 0x6A, 0x28, 0x69, 0x27, 0x6B, 0x28, 0x69, 0x27, 0x6C, 0x28, 0x6B, 0x28, 0x68, 0x26, 0x69, 0x27, 0x64, 0x25, 0x64, 0x26, 0x67, 0x27, 0x66, 0x26, 0x6A, 0x27, 0x68, 0x26, 0x68, 0x26, 0x65, 0x26, 0x66, 0x27, 0x6A, 0x28, 0x68, 0x28, 0x6C, 0x28, 0x68, 0x27, 0x67, 0x26, 0x68, 0x27, 0x6A, 0x28, 0x6C, 0x27, 0x6C, 0x27, 0x6A, 0x28, 0x6E, 0x28, 0x6B, 0x28, 0x69, 0x28, 0x6C, 0x28, 0x68, 0x26, 0x64, 0x25, 0x65, 0x26, 0x63, 0x26, 0x64, 0x25, 0x67, 0x26, 0x67, 0x26, 0x69, 0x26, 0x65, 0x25, 0x62, 0x24, 0x63, 0x24, 0x5F, 0x23, 0x61, 0x24, 0x62, 0x23, 0x62, 0x24, 0x63, 0x25, 0x62, 0x24, 0x62, 0x22, 0x63, 0x23, 0x61, 0x23, 0x63, 0x24, 0x65, 0x24, 0x62, 0x24, 0x67, 0x25, 0x63, 0x23, 0x64, 0x24, 0x66, 0x24, 0x65, 0x25, 0x65, 0x25, 0x6A, 0x27, 0x68, 0x26, 0x62, 0x23, 0x62, 0x24, 0x62, 0x24, 0x63, 0x23, 0x63, 0x24, 0x66, 0x24, 0x61, 0x23, 0x5E, 0x22, 0x60, 0x23, 0x5E, 0x22, 0x5E, 0x22, 0x61, 0x22, 0x5B, 0x20, 0x5C, 0x21, 0x5C, 0x21, 0x5D, 0x22, 0x5C, 0x22, 0x60, 0x24, 0x5E, 0x23, 0x5D, 0x22, 0x61, 0x25, 0x5F, 0x23, 0x5C, 0x22, 0x61, 0x23, 0x5F, 0x23, 0x5B, 0x23, 0x5C, 0x22, 0x62, 0x24, 0x62, 0x25, 0x61, 0x24, 0x62, 0x24, 0x5C, 0x22, 0x5F, 0x23, 0x60, 0x23, 0x61, 0x24, 0x5F, 0x23, 0x61, 0x24, 0x61, 0x24, 0x60, 0x23, 0x5E, 0x23, 0x5B, 0x21, 0x5D, 0x21, 0x5A, 0x21, 0x5E, 0x22, 0x5C, 0x22, 0x5D, 0x23, 0x5B, 0x22, 0x5A, 0x22, 0x5A, 0x21, 0x5E, 0x23, 0x5B, 0x22, 0x5B, 0x22, 0x5C, 0x22, 0x5B, 0x21, 0x59, 0x21, 0x5C, 0x21, 0x58, 0x21, 0x5C, 0x22, 0x59, 0x21, 0x57, 0x21, 0x55, 0x20, 0x56, 0x20, 0x58, 0x21, 0x5A, 0x21, 0x59, 0x21, 0x59, 0x21, 0x5B, 0x21, 0x58, 0x21, 0x5B, 0x21, 0x58, 0x21, 0x59, 0x20, 0x58, 0x20, 0x57, 0x20, 0x55, 0x20, 0x57, 0x1F, 0x46, 0x1D, 0x33, 0x1B, 0x30, 0x1C, 0x3B, 0x1F, 0x3A, 0x20, 0x35, 0x1C, 0x36, 0x1D, 0x35, 0x1D, 0x30, 0x1B, 0x2F, 0x1B, 0x2D, 0x19, 0x33, 0x1C, 0x2C, 0x19, 0x28, 0x18, 0x2E, 0x1A, 0x2E, 0x1B, 0x32, 0x1B, 0x2F, 0x1C, 0x34, 0x1C, 0x34, 0x1C, 0x2C, 0x19, 0x2E, 0x1A, 0x2C, 0x1A, 0x34, 0x1C, 0x37, 0x1F, 0x35, 0x1D, 0x2E, 0x19, 0x38, 0x1E, 0x33, 0x1C, 0x3D, 0x20, 0x2D, 0x1A, 0x36, 0x1D, 0x2B, 0x19, 0x34, 0x1C, 0x2D, 0x1A, 0x35, 0x1D, 0x2F, 0x1B, 0x39, 0x1F, 0x37, 0x1E, 0x36, 0x1C, 0x32, 0x1C, 0x38, 0x1E, 0x35, 0x1D, 0x37, 0x1F, 0x37, 0x1D, 0x34, 0x1C, 0x31, 0x1B
    },

    {
        0x60, 0x55, 0x60, 0x55, 0x61, 0x56, 0x63, 0x57, 0x62, 0x56, 0x61, 0x56, 0x62, 0x56, 0x63, 0x57, 0x64, 0x57, 0x62, 0x57, 0x64, 0x57, 0x62, 0x55, 0x62, 0x57, 0x62, 0x57, 0x62, 0x56, 0x63, 0x57, 0x5E, 0x52, 0x55, 0x4A, 0x45, 0x3C, 0x3C, 0x39, 0x49, 0x48, 0x57, 0x50, 0x58, 0x4E, 0x4C, 0x42, 0x35, 0x2E, 0x22, 0x21, 0x1C, 0x1D, 0x19, 0x1B, 0x17, 0x19, 0x16, 0x19, 0x15, 0x18, 0x14, 0x17, 0x14, 0x17, 0x13, 0x17, 0x13, 0x16, 0x12, 0x16, 0x12, 0x16, 0x13, 0x16, 0x13, 0x16, 0x13, 0x16, 0x13, 0x17, 0x13, 0x18, 0x14, 0x19, 0x15, 0x1A, 0x17, 0x1D, 0x17, 0x1C, 0x15, 0x19, 0x13, 0x17, 0x13, 0x17, 0x13, 0x16, 0x13, 0x17, 0x12, 0x16, 0x13, 0x17, 0x13, 0x17, 0x13, 0x16, 0x13, 0x16, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x15, 0x18, 0x14, 0x18, 0x15, 0x1A, 0x15, 0x1A, 0x15, 0x19, 0x14, 0x18, 0x13, 0x19, 0x14, 0x19, 0x16, 0x1E, 0x1F, 0x38, 0x2E, 0x57, 0x33, 0x5E, 0x36, 0x66, 0x38, 0x69, 0x38, 0x68, 0x31, 0x54, 0x22, 0x30, 0x1A, 0x24, 0x19, 0x21, 0x1A, 0x22, 0x19, 0x25, 0x1C, 0x2C, 0x1D, 0x2C, 0x1D, 0x2E, 0x1F, 0x32, 0x1F, 0x32, 0x1F, 0x31, 0x1F, 0x30, 0x1D, 0x2C, 0x1A, 0x22, 0x16, 0x1D, 0x15, 0x1A, 0x14, 0x19, 0x14, 0x18, 0x14, 0x19, 0x15, 0x19, 0x14, 0x18, 0x15, 0x19, 0x15, 0x1A, 0x15, 0x19, 0x14, 0x19, 0x14, 0x18, 0x15, 0x18, 0x14, 0x18, 0x15, 0x19, 0x15, 0x19, 0x15, 0x19, 0x15, 0x19, 0x17, 0x1C, 0x16, 0x1B, 0x17, 0x1E, 0x1A, 0x1E, 0x18, 0x1D, 0x18, 0x1C, 0x17, 0x1C, 0x16, 0x1B, 0x17, 0x1C, 0x17, 0x1C, 0x16, 0x1A, 0x16, 0x1B, 0x17, 0x1B, 0x16, 0x1B, 0x17, 0x1C, 0x17, 0x1C, 0x18, 0x1B, 0x1A, 0x1C, 0x25, 0x29, 0x4B, 0x4E, 0x66, 0x5F, 0x67, 0x60, 0x4F, 0x44, 0x35, 0x34, 0x50, 0x50, 0x64, 0x5D, 0x6E, 0x66, 0x70, 0x65, 0x75, 0x6B, 0x73, 0x69, 0x76, 0x6A, 0x75, 0x6A, 0x77, 0x6B, 0x77, 0x6A, 0x74, 0x67, 0x74, 0x68, 0x70, 0x64, 0x70, 0x65, 0x72, 0x67, 0x73, 0x68, 0x77, 0x6A, 0x73, 0x66, 0x73, 0x64, 0x71, 0x65, 0x72, 0x67, 0x77, 0x6B, 0x75, 0x68, 0x79, 0x6B, 0x75, 0x69, 0x73, 0x66, 0x75, 0x68, 0x77, 0x6B, 0x79, 0x6C, 0x78, 0x6A, 0x77, 0x6C, 0x79, 0x6C, 0x77, 0x6B, 0x75, 0x6A, 0x79, 0x6B, 0x77, 0x67, 0x6F, 0x64, 0x70, 0x65, 0x70, 0x63, 0x73, 0x65, 0x73, 0x65, 0x76, 0x68, 0x76, 0x67, 0x74, 0x65, 0x6F, 0x63, 0x70, 0x64, 0x6C, 0x5F, 0x6D, 0x60, 0x6F, 0x63, 0x71, 0x63, 0x71, 0x63, 0x70, 0x61, 0x71, 0x61, 0x73, 0x65, 0x70, 0x63, 0x70, 0x64, 0x73, 0x65, 0x6E, 0x63, 0x74, 0x68, 0x70, 0x61, 0x72, 0x63, 0x73, 0x66, 0x74, 0x69, 0x73, 0x66, 0x78, 0x6B, 0x75, 0x67, 0x71, 0x62, 0x70, 0x65, 0x71, 0x65, 0x71, 0x63, 0x6F, 0x63, 0x71, 0x63, 0x70, 0x62, 0x6C, 0x5E, 0x6E, 0x60, 0x6B, 0x5F, 0x69, 0x5E, 0x6D, 0x61, 0x68, 0x5B, 0x6B, 0x5D, 0x69, 0x5C, 0x6B, 0x5F, 0x6D, 0x5F, 0x6E, 0x60, 0x6D, 0x61, 0x68, 0x5D, 0x6B, 0x5F, 0x6B, 0x5F, 0x6A, 0x5F, 0x71, 0x63, 0x6F, 0x62, 0x69, 0x5E, 0x68, 0x5C, 0x6E, 0x63, 0x6D, 0x61, 0x6E, 0x63, 0x6E, 0x61, 0x69, 0x5B, 0x6C, 0x61, 0x6D, 0x60, 0x6D, 0x61, 0x6D, 0x61, 0x6D, 0x62, 0x6C, 0x61, 0x6B, 0x5F, 0x6B, 0x5E, 0x68, 0x5C, 0x6A, 0x5C, 0x67, 0x5B, 0x6C, 0x5E, 0x69, 0x5D, 0x6C, 0x60, 0x69, 0x5E, 0x67, 0x5C, 0x66, 0x5B, 0x68, 0x5D, 0x6A, 0x5E, 0x68, 0x5E, 0x6A, 0x5F, 0x67, 0x5A, 0x63, 0x5A, 0x68, 0x5B, 0x65, 0x5A, 0x69, 0x5C, 0x68, 0x5C, 0x61, 0x57, 0x61, 0x57, 0x62, 0x57, 0x64, 0x5A, 0x66, 0x5A, 0x65, 0x59, 0x65, 0x5A, 0x69, 0x5C, 0x65, 0x59, 0x68, 0x5D, 0x64, 0x59, 0x64, 0x58, 0x65, 0x5A, 0x63, 0x56, 0x60, 0x58, 0x62, 0x55, 0x4B, 0x43, 0x31, 0x32, 0x2D, 0x35, 0x35, 0x3A, 0x31, 0x36, 0x2C, 0x30, 0x2B, 0x30, 0x2D, 0x33, 0x2A, 0x2B, 0x2A, 0x2F, 0x29, 0x2D, 0x2E, 0x33, 0x27, 0x2A, 0x26, 0x2A, 0x2C, 0x30, 0x2C, 0x32, 0x2A, 0x2E, 0x2E, 0x36, 0x2F, 0x35, 0x2F, 0x33, 0x28, 0x2E, 0x2A, 0x2E, 0x28, 0x2D, 0x30, 0x34, 0x30, 0x38, 0x2F, 0x32, 0x2A, 0x2E, 0x31, 0x37, 0x2E, 0x34, 0x36, 0x3A, 0x28, 0x2C, 0x2E, 0x33, 0x28, 0x2C, 0x30, 0x34, 0x2B, 0x30, 0x30, 0x35, 0x2B, 0x31, 0x33, 0x3A, 0x34, 0x3A, 0x2E, 0x30, 0x2C, 0x33, 0x30, 0x36, 0x2F, 0x34, 0x33, 0x3A, 0x30, 0x33, 0x2F, 0x36, 0x2C, 0x2F
    },

    {
        0x55, 0x1E, 0x55, 0x1E, 0x56, 0x1F, 0x57, 0x1E, 0x57, 0x1F, 0x57, 0x1F, 0x57, 0x1F, 0x59, 0x20, 0x58, 0x1F, 0x59, 0x1E, 0x59, 0x1F, 0x58, 0x1F, 0x57, 0x1F, 0x58, 0x1F, 0x59, 0x20, 0x59, 0x20, 0x57, 0x1F, 0x54, 0x1F, 0x4F, 0x1E, 0x3E, 0x1B, 0x38, 0x1A, 0x46, 0x1D, 0x51, 0x1E, 0x4F, 0x1D, 0x43, 0x1A, 0x2F, 0x16, 0x22, 0x13, 0x1D, 0x11, 0x1B, 0x11, 0x19, 0x10, 0x18, 0x10, 0x18, 0x10, 0x18, 0x11, 0x18, 0x11, 0x17, 0x10, 0x16, 0x10, 0x16, 0x10, 0x16, 0x10, 0x17, 0x10, 0x16, 0x10, 0x17, 0x10, 0x17, 0x10, 0x18, 0x11, 0x17, 0x11, 0x18, 0x11, 0x19, 0x12, 0x1B, 0x13, 0x1B, 0x12, 0x19, 0x11, 0x17, 0x10, 0x18, 0x11, 0x17, 0x10, 0x18, 0x11, 0x17, 0x10, 0x18, 0x11, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x18, 0x12, 0x19, 0x12, 0x19, 0x11, 0x18, 0x11, 0x18, 0x11, 0x19, 0x11, 0x19, 0x11, 0x19, 0x11, 0x19, 0x11, 0x1B, 0x13, 0x28, 0x1C, 0x4A, 0x2B, 0x5D, 0x33, 0x64, 0x35, 0x68, 0x37, 0x6D, 0x3A, 0x6C, 0x3A, 0x69, 0x37, 0x56, 0x2C, 0x34, 0x1C, 0x24, 0x17, 0x22, 0x19, 0x2B, 0x1F, 0x2D, 0x21, 0x2E, 0x22, 0x2F, 0x23, 0x30, 0x23, 0x31, 0x24, 0x31, 0x24, 0x31, 0x24, 0x31, 0x24, 0x2E, 0x20, 0x26, 0x1A, 0x1C, 0x14, 0x19, 0x12, 0x18, 0x11, 0x19, 0x12, 0x19, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x19, 0x11, 0x18, 0x11, 0x1A, 0x12, 0x19, 0x11, 0x18, 0x11, 0x19, 0x12, 0x1A, 0x12, 0x1B, 0x12, 0x1A, 0x12, 0x1B, 0x12, 0x1A, 0x12, 0x1A, 0x12, 0x1C, 0x14, 0x20, 0x15, 0x1C, 0x13, 0x1B, 0x13, 0x1C, 0x13, 0x1D, 0x14, 0x1C, 0x14, 0x1C, 0x14, 0x1B, 0x13, 0x1B, 0x12, 0x1B, 0x12, 0x1B, 0x13, 0x1B, 0x12, 0x1B, 0x12, 0x21, 0x15, 0x44, 0x1F, 0x5E, 0x24, 0x5E, 0x23, 0x50, 0x20, 0x35, 0x1B, 0x44, 0x20, 0x5D, 0x25, 0x60, 0x24, 0x65, 0x27, 0x68, 0x28, 0x6B, 0x28, 0x6A, 0x27, 0x65, 0x27, 0x67, 0x27, 0x68, 0x27, 0x69, 0x27, 0x66, 0x27, 0x67, 0x26, 0x67, 0x27, 0x67, 0x26, 0x65, 0x26, 0x66, 0x25, 0x69, 0x26, 0x63, 0x24, 0x61, 0x25, 0x66, 0x26, 0x69, 0x26, 0x67, 0x26, 0x6A, 0x27, 0x68, 0x27, 0x6B, 0x27, 0x6A, 0x27, 0x65, 0x25, 0x6A, 0x27, 0x69, 0x26, 0x68, 0x26, 0x68, 0x26, 0x6A, 0x27, 0x68, 0x27, 0x69, 0x27, 0x69, 0x27, 0x67, 0x26, 0x69, 0x27, 0x67, 0x26, 0x68, 0x27, 0x66, 0x25, 0x65, 0x25, 0x68, 0x26, 0x6A, 0x26, 0x64, 0x24, 0x64, 0x23, 0x61, 0x23, 0x65, 0x24, 0x60, 0x22, 0x60, 0x24, 0x63, 0x24, 0x63, 0x24, 0x61, 0x22, 0x60, 0x22, 0x64, 0x24, 0x67, 0x25, 0x64, 0x24, 0x65, 0x24, 0x62, 0x23, 0x66, 0x24, 0x65, 0x23, 0x5F, 0x23, 0x65, 0x25, 0x68, 0x25, 0x64, 0x24, 0x6D, 0x27, 0x64, 0x24, 0x66, 0x24, 0x66, 0x25, 0x66, 0x25, 0x64, 0x23, 0x61, 0x22, 0x61, 0x23, 0x62, 0x23, 0x61, 0x23, 0x5F, 0x22, 0x5F, 0x22, 0x5B, 0x21, 0x60, 0x22, 0x5E, 0x22, 0x5E, 0x22, 0x5E, 0x21, 0x5D, 0x21, 0x5B, 0x22, 0x60, 0x23, 0x5D, 0x22, 0x60, 0x23, 0x5F, 0x24, 0x60, 0x24, 0x60, 0x23, 0x5F, 0x23, 0x5F, 0x23, 0x5E, 0x23, 0x60, 0x23, 0x62, 0x25, 0x64, 0x25, 0x60, 0x24, 0x61, 0x24, 0x5D, 0x23, 0x5E, 0x23, 0x62, 0x24, 0x61, 0x25, 0x65, 0x24, 0x60, 0x24, 0x62, 0x24, 0x5F, 0x22, 0x5E, 0x22, 0x5D, 0x22, 0x5A, 0x21, 0x5C, 0x23, 0x5F, 0x22, 0x5F, 0x23, 0x5F, 0x23, 0x5D, 0x22, 0x5B, 0x21, 0x5E, 0x23, 0x5F, 0x22, 0x63, 0x24, 0x62, 0x23, 0x5D, 0x23, 0x5B, 0x21, 0x57, 0x20, 0x59, 0x21, 0x58, 0x21, 0x5E, 0x23, 0x5A, 0x21, 0x57, 0x21, 0x59, 0x21, 0x5A, 0x21, 0x58, 0x21, 0x5A, 0x20, 0x58, 0x21, 0x57, 0x1F, 0x5A, 0x21, 0x5A, 0x21, 0x55, 0x20, 0x56, 0x20, 0x57, 0x20, 0x59, 0x21, 0x56, 0x1F, 0x55, 0x1F, 0x52, 0x1F, 0x45, 0x1C, 0x31, 0x1A, 0x33, 0x1E, 0x3A, 0x1E, 0x2B, 0x18, 0x2E, 0x1B, 0x2C, 0x19, 0x2F, 0x1A, 0x2C, 0x19, 0x2C, 0x1A, 0x36, 0x1E, 0x34, 0x1C, 0x34, 0x1D, 0x31, 0x1B, 0x3C, 0x20, 0x37, 0x1D, 0x37, 0x1E, 0x42, 0x22, 0x34, 0x1C, 0x33, 0x1A, 0x34, 0x1C, 0x34, 0x1B, 0x2E, 0x19, 0x37, 0x1C, 0x32, 0x1C, 0x2F, 0x1A, 0x2C, 0x19, 0x2D, 0x1A, 0x33, 0x1D, 0x36, 0x1C, 0x2D, 0x1A, 0x34, 0x1B, 0x2F, 0x1A, 0x3E, 0x22, 0x35, 0x1E, 0x3D, 0x21, 0x30, 0x1B, 0x3B, 0x20, 0x2F, 0x1A, 0x28, 0x17, 0x31, 0x1B, 0x2F, 0x1B, 0x2C, 0x19, 0x3A, 0x1E, 0x34, 0x1D, 0x37, 0x1D, 0x33, 0x1B
    },

    {
        0x60, 0x55, 0x61, 0x56, 0x62, 0x56, 0x63, 0x56, 0x62, 0x57, 0x63, 0x57, 0x63, 0x58, 0x64, 0x58, 0x64, 0x57, 0x64, 0x57, 0x66, 0x58, 0x64, 0x57, 0x65, 0x58, 0x63, 0x57, 0x65, 0x5A, 0x65, 0x59, 0x63, 0x58, 0x60, 0x55, 0x5A, 0x50, 0x4B, 0x3F, 0x3C, 0x36, 0x45, 0x44, 0x56, 0x50, 0x59, 0x4F, 0x4F, 0x45, 0x3B, 0x33, 0x26, 0x23, 0x1D, 0x1E, 0x1A, 0x1B, 0x18, 0x1A, 0x16, 0x18, 0x16, 0x18, 0x15, 0x18, 0x14, 0x18, 0x14, 0x17, 0x13, 0x16, 0x13, 0x16, 0x13, 0x16, 0x13, 0x16, 0x13, 0x16, 0x14, 0x18, 0x13, 0x17, 0x14, 0x17, 0x13, 0x17, 0x13, 0x17, 0x14, 0x19, 0x16, 0x1B, 0x16, 0x1A, 0x15, 0x18, 0x13, 0x17, 0x14, 0x17, 0x13, 0x16, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x14, 0x17, 0x14, 0x18, 0x14, 0x18, 0x13, 0x18, 0x14, 0x18, 0x14, 0x19, 0x14, 0x18, 0x14, 0x18, 0x14, 0x19, 0x16, 0x1E, 0x1D, 0x33, 0x2B, 0x52, 0x32, 0x5E, 0x34, 0x63, 0x37, 0x68, 0x38, 0x6A, 0x39, 0x6C, 0x37, 0x66, 0x32, 0x58, 0x24, 0x35, 0x1A, 0x24, 0x1A, 0x25, 0x1D, 0x2C, 0x1D, 0x2E, 0x1D, 0x2E, 0x1D, 0x2E, 0x1D, 0x2F, 0x1E, 0x30, 0x1E, 0x31, 0x1E, 0x30, 0x1E, 0x30, 0x1D, 0x2C, 0x1B, 0x27, 0x16, 0x1C, 0x16, 0x19, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x15, 0x19, 0x14, 0x18, 0x15, 0x19, 0x15, 0x19, 0x15, 0x19, 0x14, 0x18, 0x15, 0x19, 0x16, 0x1A, 0x16, 0x1A, 0x15, 0x19, 0x16, 0x1B, 0x15, 0x1A, 0x15, 0x1A, 0x16, 0x1D, 0x19, 0x1E, 0x17, 0x1C, 0x17, 0x1C, 0x16, 0x1B, 0x17, 0x1C, 0x17, 0x1C, 0x17, 0x1D, 0x16, 0x1B, 0x16, 0x1A, 0x16, 0x1A, 0x17, 0x1B, 0x16, 0x1A, 0x19, 0x1B, 0x26, 0x2A, 0x50, 0x53, 0x67, 0x62, 0x63, 0x5C, 0x4D, 0x43, 0x37, 0x34, 0x51, 0x51, 0x69, 0x62, 0x6A, 0x62, 0x6F, 0x66, 0x76, 0x69, 0x79, 0x6C, 0x77, 0x6A, 0x74, 0x67, 0x73, 0x69, 0x74, 0x68, 0x76, 0x69, 0x74, 0x65, 0x75, 0x68, 0x73, 0x68, 0x72, 0x67, 0x71, 0x64, 0x72, 0x67, 0x74, 0x6A, 0x70, 0x63, 0x6D, 0x60, 0x72, 0x67, 0x76, 0x69, 0x74, 0x68, 0x76, 0x69, 0x76, 0x68, 0x78, 0x6C, 0x77, 0x69, 0x74, 0x67, 0x77, 0x6A, 0x75, 0x68, 0x74, 0x68, 0x75, 0x69, 0x76, 0x6A, 0x74, 0x69, 0x73, 0x67, 0x74, 0x69, 0x74, 0x68, 0x77, 0x69, 0x74, 0x67, 0x75, 0x69, 0x72, 0x64, 0x73, 0x66, 0x75, 0x6A, 0x76, 0x69, 0x6F, 0x63, 0x72, 0x65, 0x70, 0x62, 0x71, 0x64, 0x6C, 0x5E, 0x6D, 0x63, 0x70, 0x62, 0x73, 0x66, 0x72, 0x61, 0x70, 0x62, 0x72, 0x64, 0x77, 0x68, 0x72, 0x64, 0x73, 0x66, 0x71, 0x63, 0x72, 0x66, 0x73, 0x64, 0x6F, 0x62, 0x74, 0x66, 0x76, 0x67, 0x71, 0x63, 0x78, 0x6A, 0x73, 0x65, 0x73, 0x66, 0x72, 0x63, 0x73, 0x66, 0x70, 0x63, 0x70, 0x62, 0x71, 0x63, 0x71, 0x63, 0x6F, 0x61, 0x6D, 0x61, 0x6B, 0x5F, 0x68, 0x5C, 0x6E, 0x60, 0x6D, 0x5F, 0x6D, 0x60, 0x6D, 0x5F, 0x6C, 0x5E, 0x66, 0x59, 0x6C, 0x62, 0x6A, 0x5E, 0x6B, 0x61, 0x6D, 0x61, 0x6E, 0x61, 0x6D, 0x5F, 0x6A, 0x5E, 0x6B, 0x5F, 0x6A, 0x60, 0x6C, 0x61, 0x6E, 0x64, 0x72, 0x66, 0x6E, 0x60, 0x6D, 0x61, 0x6B, 0x5E, 0x6C, 0x5E, 0x6F, 0x61, 0x6B, 0x61, 0x71, 0x64, 0x6D, 0x61, 0x6F, 0x62, 0x6C, 0x5E, 0x69, 0x5D, 0x69, 0x5C, 0x67, 0x5A, 0x6A, 0x5E, 0x6C, 0x60, 0x6A, 0x5F, 0x69, 0x5F, 0x6A, 0x5E, 0x68, 0x5C, 0x6A, 0x61, 0x6C, 0x60, 0x6F, 0x63, 0x6E, 0x61, 0x69, 0x5D, 0x68, 0x5B, 0x64, 0x58, 0x64, 0x59, 0x63, 0x59, 0x69, 0x5D, 0x67, 0x5A, 0x62, 0x58, 0x64, 0x59, 0x66, 0x59, 0x63, 0x59, 0x65, 0x5A, 0x63, 0x59, 0x64, 0x58, 0x67, 0x5A, 0x67, 0x5A, 0x60, 0x55, 0x63, 0x59, 0x64, 0x59, 0x66, 0x59, 0x62, 0x57, 0x61, 0x56, 0x5E, 0x52, 0x49, 0x3E, 0x2E, 0x2E, 0x30, 0x37, 0x31, 0x35, 0x26, 0x28, 0x2A, 0x30, 0x2A, 0x2D, 0x2B, 0x2F, 0x2C, 0x31, 0x2B, 0x30, 0x32, 0x38, 0x2F, 0x32, 0x31, 0x37, 0x2B, 0x2F, 0x36, 0x41, 0x2F, 0x33, 0x32, 0x3B, 0x38, 0x3E, 0x2E, 0x35, 0x2C, 0x2F, 0x2F, 0x35, 0x2C, 0x2F, 0x2A, 0x30, 0x2D, 0x2F, 0x2C, 0x32, 0x29, 0x2B, 0x29, 0x2C, 0x2A, 0x2E, 0x2F, 0x36, 0x30, 0x32, 0x2C, 0x34, 0x30, 0x35, 0x2C, 0x32, 0x38, 0x3F, 0x2E, 0x34, 0x35, 0x3D, 0x2B, 0x2F, 0x34, 0x3A, 0x29, 0x2C, 0x25, 0x28, 0x2E, 0x32, 0x2B, 0x31, 0x2A, 0x2F, 0x35, 0x3A, 0x30, 0x36, 0x30, 0x36, 0x2D, 0x31
    },

    {
        0x56, 0x1F, 0x57, 0x1E, 0x59, 0x1F, 0x56, 0x1E, 0x57, 0x1F, 0x5A, 0x1F, 0x59, 0x1F, 0x57, 0x1F, 0x58, 0x1F, 0x58, 0x20, 0x58, 0x1F, 0x59, 0x1F, 0x59, 0x20, 0x5A, 0x20, 0x5B, 0x20, 0x5A, 0x20, 0x58, 0x1F, 0x57, 0x1F, 0x54, 0x1F, 0x4F, 0x1D, 0x3F, 0x1A, 0x36, 0x19, 0x41, 0x1C, 0x4E, 0x1E, 0x4E, 0x1E, 0x48, 0x1C, 0x37, 0x17, 0x24, 0x13, 0x1E, 0x12, 0x1B, 0x11, 0x19, 0x10, 0x19, 0x11, 0x18, 0x10, 0x18, 0x10, 0x18, 0x10, 0x17, 0x10, 0x17, 0x0F, 0x16, 0x0F, 0x17, 0x0F, 0x17, 0x10, 0x16, 0x10, 0x18, 0x10, 0x18, 0x11, 0x17, 0x10, 0x17, 0x11, 0x18, 0x10, 0x18, 0x11, 0x1A, 0x12, 0x1C, 0x14, 0x1B, 0x13, 0x18, 0x11, 0x17, 0x10, 0x18, 0x11, 0x17, 0x11, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x18, 0x11, 0x18, 0x11, 0x17, 0x10, 0x17, 0x10, 0x17, 0x11, 0x18, 0x11, 0x19, 0x11, 0x18, 0x11, 0x19, 0x11, 0x1B, 0x13, 0x29, 0x1D, 0x4B, 0x2C, 0x5C, 0x32, 0x64, 0x36, 0x6A, 0x39, 0x6C, 0x39, 0x6D, 0x3B, 0x6F, 0x3A, 0x6F, 0x3A, 0x6A, 0x37, 0x5B, 0x2D, 0x35, 0x20, 0x2D, 0x20, 0x2F, 0x22, 0x30, 0x23, 0x30, 0x24, 0x2F, 0x23, 0x30, 0x23, 0x30, 0x24, 0x32, 0x25, 0x33, 0x26, 0x31, 0x24, 0x2E, 0x23, 0x29, 0x1C, 0x1E, 0x14, 0x1A, 0x13, 0x19, 0x11, 0x18, 0x11, 0x18, 0x11, 0x19, 0x11, 0x19, 0x12, 0x1A, 0x12, 0x19, 0x11, 0x18, 0x11, 0x19, 0x11, 0x19, 0x12, 0x1A, 0x12, 0x1A, 0x12, 0x1A, 0x12, 0x1A, 0x12, 0x19, 0x12, 0x1A, 0x12, 0x1A, 0x12, 0x1B, 0x12, 0x1B, 0x13, 0x1B, 0x13, 0x1B, 0x13, 0x1C, 0x13, 0x1D, 0x15, 0x21, 0x15, 0x1C, 0x14, 0x1B, 0x12, 0x1B, 0x12, 0x1B, 0x12, 0x1B, 0x13, 0x1C, 0x13, 0x1C, 0x13, 0x21, 0x15, 0x40, 0x1E, 0x5E, 0x24, 0x62, 0x25, 0x51, 0x21, 0x34, 0x1B, 0x43, 0x20, 0x5F, 0x24, 0x65, 0x26, 0x64, 0x26, 0x64, 0x26, 0x6A, 0x27, 0x69, 0x27, 0x6A, 0x27, 0x69, 0x28, 0x65, 0x26, 0x69, 0x26, 0x64, 0x26, 0x66, 0x26, 0x6A, 0x27, 0x69, 0x27, 0x67, 0x27, 0x69, 0x28, 0x64, 0x26, 0x68, 0x26, 0x62, 0x24, 0x62, 0x23, 0x60, 0x24, 0x66, 0x26, 0x66, 0x25, 0x67, 0x26, 0x69, 0x27, 0x6A, 0x27, 0x67, 0x27, 0x69, 0x27, 0x67, 0x26, 0x67, 0x26, 0x66, 0x26, 0x69, 0x28, 0x6A, 0x27, 0x6D, 0x27, 0x68, 0x27, 0x68, 0x26, 0x6A, 0x27, 0x6A, 0x26, 0x64, 0x25, 0x66, 0x25, 0x63, 0x25, 0x68, 0x26, 0x65, 0x25, 0x69, 0x27, 0x65, 0x24, 0x63, 0x23, 0x66, 0x24, 0x63, 0x24, 0x5E, 0x23, 0x66, 0x24, 0x65, 0x24, 0x67, 0x26, 0x68, 0x25, 0x61, 0x23, 0x64, 0x25, 0x64, 0x24, 0x68, 0x24, 0x62, 0x23, 0x61, 0x22, 0x60, 0x22, 0x64, 0x24, 0x64, 0x24, 0x64, 0x23, 0x65, 0x24, 0x63, 0x23, 0x64, 0x24, 0x65, 0x23, 0x62, 0x23, 0x63, 0x23, 0x66, 0x25, 0x65, 0x24, 0x60, 0x23, 0x5F, 0x23, 0x65, 0x24, 0x5F, 0x22, 0x61, 0x23, 0x60, 0x22, 0x60, 0x21, 0x5D, 0x22, 0x5B, 0x22, 0x57, 0x20, 0x5E, 0x22, 0x5F, 0x23, 0x5D, 0x22, 0x61, 0x24, 0x5F, 0x23, 0x5E, 0x22, 0x5D, 0x22, 0x5D, 0x23, 0x5F, 0x22, 0x5E, 0x23, 0x60, 0x23, 0x5C, 0x22, 0x5E, 0x23, 0x5F, 0x24, 0x5E, 0x23, 0x60, 0x22, 0x60, 0x23, 0x62, 0x25, 0x60, 0x24, 0x5F, 0x23, 0x60, 0x23, 0x5E, 0x23, 0x60, 0x24, 0x5F, 0x22, 0x5C, 0x22, 0x5E, 0x22, 0x5D, 0x22, 0x5E, 0x22, 0x5D, 0x22, 0x5E, 0x22, 0x5B, 0x22, 0x5F, 0x24, 0x5F, 0x23, 0x5D, 0x22, 0x5E, 0x23, 0x5D, 0x22, 0x5D, 0x22, 0x5D, 0x22, 0x5E, 0x23, 0x5B, 0x21, 0x5A, 0x21, 0x5C, 0x21, 0x5A, 0x21, 0x5A, 0x21, 0x5B, 0x21, 0x57, 0x21, 0x5D, 0x24, 0x5D, 0x23, 0x59, 0x21, 0x5B, 0x22, 0x59, 0x21, 0x5B, 0x21, 0x58, 0x20, 0x58, 0x20, 0x53, 0x1F, 0x55, 0x20, 0x59, 0x21, 0x5A, 0x22, 0x58, 0x21, 0x58, 0x21, 0x56, 0x21, 0x43, 0x1C, 0x2C, 0x19, 0x35, 0x1C, 0x2F, 0x1A, 0x30, 0x1C, 0x34, 0x1D, 0x39, 0x1E, 0x3C, 0x20, 0x35, 0x1C, 0x33, 0x1D, 0x34, 0x1B, 0x34, 0x1D, 0x30, 0x1A, 0x29, 0x19, 0x39, 0x1E, 0x2B, 0x19, 0x32, 0x1D, 0x32, 0x1B, 0x31, 0x1B, 0x2C, 0x19, 0x32, 0x1C, 0x30, 0x1A, 0x2F, 0x1B, 0x33, 0x1B, 0x31, 0x1C, 0x36, 0x1D, 0x32, 0x1C, 0x37, 0x1D, 0x33, 0x1D, 0x3D, 0x1F, 0x33, 0x1C, 0x34, 0x1C, 0x2C, 0x19, 0x39, 0x1F, 0x2C, 0x1A, 0x31, 0x1A, 0x2F, 0x1B, 0x38, 0x1F, 0x38, 0x1E, 0x35, 0x1C, 0x36, 0x1F, 0x39, 0x1F, 0x34, 0x1D, 0x38, 0x1D, 0x2A, 0x18, 0x2F, 0x1B, 0x2E, 0x1B
    },

    {
        0x60, 0x57, 0x63, 0x58, 0x64, 0x58, 0x63, 0x58, 0x63, 0x57, 0x64, 0x59, 0x64, 0x58, 0x64, 0x57, 0x65, 0x58, 0x65, 0x59, 0x65, 0x58, 0x65, 0x57, 0x64, 0x57, 0x64, 0x59, 0x67, 0x5A, 0x66, 0x59, 0x64, 0x57, 0x63, 0x57, 0x5F, 0x54, 0x5A, 0x50, 0x4D, 0x41, 0x3D, 0x36, 0x40, 0x40, 0x51, 0x4C, 0x56, 0x50, 0x53, 0x4B, 0x42, 0x39, 0x2A, 0x26, 0x1F, 0x1F, 0x1A, 0x1B, 0x17, 0x1A, 0x16, 0x19, 0x16, 0x18, 0x15, 0x18, 0x14, 0x17, 0x13, 0x16, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x14, 0x18, 0x14, 0x19, 0x14, 0x17, 0x14, 0x17, 0x14, 0x18, 0x14, 0x18, 0x15, 0x19, 0x17, 0x1D, 0x18, 0x1C, 0x15, 0x19, 0x14, 0x17, 0x14, 0x17, 0x13, 0x17, 0x14, 0x18, 0x13, 0x17, 0x13, 0x18, 0x14, 0x18, 0x14, 0x17, 0x12, 0x17, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x14, 0x18, 0x14, 0x19, 0x15, 0x19, 0x16, 0x1C, 0x1D, 0x34, 0x2B, 0x52, 0x32, 0x5F, 0x35, 0x64, 0x38, 0x6A, 0x39, 0x6A, 0x39, 0x6C, 0x3B, 0x6D, 0x3B, 0x6D, 0x38, 0x67, 0x32, 0x57, 0x23, 0x33, 0x1E, 0x2D, 0x1D, 0x2E, 0x1E, 0x31, 0x1E, 0x30, 0x1E, 0x2F, 0x1D, 0x2F, 0x1E, 0x31, 0x20, 0x31, 0x20, 0x33, 0x1F, 0x31, 0x1D, 0x2D, 0x1A, 0x24, 0x17, 0x1C, 0x15, 0x1A, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x14, 0x19, 0x15, 0x19, 0x15, 0x19, 0x15, 0x18, 0x14, 0x17, 0x14, 0x18, 0x15, 0x19, 0x16, 0x1A, 0x15, 0x19, 0x15, 0x19, 0x15, 0x1A, 0x16, 0x1A, 0x15, 0x1A, 0x16, 0x1A, 0x16, 0x1B, 0x16, 0x1B, 0x17, 0x1B, 0x16, 0x1B, 0x17, 0x1C, 0x18, 0x1D, 0x1B, 0x21, 0x17, 0x1C, 0x16, 0x1B, 0x16, 0x1B, 0x17, 0x1B, 0x17, 0x1B, 0x18, 0x1C, 0x19, 0x1C, 0x24, 0x28, 0x4A, 0x4E, 0x66, 0x5F, 0x67, 0x61, 0x4F, 0x46, 0x36, 0x33, 0x52, 0x52, 0x69, 0x60, 0x6F, 0x66, 0x73, 0x67, 0x73, 0x66, 0x77, 0x6A, 0x77, 0x6A, 0x78, 0x69, 0x76, 0x6B, 0x71, 0x66, 0x73, 0x66, 0x71, 0x65, 0x74, 0x68, 0x77, 0x69, 0x78, 0x6B, 0x74, 0x68, 0x77, 0x6A, 0x70, 0x65, 0x71, 0x65, 0x6D, 0x60, 0x6F, 0x63, 0x6E, 0x62, 0x73, 0x66, 0x71, 0x66, 0x74, 0x66, 0x74, 0x68, 0x76, 0x69, 0x75, 0x68, 0x75, 0x69, 0x74, 0x64, 0x74, 0x67, 0x73, 0x68, 0x77, 0x6B, 0x79, 0x6A, 0x79, 0x6C, 0x76, 0x68, 0x77, 0x69, 0x77, 0x6B, 0x76, 0x67, 0x71, 0x66, 0x73, 0x65, 0x70, 0x64, 0x75, 0x67, 0x71, 0x65, 0x74, 0x68, 0x73, 0x66, 0x73, 0x65, 0x73, 0x67, 0x71, 0x64, 0x6D, 0x5F, 0x73, 0x65, 0x72, 0x64, 0x75, 0x67, 0x76, 0x67, 0x6F, 0x60, 0x72, 0x66, 0x73, 0x66, 0x78, 0x67, 0x71, 0x62, 0x6E, 0x5F, 0x6E, 0x5F, 0x74, 0x67, 0x73, 0x63, 0x75, 0x66, 0x74, 0x65, 0x74, 0x64, 0x74, 0x65, 0x73, 0x65, 0x72, 0x65, 0x72, 0x66, 0x75, 0x68, 0x73, 0x64, 0x6B, 0x60, 0x69, 0x60, 0x6F, 0x63, 0x69, 0x5C, 0x6E, 0x62, 0x6D, 0x5F, 0x6D, 0x60, 0x6C, 0x5E, 0x69, 0x5C, 0x63, 0x57, 0x69, 0x5F, 0x6B, 0x5F, 0x69, 0x5F, 0x6E, 0x63, 0x6B, 0x60, 0x6B, 0x5F, 0x6B, 0x5D, 0x6A, 0x60, 0x6C, 0x5E, 0x6D, 0x5F, 0x6B, 0x5F, 0x69, 0x5C, 0x69, 0x5E, 0x6B, 0x60, 0x6A, 0x5F, 0x6D, 0x60, 0x6D, 0x60, 0x6E, 0x62, 0x6D, 0x60, 0x6A, 0x5E, 0x6A, 0x60, 0x68, 0x5E, 0x6E, 0x63, 0x6C, 0x61, 0x6B, 0x5F, 0x6C, 0x5F, 0x6B, 0x5D, 0x6B, 0x5E, 0x6B, 0x5F, 0x6C, 0x5E, 0x66, 0x5B, 0x69, 0x5C, 0x69, 0x5F, 0x69, 0x5D, 0x6B, 0x5F, 0x6B, 0x5E, 0x6A, 0x5D, 0x6A, 0x5D, 0x6B, 0x5F, 0x66, 0x5D, 0x67, 0x5C, 0x69, 0x5C, 0x67, 0x5C, 0x66, 0x5A, 0x67, 0x5B, 0x65, 0x5B, 0x69, 0x5F, 0x68, 0x5D, 0x65, 0x59, 0x68, 0x5C, 0x64, 0x5A, 0x65, 0x5B, 0x64, 0x57, 0x65, 0x59, 0x5F, 0x54, 0x61, 0x56, 0x65, 0x59, 0x66, 0x5B, 0x63, 0x57, 0x66, 0x59, 0x62, 0x57, 0x4A, 0x42, 0x2D, 0x2E, 0x2F, 0x35, 0x2B, 0x31, 0x2E, 0x31, 0x31, 0x3A, 0x31, 0x37, 0x34, 0x3B, 0x2C, 0x2D, 0x30, 0x36, 0x2D, 0x2F, 0x2F, 0x36, 0x2A, 0x2C, 0x26, 0x2B, 0x31, 0x36, 0x27, 0x2B, 0x2F, 0x36, 0x2E, 0x31, 0x2D, 0x32, 0x2B, 0x2D, 0x2F, 0x36, 0x2D, 0x33, 0x2C, 0x33, 0x30, 0x34, 0x2E, 0x34, 0x32, 0x36, 0x2B, 0x32, 0x30, 0x36, 0x2F, 0x36, 0x34, 0x38, 0x2C, 0x31, 0x2D, 0x31, 0x27, 0x2C, 0x30, 0x33, 0x29, 0x2D, 0x2C, 0x30, 0x2E, 0x34, 0x35, 0x3C, 0x36, 0x3C, 0x31, 0x35, 0x32, 0x38, 0x31, 0x37, 0x2D, 0x33, 0x2F, 0x32, 0x26, 0x28, 0x2D, 0x34, 0x2D, 0x32
    },

    {
        0x58, 0x20, 0x58, 0x1F, 0x59, 0x20, 0x59, 0x1F, 0x59, 0x1F, 0x59, 0x1F, 0x58, 0x1F, 0x58, 0x1F, 0x59, 0x20, 0x59, 0x20, 0x58, 0x20, 0x59, 0x20, 0x58, 0x20, 0x58, 0x20, 0x58, 0x1F, 0x59, 0x1F, 0x56, 0x1F, 0x56, 0x20, 0x58, 0x20, 0x55, 0x1F, 0x4F, 0x1D, 0x43, 0x1A, 0x37, 0x19, 0x3D, 0x1B, 0x4C, 0x1D, 0x4F, 0x1F, 0x4B, 0x1D, 0x3B, 0x18, 0x27, 0x14, 0x1F, 0x12, 0x1C, 0x11, 0x1A, 0x11, 0x1A, 0x11, 0x18, 0x10, 0x18, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x18, 0x11, 0x17, 0x10, 0x18, 0x10, 0x18, 0x11, 0x19, 0x12, 0x19, 0x11, 0x19, 0x11, 0x19, 0x11, 0x19, 0x11, 0x19, 0x11, 0x19, 0x12, 0x1B, 0x13, 0x1B, 0x12, 0x19, 0x11, 0x18, 0x11, 0x18, 0x11, 0x19, 0x12, 0x1A, 0x12, 0x19, 0x11, 0x17, 0x11, 0x17, 0x11, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x19, 0x11, 0x19, 0x12, 0x19, 0x11, 0x19, 0x11, 0x1D, 0x16, 0x39, 0x25, 0x56, 0x30, 0x60, 0x33, 0x68, 0x38, 0x6A, 0x39, 0x6D, 0x39, 0x6D, 0x3A, 0x6F, 0x3B, 0x6E, 0x3C, 0x6E, 0x3A, 0x53, 0x2C, 0x30, 0x1E, 0x29, 0x1E, 0x2D, 0x21, 0x30, 0x25, 0x32, 0x24, 0x31, 0x25, 0x34, 0x25, 0x32, 0x24, 0x32, 0x25, 0x32, 0x25, 0x31, 0x23, 0x29, 0x1C, 0x1F, 0x16, 0x1C, 0x13, 0x1A, 0x13, 0x1A, 0x12, 0x1A, 0x11, 0x19, 0x11, 0x18, 0x11, 0x18, 0x11, 0x19, 0x12, 0x18, 0x11, 0x18, 0x11, 0x19, 0x12, 0x1A, 0x12, 0x1A, 0x12, 0x1A, 0x12, 0x1A, 0x13, 0x1B, 0x13, 0x1B, 0x13, 0x1B, 0x13, 0x1A, 0x12, 0x1A, 0x12, 0x1A, 0x12, 0x1B, 0x13, 0x1C, 0x13, 0x1B, 0x13, 0x1B, 0x13, 0x1D, 0x14, 0x1C, 0x13, 0x1C, 0x13, 0x1C, 0x13, 0x1C, 0x13, 0x1C, 0x12, 0x1C, 0x13, 0x1F, 0x15, 0x3E, 0x1E, 0x5B, 0x25, 0x62, 0x25, 0x53, 0x21, 0x34, 0x1B, 0x42, 0x1F, 0x5C, 0x25, 0x63, 0x26, 0x68, 0x27, 0x6A, 0x28, 0x6B, 0x28, 0x6A, 0x28, 0x6B, 0x27, 0x66, 0x25, 0x68, 0x27, 0x6C, 0x27, 0x67, 0x26, 0x68, 0x28, 0x68, 0x28, 0x69, 0x27, 0x68, 0x27, 0x69, 0x27, 0x69, 0x28, 0x62, 0x24, 0x61, 0x24, 0x63, 0x25, 0x67, 0x25, 0x66, 0x26, 0x66, 0x27, 0x66, 0x26, 0x67, 0x26, 0x67, 0x27, 0x68, 0x26, 0x68, 0x26, 0x69, 0x26, 0x6A, 0x26, 0x6A, 0x28, 0x6A, 0x28, 0x69, 0x27, 0x65, 0x25, 0x68, 0x27, 0x69, 0x27, 0x6C, 0x28, 0x6B, 0x27, 0x6A, 0x27, 0x68, 0x26, 0x66, 0x27, 0x66, 0x26, 0x66, 0x26, 0x67, 0x26, 0x62, 0x25, 0x66, 0x26, 0x66, 0x24, 0x62, 0x24, 0x65, 0x25, 0x63, 0x23, 0x64, 0x23, 0x65, 0x24, 0x63, 0x24, 0x66, 0x24, 0x63, 0x24, 0x69, 0x26, 0x63, 0x23, 0x66, 0x25, 0x65, 0x25, 0x64, 0x24, 0x62, 0x23, 0x5F, 0x22, 0x60, 0x22, 0x62, 0x23, 0x65, 0x24, 0x64, 0x24, 0x63, 0x23, 0x63, 0x23, 0x66, 0x24, 0x64, 0x24, 0x63, 0x25, 0x5B, 0x25, 0x57, 0x26, 0x53, 0x25, 0x55, 0x22, 0x5C, 0x22, 0x5A, 0x21, 0x5C, 0x21, 0x5A, 0x20, 0x5C, 0x21, 0x5B, 0x22, 0x5D, 0x22, 0x5B, 0x21, 0x5D, 0x22, 0x5B, 0x22, 0x5D, 0x23, 0x5D, 0x23, 0x5E, 0x23, 0x5C, 0x23, 0x60, 0x23, 0x5E, 0x22, 0x5C, 0x21, 0x5D, 0x23, 0x60, 0x23, 0x60, 0x23, 0x61, 0x24, 0x5D, 0x23, 0x60, 0x23, 0x5E, 0x23, 0x60, 0x25, 0x5F, 0x23, 0x5B, 0x23, 0x5F, 0x24, 0x60, 0x25, 0x63, 0x24, 0x63, 0x26, 0x5F, 0x24, 0x5D, 0x23, 0x5C, 0x22, 0x5A, 0x21, 0x5C, 0x23, 0x60, 0x23, 0x5D, 0x23, 0x5A, 0x20, 0x58, 0x21, 0x5A, 0x21, 0x5D, 0x22, 0x5E, 0x23, 0x5D, 0x23, 0x5C, 0x22, 0x5A, 0x21, 0x59, 0x20, 0x59, 0x20, 0x5B, 0x22, 0x5B, 0x21, 0x5C, 0x22, 0x5B, 0x22, 0x58, 0x21, 0x5A, 0x21, 0x5B, 0x21, 0x5B, 0x21, 0x5C, 0x22, 0x57, 0x20, 0x55, 0x20, 0x56, 0x20, 0x57, 0x20, 0x57, 0x21, 0x57, 0x20, 0x58, 0x21, 0x56, 0x21, 0x57, 0x20, 0x57, 0x21, 0x57, 0x21, 0x47, 0x1E, 0x37, 0x1D, 0x3B, 0x1F, 0x3E, 0x20, 0x34, 0x1C, 0x39, 0x1F, 0x2C, 0x19, 0x36, 0x1E, 0x2B, 0x19, 0x3C, 0x21, 0x37, 0x1D, 0x39, 0x1F, 0x39, 0x1E, 0x3B, 0x1F, 0x3C, 0x20, 0x39, 0x1F, 0x40, 0x21, 0x36, 0x1C, 0x30, 0x1B, 0x31, 0x1B, 0x39, 0x20, 0x36, 0x1D, 0x2F, 0x1B, 0x35, 0x1C, 0x2F, 0x1B, 0x34, 0x1C, 0x2C, 0x1A, 0x32, 0x1B, 0x32, 0x1D, 0x30, 0x1B, 0x2A, 0x19, 0x2F, 0x19, 0x32, 0x1C, 0x36, 0x1D, 0x33, 0x1C, 0x3E, 0x21, 0x3B, 0x1F, 0x37, 0x1E, 0x39, 0x1F, 0x3A, 0x20, 0x39, 0x1F, 0x37, 0x1F, 0x39, 0x1F, 0x31, 0x1B, 0x37, 0x1D, 0x3A, 0x1F, 0x38, 0x1E
    },

    {
        0x63, 0x59, 0x64, 0x58, 0x64, 0x58, 0x65, 0x58, 0x64, 0x58, 0x64, 0x58, 0x62, 0x57, 0x62, 0x57, 0x63, 0x58, 0x64, 0x57, 0x64, 0x59, 0x65, 0x58, 0x65, 0x58, 0x65, 0x59, 0x66, 0x58, 0x65, 0x57, 0x64, 0x56, 0x63, 0x57, 0x64, 0x58, 0x62, 0x55, 0x5C, 0x50, 0x52, 0x46, 0x3F, 0x36, 0x3D, 0x3B, 0x4D, 0x49, 0x55, 0x4F, 0x54, 0x4B, 0x45, 0x3D, 0x2D, 0x29, 0x20, 0x20, 0x1B, 0x1C, 0x19, 0x1B, 0x17, 0x19, 0x16, 0x19, 0x15, 0x18, 0x14, 0x17, 0x13, 0x17, 0x13, 0x16, 0x14, 0x18, 0x13, 0x16, 0x13, 0x17, 0x14, 0x18, 0x15, 0x19, 0x15, 0x19, 0x14, 0x18, 0x14, 0x18, 0x14, 0x19, 0x14, 0x18, 0x14, 0x18, 0x15, 0x19, 0x16, 0x1B, 0x15, 0x19, 0x14, 0x18, 0x14, 0x17, 0x14, 0x18, 0x14, 0x18, 0x14, 0x17, 0x13, 0x17, 0x13, 0x17, 0x13, 0x16, 0x12, 0x17, 0x13, 0x17, 0x14, 0x18, 0x14, 0x18, 0x14, 0x19, 0x15, 0x19, 0x17, 0x1E, 0x21, 0x3C, 0x2D, 0x56, 0x32, 0x5E, 0x37, 0x67, 0x38, 0x69, 0x39, 0x69, 0x3A, 0x6D, 0x39, 0x6C, 0x39, 0x6C, 0x38, 0x65, 0x2B, 0x43, 0x1D, 0x29, 0x1A, 0x26, 0x1C, 0x2B, 0x1D, 0x2F, 0x1F, 0x31, 0x1F, 0x32, 0x20, 0x33, 0x1F, 0x32, 0x1F, 0x31, 0x1E, 0x30, 0x1E, 0x2E, 0x1A, 0x24, 0x17, 0x1D, 0x16, 0x1B, 0x15, 0x1A, 0x15, 0x1A, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x14, 0x19, 0x14, 0x19, 0x15, 0x1A, 0x15, 0x1A, 0x16, 0x1B, 0x16, 0x1A, 0x16, 0x1B, 0x16, 0x1A, 0x16, 0x1A, 0x16, 0x1A, 0x15, 0x1A, 0x16, 0x1B, 0x17, 0x1B, 0x17, 0x1B, 0x16, 0x1B, 0x17, 0x1C, 0x17, 0x1B, 0x16, 0x1B, 0x17, 0x1C, 0x17, 0x1C, 0x18, 0x1C, 0x1A, 0x1C, 0x22, 0x26, 0x46, 0x4C, 0x62, 0x5F, 0x67, 0x5F, 0x51, 0x47, 0x37, 0x32, 0x4D, 0x4F, 0x67, 0x60, 0x6D, 0x64, 0x74, 0x69, 0x75, 0x6A, 0x77, 0x6A, 0x78, 0x6C, 0x75, 0x6A, 0x72, 0x65, 0x74, 0x69, 0x7A, 0x6B, 0x75, 0x68, 0x75, 0x6A, 0x72, 0x68, 0x74, 0x69, 0x77, 0x68, 0x74, 0x68, 0x72, 0x67, 0x6E, 0x60, 0x6F, 0x62, 0x71, 0x65, 0x74, 0x68, 0x71, 0x66, 0x70, 0x65, 0x72, 0x66, 0x71, 0x66, 0x71, 0x67, 0x74, 0x68, 0x75, 0x67, 0x76, 0x69, 0x7A, 0x6C, 0x7A, 0x69, 0x78, 0x6B, 0x75, 0x67, 0x72, 0x66, 0x75, 0x68, 0x75, 0x69, 0x77, 0x6C, 0x76, 0x6A, 0x75, 0x6B, 0x78, 0x6A, 0x73, 0x67, 0x74, 0x67, 0x70, 0x67, 0x71, 0x65, 0x70, 0x63, 0x73, 0x68, 0x73, 0x66, 0x6F, 0x63, 0x73, 0x66, 0x72, 0x63, 0x72, 0x63, 0x73, 0x65, 0x73, 0x66, 0x75, 0x66, 0x72, 0x64, 0x77, 0x6A, 0x71, 0x63, 0x75, 0x66, 0x73, 0x66, 0x71, 0x65, 0x6C, 0x60, 0x6D, 0x60, 0x6D, 0x5E, 0x6F, 0x62, 0x71, 0x65, 0x72, 0x63, 0x70, 0x5F, 0x72, 0x62, 0x74, 0x65, 0x72, 0x64, 0x6A, 0x60, 0x5B, 0x55, 0x53, 0x51, 0x50, 0x52, 0x55, 0x53, 0x64, 0x5B, 0x63, 0x59, 0x66, 0x5A, 0x69, 0x5C, 0x68, 0x5D, 0x68, 0x5E, 0x6B, 0x5F, 0x66, 0x5B, 0x69, 0x5D, 0x65, 0x5B, 0x6A, 0x5D, 0x69, 0x5D, 0x68, 0x5D, 0x68, 0x5C, 0x6D, 0x60, 0x68, 0x5E, 0x69, 0x5D, 0x69, 0x5C, 0x6C, 0x61, 0x6D, 0x60, 0x6D, 0x61, 0x6C, 0x60, 0x6D, 0x60, 0x68, 0x5D, 0x6D, 0x61, 0x6D, 0x61, 0x68, 0x5F, 0x6A, 0x60, 0x69, 0x60, 0x6C, 0x61, 0x6C, 0x62, 0x6A, 0x5E, 0x68, 0x5F, 0x67, 0x5C, 0x67, 0x5A, 0x6A, 0x60, 0x6D, 0x60, 0x6C, 0x5E, 0x66, 0x59, 0x61, 0x59, 0x67, 0x5A, 0x6A, 0x5E, 0x6A, 0x5F, 0x68, 0x5F, 0x68, 0x5C, 0x62, 0x57, 0x65, 0x59, 0x63, 0x5A, 0x67, 0x5D, 0x67, 0x5B, 0x67, 0x5A, 0x67, 0x59, 0x63, 0x58, 0x66, 0x5A, 0x67, 0x5B, 0x67, 0x5C, 0x68, 0x5D, 0x62, 0x58, 0x61, 0x57, 0x61, 0x55, 0x62, 0x56, 0x64, 0x58, 0x65, 0x5A, 0x65, 0x58, 0x60, 0x57, 0x63, 0x55, 0x64, 0x58, 0x61, 0x57, 0x4B, 0x45, 0x37, 0x38, 0x33, 0x38, 0x35, 0x3B, 0x2C, 0x30, 0x33, 0x37, 0x28, 0x29, 0x35, 0x3A, 0x2B, 0x2F, 0x36, 0x3F, 0x30, 0x36, 0x35, 0x3C, 0x35, 0x3C, 0x33, 0x3A, 0x35, 0x3E, 0x2F, 0x36, 0x38, 0x40, 0x2E, 0x30, 0x2C, 0x32, 0x2B, 0x2F, 0x32, 0x38, 0x2C, 0x2F, 0x2B, 0x32, 0x2E, 0x2F, 0x2A, 0x32, 0x2D, 0x30, 0x29, 0x2F, 0x2B, 0x2F, 0x2D, 0x33, 0x2B, 0x31, 0x2A, 0x2F, 0x2D, 0x31, 0x30, 0x36, 0x2F, 0x34, 0x31, 0x37, 0x37, 0x3F, 0x34, 0x38, 0x31, 0x36, 0x32, 0x39, 0x32, 0x38, 0x32, 0x36, 0x34, 0x3B, 0x34, 0x38, 0x2F, 0x36, 0x34, 0x3A, 0x32, 0x38, 0x31, 0x36
    },

    {
        0x58, 0x1F, 0x57, 0x1F, 0x58, 0x1F, 0x59, 0x1F, 0x5A, 0x20, 0x5A, 0x1F, 0x58, 0x1F, 0x58, 0x20, 0x58, 0x20, 0x59, 0x20, 0x58, 0x20, 0x59, 0x20, 0x5A, 0x20, 0x5A, 0x20, 0x5A, 0x20, 0x5A, 0x20, 0x59, 0x20, 0x59, 0x20, 0x5A, 0x20, 0x59, 0x20, 0x56, 0x1F, 0x51, 0x1D, 0x45, 0x1B, 0x37, 0x19, 0x38, 0x1A, 0x49, 0x1D, 0x51, 0x1E, 0x4C, 0x1D, 0x40, 0x1A, 0x2C, 0x15, 0x21, 0x13, 0x1D, 0x12, 0x1B, 0x11, 0x1A, 0x10, 0x19, 0x11, 0x18, 0x10, 0x18, 0x10, 0x18, 0x11, 0x19, 0x11, 0x18, 0x11, 0x18, 0x11, 0x19, 0x11, 0x1B, 0x13, 0x1A, 0x12, 0x19, 0x11, 0x19, 0x11, 0x19, 0x11, 0x19, 0x11, 0x18, 0x11, 0x18, 0x11, 0x19, 0x11, 0x19, 0x11, 0x19, 0x11, 0x19, 0x11, 0x18, 0x11, 0x17, 0x10, 0x17, 0x11, 0x17, 0x11, 0x18, 0x11, 0x17, 0x10, 0x17, 0x11, 0x17, 0x11, 0x19, 0x12, 0x1A, 0x12, 0x19, 0x11, 0x18, 0x11, 0x1A, 0x13, 0x23, 0x1A, 0x40, 0x28, 0x5A, 0x32, 0x63, 0x36, 0x6A, 0x3A, 0x6C, 0x39, 0x6E, 0x39, 0x70, 0x3C, 0x6E, 0x39, 0x55, 0x2C, 0x31, 0x1D, 0x24, 0x17, 0x20, 0x16, 0x22, 0x1B, 0x2C, 0x21, 0x2F, 0x24, 0x31, 0x24, 0x33, 0x25, 0x34, 0x26, 0x32, 0x24, 0x32, 0x23, 0x2A, 0x1C, 0x1F, 0x16, 0x1C, 0x14, 0x1A, 0x12, 0x1A, 0x12, 0x19, 0x11, 0x18, 0x11, 0x19, 0x11, 0x19, 0x11, 0x18, 0x11, 0x19, 0x11, 0x18, 0x10, 0x18, 0x10, 0x18, 0x11, 0x19, 0x12, 0x1A, 0x12, 0x1B, 0x12, 0x1B, 0x13, 0x1A, 0x12, 0x19, 0x12, 0x1A, 0x12, 0x1B, 0x13, 0x1A, 0x12, 0x1A, 0x12, 0x1A, 0x12, 0x1B, 0x13, 0x1B, 0x13, 0x1C, 0x13, 0x1B, 0x12, 0x1B, 0x13, 0x1B, 0x12, 0x1A, 0x12, 0x1C, 0x13, 0x1C, 0x13, 0x20, 0x15, 0x40, 0x1E, 0x5A, 0x23, 0x61, 0x25, 0x59, 0x22, 0x35, 0x1B, 0x40, 0x20, 0x5E, 0x25, 0x65, 0x26, 0x66, 0x27, 0x68, 0x28, 0x6A, 0x28, 0x6C, 0x28, 0x69, 0x26, 0x65, 0x26, 0x65, 0x25, 0x67, 0x27, 0x6A, 0x28, 0x68, 0x26, 0x68, 0x27, 0x67, 0x27, 0x69, 0x27, 0x69, 0x27, 0x67, 0x26, 0x67, 0x27, 0x64, 0x24, 0x64, 0x26, 0x64, 0x25, 0x68, 0x26, 0x67, 0x26, 0x67, 0x27, 0x67, 0x26, 0x66, 0x26, 0x65, 0x25, 0x65, 0x26, 0x67, 0x26, 0x65, 0x25, 0x66, 0x25, 0x6B, 0x28, 0x6D, 0x28, 0x67, 0x26, 0x66, 0x26, 0x66, 0x27, 0x66, 0x26, 0x65, 0x26, 0x66, 0x26, 0x68, 0x26, 0x6A, 0x27, 0x69, 0x26, 0x68, 0x27, 0x67, 0x25, 0x63, 0x25, 0x67, 0x26, 0x65, 0x25, 0x66, 0x25, 0x67, 0x26, 0x69, 0x27, 0x6A, 0x26, 0x61, 0x22, 0x63, 0x23, 0x63, 0x23, 0x62, 0x23, 0x62, 0x24, 0x67, 0x25, 0x65, 0x24, 0x67, 0x26, 0x69, 0x24, 0x63, 0x23, 0x61, 0x22, 0x5F, 0x23, 0x5E, 0x21, 0x62, 0x23, 0x60, 0x23, 0x61, 0x23, 0x63, 0x24, 0x63, 0x23, 0x62, 0x22, 0x5F, 0x22, 0x55, 0x24, 0x4C, 0x26, 0x4D, 0x26, 0x4A, 0x24, 0x4A, 0x24, 0x4E, 0x21, 0x53, 0x1F, 0x5B, 0x21, 0x5A, 0x20, 0x5C, 0x21, 0x5D, 0x22, 0x5F, 0x23, 0x5B, 0x22, 0x5A, 0x21, 0x5C, 0x23, 0x5E, 0x23, 0x5D, 0x23, 0x5B, 0x22, 0x5E, 0x23, 0x60, 0x23, 0x5E, 0x22, 0x5D, 0x23, 0x60, 0x23, 0x5C, 0x22, 0x62, 0x24, 0x61, 0x24, 0x5E, 0x22, 0x5C, 0x22, 0x5F, 0x23, 0x64, 0x25, 0x66, 0x27, 0x62, 0x24, 0x5E, 0x23, 0x5E, 0x23, 0x5F, 0x23, 0x5D, 0x22, 0x5E, 0x22, 0x5E, 0x23, 0x5C, 0x21, 0x5B, 0x21, 0x5D, 0x22, 0x5B, 0x21, 0x58, 0x21, 0x5A, 0x21, 0x5B, 0x21, 0x5B, 0x22, 0x5E, 0x23, 0x5B, 0x21, 0x57, 0x20, 0x59, 0x21, 0x5B, 0x21, 0x5A, 0x22, 0x5C, 0x21, 0x5B, 0x21, 0x5A, 0x20, 0x5B, 0x21, 0x5A, 0x21, 0x57, 0x20, 0x56, 0x21, 0x56, 0x21, 0x5A, 0x21, 0x5C, 0x21, 0x56, 0x20, 0x53, 0x1F, 0x54, 0x1F, 0x56, 0x20, 0x59, 0x21, 0x58, 0x21, 0x58, 0x21, 0x58, 0x21, 0x57, 0x20, 0x59, 0x21, 0x56, 0x20, 0x46, 0x1F, 0x30, 0x1A, 0x35, 0x1E, 0x35, 0x1D, 0x37, 0x1E, 0x37, 0x1D, 0x30, 0x1B, 0x43, 0x22, 0x35, 0x1C, 0x32, 0x1C, 0x2E, 0x19, 0x3C, 0x1F, 0x34, 0x1B, 0x29, 0x18, 0x2F, 0x1A, 0x2B, 0x19, 0x35, 0x1C, 0x2B, 0x1A, 0x33, 0x1D, 0x33, 0x1B, 0x32, 0x1B, 0x32, 0x1A, 0x31, 0x1C, 0x32, 0x1B, 0x31, 0x1B, 0x34, 0x1C, 0x38, 0x1E, 0x39, 0x1E, 0x36, 0x1E, 0x3D, 0x22, 0x3C, 0x1F, 0x3A, 0x1F, 0x37, 0x1D, 0x36, 0x1E, 0x3D, 0x20, 0x35, 0x1C, 0x36, 0x1E, 0x31, 0x1D, 0x3C, 0x20, 0x34, 0x1D, 0x33, 0x1D, 0x41, 0x24, 0x40, 0x22, 0x43, 0x23, 0x37, 0x1D, 0x29, 0x18, 0x2F, 0x1A
    },

    {
        0x63, 0x57, 0x63, 0x58, 0x65, 0x58, 0x65, 0x59, 0x66, 0x5B, 0x66, 0x59, 0x63, 0x57, 0x63, 0x58, 0x64, 0x58, 0x64, 0x59, 0x66, 0x58, 0x65, 0x58, 0x66, 0x59, 0x67, 0x59, 0x66, 0x59, 0x67, 0x58, 0x67, 0x59, 0x67, 0x59, 0x67, 0x59, 0x66, 0x58, 0x63, 0x58, 0x5F, 0x53, 0x52, 0x46, 0x41, 0x37, 0x39, 0x37, 0x49, 0x48, 0x58, 0x4F, 0x55, 0x4D, 0x4B, 0x41, 0x34, 0x2F, 0x23, 0x22, 0x1D, 0x1E, 0x1A, 0x1C, 0x18, 0x1A, 0x17, 0x1A, 0x16, 0x18, 0x15, 0x18, 0x14, 0x18, 0x15, 0x19, 0x15, 0x18, 0x15, 0x19, 0x15, 0x1A, 0x17, 0x1B, 0x16, 0x1A, 0x14, 0x19, 0x15, 0x19, 0x15, 0x19, 0x15, 0x19, 0x15, 0x18, 0x14, 0x17, 0x14, 0x18, 0x14, 0x18, 0x15, 0x19, 0x15, 0x19, 0x14, 0x17, 0x13, 0x17, 0x13, 0x17, 0x14, 0x17, 0x14, 0x18, 0x13, 0x17, 0x13, 0x17, 0x14, 0x18, 0x14, 0x19, 0x15, 0x19, 0x15, 0x18, 0x14, 0x18, 0x15, 0x19, 0x17, 0x21, 0x22, 0x3D, 0x2F, 0x57, 0x35, 0x61, 0x38, 0x67, 0x39, 0x6A, 0x39, 0x6B, 0x3A, 0x6E, 0x37, 0x66, 0x2D, 0x46, 0x1E, 0x29, 0x19, 0x21, 0x18, 0x1E, 0x19, 0x21, 0x1C, 0x2B, 0x1E, 0x30, 0x1F, 0x31, 0x20, 0x32, 0x21, 0x33, 0x1F, 0x31, 0x1F, 0x2F, 0x1B, 0x25, 0x17, 0x1C, 0x16, 0x1A, 0x15, 0x1A, 0x15, 0x1A, 0x15, 0x19, 0x14, 0x19, 0x15, 0x19, 0x15, 0x19, 0x15, 0x19, 0x14, 0x19, 0x14, 0x17, 0x14, 0x18, 0x15, 0x19, 0x15, 0x19, 0x15, 0x19, 0x16, 0x1A, 0x16, 0x1B, 0x15, 0x19, 0x15, 0x19, 0x16, 0x1A, 0x16, 0x1A, 0x16, 0x1A, 0x16, 0x1A, 0x17, 0x1B, 0x16, 0x1B, 0x16, 0x1B, 0x17, 0x1B, 0x17, 0x1B, 0x16, 0x1B, 0x17, 0x1A, 0x16, 0x1B, 0x17, 0x1C, 0x1A, 0x1D, 0x24, 0x28, 0x49, 0x4F, 0x60, 0x5D, 0x64, 0x5F, 0x57, 0x4D, 0x36, 0x30, 0x4B, 0x4E, 0x68, 0x62, 0x70, 0x67, 0x71, 0x68, 0x74, 0x67, 0x74, 0x6B, 0x76, 0x69, 0x75, 0x66, 0x72, 0x65, 0x72, 0x66, 0x73, 0x68, 0x75, 0x6A, 0x73, 0x67, 0x76, 0x69, 0x72, 0x68, 0x76, 0x69, 0x76, 0x69, 0x74, 0x66, 0x73, 0x68, 0x70, 0x64, 0x71, 0x66, 0x72, 0x65, 0x74, 0x68, 0x75, 0x68, 0x75, 0x69, 0x71, 0x66, 0x70, 0x65, 0x6D, 0x62, 0x72, 0x67, 0x74, 0x67, 0x73, 0x65, 0x74, 0x66, 0x78, 0x6B, 0x7B, 0x6D, 0x73, 0x67, 0x73, 0x67, 0x72, 0x67, 0x72, 0x66, 0x72, 0x66, 0x72, 0x66, 0x73, 0x67, 0x78, 0x6C, 0x73, 0x67, 0x74, 0x69, 0x73, 0x68, 0x72, 0x65, 0x74, 0x68, 0x72, 0x64, 0x72, 0x65, 0x75, 0x68, 0x78, 0x6B, 0x78, 0x6A, 0x71, 0x61, 0x74, 0x63, 0x72, 0x65, 0x71, 0x63, 0x71, 0x63, 0x75, 0x67, 0x74, 0x66, 0x74, 0x69, 0x75, 0x66, 0x73, 0x64, 0x6E, 0x61, 0x6D, 0x60, 0x6E, 0x5F, 0x72, 0x65, 0x6E, 0x62, 0x6F, 0x62, 0x71, 0x63, 0x71, 0x62, 0x70, 0x61, 0x68, 0x5C, 0x56, 0x51, 0x4A, 0x4C, 0x4A, 0x4B, 0x47, 0x4A, 0x47, 0x49, 0x4D, 0x4C, 0x57, 0x52, 0x65, 0x5B, 0x66, 0x59, 0x69, 0x5D, 0x6A, 0x5E, 0x6A, 0x5E, 0x66, 0x5C, 0x62, 0x59, 0x64, 0x5B, 0x69, 0x60, 0x68, 0x5E, 0x65, 0x5D, 0x69, 0x5E, 0x6D, 0x61, 0x6A, 0x5E, 0x6B, 0x5F, 0x70, 0x63, 0x6A, 0x5E, 0x6C, 0x61, 0x6D, 0x61, 0x6B, 0x5F, 0x66, 0x5D, 0x6B, 0x60, 0x71, 0x65, 0x73, 0x67, 0x72, 0x61, 0x6A, 0x5F, 0x69, 0x5E, 0x6B, 0x60, 0x69, 0x5D, 0x6B, 0x60, 0x6C, 0x60, 0x6B, 0x5D, 0x67, 0x5B, 0x68, 0x5C, 0x68, 0x5C, 0x66, 0x59, 0x68, 0x5C, 0x68, 0x5C, 0x67, 0x5E, 0x66, 0x5C, 0x67, 0x5C, 0x64, 0x58, 0x66, 0x5A, 0x6A, 0x5D, 0x67, 0x5B, 0x68, 0x5D, 0x68, 0x5B, 0x67, 0x5C, 0x68, 0x5C, 0x65, 0x58, 0x62, 0x57, 0x63, 0x59, 0x62, 0x58, 0x66, 0x5A, 0x67, 0x5A, 0x60, 0x56, 0x5E, 0x55, 0x61, 0x56, 0x63, 0x58, 0x65, 0x5A, 0x62, 0x58, 0x65, 0x59, 0x66, 0x5A, 0x63, 0x57, 0x64, 0x5A, 0x62, 0x56, 0x49, 0x41, 0x2E, 0x2E, 0x32, 0x3B, 0x31, 0x35, 0x32, 0x39, 0x32, 0x35, 0x2C, 0x31, 0x39, 0x41, 0x2D, 0x30, 0x2D, 0x31, 0x29, 0x2D, 0x35, 0x3C, 0x2B, 0x2D, 0x27, 0x2C, 0x2D, 0x31, 0x2B, 0x31, 0x2E, 0x31, 0x2B, 0x32, 0x34, 0x3B, 0x32, 0x35, 0x2F, 0x32, 0x2F, 0x34, 0x2F, 0x35, 0x32, 0x37, 0x2E, 0x32, 0x31, 0x38, 0x34, 0x3B, 0x32, 0x39, 0x32, 0x38, 0x39, 0x41, 0x36, 0x3A, 0x35, 0x3A, 0x33, 0x35, 0x35, 0x3C, 0x36, 0x3A, 0x2D, 0x31, 0x2F, 0x33, 0x2E, 0x36, 0x3A, 0x3F, 0x34, 0x39, 0x37, 0x3F, 0x42, 0x4D, 0x40, 0x49, 0x42, 0x4B, 0x32, 0x34, 0x27, 0x2A, 0x2B, 0x30
    },

    {
        0x57, 0x1F, 0x58, 0x1F, 0x59, 0x20, 0x58, 0x1F, 0x5A, 0x20, 0x5A, 0x20, 0x59, 0x1F, 0x59, 0x20, 0x59, 0x1F, 0x57, 0x1F, 0x59, 0x20, 0x58, 0x1F, 0x5A, 0x20, 0x5A, 0x20, 0x5A, 0x1F, 0x59, 0x20, 0x5A, 0x20, 0x5A, 0x20, 0x58, 0x20, 0x5A, 0x1F, 0x5A, 0x20, 0x57, 0x20, 0x53, 0x1E, 0x48, 0x1C, 0x3A, 0x1A, 0x38, 0x1B, 0x47, 0x1E, 0x51, 0x1E, 0x4E, 0x1E, 0x45, 0x1B, 0x2F, 0x16, 0x21, 0x13, 0x1E, 0x12, 0x1C, 0x12, 0x1B, 0x12, 0x1B, 0x11, 0x19, 0x11, 0x19, 0x11, 0x18, 0x11, 0x19, 0x11, 0x1A, 0x12, 0x1B, 0x12, 0x1B, 0x13, 0x1B, 0x13, 0x1B, 0x13, 0x1A, 0x12, 0x1A, 0x11, 0x19, 0x11, 0x18, 0x10, 0x17, 0x10, 0x18, 0x11, 0x18, 0x12, 0x19, 0x12, 0x18, 0x11, 0x18, 0x10, 0x17, 0x10, 0x16, 0x10, 0x17, 0x11, 0x17, 0x11, 0x17, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x12, 0x18, 0x11, 0x18, 0x10, 0x19, 0x12, 0x1A, 0x12, 0x21, 0x18, 0x3B, 0x26, 0x58, 0x33, 0x66, 0x38, 0x6B, 0x39, 0x6C, 0x3A, 0x6C, 0x39, 0x58, 0x2D, 0x34, 0x1E, 0x25, 0x17, 0x20, 0x15, 0x1D, 0x14, 0x1B, 0x14, 0x21, 0x19, 0x2C, 0x21, 0x31, 0x24, 0x33, 0x24, 0x31, 0x24, 0x30, 0x23, 0x2D, 0x1F, 0x21, 0x17, 0x1C, 0x14, 0x1C, 0x14, 0x1A, 0x12, 0x1A, 0x12, 0x19, 0x11, 0x19, 0x11, 0x19, 0x12, 0x19, 0x12, 0x19, 0x12, 0x1A, 0x12, 0x19, 0x11, 0x19, 0x11, 0x1A, 0x12, 0x19, 0x12, 0x1A, 0x12, 0x19, 0x12, 0x19, 0x12, 0x1A, 0x12, 0x1A, 0x12, 0x1B, 0x13, 0x1B, 0x13, 0x1C, 0x13, 0x1C, 0x14, 0x1C, 0x13, 0x1B, 0x13, 0x1C, 0x13, 0x1C, 0x13, 0x1B, 0x12, 0x1B, 0x13, 0x1C, 0x13, 0x1C, 0x13, 0x1D, 0x14, 0x22, 0x16, 0x3F, 0x1E, 0x59, 0x23, 0x62, 0x25, 0x56, 0x22, 0x37, 0x1C, 0x3D, 0x1F, 0x5B, 0x24, 0x67, 0x27, 0x69, 0x28, 0x6B, 0x28, 0x68, 0x26, 0x67, 0x28, 0x67, 0x27, 0x66, 0x27, 0x66, 0x26, 0x66, 0x26, 0x68, 0x27, 0x68, 0x27, 0x68, 0x28, 0x70, 0x2A, 0x6B, 0x28, 0x69, 0x28, 0x68, 0x27, 0x68, 0x26, 0x68, 0x27, 0x67, 0x25, 0x67, 0x27, 0x68, 0x27, 0x69, 0x27, 0x66, 0x26, 0x63, 0x25, 0x62, 0x25, 0x65, 0x26, 0x63, 0x25, 0x64, 0x25, 0x66, 0x26, 0x67, 0x25, 0x63, 0x25, 0x66, 0x26, 0x67, 0x27, 0x65, 0x25, 0x68, 0x26, 0x62, 0x25, 0x62, 0x25, 0x66, 0x26, 0x66, 0x26, 0x68, 0x26, 0x69, 0x27, 0x6B, 0x28, 0x66, 0x26, 0x6A, 0x27, 0x6A, 0x27, 0x69, 0x28, 0x68, 0x27, 0x63, 0x24, 0x67, 0x25, 0x68, 0x25, 0x69, 0x26, 0x64, 0x24, 0x64, 0x23, 0x61, 0x23, 0x64, 0x24, 0x62, 0x23, 0x64, 0x24, 0x67, 0x25, 0x66, 0x25, 0x62, 0x24, 0x68, 0x26, 0x67, 0x24, 0x63, 0x23, 0x63, 0x23, 0x63, 0x23, 0x65, 0x26, 0x63, 0x24, 0x60, 0x23, 0x5E, 0x21, 0x61, 0x22, 0x58, 0x23, 0x4C, 0x26, 0x4A, 0x25, 0x4B, 0x25, 0x4A, 0x24, 0x49, 0x24, 0x48, 0x23, 0x45, 0x1D, 0x50, 0x1F, 0x57, 0x21, 0x5C, 0x21, 0x5E, 0x24, 0x66, 0x31, 0x66, 0x38, 0x58, 0x2F, 0x4D, 0x25, 0x50, 0x21, 0x5A, 0x21, 0x5B, 0x22, 0x5F, 0x23, 0x5E, 0x22, 0x5C, 0x22, 0x5D, 0x23, 0x63, 0x25, 0x5F, 0x23, 0x5E, 0x22, 0x5D, 0x21, 0x5D, 0x22, 0x5D, 0x23, 0x5D, 0x23, 0x60, 0x25, 0x65, 0x26, 0x63, 0x25, 0x5C, 0x23, 0x5F, 0x23, 0x5D, 0x22, 0x61, 0x24, 0x5F, 0x23, 0x61, 0x24, 0x5E, 0x23, 0x5C, 0x22, 0x5E, 0x22, 0x5D, 0x21, 0x59, 0x21, 0x5B, 0x21, 0x5E, 0x22, 0x5E, 0x26, 0x61, 0x23, 0x5B, 0x21, 0x5D, 0x23, 0x5B, 0x22, 0x5C, 0x22, 0x5A, 0x21, 0x5C, 0x22, 0x59, 0x21, 0x59, 0x21, 0x5B, 0x21, 0x5A, 0x20, 0x54, 0x1F, 0x59, 0x21, 0x58, 0x21, 0x5A, 0x21, 0x58, 0x20, 0x55, 0x20, 0x55, 0x20, 0x57, 0x20, 0x58, 0x21, 0x5B, 0x22, 0x56, 0x20, 0x57, 0x21, 0x57, 0x21, 0x55, 0x20, 0x55, 0x20, 0x54, 0x1F, 0x4B, 0x20, 0x3B, 0x1E, 0x3C, 0x20, 0x38, 0x1C, 0x2C, 0x19, 0x32, 0x1B, 0x32, 0x1C, 0x32, 0x1B, 0x2F, 0x1A, 0x36, 0x1F, 0x39, 0x1F, 0x33, 0x1D, 0x3A, 0x1F, 0x40, 0x21, 0x3E, 0x21, 0x40, 0x21, 0x36, 0x1D, 0x44, 0x23, 0x44, 0x23, 0x3B, 0x1F, 0x30, 0x1B, 0x3C, 0x20, 0x37, 0x1D, 0x3D, 0x20, 0x31, 0x1A, 0x3E, 0x21, 0x34, 0x1C, 0x34, 0x1F, 0x41, 0x22, 0x43, 0x25, 0x3D, 0x22, 0x49, 0x29, 0x4B, 0x28, 0x4E, 0x28, 0x31, 0x1B, 0x2A, 0x19, 0x34, 0x1C, 0x4A, 0x2A, 0x67, 0x35, 0x68, 0x37, 0x6F, 0x3A, 0x73, 0x3B, 0x70, 0x39, 0x6B, 0x36, 0x43, 0x23, 0x2F, 0x1B, 0x3D, 0x20
    },

    {
        0x63, 0x57, 0x63, 0x59, 0x65, 0x5A, 0x65, 0x58, 0x65, 0x59, 0x65, 0x5A, 0x65, 0x58, 0x65, 0x5A, 0x64, 0x58, 0x63, 0x57, 0x64, 0x58, 0x66, 0x58, 0x66, 0x59, 0x66, 0x59, 0x66, 0x59, 0x67, 0x5A, 0x68, 0x5B, 0x68, 0x59, 0x65, 0x59, 0x68, 0x59, 0x67, 0x59, 0x63, 0x58, 0x60, 0x53, 0x57, 0x4A, 0x46, 0x3B, 0x3B, 0x38, 0x47, 0x47, 0x57, 0x51, 0x58, 0x4F, 0x50, 0x47, 0x39, 0x32, 0x25, 0x23, 0x1E, 0x1F, 0x1A, 0x1D, 0x19, 0x1B, 0x17, 0x1A, 0x16, 0x19, 0x15, 0x19, 0x15, 0x19, 0x15, 0x19, 0x16, 0x1A, 0x16, 0x1B, 0x16, 0x1B, 0x17, 0x1B, 0x16, 0x1B, 0x15, 0x19, 0x15, 0x19, 0x14, 0x18, 0x14, 0x17, 0x13, 0x17, 0x14, 0x18, 0x14, 0x19, 0x14, 0x18, 0x14, 0x18, 0x13, 0x17, 0x13, 0x17, 0x13, 0x16, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x14, 0x17, 0x13, 0x18, 0x15, 0x19, 0x14, 0x19, 0x14, 0x18, 0x14, 0x19, 0x15, 0x19, 0x17, 0x1F, 0x20, 0x37, 0x2E, 0x55, 0x35, 0x63, 0x37, 0x69, 0x39, 0x68, 0x37, 0x65, 0x2D, 0x4A, 0x20, 0x2B, 0x1A, 0x21, 0x18, 0x1E, 0x16, 0x1B, 0x16, 0x1A, 0x17, 0x20, 0x1C, 0x2A, 0x1F, 0x30, 0x20, 0x32, 0x1F, 0x30, 0x1E, 0x2F, 0x1C, 0x28, 0x18, 0x1E, 0x16, 0x1B, 0x17, 0x1B, 0x15, 0x19, 0x15, 0x19, 0x14, 0x19, 0x15, 0x19, 0x15, 0x19, 0x15, 0x19, 0x15, 0x19, 0x15, 0x19, 0x15, 0x19, 0x14, 0x18, 0x15, 0x19, 0x15, 0x19, 0x16, 0x19, 0x16, 0x1A, 0x15, 0x19, 0x16, 0x1A, 0x15, 0x1A, 0x16, 0x1B, 0x16, 0x1C, 0x16, 0x1B, 0x17, 0x1C, 0x17, 0x1B, 0x17, 0x1C, 0x17, 0x1C, 0x17, 0x1C, 0x16, 0x1A, 0x17, 0x1C, 0x18, 0x1C, 0x18, 0x1C, 0x19, 0x1D, 0x25, 0x29, 0x48, 0x4D, 0x61, 0x5C, 0x66, 0x5F, 0x54, 0x4A, 0x37, 0x33, 0x49, 0x4B, 0x65, 0x60, 0x70, 0x69, 0x74, 0x6A, 0x74, 0x69, 0x74, 0x68, 0x76, 0x6A, 0x75, 0x69, 0x75, 0x68, 0x72, 0x66, 0x73, 0x68, 0x73, 0x69, 0x74, 0x6A, 0x75, 0x6B, 0x79, 0x6E, 0x74, 0x69, 0x74, 0x69, 0x75, 0x6A, 0x75, 0x69, 0x74, 0x68, 0x71, 0x65, 0x71, 0x66, 0x74, 0x68, 0x76, 0x6A, 0x71, 0x67, 0x6F, 0x62, 0x70, 0x63, 0x71, 0x65, 0x70, 0x65, 0x72, 0x66, 0x74, 0x65, 0x74, 0x66, 0x70, 0x62, 0x71, 0x65, 0x72, 0x68, 0x70, 0x64, 0x71, 0x68, 0x6C, 0x60, 0x6D, 0x65, 0x73, 0x68, 0x70, 0x66, 0x73, 0x67, 0x75, 0x69, 0x75, 0x6A, 0x71, 0x66, 0x73, 0x6A, 0x77, 0x6C, 0x75, 0x6B, 0x75, 0x69, 0x72, 0x64, 0x74, 0x68, 0x74, 0x66, 0x74, 0x68, 0x72, 0x64, 0x71, 0x63, 0x6F, 0x61, 0x72, 0x64, 0x72, 0x64, 0x73, 0x65, 0x76, 0x68, 0x75, 0x67, 0x74, 0x65, 0x76, 0x6A, 0x75, 0x69, 0x72, 0x65, 0x71, 0x63, 0x70, 0x62, 0x74, 0x69, 0x72, 0x63, 0x6E, 0x62, 0x6B, 0x5E, 0x6D, 0x62, 0x5C, 0x52, 0x4C, 0x4E, 0x48, 0x49, 0x47, 0x4B, 0x48, 0x4B, 0x47, 0x49, 0x46, 0x48, 0x45, 0x44, 0x58, 0x51, 0x61, 0x58, 0x66, 0x5B, 0x68, 0x5E, 0x67, 0x6B, 0x5E, 0x67, 0x50, 0x53, 0x49, 0x45, 0x50, 0x4B, 0x62, 0x59, 0x66, 0x5D, 0x6B, 0x61, 0x6A, 0x5D, 0x69, 0x5C, 0x69, 0x5E, 0x70, 0x63, 0x6C, 0x5E, 0x6A, 0x5E, 0x6A, 0x5C, 0x6B, 0x61, 0x6A, 0x5F, 0x67, 0x5E, 0x6D, 0x62, 0x71, 0x66, 0x70, 0x63, 0x6A, 0x5E, 0x6C, 0x60, 0x69, 0x5D, 0x6D, 0x62, 0x6B, 0x5F, 0x6C, 0x61, 0x69, 0x5F, 0x6A, 0x5E, 0x6C, 0x5F, 0x69, 0x5C, 0x66, 0x59, 0x6A, 0x5D, 0x6C, 0x5F, 0x68, 0x5F, 0x6B, 0x60, 0x68, 0x5E, 0x68, 0x5D, 0x68, 0x5D, 0x69, 0x5D, 0x68, 0x5D, 0x68, 0x5D, 0x64, 0x59, 0x64, 0x5B, 0x67, 0x5D, 0x67, 0x59, 0x61, 0x55, 0x65, 0x58, 0x66, 0x5A, 0x68, 0x5B, 0x64, 0x57, 0x60, 0x55, 0x62, 0x57, 0x64, 0x59, 0x63, 0x59, 0x67, 0x5B, 0x61, 0x56, 0x62, 0x57, 0x61, 0x58, 0x62, 0x57, 0x61, 0x55, 0x5F, 0x54, 0x4D, 0x47, 0x36, 0x36, 0x35, 0x3B, 0x30, 0x32, 0x28, 0x2C, 0x2F, 0x35, 0x2F, 0x35, 0x2B, 0x2F, 0x2D, 0x32, 0x31, 0x39, 0x35, 0x3B, 0x2E, 0x33, 0x36, 0x3E, 0x3A, 0x40, 0x34, 0x39, 0x38, 0x3E, 0x31, 0x37, 0x3C, 0x43, 0x38, 0x3D, 0x33, 0x37, 0x2E, 0x31, 0x38, 0x3F, 0x32, 0x35, 0x36, 0x3C, 0x2A, 0x2E, 0x38, 0x3F, 0x2C, 0x2F, 0x34, 0x41, 0x3E, 0x47, 0x42, 0x4C, 0x3E, 0x47, 0x49, 0x56, 0x49, 0x55, 0x48, 0x51, 0x2D, 0x2F, 0x28, 0x2D, 0x32, 0x37, 0x45, 0x58, 0x5C, 0x6E, 0x5E, 0x72, 0x60, 0x72, 0x60, 0x75, 0x5F, 0x71, 0x59, 0x68, 0x35, 0x38, 0x2B, 0x31, 0x38, 0x40
    },

    {
        0x58, 0x1F, 0x57, 0x1F, 0x58, 0x20, 0x59, 0x1F, 0x5A, 0x1F, 0x5A, 0x20, 0x5A, 0x20, 0x5A, 0x20, 0x59, 0x20, 0x59, 0x20, 0x5A, 0x21, 0x5B, 0x21, 0x5B, 0x20, 0x59, 0x1F, 0x58, 0x1F, 0x59, 0x1F, 0x5B, 0x1F, 0x58, 0x20, 0x58, 0x1F, 0x57, 0x1F, 0x58, 0x1F, 0x58, 0x1F, 0x55, 0x1E, 0x52, 0x1E, 0x4D, 0x1D, 0x3E, 0x1A, 0x38, 0x1A, 0x46, 0x1D, 0x53, 0x1F, 0x51, 0x1F, 0x4B, 0x1D, 0x32, 0x16, 0x23, 0x13, 0x1E, 0x12, 0x1C, 0x11, 0x1A, 0x11, 0x1A, 0x11, 0x19, 0x10, 0x19, 0x11, 0x19, 0x11, 0x1B, 0x12, 0x1D, 0x12, 0x1B, 0x12, 0x1B, 0x12, 0x1A, 0x12, 0x19, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x10, 0x18, 0x11, 0x18, 0x12, 0x18, 0x11, 0x18, 0x10, 0x18, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x18, 0x10, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x19, 0x11, 0x19, 0x11, 0x19, 0x11, 0x19, 0x11, 0x19, 0x12, 0x18, 0x11, 0x19, 0x12, 0x1F, 0x16, 0x34, 0x23, 0x56, 0x32, 0x63, 0x35, 0x66, 0x37, 0x58, 0x2E, 0x36, 0x1E, 0x25, 0x17, 0x1F, 0x14, 0x1D, 0x13, 0x1B, 0x13, 0x1B, 0x13, 0x1C, 0x14, 0x20, 0x18, 0x27, 0x1F, 0x30, 0x23, 0x31, 0x23, 0x2A, 0x1D, 0x20, 0x16, 0x1D, 0x14, 0x1C, 0x13, 0x1B, 0x13, 0x1A, 0x12, 0x19, 0x11, 0x18, 0x11, 0x19, 0x11, 0x19, 0x12, 0x19, 0x12, 0x19, 0x12, 0x19, 0x11, 0x19, 0x11, 0x18, 0x11, 0x19, 0x11, 0x19, 0x12, 0x1A, 0x12, 0x1A, 0x12, 0x1A, 0x12, 0x1A, 0x12, 0x1A, 0x12, 0x1A, 0x12, 0x1B, 0x13, 0x1B, 0x12, 0x1B, 0x12, 0x1B, 0x13, 0x1D, 0x14, 0x1C, 0x13, 0x1B, 0x13, 0x1B, 0x13, 0x1D, 0x13, 0x1C, 0x13, 0x1C, 0x13, 0x20, 0x15, 0x3F, 0x1D, 0x5E, 0x24, 0x63, 0x26, 0x5A, 0x23, 0x39, 0x1C, 0x3F, 0x1F, 0x59, 0x24, 0x63, 0x26, 0x69, 0x28, 0x69, 0x28, 0x66, 0x26, 0x6B, 0x27, 0x69, 0x27, 0x6A, 0x27, 0x6C, 0x28, 0x6A, 0x27, 0x68, 0x29, 0x6A, 0x27, 0x6B, 0x28, 0x67, 0x27, 0x6E, 0x29, 0x6C, 0x28, 0x6B, 0x28, 0x6A, 0x27, 0x6A, 0x28, 0x68, 0x27, 0x68, 0x27, 0x62, 0x26, 0x69, 0x27, 0x65, 0x26, 0x66, 0x26, 0x64, 0x25, 0x67, 0x27, 0x67, 0x26, 0x62, 0x25, 0x69, 0x27, 0x66, 0x27, 0x66, 0x26, 0x67, 0x26, 0x66, 0x27, 0x6A, 0x28, 0x66, 0x25, 0x62, 0x25, 0x65, 0x25, 0x66, 0x26, 0x66, 0x26, 0x63, 0x25, 0x65, 0x25, 0x68, 0x26, 0x64, 0x26, 0x66, 0x26, 0x69, 0x27, 0x6B, 0x28, 0x6C, 0x28, 0x6A, 0x26, 0x66, 0x25, 0x63, 0x24, 0x63, 0x24, 0x64, 0x24, 0x62, 0x24, 0x65, 0x24, 0x64, 0x24, 0x63, 0x23, 0x62, 0x23, 0x67, 0x25, 0x68, 0x26, 0x67, 0x24, 0x65, 0x24, 0x68, 0x25, 0x65, 0x24, 0x61, 0x24, 0x60, 0x23, 0x61, 0x23, 0x6A, 0x29, 0x65, 0x24, 0x61, 0x23, 0x5E, 0x21, 0x60, 0x22, 0x4F, 0x21, 0x4B, 0x25, 0x4A, 0x25, 0x4B, 0x24, 0x48, 0x24, 0x47, 0x24, 0x48, 0x23, 0x39, 0x1A, 0x45, 0x1C, 0x58, 0x21, 0x5B, 0x21, 0x5E, 0x2F, 0x69, 0x3C, 0x53, 0x2E, 0x41, 0x25, 0x34, 0x1D, 0x2B, 0x18, 0x44, 0x1C, 0x57, 0x20, 0x59, 0x22, 0x5C, 0x22, 0x5E, 0x23, 0x5D, 0x23, 0x5B, 0x22, 0x5B, 0x22, 0x5D, 0x22, 0x5C, 0x22, 0x60, 0x23, 0x5D, 0x22, 0x61, 0x24, 0x63, 0x24, 0x61, 0x23, 0x63, 0x26, 0x5F, 0x23, 0x5C, 0x22, 0x5B, 0x22, 0x5C, 0x22, 0x5F, 0x22, 0x5E, 0x21, 0x5A, 0x21, 0x5F, 0x23, 0x5E, 0x23, 0x5A, 0x22, 0x5C, 0x22, 0x5E, 0x23, 0x5D, 0x22, 0x5D, 0x22, 0x5C, 0x22, 0x60, 0x24, 0x5C, 0x22, 0x61, 0x23, 0x5F, 0x23, 0x5C, 0x21, 0x5B, 0x21, 0x57, 0x20, 0x5B, 0x21, 0x59, 0x20, 0x58, 0x20, 0x56, 0x20, 0x5C, 0x22, 0x5C, 0x21, 0x59, 0x21, 0x5A, 0x21, 0x5A, 0x21, 0x5C, 0x21, 0x58, 0x20, 0x58, 0x20, 0x58, 0x21, 0x56, 0x20, 0x53, 0x1F, 0x56, 0x21, 0x54, 0x20, 0x54, 0x1F, 0x58, 0x20, 0x47, 0x1E, 0x39, 0x1E, 0x32, 0x1B, 0x36, 0x1E, 0x3C, 0x20, 0x42, 0x22, 0x3D, 0x1F, 0x36, 0x1D, 0x3F, 0x21, 0x31, 0x1B, 0x3A, 0x1F, 0x31, 0x1C, 0x41, 0x22, 0x34, 0x1C, 0x2C, 0x19, 0x36, 0x1D, 0x32, 0x1D, 0x42, 0x24, 0x40, 0x23, 0x4C, 0x29, 0x4C, 0x29, 0x5D, 0x30, 0x4F, 0x2A, 0x4D, 0x25, 0x2D, 0x1A, 0x38, 0x1E, 0x31, 0x1C, 0x5D, 0x33, 0x70, 0x3A, 0x71, 0x3B, 0x74, 0x3B, 0x75, 0x3C, 0x72, 0x3A, 0x66, 0x32, 0x34, 0x1D, 0x32, 0x1C, 0x41, 0x22, 0x55, 0x2F, 0x6D, 0x38, 0x71, 0x3B, 0x6F, 0x39, 0x6D, 0x39, 0x68, 0x36, 0x5F, 0x30, 0x2C, 0x19, 0x2B, 0x1A, 0x3A, 0x1E
    },

    {
        0x63, 0x58, 0x63, 0x57, 0x64, 0x59, 0x64, 0x59, 0x66, 0x5A, 0x68, 0x5A, 0x67, 0x5B, 0x65, 0x59, 0x65, 0x59, 0x65, 0x5A, 0x66, 0x5D, 0x68, 0x5C, 0x67, 0x5A, 0x65, 0x57, 0x65, 0x58, 0x66, 0x59, 0x68, 0x5A, 0x65, 0x59, 0x65, 0x57, 0x65, 0x58, 0x65, 0x58, 0x64, 0x58, 0x63, 0x55, 0x5F, 0x52, 0x59, 0x4E, 0x4C, 0x3F, 0x3E, 0x37, 0x44, 0x44, 0x57, 0x51, 0x5A, 0x51, 0x53, 0x4A, 0x3F, 0x35, 0x28, 0x24, 0x1F, 0x1F, 0x1B, 0x1C, 0x19, 0x1B, 0x18, 0x1A, 0x16, 0x19, 0x16, 0x19, 0x16, 0x1A, 0x16, 0x1C, 0x18, 0x1D, 0x16, 0x1B, 0x16, 0x1A, 0x15, 0x1A, 0x15, 0x18, 0x15, 0x18, 0x14, 0x18, 0x14, 0x17, 0x14, 0x18, 0x14, 0x19, 0x14, 0x17, 0x14, 0x18, 0x14, 0x17, 0x13, 0x16, 0x13, 0x17, 0x13, 0x16, 0x13, 0x17, 0x14, 0x17, 0x13, 0x18, 0x14, 0x18, 0x14, 0x18, 0x14, 0x19, 0x14, 0x18, 0x14, 0x18, 0x14, 0x19, 0x15, 0x19, 0x14, 0x19, 0x15, 0x19, 0x16, 0x1D, 0x1D, 0x31, 0x2C, 0x52, 0x33, 0x60, 0x34, 0x5F, 0x2E, 0x4A, 0x20, 0x2B, 0x1A, 0x21, 0x17, 0x1D, 0x16, 0x1C, 0x16, 0x1B, 0x16, 0x1B, 0x17, 0x1B, 0x17, 0x1E, 0x1B, 0x26, 0x1E, 0x2F, 0x1F, 0x2E, 0x1C, 0x26, 0x18, 0x1D, 0x17, 0x1C, 0x16, 0x1B, 0x16, 0x1B, 0x15, 0x19, 0x14, 0x18, 0x14, 0x19, 0x14, 0x19, 0x15, 0x19, 0x15, 0x19, 0x15, 0x19, 0x15, 0x1A, 0x14, 0x18, 0x14, 0x18, 0x14, 0x19, 0x15, 0x1A, 0x16, 0x1B, 0x16, 0x1B, 0x15, 0x1A, 0x15, 0x19, 0x15, 0x1A, 0x15, 0x1A, 0x16, 0x1B, 0x17, 0x1A, 0x16, 0x1B, 0x17, 0x1B, 0x17, 0x1C, 0x17, 0x1C, 0x16, 0x1B, 0x16, 0x1B, 0x18, 0x1C, 0x18, 0x1C, 0x19, 0x1D, 0x22, 0x26, 0x47, 0x4D, 0x68, 0x62, 0x6B, 0x63, 0x59, 0x51, 0x38, 0x34, 0x45, 0x4A, 0x62, 0x5D, 0x6E, 0x66, 0x74, 0x6A, 0x73, 0x68, 0x73, 0x68, 0x79, 0x6C, 0x76, 0x69, 0x77, 0x6A, 0x7A, 0x6C, 0x76, 0x6A, 0x72, 0x6C, 0x75, 0x68, 0x75, 0x6B, 0x75, 0x69, 0x79, 0x6E, 0x79, 0x6D, 0x78, 0x69, 0x74, 0x69, 0x74, 0x6B, 0x73, 0x68, 0x73, 0x68, 0x70, 0x62, 0x77, 0x6A, 0x71, 0x65, 0x73, 0x68, 0x70, 0x64, 0x70, 0x67, 0x70, 0x65, 0x6E, 0x62, 0x74, 0x69, 0x73, 0x68, 0x74, 0x68, 0x73, 0x69, 0x76, 0x6A, 0x76, 0x6A, 0x74, 0x66, 0x6E, 0x64, 0x71, 0x65, 0x73, 0x67, 0x72, 0x64, 0x70, 0x66, 0x71, 0x64, 0x74, 0x67, 0x70, 0x63, 0x72, 0x67, 0x76, 0x69, 0x76, 0x6B, 0x7A, 0x6D, 0x77, 0x6A, 0x75, 0x66, 0x71, 0x64, 0x70, 0x61, 0x70, 0x64, 0x6E, 0x62, 0x72, 0x65, 0x74, 0x68, 0x72, 0x62, 0x70, 0x63, 0x75, 0x67, 0x77, 0x6A, 0x75, 0x65, 0x74, 0x66, 0x75, 0x67, 0x71, 0x65, 0x70, 0x63, 0x6D, 0x62, 0x70, 0x61, 0x72, 0x68, 0x74, 0x65, 0x6F, 0x61, 0x6B, 0x5F, 0x6D, 0x60, 0x55, 0x4D, 0x4B, 0x4B, 0x49, 0x4A, 0x48, 0x49, 0x46, 0x48, 0x45, 0x46, 0x44, 0x45, 0x3A, 0x36, 0x4A, 0x49, 0x64, 0x5A, 0x66, 0x5A, 0x5E, 0x62, 0x58, 0x5D, 0x47, 0x44, 0x3B, 0x3A, 0x35, 0x30, 0x2D, 0x2A, 0x45, 0x45, 0x60, 0x58, 0x64, 0x5A, 0x69, 0x5E, 0x6B, 0x60, 0x6A, 0x5F, 0x68, 0x5D, 0x67, 0x5D, 0x6B, 0x60, 0x68, 0x5D, 0x6C, 0x60, 0x6A, 0x5E, 0x71, 0x65, 0x6E, 0x63, 0x6E, 0x62, 0x6F, 0x65, 0x6B, 0x5F, 0x68, 0x5D, 0x69, 0x5D, 0x68, 0x5E, 0x6C, 0x61, 0x6A, 0x5D, 0x66, 0x5B, 0x6B, 0x5F, 0x6A, 0x5E, 0x69, 0x5D, 0x68, 0x5D, 0x68, 0x5C, 0x6A, 0x5D, 0x68, 0x5D, 0x68, 0x5D, 0x6C, 0x60, 0x6B, 0x5F, 0x70, 0x62, 0x6C, 0x60, 0x68, 0x5C, 0x66, 0x59, 0x63, 0x58, 0x66, 0x5A, 0x65, 0x5A, 0x66, 0x5A, 0x63, 0x58, 0x66, 0x5B, 0x66, 0x5B, 0x65, 0x5B, 0x67, 0x5B, 0x67, 0x5B, 0x68, 0x5B, 0x64, 0x59, 0x66, 0x5B, 0x64, 0x58, 0x62, 0x58, 0x5C, 0x52, 0x61, 0x57, 0x61, 0x55, 0x61, 0x57, 0x65, 0x58, 0x4A, 0x43, 0x38, 0x3C, 0x2C, 0x30, 0x35, 0x3E, 0x37, 0x3F, 0x38, 0x3E, 0x35, 0x3C, 0x33, 0x39, 0x3D, 0x43, 0x2E, 0x32, 0x36, 0x39, 0x2F, 0x36, 0x3C, 0x41, 0x2F, 0x32, 0x29, 0x2D, 0x30, 0x34, 0x2E, 0x35, 0x3F, 0x4B, 0x42, 0x4D, 0x4C, 0x59, 0x4E, 0x5C, 0x58, 0x67, 0x4F, 0x5C, 0x45, 0x49, 0x2C, 0x33, 0x33, 0x39, 0x2E, 0x37, 0x50, 0x67, 0x5F, 0x74, 0x60, 0x74, 0x62, 0x76, 0x64, 0x75, 0x5F, 0x6F, 0x54, 0x5D, 0x2A, 0x2F, 0x2D, 0x33, 0x37, 0x3F, 0x49, 0x5B, 0x59, 0x6A, 0x5B, 0x6C, 0x57, 0x68, 0x53, 0x65, 0x4F, 0x5D, 0x45, 0x4E, 0x23, 0x25, 0x27, 0x2E, 0x31, 0x36
    },

    {
        0x59, 0x20, 0x59, 0x1F, 0x5A, 0x20, 0x59, 0x20, 0x59, 0x1F, 0x5A, 0x20, 0x5A, 0x20, 0x5B, 0x20, 0x5A, 0x20, 0x59, 0x20, 0x5B, 0x21, 0x5C, 0x20, 0x5A, 0x20, 0x58, 0x20, 0x5A, 0x20, 0x5B, 0x21, 0x5A, 0x20, 0x59, 0x20, 0x59, 0x20, 0x58, 0x20, 0x58, 0x20, 0x59, 0x20, 0x5A, 0x20, 0x58, 0x1F, 0x57, 0x20, 0x53, 0x1F, 0x45, 0x1C, 0x38, 0x19, 0x41, 0x1C, 0x50, 0x1E, 0x50, 0x1E, 0x4B, 0x1C, 0x39, 0x18, 0x26, 0x14, 0x1E, 0x13, 0x1C, 0x11, 0x1B, 0x11, 0x1A, 0x11, 0x1A, 0x11, 0x1A, 0x12, 0x1B, 0x13, 0x1B, 0x12, 0x1A, 0x12, 0x19, 0x11, 0x19, 0x11, 0x18, 0x10, 0x18, 0x11, 0x17, 0x10, 0x17, 0x11, 0x18, 0x11, 0x19, 0x11, 0x18, 0x11, 0x18, 0x11, 0x19, 0x11, 0x18, 0x10, 0x17, 0x10, 0x18, 0x10, 0x19, 0x11, 0x19, 0x12, 0x18, 0x11, 0x18, 0x11, 0x19, 0x11, 0x19, 0x11, 0x19, 0x11, 0x19, 0x11, 0x1A, 0x12, 0x1A, 0x12, 0x1A, 0x11, 0x19, 0x11, 0x19, 0x12, 0x1C, 0x15, 0x2E, 0x1F, 0x4E, 0x2D, 0x50, 0x2B, 0x33, 0x1E, 0x24, 0x17, 0x1F, 0x15, 0x1D, 0x13, 0x1B, 0x13, 0x1A, 0x12, 0x1B, 0x13, 0x1A, 0x12, 0x1B, 0x13, 0x1E, 0x17, 0x28, 0x1E, 0x2C, 0x1F, 0x24, 0x18, 0x1E, 0x15, 0x1E, 0x15, 0x1B, 0x12, 0x19, 0x12, 0x19, 0x11, 0x19, 0x12, 0x1A, 0x12, 0x19, 0x11, 0x1A, 0x12, 0x1A, 0x12, 0x18, 0x11, 0x1A, 0x12, 0x19, 0x11, 0x19, 0x11, 0x19, 0x11, 0x19, 0x12, 0x1A, 0x12, 0x1A, 0x12, 0x1A, 0x12, 0x1A, 0x12, 0x1A, 0x12, 0x1B, 0x12, 0x1B, 0x12, 0x1B, 0x12, 0x1C, 0x13, 0x1B, 0x13, 0x1D, 0x14, 0x1C, 0x13, 0x1C, 0x13, 0x1B, 0x12, 0x1C, 0x13, 0x1D, 0x13, 0x1F, 0x15, 0x3D, 0x1E, 0x5D, 0x24, 0x66, 0x27, 0x5B, 0x24, 0x3D, 0x1E, 0x3F, 0x1F, 0x57, 0x25, 0x63, 0x25, 0x68, 0x27, 0x6A, 0x27, 0x67, 0x28, 0x69, 0x27, 0x6C, 0x27, 0x66, 0x26, 0x67, 0x27, 0x6A, 0x27, 0x67, 0x26, 0x6A, 0x28, 0x69, 0x27, 0x6B, 0x28, 0x6C, 0x28, 0x6D, 0x28, 0x6C, 0x28, 0x6D, 0x28, 0x67, 0x27, 0x6A, 0x28, 0x69, 0x27, 0x69, 0x27, 0x67, 0x27, 0x69, 0x27, 0x69, 0x28, 0x6A, 0x27, 0x68, 0x26, 0x65, 0x27, 0x65, 0x27, 0x67, 0x26, 0x67, 0x26, 0x69, 0x28, 0x6A, 0x27, 0x69, 0x27, 0x6B, 0x29, 0x6A, 0x28, 0x69, 0x27, 0x6A, 0x27, 0x68, 0x27, 0x66, 0x26, 0x68, 0x27, 0x6D, 0x28, 0x66, 0x25, 0x69, 0x27, 0x67, 0x26, 0x66, 0x27, 0x67, 0x27, 0x68, 0x26, 0x69, 0x27, 0x67, 0x26, 0x64, 0x25, 0x65, 0x25, 0x62, 0x24, 0x61, 0x24, 0x62, 0x24, 0x66, 0x24, 0x68, 0x26, 0x63, 0x23, 0x63, 0x24, 0x67, 0x24, 0x68, 0x25, 0x66, 0x24, 0x66, 0x24, 0x6A, 0x26, 0x66, 0x25, 0x65, 0x25, 0x64, 0x24, 0x66, 0x24, 0x64, 0x23, 0x63, 0x24, 0x63, 0x24, 0x63, 0x24, 0x61, 0x23, 0x54, 0x24, 0x4B, 0x24, 0x4A, 0x25, 0x48, 0x24, 0x47, 0x23, 0x47, 0x24, 0x47, 0x21, 0x30, 0x16, 0x3E, 0x1B, 0x58, 0x21, 0x58, 0x23, 0x51, 0x2D, 0x40, 0x23, 0x2B, 0x18, 0x28, 0x16, 0x27, 0x17, 0x24, 0x14, 0x2E, 0x18, 0x57, 0x21, 0x5B, 0x23, 0x5C, 0x23, 0x5F, 0x23, 0x5D, 0x23, 0x5B, 0x21, 0x61, 0x24, 0x61, 0x24, 0x5E, 0x23, 0x5C, 0x22, 0x60, 0x24, 0x62, 0x24, 0x5F, 0x23, 0x5B, 0x22, 0x61, 0x24, 0x60, 0x23, 0x5D, 0x22, 0x5F, 0x22, 0x5E, 0x23, 0x5D, 0x22, 0x5C, 0x22, 0x5B, 0x22, 0x5B, 0x22, 0x5C, 0x22, 0x5B, 0x22, 0x5B, 0x21, 0x5B, 0x21, 0x58, 0x22, 0x60, 0x24, 0x5D, 0x22, 0x5E, 0x23, 0x5D, 0x22, 0x5E, 0x23, 0x5F, 0x23, 0x5B, 0x21, 0x5A, 0x21, 0x5C, 0x22, 0x5A, 0x21, 0x5B, 0x22, 0x59, 0x21, 0x57, 0x21, 0x5A, 0x21, 0x59, 0x20, 0x5B, 0x21, 0x5C, 0x22, 0x5A, 0x21, 0x5A, 0x21, 0x58, 0x20, 0x58, 0x21, 0x58, 0x21, 0x59, 0x22, 0x59, 0x22, 0x58, 0x21, 0x54, 0x1F, 0x59, 0x21, 0x5A, 0x21, 0x43, 0x20, 0x3C, 0x1F, 0x31, 0x1B, 0x3B, 0x20, 0x30, 0x1B, 0x2D, 0x1B, 0x42, 0x25, 0x4B, 0x29, 0x5D, 0x30, 0x57, 0x2F, 0x63, 0x34, 0x5D, 0x31, 0x68, 0x35, 0x3A, 0x1E, 0x2C, 0x19, 0x39, 0x1E, 0x3D, 0x24, 0x6D, 0x39, 0x75, 0x3D, 0x75, 0x3D, 0x78, 0x3D, 0x79, 0x3F, 0x78, 0x3E, 0x55, 0x2A, 0x30, 0x1E, 0x3D, 0x21, 0x37, 0x1E, 0x62, 0x35, 0x6F, 0x3A, 0x6E, 0x39, 0x68, 0x37, 0x62, 0x34, 0x5B, 0x31, 0x4D, 0x29, 0x25, 0x17, 0x2D, 0x1B, 0x32, 0x1C, 0x3D, 0x23, 0x3C, 0x21, 0x34, 0x1E, 0x2C, 0x1B, 0x29, 0x1B, 0x25, 0x17, 0x21, 0x15, 0x1F, 0x14, 0x31, 0x1C, 0x32, 0x1C
    },

    {
        0x64, 0x58, 0x64, 0x57, 0x65, 0x59, 0x65, 0x59, 0x65, 0x59, 0x66, 0x59, 0x67, 0x5B, 0x67, 0x5B, 0x66, 0x5A, 0x66, 0x5B, 0x67, 0x5A, 0x67, 0x5A, 0x67, 0x59, 0x65, 0x58, 0x67, 0x5A, 0x68, 0x5A, 0x66, 0x59, 0x66, 0x58, 0x64, 0x59, 0x65, 0x59, 0x64, 0x58, 0x65, 0x59, 0x67, 0x59, 0x65, 0x58, 0x64, 0x58, 0x60, 0x54, 0x54, 0x46, 0x3E, 0x36, 0x3F, 0x3F, 0x53, 0x4E, 0x59, 0x50, 0x56, 0x4D, 0x46, 0x3C, 0x2C, 0x27, 0x20, 0x1F, 0x1B, 0x1C, 0x19, 0x1B, 0x18, 0x1A, 0x17, 0x1A, 0x17, 0x1A, 0x17, 0x1A, 0x16, 0x19, 0x15, 0x19, 0x15, 0x18, 0x14, 0x18, 0x14, 0x17, 0x14, 0x17, 0x13, 0x17, 0x14, 0x17, 0x14, 0x17, 0x14, 0x18, 0x13, 0x16, 0x14, 0x18, 0x14, 0x18, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x14, 0x18, 0x14, 0x18, 0x14, 0x17, 0x14, 0x18, 0x15, 0x19, 0x15, 0x19, 0x14, 0x19, 0x15, 0x19, 0x14, 0x19, 0x15, 0x19, 0x15, 0x19, 0x14, 0x18, 0x15, 0x19, 0x16, 0x1B, 0x1B, 0x2A, 0x28, 0x48, 0x2A, 0x41, 0x20, 0x29, 0x1A, 0x21, 0x18, 0x1D, 0x16, 0x1B, 0x15, 0x1A, 0x15, 0x1A, 0x16, 0x1A, 0x16, 0x1B, 0x17, 0x1C, 0x18, 0x1E, 0x1C, 0x27, 0x20, 0x2A, 0x1D, 0x22, 0x19, 0x1E, 0x18, 0x1D, 0x16, 0x1A, 0x15, 0x19, 0x15, 0x19, 0x14, 0x19, 0x15, 0x19, 0x15, 0x19, 0x15, 0x1A, 0x15, 0x19, 0x14, 0x18, 0x15, 0x19, 0x15, 0x19, 0x15, 0x18, 0x15, 0x19, 0x15, 0x1A, 0x16, 0x19, 0x16, 0x1A, 0x15, 0x19, 0x16, 0x19, 0x16, 0x1A, 0x16, 0x1A, 0x16, 0x1A, 0x16, 0x1B, 0x17, 0x1B, 0x17, 0x1B, 0x17, 0x1C, 0x18, 0x1D, 0x17, 0x1B, 0x17, 0x1B, 0x18, 0x1C, 0x19, 0x1D, 0x21, 0x25, 0x46, 0x4C, 0x64, 0x60, 0x6C, 0x65, 0x5B, 0x50, 0x39, 0x34, 0x49, 0x4A, 0x62, 0x5E, 0x6F, 0x65, 0x73, 0x68, 0x73, 0x67, 0x73, 0x69, 0x76, 0x69, 0x78, 0x6B, 0x72, 0x66, 0x76, 0x6A, 0x77, 0x6B, 0x74, 0x67, 0x75, 0x69, 0x76, 0x6A, 0x76, 0x6C, 0x79, 0x6B, 0x78, 0x6C, 0x79, 0x6C, 0x7A, 0x6A, 0x72, 0x66, 0x75, 0x6A, 0x75, 0x67, 0x76, 0x6C, 0x75, 0x6A, 0x77, 0x6A, 0x77, 0x6C, 0x75, 0x6A, 0x74, 0x68, 0x6F, 0x66, 0x72, 0x67, 0x71, 0x67, 0x75, 0x69, 0x75, 0x68, 0x74, 0x69, 0x77, 0x69, 0x77, 0x6A, 0x74, 0x69, 0x75, 0x69, 0x76, 0x6A, 0x75, 0x69, 0x74, 0x67, 0x75, 0x6B, 0x78, 0x6C, 0x74, 0x66, 0x76, 0x6A, 0x76, 0x68, 0x75, 0x68, 0x75, 0x69, 0x77, 0x68, 0x77, 0x6A, 0x74, 0x67, 0x73, 0x66, 0x75, 0x66, 0x71, 0x63, 0x70, 0x61, 0x71, 0x63, 0x73, 0x65, 0x76, 0x69, 0x75, 0x64, 0x70, 0x63, 0x74, 0x66, 0x77, 0x68, 0x74, 0x66, 0x75, 0x68, 0x77, 0x6B, 0x74, 0x65, 0x71, 0x65, 0x70, 0x64, 0x73, 0x67, 0x71, 0x64, 0x71, 0x66, 0x71, 0x63, 0x71, 0x65, 0x6D, 0x60, 0x59, 0x52, 0x49, 0x4A, 0x47, 0x4A, 0x47, 0x48, 0x45, 0x49, 0x45, 0x47, 0x44, 0x43, 0x30, 0x2D, 0x43, 0x43, 0x62, 0x5A, 0x60, 0x58, 0x4E, 0x4C, 0x3E, 0x37, 0x2E, 0x29, 0x2C, 0x26, 0x2A, 0x27, 0x24, 0x20, 0x34, 0x36, 0x60, 0x5A, 0x64, 0x5D, 0x66, 0x5C, 0x6A, 0x5F, 0x69, 0x5D, 0x68, 0x5C, 0x6B, 0x61, 0x6D, 0x62, 0x6D, 0x60, 0x6A, 0x5C, 0x6E, 0x62, 0x6C, 0x60, 0x6D, 0x5F, 0x69, 0x5D, 0x6F, 0x62, 0x6D, 0x60, 0x6A, 0x5E, 0x69, 0x5F, 0x69, 0x5D, 0x69, 0x5E, 0x67, 0x5C, 0x67, 0x5B, 0x66, 0x5B, 0x68, 0x5E, 0x68, 0x5D, 0x68, 0x5D, 0x67, 0x5A, 0x65, 0x58, 0x6C, 0x62, 0x6A, 0x5F, 0x68, 0x5D, 0x66, 0x5C, 0x6A, 0x5D, 0x6A, 0x5F, 0x68, 0x5C, 0x65, 0x5B, 0x69, 0x5D, 0x66, 0x5A, 0x67, 0x5B, 0x63, 0x58, 0x64, 0x5B, 0x69, 0x5C, 0x67, 0x5B, 0x66, 0x5B, 0x68, 0x5C, 0x66, 0x5A, 0x67, 0x5B, 0x63, 0x59, 0x63, 0x5A, 0x65, 0x59, 0x64, 0x5B, 0x65, 0x5B, 0x62, 0x58, 0x5E, 0x55, 0x65, 0x59, 0x66, 0x5A, 0x43, 0x3F, 0x34, 0x36, 0x2C, 0x2F, 0x32, 0x36, 0x29, 0x2C, 0x2A, 0x2F, 0x3F, 0x4C, 0x4C, 0x5B, 0x57, 0x67, 0x54, 0x65, 0x5A, 0x6B, 0x58, 0x6C, 0x5C, 0x6A, 0x33, 0x36, 0x2A, 0x2E, 0x35, 0x3C, 0x3C, 0x49, 0x5C, 0x71, 0x63, 0x77, 0x61, 0x75, 0x64, 0x77, 0x64, 0x78, 0x62, 0x76, 0x44, 0x47, 0x26, 0x2D, 0x34, 0x3C, 0x30, 0x39, 0x4D, 0x63, 0x56, 0x67, 0x54, 0x63, 0x4E, 0x5A, 0x48, 0x54, 0x43, 0x4D, 0x37, 0x3B, 0x1E, 0x22, 0x2A, 0x30, 0x2D, 0x30, 0x32, 0x3B, 0x2B, 0x2E, 0x23, 0x27, 0x20, 0x24, 0x20, 0x24, 0x1E, 0x20, 0x1D, 0x1F, 0x21, 0x26, 0x2D, 0x35, 0x2E, 0x33
    },

    {
        0x58, 0x20, 0x58, 0x1F, 0x59, 0x20, 0x59, 0x1F, 0x59, 0x20, 0x5A, 0x20, 0x5B, 0x20, 0x5C, 0x21, 0x5B, 0x20, 0x5A, 0x20, 0x5A, 0x20, 0x59, 0x20, 0x5A, 0x20, 0x5B, 0x20, 0x5C, 0x21, 0x5D, 0x21, 0x5C, 0x21, 0x5B, 0x21, 0x5A, 0x20, 0x59, 0x20, 0x59, 0x20, 0x5A, 0x21, 0x59, 0x21, 0x5A, 0x20, 0x58, 0x21, 0x57, 0x21, 0x53, 0x1F, 0x44, 0x1B, 0x36, 0x19, 0x3D, 0x1B, 0x4D, 0x1E, 0x52, 0x1F, 0x4C, 0x1D, 0x3D, 0x19, 0x28, 0x14, 0x1F, 0x12, 0x1C, 0x12, 0x1B, 0x11, 0x1B, 0x11, 0x1B, 0x12, 0x1B, 0x12, 0x1A, 0x12, 0x19, 0x11, 0x18, 0x11, 0x19, 0x11, 0x18, 0x11, 0x18, 0x11, 0x19, 0x11, 0x18, 0x11, 0x17, 0x11, 0x18, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x16, 0x10, 0x17, 0x11, 0x18, 0x11, 0x19, 0x12, 0x18, 0x12, 0x19, 0x11, 0x19, 0x13, 0x1B, 0x13, 0x1A, 0x12, 0x19, 0x11, 0x19, 0x12, 0x1B, 0x13, 0x19, 0x11, 0x19, 0x12, 0x19, 0x11, 0x1B, 0x14, 0x26, 0x1B, 0x2A, 0x1C, 0x23, 0x18, 0x20, 0x16, 0x1F, 0x15, 0x1C, 0x14, 0x1C, 0x13, 0x1B, 0x14, 0x1C, 0x13, 0x1B, 0x13, 0x1C, 0x14, 0x1C, 0x14, 0x27, 0x22, 0x36, 0x27, 0x27, 0x1C, 0x22, 0x18, 0x1F, 0x16, 0x1B, 0x14, 0x1B, 0x13, 0x1A, 0x13, 0x1A, 0x13, 0x19, 0x12, 0x1A, 0x12, 0x1A, 0x12, 0x19, 0x12, 0x19, 0x12, 0x19, 0x12, 0x19, 0x11, 0x18, 0x11, 0x19, 0x12, 0x19, 0x12, 0x19, 0x12, 0x1A, 0x12, 0x1A, 0x12, 0x1A, 0x12, 0x1B, 0x13, 0x1A, 0x12, 0x1B, 0x13, 0x1C, 0x13, 0x1C, 0x14, 0x1D, 0x14, 0x1D, 0x14, 0x1D, 0x14, 0x1C, 0x13, 0x1C, 0x13, 0x1C, 0x13, 0x20, 0x15, 0x3A, 0x1D, 0x5A, 0x24, 0x62, 0x26, 0x5D, 0x24, 0x3B, 0x1D, 0x38, 0x1E, 0x59, 0x25, 0x62, 0x26, 0x68, 0x27, 0x69, 0x27, 0x67, 0x26, 0x68, 0x28, 0x69, 0x27, 0x6A, 0x28, 0x69, 0x28, 0x67, 0x26, 0x68, 0x28, 0x66, 0x26, 0x66, 0x27, 0x6A, 0x29, 0x6A, 0x28, 0x66, 0x27, 0x67, 0x28, 0x6B, 0x28, 0x6C, 0x29, 0x6C, 0x28, 0x6A, 0x28, 0x69, 0x28, 0x69, 0x27, 0x64, 0x26, 0x6A, 0x28, 0x6C, 0x27, 0x69, 0x27, 0x69, 0x27, 0x68, 0x27, 0x67, 0x28, 0x66, 0x26, 0x68, 0x27, 0x69, 0x27, 0x67, 0x26, 0x69, 0x27, 0x68, 0x27, 0x68, 0x27, 0x66, 0x26, 0x66, 0x27, 0x65, 0x26, 0x68, 0x26, 0x67, 0x26, 0x69, 0x28, 0x67, 0x26, 0x66, 0x25, 0x66, 0x27, 0x6A, 0x27, 0x68, 0x27, 0x67, 0x26, 0x69, 0x27, 0x63, 0x26, 0x66, 0x26, 0x67, 0x25, 0x64, 0x24, 0x5F, 0x23, 0x62, 0x24, 0x66, 0x25, 0x67, 0x25, 0x68, 0x26, 0x64, 0x24, 0x62, 0x23, 0x64, 0x25, 0x65, 0x24, 0x62, 0x23, 0x64, 0x24, 0x66, 0x25, 0x67, 0x25, 0x64, 0x24, 0x67, 0x25, 0x64, 0x24, 0x66, 0x25, 0x65, 0x23, 0x60, 0x23, 0x5E, 0x21, 0x4F, 0x1F, 0x48, 0x21, 0x47, 0x23, 0x48, 0x24, 0x47, 0x24, 0x45, 0x23, 0x3B, 0x1A, 0x25, 0x13, 0x3D, 0x1A, 0x56, 0x20, 0x54, 0x22, 0x3D, 0x20, 0x2D, 0x19, 0x26, 0x15, 0x28, 0x16, 0x26, 0x14, 0x1F, 0x12, 0x29, 0x17, 0x58, 0x22, 0x5E, 0x23, 0x5F, 0x24, 0x5F, 0x24, 0x5F, 0x23, 0x5E, 0x23, 0x62, 0x25, 0x62, 0x24, 0x61, 0x24, 0x64, 0x26, 0x60, 0x24, 0x5F, 0x23, 0x62, 0x24, 0x5E, 0x23, 0x5E, 0x23, 0x5E, 0x22, 0x5A, 0x21, 0x5F, 0x23, 0x5E, 0x23, 0x61, 0x23, 0x59, 0x22, 0x5D, 0x23, 0x5F, 0x23, 0x5D, 0x22, 0x5B, 0x22, 0x5E, 0x23, 0x5A, 0x21, 0x5C, 0x22, 0x60, 0x23, 0x5D, 0x22, 0x5A, 0x21, 0x56, 0x21, 0x5A, 0x21, 0x5A, 0x22, 0x58, 0x22, 0x5B, 0x22, 0x5D, 0x23, 0x5D, 0x22, 0x5C, 0x22, 0x59, 0x21, 0x5B, 0x22, 0x5A, 0x21, 0x58, 0x21, 0x59, 0x21, 0x59, 0x21, 0x56, 0x20, 0x57, 0x20, 0x58, 0x20, 0x57, 0x20, 0x57, 0x21, 0x57, 0x21, 0x5A, 0x22, 0x5A, 0x21, 0x57, 0x21, 0x57, 0x20, 0x58, 0x21, 0x44, 0x20, 0x37, 0x1D, 0x36, 0x1E, 0x3F, 0x22, 0x38, 0x1E, 0x34, 0x1E, 0x60, 0x34, 0x7B, 0x40, 0x7B, 0x41, 0x7C, 0x40, 0x7C, 0x40, 0x7A, 0x40, 0x72, 0x37, 0x31, 0x1A, 0x2C, 0x1A, 0x3F, 0x20, 0x38, 0x22, 0x64, 0x36, 0x65, 0x37, 0x5B, 0x32, 0x5A, 0x31, 0x56, 0x30, 0x4F, 0x2C, 0x36, 0x1E, 0x26, 0x18, 0x36, 0x1D, 0x2E, 0x1B, 0x3C, 0x22, 0x2B, 0x1B, 0x27, 0x19, 0x22, 0x16, 0x20, 0x15, 0x1E, 0x14, 0x21, 0x15, 0x24, 0x18, 0x38, 0x1E, 0x37, 0x1D, 0x35, 0x1C, 0x32, 0x1B, 0x2A, 0x1C, 0x2C, 0x1B, 0x35, 0x1D, 0x2B, 0x18, 0x36, 0x1D, 0x39, 0x1E, 0x30, 0x1A, 0x35, 0x1C
    },

    {
        0x65, 0x58, 0x63, 0x58, 0x64, 0x59, 0x64, 0x59, 0x65, 0x59, 0x67, 0x5A, 0x68, 0x5C, 0x68, 0x5B, 0x68, 0x5A, 0x67, 0x5A, 0x67, 0x59, 0x66, 0x58, 0x69, 0x5C, 0x68, 0x5A, 0x68, 0x5B, 0x6A, 0x5D, 0x69, 0x5D, 0x69, 0x5C, 0x66, 0x5B, 0x67, 0x5A, 0x67, 0x58, 0x66, 0x59, 0x66, 0x59, 0x66, 0x59, 0x65, 0x58, 0x63, 0x58, 0x5F, 0x54, 0x53, 0x47, 0x40, 0x37, 0x3D, 0x3A, 0x4E, 0x4B, 0x58, 0x51, 0x56, 0x4E, 0x49, 0x3F, 0x30, 0x2A, 0x21, 0x20, 0x1C, 0x1D, 0x1A, 0x1B, 0x19, 0x1B, 0x18, 0x1A, 0x17, 0x1A, 0x16, 0x1A, 0x16, 0x19, 0x15, 0x19, 0x15, 0x19, 0x15, 0x18, 0x14, 0x18, 0x14, 0x18, 0x14, 0x17, 0x14, 0x18, 0x14, 0x18, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x14, 0x18, 0x14, 0x19, 0x15, 0x19, 0x15, 0x18, 0x15, 0x19, 0x16, 0x1A, 0x16, 0x1A, 0x15, 0x19, 0x15, 0x19, 0x15, 0x1A, 0x15, 0x19, 0x14, 0x18, 0x15, 0x19, 0x16, 0x1B, 0x1B, 0x23, 0x1F, 0x27, 0x1E, 0x22, 0x1B, 0x20, 0x1A, 0x1E, 0x18, 0x1D, 0x17, 0x1B, 0x17, 0x1B, 0x17, 0x1B, 0x17, 0x1B, 0x18, 0x1C, 0x1A, 0x1D, 0x25, 0x32, 0x35, 0x3F, 0x27, 0x2A, 0x1F, 0x23, 0x1B, 0x1F, 0x18, 0x1C, 0x17, 0x1B, 0x16, 0x1B, 0x16, 0x1A, 0x15, 0x1A, 0x16, 0x1A, 0x15, 0x19, 0x15, 0x19, 0x15, 0x18, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x15, 0x19, 0x15, 0x19, 0x16, 0x19, 0x16, 0x1A, 0x16, 0x1B, 0x16, 0x1A, 0x16, 0x1A, 0x17, 0x1B, 0x17, 0x1C, 0x17, 0x1D, 0x18, 0x1E, 0x18, 0x1D, 0x18, 0x1D, 0x17, 0x1B, 0x17, 0x1C, 0x19, 0x1C, 0x23, 0x27, 0x44, 0x49, 0x63, 0x5E, 0x6A, 0x63, 0x5C, 0x52, 0x3A, 0x33, 0x44, 0x46, 0x65, 0x60, 0x6D, 0x64, 0x74, 0x6A, 0x74, 0x6A, 0x73, 0x67, 0x72, 0x67, 0x73, 0x67, 0x78, 0x6C, 0x76, 0x69, 0x72, 0x66, 0x74, 0x6A, 0x72, 0x66, 0x71, 0x67, 0x74, 0x6A, 0x74, 0x69, 0x72, 0x67, 0x74, 0x69, 0x77, 0x6C, 0x79, 0x6C, 0x7B, 0x6C, 0x78, 0x6B, 0x75, 0x68, 0x75, 0x68, 0x6F, 0x66, 0x76, 0x6A, 0x7A, 0x6C, 0x76, 0x6A, 0x74, 0x68, 0x74, 0x67, 0x73, 0x69, 0x73, 0x67, 0x79, 0x6A, 0x76, 0x6A, 0x78, 0x68, 0x76, 0x69, 0x76, 0x68, 0x76, 0x69, 0x72, 0x66, 0x71, 0x67, 0x74, 0x66, 0x73, 0x67, 0x75, 0x68, 0x75, 0x6A, 0x73, 0x66, 0x6F, 0x63, 0x72, 0x66, 0x75, 0x6B, 0x78, 0x6B, 0x75, 0x69, 0x75, 0x68, 0x71, 0x65, 0x73, 0x68, 0x74, 0x66, 0x71, 0x63, 0x6F, 0x62, 0x72, 0x65, 0x74, 0x67, 0x74, 0x67, 0x76, 0x68, 0x74, 0x66, 0x6E, 0x60, 0x72, 0x65, 0x74, 0x66, 0x70, 0x62, 0x74, 0x66, 0x78, 0x68, 0x76, 0x68, 0x72, 0x65, 0x75, 0x66, 0x73, 0x66, 0x71, 0x64, 0x6F, 0x62, 0x6B, 0x5F, 0x6B, 0x5B, 0x55, 0x4B, 0x48, 0x47, 0x44, 0x45, 0x45, 0x47, 0x44, 0x46, 0x43, 0x46, 0x35, 0x30, 0x29, 0x27, 0x44, 0x43, 0x61, 0x58, 0x5B, 0x4D, 0x3D, 0x38, 0x31, 0x2B, 0x2B, 0x26, 0x2B, 0x28, 0x2A, 0x26, 0x20, 0x1E, 0x2D, 0x32, 0x62, 0x5B, 0x69, 0x5F, 0x6A, 0x61, 0x6A, 0x60, 0x6E, 0x60, 0x6C, 0x60, 0x6E, 0x63, 0x6F, 0x61, 0x6B, 0x61, 0x73, 0x66, 0x6D, 0x61, 0x6D, 0x61, 0x71, 0x64, 0x6C, 0x60, 0x6C, 0x61, 0x6D, 0x60, 0x67, 0x5B, 0x6B, 0x5F, 0x6B, 0x60, 0x6E, 0x62, 0x65, 0x59, 0x6D, 0x60, 0x6C, 0x5F, 0x69, 0x5D, 0x66, 0x5C, 0x6A, 0x5F, 0x67, 0x5C, 0x69, 0x5C, 0x6A, 0x5F, 0x66, 0x5C, 0x64, 0x59, 0x62, 0x57, 0x66, 0x5A, 0x64, 0x5B, 0x63, 0x59, 0x68, 0x5C, 0x69, 0x5D, 0x6A, 0x5E, 0x67, 0x5C, 0x66, 0x5A, 0x68, 0x5C, 0x66, 0x5B, 0x64, 0x59, 0x65, 0x5A, 0x64, 0x59, 0x63, 0x58, 0x65, 0x59, 0x64, 0x59, 0x62, 0x57, 0x62, 0x58, 0x64, 0x59, 0x66, 0x5B, 0x68, 0x5B, 0x64, 0x59, 0x61, 0x57, 0x61, 0x56, 0x44, 0x41, 0x37, 0x3A, 0x32, 0x39, 0x3B, 0x44, 0x33, 0x36, 0x31, 0x38, 0x52, 0x68, 0x64, 0x7B, 0x65, 0x7C, 0x65, 0x7A, 0x64, 0x7A, 0x63, 0x79, 0x5A, 0x65, 0x26, 0x26, 0x28, 0x30, 0x32, 0x38, 0x2F, 0x3A, 0x4C, 0x58, 0x48, 0x56, 0x42, 0x4E, 0x3E, 0x4A, 0x3C, 0x44, 0x37, 0x3E, 0x26, 0x28, 0x23, 0x2A, 0x2E, 0x31, 0x2A, 0x32, 0x2F, 0x33, 0x21, 0x23, 0x1F, 0x21, 0x1D, 0x1E, 0x1D, 0x1F, 0x1B, 0x1E, 0x22, 0x25, 0x26, 0x2F, 0x33, 0x3A, 0x32, 0x38, 0x30, 0x37, 0x2F, 0x34, 0x28, 0x2D, 0x2B, 0x35, 0x30, 0x38, 0x28, 0x2D, 0x34, 0x3C, 0x31, 0x37, 0x29, 0x2D, 0x2E, 0x33
    },

    {
        0x58, 0x20, 0x58, 0x1F, 0x58, 0x20, 0x56, 0x1F, 0x58, 0x20, 0x59, 0x20, 0x5A, 0x20, 0x5B, 0x21, 0x5B, 0x20, 0x5A, 0x20, 0x58, 0x20, 0x58, 0x1F, 0x59, 0x20, 0x5A, 0x21, 0x5B, 0x21, 0x5E, 0x22, 0x5D, 0x22, 0x5C, 0x22, 0x5B, 0x21, 0x5A, 0x21, 0x59, 0x20, 0x5A, 0x21, 0x5A, 0x20, 0x59, 0x21, 0x5A, 0x20, 0x5A, 0x21, 0x5A, 0x21, 0x53, 0x1F, 0x4A, 0x1C, 0x3A, 0x19, 0x39, 0x1A, 0x4A, 0x1E, 0x51, 0x1F, 0x51, 0x1E, 0x43, 0x1A, 0x2E, 0x16, 0x22, 0x13, 0x1E, 0x13, 0x1E, 0x13, 0x1B, 0x12, 0x1C, 0x12, 0x1B, 0x12, 0x1A, 0x12, 0x19, 0x12, 0x1A, 0x12, 0x19, 0x11, 0x18, 0x11, 0x18, 0x11, 0x17, 0x10, 0x18, 0x11, 0x18, 0x11, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x17, 0x10, 0x18, 0x11, 0x19, 0x12, 0x19, 0x12, 0x18, 0x12, 0x1A, 0x12, 0x19, 0x12, 0x19, 0x12, 0x19, 0x12, 0x19, 0x12, 0x1A, 0x12, 0x1A, 0x13, 0x19, 0x12, 0x18, 0x11, 0x1A, 0x12, 0x1A, 0x12, 0x1B, 0x14, 0x24, 0x20, 0x40, 0x33, 0x36, 0x26, 0x25, 0x1A, 0x20, 0x17, 0x1E, 0x16, 0x1D, 0x15, 0x1C, 0x14, 0x1B, 0x14, 0x1A, 0x13, 0x1C, 0x15, 0x26, 0x22, 0x50, 0x47, 0x6C, 0x53, 0x4E, 0x36, 0x2C, 0x20, 0x26, 0x1A, 0x21, 0x18, 0x1F, 0x16, 0x1C, 0x14, 0x1B, 0x13, 0x1B, 0x13, 0x1B, 0x13, 0x1B, 0x13, 0x1A, 0x13, 0x19, 0x12, 0x1A, 0x13, 0x1A, 0x13, 0x19, 0x11, 0x19, 0x11, 0x19, 0x12, 0x1A, 0x12, 0x1A, 0x13, 0x1A, 0x13, 0x1C, 0x13, 0x1B, 0x13, 0x1B, 0x13, 0x1B, 0x13, 0x1C, 0x14, 0x1D, 0x14, 0x1D, 0x14, 0x1C, 0x13, 0x1C, 0x13, 0x1C, 0x13, 0x1D, 0x14, 0x1F, 0x14, 0x38, 0x1C, 0x5A, 0x24, 0x62, 0x26, 0x60, 0x26, 0x3D, 0x1D, 0x3A, 0x1E, 0x5B, 0x25, 0x62, 0x26, 0x68, 0x27, 0x69, 0x27, 0x6B, 0x28, 0x67, 0x27, 0x69, 0x29, 0x6A, 0x28, 0x6B, 0x29, 0x6B, 0x28, 0x6A, 0x28, 0x6A, 0x29, 0x67, 0x26, 0x68, 0x27, 0x69, 0x27, 0x6B, 0x28, 0x6A, 0x27, 0x68, 0x28, 0x6C, 0x28, 0x6C, 0x29, 0x6E, 0x29, 0x6D, 0x28, 0x67, 0x27, 0x6A, 0x28, 0x68, 0x28, 0x67, 0x27, 0x6A, 0x27, 0x69, 0x28, 0x6B, 0x27, 0x69, 0x27, 0x67, 0x27, 0x67, 0x28, 0x6D, 0x29, 0x6B, 0x28, 0x68, 0x27, 0x65, 0x27, 0x69, 0x27, 0x69, 0x27, 0x67, 0x27, 0x6A, 0x28, 0x67, 0x27, 0x69, 0x27, 0x69, 0x28, 0x6D, 0x29, 0x66, 0x25, 0x63, 0x25, 0x67, 0x28, 0x6A, 0x28, 0x6B, 0x28, 0x67, 0x27, 0x6A, 0x29, 0x68, 0x28, 0x68, 0x27, 0x67, 0x25, 0x65, 0x26, 0x64, 0x25, 0x62, 0x23, 0x66, 0x25, 0x65, 0x25, 0x67, 0x25, 0x64, 0x24, 0x64, 0x24, 0x63, 0x24, 0x61, 0x22, 0x63, 0x24, 0x67, 0x25, 0x67, 0x25, 0x67, 0x26, 0x66, 0x24, 0x66, 0x25, 0x62, 0x24, 0x5E, 0x22, 0x5D, 0x22, 0x5E, 0x22, 0x5D, 0x21, 0x4E, 0x1C, 0x3A, 0x1A, 0x3D, 0x1E, 0x42, 0x20, 0x42, 0x1F, 0x37, 0x19, 0x24, 0x12, 0x2B, 0x15, 0x47, 0x1D, 0x5C, 0x21, 0x51, 0x1E, 0x2E, 0x18, 0x26, 0x16, 0x25, 0x15, 0x26, 0x16, 0x25, 0x15, 0x1D, 0x11, 0x33, 0x1A, 0x5A, 0x23, 0x61, 0x24, 0x60, 0x24, 0x60, 0x23, 0x5F, 0x23, 0x60, 0x23, 0x5E, 0x23, 0x62, 0x24, 0x5F, 0x23, 0x5F, 0x24, 0x63, 0x25, 0x60, 0x24, 0x60, 0x24, 0x61, 0x24, 0x62, 0x25, 0x62, 0x24, 0x5F, 0x23, 0x5F, 0x23, 0x60, 0x23, 0x60, 0x23, 0x5A, 0x21, 0x5D, 0x22, 0x5D, 0x22, 0x59, 0x21, 0x59, 0x20, 0x5A, 0x22, 0x59, 0x21, 0x59, 0x22, 0x5A, 0x22, 0x5C, 0x22, 0x59, 0x22, 0x5B, 0x22, 0x57, 0x21, 0x5D, 0x23, 0x59, 0x21, 0x5B, 0x22, 0x5A, 0x21, 0x5A, 0x21, 0x5D, 0x22, 0x59, 0x22, 0x58, 0x22, 0x5D, 0x22, 0x5B, 0x22, 0x5F, 0x23, 0x5D, 0x22, 0x5A, 0x21, 0x5B, 0x23, 0x5A, 0x21, 0x59, 0x21, 0x5A, 0x21, 0x58, 0x21, 0x5B, 0x22, 0x5A, 0x21, 0x58, 0x21, 0x57, 0x21, 0x58, 0x21, 0x43, 0x20, 0x45, 0x23, 0x34, 0x1E, 0x3D, 0x20, 0x33, 0x1C, 0x37, 0x1F, 0x5A, 0x31, 0x62, 0x35, 0x5C, 0x33, 0x53, 0x2E, 0x4A, 0x2A, 0x44, 0x27, 0x39, 0x21, 0x21, 0x15, 0x30, 0x1C, 0x2C, 0x19, 0x30, 0x1B, 0x2D, 0x1A, 0x22, 0x15, 0x20, 0x15, 0x1E, 0x13, 0x20, 0x15, 0x24, 0x17, 0x25, 0x16, 0x2C, 0x19, 0x36, 0x1C, 0x3E, 0x20, 0x3A, 0x1E, 0x2C, 0x18, 0x36, 0x1D, 0x2E, 0x1A, 0x34, 0x1D, 0x2A, 0x19, 0x3D, 0x21, 0x35, 0x1D, 0x34, 0x1D, 0x32, 0x1C, 0x36, 0x1E, 0x38, 0x1D, 0x2E, 0x19, 0x30, 0x1B, 0x34, 0x1C, 0x2B, 0x18, 0x34, 0x1C, 0x2D, 0x19, 0x2C, 0x1A, 0x33, 0x1C
    },

    {
        0x64, 0x58, 0x64, 0x58, 0x63, 0x58, 0x61, 0x57, 0x63, 0x58, 0x66, 0x59, 0x68, 0x5B, 0x68, 0x5B, 0x69, 0x5C, 0x68, 0x59, 0x66, 0x58, 0x65, 0x58, 0x66, 0x59, 0x68, 0x5A, 0x69, 0x5C, 0x69, 0x5D, 0x6B, 0x5D, 0x6A, 0x5C, 0x67, 0x5A, 0x67, 0x5A, 0x65, 0x58, 0x67, 0x5A, 0x66, 0x5A, 0x65, 0x59, 0x65, 0x58, 0x65, 0x59, 0x63, 0x58, 0x5F, 0x53, 0x58, 0x4C, 0x46, 0x3B, 0x3A, 0x39, 0x4B, 0x48, 0x58, 0x50, 0x5A, 0x50, 0x51, 0x46, 0x39, 0x30, 0x25, 0x22, 0x1E, 0x1F, 0x1C, 0x1D, 0x1A, 0x1C, 0x18, 0x1B, 0x17, 0x1B, 0x16, 0x19, 0x15, 0x19, 0x15, 0x18, 0x15, 0x18, 0x14, 0x19, 0x14, 0x17, 0x14, 0x17, 0x14, 0x17, 0x14, 0x18, 0x13, 0x17, 0x13, 0x17, 0x13, 0x17, 0x14, 0x17, 0x14, 0x17, 0x13, 0x18, 0x14, 0x18, 0x14, 0x18, 0x14, 0x19, 0x15, 0x19, 0x15, 0x19, 0x15, 0x19, 0x14, 0x18, 0x15, 0x1A, 0x16, 0x1B, 0x15, 0x19, 0x14, 0x18, 0x14, 0x18, 0x15, 0x19, 0x16, 0x1A, 0x19, 0x1C, 0x22, 0x2D, 0x3A, 0x4C, 0x36, 0x3A, 0x24, 0x27, 0x1D, 0x21, 0x1A, 0x1F, 0x19, 0x1D, 0x17, 0x1C, 0x16, 0x1A, 0x17, 0x1A, 0x1A, 0x1D, 0x26, 0x31, 0x47, 0x61, 0x58, 0x6D, 0x4A, 0x50, 0x2D, 0x2F, 0x23, 0x26, 0x1D, 0x21, 0x1B, 0x1F, 0x18, 0x1C, 0x16, 0x1A, 0x16, 0x1B, 0x16, 0x1B, 0x16, 0x1A, 0x15, 0x1A, 0x15, 0x19, 0x15, 0x1A, 0x15, 0x1A, 0x14, 0x19, 0x15, 0x18, 0x15, 0x1A, 0x16, 0x1A, 0x16, 0x1A, 0x16, 0x1A, 0x16, 0x1B, 0x17, 0x1B, 0x16, 0x1A, 0x16, 0x1B, 0x17, 0x1D, 0x17, 0x1C, 0x18, 0x1C, 0x17, 0x1B, 0x18, 0x1C, 0x18, 0x1C, 0x19, 0x1D, 0x20, 0x23, 0x40, 0x45, 0x5F, 0x5E, 0x68, 0x62, 0x5E, 0x57, 0x3D, 0x34, 0x43, 0x46, 0x65, 0x61, 0x6B, 0x64, 0x72, 0x68, 0x74, 0x68, 0x77, 0x6B, 0x72, 0x67, 0x73, 0x69, 0x73, 0x69, 0x77, 0x6B, 0x7A, 0x6C, 0x78, 0x6C, 0x77, 0x6C, 0x75, 0x68, 0x71, 0x67, 0x75, 0x6A, 0x7A, 0x6E, 0x76, 0x69, 0x75, 0x6B, 0x78, 0x6D, 0x78, 0x6B, 0x7B, 0x6F, 0x79, 0x6B, 0x75, 0x68, 0x76, 0x69, 0x75, 0x69, 0x72, 0x68, 0x78, 0x68, 0x76, 0x6A, 0x7A, 0x6C, 0x76, 0x6A, 0x75, 0x68, 0x75, 0x6A, 0x79, 0x6D, 0x76, 0x69, 0x75, 0x68, 0x72, 0x66, 0x76, 0x6A, 0x74, 0x67, 0x74, 0x68, 0x76, 0x6B, 0x72, 0x66, 0x75, 0x69, 0x76, 0x6A, 0x79, 0x6A, 0x74, 0x66, 0x72, 0x67, 0x72, 0x68, 0x74, 0x6B, 0x76, 0x6A, 0x74, 0x6A, 0x76, 0x6C, 0x76, 0x6A, 0x74, 0x69, 0x73, 0x67, 0x73, 0x67, 0x72, 0x64, 0x71, 0x62, 0x74, 0x66, 0x75, 0x68, 0x76, 0x66, 0x72, 0x65, 0x72, 0x65, 0x71, 0x64, 0x6F, 0x61, 0x71, 0x64, 0x76, 0x67, 0x76, 0x67, 0x74, 0x67, 0x72, 0x65, 0x72, 0x65, 0x6F, 0x63, 0x6C, 0x5E, 0x68, 0x5B, 0x6A, 0x5E, 0x6B, 0x5D, 0x59, 0x4B, 0x40, 0x3A, 0x3A, 0x39, 0x39, 0x3B, 0x3B, 0x3D, 0x30, 0x2D, 0x24, 0x22, 0x32, 0x33, 0x4E, 0x4D, 0x64, 0x5B, 0x5E, 0x4E, 0x35, 0x2B, 0x2A, 0x25, 0x27, 0x24, 0x27, 0x26, 0x25, 0x22, 0x1E, 0x1C, 0x3B, 0x3F, 0x66, 0x5F, 0x6A, 0x60, 0x6B, 0x60, 0x6E, 0x61, 0x6E, 0x62, 0x6D, 0x5F, 0x6A, 0x5F, 0x6D, 0x62, 0x6B, 0x5F, 0x6B, 0x5F, 0x6F, 0x63, 0x6D, 0x61, 0x6C, 0x60, 0x6C, 0x62, 0x6C, 0x62, 0x6C, 0x63, 0x6C, 0x60, 0x6B, 0x61, 0x6C, 0x5E, 0x6A, 0x60, 0x68, 0x5C, 0x6A, 0x5D, 0x69, 0x5E, 0x66, 0x5A, 0x63, 0x58, 0x66, 0x5C, 0x65, 0x5A, 0x64, 0x5B, 0x66, 0x5B, 0x66, 0x5C, 0x65, 0x5A, 0x69, 0x5D, 0x62, 0x5A, 0x6B, 0x5E, 0x64, 0x5A, 0x66, 0x5D, 0x67, 0x5B, 0x68, 0x5B, 0x6A, 0x5F, 0x65, 0x5A, 0x64, 0x5B, 0x67, 0x5C, 0x65, 0x5C, 0x6A, 0x5F, 0x68, 0x5C, 0x64, 0x59, 0x65, 0x5D, 0x63, 0x5A, 0x66, 0x5A, 0x65, 0x59, 0x64, 0x5A, 0x67, 0x5D, 0x69, 0x5C, 0x64, 0x5A, 0x63, 0x5B, 0x62, 0x57, 0x45, 0x45, 0x3D, 0x3F, 0x2F, 0x34, 0x36, 0x3B, 0x2D, 0x30, 0x31, 0x3A, 0x46, 0x54, 0x47, 0x51, 0x40, 0x49, 0x38, 0x41, 0x33, 0x39, 0x2E, 0x33, 0x27, 0x2B, 0x1C, 0x20, 0x2B, 0x30, 0x28, 0x2B, 0x2D, 0x32, 0x28, 0x29, 0x20, 0x21, 0x1F, 0x22, 0x1E, 0x21, 0x21, 0x24, 0x26, 0x29, 0x25, 0x2B, 0x29, 0x32, 0x31, 0x37, 0x37, 0x40, 0x34, 0x3A, 0x2A, 0x30, 0x33, 0x3A, 0x2B, 0x30, 0x2F, 0x35, 0x29, 0x2F, 0x37, 0x3F, 0x2D, 0x32, 0x2D, 0x34, 0x2C, 0x2F, 0x2F, 0x38, 0x2F, 0x33, 0x28, 0x2D, 0x2C, 0x32, 0x2D, 0x32, 0x27, 0x2B, 0x2D, 0x33, 0x2A, 0x2D, 0x29, 0x30, 0x2F, 0x33
    },

    {
        0x5A, 0x20, 0x59, 0x1F, 0x58, 0x1F, 0x58, 0x1F, 0x59, 0x20, 0x5A, 0x20, 0x5B, 0x21, 0x5B, 0x21, 0x5A, 0x20, 0x59, 0x21, 0x5A, 0x20, 0x59, 0x20, 0x5B, 0x20, 0x5C, 0x21, 0x5C, 0x21, 0x5D, 0x22, 0x5C, 0x21, 0x5C, 0x21, 0x5A, 0x20, 0x59, 0x21, 0x5A, 0x21, 0x5B, 0x20, 0x59, 0x20, 0x59, 0x22, 0x5B, 0x22, 0x5B, 0x22, 0x5B, 0x21, 0x58, 0x20, 0x54, 0x1F, 0x4D, 0x1D, 0x3C, 0x1A, 0x38, 0x1A, 0x46, 0x1D, 0x52, 0x1F, 0x51, 0x1E, 0x4A, 0x1C, 0x34, 0x16, 0x23, 0x14, 0x1F, 0x13, 0x1D, 0x12, 0x1C, 0x12, 0x1C, 0x12, 0x1B, 0x12, 0x1A, 0x12, 0x18, 0x11, 0x1A, 0x11, 0x19, 0x11, 0x17, 0x10, 0x18, 0x11, 0x17, 0x10, 0x18, 0x11, 0x17, 0x10, 0x18, 0x11, 0x18, 0x11, 0x17, 0x11, 0x17, 0x11, 0x18, 0x11, 0x18, 0x12, 0x19, 0x11, 0x18, 0x11, 0x18, 0x11, 0x1A, 0x12, 0x19, 0x12, 0x19, 0x12, 0x19, 0x11, 0x1A, 0x12, 0x19, 0x12, 0x19, 0x11, 0x18, 0x12, 0x1A, 0x12, 0x1B, 0x14, 0x23, 0x1E, 0x44, 0x3F, 0x6A, 0x57, 0x64, 0x4B, 0x42, 0x2D, 0x29, 0x1E, 0x23, 0x19, 0x1F, 0x16, 0x1D, 0x15, 0x1C, 0x14, 0x1C, 0x15, 0x23, 0x21, 0x4F, 0x48, 0x71, 0x5E, 0x77, 0x62, 0x76, 0x5C, 0x5B, 0x40, 0x36, 0x25, 0x29, 0x1D, 0x23, 0x18, 0x1D, 0x15, 0x1B, 0x13, 0x19, 0x12, 0x19, 0x12, 0x1B, 0x13, 0x1A, 0x12, 0x1A, 0x12, 0x1A, 0x12, 0x1B, 0x13, 0x1A, 0x12, 0x19, 0x12, 0x1A, 0x13, 0x1B, 0x13, 0x1B, 0x13, 0x1B, 0x12, 0x1A, 0x13, 0x1B, 0x13, 0x1B, 0x13, 0x1C, 0x13, 0x1C, 0x13, 0x1C, 0x14, 0x1C, 0x13, 0x1C, 0x13, 0x1D, 0x14, 0x1C, 0x13, 0x1E, 0x14, 0x35, 0x1D, 0x5A, 0x25, 0x61, 0x26, 0x5E, 0x25, 0x3F, 0x1D, 0x37, 0x1D, 0x58, 0x23, 0x63, 0x26, 0x65, 0x26, 0x67, 0x27, 0x6A, 0x28, 0x6B, 0x28, 0x6A, 0x28, 0x6B, 0x29, 0x69, 0x28, 0x6B, 0x28, 0x6B, 0x28, 0x6C, 0x28, 0x6B, 0x29, 0x6E, 0x2A, 0x6A, 0x28, 0x6D, 0x29, 0x6E, 0x29, 0x6D, 0x28, 0x68, 0x28, 0x69, 0x28, 0x6B, 0x28, 0x6D, 0x29, 0x6A, 0x27, 0x69, 0x27, 0x67, 0x27, 0x68, 0x28, 0x69, 0x27, 0x6B, 0x27, 0x69, 0x26, 0x6E, 0x28, 0x6B, 0x28, 0x6A, 0x28, 0x69, 0x27, 0x68, 0x27, 0x66, 0x26, 0x67, 0x28, 0x67, 0x27, 0x66, 0x27, 0x64, 0x27, 0x68, 0x27, 0x66, 0x27, 0x67, 0x27, 0x69, 0x27, 0x6A, 0x28, 0x69, 0x28, 0x65, 0x27, 0x67, 0x26, 0x6B, 0x28, 0x66, 0x26, 0x67, 0x27, 0x6C, 0x28, 0x69, 0x28, 0x6D, 0x28, 0x68, 0x26, 0x65, 0x26, 0x69, 0x27, 0x69, 0x27, 0x68, 0x26, 0x64, 0x25, 0x69, 0x26, 0x67, 0x24, 0x63, 0x24, 0x66, 0x26, 0x67, 0x25, 0x65, 0x24, 0x61, 0x23, 0x63, 0x24, 0x67, 0x25, 0x66, 0x25, 0x63, 0x24, 0x60, 0x23, 0x61, 0x23, 0x60, 0x23, 0x5B, 0x21, 0x58, 0x20, 0x5A, 0x20, 0x55, 0x1F, 0x43, 0x1A, 0x2E, 0x14, 0x25, 0x13, 0x22, 0x12, 0x20, 0x10, 0x29, 0x14, 0x40, 0x1B, 0x52, 0x1F, 0x56, 0x20, 0x5A, 0x20, 0x38, 0x18, 0x20, 0x12, 0x1E, 0x12, 0x1E, 0x11, 0x1B, 0x10, 0x21, 0x14, 0x4A, 0x20, 0x60, 0x24, 0x5F, 0x25, 0x61, 0x25, 0x65, 0x26, 0x64, 0x24, 0x60, 0x24, 0x5D, 0x23, 0x60, 0x25, 0x61, 0x24, 0x5E, 0x24, 0x60, 0x24, 0x60, 0x25, 0x60, 0x25, 0x5E, 0x25, 0x61, 0x25, 0x5D, 0x22, 0x5E, 0x23, 0x5C, 0x22, 0x5E, 0x23, 0x5D, 0x23, 0x5C, 0x22, 0x5A, 0x22, 0x5A, 0x22, 0x59, 0x21, 0x5B, 0x21, 0x59, 0x21, 0x59, 0x21, 0x5C, 0x23, 0x59, 0x20, 0x58, 0x21, 0x5A, 0x21, 0x5D, 0x23, 0x5A, 0x22, 0x5A, 0x22, 0x63, 0x27, 0x63, 0x26, 0x60, 0x25, 0x5D, 0x24, 0x5C, 0x23, 0x5A, 0x22, 0x59, 0x21, 0x57, 0x20, 0x57, 0x21, 0x59, 0x21, 0x5B, 0x22, 0x5E, 0x23, 0x5A, 0x22, 0x58, 0x22, 0x5A, 0x22, 0x59, 0x21, 0x59, 0x22, 0x59, 0x22, 0x5D, 0x21, 0x57, 0x21, 0x58, 0x20, 0x56, 0x20, 0x4F, 0x25, 0x3A, 0x1D, 0x33, 0x1D, 0x34, 0x1C, 0x29, 0x19, 0x37, 0x1F, 0x31, 0x1C, 0x25, 0x16, 0x21, 0x15, 0x23, 0x15, 0x22, 0x15, 0x23, 0x16, 0x2F, 0x1A, 0x30, 0x1B, 0x32, 0x1C, 0x38, 0x1E, 0x36, 0x1E, 0x3F, 0x20, 0x38, 0x1D, 0x37, 0x1C, 0x35, 0x1D, 0x3B, 0x1E, 0x33, 0x1C, 0x37, 0x1D, 0x35, 0x1E, 0x41, 0x22, 0x35, 0x1D, 0x39, 0x1E, 0x31, 0x1C, 0x3A, 0x1E, 0x2A, 0x19, 0x32, 0x1B, 0x2F, 0x1B, 0x37, 0x1E, 0x2C, 0x1A, 0x38, 0x1F, 0x2F, 0x1B, 0x3B, 0x1F, 0x39, 0x1E, 0x33, 0x1C, 0x33, 0x1C, 0x36, 0x1D, 0x31, 0x1B, 0x3D, 0x20, 0x36, 0x1E, 0x2F, 0x1A, 0x3B, 0x1F
    },

    {
        0x65, 0x5A, 0x64, 0x59, 0x63, 0x58, 0x64, 0x59, 0x64, 0x59, 0x67, 0x59, 0x67, 0x5B, 0x66, 0x5B, 0x67, 0x5B, 0x66, 0x5A, 0x68, 0x5B, 0x65, 0x59, 0x66, 0x5B, 0x68, 0x5C, 0x69, 0x5C, 0x69, 0x5C, 0x6A, 0x5D, 0x6A, 0x5B, 0x67, 0x5A, 0x67, 0x5A, 0x66, 0x5B, 0x68, 0x5B, 0x67, 0x59, 0x66, 0x5A, 0x67, 0x5D, 0x68, 0x5C, 0x67, 0x5C, 0x65, 0x59, 0x60, 0x54, 0x59, 0x4D, 0x48, 0x3C, 0x3B, 0x38, 0x46, 0x46, 0x58, 0x51, 0x5C, 0x52, 0x55, 0x4B, 0x41, 0x37, 0x29, 0x25, 0x20, 0x20, 0x1C, 0x1D, 0x1A, 0x1C, 0x19, 0x1B, 0x18, 0x1B, 0x16, 0x1A, 0x16, 0x19, 0x15, 0x19, 0x14, 0x18, 0x14, 0x17, 0x13, 0x17, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x14, 0x18, 0x14, 0x17, 0x14, 0x17, 0x14, 0x18, 0x15, 0x19, 0x15, 0x18, 0x14, 0x18, 0x14, 0x18, 0x15, 0x19, 0x14, 0x19, 0x15, 0x1A, 0x15, 0x19, 0x14, 0x19, 0x15, 0x19, 0x14, 0x19, 0x15, 0x19, 0x16, 0x1A, 0x19, 0x1D, 0x23, 0x2C, 0x40, 0x57, 0x58, 0x6E, 0x58, 0x69, 0x43, 0x46, 0x2A, 0x2C, 0x20, 0x24, 0x1C, 0x20, 0x1A, 0x1E, 0x19, 0x1D, 0x1A, 0x1D, 0x25, 0x30, 0x46, 0x62, 0x60, 0x77, 0x65, 0x79, 0x64, 0x78, 0x57, 0x60, 0x38, 0x39, 0x26, 0x2A, 0x20, 0x23, 0x1A, 0x1E, 0x18, 0x1B, 0x15, 0x1A, 0x15, 0x1A, 0x16, 0x1A, 0x16, 0x1A, 0x15, 0x1A, 0x16, 0x1B, 0x15, 0x1A, 0x15, 0x1A, 0x15, 0x1A, 0x16, 0x1B, 0x17, 0x1B, 0x17, 0x1B, 0x16, 0x1A, 0x16, 0x1A, 0x16, 0x1B, 0x17, 0x1B, 0x18, 0x1C, 0x17, 0x1B, 0x17, 0x1C, 0x17, 0x1C, 0x18, 0x1C, 0x18, 0x1D, 0x19, 0x1C, 0x1F, 0x22, 0x3F, 0x46, 0x63, 0x63, 0x6A, 0x63, 0x5F, 0x55, 0x3D, 0x34, 0x41, 0x44, 0x62, 0x5F, 0x70, 0x67, 0x73, 0x67, 0x74, 0x69, 0x74, 0x6A, 0x77, 0x6C, 0x77, 0x6C, 0x7A, 0x6D, 0x76, 0x6A, 0x78, 0x6C, 0x78, 0x6A, 0x7A, 0x6B, 0x77, 0x6C, 0x7C, 0x70, 0x77, 0x6C, 0x79, 0x6E, 0x7B, 0x6D, 0x79, 0x6D, 0x76, 0x6B, 0x75, 0x6C, 0x76, 0x6B, 0x78, 0x6D, 0x76, 0x69, 0x76, 0x6A, 0x75, 0x68, 0x75, 0x6A, 0x74, 0x68, 0x77, 0x6B, 0x77, 0x6A, 0x7B, 0x6F, 0x78, 0x6A, 0x77, 0x6B, 0x78, 0x6B, 0x76, 0x6A, 0x74, 0x66, 0x76, 0x6B, 0x76, 0x69, 0x75, 0x67, 0x72, 0x68, 0x75, 0x67, 0x72, 0x67, 0x77, 0x6B, 0x77, 0x6B, 0x77, 0x6B, 0x74, 0x69, 0x70, 0x66, 0x74, 0x67, 0x77, 0x6D, 0x72, 0x66, 0x73, 0x69, 0x76, 0x69, 0x77, 0x6B, 0x7A, 0x6E, 0x75, 0x67, 0x73, 0x67, 0x77, 0x6A, 0x76, 0x6B, 0x77, 0x6B, 0x74, 0x68, 0x76, 0x69, 0x75, 0x68, 0x72, 0x64, 0x75, 0x6B, 0x78, 0x6A, 0x76, 0x66, 0x70, 0x63, 0x70, 0x63, 0x76, 0x68, 0x74, 0x68, 0x73, 0x63, 0x6E, 0x63, 0x71, 0x63, 0x6F, 0x62, 0x67, 0x5B, 0x67, 0x5C, 0x67, 0x5B, 0x63, 0x56, 0x50, 0x46, 0x38, 0x30, 0x2C, 0x26, 0x26, 0x22, 0x26, 0x22, 0x32, 0x31, 0x4B, 0x48, 0x5F, 0x58, 0x63, 0x59, 0x67, 0x5B, 0x43, 0x36, 0x25, 0x1F, 0x21, 0x1D, 0x1F, 0x1C, 0x1E, 0x1B, 0x2A, 0x2B, 0x56, 0x56, 0x69, 0x60, 0x6C, 0x62, 0x6E, 0x64, 0x70, 0x66, 0x70, 0x63, 0x6D, 0x62, 0x6C, 0x60, 0x6E, 0x63, 0x6B, 0x5F, 0x6D, 0x62, 0x6B, 0x62, 0x6B, 0x60, 0x6B, 0x61, 0x6B, 0x61, 0x6C, 0x63, 0x69, 0x5E, 0x69, 0x60, 0x67, 0x5D, 0x69, 0x5F, 0x69, 0x5D, 0x68, 0x5D, 0x67, 0x5B, 0x66, 0x5C, 0x67, 0x5B, 0x66, 0x5C, 0x64, 0x5A, 0x67, 0x5D, 0x66, 0x5C, 0x67, 0x5B, 0x63, 0x59, 0x65, 0x59, 0x6A, 0x5F, 0x67, 0x5B, 0x69, 0x5D, 0x6D, 0x63, 0x6D, 0x64, 0x69, 0x61, 0x69, 0x5F, 0x67, 0x5E, 0x65, 0x5B, 0x65, 0x58, 0x63, 0x58, 0x63, 0x58, 0x67, 0x5B, 0x66, 0x5B, 0x69, 0x5F, 0x67, 0x5B, 0x66, 0x5C, 0x67, 0x5C, 0x68, 0x5C, 0x65, 0x5B, 0x66, 0x5B, 0x6A, 0x5D, 0x64, 0x5A, 0x63, 0x59, 0x60, 0x54, 0x4C, 0x4E, 0x35, 0x34, 0x30, 0x36, 0x2E, 0x31, 0x29, 0x2F, 0x35, 0x3A, 0x2C, 0x31, 0x24, 0x25, 0x23, 0x28, 0x24, 0x27, 0x23, 0x25, 0x25, 0x2C, 0x2E, 0x36, 0x2D, 0x33, 0x2D, 0x33, 0x33, 0x39, 0x32, 0x39, 0x37, 0x3F, 0x30, 0x38, 0x31, 0x35, 0x31, 0x3A, 0x35, 0x39, 0x2B, 0x31, 0x31, 0x37, 0x2F, 0x37, 0x36, 0x3C, 0x2C, 0x30, 0x35, 0x3C, 0x2D, 0x32, 0x30, 0x34, 0x27, 0x2B, 0x2D, 0x32, 0x2C, 0x31, 0x31, 0x36, 0x2C, 0x30, 0x33, 0x3A, 0x2D, 0x34, 0x34, 0x3D, 0x36, 0x3B, 0x2F, 0x33, 0x2F, 0x37, 0x32, 0x39, 0x2D, 0x34, 0x39, 0x41, 0x30, 0x35, 0x2B, 0x32, 0x33, 0x37
    },

    {
        0x59, 0x21, 0x58, 0x1F, 0x58, 0x20, 0x59, 0x1F, 0x59, 0x20, 0x5C, 0x21, 0x5B, 0x20, 0x5B, 0x21, 0x5B, 0x21, 0x5C, 0x21, 0x5C, 0x21, 0x5C, 0x21, 0x5A, 0x21, 0x5A, 0x20, 0x5A, 0x21, 0x5A, 0x21, 0x5B, 0x20, 0x5A, 0x20, 0x5A, 0x21, 0x5B, 0x21, 0x5A, 0x21, 0x5A, 0x21, 0x5A, 0x21, 0x5A, 0x22, 0x5B, 0x22, 0x5C, 0x22, 0x5D, 0x22, 0x5C, 0x21, 0x57, 0x20, 0x55, 0x1F, 0x4E, 0x1D, 0x41, 0x1B, 0x36, 0x1A, 0x43, 0x1D, 0x52, 0x20, 0x52, 0x1E, 0x4C, 0x1D, 0x39, 0x18, 0x26, 0x15, 0x20, 0x13, 0x1E, 0x12, 0x1D, 0x13, 0x1C, 0x13, 0x1C, 0x12, 0x1A, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x19, 0x11, 0x19, 0x11, 0x19, 0x12, 0x19, 0x11, 0x19, 0x11, 0x18, 0x11, 0x17, 0x11, 0x18, 0x11, 0x19, 0x11, 0x19, 0x11, 0x19, 0x11, 0x19, 0x11, 0x19, 0x12, 0x19, 0x12, 0x1A, 0x12, 0x19, 0x12, 0x19, 0x12, 0x1A, 0x12, 0x1A, 0x12, 0x1A, 0x12, 0x1C, 0x14, 0x22, 0x1D, 0x44, 0x3F, 0x6E, 0x5B, 0x78, 0x62, 0x7B, 0x64, 0x74, 0x58, 0x52, 0x38, 0x30, 0x21, 0x25, 0x1B, 0x21, 0x18, 0x20, 0x17, 0x25, 0x21, 0x4F, 0x47, 0x72, 0x5F, 0x7D, 0x66, 0x81, 0x68, 0x83, 0x6B, 0x82, 0x66, 0x69, 0x4A, 0x39, 0x28, 0x28, 0x1D, 0x22, 0x18, 0x1D, 0x15, 0x1B, 0x14, 0x1B, 0x13, 0x1A, 0x12, 0x1A, 0x12, 0x1A, 0x12, 0x1B, 0x13, 0x1A, 0x12, 0x1A, 0x12, 0x1A, 0x12, 0x1C, 0x14, 0x1F, 0x15, 0x1E, 0x14, 0x1B, 0x13, 0x1B, 0x13, 0x1C, 0x13, 0x1C, 0x13, 0x1D, 0x13, 0x1C, 0x13, 0x1B, 0x13, 0x1B, 0x13, 0x1D, 0x13, 0x1C, 0x13, 0x1F, 0x15, 0x35, 0x1B, 0x58, 0x24, 0x64, 0x27, 0x61, 0x25, 0x40, 0x1E, 0x37, 0x1D, 0x5B, 0x26, 0x63, 0x27, 0x6C, 0x28, 0x6B, 0x28, 0x6C, 0x28, 0x67, 0x27, 0x68, 0x27, 0x6A, 0x28, 0x6E, 0x29, 0x67, 0x27, 0x6B, 0x28, 0x68, 0x27, 0x6B, 0x28, 0x6A, 0x27, 0x6B, 0x28, 0x6B, 0x29, 0x6B, 0x29, 0x6B, 0x28, 0x6B, 0x28, 0x6F, 0x2B, 0x71, 0x2B, 0x6C, 0x2A, 0x69, 0x27, 0x6B, 0x28, 0x6A, 0x27, 0x67, 0x27, 0x6A, 0x27, 0x67, 0x26, 0x68, 0x27, 0x69, 0x27, 0x6A, 0x27, 0x63, 0x25, 0x6A, 0x27, 0x6D, 0x29, 0x6E, 0x29, 0x6A, 0x27, 0x6B, 0x28, 0x6A, 0x28, 0x69, 0x27, 0x68, 0x28, 0x6A, 0x29, 0x6A, 0x27, 0x6B, 0x28, 0x68, 0x27, 0x69, 0x27, 0x69, 0x28, 0x65, 0x26, 0x67, 0x27, 0x6B, 0x2A, 0x68, 0x27, 0x6B, 0x28, 0x67, 0x26, 0x68, 0x28, 0x6A, 0x28, 0x6A, 0x26, 0x68, 0x26, 0x6A, 0x27, 0x6C, 0x27, 0x65, 0x25, 0x69, 0x25, 0x66, 0x25, 0x67, 0x25, 0x64, 0x23, 0x64, 0x24, 0x66, 0x24, 0x65, 0x24, 0x64, 0x24, 0x65, 0x24, 0x68, 0x24, 0x65, 0x24, 0x64, 0x24, 0x63, 0x23, 0x60, 0x24, 0x60, 0x23, 0x5E, 0x22, 0x5E, 0x21, 0x5C, 0x21, 0x59, 0x20, 0x58, 0x21, 0x4B, 0x1D, 0x41, 0x1A, 0x36, 0x17, 0x3C, 0x1A, 0x47, 0x1C, 0x52, 0x20, 0x5C, 0x22, 0x5C, 0x21, 0x5B, 0x21, 0x53, 0x1F, 0x39, 0x18, 0x29, 0x14, 0x25, 0x15, 0x34, 0x1A, 0x4F, 0x20, 0x5A, 0x22, 0x5F, 0x23, 0x5F, 0x23, 0x62, 0x24, 0x61, 0x24, 0x62, 0x25, 0x61, 0x24, 0x61, 0x25, 0x60, 0x24, 0x63, 0x26, 0x64, 0x26, 0x64, 0x26, 0x5E, 0x24, 0x60, 0x24, 0x62, 0x24, 0x63, 0x26, 0x5E, 0x23, 0x5F, 0x24, 0x5D, 0x23, 0x5C, 0x22, 0x5C, 0x22, 0x59, 0x22, 0x5C, 0x22, 0x57, 0x20, 0x5A, 0x21, 0x5C, 0x22, 0x59, 0x21, 0x5C, 0x22, 0x59, 0x22, 0x5C, 0x21, 0x59, 0x22, 0x5D, 0x22, 0x5C, 0x22, 0x5E, 0x23, 0x5D, 0x22, 0x5B, 0x22, 0x5C, 0x23, 0x5B, 0x22, 0x59, 0x21, 0x58, 0x21, 0x5A, 0x22, 0x59, 0x21, 0x59, 0x21, 0x58, 0x22, 0x5D, 0x22, 0x57, 0x21, 0x5C, 0x23, 0x5C, 0x23, 0x5A, 0x21, 0x5A, 0x22, 0x5C, 0x22, 0x5C, 0x22, 0x58, 0x21, 0x59, 0x21, 0x5B, 0x22, 0x58, 0x21, 0x58, 0x21, 0x43, 0x20, 0x3A, 0x1E, 0x33, 0x1D, 0x42, 0x22, 0x40, 0x21, 0x34, 0x1C, 0x37, 0x1E, 0x36, 0x1E, 0x41, 0x21, 0x35, 0x1D, 0x2F, 0x19, 0x38, 0x1F, 0x3D, 0x1F, 0x2F, 0x1A, 0x2D, 0x1B, 0x36, 0x1C, 0x38, 0x1E, 0x37, 0x1C, 0x2E, 0x1B, 0x2D, 0x19, 0x31, 0x1C, 0x30, 0x1B, 0x2B, 0x19, 0x32, 0x1C, 0x31, 0x1B, 0x35, 0x1D, 0x2F, 0x1B, 0x3E, 0x21, 0x38, 0x1E, 0x34, 0x1C, 0x33, 0x1C, 0x3F, 0x20, 0x32, 0x1B, 0x3C, 0x20, 0x38, 0x1E, 0x3C, 0x1F, 0x34, 0x1D, 0x35, 0x1F, 0x34, 0x1C, 0x2C, 0x19, 0x36, 0x1E, 0x3D, 0x21, 0x30, 0x1C, 0x37, 0x1D, 0x2C, 0x19, 0x2C, 0x1A, 0x31, 0x1A
    },

    {
        0x64, 0x58, 0x63, 0x58, 0x64, 0x58, 0x64, 0x57, 0x65, 0x5A, 0x67, 0x5B, 0x67, 0x5A, 0x67, 0x5B, 0x67, 0x5B, 0x67, 0x5A, 0x69, 0x5B, 0x69, 0x5C, 0x66, 0x5A, 0x67, 0x5A, 0x67, 0x59, 0x68, 0x5A, 0x69, 0x5A, 0x68, 0x5A, 0x69, 0x5C, 0x69, 0x5B, 0x68, 0x5A, 0x67, 0x5A, 0x68, 0x5B, 0x66, 0x59, 0x68, 0x5B, 0x69, 0x5B, 0x6B, 0x5C, 0x69, 0x5B, 0x65, 0x57, 0x62, 0x55, 0x5C, 0x4F, 0x4F, 0x42, 0x3C, 0x35, 0x42, 0x41, 0x56, 0x50, 0x5B, 0x52, 0x57, 0x4E, 0x46, 0x3C, 0x2C, 0x27, 0x21, 0x20, 0x1D, 0x1E, 0x1B, 0x1E, 0x1A, 0x1D, 0x18, 0x1A, 0x16, 0x19, 0x15, 0x18, 0x14, 0x17, 0x14, 0x17, 0x13, 0x17, 0x14, 0x18, 0x16, 0x1A, 0x15, 0x19, 0x15, 0x19, 0x14, 0x18, 0x14, 0x17, 0x14, 0x17, 0x14, 0x17, 0x15, 0x19, 0x15, 0x19, 0x15, 0x18, 0x14, 0x18, 0x14, 0x18, 0x15, 0x19, 0x15, 0x19, 0x15, 0x19, 0x15, 0x19, 0x15, 0x19, 0x15, 0x1A, 0x15, 0x19, 0x18, 0x1C, 0x22, 0x2A, 0x3F, 0x56, 0x5D, 0x72, 0x65, 0x79, 0x68, 0x7E, 0x65, 0x76, 0x50, 0x56, 0x31, 0x32, 0x23, 0x26, 0x1F, 0x23, 0x1E, 0x21, 0x26, 0x30, 0x47, 0x60, 0x60, 0x75, 0x69, 0x7B, 0x6D, 0x81, 0x71, 0x86, 0x6D, 0x81, 0x5F, 0x6A, 0x3C, 0x3C, 0x27, 0x29, 0x1E, 0x22, 0x19, 0x1D, 0x18, 0x1B, 0x16, 0x1A, 0x16, 0x1A, 0x16, 0x19, 0x15, 0x19, 0x16, 0x1A, 0x16, 0x1A, 0x16, 0x1B, 0x16, 0x1A, 0x17, 0x1C, 0x19, 0x1E, 0x19, 0x1D, 0x17, 0x1B, 0x17, 0x1C, 0x17, 0x1C, 0x17, 0x1B, 0x17, 0x1C, 0x17, 0x1B, 0x17, 0x1B, 0x17, 0x1B, 0x18, 0x1C, 0x19, 0x1C, 0x20, 0x24, 0x3F, 0x44, 0x62, 0x5D, 0x68, 0x64, 0x62, 0x58, 0x3D, 0x34, 0x41, 0x42, 0x66, 0x61, 0x6E, 0x66, 0x75, 0x6D, 0x77, 0x6A, 0x79, 0x6C, 0x76, 0x68, 0x75, 0x6A, 0x75, 0x6B, 0x7B, 0x6D, 0x75, 0x68, 0x77, 0x6D, 0x75, 0x69, 0x77, 0x6C, 0x79, 0x6B, 0x78, 0x6A, 0x78, 0x6C, 0x78, 0x6D, 0x78, 0x6B, 0x76, 0x6A, 0x79, 0x70, 0x7B, 0x70, 0x76, 0x6C, 0x78, 0x6A, 0x77, 0x69, 0x75, 0x68, 0x75, 0x69, 0x76, 0x69, 0x72, 0x67, 0x75, 0x68, 0x74, 0x68, 0x77, 0x6A, 0x70, 0x63, 0x79, 0x6B, 0x7B, 0x6E, 0x7C, 0x6D, 0x79, 0x6B, 0x78, 0x6B, 0x76, 0x69, 0x76, 0x6A, 0x75, 0x68, 0x77, 0x6B, 0x75, 0x69, 0x77, 0x69, 0x76, 0x6A, 0x75, 0x6A, 0x75, 0x69, 0x72, 0x65, 0x75, 0x68, 0x77, 0x6C, 0x76, 0x6B, 0x79, 0x6D, 0x76, 0x66, 0x75, 0x6A, 0x75, 0x68, 0x78, 0x6A, 0x77, 0x69, 0x77, 0x6A, 0x74, 0x67, 0x71, 0x63, 0x76, 0x6A, 0x76, 0x67, 0x76, 0x68, 0x71, 0x61, 0x71, 0x65, 0x74, 0x65, 0x75, 0x66, 0x74, 0x67, 0x76, 0x66, 0x77, 0x68, 0x74, 0x65, 0x73, 0x64, 0x71, 0x64, 0x70, 0x62, 0x6D, 0x5F, 0x6C, 0x60, 0x6F, 0x60, 0x6C, 0x5F, 0x67, 0x59, 0x63, 0x59, 0x57, 0x4D, 0x4E, 0x46, 0x45, 0x3D, 0x4C, 0x47, 0x53, 0x4C, 0x5D, 0x55, 0x67, 0x5C, 0x68, 0x5B, 0x68, 0x5C, 0x61, 0x57, 0x4A, 0x40, 0x37, 0x2F, 0x34, 0x31, 0x45, 0x46, 0x5E, 0x5A, 0x64, 0x5B, 0x68, 0x5E, 0x6A, 0x5F, 0x6E, 0x61, 0x6C, 0x60, 0x6E, 0x63, 0x6D, 0x63, 0x6F, 0x63, 0x6C, 0x60, 0x6F, 0x63, 0x6F, 0x65, 0x6D, 0x64, 0x6A, 0x5F, 0x6B, 0x61, 0x70, 0x64, 0x70, 0x64, 0x69, 0x5E, 0x6B, 0x60, 0x68, 0x5F, 0x69, 0x5D, 0x68, 0x5D, 0x64, 0x5A, 0x69, 0x5C, 0x64, 0x57, 0x66, 0x5C, 0x6A, 0x5D, 0x64, 0x5A, 0x67, 0x5C, 0x66, 0x59, 0x66, 0x5B, 0x66, 0x5C, 0x68, 0x5E, 0x68, 0x5C, 0x6A, 0x5D, 0x6A, 0x5E, 0x68, 0x5C, 0x66, 0x5B, 0x64, 0x5B, 0x65, 0x5A, 0x65, 0x5A, 0x67, 0x5B, 0x66, 0x58, 0x66, 0x59, 0x66, 0x5A, 0x68, 0x5B, 0x65, 0x5A, 0x68, 0x5D, 0x67, 0x5B, 0x65, 0x5A, 0x68, 0x5C, 0x67, 0x5E, 0x66, 0x5C, 0x63, 0x58, 0x66, 0x5A, 0x69, 0x5D, 0x65, 0x58, 0x61, 0x55, 0x41, 0x3F, 0x37, 0x39, 0x30, 0x36, 0x3C, 0x43, 0x37, 0x3C, 0x2B, 0x30, 0x30, 0x36, 0x32, 0x3D, 0x36, 0x3A, 0x2E, 0x36, 0x28, 0x2B, 0x32, 0x3C, 0x32, 0x37, 0x29, 0x2A, 0x2C, 0x33, 0x2E, 0x31, 0x33, 0x39, 0x2F, 0x31, 0x2A, 0x30, 0x29, 0x2B, 0x2C, 0x32, 0x2D, 0x31, 0x2A, 0x30, 0x2D, 0x32, 0x2D, 0x35, 0x32, 0x37, 0x2D, 0x32, 0x37, 0x3E, 0x34, 0x3A, 0x30, 0x35, 0x30, 0x38, 0x37, 0x3B, 0x2C, 0x2F, 0x36, 0x3F, 0x31, 0x35, 0x34, 0x39, 0x2B, 0x2D, 0x31, 0x37, 0x2C, 0x2F, 0x28, 0x2C, 0x2F, 0x37, 0x36, 0x3B, 0x2C, 0x32, 0x30, 0x33, 0x27, 0x2A, 0x2C, 0x30, 0x2F, 0x32
    },

    {
        0x59, 0x20, 0x59, 0x1F, 0x58, 0x1F, 0x57, 0x1F, 0x58, 0x1F, 0x59, 0x20, 0x5A, 0x20, 0x59, 0x20, 0x59, 0x20, 0x58, 0x20, 0x5A, 0x20, 0x5B, 0x20, 0x5C, 0x20, 0x5B, 0x20, 0x58, 0x20, 0x5B, 0x20, 0x5B, 0x21, 0x5A, 0x21, 0x5A, 0x20, 0x59, 0x20, 0x59, 0x20, 0x5A, 0x21, 0x5B, 0x20, 0x5A, 0x20, 0x5A, 0x20, 0x5B, 0x21, 0x5C, 0x21, 0x5C, 0x21, 0x5B, 0x20, 0x59, 0x20, 0x57, 0x1F, 0x51, 0x1E, 0x44, 0x1B, 0x36, 0x1A, 0x3E, 0x1C, 0x4F, 0x1E, 0x53, 0x1F, 0x4F, 0x1D, 0x3F, 0x19, 0x29, 0x15, 0x22, 0x14, 0x1E, 0x12, 0x1E, 0x12, 0x1B, 0x11, 0x19, 0x11, 0x19, 0x10, 0x18, 0x10, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x19, 0x12, 0x1A, 0x12, 0x1A, 0x12, 0x19, 0x11, 0x18, 0x11, 0x17, 0x10, 0x18, 0x11, 0x19, 0x12, 0x1C, 0x13, 0x18, 0x11, 0x19, 0x11, 0x1A, 0x12, 0x1B, 0x12, 0x19, 0x12, 0x19, 0x12, 0x19, 0x12, 0x1A, 0x13, 0x1A, 0x12, 0x1A, 0x13, 0x21, 0x1D, 0x44, 0x3F, 0x6A, 0x58, 0x79, 0x62, 0x7F, 0x66, 0x83, 0x6A, 0x82, 0x6A, 0x7D, 0x60, 0x5F, 0x41, 0x37, 0x26, 0x28, 0x1D, 0x29, 0x22, 0x4B, 0x45, 0x72, 0x5F, 0x7A, 0x65, 0x7F, 0x69, 0x84, 0x6C, 0x87, 0x6E, 0x87, 0x6A, 0x7F, 0x65, 0x6F, 0x51, 0x43, 0x2E, 0x29, 0x1D, 0x21, 0x17, 0x1E, 0x15, 0x1B, 0x13, 0x1A, 0x13, 0x19, 0x12, 0x19, 0x12, 0x1A, 0x12, 0x1B, 0x12, 0x1B, 0x13, 0x1B, 0x12, 0x1B, 0x13, 0x1C, 0x13, 0x1E, 0x14, 0x1C, 0x13, 0x1C, 0x13, 0x1C, 0x13, 0x1C, 0x13, 0x1C, 0x13, 0x1B, 0x12, 0x1B, 0x12, 0x1C, 0x13, 0x1D, 0x13, 0x1E, 0x15, 0x34, 0x1C, 0x59, 0x24, 0x62, 0x26, 0x5F, 0x25, 0x40, 0x1D, 0x36, 0x1D, 0x57, 0x25, 0x68, 0x29, 0x68, 0x28, 0x6A, 0x27, 0x68, 0x27, 0x6A, 0x27, 0x68, 0x28, 0x69, 0x28, 0x6D, 0x29, 0x6E, 0x29, 0x6C, 0x28, 0x6C, 0x28, 0x6D, 0x28, 0x6A, 0x28, 0x6B, 0x28, 0x69, 0x28, 0x6B, 0x27, 0x6B, 0x28, 0x69, 0x28, 0x6C, 0x29, 0x6A, 0x29, 0x6C, 0x29, 0x6A, 0x27, 0x6A, 0x27, 0x68, 0x27, 0x6A, 0x28, 0x68, 0x27, 0x67, 0x27, 0x66, 0x26, 0x68, 0x26, 0x69, 0x26, 0x6A, 0x27, 0x68, 0x27, 0x6D, 0x28, 0x6B, 0x27, 0x69, 0x28, 0x6B, 0x28, 0x6D, 0x28, 0x6E, 0x28, 0x6A, 0x26, 0x6A, 0x27, 0x6B, 0x28, 0x6B, 0x28, 0x6A, 0x27, 0x6B, 0x28, 0x64, 0x26, 0x65, 0x28, 0x69, 0x27, 0x67, 0x26, 0x6A, 0x28, 0x6A, 0x27, 0x6B, 0x29, 0x69, 0x27, 0x70, 0x2B, 0x6C, 0x27, 0x6D, 0x28, 0x6C, 0x28, 0x62, 0x24, 0x62, 0x24, 0x62, 0x25, 0x64, 0x24, 0x66, 0x25, 0x64, 0x24, 0x61, 0x24, 0x65, 0x24, 0x63, 0x24, 0x67, 0x26, 0x68, 0x25, 0x67, 0x24, 0x63, 0x24, 0x60, 0x22, 0x60, 0x22, 0x61, 0x23, 0x62, 0x24, 0x61, 0x24, 0x61, 0x23, 0x5D, 0x21, 0x5F, 0x22, 0x5A, 0x22, 0x5F, 0x23, 0x5B, 0x21, 0x5D, 0x22, 0x59, 0x22, 0x5D, 0x22, 0x5A, 0x22, 0x5A, 0x21, 0x5B, 0x22, 0x5D, 0x22, 0x5A, 0x22, 0x5B, 0x23, 0x60, 0x25, 0x5B, 0x23, 0x5D, 0x25, 0x65, 0x27, 0x61, 0x24, 0x5C, 0x23, 0x5A, 0x22, 0x5E, 0x24, 0x5E, 0x24, 0x64, 0x25, 0x64, 0x25, 0x61, 0x24, 0x65, 0x28, 0x63, 0x25, 0x61, 0x24, 0x60, 0x25, 0x61, 0x25, 0x5C, 0x23, 0x5E, 0x24, 0x5E, 0x23, 0x5C, 0x23, 0x5E, 0x23, 0x5B, 0x22, 0x5C, 0x23, 0x5C, 0x22, 0x5C, 0x22, 0x5B, 0x22, 0x5A, 0x21, 0x5A, 0x21, 0x59, 0x22, 0x5E, 0x23, 0x58, 0x21, 0x55, 0x1F, 0x59, 0x21, 0x57, 0x21, 0x58, 0x21, 0x58, 0x21, 0x5B, 0x22, 0x5A, 0x21, 0x5C, 0x22, 0x5D, 0x23, 0x59, 0x22, 0x58, 0x21, 0x59, 0x22, 0x5A, 0x21, 0x57, 0x20, 0x5A, 0x22, 0x58, 0x21, 0x5A, 0x22, 0x5E, 0x24, 0x57, 0x21, 0x58, 0x21, 0x5A, 0x22, 0x56, 0x21, 0x58, 0x20, 0x58, 0x21, 0x57, 0x21, 0x58, 0x21, 0x58, 0x21, 0x5A, 0x22, 0x59, 0x20, 0x55, 0x1F, 0x3C, 0x1D, 0x36, 0x1C, 0x2F, 0x1B, 0x39, 0x1E, 0x2C, 0x18, 0x2F, 0x1C, 0x36, 0x1C, 0x37, 0x1E, 0x31, 0x1B, 0x30, 0x1B, 0x2D, 0x19, 0x35, 0x1D, 0x33, 0x1C, 0x2D, 0x19, 0x35, 0x1E, 0x3A, 0x1F, 0x39, 0x1F, 0x34, 0x1C, 0x31, 0x1C, 0x3B, 0x1F, 0x39, 0x1F, 0x40, 0x21, 0x33, 0x1D, 0x40, 0x21, 0x34, 0x1E, 0x3A, 0x1F, 0x30, 0x1C, 0x3F, 0x20, 0x30, 0x1A, 0x31, 0x1B, 0x2C, 0x1A, 0x2D, 0x19, 0x2D, 0x1A, 0x36, 0x1D, 0x2A, 0x18, 0x2B, 0x19, 0x2B, 0x19, 0x36, 0x1D, 0x34, 0x1C, 0x36, 0x1C, 0x33, 0x1C, 0x35, 0x1D, 0x33, 0x1D, 0x3F, 0x20, 0x3B, 0x1E, 0x3A, 0x1F, 0x38, 0x1D
    },

    {
        0x65, 0x59, 0x64, 0x58, 0x64, 0x59, 0x61, 0x58, 0x65, 0x58, 0x65, 0x59, 0x67, 0x5A, 0x65, 0x59, 0x65, 0x58, 0x66, 0x59, 0x66, 0x5A, 0x69, 0x5A, 0x68, 0x5B, 0x69, 0x5B, 0x66, 0x59, 0x69, 0x5B, 0x68, 0x5B, 0x67, 0x59, 0x67, 0x59, 0x67, 0x59, 0x68, 0x5A, 0x6A, 0x5C, 0x6B, 0x5B, 0x69, 0x5A, 0x68, 0x5B, 0x68, 0x5C, 0x6A, 0x5C, 0x69, 0x5B, 0x67, 0x5A, 0x67, 0x5B, 0x66, 0x57, 0x5F, 0x52, 0x54, 0x47, 0x3F, 0x36, 0x3E, 0x3D, 0x51, 0x4D, 0x5C, 0x53, 0x5B, 0x51, 0x4D, 0x42, 0x32, 0x2A, 0x23, 0x22, 0x1E, 0x1F, 0x1B, 0x1D, 0x19, 0x1A, 0x16, 0x19, 0x15, 0x18, 0x15, 0x18, 0x14, 0x18, 0x15, 0x18, 0x14, 0x18, 0x15, 0x19, 0x16, 0x1A, 0x16, 0x19, 0x15, 0x19, 0x15, 0x18, 0x15, 0x19, 0x14, 0x18, 0x15, 0x19, 0x16, 0x1A, 0x15, 0x19, 0x15, 0x19, 0x15, 0x1A, 0x15, 0x1A, 0x15, 0x19, 0x15, 0x19, 0x15, 0x19, 0x16, 0x1A, 0x16, 0x1A, 0x18, 0x1B, 0x20, 0x28, 0x3D, 0x54, 0x5B, 0x71, 0x66, 0x79, 0x6A, 0x7D, 0x6F, 0x82, 0x6D, 0x83, 0x6B, 0x7F, 0x59, 0x63, 0x38, 0x39, 0x27, 0x2A, 0x2A, 0x33, 0x46, 0x5E, 0x62, 0x78, 0x6A, 0x7C, 0x6D, 0x80, 0x70, 0x85, 0x72, 0x85, 0x72, 0x85, 0x6C, 0x80, 0x63, 0x73, 0x43, 0x45, 0x29, 0x2A, 0x1F, 0x22, 0x1B, 0x1E, 0x17, 0x1B, 0x16, 0x1A, 0x16, 0x1A, 0x16, 0x19, 0x16, 0x1A, 0x16, 0x1B, 0x17, 0x1B, 0x17, 0x1B, 0x17, 0x1B, 0x17, 0x1B, 0x18, 0x1D, 0x17, 0x1C, 0x17, 0x1B, 0x18, 0x1C, 0x18, 0x1C, 0x17, 0x1C, 0x17, 0x1B, 0x17, 0x1B, 0x18, 0x1C, 0x19, 0x1D, 0x1F, 0x21, 0x3E, 0x42, 0x61, 0x5F, 0x6B, 0x65, 0x62, 0x5A, 0x3E, 0x36, 0x3D, 0x40, 0x62, 0x5F, 0x70, 0x69, 0x74, 0x6A, 0x76, 0x68, 0x76, 0x69, 0x78, 0x6A, 0x77, 0x6B, 0x77, 0x6C, 0x78, 0x6D, 0x7B, 0x6D, 0x78, 0x6A, 0x78, 0x6C, 0x78, 0x6C, 0x76, 0x6C, 0x78, 0x6C, 0x77, 0x6A, 0x78, 0x69, 0x77, 0x6A, 0x77, 0x6C, 0x77, 0x6E, 0x76, 0x6B, 0x79, 0x6C, 0x77, 0x68, 0x78, 0x6C, 0x76, 0x6A, 0x75, 0x6A, 0x74, 0x68, 0x75, 0x68, 0x74, 0x66, 0x75, 0x68, 0x78, 0x6A, 0x77, 0x69, 0x74, 0x68, 0x78, 0x6C, 0x79, 0x6C, 0x78, 0x69, 0x7A, 0x6B, 0x79, 0x6C, 0x7A, 0x6D, 0x78, 0x69, 0x77, 0x6A, 0x76, 0x6B, 0x77, 0x6C, 0x76, 0x6A, 0x79, 0x6C, 0x73, 0x66, 0x70, 0x68, 0x75, 0x6A, 0x75, 0x69, 0x78, 0x6C, 0x78, 0x6D, 0x78, 0x6B, 0x78, 0x6B, 0x7B, 0x6F, 0x79, 0x6B, 0x7A, 0x6E, 0x7C, 0x6C, 0x72, 0x63, 0x71, 0x65, 0x71, 0x64, 0x71, 0x65, 0x76, 0x68, 0x72, 0x65, 0x71, 0x64, 0x74, 0x68, 0x70, 0x62, 0x75, 0x68, 0x76, 0x69, 0x74, 0x66, 0x71, 0x63, 0x6E, 0x62, 0x6E, 0x62, 0x6D, 0x62, 0x6F, 0x63, 0x6B, 0x62, 0x6D, 0x60, 0x69, 0x5D, 0x6C, 0x60, 0x6A, 0x5E, 0x69, 0x60, 0x67, 0x5D, 0x6A, 0x5E, 0x68, 0x5F, 0x6A, 0x60, 0x65, 0x5B, 0x68, 0x5D, 0x6A, 0x5E, 0x68, 0x5C, 0x69, 0x5D, 0x66, 0x5D, 0x6A, 0x64, 0x69, 0x60, 0x6A, 0x62, 0x6C, 0x64, 0x6B, 0x61, 0x69, 0x5D, 0x67, 0x5C, 0x6B, 0x5F, 0x6B, 0x5F, 0x6F, 0x65, 0x6F, 0x64, 0x6C, 0x62, 0x70, 0x67, 0x71, 0x66, 0x6E, 0x64, 0x6B, 0x62, 0x6C, 0x62, 0x69, 0x5D, 0x69, 0x5E, 0x69, 0x5E, 0x67, 0x5C, 0x6B, 0x5F, 0x66, 0x5B, 0x6A, 0x5F, 0x6B, 0x5F, 0x69, 0x5E, 0x66, 0x5B, 0x66, 0x5A, 0x67, 0x5B, 0x66, 0x5B, 0x68, 0x5E, 0x65, 0x5A, 0x62, 0x57, 0x66, 0x59, 0x61, 0x58, 0x62, 0x59, 0x64, 0x5B, 0x67, 0x5B, 0x67, 0x5B, 0x6B, 0x5E, 0x67, 0x5F, 0x65, 0x5D, 0x62, 0x57, 0x65, 0x59, 0x65, 0x5A, 0x62, 0x58, 0x67, 0x5D, 0x65, 0x5A, 0x65, 0x5C, 0x6A, 0x5F, 0x66, 0x5A, 0x67, 0x5B, 0x67, 0x5A, 0x64, 0x57, 0x65, 0x59, 0x65, 0x5A, 0x63, 0x58, 0x63, 0x59, 0x65, 0x5A, 0x68, 0x5D, 0x67, 0x59, 0x5E, 0x50, 0x3D, 0x3B, 0x30, 0x31, 0x2B, 0x2F, 0x30, 0x34, 0x2A, 0x2C, 0x2E, 0x34, 0x2F, 0x32, 0x32, 0x39, 0x2D, 0x31, 0x2D, 0x34, 0x2B, 0x30, 0x30, 0x38, 0x30, 0x36, 0x2D, 0x31, 0x32, 0x3D, 0x37, 0x3B, 0x33, 0x39, 0x2F, 0x33, 0x2F, 0x37, 0x36, 0x3B, 0x34, 0x3B, 0x36, 0x3C, 0x2E, 0x36, 0x37, 0x3A, 0x30, 0x36, 0x30, 0x36, 0x2C, 0x30, 0x36, 0x3C, 0x2A, 0x2D, 0x2D, 0x2E, 0x29, 0x2C, 0x2A, 0x2D, 0x2B, 0x32, 0x2F, 0x33, 0x29, 0x2D, 0x2A, 0x2E, 0x2A, 0x30, 0x34, 0x3A, 0x31, 0x37, 0x31, 0x35, 0x30, 0x35, 0x31, 0x37, 0x2F, 0x37, 0x39, 0x3F, 0x35, 0x3B, 0x34, 0x3B, 0x31, 0x33
    },

    {
        0x5B, 0x20, 0x5B, 0x20, 0x5A, 0x1F, 0x58, 0x1F, 0x59, 0x20, 0x5A, 0x20, 0x5B, 0x20, 0x5A, 0x20, 0x5A, 0x20, 0x58, 0x20, 0x5B, 0x21, 0x5C, 0x21, 0x5C, 0x21, 0x5B, 0x21, 0x5A, 0x20, 0x5A, 0x21, 0x59, 0x21, 0x5A, 0x21, 0x5A, 0x20, 0x5A, 0x20, 0x5A, 0x20, 0x59, 0x20, 0x5A, 0x21, 0x5B, 0x20, 0x5C, 0x21, 0x5B, 0x21, 0x5C, 0x21, 0x5B, 0x20, 0x5B, 0x20, 0x5B, 0x21, 0x5C, 0x21, 0x58, 0x20, 0x53, 0x1F, 0x48, 0x1C, 0x38, 0x19, 0x3B, 0x1B, 0x4C, 0x1E, 0x54, 0x20, 0x51, 0x1E, 0x42, 0x1A, 0x2C, 0x16, 0x22, 0x14, 0x1E, 0x13, 0x1C, 0x11, 0x1B, 0x11, 0x1B, 0x12, 0x1A, 0x12, 0x1A, 0x12, 0x1A, 0x11, 0x1A, 0x12, 0x1A, 0x12, 0x1B, 0x12, 0x1B, 0x12, 0x1A, 0x12, 0x19, 0x11, 0x19, 0x11, 0x19, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x18, 0x11, 0x19, 0x12, 0x19, 0x11, 0x19, 0x12, 0x1A, 0x12, 0x1B, 0x13, 0x1B, 0x13, 0x20, 0x1A, 0x3D, 0x39, 0x66, 0x57, 0x73, 0x5F, 0x7B, 0x65, 0x81, 0x69, 0x85, 0x6C, 0x85, 0x6B, 0x83, 0x6B, 0x80, 0x67, 0x66, 0x48, 0x3E, 0x31, 0x50, 0x49, 0x74, 0x61, 0x7E, 0x67, 0x82, 0x6A, 0x86, 0x6D, 0x85, 0x6D, 0x88, 0x6E, 0x88, 0x6E, 0x84, 0x6C, 0x80, 0x68, 0x73, 0x56, 0x48, 0x32, 0x2B, 0x1F, 0x22, 0x18, 0x1F, 0x16, 0x1D, 0x14, 0x1C, 0x13, 0x1C, 0x14, 0x1D, 0x13, 0x1C, 0x14, 0x1D, 0x13, 0x1C, 0x13, 0x1B, 0x13, 0x1C, 0x13, 0x1C, 0x13, 0x1D, 0x13, 0x1C, 0x13, 0x1B, 0x13, 0x1C, 0x13, 0x1C, 0x13, 0x1C, 0x13, 0x1C, 0x13, 0x1D, 0x14, 0x1E, 0x13, 0x30, 0x1B, 0x56, 0x22, 0x5F, 0x25, 0x61, 0x25, 0x44, 0x1F, 0x35, 0x1D, 0x53, 0x24, 0x64, 0x28, 0x68, 0x28, 0x68, 0x27, 0x6A, 0x28, 0x6D, 0x29, 0x6D, 0x28, 0x67, 0x27, 0x67, 0x27, 0x6A, 0x27, 0x69, 0x28, 0x6B, 0x29, 0x6B, 0x28, 0x69, 0x27, 0x6C, 0x28, 0x6B, 0x28, 0x68, 0x28, 0x6B, 0x27, 0x6B, 0x29, 0x6C, 0x29, 0x6B, 0x28, 0x6B, 0x28, 0x6A, 0x28, 0x69, 0x27, 0x69, 0x27, 0x69, 0x27, 0x69, 0x28, 0x67, 0x27, 0x66, 0x27, 0x6B, 0x29, 0x68, 0x27, 0x68, 0x26, 0x65, 0x26, 0x68, 0x27, 0x6A, 0x27, 0x68, 0x27, 0x6B, 0x27, 0x68, 0x27, 0x69, 0x26, 0x69, 0x28, 0x69, 0x27, 0x69, 0x27, 0x68, 0x27, 0x6B, 0x27, 0x68, 0x27, 0x6A, 0x27, 0x6E, 0x29, 0x6A, 0x28, 0x69, 0x28, 0x6B, 0x27, 0x69, 0x27, 0x68, 0x26, 0x65, 0x26, 0x66, 0x26, 0x69, 0x27, 0x68, 0x25, 0x6A, 0x27, 0x69, 0x27, 0x69, 0x27, 0x66, 0x26, 0x67, 0x26, 0x65, 0x24, 0x64, 0x25, 0x6A, 0x26, 0x65, 0x24, 0x67, 0x25, 0x62, 0x24, 0x64, 0x25, 0x64, 0x24, 0x67, 0x24, 0x63, 0x23, 0x61, 0x24, 0x62, 0x23, 0x61, 0x23, 0x5C, 0x22, 0x5C, 0x23, 0x60, 0x22, 0x5F, 0x22, 0x5D, 0x22, 0x5C, 0x21, 0x5B, 0x22, 0x5E, 0x23, 0x5E, 0x23, 0x61, 0x24, 0x5D, 0x22, 0x5B, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x5E, 0x22, 0x65, 0x27, 0x67, 0x29, 0x60, 0x25, 0x5F, 0x23, 0x5E, 0x23, 0x5E, 0x23, 0x60, 0x24, 0x63, 0x26, 0x63, 0x26, 0x62, 0x25, 0x5F, 0x25, 0x5F, 0x24, 0x63, 0x24, 0x61, 0x25, 0x66, 0x28, 0x67, 0x28, 0x65, 0x26, 0x62, 0x26, 0x63, 0x26, 0x5F, 0x24, 0x5F, 0x24, 0x5E, 0x24, 0x63, 0x27, 0x62, 0x25, 0x5C, 0x23, 0x60, 0x24, 0x5E, 0x23, 0x5C, 0x22, 0x59, 0x21, 0x58, 0x22, 0x5F, 0x25, 0x5D, 0x22, 0x59, 0x21, 0x5C, 0x22, 0x5B, 0x21, 0x5B, 0x21, 0x59, 0x22, 0x5B, 0x23, 0x5D, 0x22, 0x59, 0x21, 0x5A, 0x22, 0x5D, 0x23, 0x64, 0x28, 0x62, 0x25, 0x5B, 0x21, 0x59, 0x22, 0x58, 0x21, 0x57, 0x20, 0x58, 0x20, 0x5A, 0x21, 0x58, 0x21, 0x59, 0x21, 0x55, 0x20, 0x5C, 0x23, 0x5C, 0x23, 0x5B, 0x21, 0x5B, 0x22, 0x59, 0x21, 0x58, 0x21, 0x5A, 0x21, 0x57, 0x20, 0x5B, 0x21, 0x5A, 0x21, 0x58, 0x20, 0x3E, 0x1E, 0x35, 0x1D, 0x32, 0x1C, 0x3F, 0x21, 0x36, 0x1C, 0x37, 0x1E, 0x41, 0x21, 0x3C, 0x20, 0x38, 0x1D, 0x38, 0x1F, 0x38, 0x1E, 0x3A, 0x1F, 0x3D, 0x1F, 0x30, 0x1A, 0x3A, 0x20, 0x36, 0x1C, 0x35, 0x1E, 0x30, 0x1A, 0x32, 0x1D, 0x2D, 0x19, 0x2F, 0x1A, 0x2B, 0x19, 0x37, 0x1E, 0x2E, 0x1A, 0x35, 0x1E, 0x30, 0x1A, 0x2D, 0x1A, 0x2F, 0x1A, 0x2C, 0x1A, 0x32, 0x1C, 0x36, 0x1D, 0x3C, 0x20, 0x38, 0x1F, 0x3E, 0x20, 0x3E, 0x20, 0x3C, 0x20, 0x3B, 0x1E, 0x44, 0x23, 0x3B, 0x1F, 0x2D, 0x1A, 0x35, 0x1D, 0x3B, 0x20, 0x32, 0x1C, 0x3A, 0x1E, 0x2F, 0x1A, 0x2F, 0x1B, 0x2E, 0x19
    },

    {
        0x66, 0x5A, 0x65, 0x5A, 0x64, 0x59, 0x64, 0x58, 0x64, 0x58, 0x66, 0x5A, 0x67, 0x59, 0x67, 0x5A, 0x67, 0x59, 0x67, 0x5B, 0x69, 0x5B, 0x69, 0x5B, 0x6A, 0x5B, 0x69, 0x5A, 0x69, 0x5B, 0x68, 0x5A, 0x67, 0x59, 0x67, 0x5A, 0x67, 0x59, 0x68, 0x5A, 0x68, 0x5A, 0x67, 0x5B, 0x68, 0x5A, 0x68, 0x5A, 0x6A, 0x5B, 0x69, 0x5B, 0x69, 0x5C, 0x6A, 0x5C, 0x69, 0x5A, 0x6A, 0x5B, 0x69, 0x5B, 0x67, 0x59, 0x60, 0x54, 0x56, 0x4A, 0x44, 0x39, 0x3C, 0x39, 0x4E, 0x4A, 0x5C, 0x54, 0x5A, 0x51, 0x4E, 0x45, 0x36, 0x2F, 0x24, 0x22, 0x1E, 0x1F, 0x1A, 0x1C, 0x19, 0x1B, 0x18, 0x1B, 0x18, 0x1B, 0x17, 0x1A, 0x16, 0x1A, 0x16, 0x1A, 0x16, 0x1B, 0x17, 0x1B, 0x17, 0x1B, 0x16, 0x1A, 0x15, 0x19, 0x16, 0x1A, 0x16, 0x19, 0x15, 0x18, 0x15, 0x18, 0x14, 0x17, 0x14, 0x18, 0x14, 0x19, 0x15, 0x19, 0x15, 0x18, 0x14, 0x19, 0x15, 0x19, 0x16, 0x1A, 0x19, 0x1C, 0x20, 0x27, 0x39, 0x4D, 0x56, 0x6C, 0x63, 0x75, 0x69, 0x7E, 0x6E, 0x80, 0x70, 0x82, 0x71, 0x81, 0x6F, 0x81, 0x6C, 0x81, 0x5E, 0x67, 0x42, 0x47, 0x4B, 0x62, 0x63, 0x77, 0x6B, 0x80, 0x7F, 0x84, 0x72, 0x87, 0x72, 0x86, 0x73, 0x86, 0x71, 0x83, 0x70, 0x82, 0x6C, 0x80, 0x64, 0x75, 0x49, 0x4B, 0x2B, 0x2D, 0x20, 0x23, 0x1C, 0x20, 0x19, 0x1D, 0x17, 0x1C, 0x17, 0x1C, 0x17, 0x1D, 0x17, 0x1B, 0x17, 0x1C, 0x17, 0x1C, 0x17, 0x1B, 0x17, 0x1C, 0x17, 0x1C, 0x18, 0x1C, 0x18, 0x1C, 0x17, 0x1C, 0x18, 0x1C, 0x17, 0x1C, 0x17, 0x1C, 0x17, 0x1C, 0x1A, 0x1E, 0x1F, 0x20, 0x3B, 0x41, 0x61, 0x5C, 0x68, 0x63, 0x62, 0x5B, 0x40, 0x39, 0x3B, 0x3F, 0x5C, 0x5B, 0x6C, 0x65, 0x72, 0x6A, 0x73, 0x6A, 0x77, 0x6B, 0x7A, 0x6E, 0x79, 0x6A, 0x76, 0x68, 0x73, 0x68, 0x76, 0x6B, 0x75, 0x69, 0x77, 0x6D, 0x76, 0x6B, 0x77, 0x6A, 0x78, 0x6D, 0x78, 0x6B, 0x76, 0x6B, 0x78, 0x6B, 0x79, 0x6A, 0x78, 0x6C, 0x76, 0x6A, 0x77, 0x6C, 0x78, 0x6A, 0x76, 0x67, 0x76, 0x69, 0x76, 0x68, 0x75, 0x6A, 0x75, 0x68, 0x72, 0x69, 0x77, 0x6B, 0x77, 0x6A, 0x74, 0x66, 0x74, 0x66, 0x75, 0x6A, 0x78, 0x6B, 0x75, 0x69, 0x78, 0x69, 0x77, 0x6C, 0x78, 0x68, 0x78, 0x6B, 0x77, 0x68, 0x75, 0x67, 0x76, 0x6A, 0x76, 0x6B, 0x74, 0x69, 0x78, 0x6C, 0x7C, 0x6F, 0x77, 0x6B, 0x74, 0x6B, 0x78, 0x6B, 0x78, 0x6C, 0x75, 0x67, 0x71, 0x65, 0x75, 0x68, 0x78, 0x6B, 0x77, 0x68, 0x7A, 0x6C, 0x76, 0x68, 0x78, 0x6D, 0x77, 0x69, 0x75, 0x67, 0x75, 0x66, 0x72, 0x66, 0x77, 0x6A, 0x74, 0x65, 0x76, 0x69, 0x74, 0x65, 0x73, 0x65, 0x74, 0x68, 0x77, 0x68, 0x6F, 0x63, 0x6F, 0x63, 0x6F, 0x61, 0x6C, 0x5F, 0x69, 0x5D, 0x6A, 0x5D, 0x6B, 0x5F, 0x6C, 0x60, 0x6C, 0x60, 0x69, 0x5C, 0x69, 0x5E, 0x6C, 0x61, 0x6B, 0x60, 0x6F, 0x62, 0x6B, 0x5E, 0x6A, 0x5C, 0x6B, 0x60, 0x6C, 0x5F, 0x6A, 0x5F, 0x70, 0x67, 0x6E, 0x68, 0x6B, 0x61, 0x6B, 0x60, 0x69, 0x5D, 0x6B, 0x61, 0x6D, 0x62, 0x70, 0x65, 0x6F, 0x66, 0x6C, 0x61, 0x6A, 0x60, 0x6C, 0x61, 0x6F, 0x64, 0x6E, 0x65, 0x71, 0x67, 0x70, 0x66, 0x6F, 0x64, 0x6F, 0x65, 0x6F, 0x64, 0x6D, 0x62, 0x6C, 0x60, 0x6B, 0x61, 0x71, 0x67, 0x6F, 0x64, 0x6B, 0x60, 0x6C, 0x61, 0x6B, 0x5F, 0x68, 0x5B, 0x64, 0x5A, 0x64, 0x5A, 0x69, 0x60, 0x69, 0x5C, 0x64, 0x5B, 0x66, 0x5E, 0x67, 0x5D, 0x69, 0x5D, 0x66, 0x5B, 0x66, 0x5D, 0x6A, 0x5E, 0x66, 0x5B, 0x69, 0x5D, 0x6B, 0x5E, 0x6D, 0x65, 0x6B, 0x62, 0x68, 0x5B, 0x64, 0x59, 0x63, 0x58, 0x63, 0x5B, 0x64, 0x59, 0x64, 0x5B, 0x62, 0x57, 0x65, 0x59, 0x60, 0x57, 0x68, 0x5E, 0x69, 0x5F, 0x69, 0x5D, 0x68, 0x5C, 0x66, 0x59, 0x66, 0x5A, 0x65, 0x5B, 0x64, 0x5A, 0x67, 0x5A, 0x67, 0x5C, 0x63, 0x57, 0x3F, 0x3D, 0x33, 0x36, 0x30, 0x37, 0x3A, 0x44, 0x30, 0x34, 0x32, 0x3A, 0x37, 0x3E, 0x35, 0x3D, 0x30, 0x33, 0x32, 0x3C, 0x2F, 0x34, 0x34, 0x3D, 0x32, 0x37, 0x29, 0x2B, 0x32, 0x3B, 0x2B, 0x2E, 0x30, 0x37, 0x29, 0x2C, 0x2C, 0x32, 0x27, 0x29, 0x2C, 0x32, 0x27, 0x2B, 0x33, 0x39, 0x2B, 0x2E, 0x34, 0x3C, 0x2B, 0x2E, 0x2B, 0x30, 0x2D, 0x2E, 0x2B, 0x31, 0x32, 0x39, 0x32, 0x3A, 0x36, 0x3C, 0x33, 0x39, 0x3A, 0x42, 0x36, 0x3D, 0x35, 0x3D, 0x34, 0x39, 0x3B, 0x43, 0x30, 0x34, 0x27, 0x2B, 0x2F, 0x35, 0x32, 0x38, 0x2C, 0x33, 0x31, 0x36, 0x29, 0x2D, 0x2B, 0x30, 0x2A, 0x2E
    },

    {
        0x5A, 0x20, 0x58, 0x1F, 0x59, 0x1F, 0x58, 0x1F, 0x59, 0x20, 0x59, 0x20, 0x5B, 0x20, 0x5A, 0x21, 0x5B, 0x20, 0x5B, 0x20, 0x5B, 0x21, 0x5D, 0x21, 0x5B, 0x21, 0x59, 0x20, 0x5E, 0x22, 0x5C, 0x21, 0x5C, 0x21, 0x5A, 0x21, 0x59, 0x20, 0x58, 0x1F, 0x59, 0x20, 0x5A, 0x21, 0x5A, 0x20, 0x58, 0x20, 0x5B, 0x21, 0x5A, 0x21, 0x5A, 0x20, 0x5A, 0x20, 0x5B, 0x21, 0x5B, 0x20, 0x5B, 0x20, 0x59, 0x20, 0x58, 0x20, 0x55, 0x1F, 0x49, 0x1D, 0x3B, 0x19, 0x38, 0x1A, 0x48, 0x1D, 0x50, 0x1F, 0x51, 0x1E, 0x47, 0x1B, 0x2F, 0x16, 0x23, 0x13, 0x1E, 0x12, 0x1D, 0x12, 0x1C, 0x13, 0x1D, 0x14, 0x1D, 0x13, 0x1E, 0x14, 0x1F, 0x15, 0x20, 0x17, 0x21, 0x17, 0x1C, 0x13, 0x1B, 0x12, 0x1B, 0x13, 0x1C, 0x12, 0x1A, 0x11, 0x19, 0x11, 0x19, 0x12, 0x19, 0x11, 0x19, 0x11, 0x19, 0x12, 0x1A, 0x12, 0x19, 0x12, 0x1A, 0x12, 0x1A, 0x12, 0x1B, 0x13, 0x20, 0x1B, 0x3E, 0x39, 0x69, 0x58, 0x76, 0x60, 0x79, 0x64, 0x7E, 0x69, 0x84, 0x6C, 0x86, 0x6D, 0x85, 0x6C, 0x87, 0x6D, 0x85, 0x6C, 0x83, 0x69, 0x7B, 0x63, 0x7C, 0x67, 0x80, 0x68, 0x83, 0x6C, 0x87, 0x6E, 0x88, 0x6E, 0x86, 0x6D, 0x87, 0x6E, 0x85, 0x6C, 0x85, 0x6B, 0x82, 0x6B, 0x82, 0x6A, 0x7A, 0x5D, 0x51, 0x38, 0x2E, 0x21, 0x24, 0x1A, 0x21, 0x17, 0x1F, 0x16, 0x1C, 0x13, 0x1D, 0x14, 0x1C, 0x13, 0x1C, 0x13, 0x1B, 0x13, 0x1B, 0x13, 0x1B, 0x13, 0x1C, 0x13, 0x1C, 0x13, 0x1D, 0x14, 0x1C, 0x13, 0x1B, 0x13, 0x1D, 0x14, 0x1C, 0x13, 0x1D, 0x14, 0x1E, 0x15, 0x2F, 0x1A, 0x55, 0x23, 0x5E, 0x24, 0x5D, 0x25, 0x44, 0x1E, 0x34, 0x1C, 0x53, 0x24, 0x60, 0x26, 0x66, 0x27, 0x69, 0x28, 0x67, 0x27, 0x68, 0x28, 0x68, 0x28, 0x6A, 0x28, 0x67, 0x27, 0x67, 0x26, 0x65, 0x26, 0x68, 0x28, 0x6B, 0x29, 0x6E, 0x29, 0x6D, 0x29, 0x6C, 0x28, 0x6A, 0x29, 0x6E, 0x28, 0x6C, 0x28, 0x68, 0x27, 0x6A, 0x28, 0x68, 0x28, 0x69, 0x28, 0x67, 0x27, 0x68, 0x27, 0x68, 0x28, 0x67, 0x28, 0x66, 0x27, 0x67, 0x27, 0x69, 0x28, 0x6A, 0x28, 0x6A, 0x28, 0x6A, 0x29, 0x6A, 0x27, 0x6B, 0x27, 0x6A, 0x27, 0x68, 0x27, 0x70, 0x2B, 0x67, 0x27, 0x68, 0x27, 0x6A, 0x28, 0x6B, 0x28, 0x67, 0x27, 0x6A, 0x27, 0x67, 0x27, 0x68, 0x27, 0x6B, 0x29, 0x78, 0x30, 0x72, 0x2B, 0x69, 0x28, 0x6B, 0x27, 0x6A, 0x28, 0x68, 0x28, 0x67, 0x27, 0x6D, 0x28, 0x6C, 0x28, 0x6B, 0x27, 0x69, 0x26, 0x68, 0x26, 0x6A, 0x28, 0x68, 0x27, 0x67, 0x27, 0x68, 0x26, 0x69, 0x26, 0x64, 0x24, 0x64, 0x24, 0x67, 0x24, 0x64, 0x24, 0x66, 0x25, 0x65, 0x24, 0x64, 0x25, 0x62, 0x24, 0x63, 0x24, 0x65, 0x24, 0x62, 0x25, 0x5E, 0x23, 0x5C, 0x22, 0x5C, 0x22, 0x5C, 0x22, 0x60, 0x22, 0x62, 0x23, 0x61, 0x23, 0x63, 0x25, 0x62, 0x24, 0x5E, 0x22, 0x60, 0x23, 0x5F, 0x23, 0x60, 0x23, 0x5C, 0x22, 0x5D, 0x23, 0x5D, 0x22, 0x5B, 0x22, 0x5F, 0x23, 0x5C, 0x22, 0x5E, 0x23, 0x61, 0x25, 0x65, 0x27, 0x65, 0x26, 0x61, 0x24, 0x60, 0x24, 0x60, 0x24, 0x5F, 0x24, 0x63, 0x25, 0x63, 0x26, 0x62, 0x24, 0x62, 0x25, 0x61, 0x24, 0x64, 0x27, 0x63, 0x26, 0x63, 0x25, 0x62, 0x25, 0x64, 0x26, 0x61, 0x24, 0x64, 0x27, 0x65, 0x26, 0x64, 0x25, 0x5D, 0x23, 0x5A, 0x20, 0x58, 0x22, 0x5C, 0x23, 0x5B, 0x21, 0x5B, 0x23, 0x5A, 0x22, 0x5B, 0x23, 0x5D, 0x22, 0x5C, 0x22, 0x57, 0x22, 0x59, 0x22, 0x5A, 0x21, 0x5A, 0x22, 0x5E, 0x24, 0x5A, 0x22, 0x5A, 0x22, 0x5A, 0x22, 0x5C, 0x23, 0x5A, 0x21, 0x57, 0x21, 0x5A, 0x21, 0x55, 0x21, 0x55, 0x20, 0x54, 0x20, 0x5A, 0x21, 0x57, 0x21, 0x58, 0x22, 0x5A, 0x23, 0x5D, 0x22, 0x5A, 0x21, 0x5B, 0x22, 0x58, 0x21, 0x5B, 0x22, 0x5B, 0x21, 0x59, 0x21, 0x57, 0x21, 0x55, 0x20, 0x41, 0x20, 0x3E, 0x1F, 0x36, 0x1F, 0x3C, 0x1F, 0x2C, 0x19, 0x30, 0x1C, 0x31, 0x1B, 0x37, 0x1E, 0x2E, 0x1A, 0x3A, 0x1F, 0x30, 0x1B, 0x39, 0x1F, 0x2E, 0x1A, 0x2E, 0x1A, 0x35, 0x1D, 0x2F, 0x1B, 0x34, 0x1D, 0x33, 0x1B, 0x34, 0x1C, 0x34, 0x1C, 0x37, 0x1E, 0x39, 0x1F, 0x41, 0x21, 0x38, 0x1E, 0x3C, 0x1F, 0x36, 0x1D, 0x3E, 0x20, 0x3B, 0x1F, 0x35, 0x1D, 0x42, 0x21, 0x2E, 0x1A, 0x38, 0x1D, 0x34, 0x1D, 0x36, 0x1D, 0x2E, 0x1A, 0x33, 0x1C, 0x2E, 0x1B, 0x37, 0x1D, 0x2F, 0x1A, 0x2E, 0x1A, 0x32, 0x1C, 0x33, 0x1B, 0x34, 0x1E, 0x38, 0x1E, 0x36, 0x1D, 0x36, 0x1E, 0x3C, 0x1F
    },

    {
        0x63, 0x59, 0x64, 0x59, 0x64, 0x58, 0x65, 0x59, 0x64, 0x58, 0x65, 0x5B, 0x67, 0x5B, 0x69, 0x5C, 0x69, 0x5B, 0x67, 0x5A, 0x69, 0x5B, 0x69, 0x5C, 0x69, 0x5B, 0x67, 0x59, 0x6B, 0x5D, 0x6B, 0x5D, 0x69, 0x5B, 0x68, 0x5A, 0x68, 0x5A, 0x68, 0x58, 0x67, 0x59, 0x69, 0x5C, 0x67, 0x5A, 0x67, 0x59, 0x68, 0x5A, 0x68, 0x5A, 0x68, 0x59, 0x68, 0x59, 0x69, 0x5A, 0x68, 0x5B, 0x69, 0x5A, 0x68, 0x58, 0x67, 0x59, 0x63, 0x55, 0x5A, 0x4C, 0x48, 0x3C, 0x3B, 0x36, 0x47, 0x46, 0x56, 0x50, 0x59, 0x50, 0x51, 0x48, 0x3B, 0x32, 0x26, 0x23, 0x1F, 0x1F, 0x1C, 0x1D, 0x1B, 0x1E, 0x1B, 0x1E, 0x1A, 0x1E, 0x1A, 0x1F, 0x1A, 0x1F, 0x1B, 0x22, 0x1C, 0x21, 0x18, 0x1C, 0x17, 0x1B, 0x17, 0x1C, 0x17, 0x1B, 0x15, 0x19, 0x15, 0x1A, 0x16, 0x1A, 0x15, 0x19, 0x14, 0x19, 0x16, 0x1A, 0x15, 0x19, 0x15, 0x19, 0x16, 0x1A, 0x17, 0x1B, 0x19, 0x1B, 0x20, 0x26, 0x3A, 0x50, 0x5A, 0x70, 0x64, 0x76, 0x68, 0x79, 0x6B, 0x7F, 0x71, 0x85, 0x73, 0x86, 0x71, 0x85, 0x72, 0x85, 0x72, 0x83, 0x6F, 0x83, 0x6D, 0x80, 0x6D, 0x82, 0x6E, 0x81, 0x70, 0x82, 0x72, 0x85, 0x74, 0x85, 0x72, 0x85, 0x74, 0x87, 0x73, 0x85, 0x70, 0x82, 0x6F, 0x81, 0x6D, 0x7F, 0x66, 0x78, 0x4F, 0x56, 0x30, 0x31, 0x22, 0x26, 0x1D, 0x22, 0x1B, 0x1F, 0x18, 0x1C, 0x18, 0x1D, 0x18, 0x1D, 0x17, 0x1C, 0x18, 0x1C, 0x17, 0x1C, 0x18, 0x1C, 0x18, 0x1C, 0x18, 0x1D, 0x19, 0x1E, 0x19, 0x1D, 0x18, 0x1C, 0x18, 0x1D, 0x18, 0x1C, 0x19, 0x1E, 0x1E, 0x21, 0x39, 0x40, 0x5F, 0x5D, 0x67, 0x5F, 0x60, 0x59, 0x41, 0x38, 0x3C, 0x3E, 0x5D, 0x5C, 0x6D, 0x65, 0x6F, 0x66, 0x74, 0x6A, 0x75, 0x68, 0x75, 0x6A, 0x77, 0x6A, 0x78, 0x6B, 0x73, 0x67, 0x75, 0x68, 0x75, 0x67, 0x75, 0x68, 0x77, 0x6D, 0x77, 0x6E, 0x7A, 0x6E, 0x78, 0x6B, 0x77, 0x6D, 0x7A, 0x6E, 0x78, 0x6B, 0x77, 0x69, 0x77, 0x68, 0x76, 0x6A, 0x77, 0x6A, 0x74, 0x68, 0x75, 0x6A, 0x73, 0x67, 0x73, 0x68, 0x74, 0x66, 0x73, 0x67, 0x76, 0x6B, 0x78, 0x6C, 0x76, 0x6A, 0x78, 0x6F, 0x76, 0x69, 0x78, 0x6B, 0x79, 0x6B, 0x77, 0x69, 0x7A, 0x6F, 0x77, 0x69, 0x78, 0x6B, 0x76, 0x6C, 0x7A, 0x6E, 0x74, 0x68, 0x77, 0x6A, 0x75, 0x68, 0x76, 0x6B, 0x79, 0x6F, 0x83, 0x7A, 0x7F, 0x73, 0x74, 0x69, 0x78, 0x6B, 0x75, 0x6B, 0x76, 0x69, 0x73, 0x69, 0x78, 0x6C, 0x78, 0x6C, 0x7B, 0x6D, 0x7A, 0x6B, 0x77, 0x67, 0x78, 0x6B, 0x78, 0x69, 0x76, 0x67, 0x77, 0x69, 0x7B, 0x6D, 0x71, 0x63, 0x72, 0x65, 0x76, 0x68, 0x74, 0x67, 0x77, 0x68, 0x76, 0x66, 0x72, 0x64, 0x72, 0x63, 0x70, 0x65, 0x74, 0x66, 0x70, 0x65, 0x6C, 0x61, 0x6B, 0x5E, 0x6B, 0x5E, 0x6B, 0x5F, 0x6C, 0x60, 0x6F, 0x61, 0x6F, 0x62, 0x70, 0x65, 0x70, 0x63, 0x6D, 0x60, 0x6F, 0x61, 0x6E, 0x61, 0x6B, 0x61, 0x68, 0x5D, 0x69, 0x5E, 0x6B, 0x5D, 0x66, 0x5D, 0x6B, 0x5F, 0x6B, 0x5F, 0x6D, 0x61, 0x6E, 0x63, 0x71, 0x65, 0x71, 0x64, 0x6E, 0x62, 0x6D, 0x62, 0x6A, 0x60, 0x6A, 0x60, 0x6F, 0x63, 0x6C, 0x63, 0x6D, 0x62, 0x6F, 0x63, 0x6C, 0x61, 0x6F, 0x65, 0x6D, 0x63, 0x6E, 0x64, 0x6E, 0x62, 0x6E, 0x64, 0x6B, 0x61, 0x6F, 0x66, 0x71, 0x66, 0x6F, 0x66, 0x69, 0x5B, 0x68, 0x5C, 0x65, 0x59, 0x6A, 0x5F, 0x68, 0x5D, 0x69, 0x5D, 0x64, 0x5A, 0x66, 0x5C, 0x66, 0x5D, 0x67, 0x5C, 0x63, 0x59, 0x64, 0x5A, 0x64, 0x5A, 0x66, 0x5D, 0x68, 0x5E, 0x68, 0x5C, 0x63, 0x59, 0x65, 0x5B, 0x6B, 0x60, 0x67, 0x5A, 0x63, 0x5A, 0x64, 0x5B, 0x5F, 0x57, 0x61, 0x55, 0x61, 0x57, 0x67, 0x5B, 0x63, 0x58, 0x65, 0x5B, 0x66, 0x5C, 0x69, 0x5D, 0x67, 0x5A, 0x67, 0x5C, 0x66, 0x5A, 0x6A, 0x5E, 0x67, 0x5A, 0x66, 0x5B, 0x63, 0x58, 0x5E, 0x54, 0x40, 0x43, 0x37, 0x38, 0x31, 0x39, 0x32, 0x35, 0x26, 0x29, 0x2C, 0x30, 0x2C, 0x2F, 0x30, 0x37, 0x29, 0x2F, 0x33, 0x3A, 0x2E, 0x33, 0x33, 0x39, 0x2C, 0x31, 0x2E, 0x35, 0x30, 0x37, 0x2D, 0x32, 0x31, 0x38, 0x32, 0x38, 0x32, 0x39, 0x32, 0x38, 0x34, 0x3C, 0x37, 0x3F, 0x38, 0x3D, 0x32, 0x38, 0x34, 0x3C, 0x31, 0x35, 0x36, 0x3D, 0x33, 0x3A, 0x30, 0x38, 0x37, 0x39, 0x2A, 0x2E, 0x33, 0x36, 0x2E, 0x34, 0x2D, 0x31, 0x2A, 0x2E, 0x2D, 0x30, 0x2A, 0x31, 0x30, 0x34, 0x2D, 0x32, 0x2D, 0x30, 0x2F, 0x34, 0x30, 0x35, 0x30, 0x39, 0x33, 0x38, 0x32, 0x35, 0x33, 0x3C, 0x34, 0x3B
    },

    {
        0x57, 0x20, 0x57, 0x1F, 0x57, 0x1F, 0x58, 0x1F, 0x5A, 0x1F, 0x5B, 0x20, 0x5B, 0x21, 0x5D, 0x21, 0x5C, 0x20, 0x5A, 0x21, 0x5A, 0x21, 0x5D, 0x21, 0x5D, 0x22, 0x5B, 0x21, 0x5C, 0x21, 0x5C, 0x22, 0x5B, 0x21, 0x59, 0x20, 0x5A, 0x20, 0x59, 0x20, 0x59, 0x20, 0x5B, 0x21, 0x5B, 0x21, 0x5A, 0x20, 0x5B, 0x21, 0x59, 0x20, 0x5B, 0x21, 0x5A, 0x21, 0x58, 0x20, 0x59, 0x20, 0x5A, 0x21, 0x5A, 0x20, 0x5A, 0x20, 0x5A, 0x20, 0x58, 0x20, 0x4F, 0x1D, 0x3E, 0x1A, 0x34, 0x1A, 0x42, 0x1C, 0x4E, 0x1E, 0x52, 0x1E, 0x49, 0x1C, 0x35, 0x18, 0x27, 0x16, 0x24, 0x17, 0x28, 0x1A, 0x2A, 0x1B, 0x2A, 0x1A, 0x26, 0x18, 0x24, 0x18, 0x24, 0x18, 0x24, 0x18, 0x21, 0x16, 0x1F, 0x15, 0x1F, 0x15, 0x1C, 0x13, 0x1A, 0x12, 0x1B, 0x12, 0x1A, 0x13, 0x1A, 0x12, 0x1A, 0x12, 0x19, 0x12, 0x19, 0x12, 0x1A, 0x13, 0x1B, 0x13, 0x1B, 0x13, 0x1F, 0x1A, 0x39, 0x36, 0x67, 0x57, 0x77, 0x62, 0x7B, 0x66, 0x80, 0x69, 0x84, 0x6A, 0x85, 0x6E, 0x85, 0x6D, 0x85, 0x6D, 0x84, 0x6D, 0x86, 0x6D, 0x88, 0x6F, 0x87, 0x6D, 0x85, 0x6D, 0x83, 0x6B, 0x84, 0x6D, 0x87, 0x6E, 0x8A, 0x70, 0x8A, 0x70, 0x88, 0x6F, 0x87, 0x6D, 0x85, 0x6C, 0x83, 0x6C, 0x84, 0x6C, 0x83, 0x69, 0x7E, 0x64, 0x64, 0x44, 0x34, 0x24, 0x26, 0x1B, 0x22, 0x18, 0x1F, 0x16, 0x1D, 0x14, 0x1C, 0x14, 0x1B, 0x13, 0x1C, 0x13, 0x1B, 0x13, 0x1C, 0x13, 0x1E, 0x14, 0x1E, 0x14, 0x20, 0x15, 0x1F, 0x15, 0x1D, 0x13, 0x1D, 0x13, 0x1C, 0x13, 0x1F, 0x15, 0x2C, 0x1A, 0x55, 0x24, 0x62, 0x25, 0x5E, 0x24, 0x45, 0x1E, 0x34, 0x1C, 0x51, 0x23, 0x62, 0x26, 0x69, 0x28, 0x68, 0x27, 0x68, 0x27, 0x68, 0x28, 0x6C, 0x28, 0x6C, 0x28, 0x6A, 0x28, 0x6C, 0x28, 0x6A, 0x27, 0x67, 0x27, 0x6C, 0x28, 0x6A, 0x28, 0x69, 0x28, 0x6E, 0x2A, 0x6A, 0x28, 0x6B, 0x29, 0x6B, 0x27, 0x67, 0x27, 0x69, 0x27, 0x66, 0x27, 0x6A, 0x28, 0x6A, 0x28, 0x6A, 0x28, 0x69, 0x29, 0x6B, 0x29, 0x69, 0x29, 0x71, 0x2C, 0x6A, 0x28, 0x6E, 0x2C, 0x6E, 0x2B, 0x69, 0x29, 0x6C, 0x2A, 0x69, 0x28, 0x6A, 0x28, 0x6A, 0x28, 0x68, 0x27, 0x6A, 0x28, 0x69, 0x28, 0x6C, 0x28, 0x67, 0x27, 0x6A, 0x27, 0x6A, 0x27, 0x6B, 0x29, 0x69, 0x27, 0x69, 0x28, 0x6C, 0x28, 0x6B, 0x28, 0x6F, 0x2A, 0x6A, 0x29, 0x69, 0x27, 0x6B, 0x28, 0x68, 0x29, 0x6A, 0x29, 0x6B, 0x2A, 0x69, 0x27, 0x6E, 0x2A, 0x6E, 0x28, 0x6C, 0x29, 0x6E, 0x28, 0x68, 0x26, 0x68, 0x26, 0x65, 0x25, 0x66, 0x25, 0x66, 0x24, 0x62, 0x23, 0x67, 0x25, 0x66, 0x25, 0x67, 0x26, 0x64, 0x24, 0x64, 0x24, 0x68, 0x26, 0x63, 0x23, 0x62, 0x25, 0x64, 0x24, 0x63, 0x24, 0x60, 0x23, 0x5D, 0x22, 0x5E, 0x22, 0x63, 0x25, 0x61, 0x24, 0x61, 0x23, 0x61, 0x24, 0x5F, 0x24, 0x63, 0x25, 0x63, 0x25, 0x60, 0x23, 0x5C, 0x22, 0x5A, 0x21, 0x5D, 0x23, 0x5C, 0x22, 0x5A, 0x22, 0x5A, 0x21, 0x5C, 0x22, 0x60, 0x22, 0x61, 0x25, 0x63, 0x25, 0x62, 0x24, 0x65, 0x26, 0x63, 0x25, 0x5E, 0x23, 0x5F, 0x24, 0x62, 0x24, 0x5E, 0x23, 0x5E, 0x23, 0x5E, 0x24, 0x62, 0x25, 0x65, 0x26, 0x5E, 0x23, 0x60, 0x24, 0x5F, 0x22, 0x5B, 0x22, 0x5A, 0x21, 0x64, 0x26, 0x62, 0x24, 0x5F, 0x23, 0x5B, 0x22, 0x59, 0x21, 0x5C, 0x21, 0x5D, 0x22, 0x5C, 0x22, 0x5C, 0x23, 0x5A, 0x23, 0x5F, 0x24, 0x5E, 0x22, 0x5B, 0x23, 0x5C, 0x23, 0x5B, 0x22, 0x5B, 0x22, 0x5A, 0x22, 0x5A, 0x22, 0x5A, 0x23, 0x5A, 0x22, 0x56, 0x21, 0x5B, 0x23, 0x57, 0x21, 0x56, 0x21, 0x5C, 0x22, 0x5A, 0x22, 0x5A, 0x21, 0x56, 0x20, 0x58, 0x21, 0x58, 0x20, 0x59, 0x22, 0x59, 0x22, 0x58, 0x21, 0x58, 0x21, 0x5C, 0x23, 0x59, 0x21, 0x5C, 0x22, 0x57, 0x21, 0x5B, 0x22, 0x5C, 0x22, 0x54, 0x20, 0x3A, 0x1E, 0x33, 0x1C, 0x38, 0x1F, 0x3B, 0x1E, 0x3A, 0x20, 0x3F, 0x22, 0x3D, 0x20, 0x3C, 0x20, 0x3E, 0x21, 0x3B, 0x20, 0x3B, 0x1F, 0x3D, 0x21, 0x40, 0x22, 0x3E, 0x20, 0x39, 0x1F, 0x37, 0x1D, 0x40, 0x22, 0x3A, 0x1F, 0x35, 0x1C, 0x34, 0x1C, 0x37, 0x1E, 0x34, 0x1C, 0x2F, 0x1B, 0x2D, 0x1A, 0x35, 0x1E, 0x33, 0x1B, 0x2E, 0x1A, 0x2F, 0x1A, 0x2D, 0x1B, 0x31, 0x1A, 0x32, 0x1D, 0x3A, 0x1E, 0x33, 0x1C, 0x37, 0x1D, 0x35, 0x1E, 0x37, 0x1D, 0x36, 0x1D, 0x3B, 0x1F, 0x31, 0x1C, 0x34, 0x1D, 0x37, 0x1E, 0x40, 0x21, 0x37, 0x1E, 0x39, 0x1E, 0x2E, 0x1A, 0x3A, 0x1F, 0x30, 0x1A
    },

    {
        0x62, 0x57, 0x64, 0x57, 0x63, 0x58, 0x64, 0x59, 0x67, 0x5B, 0x66, 0x5A, 0x69, 0x5B, 0x69, 0x5D, 0x69, 0x5C, 0x68, 0x5B, 0x69, 0x5C, 0x6A, 0x5C, 0x6B, 0x5C, 0x66, 0x5A, 0x68, 0x5B, 0x6A, 0x5C, 0x6A, 0x5B, 0x69, 0x59, 0x68, 0x58, 0x66, 0x58, 0x66, 0x58, 0x69, 0x5B, 0x69, 0x5A, 0x67, 0x59, 0x67, 0x5A, 0x67, 0x59, 0x69, 0x5B, 0x69, 0x5A, 0x68, 0x58, 0x68, 0x5A, 0x68, 0x5B, 0x68, 0x5A, 0x68, 0x5A, 0x69, 0x5A, 0x67, 0x59, 0x5D, 0x50, 0x4C, 0x3E, 0x3B, 0x35, 0x42, 0x40, 0x54, 0x4D, 0x5A, 0x51, 0x54, 0x4B, 0x41, 0x3A, 0x2C, 0x29, 0x24, 0x26, 0x24, 0x29, 0x24, 0x2A, 0x23, 0x29, 0x21, 0x26, 0x1E, 0x23, 0x1D, 0x23, 0x1C, 0x23, 0x1B, 0x20, 0x1A, 0x20, 0x1B, 0x21, 0x18, 0x1B, 0x17, 0x1B, 0x17, 0x1B, 0x17, 0x1B, 0x16, 0x1A, 0x16, 0x19, 0x15, 0x19, 0x15, 0x19, 0x16, 0x1A, 0x16, 0x1A, 0x18, 0x1B, 0x1F, 0x25, 0x37, 0x4A, 0x59, 0x70, 0x66, 0x79, 0x6B, 0x7E, 0x6E, 0x82, 0x70, 0x82, 0x72, 0x82, 0x73, 0x84, 0x73, 0x83, 0x71, 0x85, 0x73, 0x85, 0x73, 0x85, 0x72, 0x82, 0x71, 0x84, 0x71, 0x83, 0x73, 0x87, 0x74, 0x86, 0x75, 0x87, 0x76, 0x89, 0x75, 0x89, 0x73, 0x86, 0x72, 0x83, 0x70, 0x84, 0x70, 0x84, 0x6E, 0x82, 0x6B, 0x7E, 0x5C, 0x65, 0x36, 0x37, 0x25, 0x28, 0x1E, 0x23, 0x1C, 0x1F, 0x19, 0x1D, 0x17, 0x1C, 0x17, 0x1C, 0x17, 0x1B, 0x16, 0x1C, 0x18, 0x1D, 0x18, 0x1E, 0x19, 0x1E, 0x1A, 0x20, 0x1A, 0x1F, 0x18, 0x1D, 0x18, 0x1C, 0x19, 0x1D, 0x1E, 0x21, 0x36, 0x3D, 0x5E, 0x5E, 0x6A, 0x64, 0x63, 0x5A, 0x41, 0x39, 0x3B, 0x3C, 0x5C, 0x5B, 0x6D, 0x64, 0x76, 0x6C, 0x76, 0x68, 0x76, 0x6A, 0x76, 0x6B, 0x77, 0x6C, 0x78, 0x6C, 0x79, 0x6B, 0x7B, 0x6D, 0x7A, 0x6A, 0x76, 0x69, 0x7A, 0x6C, 0x77, 0x6C, 0x76, 0x6A, 0x77, 0x6D, 0x76, 0x6A, 0x78, 0x6C, 0x75, 0x67, 0x75, 0x69, 0x77, 0x6A, 0x74, 0x68, 0x74, 0x69, 0x75, 0x69, 0x75, 0x69, 0x76, 0x69, 0x79, 0x6D, 0x77, 0x6E, 0x7C, 0x73, 0x77, 0x69, 0x7B, 0x72, 0x7A, 0x70, 0x77, 0x6B, 0x77, 0x6B, 0x76, 0x6A, 0x76, 0x6A, 0x77, 0x6C, 0x76, 0x69, 0x77, 0x6B, 0x79, 0x6C, 0x79, 0x6C, 0x77, 0x69, 0x79, 0x6B, 0x77, 0x69, 0x78, 0x6C, 0x77, 0x69, 0x78, 0x6C, 0x7A, 0x6D, 0x7B, 0x6E, 0x7A, 0x6D, 0x78, 0x6D, 0x76, 0x69, 0x77, 0x6D, 0x73, 0x6A, 0x77, 0x6D, 0x7C, 0x70, 0x79, 0x6C, 0x7C, 0x6F, 0x7C, 0x6E, 0x7D, 0x6F, 0x7E, 0x6F, 0x77, 0x69, 0x76, 0x69, 0x79, 0x67, 0x75, 0x68, 0x76, 0x67, 0x72, 0x63, 0x75, 0x6A, 0x78, 0x68, 0x77, 0x69, 0x76, 0x67, 0x72, 0x65, 0x76, 0x6A, 0x73, 0x65, 0x6E, 0x62, 0x6E, 0x62, 0x70, 0x64, 0x6C, 0x60, 0x6B, 0x5F, 0x6B, 0x60, 0x70, 0x65, 0x6E, 0x63, 0x6D, 0x61, 0x6F, 0x64, 0x6C, 0x63, 0x71, 0x65, 0x6F, 0x63, 0x6F, 0x60, 0x6D, 0x60, 0x6A, 0x5D, 0x6B, 0x60, 0x6C, 0x5E, 0x68, 0x5C, 0x66, 0x5B, 0x6A, 0x5E, 0x6E, 0x60, 0x70, 0x64, 0x6F, 0x63, 0x6E, 0x63, 0x72, 0x66, 0x6F, 0x63, 0x6A, 0x60, 0x6D, 0x62, 0x70, 0x61, 0x6A, 0x5E, 0x69, 0x5F, 0x67, 0x5F, 0x6E, 0x65, 0x6F, 0x64, 0x6C, 0x60, 0x6C, 0x62, 0x6C, 0x5F, 0x68, 0x5C, 0x66, 0x5B, 0x6E, 0x63, 0x6E, 0x62, 0x6D, 0x5F, 0x6A, 0x5E, 0x65, 0x59, 0x69, 0x5C, 0x68, 0x5C, 0x67, 0x5E, 0x68, 0x5F, 0x66, 0x5D, 0x69, 0x61, 0x69, 0x5D, 0x69, 0x5F, 0x68, 0x5D, 0x67, 0x5B, 0x68, 0x5C, 0x65, 0x5A, 0x66, 0x5D, 0x67, 0x5D, 0x67, 0x5C, 0x63, 0x58, 0x68, 0x5C, 0x64, 0x5B, 0x63, 0x58, 0x68, 0x5C, 0x68, 0x5B, 0x67, 0x5B, 0x63, 0x59, 0x67, 0x5B, 0x66, 0x59, 0x64, 0x5A, 0x65, 0x5A, 0x62, 0x58, 0x64, 0x58, 0x68, 0x5D, 0x65, 0x5C, 0x67, 0x5C, 0x65, 0x59, 0x66, 0x5A, 0x67, 0x5C, 0x5E, 0x51, 0x3A, 0x39, 0x2F, 0x32, 0x33, 0x3C, 0x36, 0x3D, 0x36, 0x3F, 0x38, 0x41, 0x35, 0x39, 0x37, 0x40, 0x39, 0x40, 0x35, 0x3D, 0x31, 0x36, 0x35, 0x3F, 0x37, 0x40, 0x31, 0x35, 0x32, 0x39, 0x2F, 0x33, 0x39, 0x42, 0x2F, 0x32, 0x2E, 0x33, 0x2C, 0x2F, 0x2F, 0x35, 0x2E, 0x31, 0x2A, 0x2F, 0x28, 0x2B, 0x2E, 0x36, 0x2B, 0x2E, 0x2B, 0x2F, 0x2C, 0x2E, 0x2C, 0x33, 0x2D, 0x31, 0x30, 0x39, 0x36, 0x39, 0x31, 0x35, 0x36, 0x3C, 0x31, 0x39, 0x32, 0x36, 0x31, 0x38, 0x35, 0x38, 0x2B, 0x2E, 0x31, 0x37, 0x31, 0x3A, 0x37, 0x3B, 0x33, 0x39, 0x33, 0x36, 0x29, 0x2D, 0x31, 0x38, 0x29, 0x2C
    },

    {
        0x59, 0x20, 0x58, 0x1F, 0x59, 0x1F, 0x57, 0x1F, 0x59, 0x1F, 0x59, 0x20, 0x5C, 0x21, 0x5E, 0x21, 0x5C, 0x21, 0x5C, 0x21, 0x5C, 0x21, 0x5B, 0x21, 0x5D, 0x22, 0x5D, 0x22, 0x5C, 0x21, 0x5D, 0x21, 0x5B, 0x20, 0x5A, 0x20, 0x5A, 0x20, 0x59, 0x21, 0x5A, 0x21, 0x5A, 0x20, 0x59, 0x20, 0x57, 0x20, 0x59, 0x20, 0x5B, 0x21, 0x5A, 0x21, 0x5A, 0x20, 0x58, 0x1F, 0x58, 0x20, 0x59, 0x20, 0x5A, 0x20, 0x58, 0x20, 0x57, 0x1F, 0x58, 0x20, 0x56, 0x1F, 0x50, 0x1E, 0x44, 0x1C, 0x36, 0x1A, 0x3F, 0x1C, 0x4E, 0x1F, 0x53, 0x1F, 0x4F, 0x1F, 0x3F, 0x1B, 0x2B, 0x18, 0x28, 0x18, 0x28, 0x19, 0x28, 0x19, 0x27, 0x18, 0x22, 0x16, 0x20, 0x16, 0x20, 0x16, 0x20, 0x16, 0x25, 0x19, 0x29, 0x1C, 0x22, 0x16, 0x1E, 0x14, 0x1D, 0x14, 0x1B, 0x13, 0x1A, 0x12, 0x1A, 0x12, 0x1A, 0x13, 0x1C, 0x13, 0x1C, 0x13, 0x1B, 0x13, 0x1E, 0x18, 0x38, 0x35, 0x66, 0x56, 0x75, 0x60, 0x7F, 0x67, 0x81, 0x69, 0x85, 0x6C, 0x86, 0x6C, 0x88, 0x6E, 0x88, 0x6E, 0x88, 0x6E, 0x88, 0x6E, 0x89, 0x6E, 0x85, 0x6D, 0x86, 0x6D, 0x86, 0x6D, 0x88, 0x6E, 0x89, 0x70, 0x89, 0x6F, 0x89, 0x70, 0x89, 0x70, 0x8E, 0x71, 0x8A, 0x6F, 0x86, 0x6E, 0x85, 0x6D, 0x85, 0x6E, 0x86, 0x6D, 0x85, 0x6D, 0x81, 0x67, 0x69, 0x48, 0x39, 0x28, 0x29, 0x1D, 0x23, 0x18, 0x1F, 0x17, 0x1E, 0x15, 0x1D, 0x14, 0x1C, 0x13, 0x1D, 0x14, 0x1F, 0x15, 0x1C, 0x14, 0x1D, 0x14, 0x1E, 0x14, 0x1D, 0x14, 0x1E, 0x14, 0x1D, 0x14, 0x1E, 0x14, 0x2D, 0x1A, 0x55, 0x23, 0x62, 0x26, 0x64, 0x27, 0x48, 0x20, 0x32, 0x1C, 0x52, 0x24, 0x62, 0x26, 0x6A, 0x28, 0x6A, 0x27, 0x6B, 0x29, 0x6B, 0x28, 0x6B, 0x27, 0x69, 0x28, 0x6C, 0x28, 0x6C, 0x27, 0x68, 0x27, 0x6B, 0x28, 0x6A, 0x28, 0x6B, 0x29, 0x6A, 0x28, 0x68, 0x27, 0x6D, 0x28, 0x6A, 0x28, 0x6A, 0x28, 0x66, 0x26, 0x6D, 0x29, 0x6A, 0x28, 0x68, 0x27, 0x67, 0x26, 0x68, 0x28, 0x6A, 0x29, 0x6B, 0x28, 0x6D, 0x29, 0x6C, 0x2B, 0x71, 0x2E, 0x69, 0x29, 0x68, 0x2A, 0x6D, 0x2B, 0x6C, 0x29, 0x6B, 0x29, 0x6B, 0x28, 0x68, 0x27, 0x6A, 0x28, 0x6B, 0x28, 0x6C, 0x2A, 0x6F, 0x29, 0x6A, 0x27, 0x6A, 0x27, 0x69, 0x26, 0x68, 0x28, 0x6B, 0x28, 0x69, 0x27, 0x6C, 0x28, 0x6B, 0x27, 0x6C, 0x28, 0x6C, 0x29, 0x6F, 0x2B, 0x71, 0x2B, 0x6F, 0x2B, 0x71, 0x2C, 0x72, 0x2C, 0x77, 0x2E, 0x6C, 0x2A, 0x6C, 0x28, 0x69, 0x27, 0x6F, 0x28, 0x6E, 0x29, 0x6E, 0x29, 0x6E, 0x28, 0x68, 0x25, 0x67, 0x26, 0x67, 0x26, 0x67, 0x24, 0x66, 0x25, 0x6C, 0x28, 0x6C, 0x27, 0x6B, 0x27, 0x63, 0x25, 0x67, 0x26, 0x64, 0x25, 0x63, 0x24, 0x5F, 0x23, 0x61, 0x23, 0x5E, 0x23, 0x61, 0x24, 0x5E, 0x22, 0x61, 0x24, 0x5E, 0x23, 0x5D, 0x22, 0x60, 0x24, 0x62, 0x25, 0x61, 0x23, 0x5C, 0x22, 0x61, 0x23, 0x63, 0x23, 0x62, 0x24, 0x63, 0x24, 0x61, 0x23, 0x5D, 0x23, 0x5E, 0x23, 0x5E, 0x22, 0x5F, 0x23, 0x5E, 0x23, 0x60, 0x23, 0x5F, 0x22, 0x5E, 0x23, 0x61, 0x25, 0x60, 0x24, 0x64, 0x27, 0x5E, 0x23, 0x5F, 0x23, 0x60, 0x24, 0x63, 0x27, 0x62, 0x24, 0x62, 0x25, 0x5E, 0x23, 0x5F, 0x23, 0x5D, 0x23, 0x5D, 0x23, 0x5F, 0x24, 0x5C, 0x22, 0x5F, 0x22, 0x5A, 0x21, 0x5D, 0x22, 0x5C, 0x22, 0x5C, 0x22, 0x5D, 0x23, 0x5C, 0x23, 0x5E, 0x25, 0x5B, 0x23, 0x5D, 0x23, 0x5B, 0x22, 0x5B, 0x22, 0x5C, 0x23, 0x5E, 0x22, 0x5C, 0x22, 0x60, 0x23, 0x5F, 0x24, 0x5F, 0x24, 0x5F, 0x24, 0x5B, 0x23, 0x5C, 0x23, 0x5A, 0x22, 0x56, 0x21, 0x5D, 0x23, 0x5E, 0x23, 0x5E, 0x24, 0x5B, 0x23, 0x5B, 0x23, 0x5B, 0x23, 0x5C, 0x23, 0x5A, 0x22, 0x58, 0x22, 0x56, 0x21, 0x57, 0x21, 0x55, 0x20, 0x54, 0x1F, 0x57, 0x21, 0x57, 0x21, 0x59, 0x22, 0x54, 0x20, 0x41, 0x21, 0x3F, 0x21, 0x39, 0x1F, 0x3E, 0x20, 0x31, 0x1B, 0x35, 0x1E, 0x2E, 0x1A, 0x3A, 0x1F, 0x32, 0x1C, 0x35, 0x1E, 0x2D, 0x1A, 0x36, 0x1E, 0x36, 0x1D, 0x29, 0x18, 0x34, 0x1D, 0x2D, 0x1A, 0x36, 0x1E, 0x2E, 0x19, 0x34, 0x1C, 0x32, 0x1B, 0x39, 0x1E, 0x38, 0x1D, 0x2D, 0x1A, 0x38, 0x1D, 0x3C, 0x1F, 0x34, 0x1C, 0x32, 0x1C, 0x3D, 0x20, 0x3D, 0x20, 0x3B, 0x1E, 0x3B, 0x20, 0x38, 0x1D, 0x34, 0x1D, 0x3A, 0x1E, 0x2C, 0x1A, 0x2F, 0x1A, 0x2D, 0x1B, 0x30, 0x1A, 0x2F, 0x1C, 0x3B, 0x1F, 0x3A, 0x20, 0x35, 0x1C, 0x37, 0x1E, 0x31, 0x1A, 0x31, 0x1B, 0x34, 0x1B, 0x2C, 0x1A
    },

    {
        0x64, 0x59, 0x65, 0x58, 0x66, 0x59, 0x64, 0x57, 0x64, 0x58, 0x68, 0x5B, 0x6B, 0x5C, 0x6B, 0x5E, 0x68, 0x5D, 0x69, 0x5C, 0x6A, 0x5D, 0x6A, 0x5C, 0x6B, 0x5D, 0x69, 0x5C, 0x6A, 0x5D, 0x6C, 0x5D, 0x69, 0x5A, 0x68, 0x59, 0x68, 0x5A, 0x67, 0x59, 0x6A, 0x5D, 0x68, 0x5A, 0x68, 0x58, 0x65, 0x57, 0x66, 0x59, 0x69, 0x5B, 0x68, 0x5A, 0x69, 0x59, 0x67, 0x57, 0x66, 0x58, 0x67, 0x58, 0x67, 0x58, 0x67, 0x57, 0x66, 0x58, 0x67, 0x58, 0x64, 0x56, 0x5E, 0x51, 0x53, 0x46, 0x3F, 0x36, 0x3F, 0x3D, 0x52, 0x4E, 0x5D, 0x53, 0x5B, 0x51, 0x4B, 0x41, 0x32, 0x2E, 0x27, 0x29, 0x24, 0x28, 0x23, 0x28, 0x21, 0x25, 0x1E, 0x21, 0x1C, 0x20, 0x1A, 0x1F, 0x1B, 0x21, 0x1D, 0x25, 0x20, 0x2A, 0x1D, 0x22, 0x19, 0x1E, 0x18, 0x1C, 0x17, 0x1B, 0x16, 0x1A, 0x16, 0x1A, 0x17, 0x1A, 0x18, 0x1C, 0x18, 0x1C, 0x18, 0x1B, 0x1E, 0x23, 0x35, 0x49, 0x57, 0x6F, 0x64, 0x76, 0x6A, 0x7E, 0x6F, 0x82, 0x71, 0x85, 0x73, 0x85, 0x74, 0x87, 0x75, 0x87, 0x74, 0x85, 0x74, 0x86, 0x74, 0x86, 0x72, 0x84, 0x72, 0x85, 0x72, 0x85, 0x73, 0x86, 0x75, 0x89, 0x75, 0x86, 0x75, 0x89, 0x76, 0x8A, 0x78, 0x8B, 0x76, 0x87, 0x73, 0x85, 0x72, 0x86, 0x72, 0x86, 0x72, 0x86, 0x71, 0x85, 0x6D, 0x81, 0x5F, 0x6B, 0x3C, 0x3D, 0x28, 0x2B, 0x20, 0x24, 0x1C, 0x20, 0x1A, 0x1F, 0x19, 0x1D, 0x18, 0x1C, 0x18, 0x1D, 0x19, 0x1E, 0x18, 0x1C, 0x17, 0x1C, 0x19, 0x1D, 0x18, 0x1E, 0x19, 0x1D, 0x1A, 0x1E, 0x1E, 0x21, 0x36, 0x3C, 0x60, 0x5E, 0x6B, 0x63, 0x68, 0x60, 0x47, 0x3D, 0x39, 0x3A, 0x5E, 0x5F, 0x6C, 0x64, 0x74, 0x6C, 0x74, 0x67, 0x74, 0x69, 0x77, 0x6B, 0x79, 0x6D, 0x76, 0x6B, 0x7A, 0x6E, 0x79, 0x68, 0x76, 0x6A, 0x7A, 0x6E, 0x78, 0x6C, 0x79, 0x6D, 0x77, 0x69, 0x75, 0x66, 0x7B, 0x6D, 0x77, 0x6B, 0x77, 0x6B, 0x77, 0x69, 0x78, 0x6D, 0x77, 0x69, 0x75, 0x6C, 0x75, 0x67, 0x74, 0x6A, 0x76, 0x6C, 0x79, 0x6C, 0x7B, 0x6E, 0x76, 0x6C, 0x79, 0x72, 0x75, 0x69, 0x71, 0x67, 0x79, 0x6E, 0x78, 0x6E, 0x79, 0x6B, 0x77, 0x69, 0x72, 0x67, 0x74, 0x6C, 0x75, 0x6A, 0x78, 0x6D, 0x7B, 0x6D, 0x79, 0x6C, 0x79, 0x69, 0x78, 0x6B, 0x78, 0x6A, 0x77, 0x6B, 0x75, 0x69, 0x77, 0x6B, 0x77, 0x6A, 0x7A, 0x6D, 0x78, 0x6D, 0x7A, 0x6F, 0x7A, 0x70, 0x7B, 0x71, 0x7D, 0x71, 0x7D, 0x72, 0x82, 0x77, 0x78, 0x6C, 0x7A, 0x6A, 0x79, 0x6A, 0x80, 0x70, 0x7D, 0x70, 0x7D, 0x6F, 0x7C, 0x6C, 0x76, 0x66, 0x79, 0x6A, 0x78, 0x6A, 0x76, 0x68, 0x76, 0x68, 0x7B, 0x6D, 0x7A, 0x6D, 0x78, 0x6B, 0x6F, 0x64, 0x72, 0x67, 0x70, 0x64, 0x70, 0x64, 0x6E, 0x62, 0x6F, 0x62, 0x6A, 0x5F, 0x6C, 0x60, 0x6B, 0x60, 0x6D, 0x61, 0x69, 0x5E, 0x69, 0x5E, 0x6E, 0x60, 0x6B, 0x5F, 0x6B, 0x5E, 0x6C, 0x5E, 0x6F, 0x62, 0x71, 0x63, 0x72, 0x63, 0x71, 0x66, 0x6D, 0x61, 0x6A, 0x5D, 0x67, 0x5E, 0x6C, 0x5F, 0x6C, 0x5E, 0x6A, 0x5F, 0x6C, 0x60, 0x6C, 0x60, 0x6A, 0x5F, 0x6E, 0x64, 0x6D, 0x62, 0x6E, 0x66, 0x6B, 0x5F, 0x6D, 0x5F, 0x6C, 0x61, 0x6D, 0x65, 0x6D, 0x63, 0x6B, 0x60, 0x6B, 0x60, 0x69, 0x5F, 0x6A, 0x5E, 0x6A, 0x5F, 0x6B, 0x5E, 0x67, 0x5B, 0x6D, 0x60, 0x66, 0x5A, 0x69, 0x5D, 0x6A, 0x5C, 0x69, 0x5D, 0x6B, 0x5F, 0x66, 0x5D, 0x68, 0x60, 0x66, 0x5D, 0x66, 0x5D, 0x66, 0x5C, 0x67, 0x5C, 0x68, 0x5E, 0x6A, 0x5E, 0x68, 0x5E, 0x6A, 0x5E, 0x6B, 0x60, 0x6E, 0x60, 0x6B, 0x5F, 0x67, 0x5D, 0x68, 0x5D, 0x67, 0x5C, 0x65, 0x5A, 0x6A, 0x5D, 0x68, 0x5E, 0x6B, 0x60, 0x69, 0x5D, 0x68, 0x5D, 0x67, 0x5C, 0x66, 0x5C, 0x65, 0x59, 0x66, 0x5C, 0x62, 0x56, 0x64, 0x59, 0x60, 0x54, 0x62, 0x57, 0x65, 0x59, 0x65, 0x58, 0x64, 0x58, 0x5C, 0x50, 0x3F, 0x41, 0x36, 0x3A, 0x33, 0x3B, 0x33, 0x37, 0x29, 0x2C, 0x2F, 0x36, 0x2A, 0x2D, 0x33, 0x38, 0x2C, 0x2E, 0x30, 0x38, 0x2A, 0x2E, 0x31, 0x39, 0x30, 0x35, 0x27, 0x29, 0x30, 0x34, 0x2C, 0x32, 0x33, 0x37, 0x2C, 0x30, 0x30, 0x38, 0x30, 0x36, 0x36, 0x3D, 0x33, 0x37, 0x2A, 0x31, 0x32, 0x39, 0x36, 0x3D, 0x31, 0x33, 0x30, 0x37, 0x3A, 0x40, 0x36, 0x3B, 0x32, 0x36, 0x36, 0x3E, 0x31, 0x32, 0x2E, 0x35, 0x30, 0x33, 0x28, 0x2C, 0x2C, 0x2E, 0x2B, 0x31, 0x2E, 0x2F, 0x31, 0x38, 0x35, 0x39, 0x37, 0x3F, 0x32, 0x34, 0x35, 0x3C, 0x2D, 0x2F, 0x30, 0x36, 0x2F, 0x32, 0x2B, 0x2F
    },

    {
        0x59, 0x20, 0x59, 0x1F, 0x5A, 0x20, 0x58, 0x1F, 0x58, 0x1F, 0x5C, 0x21, 0x5F, 0x21, 0x5D, 0x21, 0x5B, 0x20, 0x5B, 0x20, 0x5D, 0x22, 0x5E, 0x21, 0x5F, 0x21, 0x5C, 0x22, 0x5E, 0x21, 0x5C, 0x21, 0x5A, 0x21, 0x5A, 0x20, 0x5B, 0x21, 0x5D, 0x22, 0x5E, 0x22, 0x5B, 0x21, 0x59, 0x20, 0x59, 0x1F, 0x58, 0x20, 0x5A, 0x20, 0x5C, 0x21, 0x5A, 0x20, 0x5A, 0x21, 0x5A, 0x20, 0x59, 0x1F, 0x57, 0x20, 0x57, 0x1F, 0x58, 0x20, 0x59, 0x20, 0x58, 0x20, 0x56, 0x20, 0x54, 0x1F, 0x49, 0x1C, 0x36, 0x1A, 0x3F, 0x1C, 0x51, 0x20, 0x56, 0x21, 0x54, 0x21, 0x48, 0x1E, 0x33, 0x1B, 0x2C, 0x1A, 0x27, 0x18, 0x26, 0x18, 0x26, 0x17, 0x21, 0x15, 0x1F, 0x15, 0x20, 0x16, 0x23, 0x18, 0x25, 0x19, 0x22, 0x16, 0x1E, 0x14, 0x1C, 0x14, 0x1C, 0x13, 0x1A, 0x12, 0x1C, 0x14, 0x1C, 0x14, 0x1C, 0x14, 0x1B, 0x13, 0x1D, 0x18, 0x36, 0x33, 0x65, 0x58, 0x76, 0x61, 0x7C, 0x66, 0x81, 0x6A, 0x84, 0x6B, 0x88, 0x6C, 0x86, 0x6C, 0x86, 0x6D, 0x88, 0x6E, 0x89, 0x6E, 0x8A, 0x6F, 0x87, 0x6E, 0x86, 0x6D, 0x86, 0x6D, 0x86, 0x6F, 0x87, 0x6F, 0x89, 0x6F, 0x89, 0x70, 0x8B, 0x72, 0x8B, 0x71, 0x88, 0x70, 0x89, 0x6F, 0x89, 0x6E, 0x88, 0x6F, 0x87, 0x6E, 0x89, 0x6F, 0x86, 0x6E, 0x85, 0x6C, 0x83, 0x6A, 0x72, 0x52, 0x41, 0x2D, 0x2B, 0x1E, 0x24, 0x18, 0x1F, 0x16, 0x1D, 0x15, 0x1C, 0x13, 0x1C, 0x13, 0x1C, 0x13, 0x1B, 0x13, 0x1C, 0x14, 0x1D, 0x14, 0x1C, 0x13, 0x1C, 0x14, 0x20, 0x16, 0x2D, 0x1A, 0x54, 0x22, 0x62, 0x26, 0x61, 0x26, 0x4C, 0x21, 0x34, 0x1C, 0x4C, 0x22, 0x64, 0x26, 0x68, 0x28, 0x6A, 0x28, 0x69, 0x28, 0x69, 0x28, 0x6A, 0x28, 0x67, 0x27, 0x68, 0x27, 0x6B, 0x28, 0x6C, 0x28, 0x69, 0x27, 0x6B, 0x28, 0x6B, 0x28, 0x6D, 0x29, 0x6C, 0x29, 0x69, 0x27, 0x6B, 0x28, 0x6B, 0x29, 0x6C, 0x29, 0x6A, 0x27, 0x69, 0x28, 0x6A, 0x28, 0x6B, 0x28, 0x6B, 0x29, 0x6A, 0x29, 0x6B, 0x28, 0x6F, 0x2A, 0x6D, 0x2E, 0x79, 0x37, 0x75, 0x2E, 0x6E, 0x2A, 0x6E, 0x2A, 0x6D, 0x28, 0x68, 0x27, 0x69, 0x28, 0x6A, 0x28, 0x65, 0x27, 0x6A, 0x29, 0x68, 0x27, 0x69, 0x28, 0x67, 0x27, 0x67, 0x26, 0x6A, 0x27, 0x69, 0x28, 0x6B, 0x28, 0x6B, 0x29, 0x69, 0x27, 0x69, 0x27, 0x68, 0x27, 0x6A, 0x27, 0x6A, 0x29, 0x6F, 0x2A, 0x72, 0x2C, 0x6E, 0x2B, 0x71, 0x2B, 0x6C, 0x2B, 0x71, 0x2C, 0x6B, 0x29, 0x68, 0x27, 0x64, 0x26, 0x6A, 0x27, 0x73, 0x2C, 0x6F, 0x29, 0x6D, 0x28, 0x67, 0x26, 0x68, 0x24, 0x66, 0x25, 0x69, 0x26, 0x6A, 0x26, 0x69, 0x27, 0x67, 0x27, 0x67, 0x26, 0x69, 0x26, 0x64, 0x25, 0x65, 0x25, 0x63, 0x24, 0x60, 0x24, 0x62, 0x24, 0x64, 0x25, 0x61, 0x25, 0x64, 0x25, 0x64, 0x25, 0x63, 0x24, 0x5F, 0x23, 0x5F, 0x23, 0x5C, 0x22, 0x5A, 0x21, 0x5F, 0x23, 0x61, 0x25, 0x61, 0x24, 0x5E, 0x22, 0x60, 0x24, 0x64, 0x25, 0x61, 0x24, 0x5D, 0x24, 0x5F, 0x23, 0x5F, 0x23, 0x5C, 0x22, 0x5C, 0x22, 0x5C, 0x22, 0x5C, 0x22, 0x5F, 0x24, 0x64, 0x25, 0x61, 0x25, 0x60, 0x24, 0x5E, 0x23, 0x60, 0x25, 0x64, 0x25, 0x61, 0x23, 0x5D, 0x22, 0x5D, 0x23, 0x5E, 0x22, 0x5C, 0x22, 0x5E, 0x23, 0x5E, 0x23, 0x5C, 0x22, 0x5B, 0x21, 0x59, 0x20, 0x59, 0x21, 0x5B, 0x21, 0x5E, 0x22, 0x5D, 0x21, 0x5B, 0x23, 0x5B, 0x22, 0x59, 0x21, 0x5A, 0x21, 0x5C, 0x22, 0x5B, 0x22, 0x5B, 0x22, 0x59, 0x21, 0x5B, 0x22, 0x5C, 0x23, 0x5C, 0x23, 0x5C, 0x23, 0x5D, 0x23, 0x61, 0x24, 0x60, 0x25, 0x5E, 0x23, 0x5D, 0x23, 0x5C, 0x22, 0x5D, 0x22, 0x5C, 0x22, 0x5A, 0x22, 0x5A, 0x22, 0x59, 0x21, 0x57, 0x20, 0x59, 0x22, 0x5D, 0x23, 0x59, 0x21, 0x5B, 0x22, 0x57, 0x21, 0x57, 0x20, 0x59, 0x21, 0x5A, 0x21, 0x59, 0x20, 0x53, 0x1F, 0x3A, 0x1E, 0x33, 0x1C, 0x3A, 0x1F, 0x33, 0x1C, 0x32, 0x1B, 0x34, 0x1E, 0x38, 0x1E, 0x41, 0x22, 0x3C, 0x1F, 0x3A, 0x21, 0x3D, 0x20, 0x45, 0x24, 0x3D, 0x20, 0x2D, 0x19, 0x3C, 0x20, 0x37, 0x1E, 0x3C, 0x1F, 0x33, 0x1C, 0x3B, 0x20, 0x35, 0x1D, 0x3C, 0x1F, 0x2F, 0x1A, 0x33, 0x1D, 0x32, 0x1B, 0x32, 0x1C, 0x2F, 0x1A, 0x36, 0x1E, 0x36, 0x1D, 0x32, 0x1D, 0x2D, 0x1A, 0x31, 0x1C, 0x2E, 0x1A, 0x36, 0x1D, 0x31, 0x1B, 0x35, 0x1D, 0x37, 0x1F, 0x37, 0x20, 0x4A, 0x28, 0x55, 0x2D, 0x52, 0x2C, 0x57, 0x2E, 0x57, 0x30, 0x5C, 0x32, 0x4F, 0x29, 0x43, 0x23, 0x38, 0x1E, 0x35, 0x1D
    },

    {
        0x64, 0x59, 0x67, 0x5A, 0x67, 0x5B, 0x65, 0x59, 0x65, 0x5A, 0x69, 0x5D, 0x6C, 0x5E, 0x6B, 0x5E, 0x68, 0x5B, 0x67, 0x5B, 0x68, 0x5D, 0x6B, 0x5E, 0x6C, 0x5E, 0x6C, 0x5E, 0x6B, 0x5E, 0x6A, 0x5C, 0x6B, 0x5D, 0x69, 0x5B, 0x69, 0x5C, 0x6A, 0x5C, 0x6B, 0x5C, 0x6A, 0x5B, 0x68, 0x5B, 0x69, 0x5A, 0x67, 0x58, 0x67, 0x59, 0x69, 0x5C, 0x69, 0x5B, 0x68, 0x5A, 0x68, 0x59, 0x66, 0x59, 0x67, 0x57, 0x68, 0x58, 0x67, 0x59, 0x68, 0x5A, 0x66, 0x59, 0x65, 0x57, 0x61, 0x57, 0x58, 0x4B, 0x41, 0x39, 0x3E, 0x3E, 0x52, 0x51, 0x61, 0x58, 0x61, 0x57, 0x56, 0x4D, 0x3B, 0x36, 0x2C, 0x2D, 0x25, 0x27, 0x22, 0x27, 0x20, 0x25, 0x1D, 0x20, 0x1B, 0x1F, 0x1B, 0x20, 0x1C, 0x23, 0x1D, 0x23, 0x1B, 0x20, 0x19, 0x1D, 0x17, 0x1C, 0x18, 0x1C, 0x16, 0x1B, 0x17, 0x1D, 0x18, 0x1C, 0x18, 0x1C, 0x18, 0x1B, 0x1E, 0x22, 0x33, 0x46, 0x57, 0x70, 0x67, 0x7A, 0x6B, 0x7F, 0x6F, 0x83, 0x72, 0x82, 0x73, 0x86, 0x74, 0x85, 0x74, 0x86, 0x74, 0x87, 0x74, 0x88, 0x75, 0x88, 0x74, 0x85, 0x73, 0x84, 0x72, 0x86, 0x73, 0x87, 0x73, 0x85, 0x75, 0x88, 0x76, 0x86, 0x76, 0x8B, 0x76, 0x88, 0x74, 0x87, 0x75, 0x89, 0x75, 0x89, 0x73, 0x88, 0x74, 0x87, 0x74, 0x87, 0x73, 0x87, 0x72, 0x86, 0x6F, 0x82, 0x66, 0x74, 0x44, 0x45, 0x29, 0x2C, 0x20, 0x23, 0x1B, 0x1F, 0x19, 0x1D, 0x18, 0x1C, 0x18, 0x1D, 0x18, 0x1C, 0x17, 0x1C, 0x18, 0x1C, 0x18, 0x1D, 0x18, 0x1D, 0x19, 0x1D, 0x1E, 0x22, 0x33, 0x39, 0x5D, 0x5D, 0x6C, 0x64, 0x67, 0x60, 0x4A, 0x3F, 0x39, 0x37, 0x5A, 0x59, 0x6E, 0x66, 0x73, 0x68, 0x77, 0x6B, 0x76, 0x6B, 0x76, 0x6A, 0x77, 0x6B, 0x74, 0x68, 0x73, 0x69, 0x7A, 0x6C, 0x79, 0x6D, 0x77, 0x69, 0x75, 0x6B, 0x77, 0x6D, 0x7B, 0x6E, 0x7B, 0x6D, 0x78, 0x69, 0x78, 0x6B, 0x7A, 0x6C, 0x79, 0x6D, 0x7B, 0x6D, 0x77, 0x6C, 0x79, 0x6B, 0x78, 0x6C, 0x7A, 0x6D, 0x79, 0x6C, 0x79, 0x6D, 0x7A, 0x6F, 0x7A, 0x77, 0x82, 0x80, 0x7B, 0x71, 0x78, 0x71, 0x7A, 0x6E, 0x7A, 0x6C, 0x74, 0x66, 0x79, 0x6C, 0x7A, 0x6A, 0x74, 0x69, 0x78, 0x6C, 0x76, 0x6A, 0x79, 0x6B, 0x77, 0x6A, 0x77, 0x69, 0x7A, 0x6B, 0x77, 0x6A, 0x7A, 0x6A, 0x79, 0x6C, 0x7A, 0x6C, 0x76, 0x69, 0x76, 0x6B, 0x75, 0x69, 0x76, 0x6D, 0x7F, 0x73, 0x80, 0x74, 0x7A, 0x71, 0x7D, 0x70, 0x77, 0x70, 0x79, 0x70, 0x7B, 0x6E, 0x79, 0x6A, 0x76, 0x68, 0x79, 0x6C, 0x82, 0x76, 0x7E, 0x6E, 0x7B, 0x6C, 0x78, 0x69, 0x77, 0x68, 0x76, 0x68, 0x78, 0x6B, 0x7B, 0x6D, 0x78, 0x68, 0x76, 0x69, 0x79, 0x6A, 0x78, 0x6A, 0x70, 0x65, 0x72, 0x67, 0x71, 0x65, 0x70, 0x64, 0x71, 0x66, 0x74, 0x66, 0x6F, 0x63, 0x71, 0x65, 0x72, 0x66, 0x70, 0x64, 0x6F, 0x62, 0x6E, 0x61, 0x6B, 0x5E, 0x68, 0x5D, 0x6E, 0x62, 0x6F, 0x63, 0x6F, 0x62, 0x6B, 0x5E, 0x6D, 0x61, 0x6F, 0x65, 0x6C, 0x61, 0x6B, 0x60, 0x6C, 0x60, 0x6D, 0x61, 0x69, 0x5E, 0x67, 0x5C, 0x69, 0x5E, 0x69, 0x5D, 0x6A, 0x5F, 0x6E, 0x62, 0x6E, 0x62, 0x6D, 0x61, 0x6C, 0x5F, 0x6D, 0x64, 0x70, 0x66, 0x6D, 0x61, 0x68, 0x5E, 0x69, 0x61, 0x6A, 0x5D, 0x6A, 0x5E, 0x6C, 0x5F, 0x6C, 0x5F, 0x6B, 0x5F, 0x66, 0x59, 0x67, 0x5A, 0x68, 0x5C, 0x6A, 0x5D, 0x6B, 0x5F, 0x6B, 0x5D, 0x66, 0x5D, 0x67, 0x5D, 0x67, 0x5B, 0x67, 0x5C, 0x68, 0x5F, 0x66, 0x5B, 0x65, 0x5C, 0x67, 0x5C, 0x68, 0x5C, 0x67, 0x5D, 0x69, 0x5D, 0x67, 0x5C, 0x6A, 0x5F, 0x6E, 0x62, 0x6B, 0x61, 0x69, 0x5E, 0x68, 0x5E, 0x6A, 0x5E, 0x6B, 0x5F, 0x69, 0x5D, 0x67, 0x5C, 0x65, 0x5B, 0x67, 0x5B, 0x62, 0x57, 0x66, 0x5B, 0x67, 0x5E, 0x67, 0x5C, 0x69, 0x5A, 0x63, 0x59, 0x63, 0x5A, 0x67, 0x5D, 0x67, 0x5C, 0x64, 0x5A, 0x5D, 0x50, 0x3B, 0x3C, 0x2F, 0x32, 0x34, 0x3B, 0x31, 0x37, 0x2E, 0x32, 0x33, 0x3C, 0x35, 0x3D, 0x3B, 0x44, 0x34, 0x38, 0x34, 0x3E, 0x36, 0x3F, 0x3A, 0x42, 0x33, 0x38, 0x29, 0x2C, 0x38, 0x40, 0x2D, 0x34, 0x32, 0x37, 0x2C, 0x2F, 0x37, 0x3F, 0x2F, 0x33, 0x33, 0x37, 0x2A, 0x2C, 0x30, 0x39, 0x2C, 0x2E, 0x2E, 0x33, 0x2A, 0x2D, 0x30, 0x38, 0x2F, 0x30, 0x2F, 0x32, 0x2D, 0x30, 0x31, 0x35, 0x2F, 0x32, 0x35, 0x3B, 0x2E, 0x31, 0x33, 0x38, 0x34, 0x3B, 0x34, 0x3E, 0x4A, 0x59, 0x52, 0x60, 0x4F, 0x5E, 0x52, 0x62, 0x53, 0x64, 0x56, 0x68, 0x48, 0x51, 0x39, 0x40, 0x31, 0x38, 0x31, 0x38
    },

    {
        0x58, 0x20, 0x59, 0x1F, 0x59, 0x20, 0x58, 0x20, 0x59, 0x20, 0x5B, 0x20, 0x5B, 0x21, 0x5B, 0x21, 0x5C, 0x20, 0x5B, 0x21, 0x5B, 0x21, 0x5C, 0x21, 0x5B, 0x21, 0x5D, 0x21, 0x5C, 0x21, 0x5B, 0x21, 0x5B, 0x21, 0x5B, 0x22, 0x5B, 0x21, 0x5B, 0x21, 0x5A, 0x20, 0x5C, 0x21, 0x5D, 0x21, 0x5A, 0x21, 0x5A, 0x20, 0x5A, 0x21, 0x5A, 0x21, 0x5B, 0x21, 0x5B, 0x21, 0x59, 0x20, 0x58, 0x1F, 0x57, 0x1F, 0x58, 0x20, 0x59, 0x20, 0x59, 0x21, 0x5A, 0x21, 0x5B, 0x21, 0x59, 0x21, 0x57, 0x20, 0x4E, 0x1F, 0x3D, 0x1C, 0x3C, 0x1C, 0x50, 0x20, 0x5A, 0x22, 0x5B, 0x23, 0x50, 0x21, 0x39, 0x1C, 0x2A, 0x18, 0x26, 0x18, 0x23, 0x16, 0x22, 0x16, 0x20, 0x15, 0x1F, 0x15, 0x1F, 0x16, 0x1E, 0x15, 0x1E, 0x15, 0x1D, 0x14, 0x1C, 0x14, 0x1B, 0x13, 0x1C, 0x13, 0x1C, 0x14, 0x1C, 0x14, 0x1B, 0x13, 0x1D, 0x17, 0x32, 0x30, 0x61, 0x55, 0x76, 0x61, 0x7C, 0x66, 0x81, 0x69, 0x85, 0x6C, 0x87, 0x6D, 0x8A, 0x70, 0x8A, 0x70, 0x8B, 0x71, 0x89, 0x6F, 0x85, 0x6D, 0x88, 0x6E, 0x87, 0x6E, 0x87, 0x6E, 0x89, 0x6F, 0x89, 0x6F, 0x87, 0x6F, 0x8B, 0x71, 0x8A, 0x72, 0x8B, 0x71, 0x87, 0x6F, 0x88, 0x70, 0x89, 0x71, 0x89, 0x6F, 0x89, 0x70, 0x8A, 0x70, 0x89, 0x6E, 0x87, 0x6E, 0x86, 0x6D, 0x84, 0x6D, 0x86, 0x6C, 0x79, 0x59, 0x4A, 0x32, 0x2B, 0x1E, 0x22, 0x18, 0x1F, 0x16, 0x1D, 0x15, 0x1C, 0x14, 0x1C, 0x14, 0x1C, 0x13, 0x1B, 0x13, 0x1D, 0x14, 0x1D, 0x14, 0x1D, 0x14, 0x2A, 0x19, 0x4F, 0x22, 0x5F, 0x24, 0x63, 0x25, 0x4E, 0x21, 0x33, 0x1C, 0x4D, 0x23, 0x64, 0x26, 0x69, 0x29, 0x6C, 0x29, 0x69, 0x27, 0x6D, 0x29, 0x6C, 0x29, 0x6A, 0x28, 0x69, 0x28, 0x6B, 0x2A, 0x6C, 0x29, 0x6D, 0x29, 0x6A, 0x28, 0x68, 0x28, 0x6D, 0x29, 0x6A, 0x28, 0x6C, 0x29, 0x6D, 0x29, 0x68, 0x28, 0x69, 0x28, 0x69, 0x28, 0x6C, 0x28, 0x6B, 0x29, 0x6E, 0x2A, 0x6B, 0x29, 0x6A, 0x28, 0x74, 0x2E, 0x6B, 0x2C, 0x77, 0x34, 0x7D, 0x36, 0x72, 0x2D, 0x6F, 0x2D, 0x74, 0x2D, 0x6C, 0x29, 0x6A, 0x29, 0x6B, 0x28, 0x6C, 0x27, 0x6A, 0x28, 0x69, 0x28, 0x6B, 0x28, 0x68, 0x28, 0x6E, 0x29, 0x6C, 0x29, 0x6B, 0x28, 0x69, 0x27, 0x6C, 0x29, 0x6B, 0x27, 0x69, 0x27, 0x6A, 0x28, 0x63, 0x26, 0x68, 0x27, 0x68, 0x26, 0x6C, 0x28, 0x6F, 0x2A, 0x70, 0x2B, 0x73, 0x2E, 0x73, 0x2C, 0x6B, 0x2A, 0x6C, 0x2B, 0x6A, 0x29, 0x69, 0x27, 0x6C, 0x28, 0x6B, 0x29, 0x6E, 0x28, 0x6C, 0x27, 0x68, 0x26, 0x66, 0x25, 0x6A, 0x27, 0x6A, 0x26, 0x67, 0x27, 0x68, 0x27, 0x6A, 0x27, 0x6D, 0x28, 0x6F, 0x29, 0x66, 0x26, 0x67, 0x26, 0x63, 0x25, 0x65, 0x25, 0x67, 0x26, 0x65, 0x26, 0x66, 0x26, 0x60, 0x24, 0x62, 0x25, 0x63, 0x25, 0x62, 0x23, 0x5F, 0x23, 0x60, 0x24, 0x63, 0x25, 0x60, 0x24, 0x62, 0x24, 0x63, 0x25, 0x63, 0x25, 0x62, 0x26, 0x63, 0x27, 0x66, 0x29, 0x63, 0x27, 0x61, 0x26, 0x5F, 0x23, 0x5F, 0x24, 0x64, 0x27, 0x60, 0x24, 0x5D, 0x24, 0x5C, 0x22, 0x5C, 0x23, 0x60, 0x25, 0x60, 0x24, 0x5F, 0x24, 0x5F, 0x23, 0x64, 0x26, 0x64, 0x25, 0x5D, 0x23, 0x5E, 0x23, 0x5F, 0x23, 0x5E, 0x23, 0x5C, 0x24, 0x60, 0x23, 0x5E, 0x24, 0x5C, 0x22, 0x57, 0x21, 0x59, 0x21, 0x5D, 0x23, 0x5D, 0x22, 0x5C, 0x22, 0x5B, 0x22, 0x5B, 0x23, 0x5D, 0x23, 0x5F, 0x24, 0x5F, 0x25, 0x5F, 0x23, 0x5B, 0x22, 0x58, 0x21, 0x5A, 0x22, 0x59, 0x22, 0x5B, 0x22, 0x5F, 0x23, 0x5E, 0x23, 0x5A, 0x22, 0x59, 0x21, 0x5D, 0x23, 0x5E, 0x24, 0x5B, 0x22, 0x5B, 0x23, 0x5B, 0x23, 0x5E, 0x23, 0x5C, 0x23, 0x58, 0x22, 0x5B, 0x22, 0x5A, 0x22, 0x5D, 0x23, 0x5C, 0x23, 0x5B, 0x22, 0x5B, 0x22, 0x59, 0x22, 0x56, 0x21, 0x5A, 0x21, 0x59, 0x22, 0x59, 0x22, 0x54, 0x21, 0x44, 0x22, 0x42, 0x22, 0x3D, 0x21, 0x40, 0x21, 0x32, 0x1C, 0x44, 0x24, 0x39, 0x1F, 0x3A, 0x1F, 0x2E, 0x1A, 0x35, 0x1E, 0x2F, 0x1B, 0x30, 0x1B, 0x2A, 0x19, 0x29, 0x19, 0x34, 0x1D, 0x2A, 0x19, 0x2F, 0x1B, 0x2C, 0x1B, 0x35, 0x1E, 0x2D, 0x1B, 0x35, 0x1E, 0x2F, 0x1C, 0x35, 0x1D, 0x2F, 0x1A, 0x33, 0x1D, 0x2F, 0x1B, 0x3F, 0x24, 0x48, 0x2A, 0x57, 0x32, 0x5B, 0x35, 0x69, 0x3C, 0x6C, 0x3C, 0x6E, 0x3D, 0x49, 0x26, 0x35, 0x1D, 0x3C, 0x20, 0x40, 0x29, 0x78, 0x46, 0x81, 0x48, 0x81, 0x49, 0x81, 0x48, 0x81, 0x47, 0x7C, 0x42, 0x52, 0x2A, 0x2E, 0x1B, 0x34, 0x1C, 0x31, 0x1C
    },

    {
        0x64, 0x59, 0x66, 0x59, 0x65, 0x5A, 0x66, 0x5A, 0x65, 0x59, 0x68, 0x5B, 0x68, 0x5B, 0x69, 0x5B, 0x69, 0x5B, 0x69, 0x5B, 0x68, 0x5C, 0x69, 0x5A, 0x68, 0x5B, 0x68, 0x5B, 0x68, 0x5C, 0x69, 0x5C, 0x69, 0x5C, 0x68, 0x5B, 0x67, 0x5C, 0x69, 0x5A, 0x68, 0x5B, 0x6A, 0x5C, 0x6C, 0x5B, 0x68, 0x59, 0x68, 0x5B, 0x68, 0x59, 0x68, 0x5A, 0x68, 0x5B, 0x68, 0x5B, 0x66, 0x59, 0x66, 0x58, 0x64, 0x56, 0x66, 0x58, 0x68, 0x58, 0x6A, 0x5A, 0x68, 0x5B, 0x69, 0x5B, 0x67, 0x5B, 0x65, 0x57, 0x5D, 0x51, 0x49, 0x3E, 0x3D, 0x3B, 0x50, 0x4E, 0x63, 0x5A, 0x65, 0x5B, 0x5C, 0x53, 0x42, 0x3B, 0x2C, 0x2A, 0x25, 0x26, 0x21, 0x24, 0x1F, 0x22, 0x1D, 0x1F, 0x1A, 0x1E, 0x1A, 0x1E, 0x19, 0x1D, 0x19, 0x1E, 0x18, 0x1C, 0x16, 0x1B, 0x17, 0x1B, 0x17, 0x1B, 0x17, 0x1C, 0x18, 0x1C, 0x18, 0x1A, 0x1D, 0x21, 0x30, 0x41, 0x54, 0x6D, 0x64, 0x77, 0x6A, 0x7B, 0x6F, 0x82, 0x73, 0x87, 0x75, 0x86, 0x75, 0x8A, 0x77, 0x88, 0x75, 0x89, 0x76, 0x88, 0x74, 0x86, 0x75, 0x87, 0x73, 0x85, 0x74, 0x84, 0x75, 0x89, 0x75, 0x86, 0x74, 0x88, 0x77, 0x89, 0x76, 0x8A, 0x76, 0x89, 0x73, 0x86, 0x75, 0x88, 0x76, 0x89, 0x75, 0x87, 0x76, 0x89, 0x77, 0x8B, 0x76, 0x87, 0x74, 0x86, 0x74, 0x87, 0x72, 0x85, 0x71, 0x85, 0x6A, 0x7C, 0x4D, 0x4F, 0x2B, 0x2D, 0x21, 0x24, 0x1C, 0x20, 0x1A, 0x1E, 0x18, 0x1D, 0x18, 0x1C, 0x18, 0x1C, 0x17, 0x1C, 0x18, 0x1D, 0x1A, 0x1E, 0x1D, 0x1F, 0x30, 0x36, 0x5A, 0x5B, 0x69, 0x62, 0x69, 0x61, 0x4B, 0x41, 0x3A, 0x39, 0x5A, 0x5A, 0x6F, 0x67, 0x75, 0x6C, 0x77, 0x6C, 0x74, 0x68, 0x7A, 0x6D, 0x7B, 0x6E, 0x77, 0x6A, 0x76, 0x6B, 0x77, 0x6E, 0x78, 0x6C, 0x7A, 0x6E, 0x78, 0x6B, 0x74, 0x68, 0x7A, 0x6D, 0x77, 0x6A, 0x79, 0x6E, 0x7C, 0x6F, 0x78, 0x6B, 0x78, 0x6A, 0x77, 0x6B, 0x7B, 0x6C, 0x79, 0x6B, 0x7A, 0x6F, 0x77, 0x6A, 0x79, 0x6D, 0x82, 0x7A, 0x77, 0x6F, 0x7C, 0x79, 0x80, 0x76, 0x79, 0x6E, 0x7A, 0x6F, 0x7E, 0x73, 0x7A, 0x6D, 0x79, 0x6B, 0x78, 0x6B, 0x7A, 0x6C, 0x77, 0x69, 0x75, 0x69, 0x76, 0x6B, 0x78, 0x6B, 0x7C, 0x6E, 0x7C, 0x6D, 0x78, 0x6A, 0x77, 0x6B, 0x7A, 0x6E, 0x79, 0x69, 0x76, 0x69, 0x78, 0x69, 0x75, 0x67, 0x79, 0x6B, 0x78, 0x69, 0x7D, 0x6F, 0x7D, 0x6F, 0x7B, 0x70, 0x7E, 0x76, 0x7D, 0x71, 0x79, 0x6D, 0x77, 0x6D, 0x77, 0x6B, 0x79, 0x6C, 0x7A, 0x6C, 0x78, 0x6C, 0x7C, 0x6D, 0x7B, 0x6C, 0x76, 0x68, 0x77, 0x67, 0x7A, 0x6C, 0x7A, 0x6B, 0x7A, 0x6B, 0x79, 0x6A, 0x7B, 0x6C, 0x7B, 0x6D, 0x7C, 0x6E, 0x75, 0x67, 0x72, 0x68, 0x72, 0x64, 0x72, 0x66, 0x75, 0x68, 0x74, 0x66, 0x77, 0x68, 0x6D, 0x60, 0x71, 0x65, 0x70, 0x64, 0x6F, 0x60, 0x6D, 0x62, 0x6D, 0x62, 0x70, 0x64, 0x6E, 0x64, 0x72, 0x63, 0x70, 0x64, 0x72, 0x65, 0x71, 0x66, 0x71, 0x66, 0x70, 0x67, 0x6E, 0x65, 0x6A, 0x61, 0x6C, 0x60, 0x6C, 0x62, 0x70, 0x67, 0x6B, 0x60, 0x6B, 0x61, 0x6A, 0x5F, 0x6A, 0x5E, 0x6D, 0x62, 0x6E, 0x60, 0x6C, 0x62, 0x6F, 0x62, 0x72, 0x66, 0x6F, 0x63, 0x69, 0x5E, 0x68, 0x5F, 0x69, 0x5F, 0x69, 0x5E, 0x67, 0x5D, 0x6D, 0x60, 0x6D, 0x5F, 0x6C, 0x5E, 0x64, 0x59, 0x65, 0x5A, 0x68, 0x5D, 0x69, 0x5D, 0x67, 0x5E, 0x68, 0x5D, 0x67, 0x5C, 0x67, 0x5B, 0x6C, 0x63, 0x69, 0x61, 0x6C, 0x60, 0x67, 0x5B, 0x64, 0x5B, 0x67, 0x5D, 0x67, 0x5B, 0x69, 0x5E, 0x6D, 0x61, 0x69, 0x5D, 0x68, 0x5B, 0x67, 0x5C, 0x68, 0x5E, 0x6A, 0x60, 0x68, 0x5A, 0x69, 0x5F, 0x67, 0x5C, 0x68, 0x5D, 0x66, 0x5B, 0x64, 0x5B, 0x65, 0x5A, 0x69, 0x5C, 0x68, 0x5D, 0x68, 0x5E, 0x68, 0x5D, 0x69, 0x5D, 0x65, 0x5A, 0x63, 0x59, 0x66, 0x5C, 0x67, 0x5B, 0x64, 0x5A, 0x5C, 0x51, 0x43, 0x47, 0x3B, 0x3F, 0x37, 0x3F, 0x35, 0x3B, 0x2B, 0x31, 0x3C, 0x45, 0x30, 0x35, 0x31, 0x36, 0x29, 0x2D, 0x30, 0x35, 0x2B, 0x2D, 0x2D, 0x2F, 0x28, 0x2A, 0x29, 0x2F, 0x2C, 0x2F, 0x28, 0x2D, 0x2D, 0x2F, 0x2E, 0x35, 0x31, 0x35, 0x2E, 0x34, 0x33, 0x39, 0x33, 0x3A, 0x35, 0x3A, 0x2E, 0x30, 0x31, 0x36, 0x2F, 0x35, 0x3A, 0x4A, 0x49, 0x5B, 0x54, 0x69, 0x59, 0x6E, 0x61, 0x79, 0x64, 0x79, 0x62, 0x78, 0x41, 0x44, 0x2F, 0x33, 0x36, 0x3A, 0x38, 0x4C, 0x63, 0x7E, 0x6B, 0x82, 0x6A, 0x82, 0x69, 0x80, 0x68, 0x80, 0x62, 0x78, 0x3E, 0x40, 0x27, 0x2C, 0x2E, 0x34, 0x2E, 0x35
    },

    {
        0x59, 0x20, 0x59, 0x1F, 0x59, 0x1F, 0x59, 0x20, 0x59, 0x1F, 0x5A, 0x20, 0x5B, 0x21, 0x5B, 0x20, 0x5C, 0x21, 0x5D, 0x21, 0x5B, 0x21, 0x5A, 0x21, 0x5B, 0x22, 0x5E, 0x22, 0x5C, 0x21, 0x5D, 0x22, 0x5E, 0x22, 0x5D, 0x22, 0x5E, 0x22, 0x5C, 0x21, 0x5B, 0x21, 0x5C, 0x21, 0x5B, 0x21, 0x5B, 0x21, 0x5D, 0x20, 0x5C, 0x21, 0x5B, 0x22, 0x5A, 0x21, 0x5A, 0x20, 0x59, 0x20, 0x58, 0x20, 0x58, 0x20, 0x5A, 0x21, 0x5B, 0x20, 0x5B, 0x20, 0x5C, 0x22, 0x5F, 0x22, 0x5D, 0x22, 0x5C, 0x22, 0x5B, 0x23, 0x56, 0x21, 0x41, 0x1C, 0x3B, 0x1C, 0x4C, 0x1F, 0x59, 0x22, 0x5D, 0x24, 0x56, 0x22, 0x3C, 0x1B, 0x2A, 0x17, 0x25, 0x16, 0x23, 0x16, 0x1F, 0x14, 0x1D, 0x13, 0x1C, 0x13, 0x1D, 0x14, 0x1E, 0x14, 0x1C, 0x13, 0x1B, 0x13, 0x1C, 0x13, 0x1B, 0x13, 0x1C, 0x14, 0x1C, 0x13, 0x1D, 0x17, 0x2F, 0x2E, 0x5E, 0x51, 0x76, 0x60, 0x7D, 0x66, 0x83, 0x6B, 0x86, 0x6D, 0x89, 0x6E, 0x88, 0x6F, 0x8A, 0x71, 0x8D, 0x71, 0x8A, 0x70, 0x8A, 0x70, 0x88, 0x6F, 0x88, 0x6F, 0x87, 0x6F, 0x89, 0x6F, 0x89, 0x70, 0x8A, 0x70, 0x8A, 0x70, 0x8A, 0x70, 0x88, 0x70, 0x8B, 0x70, 0x89, 0x71, 0x8C, 0x72, 0x8B, 0x70, 0x89, 0x70, 0x8A, 0x70, 0x8A, 0x72, 0x8C, 0x72, 0x8B, 0x70, 0x8A, 0x71, 0x88, 0x6F, 0x88, 0x6F, 0x87, 0x6E, 0x80, 0x61, 0x54, 0x39, 0x2F, 0x21, 0x26, 0x1A, 0x20, 0x16, 0x1D, 0x14, 0x1C, 0x13, 0x1C, 0x13, 0x1B, 0x13, 0x1D, 0x14, 0x20, 0x16, 0x2A, 0x19, 0x51, 0x22, 0x61, 0x26, 0x64, 0x27, 0x4F, 0x21, 0x32, 0x1B, 0x4F, 0x23, 0x65, 0x27, 0x64, 0x26, 0x6A, 0x28, 0x6A, 0x29, 0x6A, 0x29, 0x6D, 0x28, 0x6B, 0x28, 0x6B, 0x28, 0x6B, 0x29, 0x6C, 0x29, 0x6B, 0x27, 0x67, 0x26, 0x69, 0x26, 0x6A, 0x28, 0x70, 0x29, 0x68, 0x28, 0x69, 0x28, 0x6B, 0x28, 0x6B, 0x28, 0x6E, 0x29, 0x6B, 0x28, 0x6C, 0x29, 0x6A, 0x27, 0x69, 0x28, 0x6A, 0x28, 0x71, 0x2E, 0x82, 0x38, 0x6C, 0x2B, 0x6E, 0x2B, 0x6C, 0x29, 0x68, 0x28, 0x6A, 0x2A, 0x6B, 0x29, 0x6D, 0x29, 0x6E, 0x2A, 0x6B, 0x28, 0x6D, 0x29, 0x68, 0x27, 0x69, 0x28, 0x68, 0x28, 0x6C, 0x28, 0x68, 0x27, 0x6A, 0x27, 0x68, 0x26, 0x67, 0x25, 0x69, 0x27, 0x68, 0x27, 0x68, 0x27, 0x69, 0x27, 0x69, 0x28, 0x6C, 0x27, 0x68, 0x27, 0x6D, 0x29, 0x6C, 0x28, 0x6E, 0x2B, 0x74, 0x2D, 0x74, 0x2D, 0x70, 0x29, 0x6C, 0x29, 0x6C, 0x28, 0x66, 0x26, 0x68, 0x25, 0x6A, 0x26, 0x6A, 0x26, 0x67, 0x25, 0x6A, 0x27, 0x6A, 0x26, 0x69, 0x26, 0x72, 0x2C, 0x76, 0x2B, 0x6E, 0x28, 0x69, 0x27, 0x68, 0x27, 0x69, 0x26, 0x68, 0x27, 0x69, 0x27, 0x65, 0x25, 0x68, 0x26, 0x66, 0x26, 0x67, 0x26, 0x66, 0x26, 0x64, 0x24, 0x67, 0x25, 0x63, 0x24, 0x62, 0x23, 0x5E, 0x22, 0x62, 0x24, 0x63, 0x26, 0x66, 0x25, 0x62, 0x24, 0x64, 0x26, 0x67, 0x26, 0x65, 0x26, 0x64, 0x27, 0x65, 0x27, 0x66, 0x26, 0x60, 0x24, 0x5C, 0x22, 0x5D, 0x23, 0x62, 0x26, 0x64, 0x26, 0x61, 0x24, 0x5E, 0x23, 0x5E, 0x23, 0x5F, 0x24, 0x61, 0x24, 0x61, 0x25, 0x5F, 0x24, 0x5E, 0x24, 0x5D, 0x22, 0x5E, 0x24, 0x5C, 0x24, 0x5B, 0x22, 0x5B, 0x22, 0x5B, 0x23, 0x60, 0x23, 0x5C, 0x24, 0x5C, 0x22, 0x59, 0x20, 0x5C, 0x22, 0x5B, 0x21, 0x5B, 0x22, 0x59, 0x22, 0x5B, 0x22, 0x5C, 0x22, 0x60, 0x24, 0x66, 0x27, 0x63, 0x26, 0x61, 0x26, 0x5E, 0x25, 0x5D, 0x23, 0x5E, 0x23, 0x5D, 0x23, 0x5B, 0x22, 0x5C, 0x23, 0x5D, 0x23, 0x5B, 0x22, 0x5A, 0x22, 0x5C, 0x23, 0x5D, 0x23, 0x60, 0x23, 0x5E, 0x23, 0x59, 0x22, 0x5B, 0x22, 0x5B, 0x22, 0x5B, 0x22, 0x59, 0x21, 0x5C, 0x23, 0x5F, 0x24, 0x5C, 0x22, 0x57, 0x21, 0x5A, 0x22, 0x5A, 0x22, 0x58, 0x21, 0x56, 0x20, 0x58, 0x21, 0x5A, 0x21, 0x54, 0x21, 0x48, 0x24, 0x35, 0x1D, 0x3B, 0x20, 0x30, 0x1B, 0x30, 0x1C, 0x3B, 0x1F, 0x30, 0x1C, 0x38, 0x1F, 0x3D, 0x22, 0x3F, 0x22, 0x3D, 0x22, 0x44, 0x26, 0x40, 0x22, 0x3F, 0x1F, 0x33, 0x1C, 0x34, 0x1E, 0x4B, 0x2C, 0x69, 0x3E, 0x69, 0x3E, 0x75, 0x46, 0x7A, 0x49, 0x7D, 0x4B, 0x7B, 0x46, 0x45, 0x24, 0x3E, 0x21, 0x3A, 0x1F, 0x5D, 0x3A, 0x8F, 0x55, 0x94, 0x57, 0x95, 0x57, 0x8F, 0x54, 0x8F, 0x53, 0x88, 0x4E, 0x43, 0x25, 0x2C, 0x1B, 0x32, 0x1C, 0x44, 0x2B, 0x77, 0x45, 0x75, 0x43, 0x6F, 0x40, 0x67, 0x3B, 0x5F, 0x38, 0x55, 0x31, 0x34, 0x1C, 0x25, 0x17, 0x36, 0x1D, 0x3A, 0x1F
    },

    {
        0x65, 0x5A, 0x65, 0x5A, 0x66, 0x5A, 0x66, 0x5A, 0x67, 0x5A, 0x67, 0x5B, 0x69, 0x5C, 0x68, 0x5C, 0x68, 0x5C, 0x6B, 0x5D, 0x69, 0x5B, 0x67, 0x5B, 0x69, 0x5D, 0x6A, 0x5F, 0x6A, 0x5E, 0x6B, 0x5E, 0x6B, 0x5D, 0x6B, 0x5E, 0x6B, 0x5E, 0x6A, 0x5B, 0x6A, 0x5C, 0x6A, 0x5C, 0x6B, 0x5C, 0x6C, 0x5C, 0x6C, 0x5D, 0x6B, 0x5C, 0x69, 0x5B, 0x68, 0x5A, 0x68, 0x5B, 0x67, 0x59, 0x67, 0x58, 0x66, 0x59, 0x68, 0x5B, 0x6B, 0x5C, 0x6B, 0x5D, 0x69, 0x5B, 0x6D, 0x5F, 0x6A, 0x5D, 0x6A, 0x5E, 0x6C, 0x5E, 0x66, 0x59, 0x52, 0x43, 0x41, 0x3B, 0x4C, 0x4A, 0x61, 0x59, 0x66, 0x5D, 0x61, 0x58, 0x49, 0x3F, 0x2E, 0x2B, 0x24, 0x25, 0x20, 0x23, 0x1D, 0x1F, 0x1A, 0x1D, 0x19, 0x1C, 0x18, 0x1E, 0x19, 0x1D, 0x17, 0x1B, 0x16, 0x1B, 0x17, 0x1B, 0x17, 0x1C, 0x17, 0x1C, 0x19, 0x1C, 0x1D, 0x21, 0x30, 0x3F, 0x52, 0x6B, 0x65, 0x79, 0x6A, 0x7E, 0x6F, 0x83, 0x73, 0x84, 0x74, 0x87, 0x75, 0x87, 0x77, 0x8B, 0x77, 0x88, 0x76, 0x87, 0x76, 0x87, 0x74, 0x87, 0x74, 0x87, 0x74, 0x8A, 0x75, 0x89, 0x75, 0x86, 0x75, 0x86, 0x75, 0x87, 0x76, 0x88, 0x76, 0x88, 0x77, 0x88, 0x76, 0x8A, 0x77, 0x8A, 0x76, 0x89, 0x75, 0x89, 0x77, 0x89, 0x75, 0x89, 0x76, 0x8A, 0x77, 0x89, 0x76, 0x88, 0x74, 0x89, 0x75, 0x88, 0x72, 0x87, 0x6C, 0x81, 0x52, 0x58, 0x2F, 0x31, 0x21, 0x26, 0x1C, 0x20, 0x19, 0x1D, 0x17, 0x1C, 0x18, 0x1C, 0x18, 0x1C, 0x19, 0x1E, 0x1F, 0x23, 0x31, 0x37, 0x5D, 0x5D, 0x69, 0x63, 0x68, 0x62, 0x4D, 0x44, 0x39, 0x38, 0x5B, 0x5B, 0x70, 0x68, 0x6F, 0x65, 0x75, 0x6C, 0x75, 0x6B, 0x75, 0x6D, 0x79, 0x6E, 0x79, 0x6D, 0x7A, 0x6C, 0x79, 0x6E, 0x79, 0x6E, 0x77, 0x6A, 0x75, 0x67, 0x76, 0x69, 0x78, 0x6F, 0x7B, 0x6F, 0x75, 0x69, 0x78, 0x6B, 0x7A, 0x6D, 0x79, 0x6E, 0x7C, 0x6E, 0x7A, 0x6B, 0x7B, 0x6F, 0x78, 0x69, 0x76, 0x6B, 0x76, 0x6B, 0x7C, 0x76, 0x82, 0x7C, 0x75, 0x69, 0x7A, 0x6E, 0x7A, 0x6E, 0x77, 0x68, 0x79, 0x6C, 0x79, 0x6D, 0x7A, 0x6D, 0x7E, 0x70, 0x7B, 0x6D, 0x7B, 0x6F, 0x77, 0x6A, 0x76, 0x69, 0x76, 0x6B, 0x79, 0x6C, 0x76, 0x6A, 0x79, 0x6A, 0x76, 0x67, 0x76, 0x6A, 0x7A, 0x6C, 0x77, 0x69, 0x76, 0x6A, 0x79, 0x6A, 0x78, 0x6A, 0x79, 0x6A, 0x77, 0x6D, 0x7A, 0x6E, 0x7A, 0x6C, 0x7D, 0x72, 0x82, 0x77, 0x80, 0x75, 0x7D, 0x70, 0x78, 0x6D, 0x79, 0x6A, 0x77, 0x68, 0x79, 0x68, 0x7B, 0x6C, 0x7A, 0x6B, 0x74, 0x67, 0x7C, 0x6D, 0x7C, 0x6D, 0x7B, 0x6B, 0x83, 0x77, 0x85, 0x76, 0x7D, 0x70, 0x7A, 0x6C, 0x79, 0x6C, 0x7D, 0x6D, 0x77, 0x69, 0x7A, 0x6C, 0x77, 0x69, 0x77, 0x6C, 0x75, 0x67, 0x75, 0x68, 0x75, 0x67, 0x74, 0x66, 0x76, 0x6A, 0x70, 0x63, 0x72, 0x64, 0x6B, 0x60, 0x6E, 0x63, 0x70, 0x67, 0x72, 0x67, 0x70, 0x64, 0x6F, 0x65, 0x75, 0x69, 0x74, 0x68, 0x72, 0x66, 0x73, 0x67, 0x72, 0x66, 0x6E, 0x61, 0x6A, 0x5F, 0x6C, 0x61, 0x70, 0x67, 0x72, 0x65, 0x6E, 0x63, 0x6C, 0x60, 0x6E, 0x62, 0x6C, 0x63, 0x6D, 0x61, 0x6E, 0x62, 0x6D, 0x60, 0x6B, 0x5F, 0x6B, 0x5E, 0x6B, 0x5F, 0x69, 0x5F, 0x6A, 0x5F, 0x69, 0x5D, 0x69, 0x5E, 0x6E, 0x61, 0x68, 0x5C, 0x6A, 0x5D, 0x69, 0x5D, 0x6A, 0x5E, 0x66, 0x5A, 0x66, 0x5C, 0x66, 0x5D, 0x69, 0x5E, 0x66, 0x5B, 0x6B, 0x62, 0x6E, 0x66, 0x6E, 0x64, 0x6D, 0x64, 0x6A, 0x60, 0x68, 0x5F, 0x6C, 0x5F, 0x69, 0x5D, 0x6A, 0x5F, 0x69, 0x5F, 0x69, 0x5D, 0x68, 0x5A, 0x66, 0x5D, 0x67, 0x5E, 0x69, 0x5F, 0x6D, 0x60, 0x66, 0x5D, 0x67, 0x5D, 0x68, 0x5D, 0x65, 0x5B, 0x67, 0x5D, 0x66, 0x5C, 0x6A, 0x5F, 0x6B, 0x60, 0x66, 0x5C, 0x63, 0x58, 0x67, 0x5D, 0x65, 0x5A, 0x63, 0x58, 0x62, 0x57, 0x63, 0x58, 0x67, 0x5B, 0x5B, 0x52, 0x45, 0x49, 0x2F, 0x31, 0x35, 0x3B, 0x2A, 0x2D, 0x2E, 0x37, 0x32, 0x35, 0x2E, 0x35, 0x38, 0x3E, 0x3E, 0x47, 0x3D, 0x45, 0x40, 0x49, 0x48, 0x54, 0x40, 0x47, 0x38, 0x3C, 0x32, 0x38, 0x31, 0x37, 0x48, 0x5E, 0x62, 0x7D, 0x62, 0x7B, 0x69, 0x85, 0x6C, 0x8A, 0x6F, 0x8D, 0x68, 0x7E, 0x3A, 0x3E, 0x38, 0x42, 0x32, 0x38, 0x4E, 0x6B, 0x72, 0x92, 0x75, 0x94, 0x75, 0x92, 0x71, 0x8F, 0x71, 0x8D, 0x69, 0x80, 0x33, 0x34, 0x27, 0x2E, 0x2D, 0x31, 0x3B, 0x4F, 0x5A, 0x6F, 0x54, 0x67, 0x4E, 0x5F, 0x48, 0x57, 0x42, 0x4E, 0x3A, 0x44, 0x26, 0x27, 0x22, 0x28, 0x30, 0x38, 0x34, 0x3B
    },

    {
        0x59, 0x20, 0x59, 0x1F, 0x59, 0x20, 0x5A, 0x20, 0x5B, 0x20, 0x5D, 0x20, 0x5C, 0x20, 0x5A, 0x21, 0x5B, 0x20, 0x5B, 0x20, 0x5C, 0x21, 0x5C, 0x20, 0x5B, 0x21, 0x5C, 0x22, 0x5D, 0x21, 0x5E, 0x22, 0x5E, 0x23, 0x5E, 0x22, 0x5C, 0x21, 0x5C, 0x21, 0x5C, 0x21, 0x5E, 0x21, 0x5B, 0x22, 0x5D, 0x21, 0x5C, 0x20, 0x5B, 0x20, 0x5C, 0x21, 0x5B, 0x21, 0x5B, 0x21, 0x5B, 0x21, 0x59, 0x21, 0x5B, 0x22, 0x5C, 0x22, 0x5F, 0x22, 0x5E, 0x22, 0x5C, 0x22, 0x5D, 0x22, 0x5E, 0x24, 0x62, 0x24, 0x60, 0x24, 0x5F, 0x23, 0x59, 0x21, 0x48, 0x1E, 0x3B, 0x1C, 0x49, 0x20, 0x5D, 0x24, 0x62, 0x25, 0x5B, 0x23, 0x43, 0x1C, 0x2C, 0x17, 0x25, 0x16, 0x20, 0x14, 0x1D, 0x12, 0x1D, 0x13, 0x1E, 0x14, 0x1E, 0x14, 0x1C, 0x13, 0x1A, 0x12, 0x1B, 0x13, 0x1D, 0x14, 0x1C, 0x13, 0x1E, 0x16, 0x2F, 0x2B, 0x5D, 0x51, 0x77, 0x61, 0x7E, 0x66, 0x80, 0x69, 0x83, 0x6A, 0x86, 0x6E, 0x8B, 0x6F, 0x8C, 0x70, 0x8A, 0x6F, 0x87, 0x70, 0x88, 0x6F, 0x88, 0x6F, 0x87, 0x6D, 0x87, 0x6F, 0x89, 0x6F, 0x88, 0x6D, 0x87, 0x6E, 0x89, 0x6E, 0x88, 0x6F, 0x8A, 0x70, 0x8C, 0x71, 0x8B, 0x71, 0x8C, 0x71, 0x8A, 0x70, 0x8A, 0x71, 0x8D, 0x71, 0x8B, 0x71, 0x8B, 0x73, 0x8D, 0x71, 0x8B, 0x71, 0x89, 0x70, 0x8A, 0x70, 0x8B, 0x71, 0x89, 0x71, 0x88, 0x71, 0x87, 0x66, 0x4C, 0x2F, 0x28, 0x1B, 0x21, 0x17, 0x1E, 0x14, 0x1C, 0x13, 0x1B, 0x13, 0x1C, 0x14, 0x1E, 0x14, 0x2A, 0x1A, 0x4F, 0x23, 0x66, 0x27, 0x63, 0x27, 0x52, 0x24, 0x38, 0x1F, 0x4B, 0x22, 0x62, 0x26, 0x68, 0x28, 0x68, 0x27, 0x6A, 0x28, 0x67, 0x27, 0x6B, 0x29, 0x70, 0x2A, 0x6F, 0x2A, 0x6F, 0x29, 0x6F, 0x2A, 0x6F, 0x2A, 0x6A, 0x27, 0x66, 0x26, 0x69, 0x28, 0x6B, 0x28, 0x6C, 0x27, 0x67, 0x27, 0x69, 0x28, 0x6A, 0x28, 0x6A, 0x28, 0x6B, 0x27, 0x6A, 0x27, 0x67, 0x27, 0x68, 0x28, 0x6B, 0x2B, 0x6D, 0x2C, 0x6A, 0x29, 0x6B, 0x29, 0x6C, 0x29, 0x70, 0x2A, 0x70, 0x2A, 0x6C, 0x28, 0x6E, 0x2B, 0x6F, 0x2B, 0x6D, 0x29, 0x6D, 0x28, 0x6D, 0x28, 0x6D, 0x29, 0x69, 0x28, 0x69, 0x27, 0x6A, 0x28, 0x68, 0x27, 0x66, 0x26, 0x6A, 0x28, 0x6C, 0x27, 0x6A, 0x27, 0x69, 0x27, 0x68, 0x27, 0x67, 0x27, 0x6A, 0x27, 0x6D, 0x28, 0x69, 0x28, 0x6B, 0x28, 0x6F, 0x29, 0x6D, 0x29, 0x71, 0x2A, 0x70, 0x2B, 0x70, 0x2B, 0x6F, 0x29, 0x6C, 0x28, 0x69, 0x26, 0x69, 0x27, 0x68, 0x26, 0x69, 0x25, 0x68, 0x25, 0x6B, 0x28, 0x6A, 0x27, 0x69, 0x26, 0x6A, 0x27, 0x6A, 0x27, 0x70, 0x29, 0x70, 0x29, 0x70, 0x2A, 0x6E, 0x2A, 0x71, 0x29, 0x69, 0x26, 0x6E, 0x29, 0x6F, 0x29, 0x6C, 0x27, 0x6A, 0x27, 0x6B, 0x28, 0x67, 0x26, 0x66, 0x25, 0x66, 0x26, 0x65, 0x25, 0x66, 0x25, 0x64, 0x25, 0x60, 0x24, 0x60, 0x24, 0x61, 0x23, 0x62, 0x24, 0x64, 0x26, 0x68, 0x27, 0x6B, 0x28, 0x66, 0x28, 0x64, 0x25, 0x60, 0x26, 0x61, 0x25, 0x60, 0x23, 0x61, 0x24, 0x62, 0x25, 0x68, 0x27, 0x6A, 0x26, 0x61, 0x24, 0x60, 0x24, 0x60, 0x24, 0x5E, 0x23, 0x62, 0x24, 0x64, 0x25, 0x63, 0x25, 0x5F, 0x23, 0x60, 0x23, 0x61, 0x25, 0x60, 0x24, 0x5E, 0x22, 0x59, 0x22, 0x5E, 0x22, 0x5B, 0x21, 0x5C, 0x21, 0x5E, 0x22, 0x5D, 0x22, 0x5A, 0x21, 0x59, 0x21, 0x5B, 0x21, 0x5B, 0x21, 0x5B, 0x22, 0x5E, 0x23, 0x5E, 0x23, 0x5F, 0x24, 0x60, 0x24, 0x5F, 0x24, 0x5F, 0x23, 0x5A, 0x22, 0x5E, 0x23, 0x5E, 0x23, 0x5E, 0x25, 0x5E, 0x23, 0x5B, 0x21, 0x59, 0x22, 0x5A, 0x22, 0x5A, 0x23, 0x5B, 0x22, 0x59, 0x21, 0x5C, 0x23, 0x5B, 0x23, 0x57, 0x21, 0x5C, 0x23, 0x5B, 0x22, 0x5C, 0x23, 0x5B, 0x23, 0x5B, 0x22, 0x59, 0x22, 0x58, 0x21, 0x56, 0x20, 0x55, 0x20, 0x5B, 0x21, 0x59, 0x22, 0x59, 0x21, 0x51, 0x21, 0x48, 0x24, 0x37, 0x1E, 0x37, 0x1D, 0x36, 0x1E, 0x45, 0x24, 0x40, 0x25, 0x68, 0x3F, 0x7E, 0x4C, 0x8B, 0x53, 0x86, 0x52, 0x90, 0x57, 0x95, 0x59, 0x70, 0x3B, 0x38, 0x1F, 0x3C, 0x20, 0x34, 0x1E, 0x70, 0x46, 0x97, 0x5C, 0x9B, 0x5E, 0x9F, 0x60, 0x9F, 0x61, 0x99, 0x5D, 0x83, 0x4A, 0x31, 0x1D, 0x34, 0x1D, 0x2B, 0x19, 0x55, 0x37, 0x7B, 0x4B, 0x74, 0x47, 0x6F, 0x44, 0x65, 0x40, 0x5E, 0x39, 0x52, 0x34, 0x2B, 0x1A, 0x2A, 0x19, 0x3C, 0x21, 0x3B, 0x21, 0x3A, 0x20, 0x25, 0x18, 0x22, 0x15, 0x23, 0x16, 0x21, 0x15, 0x24, 0x16, 0x26, 0x16, 0x2A, 0x19, 0x39, 0x1F, 0x2E, 0x1A
    },

    {
        0x66, 0x5A, 0x67, 0x59, 0x66, 0x5A, 0x68, 0x5B, 0x68, 0x5C, 0x69, 0x5C, 0x68, 0x5C, 0x68, 0x5B, 0x68, 0x5A, 0x69, 0x5B, 0x69, 0x5C, 0x6B, 0x5B, 0x6B, 0x5C, 0x6B, 0x5D, 0x6C, 0x5E, 0x6B, 0x5F, 0x6C, 0x5F, 0x6B, 0x5D, 0x6A, 0x5B, 0x69, 0x5C, 0x6B, 0x5C, 0x6C, 0x5D, 0x6A, 0x5C, 0x6B, 0x5B, 0x69, 0x5A, 0x69, 0x5A, 0x6B, 0x5C, 0x6A, 0x5B, 0x6A, 0x5B, 0x6A, 0x5D, 0x67, 0x5B, 0x69, 0x5B, 0x6B, 0x5C, 0x6C, 0x61, 0x6E, 0x5F, 0x6D, 0x5D, 0x6D, 0x5D, 0x6F, 0x61, 0x72, 0x63, 0x6E, 0x61, 0x6C, 0x62, 0x67, 0x5B, 0x59, 0x49, 0x42, 0x3A, 0x4A, 0x49, 0x61, 0x5C, 0x6C, 0x63, 0x66, 0x5C, 0x52, 0x47, 0x33, 0x2D, 0x25, 0x26, 0x20, 0x21, 0x1D, 0x1E, 0x1B, 0x1E, 0x1B, 0x1F, 0x1A, 0x1D, 0x19, 0x1C, 0x17, 0x1B, 0x17, 0x1B, 0x18, 0x1D, 0x19, 0x1C, 0x1D, 0x21, 0x2E, 0x3E, 0x51, 0x6A, 0x63, 0x78, 0x6B, 0x7E, 0x6F, 0x82, 0x72, 0x84, 0x73, 0x88, 0x77, 0x88, 0x77, 0x89, 0x76, 0x87, 0x75, 0x87, 0x75, 0x88, 0x76, 0x87, 0x75, 0x86, 0x74, 0x86, 0x74, 0x86, 0x75, 0x86, 0x75, 0x87, 0x74, 0x87, 0x75, 0x87, 0x75, 0x89, 0x77, 0x8A, 0x76, 0x8A, 0x78, 0x8C, 0x77, 0x8A, 0x77, 0x8A, 0x78, 0x8C, 0x76, 0x8A, 0x78, 0x8B, 0x78, 0x8B, 0x77, 0x8C, 0x76, 0x89, 0x76, 0x8A, 0x78, 0x8A, 0x74, 0x8B, 0x72, 0x88, 0x6C, 0x82, 0x40, 0x40, 0x22, 0x26, 0x1D, 0x21, 0x1A, 0x1E, 0x18, 0x1C, 0x18, 0x1B, 0x19, 0x1C, 0x1D, 0x20, 0x30, 0x35, 0x58, 0x5A, 0x6F, 0x6A, 0x6A, 0x62, 0x4E, 0x47, 0x3A, 0x39, 0x56, 0x56, 0x6B, 0x64, 0x72, 0x68, 0x73, 0x69, 0x77, 0x6B, 0x77, 0x6A, 0x7A, 0x6D, 0x7E, 0x73, 0x7D, 0x70, 0x78, 0x6E, 0x7C, 0x70, 0x7C, 0x70, 0x78, 0x69, 0x74, 0x66, 0x78, 0x6C, 0x76, 0x6B, 0x77, 0x69, 0x76, 0x69, 0x76, 0x69, 0x77, 0x6A, 0x79, 0x6B, 0x76, 0x6A, 0x79, 0x6D, 0x74, 0x67, 0x75, 0x6B, 0x75, 0x6D, 0x77, 0x6F, 0x78, 0x6A, 0x78, 0x6C, 0x7B, 0x6F, 0x7D, 0x70, 0x7E, 0x71, 0x7D, 0x6C, 0x7F, 0x72, 0x7B, 0x70, 0x7B, 0x6F, 0x7C, 0x6D, 0x7B, 0x6E, 0x7C, 0x6D, 0x79, 0x6B, 0x76, 0x6A, 0x78, 0x6B, 0x76, 0x6A, 0x75, 0x68, 0x78, 0x6B, 0x7A, 0x6C, 0x75, 0x68, 0x76, 0x69, 0x76, 0x69, 0x75, 0x6A, 0x7B, 0x6F, 0x7C, 0x6D, 0x79, 0x6C, 0x7B, 0x6D, 0x7F, 0x70, 0x79, 0x6D, 0x7C, 0x71, 0x7E, 0x70, 0x7E, 0x72, 0x7F, 0x70, 0x7A, 0x6D, 0x7A, 0x6A, 0x79, 0x6B, 0x77, 0x69, 0x77, 0x6D, 0x77, 0x69, 0x7B, 0x6E, 0x7A, 0x6B, 0x7C, 0x6C, 0x7C, 0x6E, 0x79, 0x6B, 0x7E, 0x70, 0x7F, 0x70, 0x7F, 0x72, 0x7C, 0x6F, 0x7E, 0x6E, 0x79, 0x6A, 0x7B, 0x71, 0x7D, 0x6F, 0x7B, 0x6D, 0x7A, 0x6C, 0x7D, 0x6F, 0x77, 0x69, 0x72, 0x65, 0x72, 0x67, 0x75, 0x67, 0x74, 0x68, 0x70, 0x66, 0x6B, 0x61, 0x6D, 0x60, 0x72, 0x63, 0x70, 0x66, 0x78, 0x68, 0x76, 0x67, 0x78, 0x6B, 0x74, 0x67, 0x72, 0x65, 0x6F, 0x64, 0x6D, 0x62, 0x6F, 0x61, 0x70, 0x62, 0x71, 0x65, 0x76, 0x69, 0x78, 0x66, 0x6E, 0x63, 0x6F, 0x63, 0x6F, 0x62, 0x6B, 0x60, 0x71, 0x65, 0x74, 0x66, 0x72, 0x66, 0x6E, 0x62, 0x6D, 0x62, 0x6E, 0x61, 0x6D, 0x61, 0x6D, 0x5E, 0x6A, 0x5D, 0x6C, 0x5F, 0x69, 0x5C, 0x6B, 0x5D, 0x6A, 0x5F, 0x6A, 0x5F, 0x67, 0x5B, 0x66, 0x5B, 0x67, 0x5B, 0x67, 0x5C, 0x69, 0x5E, 0x6A, 0x5E, 0x6C, 0x5F, 0x6D, 0x60, 0x6D, 0x61, 0x6B, 0x60, 0x6C, 0x60, 0x6A, 0x5C, 0x6A, 0x5D, 0x6B, 0x60, 0x6A, 0x60, 0x6A, 0x5E, 0x68, 0x59, 0x66, 0x5B, 0x66, 0x5C, 0x69, 0x5E, 0x66, 0x5A, 0x64, 0x59, 0x69, 0x5F, 0x6B, 0x5D, 0x64, 0x58, 0x6A, 0x5D, 0x64, 0x5B, 0x67, 0x5D, 0x68, 0x5C, 0x66, 0x5B, 0x66, 0x59, 0x66, 0x5A, 0x62, 0x58, 0x61, 0x57, 0x67, 0x5C, 0x66, 0x5B, 0x66, 0x59, 0x59, 0x50, 0x40, 0x41, 0x35, 0x38, 0x33, 0x38, 0x33, 0x3D, 0x3C, 0x43, 0x3C, 0x4A, 0x60, 0x7C, 0x71, 0x93, 0x79, 0x99, 0x77, 0x97, 0x7C, 0x9D, 0x7C, 0x9C, 0x5A, 0x61, 0x30, 0x36, 0x35, 0x3A, 0x30, 0x37, 0x5F, 0x7B, 0x76, 0x98, 0x7A, 0x9C, 0x7C, 0x9D, 0x7B, 0x9D, 0x75, 0x94, 0x61, 0x70, 0x27, 0x2A, 0x2D, 0x32, 0x29, 0x2C, 0x43, 0x5A, 0x55, 0x6A, 0x4F, 0x62, 0x49, 0x5A, 0x43, 0x50, 0x3D, 0x48, 0x35, 0x40, 0x21, 0x23, 0x29, 0x31, 0x38, 0x3D, 0x33, 0x3C, 0x2E, 0x2F, 0x1F, 0x21, 0x1E, 0x20, 0x22, 0x26, 0x21, 0x24, 0x24, 0x29, 0x26, 0x2A, 0x28, 0x2E, 0x32, 0x38, 0x29, 0x2F
    },

    {
        0x59, 0x20, 0x59, 0x1F, 0x57, 0x1F, 0x59, 0x20, 0x5A, 0x20, 0x5B, 0x20, 0x5D, 0x21, 0x5C, 0x20, 0x5D, 0x21, 0x5B, 0x20, 0x5C, 0x21, 0x5C, 0x20, 0x5E, 0x21, 0x5E, 0x21, 0x5E, 0x21, 0x5E, 0x22, 0x5D, 0x21, 0x5B, 0x21, 0x5D, 0x22, 0x5B, 0x21, 0x5C, 0x21, 0x5C, 0x21, 0x5B, 0x21, 0x5C, 0x21, 0x5A, 0x21, 0x59, 0x21, 0x5C, 0x21, 0x5D, 0x21, 0x5E, 0x21, 0x5E, 0x22, 0x5E, 0x23, 0x5B, 0x22, 0x5D, 0x22, 0x5F, 0x23, 0x60, 0x23, 0x5E, 0x22, 0x5F, 0x23, 0x61, 0x24, 0x65, 0x26, 0x66, 0x26, 0x68, 0x25, 0x63, 0x24, 0x5D, 0x22, 0x4C, 0x1E, 0x3C, 0x1D, 0x48, 0x21, 0x5B, 0x24, 0x61, 0x24, 0x5D, 0x23, 0x48, 0x1D, 0x2F, 0x18, 0x25, 0x16, 0x21, 0x14, 0x20, 0x14, 0x20, 0x14, 0x1E, 0x14, 0x1E, 0x14, 0x1C, 0x13, 0x1D, 0x14, 0x1F, 0x15, 0x1E, 0x16, 0x2E, 0x2B, 0x5F, 0x51, 0x75, 0x5F, 0x7D, 0x65, 0x7F, 0x68, 0x84, 0x6B, 0x85, 0x6D, 0x88, 0x6E, 0x88, 0x6F, 0x89, 0x70, 0x89, 0x6F, 0x8A, 0x71, 0x8A, 0x70, 0x88, 0x6D, 0x88, 0x6E, 0x87, 0x6E, 0x89, 0x6E, 0x88, 0x6F, 0x89, 0x6F, 0x85, 0x6D, 0x87, 0x6F, 0x89, 0x71, 0x8C, 0x72, 0x8C, 0x71, 0x8C, 0x71, 0x8C, 0x71, 0x8A, 0x71, 0x8C, 0x72, 0x8C, 0x71, 0x8A, 0x70, 0x8D, 0x72, 0x8D, 0x73, 0x8C, 0x72, 0x8C, 0x72, 0x8D, 0x72, 0x8D, 0x72, 0x89, 0x6E, 0x6A, 0x4A, 0x34, 0x24, 0x26, 0x1A, 0x21, 0x16, 0x1E, 0x14, 0x1C, 0x13, 0x1B, 0x12, 0x1D, 0x14, 0x27, 0x18, 0x4E, 0x22, 0x65, 0x28, 0x68, 0x28, 0x58, 0x24, 0x37, 0x1E, 0x49, 0x23, 0x63, 0x27, 0x65, 0x27, 0x65, 0x27, 0x69, 0x28, 0x6B, 0x2A, 0x6D, 0x2A, 0x70, 0x2B, 0x71, 0x2C, 0x6D, 0x29, 0x69, 0x27, 0x6A, 0x27, 0x69, 0x28, 0x6C, 0x29, 0x6C, 0x29, 0x69, 0x28, 0x69, 0x27, 0x69, 0x27, 0x6C, 0x28, 0x6A, 0x28, 0x69, 0x27, 0x67, 0x27, 0x6B, 0x27, 0x6A, 0x29, 0x6C, 0x2B, 0x6F, 0x2D, 0x6F, 0x2B, 0x6E, 0x29, 0x6B, 0x29, 0x6B, 0x28, 0x6A, 0x28, 0x6F, 0x2B, 0x71, 0x2A, 0x70, 0x29, 0x71, 0x2A, 0x70, 0x2A, 0x6D, 0x29, 0x6C, 0x28, 0x6C, 0x28, 0x6D, 0x29, 0x6E, 0x28, 0x68, 0x27, 0x6E, 0x29, 0x6C, 0x28, 0x68, 0x28, 0x66, 0x26, 0x68, 0x26, 0x67, 0x26, 0x69, 0x27, 0x66, 0x26, 0x68, 0x27, 0x70, 0x2B, 0x6C, 0x28, 0x6E, 0x28, 0x6B, 0x28, 0x6B, 0x28, 0x6A, 0x27, 0x67, 0x28, 0x6C, 0x28, 0x6C, 0x28, 0x6E, 0x28, 0x6C, 0x28, 0x6A, 0x27, 0x6C, 0x26, 0x68, 0x26, 0x68, 0x26, 0x66, 0x27, 0x6C, 0x28, 0x6E, 0x27, 0x6A, 0x26, 0x69, 0x27, 0x68, 0x26, 0x6B, 0x27, 0x68, 0x26, 0x6F, 0x29, 0x6D, 0x28, 0x6C, 0x28, 0x6E, 0x28, 0x6B, 0x27, 0x6B, 0x27, 0x6B, 0x27, 0x6B, 0x27, 0x6D, 0x28, 0x69, 0x26, 0x67, 0x25, 0x68, 0x27, 0x67, 0x27, 0x65, 0x24, 0x62, 0x25, 0x63, 0x26, 0x67, 0x26, 0x67, 0x25, 0x63, 0x25, 0x68, 0x26, 0x65, 0x25, 0x66, 0x26, 0x67, 0x27, 0x68, 0x27, 0x68, 0x27, 0x64, 0x26, 0x64, 0x25, 0x64, 0x24, 0x61, 0x24, 0x5F, 0x24, 0x61, 0x24, 0x61, 0x23, 0x63, 0x24, 0x60, 0x23, 0x62, 0x25, 0x63, 0x25, 0x63, 0x24, 0x63, 0x25, 0x5E, 0x23, 0x60, 0x25, 0x62, 0x24, 0x5C, 0x22, 0x5D, 0x22, 0x5E, 0x22, 0x5C, 0x22, 0x5D, 0x21, 0x5C, 0x21, 0x5B, 0x22, 0x5C, 0x22, 0x56, 0x20, 0x59, 0x21, 0x5A, 0x21, 0x5C, 0x22, 0x5B, 0x22, 0x5E, 0x23, 0x5D, 0x23, 0x5E, 0x23, 0x62, 0x24, 0x61, 0x25, 0x60, 0x25, 0x60, 0x25, 0x5E, 0x23, 0x5D, 0x23, 0x59, 0x22, 0x5E, 0x23, 0x58, 0x21, 0x5A, 0x22, 0x5C, 0x23, 0x60, 0x24, 0x5A, 0x21, 0x5A, 0x23, 0x5B, 0x23, 0x61, 0x27, 0x5C, 0x23, 0x5B, 0x22, 0x5A, 0x21, 0x5B, 0x22, 0x5A, 0x22, 0x5A, 0x22, 0x56, 0x21, 0x58, 0x22, 0x55, 0x20, 0x56, 0x20, 0x57, 0x21, 0x57, 0x21, 0x56, 0x21, 0x51, 0x21, 0x40, 0x22, 0x41, 0x22, 0x3B, 0x21, 0x41, 0x22, 0x39, 0x20, 0x48, 0x2E, 0x96, 0x5F, 0xA7, 0x67, 0xA7, 0x65, 0xA6, 0x65, 0xA6, 0x66, 0x9F, 0x61, 0x62, 0x35, 0x2A, 0x1A, 0x31, 0x1A, 0x2F, 0x1C, 0x5E, 0x3B, 0x74, 0x49, 0x6B, 0x44, 0x62, 0x3E, 0x58, 0x39, 0x4B, 0x31, 0x3D, 0x26, 0x23, 0x17, 0x38, 0x1E, 0x35, 0x1C, 0x42, 0x23, 0x2C, 0x18, 0x22, 0x15, 0x20, 0x15, 0x20, 0x14, 0x1D, 0x13, 0x28, 0x18, 0x22, 0x16, 0x2D, 0x1B, 0x32, 0x1A, 0x33, 0x1C, 0x2F, 0x1A, 0x2E, 0x1A, 0x2B, 0x19, 0x37, 0x1E, 0x30, 0x1A, 0x35, 0x1D, 0x2F, 0x19, 0x2C, 0x19, 0x2F, 0x1A, 0x30, 0x1A
    },

    {
        0x64, 0x59, 0x64, 0x58, 0x63, 0x57, 0x65, 0x59, 0x66, 0x5A, 0x67, 0x5A, 0x6B, 0x5D, 0x6A, 0x5D, 0x69, 0x5D, 0x68, 0x5B, 0x6A, 0x5B, 0x6A, 0x5B, 0x6C, 0x5D, 0x6B, 0x5E, 0x6C, 0x5D, 0x69, 0x5D, 0x6A, 0x5C, 0x69, 0x5B, 0x6A, 0x5C, 0x69, 0x5B, 0x69, 0x5D, 0x69, 0x5C, 0x6A, 0x5C, 0x6A, 0x5B, 0x67, 0x5A, 0x68, 0x5A, 0x6A, 0x5C, 0x6B, 0x5C, 0x6D, 0x5E, 0x6C, 0x5E, 0x6A, 0x5D, 0x6A, 0x5C, 0x6B, 0x5F, 0x6D, 0x5F, 0x6F, 0x60, 0x6D, 0x5F, 0x6F, 0x60, 0x71, 0x63, 0x73, 0x65, 0x73, 0x66, 0x75, 0x67, 0x70, 0x64, 0x6D, 0x5F, 0x61, 0x50, 0x4A, 0x3F, 0x47, 0x48, 0x5F, 0x5A, 0x6B, 0x60, 0x68, 0x5D, 0x57, 0x4B, 0x37, 0x30, 0x26, 0x25, 0x20, 0x21, 0x1E, 0x21, 0x1D, 0x1F, 0x1B, 0x1E, 0x19, 0x1D, 0x19, 0x1D, 0x19, 0x1E, 0x1A, 0x1F, 0x1B, 0x1F, 0x2B, 0x3C, 0x51, 0x6B, 0x63, 0x75, 0x69, 0x7D, 0x6C, 0x7E, 0x70, 0x82, 0x72, 0x84, 0x74, 0x86, 0x76, 0x8A, 0x76, 0x86, 0x75, 0x88, 0x77, 0x88, 0x75, 0x86, 0x75, 0x86, 0x74, 0x88, 0x75, 0x87, 0x73, 0x86, 0x74, 0x86, 0x75, 0x86, 0x73, 0x84, 0x74, 0x87, 0x76, 0x87, 0x77, 0x8A, 0x75, 0x88, 0x76, 0x8A, 0x76, 0x8B, 0x78, 0x8B, 0x78, 0x8B, 0x78, 0x8B, 0x77, 0x89, 0x77, 0x8B, 0x78, 0x8C, 0x78, 0x8B, 0x76, 0x8A, 0x77, 0x8B, 0x76, 0x8C, 0x6E, 0x84, 0x4E, 0x53, 0x29, 0x2B, 0x1F, 0x24, 0x1B, 0x20, 0x1A, 0x1E, 0x18, 0x1C, 0x19, 0x1C, 0x1C, 0x1E, 0x2D, 0x31, 0x59, 0x5A, 0x6E, 0x69, 0x6E, 0x65, 0x54, 0x4A, 0x39, 0x36, 0x54, 0x56, 0x6D, 0x67, 0x71, 0x68, 0x72, 0x68, 0x76, 0x6B, 0x77, 0x6B, 0x78, 0x6F, 0x7B, 0x70, 0x7D, 0x72, 0x79, 0x6C, 0x76, 0x69, 0x76, 0x68, 0x77, 0x6B, 0x78, 0x6D, 0x78, 0x6B, 0x74, 0x67, 0x74, 0x69, 0x76, 0x6B, 0x7A, 0x6D, 0x77, 0x6B, 0x76, 0x69, 0x74, 0x68, 0x78, 0x6C, 0x76, 0x6B, 0x77, 0x70, 0x7D, 0x74, 0x7C, 0x6E, 0x79, 0x6C, 0x77, 0x6C, 0x7A, 0x6C, 0x79, 0x6B, 0x7D, 0x70, 0x80, 0x71, 0x7E, 0x6F, 0x7D, 0x70, 0x7B, 0x70, 0x7B, 0x6D, 0x7A, 0x6B, 0x78, 0x6C, 0x7A, 0x6E, 0x7C, 0x6D, 0x74, 0x69, 0x7B, 0x6E, 0x79, 0x6C, 0x76, 0x6A, 0x75, 0x69, 0x77, 0x6A, 0x76, 0x68, 0x78, 0x6A, 0x73, 0x66, 0x74, 0x69, 0x7A, 0x70, 0x7A, 0x6B, 0x7E, 0x6F, 0x79, 0x6A, 0x7A, 0x6D, 0x77, 0x6A, 0x75, 0x6B, 0x7C, 0x6D, 0x79, 0x6B, 0x7D, 0x6D, 0x7B, 0x70, 0x79, 0x69, 0x7B, 0x6C, 0x78, 0x6A, 0x77, 0x6B, 0x73, 0x67, 0x7A, 0x6F, 0x7E, 0x6D, 0x7B, 0x6B, 0x78, 0x69, 0x77, 0x6A, 0x7C, 0x6D, 0x7A, 0x6B, 0x80, 0x74, 0x7B, 0x6E, 0x7B, 0x6E, 0x7A, 0x6D, 0x7A, 0x6C, 0x7A, 0x6C, 0x79, 0x6A, 0x78, 0x6C, 0x7C, 0x6E, 0x78, 0x6A, 0x76, 0x67, 0x77, 0x69, 0x74, 0x68, 0x73, 0x65, 0x71, 0x66, 0x73, 0x69, 0x77, 0x6A, 0x74, 0x68, 0x71, 0x62, 0x77, 0x69, 0x76, 0x65, 0x73, 0x66, 0x73, 0x68, 0x78, 0x6A, 0x75, 0x69, 0x72, 0x66, 0x70, 0x64, 0x71, 0x64, 0x6F, 0x62, 0x6D, 0x61, 0x6E, 0x61, 0x6E, 0x64, 0x71, 0x64, 0x6C, 0x61, 0x6D, 0x63, 0x71, 0x64, 0x73, 0x64, 0x70, 0x63, 0x6B, 0x60, 0x6A, 0x60, 0x6D, 0x61, 0x68, 0x5C, 0x6D, 0x61, 0x6B, 0x60, 0x6A, 0x5C, 0x6C, 0x5E, 0x6A, 0x5D, 0x69, 0x5D, 0x67, 0x5C, 0x66, 0x59, 0x67, 0x5B, 0x66, 0x5B, 0x66, 0x5C, 0x69, 0x5E, 0x6B, 0x61, 0x6B, 0x5F, 0x6B, 0x60, 0x70, 0x65, 0x6F, 0x63, 0x6C, 0x62, 0x6D, 0x63, 0x69, 0x60, 0x68, 0x5C, 0x66, 0x5C, 0x6A, 0x5F, 0x64, 0x59, 0x66, 0x5C, 0x6B, 0x60, 0x6C, 0x63, 0x68, 0x5C, 0x66, 0x5D, 0x67, 0x5D, 0x6A, 0x62, 0x6A, 0x5F, 0x69, 0x5C, 0x67, 0x5B, 0x67, 0x5C, 0x67, 0x5D, 0x65, 0x5B, 0x61, 0x56, 0x67, 0x5A, 0x61, 0x57, 0x63, 0x57, 0x64, 0x58, 0x65, 0x58, 0x64, 0x5A, 0x59, 0x50, 0x3E, 0x42, 0x39, 0x3B, 0x35, 0x3E, 0x38, 0x3F, 0x31, 0x36, 0x40, 0x55, 0x75, 0x9B, 0x80, 0xA4, 0x81, 0xA4, 0x7E, 0xA2, 0x7D, 0x9E, 0x77, 0x94, 0x46, 0x48, 0x26, 0x2B, 0x2C, 0x2D, 0x2E, 0x35, 0x4A, 0x5D, 0x4F, 0x5F, 0x44, 0x53, 0x3D, 0x4B, 0x36, 0x3F, 0x2F, 0x36, 0x25, 0x29, 0x1F, 0x23, 0x35, 0x3E, 0x2F, 0x33, 0x39, 0x41, 0x25, 0x26, 0x20, 0x22, 0x1F, 0x21, 0x20, 0x23, 0x1D, 0x1F, 0x26, 0x2C, 0x21, 0x23, 0x29, 0x31, 0x2C, 0x2E, 0x2E, 0x35, 0x2E, 0x32, 0x2F, 0x34, 0x29, 0x2E, 0x32, 0x37, 0x2C, 0x30, 0x2D, 0x34, 0x29, 0x2D, 0x2A, 0x2E, 0x2D, 0x33, 0x2E, 0x35
    },

    {
        0x57, 0x20, 0x57, 0x1F, 0x58, 0x1F, 0x59, 0x20, 0x59, 0x20, 0x5A, 0x21, 0x5B, 0x21, 0x5B, 0x20, 0x59, 0x1F, 0x5B, 0x20, 0x5A, 0x21, 0x5A, 0x20, 0x5C, 0x21, 0x5E, 0x22, 0x5F, 0x22, 0x5D, 0x21, 0x5A, 0x21, 0x5C, 0x22, 0x5C, 0x22, 0x5C, 0x21, 0x5B, 0x21, 0x5B, 0x22, 0x5D, 0x22, 0x5A, 0x21, 0x5A, 0x21, 0x5A, 0x20, 0x5B, 0x21, 0x5F, 0x22, 0x5F, 0x22, 0x5E, 0x21, 0x5B, 0x20, 0x5E, 0x22, 0x5E, 0x21, 0x5E, 0x22, 0x5F, 0x23, 0x60, 0x23, 0x62, 0x24, 0x64, 0x25, 0x63, 0x24, 0x64, 0x25, 0x67, 0x26, 0x67, 0x26, 0x64, 0x24, 0x60, 0x23, 0x55, 0x20, 0x41, 0x1D, 0x42, 0x1F, 0x56, 0x22, 0x5F, 0x24, 0x5D, 0x23, 0x4D, 0x1E, 0x32, 0x18, 0x24, 0x15, 0x20, 0x14, 0x20, 0x14, 0x1F, 0x14, 0x1D, 0x13, 0x1D, 0x14, 0x1F, 0x16, 0x20, 0x16, 0x25, 0x22, 0x4F, 0x47, 0x6D, 0x5B, 0x76, 0x62, 0x7D, 0x67, 0x80, 0x68, 0x87, 0x6C, 0x88, 0x6D, 0x88, 0x6E, 0x88, 0x70, 0x87, 0x6F, 0x87, 0x6D, 0x87, 0x6F, 0x89, 0x6F, 0x88, 0x6F, 0x89, 0x6F, 0x8B, 0x71, 0x88, 0x6F, 0x88, 0x6E, 0x8A, 0x70, 0x8B, 0x71, 0x88, 0x6F, 0x8D, 0x73, 0x8A, 0x72, 0x88, 0x70, 0x8B, 0x70, 0x8A, 0x71, 0x8A, 0x71, 0x8C, 0x72, 0x8C, 0x73, 0x8C, 0x72, 0x8C, 0x71, 0x8B, 0x72, 0x8A, 0x6F, 0x88, 0x6F, 0x89, 0x70, 0x88, 0x6E, 0x68, 0x4A, 0x37, 0x26, 0x27, 0x1C, 0x21, 0x17, 0x20, 0x15, 0x1E, 0x15, 0x1E, 0x14, 0x1E, 0x15, 0x26, 0x18, 0x49, 0x21, 0x61, 0x26, 0x64, 0x26, 0x58, 0x25, 0x37, 0x1E, 0x46, 0x21, 0x60, 0x26, 0x66, 0x29, 0x6B, 0x2A, 0x67, 0x27, 0x68, 0x2A, 0x71, 0x2E, 0x6D, 0x2A, 0x6C, 0x28, 0x6B, 0x28, 0x69, 0x28, 0x6E, 0x2A, 0x68, 0x28, 0x69, 0x28, 0x68, 0x27, 0x6B, 0x28, 0x6A, 0x29, 0x6D, 0x28, 0x69, 0x28, 0x68, 0x27, 0x6A, 0x28, 0x6A, 0x27, 0x69, 0x27, 0x6E, 0x2C, 0x72, 0x2E, 0x70, 0x2C, 0x73, 0x2C, 0x70, 0x2B, 0x6A, 0x27, 0x6C, 0x2A, 0x6C, 0x29, 0x6E, 0x29, 0x6B, 0x29, 0x6C, 0x28, 0x6E, 0x28, 0x6B, 0x28, 0x6C, 0x29, 0x6D, 0x2A, 0x6F, 0x2A, 0x6D, 0x29, 0x6E, 0x29, 0x6C, 0x28, 0x69, 0x28, 0x6D, 0x29, 0x6C, 0x29, 0x6D, 0x28, 0x6A, 0x27, 0x6B, 0x27, 0x67, 0x27, 0x69, 0x27, 0x68, 0x26, 0x67, 0x26, 0x64, 0x26, 0x66, 0x27, 0x69, 0x27, 0x65, 0x25, 0x6A, 0x26, 0x67, 0x27, 0x69, 0x28, 0x6B, 0x29, 0x6C, 0x28, 0x6E, 0x29, 0x6C, 0x28, 0x67, 0x26, 0x67, 0x26, 0x6D, 0x27, 0x6D, 0x28, 0x69, 0x27, 0x67, 0x25, 0x68, 0x26, 0x6B, 0x27, 0x67, 0x25, 0x6B, 0x27, 0x6C, 0x28, 0x6F, 0x29, 0x6F, 0x29, 0x6A, 0x27, 0x6A, 0x26, 0x69, 0x27, 0x69, 0x26, 0x6C, 0x27, 0x67, 0x25, 0x67, 0x26, 0x6D, 0x28, 0x6C, 0x27, 0x6C, 0x28, 0x68, 0x27, 0x65, 0x26, 0x68, 0x27, 0x65, 0x26, 0x69, 0x28, 0x6B, 0x28, 0x66, 0x27, 0x65, 0x25, 0x66, 0x26, 0x67, 0x26, 0x66, 0x27, 0x64, 0x25, 0x67, 0x26, 0x63, 0x25, 0x68, 0x27, 0x66, 0x25, 0x61, 0x24, 0x62, 0x25, 0x5D, 0x23, 0x5F, 0x23, 0x63, 0x25, 0x64, 0x26, 0x64, 0x26, 0x61, 0x24, 0x61, 0x24, 0x5F, 0x23, 0x62, 0x24, 0x61, 0x24, 0x5B, 0x23, 0x5E, 0x23, 0x5E, 0x23, 0x5D, 0x22, 0x5B, 0x22, 0x5A, 0x21, 0x5A, 0x21, 0x5E, 0x23, 0x5E, 0x22, 0x5E, 0x23, 0x5A, 0x21, 0x5C, 0x22, 0x5D, 0x23, 0x5B, 0x22, 0x60, 0x24, 0x60, 0x25, 0x5F, 0x25, 0x64, 0x27, 0x62, 0x24, 0x61, 0x25, 0x5F, 0x24, 0x62, 0x24, 0x5F, 0x24, 0x5A, 0x22, 0x5A, 0x23, 0x5D, 0x24, 0x5F, 0x24, 0x5D, 0x22, 0x5D, 0x23, 0x5C, 0x23, 0x5C, 0x24, 0x60, 0x25, 0x5C, 0x22, 0x5A, 0x23, 0x5A, 0x22, 0x5C, 0x23, 0x61, 0x24, 0x5A, 0x22, 0x5D, 0x24, 0x5A, 0x22, 0x58, 0x21, 0x59, 0x21, 0x57, 0x21, 0x56, 0x21, 0x59, 0x21, 0x57, 0x21, 0x5E, 0x23, 0x54, 0x22, 0x43, 0x22, 0x36, 0x1E, 0x37, 0x1E, 0x39, 0x1F, 0x2D, 0x1A, 0x44, 0x2B, 0x74, 0x47, 0x68, 0x42, 0x5A, 0x3B, 0x4F, 0x35, 0x48, 0x2F, 0x3B, 0x27, 0x27, 0x19, 0x25, 0x17, 0x3A, 0x1E, 0x3A, 0x1E, 0x3C, 0x20, 0x2A, 0x17, 0x22, 0x15, 0x1F, 0x14, 0x21, 0x14, 0x21, 0x14, 0x26, 0x17, 0x21, 0x15, 0x36, 0x1D, 0x2E, 0x19, 0x3C, 0x1E, 0x2D, 0x1A, 0x30, 0x1A, 0x2E, 0x1A, 0x33, 0x1D, 0x2C, 0x1A, 0x35, 0x1D, 0x33, 0x1C, 0x39, 0x1E, 0x38, 0x1D, 0x3C, 0x21, 0x3F, 0x21, 0x37, 0x1D, 0x32, 0x1C, 0x33, 0x1B, 0x32, 0x1B, 0x34, 0x1D, 0x3A, 0x1E, 0x35, 0x1D, 0x3C, 0x1F, 0x38, 0x1F
    },

    {
        0x65, 0x58, 0x64, 0x58, 0x63, 0x58, 0x67, 0x5B, 0x67, 0x5A, 0x69, 0x5C, 0x68, 0x5C, 0x68, 0x5B, 0x68, 0x5A, 0x69, 0x5A, 0x67, 0x5B, 0x68, 0x5C, 0x6B, 0x5D, 0x6C, 0x5E, 0x6C, 0x60, 0x6A, 0x5C, 0x69, 0x5C, 0x6A, 0x5C, 0x6A, 0x5D, 0x6A, 0x5D, 0x6B, 0x5D, 0x6A, 0x5D, 0x6A, 0x5D, 0x67, 0x5B, 0x68, 0x5B, 0x68, 0x5C, 0x69, 0x5B, 0x6B, 0x5F, 0x6E, 0x5F, 0x6C, 0x5E, 0x6B, 0x5C, 0x6D, 0x60, 0x6C, 0x5D, 0x6D, 0x61, 0x6E, 0x61, 0x6F, 0x62, 0x73, 0x65, 0x74, 0x65, 0x73, 0x64, 0x74, 0x64, 0x74, 0x66, 0x76, 0x67, 0x73, 0x64, 0x70, 0x62, 0x65, 0x57, 0x4F, 0x42, 0x43, 0x41, 0x56, 0x55, 0x69, 0x5F, 0x69, 0x5E, 0x5C, 0x51, 0x3E, 0x35, 0x27, 0x25, 0x21, 0x22, 0x1E, 0x21, 0x1D, 0x1F, 0x1A, 0x1D, 0x19, 0x1D, 0x1A, 0x1F, 0x1B, 0x20, 0x20, 0x2C, 0x41, 0x5A, 0x59, 0x6E, 0x62, 0x76, 0x6A, 0x7D, 0x6E, 0x82, 0x74, 0x87, 0x74, 0x87, 0x75, 0x88, 0x76, 0x87, 0x74, 0x88, 0x74, 0x87, 0x76, 0x88, 0x76, 0x88, 0x75, 0x87, 0x75, 0x88, 0x76, 0x88, 0x75, 0x88, 0x76, 0x88, 0x77, 0x88, 0x76, 0x89, 0x75, 0x87, 0x77, 0x8C, 0x78, 0x8B, 0x75, 0x88, 0x77, 0x89, 0x77, 0x89, 0x76, 0x8A, 0x77, 0x8B, 0x78, 0x8C, 0x77, 0x89, 0x79, 0x8A, 0x78, 0x8A, 0x76, 0x88, 0x75, 0x89, 0x73, 0x8A, 0x6F, 0x82, 0x50, 0x52, 0x2C, 0x2E, 0x21, 0x24, 0x1D, 0x21, 0x1B, 0x1F, 0x19, 0x1E, 0x1B, 0x1E, 0x1D, 0x20, 0x2B, 0x30, 0x55, 0x57, 0x6A, 0x65, 0x6A, 0x62, 0x56, 0x4B, 0x3A, 0x37, 0x53, 0x55, 0x6C, 0x64, 0x70, 0x67, 0x74, 0x6C, 0x77, 0x68, 0x75, 0x6C, 0x7B, 0x73, 0x79, 0x6D, 0x77, 0x6B, 0x79, 0x6C, 0x77, 0x6A, 0x79, 0x6F, 0x76, 0x6B, 0x77, 0x6A, 0x75, 0x68, 0x75, 0x6D, 0x75, 0x6D, 0x77, 0x6B, 0x76, 0x6A, 0x76, 0x69, 0x75, 0x6C, 0x78, 0x6C, 0x74, 0x6A, 0x77, 0x70, 0x78, 0x71, 0x79, 0x71, 0x7F, 0x74, 0x7E, 0x72, 0x77, 0x6A, 0x7B, 0x6D, 0x7C, 0x6E, 0x7C, 0x6E, 0x7B, 0x6D, 0x7B, 0x6C, 0x7C, 0x6D, 0x7B, 0x6E, 0x7A, 0x6E, 0x7C, 0x71, 0x7E, 0x70, 0x7A, 0x6F, 0x7B, 0x6E, 0x79, 0x6B, 0x79, 0x6D, 0x7E, 0x70, 0x7A, 0x6D, 0x7C, 0x6F, 0x7B, 0x6D, 0x79, 0x6D, 0x77, 0x6B, 0x77, 0x69, 0x76, 0x6A, 0x75, 0x67, 0x75, 0x68, 0x75, 0x67, 0x7A, 0x6C, 0x77, 0x6A, 0x7A, 0x6C, 0x75, 0x68, 0x77, 0x6B, 0x77, 0x6C, 0x78, 0x6D, 0x7E, 0x6E, 0x7B, 0x6F, 0x7A, 0x6B, 0x78, 0x6A, 0x7E, 0x6F, 0x7D, 0x6E, 0x78, 0x6C, 0x78, 0x69, 0x77, 0x68, 0x79, 0x6B, 0x77, 0x6B, 0x7B, 0x6D, 0x7E, 0x70, 0x7C, 0x6F, 0x7A, 0x6C, 0x7A, 0x6A, 0x77, 0x6A, 0x7A, 0x6C, 0x75, 0x68, 0x78, 0x6C, 0x76, 0x69, 0x78, 0x6B, 0x7E, 0x71, 0x7B, 0x6D, 0x7C, 0x6D, 0x76, 0x67, 0x71, 0x66, 0x78, 0x6A, 0x74, 0x68, 0x78, 0x6B, 0x7B, 0x6B, 0x74, 0x68, 0x73, 0x66, 0x73, 0x69, 0x77, 0x69, 0x76, 0x67, 0x72, 0x65, 0x72, 0x68, 0x6F, 0x65, 0x73, 0x69, 0x73, 0x65, 0x70, 0x64, 0x70, 0x64, 0x6A, 0x5E, 0x6B, 0x61, 0x70, 0x65, 0x6E, 0x62, 0x70, 0x64, 0x6C, 0x61, 0x6E, 0x63, 0x6D, 0x60, 0x70, 0x65, 0x71, 0x64, 0x68, 0x5E, 0x6A, 0x60, 0x6D, 0x61, 0x6B, 0x5D, 0x6B, 0x5E, 0x6A, 0x5E, 0x6A, 0x5D, 0x6C, 0x61, 0x6A, 0x5D, 0x6B, 0x5F, 0x69, 0x5C, 0x68, 0x5F, 0x6B, 0x60, 0x68, 0x5E, 0x6E, 0x60, 0x6E, 0x61, 0x6A, 0x63, 0x6C, 0x64, 0x6A, 0x62, 0x6E, 0x63, 0x6E, 0x62, 0x6D, 0x62, 0x6B, 0x60, 0x67, 0x5F, 0x66, 0x5C, 0x6A, 0x60, 0x6B, 0x62, 0x6C, 0x60, 0x69, 0x5B, 0x67, 0x5D, 0x68, 0x5E, 0x6C, 0x60, 0x6A, 0x5C, 0x66, 0x5C, 0x69, 0x5D, 0x68, 0x5D, 0x6B, 0x60, 0x66, 0x5D, 0x67, 0x5E, 0x66, 0x5C, 0x65, 0x59, 0x66, 0x59, 0x64, 0x59, 0x63, 0x5A, 0x67, 0x5A, 0x64, 0x59, 0x6B, 0x60, 0x5A, 0x51, 0x3F, 0x41, 0x33, 0x35, 0x33, 0x3A, 0x34, 0x39, 0x29, 0x2F, 0x3C, 0x49, 0x54, 0x63, 0x42, 0x4E, 0x39, 0x44, 0x31, 0x39, 0x2B, 0x32, 0x27, 0x29, 0x1E, 0x1F, 0x22, 0x2A, 0x34, 0x3A, 0x32, 0x37, 0x36, 0x3E, 0x27, 0x26, 0x23, 0x25, 0x1F, 0x21, 0x22, 0x25, 0x21, 0x23, 0x24, 0x29, 0x21, 0x25, 0x2F, 0x36, 0x28, 0x2D, 0x33, 0x38, 0x29, 0x2F, 0x2D, 0x30, 0x2B, 0x33, 0x2F, 0x34, 0x2A, 0x2F, 0x31, 0x38, 0x31, 0x37, 0x35, 0x3E, 0x33, 0x38, 0x37, 0x41, 0x38, 0x40, 0x2F, 0x32, 0x2E, 0x35, 0x2F, 0x34, 0x2F, 0x32, 0x31, 0x3A, 0x34, 0x3A, 0x2F, 0x36, 0x33, 0x38, 0x33, 0x3D
    },

    {
        0x59, 0x20, 0x58, 0x1F, 0x5A, 0x20, 0x5A, 0x20, 0x5A, 0x20, 0x5A, 0x20, 0x5A, 0x20, 0x5B, 0x20, 0x59, 0x20, 0x59, 0x20, 0x5A, 0x21, 0x5B, 0x20, 0x5E, 0x22, 0x5E, 0x22, 0x5C, 0x22, 0x5B, 0x22, 0x5B, 0x21, 0x5B, 0x22, 0x5D, 0x22, 0x5F, 0x23, 0x5D, 0x22, 0x5E, 0x23, 0x5D, 0x23, 0x5B, 0x21, 0x5B, 0x21, 0x5C, 0x21, 0x5C, 0x22, 0x5E, 0x22, 0x5C, 0x21, 0x5D, 0x21, 0x5E, 0x22, 0x5F, 0x22, 0x5E, 0x22, 0x5E, 0x23, 0x63, 0x25, 0x64, 0x26, 0x64, 0x25, 0x64, 0x25, 0x63, 0x24, 0x61, 0x24, 0x65, 0x24, 0x66, 0x25, 0x66, 0x25, 0x66, 0x25, 0x63, 0x24, 0x5B, 0x22, 0x45, 0x1D, 0x3D, 0x1E, 0x52, 0x22, 0x61, 0x24, 0x5F, 0x23, 0x51, 0x1F, 0x37, 0x18, 0x26, 0x15, 0x22, 0x15, 0x20, 0x14, 0x1E, 0x13, 0x1E, 0x15, 0x1F, 0x15, 0x1E, 0x14, 0x25, 0x21, 0x45, 0x40, 0x68, 0x57, 0x77, 0x60, 0x7E, 0x67, 0x81, 0x6A, 0x85, 0x6C, 0x87, 0x6E, 0x87, 0x6E, 0x8A, 0x6F, 0x87, 0x6F, 0x88, 0x6F, 0x89, 0x6F, 0x87, 0x6E, 0x88, 0x6E, 0x88, 0x6E, 0x87, 0x70, 0x88, 0x6F, 0x88, 0x6F, 0x8C, 0x71, 0x89, 0x70, 0x8A, 0x71, 0x8D, 0x73, 0x8B, 0x70, 0x89, 0x6F, 0x8A, 0x70, 0x89, 0x71, 0x8C, 0x72, 0x8C, 0x73, 0x8A, 0x70, 0x8A, 0x70, 0x8D, 0x72, 0x8D, 0x71, 0x87, 0x6E, 0x86, 0x70, 0x89, 0x6D, 0x6A, 0x4B, 0x37, 0x27, 0x26, 0x1B, 0x21, 0x17, 0x1F, 0x16, 0x1F, 0x16, 0x1F, 0x15, 0x1F, 0x16, 0x28, 0x19, 0x4E, 0x24, 0x61, 0x27, 0x63, 0x27, 0x54, 0x23, 0x38, 0x1E, 0x4B, 0x23, 0x62, 0x27, 0x66, 0x27, 0x69, 0x27, 0x69, 0x28, 0x6E, 0x29, 0x6A, 0x28, 0x68, 0x28, 0x6B, 0x28, 0x6D, 0x29, 0x6E, 0x2A, 0x6D, 0x29, 0x68, 0x28, 0x65, 0x28, 0x69, 0x28, 0x6B, 0x29, 0x69, 0x28, 0x65, 0x27, 0x6A, 0x27, 0x68, 0x27, 0x6A, 0x28, 0x69, 0x27, 0x69, 0x2A, 0x6D, 0x2C, 0x6A, 0x2A, 0x6E, 0x2B, 0x6E, 0x2B, 0x73, 0x2B, 0x6F, 0x2A, 0x68, 0x28, 0x6C, 0x28, 0x6D, 0x28, 0x6C, 0x29, 0x6B, 0x28, 0x6B, 0x28, 0x6E, 0x29, 0x6B, 0x29, 0x70, 0x2A, 0x6E, 0x2A, 0x6E, 0x2A, 0x69, 0x28, 0x6C, 0x29, 0x6B, 0x29, 0x6E, 0x2A, 0x6D, 0x29, 0x6C, 0x29, 0x6C, 0x29, 0x6B, 0x29, 0x6D, 0x28, 0x6A, 0x28, 0x66, 0x26, 0x6B, 0x28, 0x6A, 0x27, 0x6E, 0x2A, 0x68, 0x26, 0x6C, 0x28, 0x6A, 0x28, 0x70, 0x2A, 0x6E, 0x29, 0x68, 0x27, 0x6A, 0x28, 0x69, 0x28, 0x6B, 0x27, 0x6A, 0x27, 0x68, 0x26, 0x69, 0x25, 0x68, 0x26, 0x69, 0x26, 0x6A, 0x27, 0x6B, 0x27, 0x66, 0x26, 0x67, 0x26, 0x66, 0x25, 0x65, 0x25, 0x65, 0x25, 0x67, 0x26, 0x69, 0x27, 0x6B, 0x27, 0x66, 0x26, 0x6D, 0x28, 0x6B, 0x28, 0x69, 0x28, 0x6F, 0x2B, 0x72, 0x2B, 0x77, 0x2C, 0x6E, 0x29, 0x6C, 0x28, 0x6C, 0x28, 0x66, 0x26, 0x67, 0x27, 0x67, 0x26, 0x66, 0x25, 0x67, 0x27, 0x67, 0x26, 0x63, 0x25, 0x67, 0x26, 0x65, 0x26, 0x64, 0x25, 0x65, 0x26, 0x66, 0x27, 0x62, 0x25, 0x61, 0x25, 0x60, 0x24, 0x5E, 0x24, 0x5F, 0x24, 0x5F, 0x23, 0x60, 0x25, 0x61, 0x24, 0x5E, 0x24, 0x5F, 0x24, 0x62, 0x25, 0x5F, 0x24, 0x61, 0x24, 0x5F, 0x24, 0x60, 0x23, 0x5F, 0x24, 0x5D, 0x23, 0x5E, 0x23, 0x5F, 0x23, 0x5F, 0x23, 0x5E, 0x23, 0x5D, 0x22, 0x5E, 0x23, 0x5E, 0x23, 0x5F, 0x24, 0x5E, 0x23, 0x5C, 0x22, 0x5E, 0x23, 0x5E, 0x22, 0x5C, 0x23, 0x5F, 0x24, 0x62, 0x26, 0x5F, 0x24, 0x60, 0x24, 0x5E, 0x24, 0x5E, 0x25, 0x5C, 0x24, 0x61, 0x25, 0x60, 0x25, 0x5E, 0x24, 0x5D, 0x23, 0x5F, 0x24, 0x5F, 0x24, 0x62, 0x25, 0x5D, 0x24, 0x5B, 0x23, 0x5B, 0x22, 0x5E, 0x24, 0x59, 0x22, 0x5C, 0x23, 0x5A, 0x22, 0x5A, 0x23, 0x59, 0x22, 0x59, 0x22, 0x59, 0x23, 0x5D, 0x23, 0x5B, 0x22, 0x59, 0x21, 0x59, 0x22, 0x5B, 0x22, 0x59, 0x22, 0x5F, 0x24, 0x4F, 0x20, 0x42, 0x22, 0x33, 0x1C, 0x38, 0x1F, 0x3B, 0x21, 0x32, 0x1C, 0x41, 0x23, 0x34, 0x1C, 0x26, 0x17, 0x23, 0x16, 0x26, 0x17, 0x26, 0x17, 0x2D, 0x19, 0x27, 0x18, 0x2E, 0x1C, 0x37, 0x1D, 0x2B, 0x19, 0x38, 0x1E, 0x2B, 0x19, 0x34, 0x1C, 0x2A, 0x19, 0x31, 0x1B, 0x2B, 0x19, 0x32, 0x1C, 0x30, 0x1B, 0x37, 0x1C, 0x35, 0x1D, 0x3F, 0x23, 0x34, 0x1C, 0x3F, 0x21, 0x37, 0x1D, 0x3D, 0x20, 0x35, 0x1D, 0x40, 0x22, 0x36, 0x1D, 0x37, 0x1E, 0x31, 0x1B, 0x36, 0x1D, 0x30, 0x1B, 0x2A, 0x18, 0x30, 0x1B, 0x37, 0x1F, 0x34, 0x1C, 0x3D, 0x20, 0x30, 0x1A, 0x2D, 0x1A, 0x33, 0x1C, 0x3C, 0x20
    },

    {
        0x65, 0x5A, 0x64, 0x59, 0x65, 0x58, 0x66, 0x5A, 0x67, 0x5A, 0x66, 0x5A, 0x67, 0x5A, 0x67, 0x5B, 0x67, 0x5A, 0x67, 0x5B, 0x68, 0x5A, 0x68, 0x5A, 0x6C, 0x5F, 0x6B, 0x5D, 0x6A, 0x5E, 0x69, 0x5D, 0x6A, 0x5C, 0x6A, 0x5D, 0x6B, 0x5D, 0x6C, 0x5E, 0x6A, 0x5D, 0x6C, 0x5F, 0x6D, 0x5E, 0x6A, 0x5C, 0x6A, 0x5B, 0x69, 0x5C, 0x6A, 0x5D, 0x6D, 0x5E, 0x6C, 0x5D, 0x6D, 0x5F, 0x6E, 0x5F, 0x6E, 0x5F, 0x6D, 0x5E, 0x6C, 0x5F, 0x72, 0x66, 0x75, 0x67, 0x74, 0x65, 0x72, 0x64, 0x74, 0x63, 0x71, 0x61, 0x75, 0x65, 0x77, 0x68, 0x77, 0x67, 0x77, 0x65, 0x72, 0x66, 0x6B, 0x5E, 0x56, 0x47, 0x42, 0x3D, 0x51, 0x50, 0x66, 0x5F, 0x69, 0x5F, 0x5D, 0x52, 0x45, 0x3B, 0x2A, 0x28, 0x22, 0x23, 0x1F, 0x21, 0x1D, 0x1F, 0x1B, 0x1F, 0x1B, 0x1F, 0x1A, 0x1D, 0x1D, 0x24, 0x2F, 0x42, 0x4F, 0x68, 0x60, 0x75, 0x66, 0x7B, 0x6D, 0x80, 0x72, 0x84, 0x74, 0x86, 0x75, 0x86, 0x75, 0x89, 0x76, 0x88, 0x76, 0x89, 0x77, 0x88, 0x75, 0x87, 0x75, 0x88, 0x76, 0x87, 0x75, 0x87, 0x75, 0x86, 0x74, 0x87, 0x77, 0x8A, 0x75, 0x88, 0x76, 0x88, 0x77, 0x8B, 0x75, 0x89, 0x75, 0x88, 0x78, 0x8A, 0x76, 0x8A, 0x79, 0x8B, 0x78, 0x8A, 0x76, 0x88, 0x76, 0x88, 0x77, 0x8C, 0x77, 0x8A, 0x75, 0x87, 0x72, 0x85, 0x6F, 0x85, 0x51, 0x53, 0x2C, 0x2E, 0x22, 0x25, 0x1C, 0x20, 0x1B, 0x1F, 0x1B, 0x20, 0x1B, 0x1F, 0x1E, 0x21, 0x2B, 0x32, 0x58, 0x5C, 0x6B, 0x67, 0x6C, 0x64, 0x52, 0x48, 0x3A, 0x39, 0x56, 0x57, 0x6D, 0x65, 0x74, 0x6A, 0x76, 0x6B, 0x77, 0x6C, 0x79, 0x6E, 0x77, 0x6A, 0x76, 0x67, 0x78, 0x6C, 0x7B, 0x6D, 0x7B, 0x71, 0x78, 0x6B, 0x75, 0x69, 0x74, 0x6A, 0x76, 0x6C, 0x77, 0x6B, 0x73, 0x69, 0x73, 0x68, 0x78, 0x6C, 0x75, 0x69, 0x77, 0x6A, 0x77, 0x69, 0x75, 0x6D, 0x76, 0x6E, 0x77, 0x6D, 0x7A, 0x6D, 0x7A, 0x70, 0x7B, 0x6F, 0x7B, 0x6F, 0x78, 0x6D, 0x7D, 0x6E, 0x7A, 0x6B, 0x77, 0x6A, 0x7B, 0x6C, 0x7C, 0x6F, 0x7E, 0x6F, 0x7A, 0x6E, 0x7F, 0x70, 0x7C, 0x6E, 0x7E, 0x6F, 0x7A, 0x6B, 0x7C, 0x6F, 0x79, 0x6A, 0x7D, 0x6E, 0x7D, 0x6E, 0x7C, 0x70, 0x7B, 0x6E, 0x79, 0x6C, 0x7C, 0x6E, 0x7B, 0x6D, 0x78, 0x6B, 0x7A, 0x6C, 0x79, 0x6C, 0x78, 0x6A, 0x78, 0x69, 0x7B, 0x6F, 0x7B, 0x6C, 0x7A, 0x6E, 0x7B, 0x6E, 0x77, 0x6A, 0x7A, 0x6F, 0x7B, 0x6B, 0x7B, 0x6A, 0x76, 0x69, 0x77, 0x69, 0x78, 0x6B, 0x74, 0x68, 0x79, 0x6A, 0x78, 0x6B, 0x7D, 0x6F, 0x77, 0x68, 0x76, 0x68, 0x77, 0x6A, 0x73, 0x65, 0x75, 0x66, 0x77, 0x68, 0x79, 0x6D, 0x7C, 0x6D, 0x77, 0x69, 0x7A, 0x6D, 0x7A, 0x6E, 0x79, 0x6D, 0x7D, 0x71, 0x7F, 0x74, 0x83, 0x77, 0x7C, 0x6F, 0x7C, 0x6F, 0x7A, 0x6D, 0x73, 0x68, 0x76, 0x69, 0x78, 0x68, 0x76, 0x67, 0x78, 0x6A, 0x75, 0x66, 0x70, 0x64, 0x72, 0x67, 0x74, 0x66, 0x72, 0x64, 0x71, 0x65, 0x71, 0x65, 0x6E, 0x65, 0x71, 0x65, 0x6F, 0x62, 0x6B, 0x60, 0x6E, 0x63, 0x6F, 0x62, 0x6E, 0x62, 0x70, 0x63, 0x6B, 0x60, 0x6D, 0x60, 0x70, 0x64, 0x6E, 0x62, 0x6D, 0x62, 0x6F, 0x63, 0x6C, 0x5E, 0x6C, 0x61, 0x6B, 0x5F, 0x6B, 0x5F, 0x6D, 0x60, 0x6D, 0x60, 0x6F, 0x60, 0x6B, 0x5F, 0x6E, 0x60, 0x6D, 0x5F, 0x6C, 0x61, 0x6D, 0x60, 0x69, 0x5D, 0x69, 0x5F, 0x6C, 0x60, 0x68, 0x5D, 0x6D, 0x60, 0x6E, 0x64, 0x6A, 0x5F, 0x6C, 0x61, 0x6A, 0x5E, 0x6C, 0x61, 0x69, 0x5F, 0x6C, 0x62, 0x6C, 0x62, 0x6C, 0x61, 0x6A, 0x5E, 0x6D, 0x61, 0x6C, 0x60, 0x70, 0x63, 0x6A, 0x5F, 0x6B, 0x5F, 0x69, 0x5D, 0x6C, 0x5F, 0x64, 0x5B, 0x69, 0x5E, 0x67, 0x5D, 0x67, 0x5D, 0x65, 0x5C, 0x66, 0x5A, 0x62, 0x5C, 0x67, 0x5F, 0x66, 0x5C, 0x68, 0x5D, 0x68, 0x5D, 0x69, 0x5D, 0x65, 0x5A, 0x68, 0x5E, 0x58, 0x4F, 0x40, 0x41, 0x30, 0x34, 0x34, 0x3C, 0x37, 0x41, 0x30, 0x33, 0x3A, 0x42, 0x2C, 0x2D, 0x26, 0x2A, 0x23, 0x25, 0x26, 0x29, 0x26, 0x2C, 0x2B, 0x2E, 0x25, 0x29, 0x2C, 0x34, 0x2E, 0x33, 0x29, 0x2E, 0x31, 0x35, 0x2A, 0x2D, 0x2E, 0x33, 0x28, 0x2B, 0x2E, 0x35, 0x2A, 0x2F, 0x30, 0x36, 0x2E, 0x34, 0x33, 0x39, 0x2F, 0x37, 0x38, 0x42, 0x30, 0x37, 0x3C, 0x43, 0x30, 0x36, 0x35, 0x3C, 0x30, 0x36, 0x3C, 0x42, 0x2E, 0x30, 0x2F, 0x37, 0x2B, 0x32, 0x30, 0x35, 0x2B, 0x2E, 0x2A, 0x2C, 0x2B, 0x32, 0x32, 0x39, 0x2D, 0x32, 0x35, 0x3B, 0x2C, 0x2F, 0x2A, 0x30, 0x2F, 0x36, 0x35, 0x3B
    },

    {
        0x58, 0x20, 0x57, 0x1E, 0x57, 0x1F, 0x59, 0x20, 0x59, 0x1F, 0x57, 0x1F, 0x58, 0x20, 0x59, 0x20, 0x59, 0x1F, 0x5A, 0x20, 0x5B, 0x21, 0x5B, 0x21, 0x5C, 0x21, 0x5C, 0x21, 0x5C, 0x21, 0x5D, 0x21, 0x5C, 0x22, 0x5C, 0x22, 0x5D, 0x22, 0x5D, 0x22, 0x5E, 0x21, 0x5C, 0x21, 0x5D, 0x22, 0x5D, 0x21, 0x5C, 0x21, 0x5D, 0x21, 0x5A, 0x21, 0x5A, 0x20, 0x5B, 0x21, 0x5C, 0x21, 0x5E, 0x22, 0x5F, 0x22, 0x60, 0x22, 0x60, 0x22, 0x64, 0x25, 0x67, 0x26, 0x65, 0x25, 0x65, 0x24, 0x64, 0x25, 0x63, 0x24, 0x65, 0x24, 0x67, 0x25, 0x64, 0x24, 0x66, 0x25, 0x68, 0x26, 0x67, 0x26, 0x5F, 0x23, 0x49, 0x1E, 0x3B, 0x1C, 0x49, 0x20, 0x5A, 0x23, 0x5E, 0x23, 0x56, 0x1F, 0x3F, 0x1A, 0x29, 0x16, 0x23, 0x15, 0x20, 0x14, 0x1F, 0x15, 0x20, 0x15, 0x1D, 0x13, 0x1C, 0x14, 0x23, 0x1F, 0x40, 0x3C, 0x66, 0x57, 0x75, 0x60, 0x7C, 0x66, 0x81, 0x69, 0x83, 0x6C, 0x85, 0x6D, 0x88, 0x6E, 0x89, 0x6E, 0x88, 0x6E, 0x89, 0x6F, 0x89, 0x6F, 0x8B, 0x71, 0x8B, 0x70, 0x8B, 0x70, 0x88, 0x6F, 0x89, 0x70, 0x89, 0x6F, 0x88, 0x70, 0x8D, 0x72, 0x8D, 0x72, 0x88, 0x6E, 0x89, 0x71, 0x89, 0x6F, 0x87, 0x6F, 0x88, 0x70, 0x8A, 0x70, 0x86, 0x6F, 0x88, 0x6F, 0x89, 0x70, 0x8C, 0x71, 0x8A, 0x70, 0x89, 0x6D, 0x6F, 0x4F, 0x37, 0x27, 0x28, 0x1C, 0x22, 0x18, 0x1F, 0x16, 0x21, 0x17, 0x21, 0x16, 0x20, 0x15, 0x26, 0x19, 0x4D, 0x24, 0x63, 0x27, 0x65, 0x27, 0x5B, 0x25, 0x39, 0x1E, 0x47, 0x22, 0x60, 0x26, 0x67, 0x28, 0x6B, 0x27, 0x67, 0x26, 0x68, 0x28, 0x6B, 0x28, 0x6C, 0x28, 0x69, 0x27, 0x68, 0x28, 0x6A, 0x28, 0x6A, 0x29, 0x6B, 0x27, 0x68, 0x28, 0x69, 0x28, 0x6B, 0x28, 0x6C, 0x28, 0x69, 0x26, 0x67, 0x26, 0x6A, 0x27, 0x69, 0x27, 0x67, 0x2A, 0x6F, 0x2D, 0x6C, 0x2B, 0x6D, 0x29, 0x6A, 0x28, 0x6C, 0x28, 0x6E, 0x2A, 0x6C, 0x29, 0x70, 0x2A, 0x70, 0x2B, 0x71, 0x2A, 0x6F, 0x2A, 0x6D, 0x29, 0x6C, 0x29, 0x6F, 0x2A, 0x6D, 0x28, 0x6B, 0x29, 0x70, 0x2A, 0x6C, 0x29, 0x6F, 0x2A, 0x6E, 0x29, 0x6C, 0x28, 0x6E, 0x29, 0x6D, 0x29, 0x6B, 0x2A, 0x6D, 0x2A, 0x6D, 0x29, 0x6C, 0x27, 0x6A, 0x27, 0x6C, 0x27, 0x6B, 0x27, 0x6A, 0x28, 0x69, 0x27, 0x68, 0x27, 0x6B, 0x27, 0x6C, 0x28, 0x69, 0x27, 0x6B, 0x28, 0x6D, 0x29, 0x6D, 0x27, 0x6B, 0x27, 0x69, 0x26, 0x6A, 0x27, 0x68, 0x27, 0x6B, 0x27, 0x69, 0x27, 0x69, 0x26, 0x6B, 0x28, 0x6B, 0x29, 0x71, 0x2A, 0x6F, 0x29, 0x69, 0x26, 0x6B, 0x27, 0x68, 0x26, 0x69, 0x25, 0x66, 0x26, 0x6D, 0x29, 0x69, 0x26, 0x6C, 0x27, 0x6A, 0x27, 0x70, 0x2B, 0x70, 0x2A, 0x72, 0x2B, 0x6B, 0x29, 0x6A, 0x28, 0x6D, 0x29, 0x6A, 0x28, 0x6B, 0x29, 0x71, 0x2A, 0x68, 0x26, 0x68, 0x26, 0x66, 0x26, 0x68, 0x27, 0x64, 0x25, 0x64, 0x24, 0x60, 0x23, 0x63, 0x24, 0x5F, 0x24, 0x61, 0x25, 0x63, 0x26, 0x64, 0x26, 0x61, 0x24, 0x60, 0x23, 0x61, 0x24, 0x64, 0x25, 0x66, 0x26, 0x63, 0x25, 0x61, 0x24, 0x60, 0x23, 0x61, 0x23, 0x61, 0x23, 0x5F, 0x22, 0x61, 0x23, 0x62, 0x24, 0x5F, 0x22, 0x5E, 0x22, 0x5D, 0x23, 0x5F, 0x23, 0x60, 0x23, 0x5D, 0x22, 0x5D, 0x21, 0x5C, 0x22, 0x5D, 0x22, 0x5E, 0x23, 0x5D, 0x24, 0x63, 0x24, 0x5D, 0x22, 0x5D, 0x22, 0x5D, 0x22, 0x5E, 0x24, 0x61, 0x25, 0x61, 0x24, 0x5D, 0x24, 0x5F, 0x24, 0x63, 0x26, 0x60, 0x25, 0x5F, 0x26, 0x60, 0x25, 0x60, 0x25, 0x5E, 0x23, 0x5D, 0x25, 0x64, 0x26, 0x65, 0x26, 0x62, 0x24, 0x5D, 0x23, 0x5F, 0x23, 0x5C, 0x23, 0x5D, 0x24, 0x5E, 0x23, 0x5D, 0x22, 0x59, 0x23, 0x5D, 0x24, 0x5A, 0x22, 0x59, 0x21, 0x5A, 0x22, 0x5E, 0x26, 0x5B, 0x23, 0x5C, 0x23, 0x5A, 0x21, 0x59, 0x21, 0x57, 0x21, 0x59, 0x21, 0x54, 0x23, 0x4B, 0x24, 0x38, 0x1F, 0x42, 0x23, 0x3E, 0x22, 0x34, 0x1D, 0x32, 0x1C, 0x2F, 0x1B, 0x38, 0x1E, 0x30, 0x1B, 0x38, 0x1E, 0x36, 0x1D, 0x3F, 0x20, 0x39, 0x1F, 0x34, 0x1D, 0x3B, 0x1F, 0x34, 0x1C, 0x41, 0x21, 0x33, 0x1C, 0x39, 0x1F, 0x2E, 0x1A, 0x3F, 0x21, 0x32, 0x1B, 0x3C, 0x20, 0x30, 0x1B, 0x3E, 0x20, 0x2E, 0x1A, 0x3A, 0x1F, 0x2F, 0x1C, 0x3B, 0x1E, 0x2C, 0x19, 0x33, 0x1C, 0x32, 0x1D, 0x35, 0x1D, 0x2F, 0x1A, 0x33, 0x1C, 0x37, 0x1D, 0x33, 0x1B, 0x37, 0x1E, 0x36, 0x1C, 0x30, 0x1B, 0x33, 0x1B, 0x32, 0x1C, 0x38, 0x1D, 0x3A, 0x1F, 0x32, 0x1C, 0x3F, 0x20, 0x38, 0x1E
    },

    {
        0x64, 0x58, 0x63, 0x58, 0x64, 0x58, 0x65, 0x59, 0x66, 0x5A, 0x66, 0x59, 0x65, 0x59, 0x65, 0x5A, 0x65, 0x59, 0x67, 0x5A, 0x67, 0x5B, 0x6A, 0x5D, 0x6B, 0x5D, 0x6A, 0x5C, 0x6A, 0x5D, 0x6B, 0x5E, 0x6B, 0x5C, 0x69, 0x5D, 0x6A, 0x5E, 0x6C, 0x5F, 0x6D, 0x5E, 0x6C, 0x5D, 0x6C, 0x5E, 0x6A, 0x5D, 0x6C, 0x5C, 0x6B, 0x5C, 0x68, 0x5A, 0x6A, 0x5A, 0x6B, 0x5A, 0x6B, 0x5B, 0x6E, 0x5F, 0x70, 0x60, 0x6F, 0x61, 0x6F, 0x60, 0x73, 0x64, 0x75, 0x67, 0x73, 0x65, 0x74, 0x65, 0x75, 0x64, 0x74, 0x65, 0x78, 0x66, 0x77, 0x66, 0x75, 0x68, 0x76, 0x68, 0x76, 0x69, 0x76, 0x68, 0x6F, 0x60, 0x5C, 0x4C, 0x43, 0x3A, 0x48, 0x47, 0x5F, 0x5B, 0x68, 0x5F, 0x63, 0x59, 0x4F, 0x43, 0x30, 0x2C, 0x24, 0x24, 0x1F, 0x21, 0x1E, 0x20, 0x1C, 0x20, 0x1A, 0x1D, 0x19, 0x1C, 0x1D, 0x22, 0x2D, 0x3D, 0x4B, 0x63, 0x5E, 0x72, 0x68, 0x7A, 0x6C, 0x7D, 0x6F, 0x84, 0x72, 0x86, 0x75, 0x86, 0x75, 0x86, 0x74, 0x86, 0x76, 0x86, 0x76, 0x88, 0x78, 0x8B, 0x78, 0x8C, 0x77, 0x88, 0x75, 0x88, 0x76, 0x89, 0x75, 0x89, 0x75, 0x8A, 0x78, 0x8D, 0x78, 0x8B, 0x75, 0x87, 0x75, 0x89, 0x76, 0x89, 0x74, 0x87, 0x76, 0x89, 0x77, 0x89, 0x75, 0x85, 0x75, 0x89, 0x75, 0x89, 0x76, 0x8A, 0x75, 0x8C, 0x70, 0x85, 0x55, 0x5C, 0x2D, 0x2E, 0x23, 0x26, 0x1D, 0x21, 0x1B, 0x1F, 0x1C, 0x22, 0x1C, 0x20, 0x1D, 0x21, 0x2B, 0x31, 0x56, 0x59, 0x6C, 0x65, 0x6B, 0x64, 0x59, 0x4E, 0x3C, 0x39, 0x51, 0x54, 0x6B, 0x65, 0x73, 0x69, 0x78, 0x6B, 0x73, 0x68, 0x78, 0x68, 0x79, 0x6D, 0x79, 0x6B, 0x77, 0x69, 0x75, 0x69, 0x76, 0x69, 0x79, 0x6E, 0x78, 0x6A, 0x75, 0x6A, 0x76, 0x6B, 0x7B, 0x6F, 0x7C, 0x6E, 0x77, 0x69, 0x74, 0x69, 0x76, 0x69, 0x75, 0x6A, 0x73, 0x6C, 0x7A, 0x72, 0x78, 0x6B, 0x78, 0x6C, 0x79, 0x6B, 0x7A, 0x6F, 0x7C, 0x70, 0x79, 0x6E, 0x7D, 0x70, 0x7B, 0x71, 0x7F, 0x71, 0x7F, 0x71, 0x7F, 0x70, 0x79, 0x6D, 0x7C, 0x6F, 0x7B, 0x6E, 0x7A, 0x6D, 0x80, 0x75, 0x7C, 0x6F, 0x7C, 0x70, 0x7E, 0x71, 0x7D, 0x6E, 0x7E, 0x70, 0x7D, 0x6F, 0x78, 0x6A, 0x79, 0x6E, 0x7E, 0x70, 0x7A, 0x6B, 0x77, 0x69, 0x7B, 0x6C, 0x7B, 0x6D, 0x78, 0x6B, 0x7A, 0x6A, 0x79, 0x6A, 0x7B, 0x6C, 0x7A, 0x6D, 0x79, 0x6C, 0x79, 0x6D, 0x7A, 0x6D, 0x7B, 0x6D, 0x7B, 0x6B, 0x78, 0x69, 0x78, 0x6B, 0x77, 0x6A, 0x79, 0x6C, 0x76, 0x6B, 0x79, 0x6B, 0x7D, 0x70, 0x79, 0x6E, 0x7D, 0x71, 0x7D, 0x6D, 0x7A, 0x6A, 0x7A, 0x6C, 0x78, 0x6A, 0x7B, 0x6C, 0x78, 0x6C, 0x7A, 0x70, 0x76, 0x69, 0x79, 0x6D, 0x79, 0x6A, 0x7D, 0x72, 0x80, 0x74, 0x80, 0x75, 0x79, 0x6A, 0x76, 0x6B, 0x7A, 0x6C, 0x78, 0x6D, 0x7B, 0x70, 0x81, 0x73, 0x78, 0x6B, 0x78, 0x6A, 0x7A, 0x6A, 0x76, 0x69, 0x72, 0x66, 0x75, 0x66, 0x71, 0x61, 0x72, 0x64, 0x71, 0x62, 0x6F, 0x64, 0x70, 0x65, 0x6F, 0x65, 0x6F, 0x62, 0x6F, 0x62, 0x6F, 0x62, 0x70, 0x65, 0x74, 0x67, 0x73, 0x64, 0x6E, 0x62, 0x71, 0x65, 0x6E, 0x62, 0x6D, 0x61, 0x6E, 0x62, 0x6F, 0x63, 0x71, 0x64, 0x6D, 0x5F, 0x6C, 0x60, 0x6B, 0x5F, 0x6D, 0x63, 0x6E, 0x60, 0x6E, 0x60, 0x6B, 0x5E, 0x69, 0x5F, 0x6B, 0x5F, 0x6B, 0x60, 0x6B, 0x5F, 0x6F, 0x62, 0x6C, 0x5F, 0x6D, 0x5F, 0x6D, 0x5F, 0x6D, 0x60, 0x6D, 0x62, 0x6D, 0x61, 0x6B, 0x5F, 0x6D, 0x62, 0x70, 0x65, 0x6C, 0x5F, 0x6B, 0x63, 0x6D, 0x62, 0x6A, 0x61, 0x6A, 0x5F, 0x69, 0x61, 0x71, 0x68, 0x70, 0x66, 0x6F, 0x62, 0x6A, 0x60, 0x6C, 0x61, 0x69, 0x5E, 0x68, 0x5E, 0x6B, 0x5F, 0x69, 0x5F, 0x65, 0x5B, 0x6A, 0x5D, 0x65, 0x5B, 0x66, 0x5C, 0x66, 0x5E, 0x67, 0x5F, 0x69, 0x5E, 0x68, 0x5D, 0x65, 0x5C, 0x66, 0x5B, 0x63, 0x5A, 0x65, 0x59, 0x5E, 0x56, 0x47, 0x47, 0x34, 0x39, 0x38, 0x41, 0x33, 0x38, 0x2E, 0x32, 0x2F, 0x31, 0x2E, 0x32, 0x33, 0x38, 0x2E, 0x35, 0x35, 0x3D, 0x32, 0x3A, 0x38, 0x41, 0x33, 0x3A, 0x2E, 0x34, 0x34, 0x3B, 0x31, 0x38, 0x3A, 0x41, 0x2C, 0x2F, 0x32, 0x3A, 0x2A, 0x2F, 0x3A, 0x42, 0x2D, 0x30, 0x34, 0x3B, 0x2A, 0x2F, 0x35, 0x3A, 0x2A, 0x2E, 0x33, 0x38, 0x2B, 0x31, 0x31, 0x34, 0x29, 0x2E, 0x2E, 0x33, 0x2F, 0x34, 0x30, 0x34, 0x2C, 0x30, 0x2F, 0x37, 0x32, 0x38, 0x30, 0x35, 0x33, 0x3C, 0x2E, 0x34, 0x2C, 0x32, 0x2F, 0x34, 0x30, 0x38, 0x33, 0x3A, 0x35, 0x3A, 0x2E, 0x36, 0x38, 0x3C, 0x31, 0x36
    },

    {
        0x59, 0x20, 0x58, 0x1F, 0x5A, 0x20, 0x59, 0x1F, 0x58, 0x1F, 0x58, 0x20, 0x58, 0x20, 0x5A, 0x20, 0x5B, 0x20, 0x5B, 0x21, 0x5C, 0x21, 0x5C, 0x21, 0x5C, 0x21, 0x5A, 0x21, 0x5A, 0x20, 0x5B, 0x21, 0x5C, 0x21, 0x5D, 0x22, 0x5D, 0x23, 0x5D, 0x21, 0x5C, 0x21, 0x5D, 0x21, 0x5C, 0x21, 0x5C, 0x21, 0x5C, 0x21, 0x5D, 0x21, 0x5A, 0x21, 0x5C, 0x21, 0x5C, 0x21, 0x60, 0x22, 0x61, 0x24, 0x62, 0x23, 0x62, 0x23, 0x61, 0x23, 0x61, 0x24, 0x62, 0x24, 0x63, 0x24, 0x65, 0x24, 0x65, 0x25, 0x67, 0x25, 0x67, 0x24, 0x65, 0x24, 0x65, 0x25, 0x66, 0x25, 0x65, 0x26, 0x6B, 0x28, 0x68, 0x25, 0x5E, 0x22, 0x4D, 0x1E, 0x3A, 0x1C, 0x46, 0x1F, 0x59, 0x22, 0x61, 0x23, 0x5B, 0x22, 0x48, 0x1D, 0x2D, 0x17, 0x24, 0x15, 0x23, 0x16, 0x22, 0x16, 0x1E, 0x13, 0x1D, 0x13, 0x1D, 0x14, 0x21, 0x1C, 0x38, 0x34, 0x5B, 0x50, 0x73, 0x60, 0x7A, 0x66, 0x81, 0x69, 0x85, 0x6B, 0x87, 0x6C, 0x87, 0x6E, 0x87, 0x6F, 0x89, 0x6E, 0x8A, 0x70, 0x89, 0x70, 0x89, 0x6F, 0x89, 0x6E, 0x8A, 0x6F, 0x8E, 0x72, 0x8C, 0x72, 0x8C, 0x72, 0x8B, 0x72, 0x8A, 0x71, 0x8C, 0x72, 0x8A, 0x71, 0x8B, 0x70, 0x89, 0x6F, 0x88, 0x6F, 0x89, 0x72, 0x8A, 0x70, 0x89, 0x70, 0x8B, 0x71, 0x8C, 0x70, 0x88, 0x6C, 0x70, 0x4F, 0x3C, 0x28, 0x28, 0x1C, 0x23, 0x18, 0x1F, 0x16, 0x1F, 0x15, 0x21, 0x16, 0x21, 0x16, 0x26, 0x19, 0x48, 0x23, 0x62, 0x27, 0x67, 0x27, 0x5B, 0x25, 0x3C, 0x1F, 0x47, 0x22, 0x65, 0x28, 0x69, 0x2A, 0x6B, 0x29, 0x6B, 0x28, 0x67, 0x27, 0x6D, 0x29, 0x6A, 0x27, 0x67, 0x27, 0x67, 0x26, 0x69, 0x27, 0x68, 0x28, 0x6A, 0x29, 0x69, 0x28, 0x69, 0x28, 0x6E, 0x2A, 0x71, 0x2A, 0x6E, 0x28, 0x68, 0x27, 0x6B, 0x27, 0x68, 0x27, 0x6F, 0x2F, 0x72, 0x2E, 0x6D, 0x2A, 0x6C, 0x28, 0x68, 0x28, 0x6D, 0x29, 0x6C, 0x29, 0x6D, 0x29, 0x6B, 0x28, 0x73, 0x2B, 0x6E, 0x2B, 0x73, 0x2B, 0x6E, 0x2B, 0x6E, 0x2B, 0x6F, 0x2A, 0x6E, 0x29, 0x69, 0x28, 0x6D, 0x29, 0x70, 0x2A, 0x75, 0x2D, 0x6E, 0x29, 0x6E, 0x29, 0x6A, 0x29, 0x6E, 0x2B, 0x74, 0x2B, 0x72, 0x2B, 0x6B, 0x28, 0x69, 0x27, 0x6B, 0x29, 0x6B, 0x2A, 0x6B, 0x28, 0x6F, 0x29, 0x6E, 0x28, 0x6B, 0x29, 0x6C, 0x28, 0x69, 0x27, 0x68, 0x27, 0x6B, 0x28, 0x6C, 0x29, 0x6E, 0x28, 0x6D, 0x28, 0x68, 0x27, 0x6F, 0x29, 0x69, 0x27, 0x6A, 0x27, 0x66, 0x26, 0x6B, 0x27, 0x68, 0x27, 0x6B, 0x28, 0x69, 0x27, 0x6B, 0x28, 0x6C, 0x28, 0x6A, 0x26, 0x6D, 0x28, 0x6D, 0x27, 0x69, 0x25, 0x6A, 0x27, 0x68, 0x28, 0x66, 0x26, 0x65, 0x26, 0x67, 0x25, 0x69, 0x28, 0x71, 0x2A, 0x6C, 0x29, 0x6F, 0x2A, 0x68, 0x27, 0x6C, 0x28, 0x6C, 0x29, 0x6B, 0x27, 0x6F, 0x29, 0x6E, 0x29, 0x6E, 0x2A, 0x6A, 0x27, 0x66, 0x27, 0x61, 0x25, 0x65, 0x25, 0x64, 0x25, 0x65, 0x25, 0x65, 0x26, 0x69, 0x28, 0x65, 0x26, 0x62, 0x24, 0x62, 0x25, 0x62, 0x24, 0x61, 0x23, 0x62, 0x25, 0x64, 0x25, 0x66, 0x25, 0x64, 0x25, 0x62, 0x25, 0x64, 0x24, 0x60, 0x22, 0x5E, 0x23, 0x63, 0x24, 0x5D, 0x23, 0x63, 0x24, 0x61, 0x23, 0x60, 0x23, 0x5E, 0x23, 0x5E, 0x23, 0x5F, 0x22, 0x5E, 0x23, 0x5E, 0x23, 0x5F, 0x23, 0x5D, 0x22, 0x5D, 0x23, 0x61, 0x26, 0x62, 0x25, 0x5D, 0x23, 0x5D, 0x22, 0x5E, 0x23, 0x5E, 0x23, 0x5E, 0x23, 0x5F, 0x24, 0x5C, 0x23, 0x5D, 0x23, 0x60, 0x25, 0x61, 0x26, 0x60, 0x25, 0x5C, 0x24, 0x60, 0x26, 0x64, 0x27, 0x5F, 0x25, 0x60, 0x25, 0x5E, 0x24, 0x5E, 0x23, 0x5C, 0x24, 0x5C, 0x24, 0x5B, 0x23, 0x61, 0x24, 0x5E, 0x22, 0x5B, 0x22, 0x59, 0x22, 0x5A, 0x22, 0x5D, 0x22, 0x59, 0x21, 0x5A, 0x22, 0x58, 0x22, 0x5C, 0x23, 0x58, 0x21, 0x5B, 0x24, 0x5C, 0x23, 0x59, 0x20, 0x55, 0x23, 0x3B, 0x1F, 0x35, 0x1D, 0x39, 0x20, 0x39, 0x20, 0x3A, 0x20, 0x3E, 0x21, 0x37, 0x1E, 0x47, 0x23, 0x34, 0x1B, 0x39, 0x1E, 0x37, 0x1F, 0x3F, 0x21, 0x2D, 0x1A, 0x32, 0x1D, 0x33, 0x1B, 0x33, 0x1D, 0x33, 0x1C, 0x2D, 0x1A, 0x35, 0x1C, 0x2C, 0x1A, 0x38, 0x1D, 0x2B, 0x19, 0x33, 0x1B, 0x2E, 0x1A, 0x35, 0x1C, 0x2F, 0x1A, 0x35, 0x1D, 0x35, 0x1C, 0x3B, 0x1F, 0x33, 0x1C, 0x3E, 0x20, 0x37, 0x1D, 0x40, 0x21, 0x38, 0x1D, 0x41, 0x22, 0x35, 0x1C, 0x37, 0x1D, 0x30, 0x1B, 0x2C, 0x19, 0x36, 0x1D, 0x3E, 0x20, 0x33, 0x1D, 0x3B, 0x20, 0x32, 0x1B, 0x32, 0x1B, 0x30, 0x1A, 0x31, 0x1B
    },

    {
        0x65, 0x59, 0x64, 0x59, 0x66, 0x5A, 0x65, 0x58, 0x65, 0x59, 0x64, 0x58, 0x64, 0x59, 0x66, 0x5B, 0x66, 0x5A, 0x67, 0x5C, 0x69, 0x5C, 0x69, 0x5C, 0x6A, 0x5B, 0x69, 0x5B, 0x69, 0x5B, 0x6A, 0x5C, 0x6C, 0x5C, 0x6B, 0x5D, 0x6C, 0x5F, 0x6B, 0x5C, 0x6A, 0x5B, 0x6B, 0x5D, 0x6C, 0x5D, 0x6A, 0x5C, 0x6C, 0x5D, 0x6B, 0x5D, 0x6A, 0x5C, 0x6B, 0x5C, 0x6D, 0x5E, 0x6F, 0x60, 0x71, 0x62, 0x70, 0x62, 0x71, 0x61, 0x70, 0x63, 0x72, 0x62, 0x73, 0x64, 0x73, 0x63, 0x74, 0x65, 0x75, 0x66, 0x76, 0x67, 0x7A, 0x68, 0x79, 0x66, 0x76, 0x65, 0x75, 0x64, 0x75, 0x66, 0x79, 0x6B, 0x76, 0x68, 0x6E, 0x60, 0x5E, 0x4F, 0x45, 0x3B, 0x45, 0x46, 0x5C, 0x59, 0x6B, 0x62, 0x69, 0x5E, 0x57, 0x4B, 0x36, 0x30, 0x26, 0x26, 0x22, 0x24, 0x20, 0x22, 0x1C, 0x1F, 0x19, 0x1D, 0x1A, 0x1C, 0x1C, 0x1F, 0x27, 0x33, 0x43, 0x59, 0x5D, 0x72, 0x65, 0x79, 0x6C, 0x7F, 0x6F, 0x82, 0x73, 0x87, 0x73, 0x86, 0x75, 0x88, 0x76, 0x87, 0x74, 0x87, 0x76, 0x87, 0x76, 0x88, 0x75, 0x86, 0x76, 0x88, 0x78, 0x8C, 0x78, 0x8B, 0x79, 0x8D, 0x78, 0x8C, 0x78, 0x8B, 0x78, 0x8C, 0x78, 0x8A, 0x76, 0x88, 0x77, 0x88, 0x75, 0x87, 0x77, 0x8B, 0x77, 0x89, 0x76, 0x89, 0x78, 0x8C, 0x76, 0x8B, 0x6F, 0x83, 0x56, 0x5B, 0x30, 0x31, 0x23, 0x27, 0x1D, 0x20, 0x1B, 0x1F, 0x1B, 0x1F, 0x1C, 0x21, 0x1D, 0x21, 0x2A, 0x30, 0x53, 0x56, 0x6D, 0x66, 0x6D, 0x66, 0x59, 0x50, 0x3D, 0x38, 0x52, 0x55, 0x72, 0x6A, 0x77, 0x6F, 0x77, 0x6C, 0x79, 0x6C, 0x76, 0x6A, 0x7B, 0x70, 0x79, 0x69, 0x74, 0x68, 0x74, 0x67, 0x75, 0x69, 0x75, 0x6A, 0x78, 0x6D, 0x76, 0x68, 0x76, 0x6A, 0x7A, 0x6F, 0x80, 0x71, 0x7C, 0x6E, 0x77, 0x6A, 0x7B, 0x6C, 0x75, 0x68, 0x77, 0x73, 0x78, 0x6E, 0x7A, 0x6E, 0x7C, 0x6F, 0x79, 0x6C, 0x7A, 0x6E, 0x79, 0x6C, 0x7C, 0x6C, 0x7A, 0x6F, 0x81, 0x74, 0x7D, 0x6E, 0x82, 0x73, 0x7F, 0x6F, 0x7F, 0x71, 0x7E, 0x71, 0x7A, 0x6D, 0x77, 0x69, 0x7C, 0x6D, 0x7B, 0x6F, 0x80, 0x75, 0x7D, 0x6F, 0x7F, 0x70, 0x7A, 0x6C, 0x7D, 0x72, 0x82, 0x72, 0x80, 0x71, 0x78, 0x6A, 0x76, 0x6A, 0x7B, 0x6D, 0x78, 0x6C, 0x79, 0x6B, 0x7E, 0x6F, 0x7B, 0x6E, 0x7C, 0x6F, 0x7B, 0x6E, 0x7A, 0x6A, 0x7A, 0x6B, 0x79, 0x6D, 0x79, 0x6D, 0x81, 0x71, 0x7C, 0x6E, 0x78, 0x69, 0x7E, 0x70, 0x78, 0x6B, 0x78, 0x6B, 0x76, 0x68, 0x77, 0x6A, 0x78, 0x69, 0x78, 0x6A, 0x77, 0x69, 0x76, 0x6B, 0x7D, 0x6D, 0x7C, 0x6E, 0x7F, 0x70, 0x7D, 0x6E, 0x78, 0x69, 0x78, 0x6D, 0x70, 0x67, 0x6D, 0x65, 0x6D, 0x64, 0x74, 0x68, 0x76, 0x6B, 0x7D, 0x6E, 0x7B, 0x6E, 0x7E, 0x72, 0x77, 0x6C, 0x79, 0x6D, 0x7B, 0x6C, 0x7C, 0x6E, 0x80, 0x70, 0x7D, 0x71, 0x7D, 0x6F, 0x79, 0x6A, 0x75, 0x67, 0x72, 0x66, 0x73, 0x67, 0x74, 0x66, 0x74, 0x67, 0x73, 0x69, 0x7A, 0x6E, 0x72, 0x66, 0x71, 0x64, 0x6E, 0x61, 0x70, 0x64, 0x71, 0x64, 0x73, 0x66, 0x73, 0x68, 0x72, 0x65, 0x72, 0x65, 0x73, 0x66, 0x74, 0x64, 0x6D, 0x60, 0x6D, 0x62, 0x72, 0x66, 0x69, 0x5E, 0x72, 0x65, 0x6E, 0x60, 0x6E, 0x60, 0x6C, 0x60, 0x6F, 0x62, 0x6F, 0x5F, 0x6B, 0x5E, 0x6B, 0x60, 0x6C, 0x60, 0x6A, 0x5F, 0x6A, 0x5F, 0x6D, 0x64, 0x6D, 0x60, 0x69, 0x5D, 0x6E, 0x62, 0x6A, 0x60, 0x69, 0x5D, 0x6C, 0x5F, 0x6D, 0x60, 0x67, 0x5E, 0x6A, 0x5F, 0x69, 0x60, 0x6B, 0x62, 0x6D, 0x61, 0x6A, 0x60, 0x6B, 0x63, 0x6B, 0x63, 0x67, 0x5D, 0x6C, 0x62, 0x68, 0x5D, 0x69, 0x5E, 0x6A, 0x60, 0x69, 0x5D, 0x68, 0x5D, 0x6E, 0x61, 0x6C, 0x5E, 0x69, 0x5D, 0x67, 0x5C, 0x65, 0x5C, 0x69, 0x5D, 0x66, 0x5C, 0x68, 0x5B, 0x65, 0x5B, 0x6A, 0x5F, 0x64, 0x5B, 0x68, 0x5F, 0x6A, 0x5D, 0x65, 0x5A, 0x58, 0x50, 0x37, 0x37, 0x31, 0x35, 0x34, 0x3D, 0x38, 0x3F, 0x37, 0x3F, 0x38, 0x3E, 0x31, 0x3A, 0x3D, 0x44, 0x2C, 0x30, 0x31, 0x37, 0x32, 0x3C, 0x35, 0x38, 0x27, 0x2A, 0x30, 0x37, 0x2E, 0x30, 0x2E, 0x34, 0x2E, 0x31, 0x29, 0x2E, 0x2F, 0x33, 0x2A, 0x30, 0x30, 0x35, 0x29, 0x2C, 0x2D, 0x32, 0x2D, 0x33, 0x34, 0x39, 0x2D, 0x32, 0x34, 0x3A, 0x33, 0x3A, 0x39, 0x40, 0x30, 0x37, 0x36, 0x3C, 0x31, 0x37, 0x38, 0x3F, 0x30, 0x35, 0x3A, 0x44, 0x2E, 0x32, 0x32, 0x38, 0x2A, 0x2E, 0x2A, 0x2F, 0x32, 0x39, 0x37, 0x3B, 0x2C, 0x33, 0x34, 0x3B, 0x2B, 0x2F, 0x2D, 0x33, 0x2A, 0x2E, 0x2E, 0x34
    },

    {
        0x57, 0x20, 0x57, 0x1F, 0x59, 0x20, 0x59, 0x1F, 0x58, 0x20, 0x59, 0x20, 0x58, 0x1F, 0x57, 0x20, 0x59, 0x20, 0x59, 0x20, 0x59, 0x20, 0x59, 0x20, 0x5B, 0x21, 0x5D, 0x22, 0x5E, 0x22, 0x5D, 0x22, 0x5E, 0x22, 0x5E, 0x22, 0x5E, 0x22, 0x5D, 0x21, 0x5C, 0x22, 0x5C, 0x22, 0x5B, 0x21, 0x5C, 0x22, 0x5C, 0x22, 0x5D, 0x22, 0x5E, 0x23, 0x5E, 0x22, 0x60, 0x23, 0x62, 0x24, 0x62, 0x24, 0x5F, 0x22, 0x5F, 0x22, 0x60, 0x23, 0x60, 0x23, 0x61, 0x24, 0x62, 0x24, 0x66, 0x25, 0x66, 0x24, 0x64, 0x24, 0x63, 0x24, 0x64, 0x24, 0x65, 0x25, 0x66, 0x25, 0x65, 0x26, 0x67, 0x26, 0x68, 0x26, 0x62, 0x23, 0x5F, 0x23, 0x52, 0x20, 0x3E, 0x1D, 0x43, 0x1F, 0x59, 0x23, 0x63, 0x26, 0x62, 0x24, 0x50, 0x1F, 0x35, 0x1A, 0x29, 0x18, 0x23, 0x16, 0x1F, 0x14, 0x1D, 0x14, 0x1D, 0x13, 0x1C, 0x14, 0x1E, 0x18, 0x2F, 0x2D, 0x57, 0x4E, 0x71, 0x60, 0x7B, 0x65, 0x7F, 0x69, 0x84, 0x6C, 0x85, 0x6C, 0x87, 0x6C, 0x86, 0x6D, 0x88, 0x6E, 0x89, 0x70, 0x8A, 0x70, 0x8A, 0x70, 0x88, 0x70, 0x8A, 0x71, 0x89, 0x71, 0x90, 0x74, 0x90, 0x74, 0x8C, 0x72, 0x8A, 0x72, 0x8B, 0x70, 0x89, 0x70, 0x88, 0x6F, 0x89, 0x70, 0x8A, 0x71, 0x88, 0x71, 0x8E, 0x74, 0x8D, 0x71, 0x89, 0x6D, 0x72, 0x52, 0x3B, 0x29, 0x2A, 0x1E, 0x24, 0x1A, 0x1F, 0x15, 0x1F, 0x16, 0x1F, 0x15, 0x20, 0x16, 0x25, 0x18, 0x48, 0x22, 0x60, 0x27, 0x67, 0x28, 0x5C, 0x25, 0x3C, 0x1F, 0x45, 0x23, 0x62, 0x27, 0x69, 0x28, 0x6C, 0x29, 0x69, 0x28, 0x6A, 0x28, 0x67, 0x27, 0x6A, 0x28, 0x65, 0x27, 0x67, 0x28, 0x67, 0x27, 0x6A, 0x27, 0x6B, 0x2A, 0x6E, 0x2A, 0x6B, 0x2A, 0x6A, 0x2A, 0x6D, 0x2A, 0x6D, 0x28, 0x68, 0x27, 0x6A, 0x27, 0x6A, 0x2A, 0x73, 0x30, 0x6E, 0x2A, 0x6D, 0x2A, 0x6C, 0x29, 0x6B, 0x28, 0x6E, 0x2A, 0x6E, 0x28, 0x6A, 0x29, 0x6E, 0x28, 0x6B, 0x29, 0x71, 0x2C, 0x72, 0x2D, 0x77, 0x2E, 0x6F, 0x2A, 0x6E, 0x29, 0x6C, 0x29, 0x6D, 0x29, 0x6D, 0x2A, 0x6C, 0x2A, 0x6D, 0x29, 0x6E, 0x2A, 0x73, 0x2B, 0x71, 0x2D, 0x6E, 0x2B, 0x70, 0x2A, 0x6D, 0x2A, 0x6E, 0x2A, 0x6F, 0x2A, 0x6D, 0x29, 0x6C, 0x29, 0x6A, 0x29, 0x65, 0x27, 0x6C, 0x28, 0x69, 0x27, 0x6E, 0x29, 0x68, 0x28, 0x6C, 0x28, 0x6A, 0x29, 0x6D, 0x29, 0x6F, 0x29, 0x6F, 0x2A, 0x6F, 0x2B, 0x74, 0x2C, 0x70, 0x2A, 0x6A, 0x28, 0x68, 0x27, 0x6A, 0x27, 0x6A, 0x27, 0x69, 0x27, 0x68, 0x26, 0x67, 0x26, 0x6D, 0x2A, 0x71, 0x2A, 0x66, 0x25, 0x67, 0x27, 0x6C, 0x28, 0x68, 0x25, 0x63, 0x27, 0x58, 0x28, 0x53, 0x28, 0x55, 0x29, 0x5C, 0x27, 0x65, 0x26, 0x6A, 0x27, 0x6A, 0x27, 0x70, 0x2B, 0x70, 0x2A, 0x6B, 0x29, 0x6D, 0x2A, 0x6B, 0x29, 0x6E, 0x29, 0x6E, 0x2A, 0x6F, 0x2B, 0x6B, 0x27, 0x66, 0x27, 0x65, 0x26, 0x64, 0x26, 0x66, 0x26, 0x69, 0x27, 0x68, 0x27, 0x68, 0x28, 0x66, 0x26, 0x62, 0x24, 0x62, 0x24, 0x64, 0x25, 0x65, 0x26, 0x66, 0x26, 0x68, 0x27, 0x64, 0x26, 0x66, 0x26, 0x62, 0x24, 0x61, 0x24, 0x63, 0x25, 0x62, 0x24, 0x61, 0x24, 0x60, 0x24, 0x60, 0x23, 0x5C, 0x23, 0x60, 0x24, 0x5D, 0x23, 0x5F, 0x23, 0x61, 0x24, 0x5A, 0x22, 0x5E, 0x22, 0x60, 0x23, 0x5F, 0x24, 0x61, 0x24, 0x5F, 0x24, 0x62, 0x25, 0x5F, 0x23, 0x60, 0x24, 0x5F, 0x23, 0x5D, 0x24, 0x5F, 0x24, 0x60, 0x25, 0x60, 0x25, 0x60, 0x24, 0x5E, 0x25, 0x62, 0x27, 0x61, 0x26, 0x60, 0x26, 0x62, 0x27, 0x65, 0x28, 0x5C, 0x24, 0x5E, 0x23, 0x5A, 0x22, 0x5F, 0x25, 0x61, 0x25, 0x5D, 0x24, 0x59, 0x23, 0x5F, 0x24, 0x5E, 0x23, 0x5D, 0x23, 0x59, 0x22, 0x57, 0x21, 0x5C, 0x22, 0x5D, 0x23, 0x5A, 0x21, 0x5A, 0x22, 0x5B, 0x22, 0x5C, 0x24, 0x5B, 0x23, 0x5B, 0x23, 0x58, 0x22, 0x4D, 0x21, 0x3E, 0x21, 0x3C, 0x20, 0x4B, 0x29, 0x40, 0x22, 0x31, 0x1D, 0x35, 0x1C, 0x38, 0x1F, 0x34, 0x1C, 0x2D, 0x1B, 0x38, 0x1F, 0x40, 0x22, 0x36, 0x1D, 0x37, 0x1D, 0x39, 0x20, 0x3F, 0x21, 0x3D, 0x20, 0x3D, 0x20, 0x35, 0x1D, 0x3E, 0x21, 0x3A, 0x20, 0x43, 0x22, 0x36, 0x1C, 0x42, 0x22, 0x3B, 0x1F, 0x41, 0x21, 0x33, 0x1C, 0x42, 0x22, 0x39, 0x1F, 0x3C, 0x20, 0x31, 0x1C, 0x34, 0x1C, 0x33, 0x1C, 0x37, 0x1D, 0x2B, 0x19, 0x35, 0x1D, 0x2E, 0x1A, 0x3D, 0x20, 0x38, 0x1F, 0x39, 0x1F, 0x34, 0x1D, 0x2F, 0x1A, 0x31, 0x1C, 0x39, 0x1E, 0x38, 0x1E, 0x35, 0x1D, 0x35, 0x1D, 0x40, 0x22
    },

    {
        0x64, 0x58, 0x63, 0x59, 0x64, 0x59, 0x65, 0x59, 0x66, 0x5B, 0x67, 0x5A, 0x65, 0x58, 0x64, 0x58, 0x66, 0x59, 0x66, 0x59, 0x67, 0x59, 0x67, 0x5A, 0x69, 0x5B, 0x6D, 0x5F, 0x6F, 0x5F, 0x6C, 0x5F, 0x6C, 0x5E, 0x6D, 0x5F, 0x6B, 0x5E, 0x6C, 0x5C, 0x6B, 0x5D, 0x6A, 0x5D, 0x6B, 0x5E, 0x6B, 0x5E, 0x6B, 0x5D, 0x6A, 0x5D, 0x6F, 0x60, 0x6F, 0x60, 0x70, 0x62, 0x73, 0x63, 0x71, 0x61, 0x6E, 0x5E, 0x70, 0x60, 0x6F, 0x60, 0x6F, 0x60, 0x72, 0x62, 0x72, 0x64, 0x77, 0x67, 0x78, 0x66, 0x76, 0x64, 0x75, 0x64, 0x76, 0x66, 0x75, 0x67, 0x78, 0x66, 0x78, 0x68, 0x79, 0x68, 0x78, 0x68, 0x73, 0x64, 0x6D, 0x60, 0x62, 0x55, 0x4C, 0x3F, 0x43, 0x41, 0x5A, 0x57, 0x6C, 0x64, 0x6D, 0x63, 0x5D, 0x52, 0x3F, 0x37, 0x2A, 0x2B, 0x23, 0x24, 0x1E, 0x20, 0x1B, 0x1E, 0x1A, 0x1D, 0x19, 0x1B, 0x1B, 0x1E, 0x23, 0x2D, 0x3C, 0x54, 0x59, 0x70, 0x65, 0x78, 0x6B, 0x7F, 0x70, 0x81, 0x70, 0x83, 0x73, 0x85, 0x75, 0x86, 0x76, 0x8A, 0x78, 0x89, 0x77, 0x88, 0x77, 0x89, 0x77, 0x8A, 0x77, 0x89, 0x76, 0x89, 0x7A, 0x90, 0x7A, 0x8E, 0x78, 0x8A, 0x76, 0x89, 0x77, 0x8A, 0x76, 0x88, 0x75, 0x88, 0x77, 0x8A, 0x77, 0x8B, 0x76, 0x87, 0x78, 0x8D, 0x76, 0x8B, 0x70, 0x86, 0x57, 0x5D, 0x30, 0x31, 0x24, 0x2A, 0x21, 0x24, 0x1B, 0x20, 0x1B, 0x1F, 0x1B, 0x20, 0x1D, 0x21, 0x28, 0x2E, 0x51, 0x55, 0x6A, 0x64, 0x6E, 0x68, 0x5A, 0x52, 0x3C, 0x37, 0x51, 0x54, 0x6F, 0x67, 0x75, 0x6A, 0x77, 0x6C, 0x78, 0x6B, 0x77, 0x6A, 0x74, 0x68, 0x77, 0x6A, 0x74, 0x69, 0x75, 0x6A, 0x77, 0x69, 0x78, 0x6C, 0x78, 0x6E, 0x7A, 0x6F, 0x78, 0x6C, 0x79, 0x70, 0x79, 0x6E, 0x7A, 0x6D, 0x77, 0x6A, 0x7A, 0x6C, 0x7A, 0x70, 0x7B, 0x75, 0x77, 0x6D, 0x79, 0x6E, 0x79, 0x6D, 0x77, 0x6B, 0x7B, 0x70, 0x7C, 0x6C, 0x79, 0x6D, 0x7E, 0x6D, 0x7C, 0x6F, 0x7E, 0x73, 0x7F, 0x72, 0x7E, 0x75, 0x80, 0x71, 0x7B, 0x6E, 0x7B, 0x6D, 0x7A, 0x6D, 0x79, 0x70, 0x79, 0x6F, 0x7A, 0x6F, 0x7D, 0x70, 0x7F, 0x70, 0x7E, 0x74, 0x7D, 0x70, 0x7C, 0x6D, 0x7B, 0x70, 0x7D, 0x70, 0x7D, 0x72, 0x7B, 0x6D, 0x7D, 0x6F, 0x78, 0x6E, 0x74, 0x69, 0x79, 0x6D, 0x77, 0x69, 0x7C, 0x70, 0x79, 0x6C, 0x7C, 0x6C, 0x77, 0x6B, 0x7D, 0x6F, 0x7B, 0x6F, 0x81, 0x72, 0x80, 0x74, 0x84, 0x76, 0x7F, 0x6F, 0x79, 0x6D, 0x77, 0x6A, 0x7B, 0x6D, 0x7B, 0x6D, 0x7A, 0x6D, 0x77, 0x6A, 0x79, 0x6B, 0x7B, 0x70, 0x80, 0x70, 0x7B, 0x6A, 0x77, 0x6C, 0x7B, 0x6B, 0x76, 0x67, 0x65, 0x5E, 0x56, 0x54, 0x52, 0x53, 0x53, 0x57, 0x5C, 0x5A, 0x6A, 0x63, 0x75, 0x6A, 0x78, 0x6B, 0x7F, 0x72, 0x7F, 0x73, 0x7B, 0x6C, 0x79, 0x6D, 0x78, 0x6C, 0x7C, 0x6F, 0x7E, 0x71, 0x7C, 0x71, 0x7A, 0x6C, 0x74, 0x69, 0x75, 0x69, 0x71, 0x66, 0x75, 0x68, 0x77, 0x69, 0x76, 0x67, 0x76, 0x69, 0x76, 0x68, 0x70, 0x64, 0x6F, 0x65, 0x71, 0x66, 0x74, 0x68, 0x73, 0x68, 0x75, 0x68, 0x71, 0x66, 0x73, 0x66, 0x70, 0x62, 0x70, 0x64, 0x72, 0x65, 0x6F, 0x64, 0x70, 0x62, 0x71, 0x64, 0x6F, 0x61, 0x6A, 0x5E, 0x6F, 0x62, 0x6D, 0x60, 0x71, 0x63, 0x71, 0x63, 0x69, 0x5C, 0x6D, 0x60, 0x6F, 0x61, 0x6E, 0x63, 0x70, 0x64, 0x6E, 0x60, 0x6F, 0x65, 0x70, 0x61, 0x6F, 0x62, 0x6C, 0x61, 0x6B, 0x61, 0x6D, 0x61, 0x6F, 0x64, 0x70, 0x64, 0x6F, 0x63, 0x6B, 0x62, 0x6F, 0x65, 0x6E, 0x63, 0x6E, 0x64, 0x6F, 0x64, 0x6C, 0x65, 0x67, 0x5D, 0x6A, 0x5E, 0x69, 0x5D, 0x6C, 0x62, 0x6C, 0x62, 0x69, 0x5E, 0x67, 0x5D, 0x6D, 0x62, 0x6A, 0x5D, 0x6B, 0x5E, 0x67, 0x5D, 0x65, 0x5B, 0x6B, 0x5E, 0x6A, 0x5F, 0x68, 0x5E, 0x69, 0x5D, 0x66, 0x5C, 0x67, 0x5E, 0x67, 0x5D, 0x69, 0x5D, 0x66, 0x5A, 0x50, 0x48, 0x3E, 0x44, 0x37, 0x3C, 0x43, 0x4F, 0x35, 0x39, 0x2B, 0x31, 0x2F, 0x31, 0x34, 0x3B, 0x2F, 0x32, 0x2C, 0x32, 0x37, 0x3E, 0x39, 0x41, 0x31, 0x38, 0x32, 0x38, 0x36, 0x41, 0x3A, 0x41, 0x35, 0x3B, 0x38, 0x3E, 0x31, 0x35, 0x3A, 0x41, 0x34, 0x3A, 0x3B, 0x42, 0x32, 0x39, 0x3B, 0x43, 0x34, 0x3B, 0x37, 0x3C, 0x2C, 0x33, 0x38, 0x3F, 0x32, 0x38, 0x32, 0x35, 0x2C, 0x33, 0x2C, 0x30, 0x2E, 0x36, 0x30, 0x33, 0x29, 0x2D, 0x2F, 0x35, 0x2B, 0x31, 0x38, 0x3E, 0x34, 0x3C, 0x33, 0x37, 0x2D, 0x32, 0x2C, 0x2F, 0x2E, 0x36, 0x34, 0x3B, 0x34, 0x3B, 0x31, 0x38, 0x31, 0x36, 0x3A, 0x44
    },

    {
        0x57, 0x20, 0x58, 0x20, 0x58, 0x1F, 0x58, 0x1F, 0x58, 0x1F, 0x5A, 0x20, 0x59, 0x20, 0x59, 0x20, 0x5A, 0x20, 0x59, 0x20, 0x5A, 0x20, 0x5B, 0x21, 0x5C, 0x21, 0x5F, 0x22, 0x5D, 0x21, 0x5C, 0x22, 0x5F, 0x23, 0x5E, 0x22, 0x5E, 0x22, 0x5D, 0x22, 0x5D, 0x22, 0x5C, 0x22, 0x5E, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x5F, 0x23, 0x60, 0x23, 0x60, 0x22, 0x60, 0x22, 0x62, 0x24, 0x61, 0x24, 0x61, 0x23, 0x61, 0x22, 0x64, 0x24, 0x64, 0x24, 0x62, 0x24, 0x65, 0x23, 0x63, 0x24, 0x64, 0x24, 0x64, 0x24, 0x64, 0x24, 0x64, 0x24, 0x65, 0x25, 0x67, 0x25, 0x66, 0x25, 0x67, 0x25, 0x66, 0x25, 0x64, 0x24, 0x64, 0x24, 0x63, 0x25, 0x58, 0x22, 0x42, 0x1D, 0x3C, 0x1D, 0x53, 0x22, 0x62, 0x25, 0x5F, 0x26, 0x57, 0x22, 0x3A, 0x1B, 0x28, 0x17, 0x24, 0x16, 0x22, 0x15, 0x20, 0x15, 0x1D, 0x14, 0x1C, 0x14, 0x1E, 0x17, 0x2A, 0x27, 0x4D, 0x48, 0x70, 0x5E, 0x7B, 0x65, 0x7F, 0x69, 0x82, 0x69, 0x82, 0x6B, 0x85, 0x6C, 0x88, 0x6F, 0x89, 0x6F, 0x89, 0x70, 0x8B, 0x71, 0x8C, 0x73, 0x8D, 0x72, 0x8E, 0x75, 0x91, 0x73, 0x8C, 0x71, 0x8E, 0x75, 0x8E, 0x72, 0x8A, 0x70, 0x8A, 0x6F, 0x8A, 0x6F, 0x8B, 0x72, 0x8D, 0x72, 0x89, 0x71, 0x89, 0x6F, 0x8B, 0x6D, 0x73, 0x53, 0x3C, 0x2A, 0x2B, 0x1E, 0x27, 0x1D, 0x24, 0x18, 0x1F, 0x15, 0x20, 0x16, 0x21, 0x16, 0x25, 0x19, 0x43, 0x21, 0x60, 0x26, 0x64, 0x27, 0x5F, 0x25, 0x3C, 0x1E, 0x41, 0x21, 0x5F, 0x26, 0x66, 0x28, 0x67, 0x26, 0x68, 0x28, 0x6D, 0x28, 0x67, 0x28, 0x6A, 0x28, 0x67, 0x28, 0x69, 0x27, 0x68, 0x28, 0x66, 0x28, 0x69, 0x28, 0x69, 0x27, 0x6F, 0x2A, 0x6F, 0x2C, 0x72, 0x2D, 0x70, 0x2B, 0x6B, 0x28, 0x68, 0x28, 0x70, 0x2B, 0x74, 0x2F, 0x69, 0x28, 0x69, 0x28, 0x6D, 0x2A, 0x6C, 0x29, 0x6C, 0x29, 0x6F, 0x29, 0x6A, 0x28, 0x6D, 0x29, 0x6E, 0x29, 0x71, 0x2B, 0x70, 0x2B, 0x71, 0x2C, 0x6F, 0x2A, 0x6F, 0x2A, 0x6B, 0x29, 0x6E, 0x28, 0x6E, 0x29, 0x6A, 0x28, 0x6C, 0x29, 0x6D, 0x28, 0x6B, 0x29, 0x74, 0x2D, 0x78, 0x2D, 0x6F, 0x29, 0x6D, 0x29, 0x69, 0x28, 0x6C, 0x2A, 0x6E, 0x2A, 0x6C, 0x28, 0x6E, 0x2A, 0x6B, 0x29, 0x6A, 0x29, 0x6B, 0x29, 0x6C, 0x29, 0x6C, 0x29, 0x6B, 0x28, 0x68, 0x28, 0x68, 0x29, 0x73, 0x2B, 0x6C, 0x28, 0x6F, 0x2B, 0x6F, 0x2B, 0x71, 0x2B, 0x70, 0x29, 0x6B, 0x28, 0x69, 0x27, 0x6D, 0x28, 0x6C, 0x28, 0x6C, 0x27, 0x68, 0x27, 0x68, 0x27, 0x69, 0x28, 0x6A, 0x27, 0x6D, 0x28, 0x6A, 0x27, 0x66, 0x26, 0x5F, 0x25, 0x52, 0x27, 0x53, 0x29, 0x50, 0x28, 0x51, 0x2A, 0x53, 0x29, 0x54, 0x25, 0x5E, 0x26, 0x69, 0x28, 0x6A, 0x29, 0x75, 0x2E, 0x6F, 0x2B, 0x6C, 0x28, 0x67, 0x27, 0x6C, 0x28, 0x6C, 0x28, 0x68, 0x27, 0x6A, 0x28, 0x69, 0x28, 0x68, 0x28, 0x68, 0x29, 0x66, 0x26, 0x65, 0x26, 0x66, 0x27, 0x67, 0x27, 0x65, 0x26, 0x63, 0x26, 0x62, 0x25, 0x65, 0x25, 0x67, 0x26, 0x66, 0x26, 0x64, 0x25, 0x62, 0x25, 0x63, 0x25, 0x60, 0x24, 0x62, 0x25, 0x62, 0x24, 0x63, 0x25, 0x60, 0x23, 0x60, 0x24, 0x62, 0x25, 0x60, 0x24, 0x5E, 0x24, 0x60, 0x23, 0x63, 0x25, 0x62, 0x25, 0x61, 0x24, 0x61, 0x23, 0x5F, 0x23, 0x65, 0x25, 0x62, 0x25, 0x62, 0x24, 0x63, 0x25, 0x62, 0x25, 0x62, 0x25, 0x5E, 0x24, 0x5E, 0x24, 0x61, 0x24, 0x61, 0x25, 0x63, 0x26, 0x60, 0x25, 0x64, 0x27, 0x66, 0x27, 0x63, 0x26, 0x63, 0x27, 0x61, 0x26, 0x5E, 0x25, 0x5D, 0x23, 0x5A, 0x23, 0x62, 0x26, 0x61, 0x27, 0x63, 0x27, 0x60, 0x24, 0x5E, 0x24, 0x5D, 0x24, 0x5C, 0x22, 0x5E, 0x23, 0x5D, 0x23, 0x59, 0x22, 0x59, 0x22, 0x5C, 0x23, 0x5C, 0x22, 0x5A, 0x22, 0x5C, 0x24, 0x5C, 0x23, 0x5A, 0x22, 0x58, 0x21, 0x5B, 0x21, 0x4A, 0x1E, 0x3B, 0x20, 0x33, 0x1E, 0x3E, 0x22, 0x39, 0x1E, 0x32, 0x1C, 0x3D, 0x21, 0x3F, 0x21, 0x40, 0x21, 0x34, 0x1D, 0x44, 0x23, 0x39, 0x1F, 0x3F, 0x23, 0x36, 0x1D, 0x40, 0x23, 0x3E, 0x20, 0x32, 0x1C, 0x39, 0x1F, 0x30, 0x1C, 0x38, 0x1E, 0x34, 0x1E, 0x3A, 0x1F, 0x2D, 0x1B, 0x31, 0x1B, 0x2F, 0x1B, 0x32, 0x1C, 0x2E, 0x1B, 0x35, 0x1D, 0x34, 0x1E, 0x39, 0x1F, 0x37, 0x1E, 0x37, 0x1D, 0x36, 0x1E, 0x40, 0x21, 0x39, 0x1F, 0x40, 0x21, 0x34, 0x1C, 0x3F, 0x21, 0x33, 0x1C, 0x2E, 0x1A, 0x33, 0x1C, 0x39, 0x1E, 0x37, 0x1F, 0x43, 0x22, 0x33, 0x1B, 0x31, 0x1C, 0x32, 0x1B, 0x3A, 0x1E
    },

    {
        0x63, 0x58, 0x63, 0x58, 0x63, 0x57, 0x63, 0x58, 0x65, 0x59, 0x67, 0x5B, 0x67, 0x5B, 0x67, 0x5B, 0x66, 0x5A, 0x67, 0x5A, 0x68, 0x5B, 0x69, 0x5D, 0x6A, 0x5D, 0x6D, 0x5F, 0x6B, 0x5E, 0x6A, 0x5E, 0x6E, 0x60, 0x6E, 0x61, 0x6E, 0x5F, 0x6B, 0x5E, 0x6D, 0x5E, 0x6B, 0x5E, 0x6B, 0x5F, 0x6E, 0x60, 0x6F, 0x61, 0x6F, 0x61, 0x6E, 0x61, 0x71, 0x61, 0x6F, 0x60, 0x72, 0x63, 0x72, 0x63, 0x72, 0x63, 0x73, 0x63, 0x75, 0x65, 0x74, 0x64, 0x75, 0x65, 0x77, 0x66, 0x74, 0x64, 0x74, 0x65, 0x76, 0x66, 0x75, 0x65, 0x73, 0x65, 0x76, 0x68, 0x77, 0x68, 0x76, 0x68, 0x78, 0x67, 0x76, 0x66, 0x75, 0x66, 0x74, 0x66, 0x72, 0x66, 0x6A, 0x5D, 0x53, 0x46, 0x42, 0x3D, 0x53, 0x50, 0x68, 0x62, 0x6A, 0x64, 0x64, 0x5A, 0x46, 0x3D, 0x2B, 0x2A, 0x23, 0x25, 0x20, 0x23, 0x1D, 0x20, 0x1B, 0x1E, 0x19, 0x1C, 0x1A, 0x1E, 0x20, 0x28, 0x36, 0x4A, 0x55, 0x6E, 0x64, 0x7A, 0x6B, 0x7E, 0x6D, 0x80, 0x70, 0x81, 0x72, 0x84, 0x75, 0x88, 0x76, 0x89, 0x77, 0x88, 0x78, 0x8C, 0x79, 0x8B, 0x79, 0x8D, 0x7A, 0x90, 0x7C, 0x8F, 0x79, 0x8C, 0x79, 0x8D, 0x79, 0x8D, 0x77, 0x89, 0x76, 0x89, 0x76, 0x88, 0x76, 0x8A, 0x78, 0x8B, 0x75, 0x89, 0x74, 0x88, 0x72, 0x88, 0x5B, 0x61, 0x30, 0x33, 0x24, 0x29, 0x1F, 0x26, 0x1C, 0x21, 0x1A, 0x20, 0x1B, 0x20, 0x1E, 0x22, 0x28, 0x2D, 0x4E, 0x53, 0x6A, 0x64, 0x6C, 0x67, 0x5E, 0x54, 0x3D, 0x38, 0x4D, 0x4F, 0x6A, 0x64, 0x73, 0x69, 0x76, 0x69, 0x77, 0x6D, 0x7B, 0x6B, 0x79, 0x6C, 0x79, 0x6D, 0x76, 0x6B, 0x75, 0x68, 0x77, 0x6B, 0x73, 0x69, 0x75, 0x6A, 0x75, 0x6A, 0x7A, 0x6F, 0x7D, 0x75, 0x7D, 0x73, 0x7C, 0x75, 0x7B, 0x6E, 0x77, 0x69, 0x7D, 0x70, 0x7F, 0x73, 0x77, 0x69, 0x78, 0x6F, 0x7B, 0x6E, 0x79, 0x6B, 0x7B, 0x70, 0x7C, 0x70, 0x7B, 0x6D, 0x7A, 0x6F, 0x7E, 0x71, 0x81, 0x74, 0x81, 0x74, 0x80, 0x74, 0x7F, 0x71, 0x7B, 0x6D, 0x7C, 0x6E, 0x7D, 0x6F, 0x7D, 0x71, 0x79, 0x6D, 0x7C, 0x6E, 0x7B, 0x6D, 0x7A, 0x6E, 0x82, 0x78, 0x84, 0x79, 0x7E, 0x6E, 0x79, 0x6D, 0x78, 0x6C, 0x79, 0x6D, 0x7D, 0x71, 0x7B, 0x6C, 0x7A, 0x6F, 0x75, 0x69, 0x75, 0x6B, 0x79, 0x6E, 0x7D, 0x6F, 0x78, 0x6C, 0x7B, 0x6D, 0x79, 0x6C, 0x7A, 0x70, 0x83, 0x77, 0x7D, 0x70, 0x7B, 0x6F, 0x7D, 0x70, 0x7F, 0x73, 0x80, 0x72, 0x7B, 0x6C, 0x79, 0x6D, 0x7C, 0x6F, 0x7B, 0x6E, 0x79, 0x6D, 0x78, 0x69, 0x78, 0x6B, 0x79, 0x69, 0x76, 0x6A, 0x7E, 0x6F, 0x76, 0x6A, 0x79, 0x6A, 0x68, 0x5D, 0x54, 0x53, 0x50, 0x51, 0x4F, 0x51, 0x4F, 0x54, 0x4F, 0x53, 0x54, 0x55, 0x67, 0x62, 0x74, 0x6C, 0x79, 0x6D, 0x81, 0x78, 0x7E, 0x70, 0x7D, 0x6B, 0x74, 0x69, 0x7A, 0x6D, 0x79, 0x6C, 0x75, 0x6A, 0x78, 0x6C, 0x74, 0x6A, 0x74, 0x6C, 0x74, 0x6C, 0x75, 0x67, 0x77, 0x67, 0x74, 0x67, 0x74, 0x67, 0x73, 0x67, 0x71, 0x66, 0x70, 0x64, 0x76, 0x67, 0x75, 0x68, 0x72, 0x67, 0x71, 0x65, 0x6E, 0x63, 0x70, 0x64, 0x71, 0x65, 0x70, 0x64, 0x70, 0x64, 0x70, 0x65, 0x6F, 0x62, 0x70, 0x64, 0x72, 0x65, 0x71, 0x63, 0x6C, 0x5F, 0x6E, 0x63, 0x71, 0x64, 0x71, 0x65, 0x72, 0x66, 0x70, 0x63, 0x6D, 0x61, 0x73, 0x67, 0x71, 0x64, 0x70, 0x63, 0x72, 0x65, 0x70, 0x65, 0x70, 0x64, 0x6E, 0x61, 0x6E, 0x63, 0x6F, 0x63, 0x6D, 0x63, 0x6E, 0x64, 0x6B, 0x61, 0x71, 0x67, 0x6E, 0x67, 0x6E, 0x64, 0x6F, 0x67, 0x6E, 0x64, 0x69, 0x5F, 0x68, 0x5E, 0x6A, 0x5F, 0x6D, 0x66, 0x6A, 0x65, 0x6B, 0x64, 0x6B, 0x60, 0x6C, 0x60, 0x6C, 0x60, 0x6B, 0x5D, 0x6D, 0x62, 0x6D, 0x60, 0x66, 0x5B, 0x65, 0x5B, 0x69, 0x5F, 0x6A, 0x5D, 0x69, 0x5E, 0x68, 0x5F, 0x6B, 0x5F, 0x67, 0x5B, 0x64, 0x5C, 0x68, 0x5C, 0x50, 0x46, 0x36, 0x3A, 0x30, 0x37, 0x38, 0x3E, 0x38, 0x3E, 0x30, 0x36, 0x3B, 0x42, 0x38, 0x3F, 0x38, 0x3F, 0x2F, 0x38, 0x3A, 0x41, 0x33, 0x3B, 0x38, 0x3F, 0x2D, 0x31, 0x38, 0x46, 0x33, 0x36, 0x2D, 0x35, 0x33, 0x36, 0x2C, 0x31, 0x2F, 0x32, 0x2E, 0x38, 0x32, 0x35, 0x29, 0x2E, 0x2B, 0x30, 0x29, 0x31, 0x2D, 0x31, 0x2C, 0x33, 0x30, 0x36, 0x31, 0x3A, 0x37, 0x3D, 0x32, 0x3A, 0x32, 0x37, 0x33, 0x3C, 0x3A, 0x41, 0x33, 0x3A, 0x3A, 0x40, 0x2E, 0x35, 0x35, 0x3A, 0x2D, 0x31, 0x2B, 0x2E, 0x31, 0x39, 0x31, 0x37, 0x34, 0x3F, 0x3B, 0x40, 0x2C, 0x2F, 0x2D, 0x34, 0x2D, 0x33, 0x33, 0x39
    },

    {
        0x58, 0x1F, 0x55, 0x1E, 0x56, 0x20, 0x57, 0x1F, 0x58, 0x20, 0x5B, 0x21, 0x5A, 0x20, 0x58, 0x20, 0x5A, 0x20, 0x58, 0x20, 0x5A, 0x20, 0x5A, 0x21, 0x5A, 0x20, 0x5C, 0x21, 0x5E, 0x21, 0x5E, 0x21, 0x5F, 0x23, 0x5F, 0x23, 0x61, 0x23, 0x5F, 0x22, 0x5D, 0x22, 0x5E, 0x21, 0x5E, 0x22, 0x5F, 0x22, 0x62, 0x23, 0x61, 0x23, 0x61, 0x23, 0x62, 0x23, 0x63, 0x24, 0x61, 0x23, 0x62, 0x23, 0x61, 0x22, 0x61, 0x23, 0x62, 0x23, 0x64, 0x24, 0x67, 0x24, 0x65, 0x24, 0x64, 0x24, 0x63, 0x24, 0x63, 0x23, 0x64, 0x23, 0x65, 0x24, 0x66, 0x25, 0x65, 0x25, 0x67, 0x25, 0x68, 0x26, 0x68, 0x25, 0x65, 0x24, 0x65, 0x25, 0x67, 0x26, 0x66, 0x26, 0x5D, 0x23, 0x49, 0x1E, 0x3C, 0x1E, 0x4F, 0x24, 0x62, 0x27, 0x64, 0x28, 0x5A, 0x24, 0x3E, 0x1C, 0x2A, 0x18, 0x26, 0x17, 0x23, 0x16, 0x21, 0x15, 0x1E, 0x14, 0x1D, 0x14, 0x1C, 0x15, 0x27, 0x21, 0x45, 0x3F, 0x6C, 0x5B, 0x79, 0x63, 0x7D, 0x66, 0x81, 0x68, 0x84, 0x6B, 0x87, 0x6E, 0x88, 0x70, 0x8A, 0x6F, 0x8B, 0x71, 0x8B, 0x72, 0x8C, 0x72, 0x8D, 0x74, 0x8E, 0x74, 0x8C, 0x73, 0x89, 0x71, 0x88, 0x6F, 0x89, 0x6F, 0x89, 0x6F, 0x89, 0x6F, 0x88, 0x6F, 0x89, 0x6E, 0x88, 0x71, 0x88, 0x6F, 0x7A, 0x5A, 0x43, 0x2D, 0x2A, 0x1D, 0x25, 0x1A, 0x21, 0x17, 0x1F, 0x15, 0x1E, 0x14, 0x1F, 0x16, 0x25, 0x19, 0x44, 0x22, 0x5F, 0x28, 0x67, 0x29, 0x61, 0x28, 0x3E, 0x1F, 0x40, 0x20, 0x61, 0x27, 0x62, 0x27, 0x6C, 0x2A, 0x69, 0x27, 0x69, 0x29, 0x6D, 0x29, 0x6F, 0x2A, 0x6B, 0x28, 0x6A, 0x28, 0x66, 0x26, 0x68, 0x27, 0x6C, 0x2A, 0x6B, 0x28, 0x69, 0x28, 0x6D, 0x29, 0x72, 0x2C, 0x6F, 0x2B, 0x6C, 0x2B, 0x71, 0x2B, 0x6F, 0x2A, 0x6D, 0x28, 0x6B, 0x29, 0x71, 0x2A, 0x6F, 0x2A, 0x6C, 0x2A, 0x6C, 0x29, 0x6E, 0x29, 0x6E, 0x29, 0x6E, 0x29, 0x6C, 0x29, 0x6F, 0x29, 0x6C, 0x29, 0x70, 0x2B, 0x6F, 0x2B, 0x71, 0x2B, 0x6D, 0x29, 0x6E, 0x29, 0x6D, 0x28, 0x6A, 0x28, 0x69, 0x29, 0x6F, 0x2C, 0x76, 0x2E, 0x75, 0x2A, 0x74, 0x2C, 0x6E, 0x2A, 0x6E, 0x29, 0x6C, 0x2A, 0x6C, 0x28, 0x6B, 0x29, 0x6F, 0x29, 0x6D, 0x28, 0x6E, 0x29, 0x6D, 0x29, 0x68, 0x27, 0x69, 0x27, 0x6D, 0x29, 0x6D, 0x29, 0x6D, 0x29, 0x6F, 0x29, 0x70, 0x2A, 0x6F, 0x2A, 0x71, 0x2A, 0x70, 0x2A, 0x71, 0x2A, 0x72, 0x2A, 0x71, 0x2A, 0x70, 0x29, 0x72, 0x2B, 0x70, 0x29, 0x6B, 0x27, 0x6D, 0x28, 0x6F, 0x29, 0x6B, 0x27, 0x68, 0x27, 0x6A, 0x28, 0x68, 0x27, 0x6E, 0x2A, 0x67, 0x26, 0x58, 0x25, 0x4E, 0x27, 0x4E, 0x27, 0x4E, 0x27, 0x4F, 0x29, 0x51, 0x27, 0x4D, 0x26, 0x52, 0x24, 0x66, 0x29, 0x6B, 0x28, 0x6E, 0x29, 0x70, 0x2B, 0x6F, 0x2A, 0x6A, 0x27, 0x68, 0x26, 0x67, 0x26, 0x66, 0x26, 0x64, 0x26, 0x68, 0x27, 0x6B, 0x29, 0x66, 0x27, 0x65, 0x25, 0x66, 0x26, 0x60, 0x24, 0x60, 0x23, 0x65, 0x25, 0x61, 0x24, 0x64, 0x25, 0x62, 0x24, 0x66, 0x25, 0x63, 0x25, 0x62, 0x24, 0x62, 0x24, 0x62, 0x25, 0x6A, 0x27, 0x62, 0x23, 0x5E, 0x23, 0x5F, 0x24, 0x63, 0x24, 0x60, 0x23, 0x61, 0x23, 0x5E, 0x22, 0x61, 0x24, 0x64, 0x26, 0x5F, 0x24, 0x5B, 0x22, 0x61, 0x24, 0x60, 0x24, 0x60, 0x24, 0x65, 0x25, 0x65, 0x26, 0x61, 0x24, 0x5E, 0x23, 0x63, 0x26, 0x66, 0x26, 0x68, 0x28, 0x63, 0x26, 0x65, 0x28, 0x65, 0x27, 0x67, 0x29, 0x65, 0x27, 0x67, 0x2B, 0x66, 0x2A, 0x66, 0x28, 0x62, 0x26, 0x61, 0x26, 0x61, 0x25, 0x5B, 0x24, 0x5E, 0x24, 0x60, 0x27, 0x61, 0x28, 0x5C, 0x25, 0x5E, 0x24, 0x5C, 0x23, 0x5D, 0x24, 0x60, 0x25, 0x5E, 0x23, 0x5C, 0x23, 0x56, 0x21, 0x59, 0x21, 0x5A, 0x22, 0x5C, 0x23, 0x5C, 0x23, 0x5E, 0x23, 0x5C, 0x24, 0x5B, 0x22, 0x5A, 0x22, 0x59, 0x22, 0x4F, 0x24, 0x48, 0x24, 0x3E, 0x21, 0x41, 0x23, 0x41, 0x21, 0x35, 0x1D, 0x3C, 0x1F, 0x30, 0x1C, 0x35, 0x1D, 0x34, 0x1E, 0x34, 0x1C, 0x38, 0x1F, 0x34, 0x1C, 0x32, 0x1C, 0x3C, 0x20, 0x33, 0x1C, 0x3C, 0x21, 0x38, 0x1D, 0x31, 0x1C, 0x34, 0x1C, 0x36, 0x1F, 0x38, 0x1E, 0x38, 0x1E, 0x3E, 0x21, 0x35, 0x1C, 0x41, 0x21, 0x38, 0x1E, 0x3E, 0x21, 0x3B, 0x21, 0x40, 0x21, 0x36, 0x1E, 0x37, 0x1C, 0x38, 0x1F, 0x38, 0x1D, 0x2E, 0x1B, 0x36, 0x1D, 0x35, 0x1D, 0x3C, 0x20, 0x38, 0x1E, 0x31, 0x1C, 0x38, 0x1F, 0x33, 0x1B, 0x39, 0x20, 0x37, 0x1D, 0x2F, 0x19, 0x37, 0x1E, 0x3F, 0x21, 0x3D, 0x21
    },

    {
        0x64, 0x59, 0x63, 0x57, 0x61, 0x58, 0x63, 0x57, 0x65, 0x5A, 0x66, 0x5B, 0x67, 0x5A, 0x66, 0x5A, 0x67, 0x5B, 0x67, 0x5A, 0x66, 0x5B, 0x69, 0x5C, 0x68, 0x5C, 0x6B, 0x5D, 0x6D, 0x5E, 0x6C, 0x5E, 0x6D, 0x60, 0x6D, 0x61, 0x6F, 0x61, 0x6E, 0x60, 0x6C, 0x5D, 0x6B, 0x5F, 0x6C, 0x5F, 0x6E, 0x60, 0x6F, 0x63, 0x70, 0x62, 0x71, 0x62, 0x71, 0x61, 0x73, 0x63, 0x70, 0x61, 0x72, 0x62, 0x72, 0x62, 0x72, 0x63, 0x74, 0x64, 0x75, 0x65, 0x77, 0x67, 0x77, 0x66, 0x76, 0x63, 0x73, 0x62, 0x73, 0x64, 0x74, 0x64, 0x74, 0x63, 0x76, 0x67, 0x75, 0x65, 0x77, 0x67, 0x77, 0x69, 0x79, 0x68, 0x76, 0x65, 0x73, 0x67, 0x77, 0x69, 0x73, 0x67, 0x6C, 0x61, 0x5A, 0x4A, 0x43, 0x3D, 0x4E, 0x50, 0x65, 0x62, 0x6A, 0x64, 0x61, 0x5B, 0x49, 0x41, 0x30, 0x2C, 0x25, 0x27, 0x21, 0x23, 0x1E, 0x21, 0x1C, 0x1E, 0x1A, 0x1D, 0x19, 0x1D, 0x1F, 0x25, 0x30, 0x40, 0x4F, 0x68, 0x62, 0x77, 0x69, 0x7D, 0x6D, 0x80, 0x71, 0x83, 0x74, 0x86, 0x75, 0x89, 0x77, 0x8A, 0x78, 0x8A, 0x78, 0x8B, 0x78, 0x8A, 0x79, 0x8C, 0x7A, 0x8E, 0x78, 0x8E, 0x76, 0x89, 0x74, 0x85, 0x76, 0x89, 0x75, 0x88, 0x76, 0x8A, 0x77, 0x8A, 0x76, 0x85, 0x74, 0x89, 0x72, 0x84, 0x5C, 0x67, 0x33, 0x34, 0x25, 0x28, 0x1F, 0x23, 0x1C, 0x20, 0x1B, 0x1F, 0x1A, 0x1E, 0x1D, 0x21, 0x29, 0x2D, 0x4E, 0x55, 0x68, 0x64, 0x6F, 0x6A, 0x5F, 0x57, 0x3E, 0x38, 0x4C, 0x4F, 0x6D, 0x66, 0x6F, 0x66, 0x75, 0x6D, 0x74, 0x69, 0x74, 0x6B, 0x7A, 0x6F, 0x7E, 0x70, 0x79, 0x6B, 0x78, 0x69, 0x74, 0x66, 0x78, 0x6A, 0x7B, 0x71, 0x7B, 0x6E, 0x7C, 0x6E, 0x7B, 0x6F, 0x7E, 0x73, 0x7D, 0x6F, 0x76, 0x6A, 0x7E, 0x72, 0x7C, 0x70, 0x7C, 0x70, 0x7B, 0x6C, 0x7D, 0x71, 0x7C, 0x71, 0x7A, 0x6F, 0x79, 0x6C, 0x7B, 0x6D, 0x7A, 0x70, 0x7B, 0x6E, 0x78, 0x6C, 0x7D, 0x70, 0x79, 0x6A, 0x7B, 0x6E, 0x80, 0x72, 0x7E, 0x71, 0x7D, 0x71, 0x7C, 0x6E, 0x79, 0x6B, 0x74, 0x69, 0x78, 0x6D, 0x7C, 0x72, 0x81, 0x78, 0x81, 0x73, 0x83, 0x74, 0x7D, 0x6F, 0x79, 0x6D, 0x79, 0x70, 0x7B, 0x6E, 0x79, 0x6C, 0x80, 0x71, 0x7C, 0x6F, 0x7A, 0x6D, 0x7A, 0x6F, 0x77, 0x6A, 0x77, 0x6D, 0x7C, 0x70, 0x7C, 0x6F, 0x7E, 0x71, 0x7F, 0x71, 0x81, 0x72, 0x7E, 0x70, 0x80, 0x71, 0x7E, 0x72, 0x80, 0x71, 0x83, 0x73, 0x7E, 0x71, 0x7F, 0x71, 0x80, 0x73, 0x7E, 0x6E, 0x7D, 0x6E, 0x7E, 0x6F, 0x7F, 0x70, 0x7A, 0x6B, 0x7A, 0x6B, 0x7B, 0x6D, 0x78, 0x6B, 0x79, 0x71, 0x74, 0x65, 0x5E, 0x56, 0x4E, 0x4E, 0x4C, 0x4E, 0x4B, 0x4D, 0x4C, 0x52, 0x4D, 0x4F, 0x4B, 0x4D, 0x51, 0x50, 0x6D, 0x68, 0x7A, 0x6E, 0x7A, 0x6D, 0x7D, 0x71, 0x7E, 0x70, 0x78, 0x6B, 0x76, 0x6B, 0x74, 0x66, 0x75, 0x68, 0x77, 0x69, 0x78, 0x6B, 0x7A, 0x6E, 0x73, 0x65, 0x70, 0x66, 0x75, 0x67, 0x70, 0x64, 0x6F, 0x63, 0x73, 0x65, 0x6D, 0x63, 0x72, 0x66, 0x70, 0x63, 0x77, 0x6A, 0x71, 0x65, 0x71, 0x64, 0x73, 0x65, 0x70, 0x67, 0x76, 0x69, 0x6F, 0x61, 0x6E, 0x61, 0x6D, 0x63, 0x71, 0x63, 0x71, 0x63, 0x72, 0x63, 0x6F, 0x61, 0x71, 0x64, 0x72, 0x66, 0x6C, 0x60, 0x6A, 0x5D, 0x6E, 0x62, 0x6E, 0x61, 0x6E, 0x63, 0x73, 0x66, 0x73, 0x66, 0x6F, 0x64, 0x6E, 0x62, 0x72, 0x66, 0x72, 0x65, 0x74, 0x6A, 0x71, 0x66, 0x72, 0x69, 0x6F, 0x66, 0x71, 0x69, 0x71, 0x67, 0x73, 0x6B, 0x6F, 0x68, 0x70, 0x69, 0x6C, 0x62, 0x70, 0x64, 0x6F, 0x64, 0x69, 0x5E, 0x6A, 0x60, 0x6A, 0x62, 0x6A, 0x63, 0x69, 0x5F, 0x68, 0x5E, 0x69, 0x5D, 0x6B, 0x60, 0x6D, 0x63, 0x6A, 0x5D, 0x6A, 0x5E, 0x63, 0x5A, 0x66, 0x5B, 0x67, 0x5B, 0x69, 0x5D, 0x6C, 0x60, 0x6C, 0x60, 0x69, 0x5F, 0x67, 0x5C, 0x66, 0x5C, 0x67, 0x5C, 0x54, 0x52, 0x44, 0x48, 0x36, 0x3E, 0x3C, 0x44, 0x35, 0x39, 0x30, 0x38, 0x32, 0x34, 0x2D, 0x34, 0x30, 0x32, 0x2F, 0x38, 0x2E, 0x30, 0x33, 0x3C, 0x30, 0x35, 0x2F, 0x37, 0x34, 0x3D, 0x2D, 0x31, 0x39, 0x43, 0x33, 0x37, 0x30, 0x36, 0x30, 0x36, 0x32, 0x3B, 0x37, 0x3D, 0x34, 0x3A, 0x37, 0x3D, 0x30, 0x38, 0x3C, 0x41, 0x32, 0x36, 0x38, 0x40, 0x35, 0x3D, 0x35, 0x39, 0x30, 0x39, 0x30, 0x33, 0x32, 0x38, 0x32, 0x36, 0x2B, 0x30, 0x2E, 0x34, 0x32, 0x3A, 0x39, 0x41, 0x35, 0x3A, 0x2E, 0x33, 0x33, 0x3B, 0x31, 0x34, 0x36, 0x3E, 0x32, 0x36, 0x2C, 0x2F, 0x33, 0x3C, 0x38, 0x40, 0x38, 0x3F
    },

    {
        0x57, 0x20, 0x57, 0x1F, 0x59, 0x20, 0x59, 0x20, 0x59, 0x20, 0x5B, 0x21, 0x5A, 0x21, 0x59, 0x20, 0x5A, 0x20, 0x5A, 0x20, 0x5B, 0x21, 0x5A, 0x21, 0x5A, 0x20, 0x5C, 0x21, 0x5E, 0x21, 0x5E, 0x22, 0x5F, 0x22, 0x60, 0x23, 0x60, 0x23, 0x61, 0x23, 0x5F, 0x22, 0x5E, 0x21, 0x5D, 0x21, 0x5E, 0x22, 0x5F, 0x23, 0x61, 0x24, 0x62, 0x24, 0x61, 0x23, 0x60, 0x23, 0x63, 0x24, 0x62, 0x23, 0x60, 0x23, 0x61, 0x23, 0x63, 0x23, 0x64, 0x24, 0x63, 0x23, 0x64, 0x23, 0x62, 0x23, 0x62, 0x24, 0x64, 0x24, 0x65, 0x24, 0x65, 0x25, 0x66, 0x25, 0x66, 0x25, 0x65, 0x25, 0x65, 0x25, 0x63, 0x24, 0x64, 0x24, 0x65, 0x25, 0x67, 0x26, 0x65, 0x25, 0x64, 0x25, 0x5F, 0x24, 0x50, 0x21, 0x3F, 0x1F, 0x4D, 0x24, 0x62, 0x28, 0x63, 0x28, 0x5A, 0x24, 0x47, 0x1E, 0x2E, 0x19, 0x26, 0x16, 0x22, 0x15, 0x20, 0x15, 0x1E, 0x14, 0x1D, 0x14, 0x1D, 0x15, 0x22, 0x1D, 0x3A, 0x38, 0x65, 0x57, 0x77, 0x62, 0x7E, 0x68, 0x82, 0x6B, 0x8A, 0x6E, 0x8B, 0x71, 0x8D, 0x72, 0x8D, 0x72, 0x8D, 0x72, 0x8C, 0x72, 0x8C, 0x73, 0x8E, 0x74, 0x8D, 0x72, 0x8B, 0x71, 0x89, 0x70, 0x8C, 0x73, 0x8C, 0x72, 0x88, 0x6E, 0x88, 0x6F, 0x89, 0x70, 0x89, 0x6E, 0x78, 0x56, 0x41, 0x2D, 0x2A, 0x1E, 0x25, 0x19, 0x20, 0x16, 0x1E, 0x15, 0x20, 0x16, 0x21, 0x16, 0x26, 0x18, 0x42, 0x22, 0x61, 0x29, 0x68, 0x2A, 0x63, 0x28, 0x41, 0x20, 0x3F, 0x21, 0x63, 0x27, 0x69, 0x28, 0x67, 0x28, 0x6E, 0x2C, 0x6B, 0x2A, 0x68, 0x28, 0x69, 0x28, 0x69, 0x28, 0x67, 0x28, 0x68, 0x27, 0x67, 0x27, 0x6A, 0x29, 0x72, 0x2B, 0x6C, 0x29, 0x6D, 0x29, 0x6C, 0x2A, 0x6E, 0x2B, 0x70, 0x2B, 0x6C, 0x2A, 0x6F, 0x2A, 0x70, 0x2B, 0x6B, 0x29, 0x6E, 0x29, 0x6D, 0x29, 0x6C, 0x29, 0x6E, 0x2A, 0x6E, 0x2A, 0x70, 0x2B, 0x6E, 0x2A, 0x6C, 0x29, 0x6C, 0x29, 0x68, 0x28, 0x6C, 0x29, 0x6E, 0x2B, 0x6F, 0x2A, 0x6C, 0x29, 0x6E, 0x29, 0x6C, 0x29, 0x6B, 0x28, 0x6A, 0x27, 0x6C, 0x2A, 0x71, 0x2B, 0x6E, 0x2B, 0x6A, 0x29, 0x6C, 0x28, 0x6A, 0x2A, 0x73, 0x2C, 0x6F, 0x2A, 0x6C, 0x29, 0x6D, 0x29, 0x6B, 0x28, 0x6D, 0x2C, 0x74, 0x2D, 0x72, 0x2C, 0x6D, 0x28, 0x6C, 0x29, 0x6A, 0x29, 0x6F, 0x2A, 0x6F, 0x2C, 0x73, 0x2B, 0x70, 0x2A, 0x6D, 0x2A, 0x6F, 0x2A, 0x6E, 0x2A, 0x6E, 0x29, 0x73, 0x2B, 0x6F, 0x2A, 0x6B, 0x29, 0x6B, 0x28, 0x71, 0x2A, 0x6E, 0x29, 0x6B, 0x27, 0x6C, 0x27, 0x6B, 0x28, 0x6B, 0x28, 0x68, 0x28, 0x69, 0x28, 0x6D, 0x29, 0x64, 0x25, 0x55, 0x27, 0x4E, 0x28, 0x50, 0x28, 0x51, 0x27, 0x50, 0x28, 0x50, 0x29, 0x50, 0x26, 0x3C, 0x1C, 0x59, 0x25, 0x6D, 0x28, 0x6B, 0x28, 0x68, 0x27, 0x6D, 0x28, 0x6A, 0x29, 0x6A, 0x28, 0x69, 0x27, 0x69, 0x27, 0x69, 0x28, 0x6B, 0x2B, 0x68, 0x28, 0x66, 0x26, 0x64, 0x25, 0x66, 0x26, 0x67, 0x26, 0x61, 0x24, 0x62, 0x24, 0x61, 0x25, 0x61, 0x24, 0x60, 0x25, 0x63, 0x24, 0x62, 0x25, 0x64, 0x26, 0x65, 0x25, 0x62, 0x24, 0x65, 0x26, 0x61, 0x24, 0x63, 0x24, 0x5E, 0x24, 0x5E, 0x23, 0x5E, 0x23, 0x60, 0x23, 0x63, 0x26, 0x68, 0x27, 0x62, 0x25, 0x63, 0x25, 0x64, 0x24, 0x5F, 0x24, 0x5E, 0x23, 0x60, 0x24, 0x63, 0x25, 0x64, 0x25, 0x62, 0x25, 0x64, 0x25, 0x65, 0x26, 0x62, 0x26, 0x61, 0x27, 0x61, 0x26, 0x66, 0x27, 0x65, 0x27, 0x63, 0x27, 0x66, 0x27, 0x62, 0x27, 0x63, 0x29, 0x66, 0x2A, 0x64, 0x28, 0x64, 0x26, 0x65, 0x27, 0x62, 0x26, 0x5F, 0x24, 0x61, 0x27, 0x6C, 0x2F, 0x65, 0x28, 0x61, 0x25, 0x5A, 0x23, 0x5B, 0x23, 0x5C, 0x24, 0x5D, 0x24, 0x5B, 0x23, 0x58, 0x21, 0x5A, 0x21, 0x5E, 0x22, 0x5C, 0x23, 0x5D, 0x23, 0x5C, 0x22, 0x5C, 0x24, 0x5C, 0x23, 0x5B, 0x24, 0x5D, 0x24, 0x51, 0x24, 0x3E, 0x21, 0x34, 0x1E, 0x3D, 0x20, 0x30, 0x1B, 0x35, 0x1D, 0x32, 0x1B, 0x37, 0x1E, 0x3D, 0x20, 0x3B, 0x20, 0x3D, 0x20, 0x3D, 0x22, 0x41, 0x21, 0x36, 0x1E, 0x3D, 0x21, 0x35, 0x1C, 0x3F, 0x22, 0x38, 0x1E, 0x3B, 0x21, 0x3C, 0x1F, 0x3D, 0x23, 0x3D, 0x20, 0x2F, 0x1B, 0x35, 0x1C, 0x36, 0x1E, 0x37, 0x1D, 0x2E, 0x1B, 0x3B, 0x20, 0x34, 0x1D, 0x3A, 0x20, 0x36, 0x1F, 0x36, 0x1D, 0x39, 0x20, 0x42, 0x22, 0x37, 0x1F, 0x3D, 0x20, 0x3C, 0x21, 0x3B, 0x21, 0x37, 0x1F, 0x35, 0x1F, 0x43, 0x26, 0x46, 0x26, 0x49, 0x28, 0x41, 0x23, 0x2E, 0x1A, 0x38, 0x1E, 0x32, 0x1C, 0x47, 0x2B
    },

    {
        0x63, 0x58, 0x62, 0x56, 0x62, 0x59, 0x63, 0x59, 0x67, 0x5B, 0x68, 0x5C, 0x67, 0x5B, 0x66, 0x5A, 0x67, 0x5A, 0x68, 0x5A, 0x68, 0x5B, 0x67, 0x5A, 0x68, 0x5B, 0x69, 0x5C, 0x6B, 0x5E, 0x6B, 0x5D, 0x6C, 0x60, 0x6D, 0x5F, 0x6D, 0x61, 0x6F, 0x60, 0x6E, 0x5F, 0x6C, 0x5F, 0x6C, 0x5D, 0x6D, 0x5E, 0x6C, 0x5E, 0x6E, 0x60, 0x70, 0x62, 0x6E, 0x60, 0x70, 0x61, 0x71, 0x61, 0x71, 0x63, 0x72, 0x62, 0x71, 0x61, 0x72, 0x63, 0x74, 0x64, 0x75, 0x64, 0x77, 0x64, 0x76, 0x63, 0x75, 0x65, 0x75, 0x65, 0x77, 0x66, 0x76, 0x66, 0x75, 0x66, 0x77, 0x66, 0x74, 0x65, 0x75, 0x67, 0x73, 0x65, 0x76, 0x65, 0x78, 0x68, 0x79, 0x68, 0x75, 0x65, 0x74, 0x67, 0x70, 0x63, 0x62, 0x54, 0x49, 0x41, 0x4A, 0x4C, 0x62, 0x60, 0x69, 0x65, 0x64, 0x5D, 0x54, 0x4C, 0x37, 0x33, 0x26, 0x27, 0x20, 0x23, 0x1E, 0x21, 0x1C, 0x1E, 0x1A, 0x1D, 0x1A, 0x1C, 0x1D, 0x21, 0x2A, 0x37, 0x48, 0x60, 0x60, 0x74, 0x69, 0x7F, 0x6E, 0x81, 0x75, 0x88, 0x76, 0x89, 0x77, 0x8B, 0x77, 0x8B, 0x76, 0x8B, 0x78, 0x8C, 0x79, 0x8A, 0x79, 0x8D, 0x79, 0x8B, 0x77, 0x89, 0x77, 0x88, 0x78, 0x8B, 0x78, 0x8C, 0x75, 0x88, 0x75, 0x87, 0x74, 0x88, 0x71, 0x86, 0x5E, 0x63, 0x33, 0x33, 0x24, 0x28, 0x1F, 0x22, 0x1B, 0x1F, 0x1A, 0x1F, 0x1C, 0x21, 0x1F, 0x23, 0x27, 0x2C, 0x4C, 0x53, 0x68, 0x65, 0x6F, 0x6A, 0x62, 0x5B, 0x40, 0x39, 0x49, 0x4E, 0x70, 0x6B, 0x73, 0x69, 0x74, 0x6B, 0x7B, 0x72, 0x78, 0x6C, 0x73, 0x67, 0x76, 0x6B, 0x76, 0x68, 0x78, 0x6A, 0x7A, 0x6C, 0x78, 0x69, 0x77, 0x6E, 0x7E, 0x6F, 0x7B, 0x6D, 0x7D, 0x70, 0x7B, 0x70, 0x7A, 0x6F, 0x7F, 0x74, 0x7D, 0x72, 0x7D, 0x71, 0x7E, 0x72, 0x77, 0x6C, 0x7A, 0x6F, 0x7D, 0x70, 0x7B, 0x6E, 0x7E, 0x73, 0x7C, 0x6E, 0x7F, 0x73, 0x7A, 0x6D, 0x79, 0x6C, 0x7A, 0x6E, 0x77, 0x6C, 0x7C, 0x71, 0x7C, 0x71, 0x7B, 0x6E, 0x79, 0x6C, 0x7C, 0x70, 0x7B, 0x6F, 0x79, 0x6E, 0x78, 0x69, 0x7B, 0x6E, 0x80, 0x72, 0x7F, 0x72, 0x79, 0x6A, 0x77, 0x68, 0x7C, 0x71, 0x7F, 0x75, 0x7E, 0x73, 0x7A, 0x6B, 0x7B, 0x6C, 0x79, 0x6C, 0x7C, 0x73, 0x81, 0x76, 0x7E, 0x74, 0x7A, 0x6B, 0x7C, 0x6E, 0x7C, 0x6E, 0x7F, 0x71, 0x7D, 0x72, 0x7F, 0x73, 0x7C, 0x70, 0x7C, 0x72, 0x80, 0x73, 0x7C, 0x70, 0x7C, 0x6E, 0x81, 0x76, 0x80, 0x71, 0x7A, 0x6D, 0x7B, 0x6D, 0x7F, 0x72, 0x7E, 0x70, 0x7C, 0x6D, 0x7B, 0x6D, 0x7C, 0x6E, 0x79, 0x6A, 0x75, 0x6A, 0x7A, 0x6D, 0x79, 0x6D, 0x76, 0x67, 0x5B, 0x55, 0x4F, 0x53, 0x4D, 0x4F, 0x4C, 0x4F, 0x4C, 0x4F, 0x4E, 0x52, 0x4D, 0x4E, 0x3D, 0x3B, 0x5F, 0x5E, 0x7C, 0x6E, 0x7A, 0x6B, 0x76, 0x6A, 0x7B, 0x6F, 0x79, 0x6C, 0x76, 0x69, 0x76, 0x6B, 0x78, 0x6D, 0x78, 0x6C, 0x75, 0x6C, 0x6D, 0x66, 0x70, 0x66, 0x6F, 0x67, 0x74, 0x67, 0x78, 0x69, 0x71, 0x63, 0x70, 0x64, 0x70, 0x65, 0x71, 0x64, 0x71, 0x63, 0x72, 0x65, 0x73, 0x65, 0x72, 0x66, 0x76, 0x67, 0x71, 0x65, 0x73, 0x64, 0x70, 0x62, 0x72, 0x65, 0x6C, 0x60, 0x6E, 0x61, 0x6D, 0x60, 0x6E, 0x60, 0x73, 0x68, 0x76, 0x68, 0x70, 0x63, 0x70, 0x64, 0x71, 0x64, 0x6F, 0x62, 0x6D, 0x61, 0x6F, 0x64, 0x71, 0x64, 0x71, 0x66, 0x6F, 0x64, 0x71, 0x66, 0x72, 0x67, 0x6F, 0x64, 0x6C, 0x64, 0x6E, 0x61, 0x70, 0x68, 0x73, 0x67, 0x70, 0x66, 0x70, 0x64, 0x6D, 0x65, 0x6D, 0x67, 0x70, 0x69, 0x6F, 0x64, 0x71, 0x68, 0x70, 0x66, 0x6D, 0x63, 0x6B, 0x60, 0x6D, 0x64, 0x73, 0x6E, 0x71, 0x68, 0x6D, 0x61, 0x6A, 0x5C, 0x6B, 0x5F, 0x6B, 0x60, 0x69, 0x5E, 0x67, 0x5D, 0x63, 0x59, 0x67, 0x5D, 0x6B, 0x5F, 0x69, 0x5F, 0x6A, 0x5F, 0x6B, 0x5E, 0x69, 0x5D, 0x67, 0x5D, 0x65, 0x5C, 0x69, 0x60, 0x53, 0x4E, 0x34, 0x36, 0x30, 0x37, 0x37, 0x39, 0x2E, 0x34, 0x33, 0x39, 0x31, 0x34, 0x35, 0x3F, 0x3B, 0x43, 0x35, 0x3C, 0x36, 0x3A, 0x38, 0x44, 0x38, 0x3E, 0x2D, 0x32, 0x37, 0x3F, 0x30, 0x35, 0x39, 0x41, 0x30, 0x34, 0x35, 0x3F, 0x32, 0x36, 0x37, 0x43, 0x34, 0x36, 0x2D, 0x33, 0x2F, 0x32, 0x31, 0x3B, 0x31, 0x35, 0x2B, 0x32, 0x33, 0x38, 0x31, 0x38, 0x37, 0x3C, 0x34, 0x3B, 0x34, 0x36, 0x36, 0x3D, 0x39, 0x40, 0x32, 0x38, 0x39, 0x3E, 0x33, 0x38, 0x34, 0x3B, 0x34, 0x39, 0x36, 0x3C, 0x44, 0x50, 0x46, 0x50, 0x47, 0x51, 0x3E, 0x44, 0x2A, 0x2F, 0x33, 0x38, 0x2F, 0x36, 0x42, 0x56
    },

    {
        0x57, 0x1F, 0x55, 0x1F, 0x56, 0x20, 0x59, 0x20, 0x5A, 0x21, 0x5C, 0x21, 0x5B, 0x21, 0x5C, 0x21, 0x5B, 0x20, 0x59, 0x20, 0x5A, 0x20, 0x57, 0x20, 0x59, 0x20, 0x5B, 0x21, 0x5D, 0x21, 0x5F, 0x23, 0x60, 0x23, 0x5D, 0x22, 0x5F, 0x23, 0x61, 0x23, 0x61, 0x23, 0x5F, 0x22, 0x5C, 0x21, 0x5B, 0x21, 0x5B, 0x21, 0x5C, 0x22, 0x5D, 0x22, 0x5F, 0x22, 0x61, 0x23, 0x62, 0x23, 0x63, 0x23, 0x60, 0x23, 0x5F, 0x22, 0x61, 0x22, 0x61, 0x23, 0x62, 0x22, 0x62, 0x23, 0x61, 0x23, 0x64, 0x23, 0x65, 0x24, 0x66, 0x24, 0x63, 0x24, 0x63, 0x25, 0x65, 0x25, 0x65, 0x25, 0x66, 0x24, 0x65, 0x24, 0x66, 0x25, 0x6A, 0x26, 0x67, 0x26, 0x68, 0x26, 0x66, 0x24, 0x66, 0x26, 0x65, 0x27, 0x58, 0x23, 0x42, 0x1F, 0x47, 0x23, 0x5C, 0x27, 0x61, 0x28, 0x61, 0x26, 0x50, 0x21, 0x34, 0x1A, 0x27, 0x17, 0x23, 0x16, 0x1F, 0x14, 0x1E, 0x14, 0x1D, 0x14, 0x1D, 0x14, 0x20, 0x1A, 0x33, 0x30, 0x5D, 0x52, 0x79, 0x63, 0x7F, 0x69, 0x84, 0x6B, 0x87, 0x6E, 0x88, 0x6F, 0x87, 0x70, 0x8A, 0x71, 0x8A, 0x71, 0x8A, 0x70, 0x89, 0x70, 0x8B, 0x72, 0x8B, 0x70, 0x8A, 0x72, 0x8B, 0x70, 0x8A, 0x70, 0x8A, 0x70, 0x8C, 0x72, 0x8C, 0x71, 0x7A, 0x5A, 0x42, 0x2E, 0x29, 0x1D, 0x23, 0x19, 0x20, 0x16, 0x1F, 0x15, 0x20, 0x16, 0x23, 0x17, 0x24, 0x17, 0x40, 0x20, 0x61, 0x27, 0x69, 0x29, 0x65, 0x27, 0x3F, 0x1F, 0x3F, 0x20, 0x5C, 0x26, 0x67, 0x29, 0x6A, 0x28, 0x6D, 0x2A, 0x6E, 0x29, 0x6D, 0x2B, 0x68, 0x29, 0x68, 0x28, 0x6B, 0x29, 0x6B, 0x28, 0x6D, 0x28, 0x69, 0x28, 0x68, 0x28, 0x6C, 0x2A, 0x6D, 0x29, 0x6C, 0x28, 0x6F, 0x2A, 0x6B, 0x29, 0x70, 0x2C, 0x70, 0x2A, 0x6D, 0x28, 0x6F, 0x29, 0x6D, 0x29, 0x6B, 0x28, 0x6A, 0x29, 0x6B, 0x28, 0x6D, 0x2A, 0x6D, 0x2A, 0x68, 0x2A, 0x6A, 0x29, 0x6A, 0x29, 0x71, 0x2C, 0x73, 0x2C, 0x71, 0x2C, 0x6E, 0x2C, 0x6C, 0x29, 0x6C, 0x29, 0x72, 0x2B, 0x6D, 0x29, 0x6C, 0x29, 0x6B, 0x29, 0x71, 0x2B, 0x6F, 0x2C, 0x6D, 0x29, 0x6E, 0x29, 0x68, 0x28, 0x6E, 0x29, 0x72, 0x2B, 0x6E, 0x2B, 0x6C, 0x2A, 0x6C, 0x29, 0x6D, 0x28, 0x6A, 0x28, 0x6A, 0x29, 0x6D, 0x2A, 0x6B, 0x29, 0x72, 0x2C, 0x72, 0x2C, 0x79, 0x2E, 0x75, 0x2F, 0x77, 0x2D, 0x71, 0x2B, 0x6F, 0x2A, 0x6F, 0x2B, 0x70, 0x2A, 0x6D, 0x28, 0x6D, 0x2B, 0x6D, 0x2A, 0x72, 0x2B, 0x6C, 0x29, 0x6E, 0x28, 0x6E, 0x2A, 0x6D, 0x28, 0x6F, 0x29, 0x69, 0x28, 0x6B, 0x28, 0x6C, 0x28, 0x6B, 0x27, 0x69, 0x27, 0x6A, 0x25, 0x56, 0x27, 0x51, 0x29, 0x4E, 0x28, 0x4F, 0x27, 0x50, 0x29, 0x53, 0x29, 0x49, 0x21, 0x32, 0x19, 0x51, 0x22, 0x68, 0x27, 0x67, 0x27, 0x69, 0x27, 0x69, 0x27, 0x66, 0x27, 0x66, 0x28, 0x6D, 0x2C, 0x72, 0x35, 0x7B, 0x42, 0x6D, 0x3C, 0x56, 0x2D, 0x4A, 0x23, 0x57, 0x26, 0x68, 0x28, 0x65, 0x27, 0x64, 0x26, 0x66, 0x27, 0x65, 0x26, 0x62, 0x25, 0x63, 0x24, 0x64, 0x25, 0x63, 0x25, 0x63, 0x24, 0x61, 0x24, 0x60, 0x24, 0x61, 0x24, 0x62, 0x24, 0x62, 0x24, 0x61, 0x24, 0x60, 0x23, 0x60, 0x24, 0x62, 0x24, 0x62, 0x25, 0x63, 0x25, 0x61, 0x24, 0x60, 0x24, 0x60, 0x24, 0x61, 0x25, 0x5E, 0x23, 0x60, 0x25, 0x60, 0x24, 0x63, 0x25, 0x61, 0x24, 0x5F, 0x24, 0x65, 0x26, 0x68, 0x28, 0x62, 0x25, 0x61, 0x24, 0x60, 0x25, 0x61, 0x26, 0x63, 0x27, 0x60, 0x24, 0x5E, 0x24, 0x62, 0x26, 0x60, 0x26, 0x66, 0x29, 0x65, 0x28, 0x5D, 0x24, 0x5F, 0x24, 0x5E, 0x23, 0x63, 0x26, 0x65, 0x29, 0x64, 0x27, 0x60, 0x25, 0x5E, 0x24, 0x5E, 0x24, 0x60, 0x24, 0x5A, 0x22, 0x5B, 0x23, 0x5B, 0x23, 0x5A, 0x22, 0x5A, 0x21, 0x5C, 0x22, 0x5B, 0x22, 0x57, 0x21, 0x5B, 0x23, 0x5B, 0x24, 0x5F, 0x26, 0x5F, 0x25, 0x50, 0x23, 0x3B, 0x1F, 0x3A, 0x20, 0x44, 0x22, 0x3F, 0x21, 0x37, 0x1E, 0x3C, 0x20, 0x42, 0x23, 0x3C, 0x1E, 0x34, 0x1D, 0x37, 0x1F, 0x3C, 0x21, 0x39, 0x1F, 0x30, 0x1B, 0x3A, 0x20, 0x34, 0x1D, 0x3B, 0x20, 0x33, 0x1C, 0x38, 0x1F, 0x35, 0x1F, 0x41, 0x24, 0x3C, 0x20, 0x35, 0x1E, 0x3A, 0x1E, 0x36, 0x1E, 0x3B, 0x1F, 0x35, 0x1E, 0x3E, 0x22, 0x3F, 0x24, 0x41, 0x25, 0x45, 0x27, 0x3F, 0x24, 0x45, 0x28, 0x44, 0x25, 0x30, 0x1C, 0x33, 0x1E, 0x35, 0x20, 0x63, 0x41, 0x7A, 0x4F, 0x84, 0x56, 0x93, 0x5E, 0x96, 0x5F, 0x99, 0x60, 0x7D, 0x49, 0x3B, 0x22, 0x3D, 0x21, 0x3D, 0x21, 0x61, 0x3F
    },

    {
        0x62, 0x58, 0x60, 0x56, 0x60, 0x58, 0x63, 0x5A, 0x66, 0x5B, 0x69, 0x5C, 0x6B, 0x5D, 0x69, 0x5D, 0x68, 0x5C, 0x67, 0x5A, 0x68, 0x5B, 0x65, 0x58, 0x67, 0x5A, 0x6A, 0x5C, 0x6B, 0x5F, 0x6D, 0x61, 0x6C, 0x61, 0x6C, 0x5F, 0x6C, 0x60, 0x6E, 0x62, 0x71, 0x63, 0x6E, 0x60, 0x6C, 0x5E, 0x6C, 0x5C, 0x6B, 0x5C, 0x6C, 0x5E, 0x6E, 0x5E, 0x6E, 0x5F, 0x70, 0x62, 0x72, 0x63, 0x74, 0x64, 0x70, 0x60, 0x70, 0x60, 0x72, 0x62, 0x73, 0x62, 0x72, 0x62, 0x74, 0x64, 0x74, 0x62, 0x74, 0x64, 0x77, 0x65, 0x78, 0x68, 0x74, 0x63, 0x74, 0x66, 0x74, 0x67, 0x75, 0x66, 0x76, 0x68, 0x77, 0x65, 0x76, 0x68, 0x79, 0x69, 0x79, 0x6A, 0x7B, 0x6A, 0x77, 0x68, 0x76, 0x69, 0x73, 0x67, 0x68, 0x5C, 0x4F, 0x45, 0x47, 0x47, 0x5B, 0x5B, 0x69, 0x63, 0x68, 0x63, 0x5B, 0x52, 0x3E, 0x37, 0x28, 0x28, 0x23, 0x24, 0x1E, 0x20, 0x1C, 0x1E, 0x1B, 0x1D, 0x19, 0x1C, 0x1C, 0x1F, 0x25, 0x30, 0x42, 0x5A, 0x5F, 0x75, 0x69, 0x7E, 0x6F, 0x84, 0x73, 0x87, 0x74, 0x87, 0x75, 0x87, 0x76, 0x89, 0x76, 0x8A, 0x79, 0x8A, 0x76, 0x8A, 0x78, 0x8B, 0x77, 0x8A, 0x77, 0x8A, 0x76, 0x89, 0x76, 0x8A, 0x77, 0x8B, 0x78, 0x8D, 0x73, 0x88, 0x5E, 0x67, 0x34, 0x34, 0x23, 0x26, 0x1F, 0x23, 0x1C, 0x20, 0x1B, 0x20, 0x1C, 0x21, 0x1F, 0x23, 0x26, 0x29, 0x49, 0x4F, 0x6A, 0x66, 0x71, 0x6B, 0x64, 0x59, 0x3E, 0x38, 0x49, 0x4C, 0x6A, 0x64, 0x72, 0x6A, 0x77, 0x6D, 0x7B, 0x6E, 0x7C, 0x6E, 0x7B, 0x6F, 0x77, 0x6B, 0x77, 0x6B, 0x79, 0x6C, 0x79, 0x6C, 0x7C, 0x6F, 0x78, 0x6C, 0x78, 0x6C, 0x79, 0x6C, 0x78, 0x6C, 0x7D, 0x6F, 0x7E, 0x70, 0x7A, 0x6D, 0x7A, 0x71, 0x7C, 0x70, 0x7D, 0x6E, 0x7C, 0x6F, 0x7C, 0x6E, 0x79, 0x6B, 0x78, 0x6A, 0x79, 0x6C, 0x79, 0x6D, 0x79, 0x6E, 0x78, 0x6C, 0x79, 0x6C, 0x7A, 0x6F, 0x7F, 0x76, 0x81, 0x73, 0x7D, 0x73, 0x7D, 0x70, 0x7B, 0x6E, 0x7B, 0x6D, 0x80, 0x73, 0x7A, 0x6E, 0x7A, 0x6E, 0x7A, 0x70, 0x80, 0x76, 0x84, 0x79, 0x7E, 0x6F, 0x7E, 0x70, 0x78, 0x6B, 0x7C, 0x70, 0x80, 0x75, 0x7E, 0x73, 0x7E, 0x73, 0x7C, 0x6F, 0x7C, 0x6D, 0x79, 0x6C, 0x7D, 0x6E, 0x7B, 0x71, 0x7A, 0x6D, 0x7E, 0x72, 0x82, 0x76, 0x86, 0x79, 0x83, 0x7A, 0x7F, 0x75, 0x7F, 0x72, 0x7E, 0x71, 0x7D, 0x6F, 0x80, 0x72, 0x7B, 0x6D, 0x7B, 0x6D, 0x7C, 0x70, 0x82, 0x75, 0x7E, 0x6F, 0x7C, 0x6F, 0x7C, 0x71, 0x7F, 0x6F, 0x7D, 0x6F, 0x78, 0x6B, 0x7B, 0x6D, 0x7B, 0x6D, 0x7A, 0x6C, 0x7A, 0x6C, 0x78, 0x66, 0x5C, 0x55, 0x51, 0x53, 0x4D, 0x51, 0x4D, 0x4F, 0x4D, 0x53, 0x50, 0x54, 0x43, 0x42, 0x34, 0x35, 0x57, 0x58, 0x72, 0x69, 0x74, 0x69, 0x7B, 0x6D, 0x78, 0x6A, 0x75, 0x69, 0x78, 0x6C, 0x74, 0x6D, 0x75, 0x77, 0x70, 0x78, 0x62, 0x64, 0x52, 0x50, 0x48, 0x44, 0x58, 0x57, 0x71, 0x68, 0x70, 0x66, 0x72, 0x67, 0x74, 0x6A, 0x72, 0x67, 0x72, 0x65, 0x73, 0x65, 0x73, 0x66, 0x73, 0x66, 0x70, 0x64, 0x6F, 0x63, 0x6E, 0x63, 0x70, 0x64, 0x70, 0x63, 0x70, 0x62, 0x71, 0x65, 0x70, 0x63, 0x70, 0x63, 0x6F, 0x63, 0x72, 0x64, 0x71, 0x66, 0x73, 0x66, 0x6F, 0x62, 0x6D, 0x60, 0x70, 0x63, 0x6E, 0x61, 0x6D, 0x62, 0x6C, 0x61, 0x6F, 0x64, 0x70, 0x63, 0x6F, 0x64, 0x72, 0x69, 0x77, 0x6A, 0x6F, 0x62, 0x6F, 0x65, 0x70, 0x64, 0x6F, 0x64, 0x70, 0x64, 0x6D, 0x60, 0x6B, 0x61, 0x70, 0x64, 0x6C, 0x62, 0x6F, 0x67, 0x6F, 0x65, 0x6B, 0x60, 0x6D, 0x62, 0x6A, 0x5E, 0x6F, 0x64, 0x6E, 0x64, 0x6E, 0x65, 0x6D, 0x62, 0x6D, 0x60, 0x6E, 0x63, 0x6C, 0x61, 0x6B, 0x5D, 0x68, 0x5E, 0x68, 0x5E, 0x69, 0x5F, 0x67, 0x5D, 0x67, 0x5B, 0x69, 0x5D, 0x66, 0x5C, 0x69, 0x5D, 0x68, 0x5D, 0x69, 0x61, 0x69, 0x60, 0x53, 0x4E, 0x38, 0x3C, 0x37, 0x41, 0x40, 0x45, 0x38, 0x3C, 0x30, 0x38, 0x32, 0x37, 0x3A, 0x44, 0x32, 0x34, 0x2F, 0x37, 0x2F, 0x34, 0x36, 0x3F, 0x33, 0x3A, 0x2E, 0x32, 0x34, 0x3B, 0x33, 0x3A, 0x36, 0x3D, 0x2F, 0x33, 0x34, 0x3C, 0x33, 0x39, 0x3D, 0x46, 0x39, 0x3C, 0x35, 0x3B, 0x36, 0x37, 0x33, 0x3A, 0x35, 0x3A, 0x31, 0x39, 0x3A, 0x40, 0x3E, 0x48, 0x3E, 0x44, 0x44, 0x51, 0x40, 0x49, 0x4B, 0x5A, 0x43, 0x49, 0x2F, 0x33, 0x2E, 0x33, 0x34, 0x40, 0x5E, 0x7D, 0x6E, 0x90, 0x77, 0x9C, 0x80, 0xA5, 0x80, 0xA3, 0x7E, 0xA3, 0x64, 0x73, 0x33, 0x3A, 0x36, 0x3F, 0x36, 0x3E, 0x54, 0x72
    },

    {
        0x58, 0x20, 0x57, 0x1F, 0x59, 0x20, 0x58, 0x1F, 0x5A, 0x1F, 0x5B, 0x20, 0x5B, 0x20, 0x5A, 0x20, 0x5A, 0x20, 0x5A, 0x20, 0x58, 0x20, 0x5B, 0x21, 0x5C, 0x21, 0x5D, 0x21, 0x5E, 0x22, 0x60, 0x23, 0x5F, 0x22, 0x5E, 0x23, 0x60, 0x23, 0x62, 0x23, 0x60, 0x22, 0x5D, 0x21, 0x5C, 0x21, 0x5D, 0x21, 0x5D, 0x21, 0x60, 0x22, 0x60, 0x22, 0x60, 0x22, 0x60, 0x23, 0x63, 0x23, 0x63, 0x23, 0x60, 0x22, 0x62, 0x23, 0x63, 0x23, 0x61, 0x23, 0x5F, 0x23, 0x61, 0x23, 0x61, 0x23, 0x60, 0x23, 0x62, 0x23, 0x66, 0x25, 0x66, 0x25, 0x67, 0x27, 0x66, 0x25, 0x65, 0x25, 0x67, 0x25, 0x63, 0x23, 0x64, 0x24, 0x65, 0x24, 0x67, 0x26, 0x67, 0x24, 0x67, 0x25, 0x68, 0x26, 0x68, 0x28, 0x66, 0x27, 0x5E, 0x25, 0x46, 0x21, 0x44, 0x22, 0x56, 0x27, 0x61, 0x26, 0x63, 0x27, 0x56, 0x21, 0x38, 0x1A, 0x28, 0x17, 0x23, 0x15, 0x20, 0x14, 0x1F, 0x14, 0x1E, 0x14, 0x1D, 0x14, 0x1F, 0x18, 0x2D, 0x2A, 0x53, 0x4B, 0x76, 0x61, 0x7B, 0x66, 0x82, 0x6C, 0x85, 0x6E, 0x87, 0x6F, 0x8A, 0x70, 0x8C, 0x70, 0x8D, 0x72, 0x93, 0x75, 0x8D, 0x71, 0x89, 0x70, 0x8B, 0x71, 0x8C, 0x71, 0x8B, 0x72, 0x8C, 0x71, 0x8C, 0x72, 0x7D, 0x5C, 0x44, 0x2F, 0x2A, 0x1E, 0x23, 0x18, 0x20, 0x17, 0x1F, 0x16, 0x21, 0x16, 0x20, 0x16, 0x22, 0x17, 0x3D, 0x20, 0x5F, 0x27, 0x66, 0x27, 0x62, 0x27, 0x41, 0x20, 0x3C, 0x1F, 0x5D, 0x27, 0x66, 0x28, 0x6A, 0x29, 0x6E, 0x2A, 0x6B, 0x29, 0x69, 0x27, 0x6B, 0x29, 0x6E, 0x29, 0x69, 0x28, 0x6D, 0x2A, 0x69, 0x29, 0x6F, 0x2A, 0x6E, 0x29, 0x6A, 0x28, 0x65, 0x26, 0x67, 0x28, 0x70, 0x2A, 0x6C, 0x29, 0x71, 0x2C, 0x71, 0x2C, 0x6F, 0x2A, 0x6D, 0x29, 0x6E, 0x29, 0x6A, 0x27, 0x6D, 0x29, 0x6B, 0x29, 0x69, 0x28, 0x6E, 0x2A, 0x6F, 0x2B, 0x6F, 0x2C, 0x6F, 0x2B, 0x6D, 0x29, 0x71, 0x2D, 0x76, 0x2D, 0x6A, 0x29, 0x6D, 0x2A, 0x70, 0x2C, 0x72, 0x2B, 0x70, 0x2B, 0x6D, 0x29, 0x6F, 0x2A, 0x6B, 0x29, 0x70, 0x2E, 0x7B, 0x30, 0x70, 0x2A, 0x6E, 0x2A, 0x70, 0x2A, 0x6D, 0x29, 0x6E, 0x2A, 0x70, 0x2A, 0x75, 0x2E, 0x75, 0x2B, 0x6D, 0x28, 0x69, 0x27, 0x6D, 0x29, 0x6B, 0x29, 0x6E, 0x2A, 0x6E, 0x2A, 0x71, 0x2A, 0x74, 0x2D, 0x73, 0x2D, 0x6C, 0x29, 0x70, 0x2B, 0x77, 0x30, 0x74, 0x2C, 0x73, 0x2B, 0x72, 0x2B, 0x70, 0x2A, 0x71, 0x2B, 0x71, 0x2B, 0x6D, 0x28, 0x6E, 0x29, 0x72, 0x2C, 0x6E, 0x28, 0x6C, 0x28, 0x6C, 0x28, 0x6C, 0x28, 0x6C, 0x28, 0x69, 0x28, 0x6A, 0x27, 0x6A, 0x27, 0x55, 0x21, 0x4B, 0x25, 0x51, 0x28, 0x4F, 0x27, 0x54, 0x29, 0x50, 0x24, 0x34, 0x1A, 0x36, 0x1B, 0x55, 0x23, 0x67, 0x28, 0x7B, 0x33, 0x6E, 0x2A, 0x69, 0x28, 0x6C, 0x29, 0x66, 0x28, 0x6B, 0x2E, 0x6D, 0x3E, 0x5D, 0x35, 0x47, 0x27, 0x39, 0x20, 0x34, 0x1D, 0x36, 0x1D, 0x63, 0x2A, 0x66, 0x27, 0x63, 0x26, 0x67, 0x27, 0x64, 0x26, 0x63, 0x26, 0x64, 0x26, 0x66, 0x26, 0x62, 0x25, 0x62, 0x25, 0x63, 0x25, 0x62, 0x26, 0x62, 0x25, 0x5F, 0x23, 0x5E, 0x24, 0x63, 0x25, 0x61, 0x24, 0x5F, 0x22, 0x61, 0x23, 0x62, 0x24, 0x63, 0x25, 0x62, 0x24, 0x62, 0x24, 0x61, 0x24, 0x63, 0x24, 0x62, 0x25, 0x62, 0x25, 0x60, 0x24, 0x60, 0x23, 0x61, 0x24, 0x5F, 0x24, 0x66, 0x26, 0x64, 0x25, 0x65, 0x26, 0x64, 0x25, 0x62, 0x25, 0x62, 0x26, 0x61, 0x25, 0x62, 0x26, 0x5F, 0x25, 0x62, 0x26, 0x61, 0x26, 0x61, 0x27, 0x61, 0x27, 0x63, 0x26, 0x5E, 0x24, 0x5E, 0x23, 0x5F, 0x24, 0x5B, 0x23, 0x5F, 0x26, 0x60, 0x25, 0x5D, 0x22, 0x60, 0x23, 0x5F, 0x23, 0x5E, 0x23, 0x5E, 0x24, 0x5E, 0x22, 0x5C, 0x23, 0x5B, 0x22, 0x5A, 0x22, 0x5D, 0x23, 0x5A, 0x22, 0x5A, 0x22, 0x59, 0x21, 0x59, 0x22, 0x59, 0x21, 0x4C, 0x22, 0x3A, 0x1F, 0x40, 0x23, 0x40, 0x21, 0x2E, 0x19, 0x32, 0x1D, 0x36, 0x1E, 0x3E, 0x21, 0x37, 0x1D, 0x37, 0x1F, 0x3D, 0x21, 0x42, 0x24, 0x42, 0x22, 0x32, 0x1C, 0x44, 0x24, 0x3D, 0x20, 0x3B, 0x21, 0x36, 0x20, 0x41, 0x25, 0x3D, 0x24, 0x47, 0x2A, 0x44, 0x28, 0x46, 0x2B, 0x3D, 0x22, 0x39, 0x1F, 0x30, 0x1B, 0x3E, 0x28, 0x76, 0x4F, 0x88, 0x5C, 0x93, 0x63, 0xA2, 0x6C, 0xA6, 0x6E, 0xAE, 0x76, 0x89, 0x51, 0x42, 0x24, 0x3E, 0x21, 0x45, 0x2B, 0x98, 0x68, 0xB6, 0x79, 0xB5, 0x76, 0xB2, 0x74, 0xAC, 0x70, 0xA0, 0x67, 0x79, 0x46, 0x2B, 0x1B, 0x35, 0x1C, 0x35, 0x1D, 0x4F, 0x33
    },

    {
        0x63, 0x58, 0x62, 0x59, 0x64, 0x5A, 0x65, 0x59, 0x67, 0x5A, 0x69, 0x5B, 0x6A, 0x5B, 0x68, 0x5B, 0x69, 0x5C, 0x67, 0x59, 0x66, 0x5A, 0x69, 0x5C, 0x6B, 0x5F, 0x6B, 0x5D, 0x6A, 0x5E, 0x6D, 0x61, 0x6D, 0x61, 0x6F, 0x61, 0x6F, 0x60, 0x71, 0x62, 0x70, 0x60, 0x6C, 0x5D, 0x6E, 0x5E, 0x6F, 0x5E, 0x6D, 0x5F, 0x6F, 0x5F, 0x70, 0x60, 0x71, 0x61, 0x72, 0x63, 0x74, 0x63, 0x73, 0x64, 0x73, 0x63, 0x73, 0x64, 0x73, 0x64, 0x73, 0x64, 0x6F, 0x61, 0x73, 0x63, 0x74, 0x65, 0x73, 0x63, 0x72, 0x63, 0x76, 0x66, 0x78, 0x69, 0x77, 0x68, 0x77, 0x68, 0x77, 0x67, 0x77, 0x66, 0x75, 0x63, 0x76, 0x66, 0x78, 0x67, 0x7A, 0x6B, 0x79, 0x69, 0x7A, 0x69, 0x7A, 0x6C, 0x75, 0x69, 0x71, 0x69, 0x6A, 0x60, 0x55, 0x49, 0x45, 0x43, 0x54, 0x56, 0x68, 0x62, 0x6B, 0x63, 0x60, 0x58, 0x44, 0x3B, 0x2B, 0x29, 0x23, 0x24, 0x1F, 0x20, 0x1C, 0x1F, 0x1B, 0x1E, 0x1A, 0x1C, 0x1B, 0x1E, 0x23, 0x2A, 0x39, 0x4E, 0x5B, 0x73, 0x66, 0x79, 0x6E, 0x82, 0x72, 0x86, 0x75, 0x87, 0x76, 0x89, 0x77, 0x8A, 0x79, 0x8B, 0x7E, 0x98, 0x7E, 0x92, 0x7A, 0x8D, 0x78, 0x8A, 0x79, 0x8B, 0x78, 0x8B, 0x78, 0x8C, 0x74, 0x8A, 0x61, 0x6B, 0x37, 0x36, 0x25, 0x27, 0x1E, 0x22, 0x1C, 0x21, 0x1B, 0x1F, 0x1D, 0x22, 0x1D, 0x20, 0x25, 0x28, 0x48, 0x4E, 0x69, 0x66, 0x6F, 0x68, 0x63, 0x5B, 0x40, 0x38, 0x48, 0x4A, 0x68, 0x63, 0x73, 0x68, 0x78, 0x6D, 0x7C, 0x6F, 0x79, 0x6E, 0x78, 0x6A, 0x79, 0x6B, 0x7C, 0x70, 0x7C, 0x6D, 0x7D, 0x71, 0x77, 0x6B, 0x79, 0x70, 0x7C, 0x6E, 0x7A, 0x6B, 0x77, 0x68, 0x76, 0x6C, 0x7E, 0x71, 0x7B, 0x6E, 0x7E, 0x73, 0x7D, 0x73, 0x7B, 0x71, 0x7B, 0x6E, 0x7C, 0x70, 0x79, 0x6B, 0x7D, 0x6F, 0x7C, 0x6E, 0x78, 0x6B, 0x7D, 0x6F, 0x7A, 0x6F, 0x7E, 0x72, 0x80, 0x73, 0x7B, 0x6D, 0x7E, 0x73, 0x82, 0x73, 0x7C, 0x6E, 0x7C, 0x70, 0x81, 0x75, 0x84, 0x74, 0x80, 0x73, 0x7F, 0x70, 0x7F, 0x71, 0x7A, 0x6E, 0x7D, 0x6F, 0x80, 0x71, 0x7F, 0x72, 0x7F, 0x6F, 0x7F, 0x73, 0x7E, 0x70, 0x7D, 0x6F, 0x82, 0x74, 0x84, 0x76, 0x82, 0x75, 0x7B, 0x6C, 0x77, 0x69, 0x7C, 0x6F, 0x7C, 0x6F, 0x7E, 0x72, 0x7E, 0x72, 0x7E, 0x6F, 0x83, 0x76, 0x81, 0x73, 0x7B, 0x6F, 0x7D, 0x71, 0x83, 0x7E, 0x82, 0x78, 0x83, 0x74, 0x80, 0x73, 0x80, 0x71, 0x82, 0x76, 0x80, 0x73, 0x7E, 0x71, 0x7C, 0x70, 0x83, 0x77, 0x7E, 0x6E, 0x7C, 0x6F, 0x7E, 0x6F, 0x7E, 0x70, 0x7B, 0x6A, 0x7C, 0x6E, 0x7C, 0x6E, 0x7B, 0x6B, 0x60, 0x53, 0x4C, 0x4A, 0x4E, 0x50, 0x4F, 0x52, 0x4F, 0x51, 0x43, 0x43, 0x2E, 0x2E, 0x3A, 0x3D, 0x61, 0x5F, 0x76, 0x6B, 0x81, 0x7D, 0x7E, 0x71, 0x77, 0x69, 0x7A, 0x6D, 0x73, 0x6A, 0x73, 0x6F, 0x64, 0x69, 0x4F, 0x4D, 0x42, 0x3E, 0x39, 0x34, 0x36, 0x31, 0x34, 0x36, 0x63, 0x65, 0x73, 0x6A, 0x72, 0x67, 0x74, 0x68, 0x71, 0x67, 0x70, 0x64, 0x73, 0x67, 0x74, 0x66, 0x70, 0x65, 0x73, 0x64, 0x70, 0x65, 0x71, 0x66, 0x70, 0x64, 0x6E, 0x60, 0x6C, 0x60, 0x6F, 0x63, 0x6D, 0x62, 0x6F, 0x62, 0x70, 0x62, 0x70, 0x64, 0x72, 0x65, 0x73, 0x67, 0x71, 0x64, 0x70, 0x62, 0x76, 0x67, 0x73, 0x66, 0x71, 0x67, 0x70, 0x65, 0x6E, 0x62, 0x72, 0x64, 0x6D, 0x62, 0x74, 0x68, 0x75, 0x68, 0x75, 0x68, 0x72, 0x65, 0x6F, 0x65, 0x70, 0x63, 0x71, 0x65, 0x6F, 0x66, 0x6C, 0x64, 0x72, 0x66, 0x70, 0x64, 0x6F, 0x64, 0x6C, 0x63, 0x70, 0x66, 0x6B, 0x60, 0x6C, 0x61, 0x6C, 0x63, 0x68, 0x5E, 0x6C, 0x61, 0x6B, 0x62, 0x6E, 0x60, 0x70, 0x62, 0x6F, 0x63, 0x6E, 0x5F, 0x6C, 0x60, 0x6B, 0x5E, 0x6A, 0x5D, 0x69, 0x5D, 0x68, 0x5E, 0x6A, 0x5E, 0x68, 0x5E, 0x67, 0x5D, 0x67, 0x5B, 0x65, 0x5B, 0x65, 0x5A, 0x4D, 0x48, 0x35, 0x36, 0x38, 0x41, 0x36, 0x39, 0x2A, 0x2C, 0x30, 0x38, 0x34, 0x3B, 0x3A, 0x40, 0x36, 0x39, 0x33, 0x3B, 0x38, 0x3D, 0x3A, 0x45, 0x39, 0x3E, 0x2B, 0x32, 0x3C, 0x44, 0x31, 0x36, 0x34, 0x3B, 0x33, 0x38, 0x3E, 0x4A, 0x3D, 0x46, 0x48, 0x55, 0x47, 0x52, 0x49, 0x57, 0x3C, 0x3E, 0x35, 0x3A, 0x2D, 0x32, 0x3A, 0x4D, 0x68, 0x8A, 0x7A, 0x9F, 0x81, 0xA6, 0x86, 0xAE, 0x89, 0xB3, 0x8B, 0xB8, 0x69, 0x79, 0x37, 0x3E, 0x37, 0x3E, 0x3E, 0x50, 0x76, 0xA2, 0x8A, 0xB4, 0x88, 0xAF, 0x84, 0xA9, 0x7E, 0xA2, 0x75, 0x93, 0x55, 0x5F, 0x25, 0x29, 0x2E, 0x34, 0x2E, 0x35, 0x3D, 0x4C
    },

    {
        0x58, 0x20, 0x59, 0x20, 0x59, 0x20, 0x58, 0x20, 0x58, 0x20, 0x5B, 0x20, 0x5C, 0x21, 0x5B, 0x21, 0x5B, 0x20, 0x5A, 0x20, 0x5B, 0x21, 0x5A, 0x21, 0x5B, 0x21, 0x5B, 0x21, 0x5B, 0x21, 0x5B, 0x21, 0x5B, 0x21, 0x5C, 0x22, 0x5F, 0x23, 0x5D, 0x21, 0x5C, 0x21, 0x5D, 0x22, 0x5E, 0x21, 0x5D, 0x22, 0x5D, 0x22, 0x5F, 0x22, 0x5C, 0x21, 0x5E, 0x22, 0x60, 0x22, 0x62, 0x23, 0x60, 0x23, 0x61, 0x22, 0x65, 0x24, 0x65, 0x24, 0x64, 0x24, 0x61, 0x22, 0x62, 0x23, 0x65, 0x24, 0x63, 0x23, 0x62, 0x23, 0x65, 0x24, 0x65, 0x25, 0x69, 0x27, 0x68, 0x26, 0x67, 0x25, 0x67, 0x25, 0x63, 0x25, 0x66, 0x24, 0x67, 0x24, 0x65, 0x24, 0x65, 0x25, 0x67, 0x26, 0x6B, 0x26, 0x69, 0x26, 0x68, 0x28, 0x68, 0x28, 0x5F, 0x24, 0x4B, 0x21, 0x42, 0x22, 0x53, 0x26, 0x62, 0x27, 0x63, 0x26, 0x5B, 0x23, 0x3F, 0x1B, 0x29, 0x16, 0x23, 0x15, 0x21, 0x15, 0x1F, 0x14, 0x1C, 0x13, 0x1C, 0x13, 0x1D, 0x15, 0x27, 0x22, 0x4C, 0x46, 0x72, 0x5E, 0x7D, 0x67, 0x83, 0x6B, 0x88, 0x6D, 0x87, 0x6D, 0x87, 0x6F, 0x8C, 0x72, 0x8F, 0x76, 0x97, 0x79, 0x92, 0x73, 0x8C, 0x73, 0x8C, 0x70, 0x8C, 0x71, 0x8C, 0x71, 0x7D, 0x5D, 0x47, 0x31, 0x2C, 0x1F, 0x23, 0x19, 0x21, 0x17, 0x20, 0x16, 0x20, 0x16, 0x20, 0x15, 0x22, 0x16, 0x3A, 0x1E, 0x5D, 0x27, 0x67, 0x28, 0x63, 0x25, 0x42, 0x20, 0x3B, 0x1F, 0x5B, 0x25, 0x69, 0x29, 0x6C, 0x29, 0x6E, 0x29, 0x6B, 0x2A, 0x6F, 0x2A, 0x6F, 0x2A, 0x6B, 0x28, 0x6B, 0x29, 0x6F, 0x2A, 0x71, 0x2B, 0x69, 0x27, 0x6C, 0x29, 0x6A, 0x29, 0x6C, 0x29, 0x6A, 0x29, 0x6F, 0x29, 0x6E, 0x2B, 0x72, 0x2D, 0x73, 0x2C, 0x6C, 0x2A, 0x6B, 0x29, 0x6D, 0x2A, 0x6D, 0x2A, 0x6E, 0x29, 0x6B, 0x28, 0x69, 0x28, 0x6B, 0x2A, 0x78, 0x2E, 0x6E, 0x2B, 0x72, 0x2B, 0x70, 0x2B, 0x71, 0x2B, 0x70, 0x2A, 0x6D, 0x29, 0x70, 0x2A, 0x71, 0x2C, 0x6E, 0x2B, 0x70, 0x2B, 0x70, 0x2B, 0x75, 0x2D, 0x72, 0x2B, 0x72, 0x2C, 0x70, 0x2B, 0x6F, 0x2B, 0x71, 0x2B, 0x70, 0x29, 0x6E, 0x2A, 0x6F, 0x2A, 0x72, 0x2B, 0x71, 0x2A, 0x6D, 0x28, 0x6E, 0x29, 0x70, 0x2A, 0x6E, 0x28, 0x6F, 0x2B, 0x70, 0x2A, 0x6F, 0x2B, 0x78, 0x2F, 0x70, 0x2A, 0x71, 0x2C, 0x71, 0x2B, 0x74, 0x2C, 0x72, 0x2B, 0x70, 0x2C, 0x78, 0x2D, 0x78, 0x2E, 0x77, 0x2D, 0x72, 0x2C, 0x77, 0x2D, 0x71, 0x2C, 0x74, 0x2C, 0x6F, 0x2A, 0x6E, 0x2A, 0x71, 0x2A, 0x6E, 0x28, 0x6E, 0x29, 0x6C, 0x28, 0x6E, 0x29, 0x6E, 0x28, 0x6C, 0x28, 0x6C, 0x27, 0x5C, 0x22, 0x41, 0x1B, 0x3E, 0x1D, 0x3D, 0x1E, 0x39, 0x1B, 0x2B, 0x16, 0x2B, 0x17, 0x43, 0x1E, 0x64, 0x28, 0x6B, 0x27, 0x68, 0x29, 0x68, 0x29, 0x6D, 0x29, 0x65, 0x26, 0x66, 0x2A, 0x5E, 0x2C, 0x51, 0x2C, 0x37, 0x1E, 0x2F, 0x1B, 0x2F, 0x1B, 0x2D, 0x19, 0x24, 0x17, 0x49, 0x23, 0x6D, 0x2B, 0x67, 0x28, 0x6A, 0x27, 0x65, 0x26, 0x62, 0x25, 0x65, 0x25, 0x63, 0x25, 0x64, 0x26, 0x65, 0x26, 0x65, 0x26, 0x64, 0x25, 0x5F, 0x24, 0x62, 0x24, 0x5B, 0x22, 0x5F, 0x23, 0x60, 0x24, 0x61, 0x24, 0x64, 0x25, 0x63, 0x25, 0x64, 0x24, 0x62, 0x25, 0x62, 0x24, 0x61, 0x23, 0x65, 0x25, 0x62, 0x23, 0x62, 0x24, 0x64, 0x25, 0x60, 0x24, 0x63, 0x26, 0x65, 0x28, 0x68, 0x28, 0x65, 0x27, 0x68, 0x29, 0x66, 0x26, 0x62, 0x26, 0x66, 0x26, 0x68, 0x27, 0x6A, 0x28, 0x66, 0x29, 0x67, 0x28, 0x5F, 0x25, 0x5F, 0x26, 0x62, 0x27, 0x5F, 0x25, 0x60, 0x24, 0x5F, 0x26, 0x66, 0x28, 0x61, 0x25, 0x5A, 0x22, 0x61, 0x25, 0x60, 0x24, 0x5E, 0x23, 0x5E, 0x23, 0x5C, 0x22, 0x5A, 0x23, 0x5D, 0x22, 0x5A, 0x22, 0x5B, 0x22, 0x5B, 0x22, 0x5D, 0x23, 0x5F, 0x24, 0x5C, 0x23, 0x5A, 0x22, 0x58, 0x21, 0x59, 0x22, 0x4B, 0x22, 0x3C, 0x20, 0x40, 0x21, 0x39, 0x1E, 0x34, 0x1C, 0x3E, 0x23, 0x3F, 0x22, 0x40, 0x26, 0x41, 0x26, 0x45, 0x2B, 0x4A, 0x2D, 0x56, 0x36, 0x50, 0x30, 0x38, 0x20, 0x35, 0x1D, 0x2F, 0x1B, 0x3A, 0x28, 0x72, 0x52, 0x8C, 0x61, 0x8F, 0x64, 0x9A, 0x6B, 0x9A, 0x6D, 0x9F, 0x70, 0x65, 0x3C, 0x3E, 0x24, 0x45, 0x24, 0x4F, 0x34, 0x97, 0x6C, 0xAD, 0x78, 0xAF, 0x79, 0xB2, 0x7A, 0xB1, 0x79, 0xA6, 0x72, 0x71, 0x44, 0x32, 0x1F, 0x36, 0x1D, 0x40, 0x26, 0x6B, 0x47, 0x6A, 0x48, 0x60, 0x41, 0x50, 0x35, 0x46, 0x2F, 0x39, 0x27, 0x2C, 0x1C, 0x22, 0x16, 0x2F, 0x1A, 0x33, 0x1C, 0x34, 0x1D
    },

    {
        0x64, 0x59, 0x64, 0x5A, 0x66, 0x5A, 0x65, 0x5A, 0x64, 0x5A, 0x68, 0x5C, 0x6A, 0x5D, 0x6A, 0x5D, 0x69, 0x5C, 0x69, 0x5B, 0x6A, 0x5C, 0x6A, 0x5C, 0x6B, 0x5D, 0x6A, 0x5C, 0x6A, 0x5B, 0x69, 0x5B, 0x69, 0x5B, 0x6A, 0x5D, 0x6D, 0x5F, 0x69, 0x5C, 0x6A, 0x5D, 0x6D, 0x5E, 0x6D, 0x5E, 0x6C, 0x5D, 0x6C, 0x5F, 0x6E, 0x5E, 0x6C, 0x5D, 0x6E, 0x60, 0x72, 0x62, 0x73, 0x62, 0x71, 0x60, 0x71, 0x62, 0x75, 0x66, 0x76, 0x66, 0x77, 0x64, 0x72, 0x62, 0x74, 0x63, 0x76, 0x65, 0x74, 0x63, 0x72, 0x63, 0x75, 0x64, 0x76, 0x66, 0x76, 0x6B, 0x75, 0x65, 0x79, 0x69, 0x78, 0x67, 0x75, 0x65, 0x78, 0x68, 0x79, 0x67, 0x75, 0x64, 0x77, 0x66, 0x77, 0x69, 0x7B, 0x6C, 0x7B, 0x6B, 0x76, 0x6A, 0x73, 0x69, 0x6E, 0x62, 0x5C, 0x4E, 0x46, 0x43, 0x50, 0x52, 0x65, 0x62, 0x6B, 0x64, 0x65, 0x5E, 0x4E, 0x42, 0x2E, 0x2A, 0x23, 0x24, 0x21, 0x23, 0x1D, 0x1F, 0x1B, 0x1D, 0x19, 0x1C, 0x1B, 0x1E, 0x20, 0x26, 0x35, 0x49, 0x56, 0x6D, 0x67, 0x7B, 0x6F, 0x83, 0x71, 0x85, 0x73, 0x84, 0x75, 0x87, 0x78, 0x8B, 0x78, 0x8D, 0x7D, 0x92, 0x7B, 0x8E, 0x79, 0x8E, 0x78, 0x8A, 0x77, 0x8C, 0x75, 0x8B, 0x62, 0x6B, 0x37, 0x37, 0x25, 0x27, 0x1F, 0x22, 0x1D, 0x21, 0x1B, 0x20, 0x1C, 0x21, 0x1D, 0x20, 0x24, 0x27, 0x46, 0x4B, 0x68, 0x66, 0x70, 0x69, 0x65, 0x59, 0x40, 0x3A, 0x46, 0x49, 0x6A, 0x65, 0x75, 0x6C, 0x7B, 0x6F, 0x7B, 0x6D, 0x7A, 0x6E, 0x7C, 0x71, 0x7E, 0x6F, 0x7A, 0x6D, 0x79, 0x6C, 0x7C, 0x70, 0x7E, 0x6F, 0x78, 0x6C, 0x7A, 0x6D, 0x77, 0x6A, 0x7A, 0x6C, 0x79, 0x6D, 0x7F, 0x71, 0x7E, 0x71, 0x7E, 0x73, 0x7F, 0x72, 0x7A, 0x6D, 0x78, 0x6D, 0x7D, 0x71, 0x7D, 0x71, 0x7D, 0x6E, 0x7A, 0x6A, 0x7A, 0x6B, 0x7A, 0x6F, 0x84, 0x79, 0x7D, 0x70, 0x81, 0x73, 0x7D, 0x72, 0x7E, 0x71, 0x7E, 0x71, 0x7B, 0x6D, 0x7E, 0x72, 0x7F, 0x72, 0x7D, 0x6E, 0x7D, 0x70, 0x7D, 0x70, 0x82, 0x75, 0x7E, 0x71, 0x7F, 0x74, 0x83, 0x75, 0x81, 0x72, 0x80, 0x73, 0x7F, 0x72, 0x7F, 0x6F, 0x7C, 0x71, 0x81, 0x73, 0x80, 0x73, 0x7D, 0x6E, 0x7C, 0x6F, 0x80, 0x74, 0x7C, 0x6E, 0x7D, 0x73, 0x80, 0x73, 0x7F, 0x72, 0x86, 0x7A, 0x7E, 0x6E, 0x7E, 0x70, 0x81, 0x74, 0x85, 0x77, 0x81, 0x74, 0x81, 0x73, 0x83, 0x76, 0x86, 0x79, 0x85, 0x79, 0x80, 0x76, 0x86, 0x78, 0x80, 0x72, 0x80, 0x75, 0x7F, 0x72, 0x7E, 0x70, 0x7F, 0x70, 0x80, 0x70, 0x7D, 0x70, 0x7B, 0x6E, 0x7D, 0x73, 0x7E, 0x70, 0x7F, 0x71, 0x7A, 0x6A, 0x6B, 0x5D, 0x4A, 0x3F, 0x3C, 0x37, 0x3B, 0x3A, 0x35, 0x31, 0x2A, 0x29, 0x31, 0x31, 0x4E, 0x4E, 0x6E, 0x69, 0x78, 0x6B, 0x7A, 0x6D, 0x78, 0x6B, 0x7A, 0x6D, 0x74, 0x67, 0x71, 0x69, 0x60, 0x59, 0x4F, 0x4A, 0x3B, 0x34, 0x34, 0x31, 0x33, 0x30, 0x2F, 0x2B, 0x26, 0x24, 0x4E, 0x52, 0x77, 0x6E, 0x75, 0x69, 0x78, 0x6C, 0x73, 0x68, 0x6E, 0x64, 0x71, 0x67, 0x74, 0x68, 0x74, 0x67, 0x73, 0x68, 0x72, 0x65, 0x72, 0x64, 0x6F, 0x63, 0x71, 0x63, 0x6C, 0x5E, 0x6E, 0x63, 0x70, 0x63, 0x6D, 0x63, 0x73, 0x66, 0x74, 0x67, 0x72, 0x64, 0x6F, 0x65, 0x73, 0x67, 0x70, 0x64, 0x76, 0x67, 0x71, 0x63, 0x6F, 0x65, 0x76, 0x69, 0x72, 0x65, 0x71, 0x66, 0x71, 0x68, 0x71, 0x68, 0x76, 0x69, 0x75, 0x6A, 0x75, 0x68, 0x71, 0x66, 0x75, 0x68, 0x78, 0x6B, 0x76, 0x69, 0x71, 0x68, 0x73, 0x68, 0x6D, 0x61, 0x6A, 0x62, 0x6B, 0x62, 0x6C, 0x62, 0x70, 0x63, 0x6C, 0x63, 0x72, 0x69, 0x6B, 0x61, 0x68, 0x5E, 0x6E, 0x63, 0x6F, 0x62, 0x69, 0x5E, 0x6A, 0x5E, 0x6A, 0x5E, 0x69, 0x5E, 0x6C, 0x5E, 0x6A, 0x5E, 0x69, 0x5E, 0x69, 0x5D, 0x6B, 0x5E, 0x6E, 0x63, 0x6A, 0x5F, 0x69, 0x5D, 0x65, 0x58, 0x62, 0x59, 0x50, 0x4E, 0x3B, 0x3F, 0x3C, 0x43, 0x35, 0x39, 0x2D, 0x31, 0x38, 0x44, 0x38, 0x3E, 0x3F, 0x4A, 0x42, 0x4B, 0x48, 0x57, 0x49, 0x58, 0x54, 0x67, 0x50, 0x5C, 0x37, 0x3E, 0x31, 0x35, 0x2C, 0x33, 0x3A, 0x4A, 0x67, 0x8A, 0x78, 0x98, 0x79, 0x99, 0x7C, 0xA0, 0x7F, 0xA3, 0x7D, 0xA2, 0x4D, 0x51, 0x37, 0x42, 0x3A, 0x43, 0x42, 0x57, 0x72, 0x99, 0x7F, 0xA6, 0x7F, 0xA8, 0x7F, 0xA4, 0x7E, 0xA1, 0x72, 0x94, 0x4B, 0x53, 0x2B, 0x33, 0x2E, 0x32, 0x38, 0x45, 0x48, 0x5A, 0x43, 0x51, 0x3C, 0x47, 0x32, 0x3B, 0x2D, 0x33, 0x28, 0x2B, 0x22, 0x24, 0x21, 0x25, 0x2B, 0x30, 0x30, 0x38, 0x32, 0x37
    },

    {
        0x57, 0x20, 0x56, 0x1F, 0x59, 0x20, 0x59, 0x1F, 0x59, 0x1F, 0x58, 0x1F, 0x5C, 0x21, 0x5C, 0x20, 0x5D, 0x21, 0x5C, 0x21, 0x5B, 0x22, 0x5E, 0x22, 0x5E, 0x22, 0x5E, 0x23, 0x5D, 0x22, 0x5E, 0x22, 0x5E, 0x22, 0x5B, 0x21, 0x5D, 0x22, 0x5D, 0x21, 0x5D, 0x21, 0x5D, 0x21, 0x5A, 0x20, 0x5B, 0x21, 0x5D, 0x21, 0x5E, 0x22, 0x5F, 0x22, 0x60, 0x22, 0x60, 0x22, 0x61, 0x22, 0x60, 0x22, 0x62, 0x23, 0x66, 0x24, 0x64, 0x24, 0x66, 0x24, 0x64, 0x24, 0x65, 0x24, 0x63, 0x23, 0x62, 0x23, 0x60, 0x23, 0x61, 0x23, 0x64, 0x25, 0x66, 0x27, 0x65, 0x25, 0x64, 0x25, 0x64, 0x24, 0x65, 0x24, 0x65, 0x24, 0x65, 0x24, 0x63, 0x24, 0x67, 0x26, 0x64, 0x24, 0x65, 0x25, 0x66, 0x26, 0x69, 0x27, 0x67, 0x28, 0x66, 0x27, 0x62, 0x26, 0x51, 0x22, 0x3F, 0x1F, 0x4C, 0x23, 0x5E, 0x27, 0x63, 0x26, 0x5B, 0x22, 0x45, 0x1D, 0x2D, 0x18, 0x28, 0x18, 0x25, 0x17, 0x21, 0x15, 0x1F, 0x15, 0x20, 0x16, 0x21, 0x17, 0x27, 0x20, 0x44, 0x3D, 0x6D, 0x5C, 0x7E, 0x66, 0x81, 0x68, 0x84, 0x6C, 0x88, 0x6E, 0x8A, 0x71, 0x8D, 0x72, 0x8C, 0x72, 0x8D, 0x71, 0x88, 0x70, 0x88, 0x70, 0x8B, 0x70, 0x80, 0x5F, 0x4B, 0x33, 0x2B, 0x1E, 0x25, 0x1A, 0x22, 0x17, 0x21, 0x16, 0x20, 0x16, 0x1F, 0x15, 0x1F, 0x15, 0x38, 0x1E, 0x5C, 0x25, 0x64, 0x28, 0x67, 0x27, 0x45, 0x20, 0x3B, 0x1F, 0x5B, 0x26, 0x68, 0x29, 0x6A, 0x28, 0x69, 0x28, 0x6A, 0x28, 0x6C, 0x2A, 0x6F, 0x2A, 0x6F, 0x2A, 0x6D, 0x29, 0x6D, 0x28, 0x6D, 0x2A, 0x6D, 0x29, 0x6C, 0x2A, 0x6B, 0x2A, 0x6D, 0x29, 0x6A, 0x29, 0x70, 0x2B, 0x71, 0x2B, 0x72, 0x2C, 0x6B, 0x29, 0x6C, 0x29, 0x70, 0x2B, 0x72, 0x2B, 0x6E, 0x2A, 0x6F, 0x29, 0x69, 0x28, 0x68, 0x27, 0x69, 0x27, 0x6A, 0x29, 0x70, 0x2C, 0x70, 0x2B, 0x71, 0x2B, 0x72, 0x2C, 0x70, 0x2B, 0x70, 0x29, 0x71, 0x2A, 0x6F, 0x2A, 0x74, 0x2C, 0x74, 0x2C, 0x6E, 0x2B, 0x71, 0x2D, 0x74, 0x2D, 0x73, 0x2C, 0x73, 0x2D, 0x74, 0x2C, 0x75, 0x2D, 0x71, 0x2B, 0x72, 0x2C, 0x6F, 0x29, 0x6E, 0x2A, 0x70, 0x2A, 0x75, 0x2E, 0x6E, 0x29, 0x70, 0x2B, 0x71, 0x2C, 0x6C, 0x29, 0x6F, 0x2C, 0x72, 0x2C, 0x74, 0x2D, 0x71, 0x2A, 0x70, 0x2C, 0x77, 0x2F, 0x75, 0x2E, 0x77, 0x2D, 0x6F, 0x2A, 0x70, 0x2B, 0x76, 0x2D, 0x73, 0x2C, 0x74, 0x2D, 0x70, 0x2A, 0x70, 0x2B, 0x70, 0x2A, 0x71, 0x29, 0x6C, 0x29, 0x72, 0x2B, 0x70, 0x29, 0x70, 0x2A, 0x6A, 0x29, 0x69, 0x28, 0x70, 0x29, 0x6B, 0x27, 0x6C, 0x28, 0x69, 0x26, 0x62, 0x24, 0x55, 0x20, 0x3E, 0x19, 0x30, 0x16, 0x2B, 0x15, 0x33, 0x1A, 0x48, 0x20, 0x57, 0x24, 0x65, 0x25, 0x66, 0x27, 0x6F, 0x29, 0x6B, 0x28, 0x6B, 0x28, 0x6A, 0x27, 0x6A, 0x27, 0x4F, 0x23, 0x38, 0x1E, 0x32, 0x1D, 0x31, 0x1C, 0x32, 0x1E, 0x2E, 0x1A, 0x21, 0x15, 0x4A, 0x23, 0x69, 0x29, 0x6A, 0x29, 0x68, 0x28, 0x66, 0x27, 0x68, 0x27, 0x6A, 0x28, 0x67, 0x26, 0x65, 0x25, 0x65, 0x24, 0x63, 0x25, 0x63, 0x24, 0x5F, 0x24, 0x62, 0x23, 0x61, 0x23, 0x61, 0x24, 0x60, 0x25, 0x5C, 0x23, 0x5D, 0x23, 0x61, 0x24, 0x60, 0x24, 0x5D, 0x22, 0x61, 0x24, 0x60, 0x23, 0x5F, 0x23, 0x62, 0x24, 0x65, 0x27, 0x61, 0x24, 0x62, 0x24, 0x63, 0x25, 0x64, 0x26, 0x63, 0x26, 0x64, 0x26, 0x64, 0x27, 0x66, 0x27, 0x64, 0x26, 0x65, 0x26, 0x67, 0x27, 0x65, 0x27, 0x62, 0x26, 0x65, 0x27, 0x64, 0x27, 0x5F, 0x28, 0x62, 0x28, 0x61, 0x26, 0x5D, 0x24, 0x5F, 0x26, 0x66, 0x29, 0x68, 0x29, 0x61, 0x25, 0x61, 0x24, 0x5D, 0x23, 0x5C, 0x23, 0x5E, 0x23, 0x61, 0x24, 0x5D, 0x23, 0x5C, 0x23, 0x5E, 0x24, 0x5A, 0x21, 0x59, 0x21, 0x5D, 0x22, 0x5C, 0x22, 0x5C, 0x22, 0x5B, 0x22, 0x59, 0x22, 0x58, 0x22, 0x4A, 0x22, 0x38, 0x1E, 0x37, 0x1E, 0x2D, 0x1A, 0x2B, 0x1A, 0x3B, 0x22, 0x62, 0x47, 0x94, 0x67, 0x9A, 0x6C, 0x99, 0x70, 0x99, 0x70, 0x9F, 0x71, 0x93, 0x64, 0x47, 0x27, 0x3E, 0x21, 0x36, 0x1F, 0x57, 0x39, 0x91, 0x69, 0x9E, 0x73, 0x9D, 0x72, 0x99, 0x6F, 0x92, 0x6A, 0x88, 0x62, 0x4A, 0x2C, 0x31, 0x1E, 0x30, 0x1A, 0x32, 0x20, 0x57, 0x3C, 0x55, 0x3D, 0x4D, 0x37, 0x44, 0x31, 0x39, 0x28, 0x32, 0x22, 0x26, 0x19, 0x2F, 0x1C, 0x33, 0x1C, 0x3D, 0x20, 0x2C, 0x19, 0x2A, 0x19, 0x25, 0x17, 0x27, 0x17, 0x31, 0x1C, 0x30, 0x1B, 0x2E, 0x19, 0x34, 0x1C, 0x3A, 0x1E, 0x3F, 0x21, 0x3E, 0x21
    },

    {
        0x62, 0x58, 0x63, 0x58, 0x66, 0x5A, 0x65, 0x59, 0x66, 0x59, 0x66, 0x59, 0x69, 0x5C, 0x6C, 0x5E, 0x6B, 0x5D, 0x6A, 0x5D, 0x6A, 0x5E, 0x6A, 0x5F, 0x6D, 0x5F, 0x6D, 0x60, 0x6E, 0x5F, 0x6D, 0x5F, 0x6D, 0x60, 0x6A, 0x5B, 0x6B, 0x5F, 0x6C, 0x5E, 0x6C, 0x5C, 0x6B, 0x5D, 0x6A, 0x5B, 0x6A, 0x5D, 0x6D, 0x5F, 0x6E, 0x60, 0x71, 0x62, 0x72, 0x61, 0x70, 0x62, 0x73, 0x63, 0x70, 0x61, 0x71, 0x63, 0x74, 0x65, 0x75, 0x66, 0x77, 0x67, 0x76, 0x66, 0x77, 0x66, 0x75, 0x64, 0x75, 0x62, 0x71, 0x61, 0x72, 0x63, 0x76, 0x66, 0x75, 0x68, 0x74, 0x66, 0x77, 0x67, 0x75, 0x65, 0x77, 0x66, 0x76, 0x67, 0x76, 0x66, 0x75, 0x66, 0x76, 0x67, 0x74, 0x63, 0x76, 0x67, 0x77, 0x68, 0x77, 0x6A, 0x74, 0x69, 0x74, 0x6A, 0x73, 0x65, 0x62, 0x55, 0x47, 0x40, 0x4A, 0x4C, 0x61, 0x61, 0x6C, 0x64, 0x66, 0x5E, 0x55, 0x4A, 0x35, 0x30, 0x28, 0x2A, 0x23, 0x26, 0x20, 0x24, 0x1D, 0x22, 0x1D, 0x22, 0x1D, 0x21, 0x20, 0x25, 0x2F, 0x3E, 0x4E, 0x67, 0x64, 0x7A, 0x6A, 0x7F, 0x71, 0x85, 0x75, 0x88, 0x76, 0x8A, 0x78, 0x8D, 0x78, 0x8B, 0x78, 0x8B, 0x76, 0x88, 0x76, 0x8A, 0x74, 0x8A, 0x64, 0x71, 0x3B, 0x3A, 0x25, 0x28, 0x20, 0x25, 0x1D, 0x21, 0x1B, 0x20, 0x1B, 0x21, 0x1C, 0x1F, 0x21, 0x24, 0x43, 0x49, 0x67, 0x62, 0x6D, 0x69, 0x68, 0x5F, 0x43, 0x3B, 0x45, 0x46, 0x6A, 0x65, 0x73, 0x6A, 0x75, 0x6B, 0x78, 0x6D, 0x79, 0x6B, 0x79, 0x6E, 0x7D, 0x71, 0x7E, 0x70, 0x7D, 0x6F, 0x7C, 0x6C, 0x7B, 0x6E, 0x7C, 0x6D, 0x78, 0x6D, 0x78, 0x6D, 0x7B, 0x6F, 0x77, 0x6C, 0x7D, 0x71, 0x7E, 0x71, 0x7D, 0x72, 0x7A, 0x6D, 0x7D, 0x6F, 0x7E, 0x74, 0x7E, 0x72, 0x7B, 0x6F, 0x7C, 0x6F, 0x7A, 0x6B, 0x77, 0x68, 0x78, 0x69, 0x79, 0x6D, 0x7F, 0x74, 0x7C, 0x70, 0x7F, 0x72, 0x7B, 0x71, 0x80, 0x73, 0x7F, 0x73, 0x82, 0x72, 0x7E, 0x71, 0x81, 0x73, 0x7F, 0x74, 0x7C, 0x72, 0x80, 0x77, 0x82, 0x76, 0x81, 0x73, 0x81, 0x75, 0x83, 0x74, 0x84, 0x79, 0x80, 0x72, 0x80, 0x72, 0x7E, 0x6F, 0x7D, 0x70, 0x80, 0x72, 0x82, 0x77, 0x7F, 0x6E, 0x80, 0x73, 0x80, 0x76, 0x7E, 0x71, 0x7D, 0x71, 0x7D, 0x72, 0x83, 0x78, 0x81, 0x72, 0x82, 0x77, 0x84, 0x76, 0x83, 0x77, 0x86, 0x77, 0x7D, 0x6F, 0x82, 0x75, 0x7F, 0x75, 0x80, 0x74, 0x7F, 0x73, 0x81, 0x71, 0x80, 0x70, 0x7E, 0x71, 0x80, 0x72, 0x7D, 0x70, 0x81, 0x73, 0x7D, 0x70, 0x7C, 0x71, 0x79, 0x6E, 0x7B, 0x6D, 0x7C, 0x6F, 0x7B, 0x6C, 0x7D, 0x6F, 0x7A, 0x6C, 0x70, 0x63, 0x66, 0x5A, 0x4C, 0x42, 0x3E, 0x35, 0x35, 0x30, 0x3F, 0x3F, 0x52, 0x51, 0x64, 0x60, 0x72, 0x66, 0x77, 0x6A, 0x7C, 0x71, 0x7A, 0x6C, 0x7A, 0x6B, 0x78, 0x6D, 0x77, 0x69, 0x56, 0x49, 0x3C, 0x36, 0x35, 0x32, 0x34, 0x33, 0x35, 0x34, 0x2C, 0x2A, 0x22, 0x23, 0x52, 0x57, 0x74, 0x6B, 0x76, 0x6D, 0x75, 0x68, 0x76, 0x6A, 0x76, 0x6B, 0x75, 0x6A, 0x72, 0x64, 0x75, 0x66, 0x72, 0x65, 0x74, 0x66, 0x73, 0x64, 0x70, 0x62, 0x72, 0x65, 0x6E, 0x63, 0x70, 0x62, 0x6E, 0x62, 0x6A, 0x5F, 0x6C, 0x62, 0x6F, 0x63, 0x6E, 0x60, 0x6D, 0x60, 0x70, 0x63, 0x6F, 0x62, 0x6E, 0x61, 0x71, 0x64, 0x71, 0x65, 0x6F, 0x63, 0x70, 0x64, 0x72, 0x64, 0x70, 0x64, 0x6F, 0x64, 0x74, 0x68, 0x75, 0x69, 0x74, 0x67, 0x72, 0x65, 0x73, 0x64, 0x74, 0x68, 0x70, 0x66, 0x70, 0x64, 0x71, 0x68, 0x70, 0x67, 0x6A, 0x64, 0x6A, 0x63, 0x6C, 0x61, 0x6A, 0x60, 0x6C, 0x63, 0x72, 0x6B, 0x72, 0x69, 0x6F, 0x63, 0x72, 0x63, 0x6D, 0x60, 0x6C, 0x5F, 0x6E, 0x62, 0x6F, 0x63, 0x6D, 0x60, 0x6B, 0x5E, 0x6E, 0x61, 0x69, 0x5D, 0x67, 0x5B, 0x6B, 0x5F, 0x6A, 0x5D, 0x6C, 0x5F, 0x6A, 0x5D, 0x66, 0x5A, 0x64, 0x59, 0x4A, 0x47, 0x31, 0x33, 0x30, 0x36, 0x29, 0x2D, 0x2B, 0x32, 0x36, 0x3F, 0x59, 0x79, 0x7A, 0x9C, 0x7E, 0x9F, 0x7D, 0xA3, 0x7B, 0x9F, 0x7B, 0x9F, 0x70, 0x85, 0x37, 0x39, 0x36, 0x3D, 0x32, 0x3A, 0x4D, 0x63, 0x6F, 0x91, 0x76, 0x96, 0x74, 0x92, 0x6F, 0x8D, 0x69, 0x83, 0x5D, 0x76, 0x35, 0x35, 0x2A, 0x31, 0x2A, 0x2D, 0x2C, 0x34, 0x3D, 0x49, 0x36, 0x3F, 0x30, 0x38, 0x2B, 0x31, 0x26, 0x2A, 0x24, 0x27, 0x20, 0x23, 0x2C, 0x35, 0x2E, 0x35, 0x36, 0x3A, 0x28, 0x2D, 0x2A, 0x30, 0x27, 0x2B, 0x2A, 0x2E, 0x32, 0x39, 0x2D, 0x33, 0x2E, 0x36, 0x30, 0x38, 0x35, 0x3D, 0x39, 0x41, 0x37, 0x3E
    },

    {
        0x57, 0x1F, 0x59, 0x1F, 0x5A, 0x1F, 0x59, 0x1F, 0x59, 0x1F, 0x59, 0x20, 0x5A, 0x20, 0x5A, 0x21, 0x5B, 0x21, 0x5A, 0x21, 0x5C, 0x22, 0x5D, 0x23, 0x60, 0x23, 0x60, 0x23, 0x61, 0x23, 0x5F, 0x23, 0x5F, 0x22, 0x5E, 0x22, 0x5C, 0x22, 0x5D, 0x21, 0x5D, 0x20, 0x5D, 0x21, 0x5D, 0x21, 0x5C, 0x21, 0x5F, 0x22, 0x5F, 0x22, 0x60, 0x23, 0x60, 0x22, 0x61, 0x23, 0x63, 0x24, 0x63, 0x22, 0x63, 0x23, 0x61, 0x23, 0x62, 0x23, 0x62, 0x23, 0x61, 0x22, 0x61, 0x23, 0x62, 0x23, 0x65, 0x24, 0x64, 0x24, 0x65, 0x24, 0x68, 0x27, 0x66, 0x25, 0x66, 0x25, 0x63, 0x24, 0x64, 0x23, 0x63, 0x24, 0x62, 0x23, 0x62, 0x26, 0x64, 0x24, 0x66, 0x25, 0x65, 0x24, 0x65, 0x25, 0x66, 0x24, 0x68, 0x26, 0x6C, 0x27, 0x69, 0x27, 0x68, 0x28, 0x66, 0x28, 0x57, 0x24, 0x43, 0x22, 0x4C, 0x26, 0x61, 0x28, 0x64, 0x27, 0x61, 0x24, 0x4E, 0x1E, 0x32, 0x19, 0x28, 0x18, 0x26, 0x18, 0x25, 0x17, 0x24, 0x17, 0x21, 0x16, 0x1F, 0x15, 0x22, 0x1B, 0x37, 0x33, 0x62, 0x55, 0x78, 0x66, 0x81, 0x6A, 0x84, 0x6B, 0x86, 0x6D, 0x8A, 0x6F, 0x89, 0x70, 0x8A, 0x70, 0x8B, 0x70, 0x8B, 0x70, 0x82, 0x61, 0x4E, 0x35, 0x2E, 0x20, 0x26, 0x19, 0x21, 0x17, 0x20, 0x16, 0x20, 0x15, 0x20, 0x16, 0x20, 0x15, 0x35, 0x1D, 0x5C, 0x25, 0x66, 0x26, 0x64, 0x27, 0x48, 0x21, 0x3A, 0x1E, 0x59, 0x26, 0x6A, 0x29, 0x6A, 0x28, 0x68, 0x27, 0x6B, 0x29, 0x6B, 0x29, 0x6F, 0x2A, 0x6F, 0x2A, 0x70, 0x2A, 0x6C, 0x2A, 0x6F, 0x2B, 0x6E, 0x29, 0x6C, 0x29, 0x6C, 0x29, 0x6C, 0x29, 0x6C, 0x29, 0x6E, 0x2A, 0x6F, 0x2A, 0x70, 0x29, 0x6D, 0x29, 0x6D, 0x29, 0x6E, 0x2A, 0x72, 0x2A, 0x6F, 0x2B, 0x74, 0x2D, 0x76, 0x2D, 0x70, 0x29, 0x6D, 0x29, 0x70, 0x2B, 0x74, 0x2E, 0x71, 0x2D, 0x71, 0x2D, 0x74, 0x2C, 0x75, 0x2D, 0x76, 0x2E, 0x70, 0x2B, 0x6F, 0x2A, 0x6F, 0x2A, 0x70, 0x2B, 0x6E, 0x2B, 0x73, 0x2D, 0x78, 0x2D, 0x74, 0x2C, 0x70, 0x2C, 0x6E, 0x2B, 0x71, 0x2D, 0x75, 0x2E, 0x72, 0x2B, 0x6D, 0x29, 0x6D, 0x29, 0x6F, 0x2B, 0x71, 0x2B, 0x71, 0x2B, 0x73, 0x2B, 0x73, 0x2C, 0x6E, 0x2C, 0x7A, 0x2F, 0x70, 0x2B, 0x72, 0x2C, 0x74, 0x2C, 0x70, 0x2B, 0x74, 0x2B, 0x7A, 0x31, 0x81, 0x32, 0x76, 0x2D, 0x73, 0x2C, 0x74, 0x2C, 0x6F, 0x2B, 0x71, 0x2B, 0x6E, 0x2B, 0x6E, 0x2A, 0x6D, 0x2A, 0x71, 0x2B, 0x6D, 0x28, 0x6E, 0x29, 0x72, 0x2A, 0x71, 0x2A, 0x6D, 0x29, 0x6F, 0x29, 0x69, 0x26, 0x6B, 0x27, 0x6D, 0x28, 0x6A, 0x27, 0x6A, 0x27, 0x65, 0x25, 0x62, 0x25, 0x5C, 0x23, 0x58, 0x21, 0x50, 0x1F, 0x55, 0x22, 0x62, 0x26, 0x62, 0x25, 0x68, 0x27, 0x68, 0x27, 0x67, 0x27, 0x69, 0x26, 0x68, 0x27, 0x69, 0x28, 0x68, 0x28, 0x4E, 0x20, 0x2D, 0x19, 0x2C, 0x19, 0x2F, 0x1C, 0x2F, 0x1B, 0x27, 0x17, 0x25, 0x18, 0x58, 0x26, 0x64, 0x27, 0x68, 0x27, 0x67, 0x27, 0x68, 0x28, 0x67, 0x26, 0x60, 0x23, 0x5F, 0x23, 0x66, 0x25, 0x64, 0x25, 0x65, 0x25, 0x62, 0x23, 0x63, 0x25, 0x62, 0x24, 0x5D, 0x23, 0x5D, 0x23, 0x60, 0x23, 0x5C, 0x23, 0x62, 0x24, 0x61, 0x24, 0x5E, 0x23, 0x60, 0x23, 0x60, 0x23, 0x63, 0x24, 0x5F, 0x23, 0x63, 0x25, 0x67, 0x26, 0x62, 0x24, 0x5F, 0x24, 0x60, 0x24, 0x60, 0x24, 0x60, 0x25, 0x67, 0x28, 0x62, 0x24, 0x60, 0x24, 0x64, 0x25, 0x63, 0x25, 0x62, 0x24, 0x5F, 0x25, 0x60, 0x25, 0x60, 0x26, 0x64, 0x27, 0x66, 0x2A, 0x63, 0x29, 0x60, 0x28, 0x65, 0x27, 0x67, 0x2A, 0x6D, 0x2B, 0x68, 0x28, 0x63, 0x26, 0x61, 0x25, 0x60, 0x24, 0x61, 0x25, 0x62, 0x25, 0x60, 0x25, 0x5F, 0x24, 0x61, 0x25, 0x61, 0x25, 0x5F, 0x23, 0x5D, 0x23, 0x5D, 0x23, 0x5D, 0x22, 0x5D, 0x23, 0x5D, 0x23, 0x5A, 0x23, 0x5A, 0x23, 0x48, 0x21, 0x39, 0x20, 0x3E, 0x21, 0x40, 0x22, 0x45, 0x23, 0x3F, 0x22, 0x6C, 0x51, 0x9A, 0x70, 0x98, 0x6E, 0x92, 0x6B, 0x8C, 0x66, 0x85, 0x61, 0x70, 0x4D, 0x2D, 0x1C, 0x32, 0x1C, 0x3A, 0x21, 0x45, 0x28, 0x4F, 0x36, 0x43, 0x31, 0x3D, 0x2C, 0x33, 0x24, 0x2C, 0x20, 0x26, 0x1A, 0x21, 0x15, 0x2B, 0x19, 0x32, 0x1B, 0x33, 0x1C, 0x38, 0x1D, 0x2A, 0x17, 0x2C, 0x19, 0x2D, 0x19, 0x2F, 0x1B, 0x33, 0x1C, 0x34, 0x1D, 0x3F, 0x22, 0x39, 0x1F, 0x38, 0x1E, 0x3C, 0x20, 0x3D, 0x20, 0x3A, 0x20, 0x3D, 0x20, 0x42, 0x21, 0x38, 0x1D, 0x3E, 0x20, 0x39, 0x1E, 0x41, 0x21, 0x3C, 0x1F, 0x31, 0x1A
    },

    {
        0x64, 0x59, 0x65, 0x59, 0x66, 0x5A, 0x68, 0x5A, 0x68, 0x5A, 0x67, 0x5B, 0x68, 0x5A, 0x68, 0x5B, 0x68, 0x5D, 0x6A, 0x5B, 0x68, 0x5D, 0x6B, 0x5E, 0x6C, 0x61, 0x6D, 0x60, 0x6E, 0x62, 0x6E, 0x61, 0x6D, 0x5F, 0x6D, 0x5E, 0x6B, 0x5E, 0x6E, 0x5F, 0x6C, 0x5E, 0x6D, 0x5F, 0x6D, 0x5E, 0x6D, 0x5E, 0x6E, 0x5E, 0x6F, 0x5F, 0x71, 0x61, 0x71, 0x63, 0x70, 0x61, 0x73, 0x63, 0x75, 0x64, 0x73, 0x63, 0x72, 0x63, 0x74, 0x64, 0x72, 0x61, 0x71, 0x61, 0x71, 0x62, 0x74, 0x64, 0x77, 0x66, 0x76, 0x65, 0x77, 0x67, 0x77, 0x69, 0x74, 0x66, 0x76, 0x66, 0x74, 0x64, 0x76, 0x65, 0x75, 0x63, 0x72, 0x61, 0x73, 0x63, 0x76, 0x66, 0x77, 0x67, 0x76, 0x67, 0x77, 0x68, 0x76, 0x66, 0x77, 0x69, 0x7D, 0x6C, 0x79, 0x6B, 0x79, 0x6C, 0x75, 0x68, 0x66, 0x59, 0x4E, 0x46, 0x49, 0x4B, 0x60, 0x5F, 0x6E, 0x67, 0x6B, 0x62, 0x5D, 0x52, 0x3C, 0x34, 0x28, 0x29, 0x24, 0x26, 0x21, 0x25, 0x1F, 0x24, 0x1D, 0x22, 0x1C, 0x1F, 0x1E, 0x22, 0x29, 0x33, 0x45, 0x5D, 0x60, 0x77, 0x6B, 0x7E, 0x6F, 0x82, 0x73, 0x87, 0x75, 0x8A, 0x77, 0x89, 0x77, 0x8A, 0x76, 0x8A, 0x74, 0x8A, 0x66, 0x72, 0x3C, 0x3C, 0x27, 0x2A, 0x21, 0x24, 0x1C, 0x20, 0x1B, 0x20, 0x1B, 0x20, 0x1C, 0x20, 0x21, 0x24, 0x3E, 0x45, 0x67, 0x65, 0x6E, 0x66, 0x64, 0x5E, 0x45, 0x3E, 0x43, 0x44, 0x66, 0x64, 0x73, 0x6D, 0x79, 0x6B, 0x79, 0x6A, 0x7A, 0x6E, 0x79, 0x6E, 0x7F, 0x72, 0x7E, 0x72, 0x7E, 0x72, 0x7D, 0x72, 0x80, 0x74, 0x7C, 0x6E, 0x7A, 0x6B, 0x79, 0x6E, 0x7A, 0x6F, 0x7B, 0x6E, 0x7D, 0x73, 0x7C, 0x6F, 0x7D, 0x6F, 0x7B, 0x6F, 0x7D, 0x70, 0x7C, 0x70, 0x80, 0x71, 0x7A, 0x6D, 0x81, 0x77, 0x83, 0x75, 0x7F, 0x71, 0x7C, 0x70, 0x7C, 0x71, 0x7E, 0x76, 0x81, 0x72, 0x7F, 0x76, 0x80, 0x74, 0x82, 0x77, 0x84, 0x76, 0x7E, 0x70, 0x7E, 0x73, 0x7E, 0x73, 0x7C, 0x70, 0x78, 0x6F, 0x7E, 0x76, 0x84, 0x79, 0x80, 0x72, 0x7D, 0x71, 0x7B, 0x6E, 0x7F, 0x72, 0x80, 0x76, 0x80, 0x72, 0x7E, 0x6E, 0x7C, 0x6D, 0x7E, 0x72, 0x81, 0x76, 0x80, 0x73, 0x81, 0x73, 0x83, 0x78, 0x7E, 0x71, 0x83, 0x77, 0x80, 0x75, 0x80, 0x73, 0x80, 0x72, 0x83, 0x75, 0x85, 0x76, 0x88, 0x7F, 0x8A, 0x7F, 0x84, 0x76, 0x84, 0x75, 0x85, 0x78, 0x7D, 0x6F, 0x7E, 0x72, 0x7D, 0x72, 0x7F, 0x72, 0x7D, 0x6F, 0x7F, 0x71, 0x7C, 0x6E, 0x7D, 0x70, 0x83, 0x75, 0x82, 0x75, 0x7C, 0x6E, 0x80, 0x6F, 0x7B, 0x6A, 0x77, 0x6D, 0x7C, 0x6F, 0x78, 0x6C, 0x79, 0x69, 0x75, 0x66, 0x71, 0x64, 0x70, 0x61, 0x67, 0x5E, 0x63, 0x5B, 0x67, 0x5E, 0x70, 0x68, 0x71, 0x67, 0x79, 0x6D, 0x78, 0x6B, 0x75, 0x68, 0x79, 0x6C, 0x79, 0x6B, 0x75, 0x6A, 0x73, 0x69, 0x5B, 0x4A, 0x32, 0x2C, 0x2E, 0x2C, 0x31, 0x30, 0x2C, 0x2C, 0x24, 0x23, 0x2C, 0x32, 0x63, 0x62, 0x71, 0x69, 0x77, 0x6A, 0x75, 0x67, 0x78, 0x6A, 0x77, 0x69, 0x6E, 0x5F, 0x6E, 0x62, 0x75, 0x69, 0x74, 0x69, 0x77, 0x68, 0x71, 0x63, 0x73, 0x65, 0x71, 0x63, 0x6C, 0x5F, 0x6A, 0x60, 0x6C, 0x61, 0x6A, 0x5F, 0x71, 0x65, 0x70, 0x63, 0x6C, 0x5F, 0x6F, 0x63, 0x6D, 0x62, 0x71, 0x66, 0x70, 0x63, 0x72, 0x66, 0x73, 0x68, 0x72, 0x65, 0x6D, 0x60, 0x6E, 0x63, 0x6D, 0x61, 0x6F, 0x63, 0x76, 0x6C, 0x70, 0x63, 0x6E, 0x62, 0x73, 0x65, 0x70, 0x63, 0x6F, 0x64, 0x6F, 0x62, 0x6D, 0x63, 0x6F, 0x65, 0x70, 0x65, 0x71, 0x6A, 0x6E, 0x66, 0x6D, 0x67, 0x71, 0x68, 0x74, 0x6B, 0x76, 0x6D, 0x73, 0x69, 0x6B, 0x63, 0x6F, 0x63, 0x6E, 0x63, 0x70, 0x63, 0x73, 0x65, 0x70, 0x63, 0x6E, 0x62, 0x70, 0x63, 0x6D, 0x62, 0x70, 0x62, 0x6F, 0x61, 0x6C, 0x60, 0x6C, 0x5E, 0x6E, 0x60, 0x6B, 0x5F, 0x68, 0x5D, 0x66, 0x5B, 0x4B, 0x49, 0x37, 0x3D, 0x3A, 0x42, 0x3C, 0x44, 0x3B, 0x43, 0x37, 0x40, 0x58, 0x76, 0x70, 0x90, 0x6E, 0x8A, 0x6B, 0x86, 0x64, 0x7C, 0x5C, 0x71, 0x4C, 0x55, 0x25, 0x29, 0x2E, 0x32, 0x37, 0x41, 0x37, 0x3E, 0x37, 0x3F, 0x2D, 0x32, 0x29, 0x2D, 0x24, 0x26, 0x21, 0x24, 0x21, 0x23, 0x20, 0x22, 0x29, 0x2F, 0x30, 0x37, 0x31, 0x38, 0x35, 0x3B, 0x2B, 0x2F, 0x2F, 0x32, 0x2D, 0x33, 0x30, 0x36, 0x31, 0x37, 0x33, 0x3B, 0x3A, 0x44, 0x33, 0x39, 0x33, 0x3C, 0x36, 0x3C, 0x35, 0x3B, 0x35, 0x3C, 0x37, 0x40, 0x38, 0x3F, 0x33, 0x39, 0x39, 0x41, 0x32, 0x38, 0x39, 0x41, 0x33, 0x37, 0x2B, 0x2E
    },

    {
        0x58, 0x20, 0x59, 0x1F, 0x5A, 0x20, 0x5C, 0x21, 0x5D, 0x21, 0x5C, 0x20, 0x5D, 0x21, 0x5C, 0x21, 0x5C, 0x21, 0x5D, 0x22, 0x5E, 0x22, 0x5D, 0x21, 0x5D, 0x22, 0x5E, 0x23, 0x60, 0x23, 0x5F, 0x23, 0x61, 0x23, 0x5E, 0x22, 0x5E, 0x22, 0x5F, 0x22, 0x60, 0x21, 0x5E, 0x21, 0x5E, 0x22, 0x5C, 0x21, 0x5F, 0x22, 0x5E, 0x22, 0x5F, 0x22, 0x61, 0x23, 0x62, 0x23, 0x64, 0x23, 0x62, 0x23, 0x61, 0x23, 0x61, 0x23, 0x62, 0x23, 0x61, 0x22, 0x60, 0x22, 0x61, 0x22, 0x63, 0x24, 0x63, 0x23, 0x62, 0x23, 0x65, 0x24, 0x63, 0x24, 0x61, 0x24, 0x63, 0x24, 0x63, 0x24, 0x64, 0x24, 0x63, 0x24, 0x63, 0x24, 0x64, 0x23, 0x65, 0x25, 0x64, 0x25, 0x64, 0x24, 0x66, 0x25, 0x67, 0x25, 0x69, 0x27, 0x6B, 0x27, 0x6C, 0x28, 0x6A, 0x27, 0x6B, 0x28, 0x68, 0x28, 0x5E, 0x25, 0x4A, 0x23, 0x45, 0x23, 0x58, 0x25, 0x61, 0x27, 0x65, 0x27, 0x58, 0x23, 0x38, 0x1A, 0x29, 0x17, 0x24, 0x16, 0x23, 0x16, 0x22, 0x16, 0x20, 0x16, 0x20, 0x16, 0x22, 0x19, 0x2F, 0x2C, 0x59, 0x50, 0x78, 0x64, 0x81, 0x69, 0x87, 0x6C, 0x87, 0x6E, 0x88, 0x6F, 0x8A, 0x71, 0x8A, 0x71, 0x83, 0x65, 0x4F, 0x37, 0x2F, 0x20, 0x27, 0x1A, 0x21, 0x16, 0x1F, 0x16, 0x20, 0x16, 0x21, 0x15, 0x21, 0x16, 0x34, 0x1C, 0x55, 0x24, 0x62, 0x26, 0x63, 0x27, 0x46, 0x20, 0x39, 0x20, 0x5C, 0x27, 0x68, 0x29, 0x6A, 0x2A, 0x6C, 0x29, 0x6B, 0x29, 0x6B, 0x29, 0x6C, 0x29, 0x6D, 0x29, 0x6E, 0x2A, 0x6E, 0x2B, 0x73, 0x2C, 0x6F, 0x2B, 0x6C, 0x29, 0x6C, 0x2A, 0x6C, 0x29, 0x6D, 0x2A, 0x70, 0x2B, 0x6E, 0x2A, 0x6B, 0x29, 0x68, 0x27, 0x6A, 0x28, 0x69, 0x28, 0x6C, 0x2A, 0x70, 0x2A, 0x6B, 0x2B, 0x74, 0x2C, 0x6B, 0x29, 0x68, 0x29, 0x71, 0x2A, 0x6D, 0x2B, 0x73, 0x2E, 0x78, 0x2F, 0x75, 0x2D, 0x72, 0x2D, 0x70, 0x2B, 0x72, 0x2C, 0x6E, 0x2A, 0x71, 0x2B, 0x75, 0x2D, 0x70, 0x2B, 0x6D, 0x2A, 0x6F, 0x2B, 0x74, 0x2C, 0x6F, 0x2B, 0x71, 0x2C, 0x6F, 0x2A, 0x6D, 0x29, 0x6A, 0x29, 0x73, 0x2D, 0x70, 0x2A, 0x6C, 0x2A, 0x6E, 0x2B, 0x75, 0x2C, 0x70, 0x2B, 0x74, 0x2D, 0x78, 0x2F, 0x6F, 0x2A, 0x71, 0x2A, 0x74, 0x2C, 0x74, 0x2B, 0x72, 0x2A, 0x72, 0x2B, 0x71, 0x2B, 0x75, 0x2F, 0x79, 0x2E, 0x74, 0x2A, 0x70, 0x2A, 0x73, 0x30, 0x77, 0x2E, 0x74, 0x2C, 0x74, 0x2D, 0x71, 0x2B, 0x70, 0x2B, 0x6D, 0x28, 0x6E, 0x2A, 0x6F, 0x2A, 0x6D, 0x2A, 0x6F, 0x2A, 0x6C, 0x28, 0x6D, 0x28, 0x6A, 0x27, 0x69, 0x28, 0x6A, 0x27, 0x66, 0x25, 0x64, 0x25, 0x64, 0x26, 0x69, 0x26, 0x68, 0x26, 0x6A, 0x27, 0x66, 0x25, 0x65, 0x26, 0x6E, 0x2B, 0x65, 0x26, 0x69, 0x27, 0x6D, 0x29, 0x67, 0x27, 0x6A, 0x29, 0x6D, 0x29, 0x67, 0x28, 0x6A, 0x28, 0x62, 0x25, 0x37, 0x1B, 0x2B, 0x19, 0x27, 0x18, 0x21, 0x14, 0x24, 0x16, 0x4A, 0x22, 0x68, 0x2A, 0x6A, 0x2A, 0x6C, 0x2A, 0x6B, 0x2A, 0x6A, 0x29, 0x67, 0x26, 0x62, 0x24, 0x61, 0x25, 0x64, 0x25, 0x66, 0x26, 0x65, 0x25, 0x63, 0x25, 0x64, 0x25, 0x63, 0x24, 0x61, 0x24, 0x5C, 0x23, 0x5E, 0x23, 0x5C, 0x22, 0x5E, 0x23, 0x63, 0x24, 0x5D, 0x23, 0x62, 0x24, 0x61, 0x24, 0x5F, 0x23, 0x62, 0x24, 0x61, 0x25, 0x66, 0x25, 0x65, 0x26, 0x62, 0x23, 0x63, 0x25, 0x63, 0x25, 0x65, 0x25, 0x66, 0x26, 0x61, 0x25, 0x61, 0x24, 0x62, 0x25, 0x60, 0x25, 0x61, 0x25, 0x63, 0x25, 0x61, 0x27, 0x6B, 0x2A, 0x6A, 0x29, 0x6A, 0x2B, 0x67, 0x2A, 0x68, 0x2A, 0x64, 0x27, 0x67, 0x28, 0x62, 0x26, 0x60, 0x24, 0x60, 0x24, 0x5E, 0x23, 0x5F, 0x24, 0x5E, 0x24, 0x63, 0x25, 0x62, 0x25, 0x5F, 0x24, 0x5D, 0x23, 0x5E, 0x23, 0x5C, 0x23, 0x5F, 0x23, 0x5C, 0x22, 0x5E, 0x23, 0x5C, 0x22, 0x59, 0x22, 0x5A, 0x23, 0x5C, 0x23, 0x49, 0x21, 0x38, 0x1E, 0x3D, 0x21, 0x39, 0x1F, 0x34, 0x1C, 0x34, 0x1E, 0x40, 0x2B, 0x43, 0x2F, 0x36, 0x27, 0x2F, 0x22, 0x2A, 0x1D, 0x26, 0x1A, 0x22, 0x17, 0x20, 0x16, 0x37, 0x1D, 0x40, 0x22, 0x33, 0x1C, 0x36, 0x1D, 0x30, 0x1C, 0x35, 0x1E, 0x35, 0x1D, 0x3A, 0x20, 0x35, 0x1D, 0x37, 0x1D, 0x3C, 0x20, 0x40, 0x21, 0x3D, 0x21, 0x3D, 0x20, 0x38, 0x1E, 0x3A, 0x1F, 0x3D, 0x20, 0x38, 0x1E, 0x34, 0x1D, 0x36, 0x1D, 0x39, 0x1F, 0x2F, 0x1A, 0x3A, 0x20, 0x33, 0x1B, 0x34, 0x1D, 0x37, 0x1E, 0x39, 0x1E, 0x37, 0x1E, 0x36, 0x1E, 0x35, 0x1D, 0x31, 0x1B, 0x32, 0x1B, 0x2E, 0x1A, 0x31, 0x1A
    },

    {
        0x65, 0x5A, 0x66, 0x5B, 0x68, 0x5D, 0x69, 0x5F, 0x6B, 0x5E, 0x69, 0x5D, 0x69, 0x5D, 0x6A, 0x5D, 0x6A, 0x5F, 0x6B, 0x5E, 0x6B, 0x60, 0x6C, 0x5F, 0x6B, 0x5E, 0x6C, 0x61, 0x6F, 0x62, 0x6E, 0x61, 0x71, 0x61, 0x6F, 0x60, 0x6C, 0x5F, 0x6E, 0x60, 0x70, 0x61, 0x6E, 0x5F, 0x6D, 0x5E, 0x6E, 0x5E, 0x6D, 0x5F, 0x6E, 0x5F, 0x70, 0x60, 0x72, 0x63, 0x74, 0x63, 0x75, 0x64, 0x73, 0x62, 0x73, 0x63, 0x75, 0x64, 0x75, 0x64, 0x74, 0x64, 0x71, 0x61, 0x73, 0x61, 0x74, 0x64, 0x78, 0x65, 0x75, 0x64, 0x77, 0x66, 0x75, 0x64, 0x73, 0x64, 0x73, 0x63, 0x73, 0x63, 0x75, 0x65, 0x74, 0x64, 0x74, 0x64, 0x73, 0x65, 0x76, 0x67, 0x74, 0x65, 0x74, 0x66, 0x77, 0x68, 0x79, 0x69, 0x7B, 0x6C, 0x7B, 0x6B, 0x7A, 0x6E, 0x79, 0x6C, 0x7B, 0x6E, 0x77, 0x6A, 0x6E, 0x62, 0x57, 0x4C, 0x46, 0x44, 0x56, 0x56, 0x67, 0x62, 0x6D, 0x67, 0x65, 0x5B, 0x45, 0x3C, 0x2B, 0x2B, 0x24, 0x26, 0x20, 0x24, 0x1E, 0x22, 0x1D, 0x21, 0x1C, 0x21, 0x1D, 0x21, 0x24, 0x2C, 0x3E, 0x57, 0x5F, 0x77, 0x6B, 0x7F, 0x70, 0x85, 0x73, 0x87, 0x75, 0x8A, 0x77, 0x8C, 0x74, 0x88, 0x66, 0x73, 0x3D, 0x3D, 0x27, 0x2B, 0x21, 0x25, 0x1C, 0x20, 0x1B, 0x20, 0x1C, 0x21, 0x1D, 0x22, 0x23, 0x26, 0x3F, 0x45, 0x63, 0x5E, 0x6C, 0x64, 0x64, 0x5F, 0x44, 0x3D, 0x43, 0x46, 0x67, 0x65, 0x74, 0x6B, 0x76, 0x6C, 0x79, 0x6F, 0x78, 0x6D, 0x7A, 0x6D, 0x79, 0x6F, 0x7B, 0x6F, 0x7A, 0x6C, 0x7D, 0x70, 0x81, 0x75, 0x7D, 0x71, 0x7B, 0x6E, 0x7C, 0x70, 0x7B, 0x6D, 0x7A, 0x70, 0x7F, 0x74, 0x7B, 0x6E, 0x78, 0x6A, 0x77, 0x69, 0x77, 0x6B, 0x79, 0x6C, 0x78, 0x6E, 0x7B, 0x6F, 0x7B, 0x70, 0x80, 0x72, 0x7B, 0x6D, 0x78, 0x6B, 0x7E, 0x72, 0x7E, 0x71, 0x7E, 0x73, 0x82, 0x78, 0x81, 0x75, 0x82, 0x78, 0x80, 0x74, 0x7D, 0x71, 0x7A, 0x6F, 0x80, 0x73, 0x82, 0x7A, 0x80, 0x73, 0x7C, 0x6F, 0x7E, 0x73, 0x81, 0x77, 0x7F, 0x72, 0x81, 0x77, 0x7F, 0x71, 0x7B, 0x6B, 0x77, 0x6D, 0x7F, 0x75, 0x80, 0x71, 0x7D, 0x70, 0x79, 0x6C, 0x80, 0x75, 0x80, 0x75, 0x81, 0x74, 0x83, 0x77, 0x7F, 0x70, 0x7E, 0x72, 0x84, 0x78, 0x83, 0x76, 0x83, 0x75, 0x81, 0x75, 0x83, 0x74, 0x82, 0x78, 0x89, 0x7B, 0x85, 0x74, 0x82, 0x73, 0x84, 0x7A, 0x85, 0x77, 0x80, 0x76, 0x81, 0x75, 0x81, 0x72, 0x7F, 0x73, 0x7F, 0x6F, 0x7B, 0x6F, 0x7E, 0x70, 0x7B, 0x6E, 0x7B, 0x70, 0x7B, 0x6C, 0x7D, 0x6E, 0x7A, 0x6C, 0x79, 0x6D, 0x7B, 0x6E, 0x77, 0x67, 0x74, 0x64, 0x76, 0x68, 0x79, 0x6B, 0x79, 0x6A, 0x7A, 0x6C, 0x77, 0x69, 0x75, 0x69, 0x7B, 0x6D, 0x74, 0x68, 0x78, 0x6C, 0x7B, 0x6E, 0x77, 0x6D, 0x79, 0x6C, 0x7C, 0x70, 0x78, 0x6C, 0x77, 0x6B, 0x72, 0x63, 0x47, 0x3B, 0x2D, 0x2A, 0x29, 0x26, 0x23, 0x21, 0x2B, 0x2D, 0x5A, 0x5C, 0x73, 0x6C, 0x77, 0x6E, 0x78, 0x6E, 0x7B, 0x6F, 0x7A, 0x6D, 0x7A, 0x6A, 0x73, 0x67, 0x70, 0x66, 0x70, 0x65, 0x75, 0x69, 0x75, 0x68, 0x74, 0x68, 0x73, 0x65, 0x72, 0x65, 0x70, 0x64, 0x6E, 0x61, 0x6F, 0x61, 0x6C, 0x5E, 0x6E, 0x63, 0x72, 0x67, 0x6C, 0x60, 0x70, 0x62, 0x6F, 0x63, 0x6E, 0x60, 0x73, 0x65, 0x6F, 0x63, 0x75, 0x68, 0x75, 0x67, 0x73, 0x66, 0x73, 0x68, 0x74, 0x68, 0x75, 0x66, 0x75, 0x67, 0x73, 0x66, 0x72, 0x65, 0x71, 0x63, 0x71, 0x64, 0x6F, 0x64, 0x72, 0x65, 0x6F, 0x66, 0x78, 0x6F, 0x77, 0x6C, 0x78, 0x6F, 0x76, 0x6A, 0x74, 0x6B, 0x70, 0x67, 0x72, 0x66, 0x6D, 0x63, 0x6D, 0x62, 0x6F, 0x63, 0x6E, 0x63, 0x6E, 0x61, 0x6C, 0x61, 0x72, 0x64, 0x70, 0x63, 0x6F, 0x62, 0x6C, 0x60, 0x6C, 0x5E, 0x6C, 0x5F, 0x6F, 0x62, 0x6A, 0x5D, 0x6D, 0x60, 0x69, 0x5C, 0x66, 0x5C, 0x68, 0x5F, 0x69, 0x5D, 0x48, 0x42, 0x34, 0x37, 0x35, 0x3A, 0x31, 0x36, 0x2B, 0x31, 0x2F, 0x37, 0x35, 0x3D, 0x2F, 0x32, 0x26, 0x2B, 0x24, 0x27, 0x23, 0x26, 0x23, 0x25, 0x21, 0x23, 0x22, 0x29, 0x34, 0x3D, 0x39, 0x41, 0x31, 0x37, 0x33, 0x39, 0x32, 0x38, 0x33, 0x39, 0x32, 0x39, 0x37, 0x3E, 0x32, 0x39, 0x33, 0x3B, 0x35, 0x3E, 0x38, 0x3F, 0x37, 0x41, 0x35, 0x39, 0x33, 0x3B, 0x33, 0x38, 0x35, 0x3D, 0x2F, 0x33, 0x31, 0x37, 0x30, 0x34, 0x31, 0x38, 0x2B, 0x2F, 0x36, 0x3E, 0x2E, 0x31, 0x32, 0x3A, 0x32, 0x38, 0x33, 0x3A, 0x30, 0x37, 0x31, 0x38, 0x2E, 0x32, 0x2C, 0x32, 0x2A, 0x2F, 0x2C, 0x31, 0x30, 0x36
    },

    {
        0x58, 0x20, 0x58, 0x1F, 0x5A, 0x21, 0x5B, 0x20, 0x5B, 0x20, 0x5C, 0x21, 0x59, 0x20, 0x5A, 0x20, 0x5D, 0x21, 0x5D, 0x21, 0x5C, 0x22, 0x5C, 0x22, 0x5D, 0x22, 0x5F, 0x23, 0x5E, 0x23, 0x60, 0x23, 0x5E, 0x21, 0x5F, 0x22, 0x5E, 0x22, 0x5D, 0x21, 0x5F, 0x22, 0x5D, 0x22, 0x5B, 0x22, 0x5D, 0x22, 0x5C, 0x21, 0x5D, 0x22, 0x5F, 0x23, 0x5F, 0x22, 0x62, 0x23, 0x62, 0x23, 0x63, 0x23, 0x65, 0x24, 0x63, 0x23, 0x62, 0x22, 0x60, 0x23, 0x5E, 0x22, 0x60, 0x22, 0x62, 0x23, 0x64, 0x24, 0x63, 0x23, 0x64, 0x24, 0x65, 0x26, 0x67, 0x25, 0x63, 0x24, 0x63, 0x24, 0x63, 0x23, 0x64, 0x25, 0x62, 0x24, 0x63, 0x25, 0x67, 0x27, 0x68, 0x27, 0x66, 0x25, 0x69, 0x26, 0x67, 0x26, 0x6A, 0x27, 0x6B, 0x28, 0x6D, 0x2A, 0x6B, 0x28, 0x6A, 0x27, 0x69, 0x27, 0x69, 0x28, 0x61, 0x27, 0x4C, 0x23, 0x41, 0x22, 0x54, 0x25, 0x64, 0x28, 0x63, 0x28, 0x59, 0x24, 0x3D, 0x1C, 0x2A, 0x17, 0x25, 0x17, 0x24, 0x16, 0x20, 0x15, 0x1F, 0x15, 0x1F, 0x15, 0x20, 0x17, 0x2A, 0x25, 0x4C, 0x47, 0x72, 0x60, 0x7E, 0x67, 0x85, 0x6D, 0x8B, 0x70, 0x8A, 0x6E, 0x7F, 0x61, 0x51, 0x38, 0x2D, 0x20, 0x25, 0x1A, 0x22, 0x18, 0x1F, 0x15, 0x1F, 0x15, 0x20, 0x16, 0x22, 0x17, 0x34, 0x1D, 0x5C, 0x25, 0x64, 0x26, 0x62, 0x26, 0x47, 0x21, 0x3E, 0x20, 0x5C, 0x27, 0x67, 0x29, 0x6A, 0x2A, 0x6F, 0x2B, 0x71, 0x2B, 0x6F, 0x2C, 0x71, 0x2D, 0x6F, 0x2B, 0x6F, 0x2A, 0x6E, 0x2A, 0x70, 0x2C, 0x6F, 0x2B, 0x70, 0x2A, 0x6A, 0x28, 0x6C, 0x2A, 0x6E, 0x2A, 0x6E, 0x29, 0x6E, 0x2A, 0x6A, 0x28, 0x66, 0x28, 0x66, 0x27, 0x66, 0x27, 0x68, 0x27, 0x67, 0x27, 0x6A, 0x29, 0x6C, 0x2A, 0x6E, 0x2A, 0x6E, 0x29, 0x6E, 0x2A, 0x6E, 0x2A, 0x72, 0x2D, 0x73, 0x2D, 0x6F, 0x2B, 0x73, 0x2D, 0x74, 0x2E, 0x70, 0x2C, 0x6E, 0x2C, 0x71, 0x2C, 0x74, 0x2D, 0x77, 0x30, 0x72, 0x2D, 0x6E, 0x2A, 0x6E, 0x2A, 0x71, 0x2C, 0x76, 0x2D, 0x78, 0x30, 0x75, 0x2E, 0x72, 0x2D, 0x6E, 0x2B, 0x70, 0x2A, 0x6F, 0x2C, 0x73, 0x2D, 0x76, 0x2E, 0x74, 0x2E, 0x75, 0x2E, 0x72, 0x2B, 0x74, 0x2C, 0x73, 0x2C, 0x73, 0x2C, 0x78, 0x2E, 0x73, 0x2C, 0x79, 0x2F, 0x76, 0x2E, 0x79, 0x31, 0x74, 0x2E, 0x7C, 0x30, 0x6D, 0x2A, 0x6D, 0x29, 0x72, 0x2C, 0x77, 0x2F, 0x70, 0x2C, 0x72, 0x2C, 0x73, 0x2D, 0x6B, 0x2A, 0x67, 0x28, 0x6D, 0x29, 0x6C, 0x28, 0x71, 0x2B, 0x6E, 0x2B, 0x70, 0x2B, 0x6F, 0x2A, 0x6C, 0x29, 0x6C, 0x27, 0x6A, 0x27, 0x6B, 0x26, 0x62, 0x24, 0x61, 0x24, 0x68, 0x26, 0x68, 0x26, 0x6B, 0x27, 0x74, 0x2C, 0x6D, 0x29, 0x6F, 0x2A, 0x69, 0x27, 0x69, 0x27, 0x6A, 0x27, 0x6A, 0x28, 0x6D, 0x2A, 0x72, 0x2B, 0x6B, 0x2B, 0x6C, 0x29, 0x6A, 0x27, 0x64, 0x25, 0x4A, 0x1E, 0x3C, 0x1C, 0x3F, 0x1D, 0x53, 0x23, 0x67, 0x29, 0x6B, 0x2A, 0x6B, 0x2A, 0x6A, 0x2A, 0x6E, 0x2B, 0x6B, 0x2A, 0x69, 0x28, 0x67, 0x26, 0x67, 0x26, 0x65, 0x26, 0x63, 0x25, 0x68, 0x26, 0x63, 0x25, 0x66, 0x26, 0x64, 0x24, 0x61, 0x24, 0x60, 0x25, 0x63, 0x26, 0x65, 0x27, 0x66, 0x26, 0x64, 0x26, 0x63, 0x25, 0x5E, 0x23, 0x5D, 0x23, 0x5D, 0x23, 0x5D, 0x23, 0x5E, 0x23, 0x62, 0x25, 0x64, 0x26, 0x65, 0x25, 0x66, 0x25, 0x60, 0x23, 0x63, 0x25, 0x63, 0x25, 0x66, 0x26, 0x62, 0x24, 0x62, 0x24, 0x62, 0x26, 0x62, 0x25, 0x62, 0x25, 0x62, 0x27, 0x6A, 0x29, 0x66, 0x29, 0x6A, 0x2A, 0x67, 0x29, 0x6C, 0x2C, 0x67, 0x27, 0x62, 0x26, 0x61, 0x26, 0x61, 0x25, 0x61, 0x24, 0x60, 0x24, 0x5E, 0x25, 0x5E, 0x25, 0x5D, 0x24, 0x5F, 0x25, 0x5E, 0x24, 0x5E, 0x23, 0x5A, 0x21, 0x5B, 0x22, 0x5B, 0x22, 0x5B, 0x22, 0x59, 0x22, 0x5C, 0x23, 0x5D, 0x22, 0x58, 0x22, 0x5A, 0x23, 0x42, 0x1F, 0x36, 0x1E, 0x38, 0x1E, 0x32, 0x1B, 0x32, 0x1B, 0x37, 0x1F, 0x3A, 0x21, 0x39, 0x1F, 0x3B, 0x20, 0x3C, 0x20, 0x3A, 0x1F, 0x39, 0x1E, 0x31, 0x1B, 0x3C, 0x21, 0x44, 0x23, 0x3D, 0x20, 0x3F, 0x22, 0x3A, 0x20, 0x3A, 0x1F, 0x32, 0x1D, 0x3E, 0x21, 0x3A, 0x1E, 0x36, 0x1E, 0x35, 0x1D, 0x3D, 0x20, 0x36, 0x1C, 0x34, 0x1C, 0x2B, 0x19, 0x38, 0x1F, 0x32, 0x1C, 0x35, 0x1C, 0x2E, 0x1B, 0x38, 0x1F, 0x3F, 0x20, 0x3E, 0x20, 0x34, 0x1C, 0x40, 0x21, 0x3E, 0x21, 0x3D, 0x20, 0x39, 0x20, 0x39, 0x1E, 0x2E, 0x1A, 0x34, 0x1C, 0x2E, 0x1A, 0x37, 0x1D, 0x37, 0x1D, 0x3D, 0x20, 0x3F, 0x21
    },

    {
        0x65, 0x59, 0x65, 0x5A, 0x67, 0x5B, 0x68, 0x5B, 0x67, 0x5C, 0x6A, 0x5D, 0x66, 0x59, 0x68, 0x5B, 0x6A, 0x5D, 0x6A, 0x5E, 0x6B, 0x5D, 0x6B, 0x5D, 0x6D, 0x5E, 0x6C, 0x5F, 0x6C, 0x5F, 0x6E, 0x60, 0x6D, 0x60, 0x6E, 0x5F, 0x6E, 0x60, 0x6E, 0x5F, 0x6E, 0x61, 0x6E, 0x5E, 0x6D, 0x5E, 0x6E, 0x5E, 0x6C, 0x5D, 0x6D, 0x5F, 0x70, 0x60, 0x70, 0x61, 0x73, 0x63, 0x73, 0x63, 0x74, 0x64, 0x76, 0x66, 0x75, 0x61, 0x74, 0x62, 0x74, 0x61, 0x71, 0x61, 0x73, 0x62, 0x73, 0x63, 0x77, 0x65, 0x74, 0x63, 0x75, 0x66, 0x75, 0x68, 0x79, 0x69, 0x75, 0x64, 0x76, 0x64, 0x75, 0x65, 0x78, 0x66, 0x73, 0x64, 0x73, 0x66, 0x77, 0x6A, 0x78, 0x6A, 0x76, 0x68, 0x79, 0x69, 0x7A, 0x6A, 0x7C, 0x6C, 0x7B, 0x6E, 0x7C, 0x70, 0x7D, 0x6E, 0x7C, 0x6C, 0x78, 0x6C, 0x76, 0x6D, 0x71, 0x65, 0x5A, 0x4E, 0x46, 0x41, 0x50, 0x53, 0x6A, 0x64, 0x6C, 0x63, 0x64, 0x5D, 0x4A, 0x43, 0x2F, 0x2C, 0x25, 0x26, 0x22, 0x24, 0x1E, 0x20, 0x1C, 0x20, 0x1B, 0x1E, 0x1C, 0x20, 0x22, 0x27, 0x35, 0x47, 0x57, 0x71, 0x68, 0x7C, 0x71, 0x87, 0x74, 0x89, 0x71, 0x84, 0x66, 0x74, 0x3F, 0x3D, 0x26, 0x29, 0x20, 0x23, 0x1D, 0x21, 0x1B, 0x1E, 0x1B, 0x1F, 0x1D, 0x21, 0x22, 0x25, 0x3E, 0x44, 0x68, 0x63, 0x6F, 0x67, 0x68, 0x5D, 0x47, 0x3E, 0x44, 0x46, 0x68, 0x65, 0x73, 0x6B, 0x77, 0x6D, 0x7E, 0x73, 0x80, 0x73, 0x7B, 0x73, 0x7C, 0x72, 0x7B, 0x71, 0x7E, 0x71, 0x7E, 0x72, 0x7D, 0x74, 0x7D, 0x6E, 0x7C, 0x6F, 0x7A, 0x6B, 0x7A, 0x70, 0x7D, 0x71, 0x7E, 0x70, 0x7B, 0x6F, 0x7A, 0x6D, 0x77, 0x68, 0x75, 0x69, 0x73, 0x69, 0x77, 0x68, 0x78, 0x69, 0x7B, 0x6F, 0x7B, 0x71, 0x7C, 0x71, 0x7D, 0x6E, 0x80, 0x75, 0x80, 0x72, 0x80, 0x75, 0x80, 0x75, 0x7E, 0x71, 0x84, 0x78, 0x84, 0x78, 0x7C, 0x71, 0x7C, 0x70, 0x7C, 0x71, 0x81, 0x76, 0x82, 0x79, 0x80, 0x77, 0x7D, 0x71, 0x7F, 0x71, 0x7F, 0x70, 0x84, 0x78, 0x84, 0x79, 0x83, 0x75, 0x84, 0x77, 0x7E, 0x6F, 0x7E, 0x6F, 0x7F, 0x73, 0x84, 0x78, 0x81, 0x75, 0x81, 0x76, 0x80, 0x74, 0x80, 0x72, 0x83, 0x75, 0x81, 0x73, 0x80, 0x74, 0x8A, 0x80, 0x87, 0x79, 0x88, 0x79, 0x85, 0x78, 0x84, 0x7A, 0x83, 0x77, 0x87, 0x77, 0x7F, 0x6E, 0x7E, 0x6F, 0x84, 0x75, 0x87, 0x7A, 0x81, 0x75, 0x80, 0x71, 0x7E, 0x71, 0x7A, 0x6D, 0x79, 0x6E, 0x7C, 0x70, 0x7D, 0x6D, 0x80, 0x73, 0x7C, 0x73, 0x7F, 0x76, 0x7E, 0x70, 0x80, 0x71, 0x7C, 0x6A, 0x7C, 0x6D, 0x7B, 0x6B, 0x74, 0x62, 0x72, 0x65, 0x79, 0x6C, 0x7C, 0x6C, 0x7D, 0x6E, 0x81, 0x75, 0x7D, 0x70, 0x82, 0x73, 0x78, 0x6D, 0x7A, 0x6D, 0x77, 0x6A, 0x78, 0x6B, 0x7C, 0x72, 0x7E, 0x74, 0x78, 0x6D, 0x7B, 0x6E, 0x7A, 0x6B, 0x73, 0x66, 0x5F, 0x53, 0x4F, 0x48, 0x54, 0x51, 0x65, 0x5E, 0x74, 0x6C, 0x78, 0x6E, 0x78, 0x6D, 0x77, 0x6B, 0x7A, 0x6E, 0x7A, 0x6D, 0x7A, 0x6C, 0x77, 0x69, 0x76, 0x68, 0x75, 0x67, 0x74, 0x65, 0x77, 0x69, 0x72, 0x65, 0x76, 0x69, 0x74, 0x65, 0x71, 0x64, 0x73, 0x66, 0x74, 0x68, 0x74, 0x68, 0x72, 0x65, 0x72, 0x66, 0x72, 0x67, 0x6F, 0x62, 0x69, 0x5E, 0x6B, 0x60, 0x6D, 0x5F, 0x6E, 0x60, 0x71, 0x64, 0x71, 0x66, 0x73, 0x66, 0x73, 0x67, 0x71, 0x62, 0x70, 0x65, 0x72, 0x66, 0x75, 0x67, 0x74, 0x65, 0x73, 0x66, 0x70, 0x63, 0x72, 0x64, 0x71, 0x64, 0x70, 0x68, 0x78, 0x6A, 0x73, 0x6A, 0x78, 0x6D, 0x75, 0x6A, 0x77, 0x6F, 0x74, 0x68, 0x6E, 0x61, 0x6D, 0x64, 0x6F, 0x64, 0x6F, 0x62, 0x6F, 0x63, 0x6D, 0x61, 0x6D, 0x61, 0x6A, 0x5F, 0x6E, 0x62, 0x6C, 0x61, 0x6E, 0x60, 0x69, 0x5C, 0x69, 0x5C, 0x68, 0x5B, 0x68, 0x5D, 0x6A, 0x5C, 0x68, 0x5F, 0x6A, 0x5D, 0x66, 0x5A, 0x65, 0x59, 0x44, 0x41, 0x38, 0x3D, 0x36, 0x3B, 0x30, 0x35, 0x31, 0x35, 0x34, 0x3B, 0x38, 0x42, 0x36, 0x3B, 0x37, 0x3E, 0x39, 0x42, 0x35, 0x3C, 0x34, 0x39, 0x2E, 0x33, 0x36, 0x41, 0x39, 0x40, 0x33, 0x3A, 0x35, 0x3D, 0x33, 0x39, 0x32, 0x35, 0x2F, 0x37, 0x37, 0x3F, 0x33, 0x38, 0x32, 0x38, 0x2F, 0x34, 0x35, 0x3B, 0x30, 0x35, 0x2D, 0x31, 0x28, 0x2D, 0x33, 0x39, 0x32, 0x38, 0x31, 0x35, 0x2C, 0x32, 0x35, 0x3C, 0x3C, 0x44, 0x39, 0x3F, 0x31, 0x37, 0x3C, 0x45, 0x3B, 0x42, 0x33, 0x38, 0x33, 0x3D, 0x33, 0x36, 0x2B, 0x30, 0x2F, 0x33, 0x2C, 0x32, 0x34, 0x3C, 0x36, 0x3E, 0x3A, 0x41, 0x38, 0x40
    },

    {
        0x5B, 0x20, 0x5A, 0x20, 0x5A, 0x21, 0x5D, 0x20, 0x5B, 0x21, 0x5A, 0x21, 0x5B, 0x21, 0x5A, 0x21, 0x5B, 0x21, 0x5B, 0x21, 0x5C, 0x21, 0x5D, 0x22, 0x5D, 0x21, 0x5E, 0x21, 0x5E, 0x22, 0x60, 0x22, 0x60, 0x22, 0x60, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x5E, 0x21, 0x5E, 0x22, 0x5F, 0x22, 0x5E, 0x21, 0x5E, 0x21, 0x5E, 0x22, 0x60, 0x23, 0x62, 0x23, 0x63, 0x23, 0x61, 0x23, 0x60, 0x22, 0x61, 0x23, 0x62, 0x22, 0x62, 0x23, 0x62, 0x22, 0x61, 0x23, 0x5F, 0x23, 0x63, 0x24, 0x64, 0x24, 0x66, 0x25, 0x66, 0x25, 0x68, 0x26, 0x66, 0x24, 0x63, 0x23, 0x64, 0x23, 0x66, 0x24, 0x65, 0x25, 0x64, 0x24, 0x64, 0x25, 0x62, 0x25, 0x63, 0x25, 0x67, 0x26, 0x69, 0x26, 0x69, 0x27, 0x6A, 0x27, 0x6D, 0x29, 0x6E, 0x28, 0x6F, 0x29, 0x6B, 0x28, 0x6A, 0x28, 0x6C, 0x29, 0x63, 0x27, 0x50, 0x22, 0x3F, 0x20, 0x51, 0x23, 0x60, 0x26, 0x62, 0x26, 0x5B, 0x24, 0x46, 0x1E, 0x2B, 0x18, 0x24, 0x16, 0x22, 0x15, 0x20, 0x15, 0x1F, 0x15, 0x1E, 0x14, 0x20, 0x17, 0x28, 0x21, 0x43, 0x3F, 0x70, 0x5E, 0x7F, 0x69, 0x84, 0x6B, 0x80, 0x62, 0x53, 0x37, 0x2E, 0x1F, 0x26, 0x1A, 0x21, 0x17, 0x20, 0x15, 0x1F, 0x16, 0x23, 0x18, 0x26, 0x18, 0x30, 0x1B, 0x58, 0x25, 0x66, 0x27, 0x68, 0x28, 0x4B, 0x22, 0x38, 0x1F, 0x55, 0x25, 0x68, 0x29, 0x6E, 0x2B, 0x6E, 0x2A, 0x6E, 0x2A, 0x6C, 0x2A, 0x71, 0x2F, 0x6E, 0x2B, 0x70, 0x2C, 0x6F, 0x2B, 0x70, 0x2C, 0x70, 0x2C, 0x6D, 0x2A, 0x6A, 0x28, 0x6B, 0x28, 0x69, 0x29, 0x6A, 0x29, 0x6F, 0x2C, 0x6D, 0x2B, 0x6E, 0x2A, 0x6C, 0x2A, 0x6B, 0x2A, 0x6A, 0x29, 0x68, 0x28, 0x6C, 0x28, 0x6E, 0x2A, 0x72, 0x2B, 0x6C, 0x29, 0x70, 0x2C, 0x74, 0x2C, 0x72, 0x2C, 0x75, 0x2C, 0x72, 0x2D, 0x72, 0x2D, 0x76, 0x2E, 0x73, 0x2D, 0x6D, 0x29, 0x6C, 0x2A, 0x74, 0x2E, 0x74, 0x2D, 0x71, 0x2C, 0x77, 0x31, 0x74, 0x2D, 0x73, 0x2C, 0x71, 0x2C, 0x76, 0x2D, 0x73, 0x2C, 0x74, 0x2D, 0x72, 0x2D, 0x71, 0x2C, 0x6C, 0x2A, 0x72, 0x2D, 0x76, 0x2E, 0x76, 0x2E, 0x74, 0x2D, 0x75, 0x2E, 0x73, 0x2C, 0x6F, 0x2B, 0x71, 0x2C, 0x71, 0x2B, 0x75, 0x31, 0x86, 0x35, 0x75, 0x2C, 0x7E, 0x35, 0x7E, 0x30, 0x76, 0x2F, 0x7A, 0x2F, 0x77, 0x2E, 0x75, 0x2D, 0x77, 0x2E, 0x70, 0x2A, 0x79, 0x30, 0x74, 0x2E, 0x72, 0x2C, 0x70, 0x2B, 0x6E, 0x2A, 0x6D, 0x2A, 0x70, 0x2A, 0x72, 0x2C, 0x71, 0x2B, 0x71, 0x2C, 0x6E, 0x29, 0x6D, 0x29, 0x68, 0x26, 0x66, 0x26, 0x65, 0x26, 0x69, 0x27, 0x67, 0x25, 0x65, 0x25, 0x67, 0x26, 0x69, 0x27, 0x6A, 0x29, 0x68, 0x29, 0x70, 0x29, 0x6E, 0x2B, 0x6C, 0x29, 0x6D, 0x2A, 0x70, 0x2D, 0x71, 0x2D, 0x78, 0x2F, 0x70, 0x2D, 0x66, 0x26, 0x65, 0x28, 0x70, 0x2B, 0x68, 0x27, 0x6A, 0x28, 0x69, 0x29, 0x68, 0x29, 0x6D, 0x2C, 0x6B, 0x2A, 0x69, 0x28, 0x65, 0x26, 0x67, 0x27, 0x67, 0x28, 0x65, 0x27, 0x69, 0x27, 0x68, 0x26, 0x64, 0x25, 0x62, 0x24, 0x60, 0x23, 0x5E, 0x23, 0x62, 0x24, 0x64, 0x26, 0x69, 0x2B, 0x69, 0x2A, 0x67, 0x27, 0x66, 0x26, 0x62, 0x24, 0x60, 0x24, 0x60, 0x25, 0x5F, 0x25, 0x61, 0x25, 0x62, 0x24, 0x61, 0x24, 0x61, 0x24, 0x5D, 0x23, 0x61, 0x25, 0x61, 0x24, 0x61, 0x24, 0x5D, 0x23, 0x60, 0x23, 0x62, 0x25, 0x63, 0x25, 0x63, 0x24, 0x68, 0x28, 0x64, 0x26, 0x63, 0x24, 0x65, 0x26, 0x63, 0x27, 0x65, 0x26, 0x66, 0x27, 0x65, 0x26, 0x66, 0x29, 0x69, 0x2B, 0x66, 0x27, 0x61, 0x24, 0x5F, 0x25, 0x60, 0x25, 0x62, 0x25, 0x5F, 0x24, 0x5D, 0x24, 0x65, 0x28, 0x62, 0x25, 0x60, 0x25, 0x62, 0x26, 0x63, 0x25, 0x5E, 0x23, 0x5E, 0x23, 0x59, 0x22, 0x5C, 0x23, 0x59, 0x22, 0x59, 0x22, 0x5A, 0x22, 0x5A, 0x22, 0x59, 0x22, 0x48, 0x22, 0x4C, 0x27, 0x41, 0x23, 0x3E, 0x22, 0x42, 0x21, 0x42, 0x23, 0x43, 0x24, 0x42, 0x22, 0x39, 0x1F, 0x38, 0x1E, 0x33, 0x1D, 0x39, 0x1E, 0x35, 0x1D, 0x35, 0x1C, 0x2E, 0x1A, 0x2E, 0x1A, 0x36, 0x1C, 0x36, 0x1D, 0x30, 0x1A, 0x36, 0x1F, 0x40, 0x22, 0x33, 0x1C, 0x34, 0x1D, 0x2D, 0x1A, 0x36, 0x1D, 0x37, 0x1E, 0x30, 0x1B, 0x34, 0x1D, 0x42, 0x22, 0x3E, 0x20, 0x39, 0x1E, 0x33, 0x1C, 0x48, 0x26, 0x40, 0x21, 0x3B, 0x20, 0x35, 0x1C, 0x3A, 0x1F, 0x33, 0x1C, 0x2C, 0x19, 0x37, 0x1E, 0x36, 0x1D, 0x31, 0x1B, 0x3B, 0x1F, 0x3C, 0x1F, 0x3E, 0x21, 0x3D, 0x20, 0x3C, 0x20, 0x39, 0x1F
    },

    {
        0x66, 0x5B, 0x68, 0x5C, 0x67, 0x5B, 0x69, 0x5C, 0x68, 0x5C, 0x68, 0x5B, 0x68, 0x5B, 0x68, 0x5B, 0x6A, 0x5D, 0x6A, 0x5C, 0x6C, 0x5E, 0x6C, 0x5E, 0x6C, 0x5D, 0x6E, 0x5F, 0x6C, 0x5F, 0x6F, 0x61, 0x6F, 0x61, 0x70, 0x60, 0x70, 0x60, 0x6D, 0x5F, 0x6C, 0x5F, 0x6C, 0x5E, 0x6E, 0x5F, 0x6F, 0x60, 0x6E, 0x5F, 0x6E, 0x5E, 0x6E, 0x5F, 0x6F, 0x61, 0x72, 0x63, 0x73, 0x63, 0x71, 0x61, 0x71, 0x60, 0x72, 0x62, 0x74, 0x61, 0x73, 0x62, 0x74, 0x63, 0x73, 0x62, 0x72, 0x62, 0x76, 0x66, 0x78, 0x66, 0x77, 0x68, 0x75, 0x67, 0x77, 0x69, 0x78, 0x66, 0x75, 0x63, 0x75, 0x65, 0x77, 0x67, 0x77, 0x66, 0x75, 0x65, 0x75, 0x66, 0x71, 0x63, 0x73, 0x64, 0x77, 0x68, 0x7A, 0x6A, 0x7B, 0x6B, 0x7A, 0x6C, 0x7D, 0x6D, 0x7D, 0x6E, 0x7E, 0x71, 0x7C, 0x6C, 0x7A, 0x6C, 0x7A, 0x6E, 0x70, 0x65, 0x62, 0x54, 0x49, 0x41, 0x4C, 0x4D, 0x65, 0x5F, 0x6C, 0x65, 0x69, 0x61, 0x55, 0x4A, 0x31, 0x2D, 0x25, 0x26, 0x21, 0x22, 0x1E, 0x21, 0x1C, 0x1F, 0x1B, 0x1F, 0x1C, 0x21, 0x21, 0x27, 0x2F, 0x40, 0x52, 0x6C, 0x67, 0x7E, 0x6B, 0x80, 0x64, 0x74, 0x40, 0x3F, 0x26, 0x29, 0x21, 0x24, 0x1C, 0x20, 0x1B, 0x1F, 0x1B, 0x20, 0x1E, 0x23, 0x25, 0x29, 0x3C, 0x40, 0x64, 0x62, 0x70, 0x69, 0x6D, 0x64, 0x4A, 0x40, 0x40, 0x3F, 0x64, 0x60, 0x75, 0x6B, 0x79, 0x6F, 0x7C, 0x6F, 0x7B, 0x6D, 0x7B, 0x6D, 0x7B, 0x73, 0x7B, 0x6F, 0x7D, 0x74, 0x7B, 0x6E, 0x7C, 0x71, 0x7E, 0x72, 0x7C, 0x6E, 0x79, 0x6C, 0x7C, 0x6D, 0x78, 0x6C, 0x79, 0x6D, 0x7D, 0x70, 0x79, 0x6D, 0x7C, 0x6F, 0x7B, 0x6E, 0x7A, 0x6E, 0x7A, 0x6F, 0x77, 0x6B, 0x7B, 0x6D, 0x7F, 0x72, 0x7E, 0x74, 0x7D, 0x6E, 0x7E, 0x74, 0x82, 0x76, 0x83, 0x74, 0x83, 0x76, 0x80, 0x73, 0x7E, 0x71, 0x83, 0x76, 0x7C, 0x6D, 0x7B, 0x6F, 0x7B, 0x71, 0x80, 0x75, 0x80, 0x75, 0x7D, 0x70, 0x7E, 0x75, 0x80, 0x74, 0x83, 0x75, 0x83, 0x76, 0x81, 0x74, 0x81, 0x74, 0x82, 0x73, 0x82, 0x76, 0x81, 0x73, 0x79, 0x6B, 0x84, 0x78, 0x85, 0x77, 0x80, 0x74, 0x81, 0x75, 0x81, 0x76, 0x81, 0x74, 0x7D, 0x71, 0x7E, 0x73, 0x7E, 0x73, 0x7F, 0x74, 0x8C, 0x85, 0x87, 0x78, 0x88, 0x80, 0x86, 0x78, 0x83, 0x78, 0x8A, 0x7D, 0x84, 0x79, 0x86, 0x79, 0x87, 0x7B, 0x80, 0x72, 0x87, 0x7D, 0x85, 0x77, 0x80, 0x71, 0x80, 0x73, 0x81, 0x6F, 0x7A, 0x6E, 0x82, 0x74, 0x83, 0x76, 0x81, 0x75, 0x7E, 0x73, 0x7E, 0x70, 0x79, 0x6C, 0x79, 0x67, 0x78, 0x69, 0x78, 0x6A, 0x79, 0x6A, 0x75, 0x66, 0x74, 0x68, 0x78, 0x6A, 0x7A, 0x6B, 0x74, 0x68, 0x76, 0x68, 0x81, 0x73, 0x7E, 0x70, 0x7C, 0x6C, 0x7E, 0x70, 0x7A, 0x72, 0x7F, 0x75, 0x87, 0x7A, 0x7D, 0x72, 0x75, 0x66, 0x72, 0x69, 0x7B, 0x71, 0x78, 0x6B, 0x7A, 0x6D, 0x79, 0x6F, 0x77, 0x6F, 0x79, 0x71, 0x73, 0x6A, 0x75, 0x6C, 0x75, 0x6A, 0x74, 0x6A, 0x77, 0x69, 0x75, 0x69, 0x78, 0x6C, 0x79, 0x6A, 0x74, 0x67, 0x71, 0x62, 0x6E, 0x63, 0x6E, 0x60, 0x72, 0x63, 0x72, 0x66, 0x77, 0x6E, 0x73, 0x68, 0x75, 0x68, 0x73, 0x65, 0x70, 0x63, 0x6D, 0x64, 0x70, 0x61, 0x6C, 0x62, 0x6F, 0x64, 0x71, 0x63, 0x70, 0x64, 0x70, 0x63, 0x6E, 0x60, 0x6F, 0x63, 0x6E, 0x62, 0x6E, 0x62, 0x6B, 0x60, 0x6E, 0x62, 0x71, 0x63, 0x73, 0x67, 0x72, 0x65, 0x77, 0x6B, 0x72, 0x65, 0x73, 0x67, 0x76, 0x6A, 0x72, 0x67, 0x73, 0x67, 0x72, 0x68, 0x74, 0x68, 0x73, 0x6A, 0x75, 0x6C, 0x70, 0x67, 0x70, 0x63, 0x6D, 0x62, 0x6D, 0x63, 0x73, 0x65, 0x6E, 0x61, 0x6D, 0x65, 0x77, 0x6C, 0x72, 0x64, 0x6B, 0x61, 0x73, 0x67, 0x72, 0x66, 0x6C, 0x61, 0x6A, 0x5F, 0x67, 0x5D, 0x6B, 0x5E, 0x68, 0x5C, 0x66, 0x5A, 0x69, 0x5E, 0x69, 0x5E, 0x65, 0x5A, 0x4A, 0x49, 0x45, 0x4C, 0x3A, 0x42, 0x3A, 0x44, 0x3B, 0x41, 0x3C, 0x45, 0x3E, 0x46, 0x3A, 0x42, 0x31, 0x38, 0x30, 0x34, 0x2D, 0x35, 0x33, 0x37, 0x2E, 0x36, 0x2E, 0x32, 0x28, 0x2C, 0x2C, 0x31, 0x32, 0x38, 0x32, 0x37, 0x2C, 0x2F, 0x31, 0x3B, 0x37, 0x3F, 0x2F, 0x33, 0x31, 0x35, 0x2B, 0x31, 0x31, 0x37, 0x35, 0x3B, 0x2F, 0x34, 0x30, 0x36, 0x3D, 0x45, 0x36, 0x3B, 0x33, 0x3A, 0x2F, 0x35, 0x41, 0x4D, 0x35, 0x38, 0x35, 0x3D, 0x2F, 0x35, 0x32, 0x38, 0x2C, 0x30, 0x2A, 0x2F, 0x33, 0x3A, 0x33, 0x38, 0x2D, 0x32, 0x37, 0x3E, 0x37, 0x3E, 0x36, 0x3C, 0x34, 0x3B, 0x34, 0x3B, 0x30, 0x35
    },

    {
        0x5A, 0x20, 0x58, 0x20, 0x59, 0x20, 0x5A, 0x22, 0x5E, 0x23, 0x5C, 0x22, 0x5E, 0x23, 0x5E, 0x22, 0x5F, 0x22, 0x5E, 0x21, 0x5F, 0x22, 0x5F, 0x22, 0x5E, 0x22, 0x5C, 0x21, 0x5D, 0x22, 0x5E, 0x22, 0x5C, 0x21, 0x5C, 0x21, 0x5D, 0x21, 0x5B, 0x21, 0x5C, 0x22, 0x5E, 0x22, 0x60, 0x23, 0x60, 0x23, 0x62, 0x24, 0x61, 0x22, 0x5F, 0x22, 0x60, 0x23, 0x63, 0x23, 0x64, 0x23, 0x62, 0x23, 0x60, 0x23, 0x61, 0x23, 0x62, 0x23, 0x62, 0x23, 0x63, 0x23, 0x62, 0x24, 0x64, 0x24, 0x66, 0x24, 0x65, 0x25, 0x68, 0x25, 0x67, 0x25, 0x66, 0x25, 0x66, 0x25, 0x63, 0x24, 0x63, 0x23, 0x64, 0x24, 0x64, 0x24, 0x63, 0x24, 0x63, 0x24, 0x65, 0x25, 0x66, 0x25, 0x67, 0x26, 0x6B, 0x27, 0x6D, 0x28, 0x6A, 0x27, 0x69, 0x27, 0x6D, 0x28, 0x6C, 0x29, 0x6C, 0x28, 0x6B, 0x28, 0x6C, 0x28, 0x6A, 0x28, 0x69, 0x28, 0x59, 0x23, 0x3F, 0x1E, 0x45, 0x20, 0x5D, 0x25, 0x64, 0x26, 0x5F, 0x24, 0x4C, 0x1F, 0x31, 0x19, 0x27, 0x17, 0x23, 0x15, 0x21, 0x16, 0x20, 0x15, 0x21, 0x16, 0x1E, 0x15, 0x22, 0x1B, 0x39, 0x37, 0x68, 0x5A, 0x78, 0x5F, 0x54, 0x38, 0x2C, 0x1F, 0x26, 0x1A, 0x23, 0x18, 0x1F, 0x15, 0x1F, 0x15, 0x23, 0x17, 0x25, 0x17, 0x33, 0x1D, 0x57, 0x25, 0x65, 0x27, 0x61, 0x26, 0x4D, 0x23, 0x3A, 0x21, 0x5B, 0x28, 0x69, 0x29, 0x6E, 0x2B, 0x6E, 0x2B, 0x6C, 0x2A, 0x6F, 0x2B, 0x6E, 0x2A, 0x6E, 0x2B, 0x6F, 0x2C, 0x77, 0x30, 0x70, 0x2C, 0x71, 0x2B, 0x6C, 0x2B, 0x68, 0x29, 0x6B, 0x29, 0x6D, 0x29, 0x6E, 0x2A, 0x71, 0x2C, 0x6E, 0x2B, 0x6B, 0x29, 0x6F, 0x2C, 0x73, 0x2C, 0x71, 0x2D, 0x6E, 0x2B, 0x6F, 0x2B, 0x68, 0x27, 0x6C, 0x2A, 0x6F, 0x2B, 0x6D, 0x29, 0x6C, 0x2A, 0x71, 0x2B, 0x75, 0x2C, 0x71, 0x2B, 0x76, 0x2E, 0x6E, 0x2A, 0x73, 0x2C, 0x73, 0x2D, 0x70, 0x2B, 0x76, 0x31, 0x77, 0x30, 0x77, 0x2E, 0x71, 0x2C, 0x75, 0x2E, 0x74, 0x2D, 0x6F, 0x2D, 0x76, 0x30, 0x79, 0x30, 0x77, 0x2F, 0x7A, 0x34, 0x89, 0x38, 0x7D, 0x32, 0x77, 0x2C, 0x6F, 0x2B, 0x6F, 0x2C, 0x75, 0x30, 0x7C, 0x31, 0x73, 0x2D, 0x73, 0x2D, 0x6E, 0x2C, 0x73, 0x2F, 0x73, 0x2C, 0x6E, 0x2A, 0x7D, 0x35, 0x87, 0x39, 0x87, 0x38, 0x78, 0x31, 0x80, 0x32, 0x74, 0x2F, 0x77, 0x30, 0x83, 0x37, 0x81, 0x35, 0x7D, 0x35, 0x86, 0x38, 0x82, 0x36, 0x7A, 0x30, 0x78, 0x2F, 0x6F, 0x2A, 0x6E, 0x2A, 0x6F, 0x2B, 0x6E, 0x2A, 0x6D, 0x2A, 0x6F, 0x2A, 0x6A, 0x28, 0x69, 0x28, 0x66, 0x26, 0x69, 0x26, 0x68, 0x26, 0x68, 0x26, 0x63, 0x24, 0x61, 0x24, 0x65, 0x25, 0x68, 0x26, 0x63, 0x26, 0x74, 0x2F, 0x76, 0x2D, 0x73, 0x2B, 0x76, 0x30, 0x71, 0x2A, 0x6A, 0x2A, 0x70, 0x2D, 0x73, 0x2D, 0x74, 0x2F, 0x6B, 0x29, 0x69, 0x27, 0x6E, 0x29, 0x6D, 0x2A, 0x6E, 0x29, 0x70, 0x2D, 0x70, 0x2C, 0x75, 0x2F, 0x72, 0x2D, 0x6F, 0x2C, 0x6C, 0x29, 0x69, 0x27, 0x6B, 0x29, 0x68, 0x27, 0x64, 0x26, 0x66, 0x25, 0x61, 0x24, 0x61, 0x24, 0x63, 0x24, 0x64, 0x24, 0x62, 0x25, 0x63, 0x26, 0x65, 0x26, 0x64, 0x25, 0x62, 0x25, 0x68, 0x28, 0x64, 0x25, 0x62, 0x25, 0x5E, 0x24, 0x5E, 0x24, 0x63, 0x25, 0x61, 0x25, 0x5F, 0x24, 0x5D, 0x24, 0x63, 0x25, 0x5F, 0x23, 0x5F, 0x24, 0x60, 0x24, 0x5F, 0x24, 0x60, 0x25, 0x61, 0x25, 0x66, 0x26, 0x64, 0x26, 0x64, 0x25, 0x61, 0x24, 0x67, 0x28, 0x68, 0x28, 0x69, 0x28, 0x63, 0x27, 0x67, 0x29, 0x6A, 0x29, 0x64, 0x28, 0x63, 0x28, 0x67, 0x29, 0x68, 0x28, 0x66, 0x27, 0x62, 0x25, 0x60, 0x25, 0x61, 0x24, 0x5F, 0x25, 0x67, 0x28, 0x62, 0x24, 0x5E, 0x24, 0x63, 0x26, 0x5F, 0x24, 0x5E, 0x23, 0x61, 0x24, 0x5E, 0x24, 0x5C, 0x23, 0x5A, 0x22, 0x57, 0x21, 0x58, 0x22, 0x5D, 0x23, 0x5C, 0x24, 0x4E, 0x25, 0x4A, 0x27, 0x3E, 0x22, 0x45, 0x26, 0x3C, 0x20, 0x42, 0x23, 0x39, 0x1F, 0x31, 0x1B, 0x34, 0x1E, 0x30, 0x1B, 0x35, 0x1D, 0x37, 0x1D, 0x34, 0x1D, 0x36, 0x1E, 0x35, 0x1E, 0x3F, 0x22, 0x42, 0x23, 0x3A, 0x1E, 0x34, 0x1C, 0x38, 0x20, 0x3D, 0x1F, 0x37, 0x1E, 0x37, 0x1E, 0x34, 0x1D, 0x46, 0x24, 0x3D, 0x20, 0x3B, 0x20, 0x33, 0x1C, 0x41, 0x22, 0x2F, 0x1A, 0x38, 0x1E, 0x36, 0x1E, 0x41, 0x21, 0x2E, 0x1A, 0x35, 0x1D, 0x33, 0x1C, 0x37, 0x1E, 0x37, 0x1D, 0x3E, 0x21, 0x41, 0x22, 0x3E, 0x20, 0x33, 0x1C, 0x40, 0x22, 0x35, 0x1D, 0x32, 0x1C, 0x31, 0x1C, 0x35, 0x1D, 0x33, 0x1C
    },

    {
        0x66, 0x5A, 0x66, 0x59, 0x67, 0x5B, 0x67, 0x5D, 0x69, 0x5F, 0x6A, 0x5F, 0x6C, 0x60, 0x6C, 0x5F, 0x6C, 0x5F, 0x6B, 0x5E, 0x6E, 0x60, 0x6F, 0x60, 0x6D, 0x5F, 0x6B, 0x5E, 0x6B, 0x5E, 0x6C, 0x5E, 0x6C, 0x5D, 0x6B, 0x5C, 0x6B, 0x5D, 0x6A, 0x5D, 0x6C, 0x5E, 0x6E, 0x60, 0x70, 0x60, 0x71, 0x61, 0x71, 0x63, 0x72, 0x63, 0x71, 0x61, 0x71, 0x63, 0x73, 0x62, 0x73, 0x64, 0x72, 0x62, 0x72, 0x63, 0x73, 0x63, 0x74, 0x63, 0x72, 0x62, 0x74, 0x64, 0x75, 0x64, 0x76, 0x67, 0x77, 0x67, 0x76, 0x65, 0x79, 0x69, 0x78, 0x67, 0x76, 0x68, 0x77, 0x66, 0x75, 0x65, 0x74, 0x64, 0x74, 0x65, 0x74, 0x64, 0x74, 0x64, 0x74, 0x66, 0x76, 0x68, 0x77, 0x68, 0x79, 0x6A, 0x7C, 0x6E, 0x7F, 0x6E, 0x7B, 0x6A, 0x7A, 0x6C, 0x7E, 0x6F, 0x7D, 0x6D, 0x7E, 0x6E, 0x7C, 0x6C, 0x7B, 0x6D, 0x7B, 0x6E, 0x79, 0x6C, 0x6B, 0x5C, 0x4C, 0x40, 0x45, 0x44, 0x60, 0x5E, 0x70, 0x66, 0x68, 0x61, 0x59, 0x4F, 0x39, 0x33, 0x28, 0x28, 0x22, 0x24, 0x1F, 0x22, 0x1D, 0x21, 0x1C, 0x1F, 0x1B, 0x1F, 0x1C, 0x20, 0x28, 0x36, 0x48, 0x63, 0x5B, 0x6C, 0x3E, 0x3E, 0x25, 0x28, 0x20, 0x24, 0x1D, 0x22, 0x1B, 0x1F, 0x1B, 0x1F, 0x1E, 0x25, 0x24, 0x27, 0x39, 0x3F, 0x63, 0x63, 0x6F, 0x65, 0x66, 0x5F, 0x48, 0x42, 0x43, 0x43, 0x68, 0x68, 0x79, 0x6E, 0x7C, 0x72, 0x7A, 0x6E, 0x7B, 0x6F, 0x7C, 0x72, 0x7B, 0x6F, 0x7B, 0x72, 0x7D, 0x72, 0x82, 0x79, 0x7D, 0x72, 0x7D, 0x72, 0x7B, 0x6B, 0x76, 0x6D, 0x7C, 0x6E, 0x7C, 0x6E, 0x7B, 0x6F, 0x7F, 0x73, 0x7D, 0x70, 0x7A, 0x6D, 0x7C, 0x72, 0x7F, 0x72, 0x80, 0x76, 0x7F, 0x6F, 0x7E, 0x72, 0x78, 0x6A, 0x7B, 0x6E, 0x7A, 0x6F, 0x7D, 0x70, 0x7E, 0x6F, 0x81, 0x79, 0x86, 0x77, 0x80, 0x71, 0x82, 0x77, 0x80, 0x71, 0x81, 0x74, 0x80, 0x76, 0x7D, 0x6F, 0x82, 0x7A, 0x86, 0x7B, 0x86, 0x79, 0x80, 0x73, 0x80, 0x77, 0x81, 0x76, 0x80, 0x74, 0x84, 0x7A, 0x86, 0x7C, 0x86, 0x7B, 0x8A, 0x81, 0x93, 0x87, 0x8B, 0x80, 0x87, 0x79, 0x7F, 0x71, 0x7C, 0x71, 0x82, 0x7A, 0x8A, 0x7D, 0x83, 0x77, 0x80, 0x73, 0x7D, 0x74, 0x7D, 0x74, 0x7F, 0x72, 0x7C, 0x70, 0x85, 0x7C, 0x8E, 0x86, 0x8E, 0x87, 0x83, 0x79, 0x8A, 0x80, 0x80, 0x74, 0x83, 0x78, 0x8A, 0x82, 0x8A, 0x7E, 0x87, 0x83, 0x8D, 0x86, 0x8D, 0x85, 0x89, 0x7C, 0x87, 0x7A, 0x7F, 0x70, 0x7B, 0x70, 0x7E, 0x72, 0x7C, 0x6E, 0x7B, 0x6E, 0x7D, 0x70, 0x7B, 0x6D, 0x79, 0x6C, 0x74, 0x66, 0x7A, 0x6C, 0x78, 0x69, 0x77, 0x69, 0x72, 0x63, 0x70, 0x63, 0x76, 0x69, 0x78, 0x69, 0x74, 0x68, 0x82, 0x79, 0x82, 0x74, 0x83, 0x76, 0x86, 0x7D, 0x7E, 0x70, 0x79, 0x6F, 0x7B, 0x6E, 0x7D, 0x72, 0x7C, 0x74, 0x7B, 0x72, 0x7B, 0x6D, 0x7E, 0x71, 0x7B, 0x71, 0x7D, 0x70, 0x7E, 0x74, 0x7F, 0x74, 0x81, 0x75, 0x7F, 0x74, 0x7F, 0x72, 0x7B, 0x6E, 0x79, 0x6C, 0x7B, 0x6D, 0x77, 0x69, 0x74, 0x66, 0x77, 0x67, 0x70, 0x64, 0x70, 0x63, 0x72, 0x65, 0x73, 0x64, 0x72, 0x65, 0x71, 0x65, 0x75, 0x68, 0x73, 0x65, 0x71, 0x65, 0x75, 0x6B, 0x74, 0x65, 0x72, 0x65, 0x6E, 0x62, 0x71, 0x64, 0x6E, 0x62, 0x6F, 0x64, 0x6D, 0x60, 0x6E, 0x61, 0x73, 0x66, 0x71, 0x62, 0x6F, 0x63, 0x70, 0x63, 0x6D, 0x63, 0x70, 0x63, 0x6F, 0x64, 0x74, 0x67, 0x72, 0x67, 0x71, 0x64, 0x6E, 0x62, 0x71, 0x67, 0x76, 0x69, 0x76, 0x6B, 0x72, 0x67, 0x75, 0x6C, 0x78, 0x6C, 0x72, 0x67, 0x70, 0x66, 0x75, 0x6B, 0x76, 0x69, 0x73, 0x68, 0x71, 0x64, 0x6F, 0x63, 0x71, 0x65, 0x6F, 0x61, 0x73, 0x67, 0x72, 0x64, 0x6D, 0x62, 0x6F, 0x64, 0x6D, 0x61, 0x6D, 0x60, 0x6F, 0x63, 0x6A, 0x5D, 0x69, 0x5E, 0x69, 0x5C, 0x65, 0x59, 0x64, 0x5A, 0x6B, 0x60, 0x68, 0x5D, 0x4B, 0x4B, 0x3F, 0x47, 0x37, 0x3E, 0x3C, 0x46, 0x33, 0x3A, 0x38, 0x3F, 0x2F, 0x34, 0x2B, 0x2F, 0x2F, 0x36, 0x2F, 0x36, 0x31, 0x39, 0x31, 0x36, 0x31, 0x3A, 0x33, 0x39, 0x35, 0x3C, 0x3C, 0x47, 0x37, 0x3E, 0x33, 0x39, 0x30, 0x34, 0x34, 0x3F, 0x38, 0x3F, 0x34, 0x3A, 0x33, 0x38, 0x31, 0x38, 0x3F, 0x46, 0x33, 0x38, 0x34, 0x3B, 0x2F, 0x35, 0x3A, 0x40, 0x2A, 0x2E, 0x31, 0x39, 0x32, 0x3B, 0x36, 0x3A, 0x2C, 0x2F, 0x30, 0x35, 0x30, 0x36, 0x34, 0x3D, 0x35, 0x3B, 0x38, 0x3F, 0x39, 0x43, 0x35, 0x3A, 0x2E, 0x36, 0x38, 0x3E, 0x2F, 0x32, 0x2E, 0x35, 0x2C, 0x34, 0x2F, 0x37, 0x31, 0x37
    },

    {
        0x58, 0x20, 0x59, 0x1F, 0x5A, 0x21, 0x5B, 0x22, 0x5F, 0x23, 0x60, 0x23, 0x61, 0x23, 0x5F, 0x22, 0x5D, 0x21, 0x5F, 0x22, 0x5D, 0x21, 0x5C, 0x21, 0x5C, 0x21, 0x5B, 0x21, 0x5D, 0x22, 0x5D, 0x22, 0x5D, 0x21, 0x5D, 0x21, 0x5D, 0x21, 0x5B, 0x21, 0x5C, 0x22, 0x5F, 0x22, 0x60, 0x23, 0x61, 0x23, 0x61, 0x23, 0x61, 0x23, 0x60, 0x23, 0x60, 0x22, 0x61, 0x23, 0x62, 0x23, 0x60, 0x23, 0x62, 0x23, 0x61, 0x23, 0x60, 0x23, 0x61, 0x23, 0x61, 0x22, 0x62, 0x24, 0x65, 0x24, 0x64, 0x24, 0x64, 0x24, 0x64, 0x25, 0x66, 0x25, 0x68, 0x26, 0x65, 0x24, 0x62, 0x24, 0x62, 0x23, 0x64, 0x24, 0x62, 0x24, 0x62, 0x24, 0x68, 0x25, 0x68, 0x26, 0x64, 0x24, 0x66, 0x25, 0x6A, 0x26, 0x67, 0x25, 0x68, 0x26, 0x6B, 0x27, 0x6C, 0x28, 0x6D, 0x29, 0x6C, 0x28, 0x6C, 0x28, 0x6E, 0x29, 0x6E, 0x29, 0x6C, 0x29, 0x66, 0x26, 0x59, 0x24, 0x42, 0x1F, 0x43, 0x22, 0x5B, 0x25, 0x65, 0x27, 0x5C, 0x24, 0x4E, 0x20, 0x36, 0x1A, 0x2A, 0x18, 0x26, 0x18, 0x23, 0x16, 0x21, 0x16, 0x1E, 0x14, 0x1D, 0x14, 0x21, 0x1A, 0x30, 0x2A, 0x3C, 0x2D, 0x27, 0x1C, 0x23, 0x19, 0x22, 0x16, 0x1F, 0x15, 0x1F, 0x15, 0x20, 0x16, 0x22, 0x17, 0x2E, 0x1B, 0x54, 0x24, 0x63, 0x27, 0x62, 0x26, 0x4D, 0x23, 0x3A, 0x20, 0x5C, 0x29, 0x6B, 0x2A, 0x6D, 0x2B, 0x6F, 0x2B, 0x6F, 0x2B, 0x6E, 0x2B, 0x6C, 0x2A, 0x6D, 0x2A, 0x71, 0x2C, 0x6F, 0x2C, 0x6C, 0x2A, 0x71, 0x2C, 0x6F, 0x2C, 0x71, 0x2C, 0x6C, 0x2A, 0x6C, 0x2A, 0x6C, 0x2A, 0x72, 0x2D, 0x71, 0x2C, 0x6F, 0x2A, 0x6A, 0x29, 0x6D, 0x2A, 0x6E, 0x2A, 0x72, 0x2C, 0x73, 0x30, 0x86, 0x36, 0x74, 0x2B, 0x6F, 0x2B, 0x6D, 0x2A, 0x6F, 0x2A, 0x6F, 0x2B, 0x77, 0x2F, 0x74, 0x2D, 0x75, 0x30, 0x76, 0x2D, 0x71, 0x2B, 0x6C, 0x2A, 0x71, 0x30, 0x7B, 0x31, 0x76, 0x31, 0x7A, 0x2F, 0x74, 0x2D, 0x71, 0x2C, 0x80, 0x35, 0x7A, 0x30, 0x79, 0x32, 0x88, 0x3A, 0x85, 0x38, 0x80, 0x34, 0x76, 0x2F, 0x75, 0x2D, 0x6F, 0x2C, 0x74, 0x2E, 0x75, 0x2F, 0x74, 0x2D, 0x75, 0x2F, 0x7E, 0x33, 0x86, 0x38, 0x83, 0x35, 0x79, 0x30, 0x6E, 0x2B, 0x73, 0x2C, 0x6A, 0x28, 0x71, 0x2A, 0x77, 0x31, 0x86, 0x37, 0x78, 0x30, 0x80, 0x36, 0x73, 0x2C, 0x73, 0x2C, 0x6E, 0x2B, 0x71, 0x2B, 0x72, 0x2F, 0x7B, 0x33, 0x75, 0x30, 0x7B, 0x31, 0x78, 0x2E, 0x75, 0x2B, 0x6F, 0x2B, 0x6F, 0x2B, 0x67, 0x28, 0x70, 0x2B, 0x6E, 0x29, 0x6D, 0x2A, 0x6A, 0x28, 0x6E, 0x2A, 0x6B, 0x27, 0x68, 0x26, 0x62, 0x24, 0x63, 0x24, 0x5E, 0x23, 0x61, 0x24, 0x62, 0x25, 0x67, 0x27, 0x71, 0x2D, 0x74, 0x2B, 0x76, 0x32, 0x80, 0x33, 0x71, 0x2D, 0x70, 0x2D, 0x6E, 0x2A, 0x68, 0x29, 0x70, 0x2E, 0x74, 0x2D, 0x6C, 0x2A, 0x6F, 0x29, 0x6E, 0x2A, 0x71, 0x2B, 0x6E, 0x29, 0x6A, 0x29, 0x6A, 0x2A, 0x6D, 0x29, 0x6D, 0x29, 0x6D, 0x29, 0x6B, 0x29, 0x69, 0x28, 0x67, 0x26, 0x64, 0x25, 0x63, 0x25, 0x64, 0x25, 0x60, 0x24, 0x5E, 0x24, 0x62, 0x25, 0x6A, 0x28, 0x61, 0x25, 0x63, 0x25, 0x65, 0x27, 0x67, 0x26, 0x63, 0x26, 0x67, 0x27, 0x67, 0x26, 0x63, 0x26, 0x64, 0x25, 0x61, 0x24, 0x61, 0x24, 0x62, 0x24, 0x64, 0x25, 0x62, 0x25, 0x62, 0x25, 0x62, 0x25, 0x67, 0x2A, 0x63, 0x25, 0x5E, 0x24, 0x5E, 0x24, 0x61, 0x25, 0x61, 0x24, 0x5F, 0x24, 0x60, 0x24, 0x5E, 0x24, 0x64, 0x26, 0x69, 0x29, 0x69, 0x28, 0x6C, 0x2A, 0x6B, 0x2B, 0x6A, 0x2A, 0x63, 0x27, 0x64, 0x26, 0x63, 0x26, 0x63, 0x26, 0x5F, 0x24, 0x5F, 0x24, 0x64, 0x26, 0x5F, 0x24, 0x60, 0x26, 0x60, 0x25, 0x5C, 0x22, 0x5E, 0x24, 0x5E, 0x25, 0x5C, 0x23, 0x5C, 0x23, 0x5C, 0x22, 0x5D, 0x23, 0x5A, 0x23, 0x58, 0x22, 0x5A, 0x21, 0x58, 0x22, 0x5C, 0x24, 0x46, 0x22, 0x36, 0x1E, 0x37, 0x1F, 0x37, 0x1E, 0x35, 0x1E, 0x33, 0x1C, 0x31, 0x1C, 0x37, 0x1E, 0x3B, 0x20, 0x42, 0x23, 0x3E, 0x21, 0x41, 0x22, 0x44, 0x24, 0x43, 0x23, 0x45, 0x24, 0x39, 0x1F, 0x3A, 0x1F, 0x36, 0x1E, 0x3C, 0x21, 0x41, 0x22, 0x40, 0x21, 0x38, 0x1C, 0x38, 0x1E, 0x34, 0x1D, 0x3A, 0x1E, 0x2F, 0x1B, 0x34, 0x1D, 0x31, 0x1D, 0x3E, 0x20, 0x35, 0x1D, 0x3C, 0x1F, 0x40, 0x22, 0x39, 0x1E, 0x37, 0x1D, 0x3F, 0x22, 0x35, 0x1D, 0x3E, 0x21, 0x37, 0x1E, 0x32, 0x1C, 0x34, 0x1D, 0x31, 0x1B, 0x35, 0x1D, 0x38, 0x1E, 0x35, 0x1D, 0x36, 0x1F, 0x3D, 0x21, 0x40, 0x22, 0x3B, 0x20
    },

    {
        0x67, 0x59, 0x66, 0x59, 0x67, 0x5A, 0x66, 0x5C, 0x6A, 0x5F, 0x6C, 0x63, 0x6F, 0x61, 0x6E, 0x5F, 0x6D, 0x60, 0x6E, 0x60, 0x6D, 0x5D, 0x6D, 0x5C, 0x6C, 0x5D, 0x6B, 0x5C, 0x6C, 0x5E, 0x6F, 0x5F, 0x6E, 0x60, 0x6E, 0x5F, 0x6D, 0x5F, 0x6C, 0x5D, 0x6C, 0x5E, 0x6D, 0x61, 0x70, 0x61, 0x72, 0x63, 0x72, 0x63, 0x74, 0x62, 0x72, 0x62, 0x71, 0x61, 0x73, 0x64, 0x75, 0x63, 0x71, 0x61, 0x72, 0x61, 0x72, 0x62, 0x70, 0x61, 0x74, 0x62, 0x74, 0x63, 0x76, 0x65, 0x77, 0x65, 0x76, 0x66, 0x76, 0x65, 0x76, 0x65, 0x79, 0x68, 0x7B, 0x69, 0x78, 0x66, 0x75, 0x64, 0x75, 0x65, 0x74, 0x64, 0x72, 0x62, 0x74, 0x65, 0x79, 0x68, 0x79, 0x68, 0x76, 0x65, 0x77, 0x68, 0x7B, 0x6A, 0x79, 0x67, 0x78, 0x69, 0x7D, 0x6D, 0x80, 0x6E, 0x80, 0x6E, 0x7B, 0x6B, 0x7B, 0x6D, 0x7D, 0x6E, 0x7E, 0x70, 0x7D, 0x6D, 0x76, 0x68, 0x6C, 0x5F, 0x54, 0x47, 0x45, 0x42, 0x59, 0x59, 0x6D, 0x65, 0x6A, 0x62, 0x5F, 0x54, 0x43, 0x3B, 0x2B, 0x2B, 0x25, 0x27, 0x20, 0x23, 0x1D, 0x20, 0x1A, 0x1D, 0x1B, 0x1E, 0x1D, 0x21, 0x24, 0x2C, 0x2A, 0x2E, 0x20, 0x23, 0x1E, 0x21, 0x1C, 0x21, 0x1B, 0x1F, 0x1B, 0x20, 0x1D, 0x20, 0x21, 0x24, 0x36, 0x3B, 0x5E, 0x5E, 0x6C, 0x65, 0x68, 0x5F, 0x4B, 0x42, 0x40, 0x42, 0x69, 0x68, 0x74, 0x6A, 0x7B, 0x6F, 0x7D, 0x72, 0x7D, 0x71, 0x7C, 0x6F, 0x7A, 0x6E, 0x7C, 0x6E, 0x7D, 0x72, 0x7D, 0x70, 0x7C, 0x70, 0x7C, 0x71, 0x7D, 0x70, 0x7E, 0x71, 0x7B, 0x6F, 0x7C, 0x70, 0x7B, 0x6F, 0x7F, 0x73, 0x7E, 0x73, 0x7F, 0x70, 0x7B, 0x6D, 0x7F, 0x71, 0x7F, 0x70, 0x81, 0x73, 0x82, 0x78, 0x8E, 0x87, 0x84, 0x74, 0x7E, 0x70, 0x7B, 0x6F, 0x7E, 0x71, 0x80, 0x72, 0x83, 0x76, 0x82, 0x75, 0x82, 0x77, 0x7F, 0x71, 0x82, 0x73, 0x7B, 0x6E, 0x7D, 0x75, 0x87, 0x7F, 0x84, 0x79, 0x88, 0x79, 0x81, 0x75, 0x81, 0x75, 0x88, 0x85, 0x86, 0x79, 0x8A, 0x80, 0x93, 0x91, 0x8E, 0x85, 0x89, 0x80, 0x83, 0x77, 0x80, 0x73, 0x7F, 0x72, 0x84, 0x78, 0x83, 0x79, 0x81, 0x77, 0x82, 0x77, 0x8B, 0x83, 0x8D, 0x86, 0x8A, 0x80, 0x83, 0x78, 0x80, 0x71, 0x81, 0x75, 0x7C, 0x6D, 0x82, 0x73, 0x89, 0x7B, 0x91, 0x88, 0x88, 0x7A, 0x88, 0x80, 0x7F, 0x73, 0x83, 0x74, 0x7E, 0x73, 0x82, 0x72, 0x7E, 0x74, 0x87, 0x7E, 0x85, 0x79, 0x8B, 0x80, 0x87, 0x7B, 0x82, 0x74, 0x7E, 0x73, 0x80, 0x73, 0x78, 0x6C, 0x7E, 0x72, 0x7D, 0x6E, 0x7C, 0x6F, 0x79, 0x6E, 0x7C, 0x70, 0x7E, 0x6D, 0x77, 0x68, 0x72, 0x64, 0x73, 0x65, 0x6F, 0x61, 0x73, 0x64, 0x73, 0x65, 0x76, 0x69, 0x81, 0x72, 0x86, 0x78, 0x86, 0x7D, 0x88, 0x7A, 0x7F, 0x73, 0x7D, 0x71, 0x7D, 0x6E, 0x75, 0x6A, 0x80, 0x77, 0x80, 0x72, 0x7D, 0x70, 0x7F, 0x71, 0x7E, 0x70, 0x80, 0x72, 0x7F, 0x70, 0x78, 0x6B, 0x78, 0x6C, 0x7C, 0x6C, 0x7C, 0x6F, 0x7C, 0x6E, 0x7B, 0x6F, 0x7A, 0x6C, 0x76, 0x68, 0x73, 0x66, 0x76, 0x68, 0x74, 0x65, 0x71, 0x63, 0x6C, 0x60, 0x72, 0x66, 0x79, 0x6C, 0x72, 0x65, 0x72, 0x64, 0x71, 0x67, 0x76, 0x69, 0x72, 0x66, 0x77, 0x6A, 0x74, 0x67, 0x73, 0x66, 0x76, 0x67, 0x71, 0x63, 0x72, 0x64, 0x72, 0x64, 0x74, 0x67, 0x72, 0x64, 0x72, 0x65, 0x73, 0x64, 0x73, 0x69, 0x71, 0x64, 0x6F, 0x62, 0x6B, 0x60, 0x70, 0x62, 0x70, 0x63, 0x6F, 0x62, 0x72, 0x63, 0x6F, 0x62, 0x77, 0x68, 0x75, 0x69, 0x77, 0x6C, 0x79, 0x6E, 0x76, 0x6D, 0x78, 0x6D, 0x71, 0x66, 0x72, 0x65, 0x72, 0x64, 0x73, 0x64, 0x6E, 0x61, 0x6F, 0x64, 0x73, 0x65, 0x6D, 0x60, 0x70, 0x65, 0x6F, 0x62, 0x6D, 0x5E, 0x6C, 0x60, 0x6C, 0x61, 0x6B, 0x5F, 0x6B, 0x5F, 0x6A, 0x5E, 0x69, 0x5F, 0x65, 0x5C, 0x66, 0x5D, 0x67, 0x5B, 0x66, 0x5B, 0x67, 0x5A, 0x44, 0x42, 0x33, 0x35, 0x34, 0x39, 0x30, 0x33, 0x31, 0x39, 0x2F, 0x35, 0x31, 0x38, 0x36, 0x3D, 0x39, 0x41, 0x3C, 0x44, 0x37, 0x41, 0x3B, 0x44, 0x3C, 0x44, 0x39, 0x40, 0x38, 0x40, 0x30, 0x37, 0x35, 0x3B, 0x32, 0x38, 0x3A, 0x40, 0x3A, 0x43, 0x36, 0x3D, 0x32, 0x34, 0x33, 0x38, 0x32, 0x3A, 0x33, 0x36, 0x2C, 0x32, 0x30, 0x33, 0x2F, 0x37, 0x38, 0x3F, 0x30, 0x37, 0x37, 0x40, 0x3A, 0x43, 0x36, 0x3B, 0x32, 0x37, 0x39, 0x41, 0x2F, 0x35, 0x37, 0x3E, 0x2F, 0x33, 0x2E, 0x32, 0x2E, 0x33, 0x2E, 0x33, 0x31, 0x38, 0x33, 0x38, 0x31, 0x37, 0x33, 0x3C, 0x38, 0x3E, 0x39, 0x43, 0x34, 0x37
    },

    {
        0x5A, 0x20, 0x58, 0x1F, 0x58, 0x20, 0x5B, 0x22, 0x5E, 0x22, 0x5E, 0x22, 0x5D, 0x22, 0x5D, 0x22, 0x60, 0x23, 0x60, 0x23, 0x5C, 0x21, 0x5D, 0x21, 0x5D, 0x21, 0x5B, 0x21, 0x5D, 0x22, 0x5D, 0x22, 0x5E, 0x22, 0x5E, 0x23, 0x5D, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x60, 0x23, 0x60, 0x23, 0x62, 0x22, 0x61, 0x23, 0x63, 0x23, 0x63, 0x23, 0x63, 0x22, 0x60, 0x23, 0x5F, 0x22, 0x5F, 0x21, 0x5F, 0x22, 0x60, 0x22, 0x5F, 0x23, 0x60, 0x23, 0x62, 0x23, 0x65, 0x25, 0x65, 0x25, 0x63, 0x24, 0x63, 0x23, 0x65, 0x24, 0x66, 0x25, 0x66, 0x25, 0x65, 0x25, 0x65, 0x24, 0x64, 0x24, 0x61, 0x23, 0x63, 0x24, 0x65, 0x25, 0x68, 0x26, 0x64, 0x24, 0x63, 0x25, 0x67, 0x26, 0x67, 0x27, 0x69, 0x26, 0x6B, 0x26, 0x6B, 0x26, 0x6B, 0x27, 0x68, 0x26, 0x6A, 0x28, 0x6D, 0x29, 0x6C, 0x28, 0x6A, 0x28, 0x6D, 0x28, 0x69, 0x27, 0x64, 0x27, 0x4C, 0x21, 0x3E, 0x1F, 0x54, 0x24, 0x61, 0x26, 0x62, 0x26, 0x5A, 0x24, 0x3D, 0x1C, 0x2C, 0x19, 0x25, 0x16, 0x21, 0x15, 0x1F, 0x15, 0x1F, 0x15, 0x1F, 0x15, 0x1E, 0x16, 0x1F, 0x16, 0x20, 0x17, 0x1F, 0x16, 0x1E, 0x15, 0x1F, 0x15, 0x20, 0x15, 0x1F, 0x15, 0x2E, 0x1A, 0x53, 0x24, 0x61, 0x25, 0x60, 0x26, 0x4B, 0x21, 0x37, 0x1D, 0x54, 0x24, 0x66, 0x28, 0x68, 0x28, 0x70, 0x2C, 0x73, 0x2E, 0x6F, 0x2B, 0x71, 0x2C, 0x6F, 0x2C, 0x6E, 0x2B, 0x72, 0x2D, 0x71, 0x2C, 0x71, 0x2B, 0x6A, 0x29, 0x6B, 0x2A, 0x6F, 0x2B, 0x75, 0x2E, 0x74, 0x2C, 0x71, 0x2E, 0x70, 0x2D, 0x71, 0x2C, 0x6D, 0x2A, 0x6D, 0x2A, 0x71, 0x2C, 0x72, 0x2C, 0x6F, 0x2B, 0x6F, 0x2C, 0x75, 0x2D, 0x6E, 0x2A, 0x70, 0x2B, 0x6F, 0x2A, 0x72, 0x2A, 0x73, 0x2F, 0x71, 0x2A, 0x6C, 0x29, 0x6E, 0x2A, 0x6F, 0x2B, 0x73, 0x2C, 0x71, 0x2C, 0x75, 0x30, 0x7A, 0x32, 0x76, 0x2E, 0x7B, 0x31, 0x76, 0x30, 0x81, 0x34, 0x7A, 0x33, 0x7E, 0x36, 0x86, 0x3A, 0x92, 0x3F, 0x80, 0x34, 0x83, 0x36, 0x7C, 0x32, 0x70, 0x2C, 0x7F, 0x33, 0x78, 0x31, 0x76, 0x30, 0x74, 0x2E, 0x79, 0x31, 0x87, 0x3D, 0x80, 0x36, 0x7C, 0x30, 0x79, 0x31, 0x75, 0x2F, 0x77, 0x2E, 0x6D, 0x2B, 0x74, 0x2C, 0x71, 0x2B, 0x74, 0x2E, 0x77, 0x2E, 0x71, 0x2E, 0x7E, 0x32, 0x76, 0x30, 0x7B, 0x30, 0x77, 0x2E, 0x72, 0x2B, 0x78, 0x31, 0x78, 0x31, 0x78, 0x34, 0x76, 0x2F, 0x76, 0x2F, 0x73, 0x2C, 0x73, 0x2B, 0x6D, 0x2A, 0x70, 0x29, 0x6E, 0x2A, 0x6F, 0x2A, 0x6B, 0x29, 0x6F, 0x2A, 0x6B, 0x27, 0x68, 0x26, 0x67, 0x26, 0x67, 0x26, 0x62, 0x24, 0x67, 0x26, 0x68, 0x26, 0x6B, 0x29, 0x6B, 0x29, 0x77, 0x2E, 0x6C, 0x28, 0x6E, 0x2A, 0x6D, 0x2B, 0x70, 0x2E, 0x76, 0x2F, 0x76, 0x2F, 0x70, 0x2D, 0x6D, 0x29, 0x6F, 0x29, 0x6B, 0x28, 0x6F, 0x29, 0x6F, 0x2A, 0x6E, 0x2A, 0x6E, 0x2C, 0x67, 0x28, 0x68, 0x27, 0x68, 0x27, 0x68, 0x27, 0x6B, 0x29, 0x6A, 0x27, 0x68, 0x28, 0x68, 0x27, 0x68, 0x27, 0x67, 0x27, 0x66, 0x26, 0x69, 0x27, 0x66, 0x26, 0x63, 0x24, 0x62, 0x25, 0x66, 0x26, 0x67, 0x27, 0x66, 0x26, 0x65, 0x26, 0x62, 0x25, 0x60, 0x24, 0x61, 0x25, 0x60, 0x24, 0x62, 0x25, 0x61, 0x24, 0x62, 0x24, 0x64, 0x25, 0x62, 0x25, 0x65, 0x27, 0x68, 0x29, 0x62, 0x25, 0x65, 0x26, 0x5F, 0x24, 0x5C, 0x23, 0x5D, 0x23, 0x60, 0x25, 0x62, 0x26, 0x63, 0x26, 0x60, 0x24, 0x61, 0x25, 0x64, 0x26, 0x66, 0x27, 0x65, 0x29, 0x6B, 0x2D, 0x6D, 0x2B, 0x66, 0x28, 0x62, 0x25, 0x61, 0x24, 0x65, 0x26, 0x5F, 0x24, 0x62, 0x24, 0x5E, 0x24, 0x68, 0x2A, 0x60, 0x24, 0x61, 0x26, 0x62, 0x24, 0x63, 0x25, 0x60, 0x24, 0x5E, 0x23, 0x5B, 0x23, 0x5B, 0x23, 0x5D, 0x23, 0x5E, 0x24, 0x5F, 0x24, 0x5B, 0x22, 0x58, 0x22, 0x54, 0x20, 0x3B, 0x1D, 0x31, 0x1C, 0x3C, 0x21, 0x3A, 0x21, 0x4B, 0x28, 0x44, 0x25, 0x4B, 0x26, 0x46, 0x24, 0x3D, 0x20, 0x40, 0x22, 0x3C, 0x20, 0x3E, 0x20, 0x35, 0x1D, 0x31, 0x1B, 0x32, 0x1C, 0x37, 0x1E, 0x33, 0x1D, 0x35, 0x1F, 0x3E, 0x21, 0x39, 0x1F, 0x34, 0x1C, 0x2E, 0x19, 0x35, 0x1D, 0x3E, 0x22, 0x3D, 0x20, 0x39, 0x1E, 0x39, 0x1E, 0x39, 0x1F, 0x42, 0x21, 0x33, 0x1D, 0x40, 0x22, 0x33, 0x1C, 0x38, 0x1E, 0x31, 0x1B, 0x38, 0x1F, 0x32, 0x1C, 0x3C, 0x1F, 0x38, 0x1E, 0x3D, 0x21, 0x3C, 0x21, 0x3D, 0x20, 0x3C, 0x21, 0x3E, 0x21, 0x3D, 0x21, 0x3F, 0x22, 0x36, 0x1E, 0x3D, 0x21, 0x37, 0x1F
    },

    {
        0x69, 0x5B, 0x67, 0x5A, 0x67, 0x5C, 0x69, 0x5E, 0x6B, 0x5F, 0x6C, 0x5E, 0x6A, 0x5E, 0x6C, 0x5F, 0x6C, 0x61, 0x6C, 0x60, 0x6C, 0x5E, 0x6D, 0x5E, 0x6D, 0x5E, 0x69, 0x5D, 0x6C, 0x5F, 0x6C, 0x60, 0x6F, 0x60, 0x6E, 0x61, 0x6E, 0x61, 0x6F, 0x61, 0x70, 0x5F, 0x6C, 0x60, 0x71, 0x62, 0x71, 0x61, 0x72, 0x62, 0x73, 0x62, 0x74, 0x64, 0x75, 0x66, 0x73, 0x63, 0x70, 0x61, 0x70, 0x5F, 0x70, 0x60, 0x70, 0x5E, 0x70, 0x5F, 0x70, 0x61, 0x73, 0x63, 0x76, 0x65, 0x76, 0x66, 0x76, 0x67, 0x74, 0x64, 0x76, 0x66, 0x79, 0x67, 0x77, 0x69, 0x78, 0x64, 0x76, 0x66, 0x76, 0x67, 0x76, 0x66, 0x73, 0x63, 0x76, 0x65, 0x76, 0x67, 0x76, 0x68, 0x76, 0x66, 0x75, 0x67, 0x79, 0x6A, 0x79, 0x6B, 0x7C, 0x6C, 0x7C, 0x6B, 0x7C, 0x6B, 0x7C, 0x6C, 0x7C, 0x6B, 0x7D, 0x6F, 0x7E, 0x6D, 0x7E, 0x6D, 0x7A, 0x6D, 0x7D, 0x6F, 0x78, 0x6C, 0x74, 0x69, 0x5F, 0x50, 0x44, 0x3F, 0x52, 0x53, 0x68, 0x62, 0x6B, 0x64, 0x65, 0x5E, 0x4C, 0x43, 0x30, 0x2E, 0x24, 0x26, 0x20, 0x22, 0x1D, 0x20, 0x1C, 0x1F, 0x1B, 0x1E, 0x1A, 0x1E, 0x1B, 0x1E, 0x1C, 0x20, 0x1B, 0x1E, 0x1B, 0x1F, 0x1B, 0x20, 0x1C, 0x21, 0x20, 0x23, 0x37, 0x3C, 0x61, 0x60, 0x6C, 0x65, 0x66, 0x5D, 0x49, 0x40, 0x3E, 0x3F, 0x63, 0x61, 0x76, 0x69, 0x77, 0x6A, 0x7E, 0x71, 0x80, 0x74, 0x7D, 0x72, 0x80, 0x74, 0x7E, 0x72, 0x7B, 0x71, 0x7E, 0x75, 0x7E, 0x74, 0x7E, 0x71, 0x78, 0x6B, 0x7B, 0x6F, 0x7D, 0x71, 0x83, 0x76, 0x81, 0x75, 0x7C, 0x74, 0x7D, 0x73, 0x7E, 0x72, 0x7A, 0x6E, 0x7C, 0x6F, 0x83, 0x75, 0x84, 0x76, 0x7E, 0x71, 0x7F, 0x74, 0x81, 0x75, 0x7D, 0x70, 0x80, 0x73, 0x7C, 0x71, 0x81, 0x75, 0x81, 0x77, 0x81, 0x71, 0x7D, 0x6F, 0x7D, 0x71, 0x80, 0x77, 0x80, 0x73, 0x81, 0x77, 0x83, 0x78, 0x87, 0x7C, 0x82, 0x75, 0x87, 0x7D, 0x85, 0x7B, 0x8D, 0x83, 0x89, 0x7B, 0x8A, 0x83, 0x8D, 0x87, 0x90, 0x89, 0x8E, 0x85, 0x8F, 0x85, 0x85, 0x7B, 0x7D, 0x72, 0x89, 0x85, 0x85, 0x7B, 0x84, 0x7A, 0x81, 0x75, 0x88, 0x7F, 0x8F, 0x88, 0x8A, 0x83, 0x8A, 0x7D, 0x87, 0x7C, 0x83, 0x78, 0x85, 0x79, 0x7F, 0x70, 0x81, 0x72, 0x82, 0x71, 0x83, 0x78, 0x86, 0x7A, 0x81, 0x75, 0x87, 0x7F, 0x87, 0x7B, 0x8C, 0x7F, 0x87, 0x7A, 0x82, 0x72, 0x83, 0x78, 0x86, 0x7A, 0x80, 0x7A, 0x82, 0x78, 0x83, 0x78, 0x80, 0x73, 0x82, 0x74, 0x7E, 0x72, 0x7E, 0x70, 0x7A, 0x6F, 0x7E, 0x70, 0x7A, 0x6F, 0x7D, 0x71, 0x7A, 0x6B, 0x76, 0x6A, 0x7B, 0x6B, 0x78, 0x6B, 0x70, 0x65, 0x76, 0x68, 0x7A, 0x6D, 0x7E, 0x6F, 0x7C, 0x6F, 0x81, 0x76, 0x79, 0x6E, 0x81, 0x73, 0x7E, 0x72, 0x81, 0x78, 0x86, 0x7D, 0x83, 0x79, 0x7B, 0x71, 0x7D, 0x6F, 0x80, 0x71, 0x7A, 0x6C, 0x7E, 0x6F, 0x7F, 0x72, 0x7F, 0x71, 0x7A, 0x70, 0x77, 0x6B, 0x7A, 0x6D, 0x78, 0x69, 0x78, 0x6B, 0x7E, 0x6F, 0x7D, 0x6E, 0x79, 0x6C, 0x7A, 0x6B, 0x75, 0x6A, 0x76, 0x69, 0x78, 0x6B, 0x7A, 0x6B, 0x75, 0x68, 0x71, 0x63, 0x75, 0x68, 0x74, 0x68, 0x77, 0x6A, 0x76, 0x67, 0x76, 0x68, 0x73, 0x65, 0x71, 0x65, 0x71, 0x66, 0x70, 0x64, 0x72, 0x66, 0x70, 0x63, 0x71, 0x66, 0x73, 0x66, 0x71, 0x66, 0x77, 0x6B, 0x7A, 0x6B, 0x72, 0x64, 0x75, 0x67, 0x71, 0x62, 0x6B, 0x5F, 0x6D, 0x62, 0x70, 0x64, 0x73, 0x67, 0x76, 0x6B, 0x70, 0x60, 0x71, 0x65, 0x73, 0x66, 0x77, 0x68, 0x75, 0x69, 0x77, 0x6D, 0x7A, 0x70, 0x71, 0x67, 0x70, 0x64, 0x70, 0x66, 0x72, 0x66, 0x6D, 0x61, 0x70, 0x62, 0x6D, 0x61, 0x75, 0x6C, 0x6F, 0x63, 0x71, 0x65, 0x72, 0x65, 0x73, 0x65, 0x71, 0x64, 0x6F, 0x60, 0x6A, 0x5F, 0x68, 0x5D, 0x6A, 0x5F, 0x6D, 0x62, 0x6D, 0x60, 0x68, 0x5C, 0x67, 0x5B, 0x60, 0x54, 0x3E, 0x3A, 0x30, 0x35, 0x37, 0x3F, 0x37, 0x42, 0x44, 0x4E, 0x3D, 0x48, 0x41, 0x48, 0x3F, 0x45, 0x36, 0x3D, 0x36, 0x3D, 0x35, 0x3C, 0x35, 0x3A, 0x2E, 0x32, 0x2C, 0x32, 0x2C, 0x31, 0x34, 0x3B, 0x2E, 0x31, 0x31, 0x39, 0x36, 0x3C, 0x32, 0x39, 0x2F, 0x34, 0x2C, 0x31, 0x32, 0x38, 0x38, 0x41, 0x37, 0x3C, 0x34, 0x39, 0x36, 0x3D, 0x33, 0x3A, 0x39, 0x40, 0x2F, 0x35, 0x3A, 0x40, 0x2E, 0x33, 0x32, 0x38, 0x2D, 0x34, 0x34, 0x36, 0x2E, 0x35, 0x36, 0x3D, 0x36, 0x40, 0x37, 0x3E, 0x38, 0x42, 0x39, 0x3E, 0x38, 0x3E, 0x39, 0x41, 0x36, 0x3B, 0x3A, 0x42, 0x30, 0x34, 0x39, 0x41, 0x35, 0x3C
    },

    {
        0x5A, 0x20, 0x5A, 0x20, 0x5D, 0x21, 0x5E, 0x21, 0x5D, 0x22, 0x5E, 0x23, 0x5E, 0x21, 0x5C, 0x22, 0x5F, 0x23, 0x5E, 0x23, 0x62, 0x23, 0x61, 0x22, 0x5C, 0x21, 0x5E, 0x22, 0x60, 0x24, 0x60, 0x24, 0x63, 0x24, 0x62, 0x25, 0x64, 0x25, 0x62, 0x24, 0x61, 0x23, 0x5F, 0x22, 0x61, 0x24, 0x62, 0x23, 0x62, 0x23, 0x61, 0x23, 0x63, 0x23, 0x62, 0x23, 0x62, 0x24, 0x5D, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x5D, 0x21, 0x5E, 0x22, 0x60, 0x23, 0x62, 0x23, 0x62, 0x23, 0x65, 0x24, 0x64, 0x24, 0x63, 0x23, 0x65, 0x23, 0x63, 0x23, 0x63, 0x23, 0x62, 0x23, 0x63, 0x24, 0x65, 0x24, 0x64, 0x24, 0x63, 0x24, 0x64, 0x24, 0x67, 0x25, 0x67, 0x25, 0x67, 0x25, 0x68, 0x26, 0x66, 0x25, 0x68, 0x26, 0x68, 0x26, 0x68, 0x25, 0x65, 0x25, 0x68, 0x26, 0x67, 0x25, 0x69, 0x27, 0x6A, 0x27, 0x69, 0x26, 0x69, 0x2A, 0x74, 0x2D, 0x6C, 0x29, 0x6F, 0x2B, 0x67, 0x27, 0x50, 0x21, 0x3D, 0x20, 0x4C, 0x23, 0x5D, 0x26, 0x5F, 0x26, 0x5D, 0x24, 0x46, 0x1E, 0x2E, 0x18, 0x25, 0x16, 0x21, 0x15, 0x1F, 0x14, 0x1D, 0x13, 0x1D, 0x13, 0x1D, 0x13, 0x1E, 0x14, 0x1D, 0x14, 0x20, 0x16, 0x22, 0x17, 0x20, 0x16, 0x2E, 0x1B, 0x54, 0x23, 0x63, 0x27, 0x65, 0x27, 0x4C, 0x20, 0x36, 0x1E, 0x53, 0x24, 0x68, 0x28, 0x69, 0x28, 0x6B, 0x29, 0x6E, 0x2A, 0x72, 0x2C, 0x72, 0x2B, 0x6C, 0x2A, 0x70, 0x2E, 0x75, 0x2E, 0x75, 0x2F, 0x73, 0x2D, 0x6F, 0x2B, 0x6F, 0x2B, 0x6F, 0x2B, 0x6C, 0x29, 0x6E, 0x2A, 0x6C, 0x2B, 0x71, 0x2D, 0x6F, 0x2D, 0x6C, 0x2A, 0x6B, 0x2A, 0x71, 0x2C, 0x72, 0x2C, 0x71, 0x2B, 0x70, 0x2C, 0x6F, 0x2C, 0x71, 0x2B, 0x72, 0x2D, 0x71, 0x2C, 0x6F, 0x2B, 0x6C, 0x2A, 0x6D, 0x2A, 0x6E, 0x29, 0x6E, 0x2B, 0x76, 0x2F, 0x79, 0x30, 0x73, 0x2C, 0x78, 0x30, 0x71, 0x2B, 0x77, 0x32, 0x78, 0x2F, 0x74, 0x2D, 0x74, 0x2D, 0x71, 0x2D, 0x7C, 0x32, 0x81, 0x37, 0x80, 0x34, 0x88, 0x3C, 0x9B, 0x42, 0x81, 0x34, 0x73, 0x2D, 0x72, 0x2D, 0x77, 0x33, 0x90, 0x42, 0x87, 0x3C, 0x96, 0x42, 0x8E, 0x3C, 0x88, 0x3C, 0x8A, 0x3C, 0x77, 0x2E, 0x7D, 0x34, 0x7A, 0x31, 0x7B, 0x32, 0x74, 0x2D, 0x71, 0x2A, 0x74, 0x2E, 0x7F, 0x35, 0x7A, 0x31, 0x75, 0x2E, 0x76, 0x31, 0x7C, 0x31, 0x75, 0x2E, 0x71, 0x2D, 0x73, 0x2F, 0x73, 0x2E, 0x74, 0x2E, 0x74, 0x2F, 0x78, 0x31, 0x73, 0x2D, 0x72, 0x2A, 0x72, 0x2C, 0x70, 0x29, 0x6A, 0x28, 0x69, 0x29, 0x6B, 0x29, 0x6C, 0x29, 0x69, 0x28, 0x6B, 0x28, 0x68, 0x27, 0x67, 0x26, 0x68, 0x27, 0x62, 0x25, 0x67, 0x27, 0x6A, 0x27, 0x68, 0x26, 0x68, 0x27, 0x70, 0x2B, 0x7A, 0x34, 0x80, 0x32, 0x76, 0x31, 0x83, 0x37, 0x7D, 0x33, 0x76, 0x31, 0x78, 0x30, 0x71, 0x2B, 0x6A, 0x27, 0x69, 0x27, 0x67, 0x28, 0x6C, 0x2A, 0x6D, 0x2A, 0x6F, 0x2B, 0x70, 0x2A, 0x6C, 0x2A, 0x6D, 0x2A, 0x6F, 0x2B, 0x6D, 0x29, 0x6E, 0x29, 0x6B, 0x29, 0x68, 0x27, 0x67, 0x26, 0x65, 0x26, 0x65, 0x28, 0x68, 0x27, 0x66, 0x27, 0x63, 0x25, 0x65, 0x26, 0x68, 0x28, 0x66, 0x27, 0x62, 0x27, 0x66, 0x28, 0x66, 0x26, 0x65, 0x26, 0x64, 0x26, 0x62, 0x24, 0x60, 0x24, 0x5F, 0x24, 0x5F, 0x23, 0x62, 0x25, 0x60, 0x25, 0x64, 0x25, 0x60, 0x24, 0x63, 0x25, 0x61, 0x24, 0x62, 0x24, 0x61, 0x24, 0x63, 0x26, 0x66, 0x28, 0x6B, 0x29, 0x6B, 0x2A, 0x66, 0x28, 0x67, 0x27, 0x63, 0x26, 0x66, 0x27, 0x66, 0x27, 0x64, 0x27, 0x68, 0x29, 0x61, 0x26, 0x66, 0x28, 0x65, 0x28, 0x65, 0x26, 0x5F, 0x24, 0x5C, 0x22, 0x5E, 0x24, 0x62, 0x26, 0x60, 0x24, 0x61, 0x25, 0x5F, 0x24, 0x64, 0x27, 0x62, 0x25, 0x60, 0x24, 0x5C, 0x23, 0x5A, 0x22, 0x5C, 0x23, 0x5F, 0x23, 0x5E, 0x24, 0x5C, 0x23, 0x5D, 0x24, 0x5A, 0x24, 0x44, 0x21, 0x36, 0x1D, 0x48, 0x26, 0x42, 0x24, 0x40, 0x23, 0x3B, 0x20, 0x3B, 0x20, 0x39, 0x1F, 0x32, 0x1C, 0x34, 0x1D, 0x3A, 0x20, 0x35, 0x1C, 0x33, 0x1C, 0x3A, 0x20, 0x3B, 0x20, 0x3B, 0x1F, 0x3A, 0x21, 0x42, 0x23, 0x41, 0x22, 0x35, 0x1D, 0x3C, 0x1E, 0x33, 0x1B, 0x3D, 0x20, 0x3B, 0x20, 0x3B, 0x1F, 0x34, 0x1C, 0x37, 0x1E, 0x35, 0x1E, 0x3F, 0x20, 0x2F, 0x1C, 0x39, 0x1E, 0x35, 0x1D, 0x3F, 0x21, 0x37, 0x1E, 0x40, 0x22, 0x35, 0x1E, 0x44, 0x24, 0x3B, 0x21, 0x34, 0x1E, 0x3F, 0x23, 0x3C, 0x21, 0x39, 0x21, 0x42, 0x23, 0x3D, 0x21, 0x40, 0x22, 0x3A, 0x20, 0x4C, 0x2A, 0x4D, 0x2D
    },

    {
        0x68, 0x5B, 0x68, 0x5C, 0x6B, 0x5F, 0x6A, 0x5E, 0x6B, 0x60, 0x6E, 0x61, 0x6C, 0x5F, 0x6C, 0x5F, 0x6D, 0x61, 0x6E, 0x62, 0x72, 0x63, 0x6F, 0x61, 0x6D, 0x5E, 0x6C, 0x61, 0x6E, 0x61, 0x6F, 0x64, 0x73, 0x64, 0x71, 0x63, 0x71, 0x65, 0x71, 0x62, 0x70, 0x62, 0x6F, 0x60, 0x71, 0x61, 0x73, 0x63, 0x73, 0x64, 0x72, 0x63, 0x76, 0x64, 0x71, 0x62, 0x72, 0x62, 0x6D, 0x5F, 0x70, 0x61, 0x71, 0x60, 0x70, 0x5F, 0x6E, 0x5F, 0x72, 0x61, 0x74, 0x63, 0x75, 0x65, 0x79, 0x67, 0x77, 0x65, 0x75, 0x65, 0x77, 0x65, 0x75, 0x63, 0x74, 0x64, 0x75, 0x65, 0x76, 0x65, 0x75, 0x65, 0x75, 0x65, 0x73, 0x64, 0x74, 0x65, 0x76, 0x67, 0x79, 0x69, 0x78, 0x67, 0x7B, 0x69, 0x7A, 0x66, 0x79, 0x69, 0x7B, 0x69, 0x7D, 0x69, 0x76, 0x65, 0x78, 0x69, 0x78, 0x68, 0x7A, 0x6C, 0x7C, 0x6B, 0x7D, 0x6C, 0x7B, 0x71, 0x82, 0x76, 0x7B, 0x6E, 0x7D, 0x70, 0x74, 0x69, 0x62, 0x53, 0x45, 0x3F, 0x4B, 0x4D, 0x61, 0x5D, 0x66, 0x62, 0x67, 0x5F, 0x55, 0x4B, 0x33, 0x2F, 0x26, 0x27, 0x20, 0x22, 0x1E, 0x1F, 0x1B, 0x1E, 0x1A, 0x1D, 0x19, 0x1D, 0x1B, 0x1F, 0x1A, 0x1E, 0x1B, 0x20, 0x1E, 0x22, 0x1F, 0x23, 0x34, 0x39, 0x61, 0x5E, 0x6E, 0x66, 0x6A, 0x65, 0x4E, 0x41, 0x3E, 0x3C, 0x61, 0x5F, 0x76, 0x6B, 0x7A, 0x6D, 0x7D, 0x70, 0x7D, 0x71, 0x82, 0x76, 0x81, 0x72, 0x7A, 0x6C, 0x7E, 0x74, 0x83, 0x79, 0x82, 0x77, 0x81, 0x74, 0x7E, 0x71, 0x80, 0x72, 0x7E, 0x71, 0x7C, 0x6D, 0x7C, 0x6D, 0x7B, 0x6F, 0x7C, 0x71, 0x7C, 0x72, 0x7A, 0x6D, 0x79, 0x6D, 0x7F, 0x73, 0x81, 0x72, 0x81, 0x72, 0x7F, 0x73, 0x7E, 0x71, 0x7E, 0x70, 0x81, 0x73, 0x7D, 0x73, 0x7D, 0x72, 0x79, 0x6D, 0x7C, 0x6F, 0x7D, 0x6E, 0x7D, 0x70, 0x83, 0x78, 0x82, 0x77, 0x83, 0x76, 0x85, 0x77, 0x7F, 0x72, 0x86, 0x7D, 0x84, 0x79, 0x84, 0x77, 0x84, 0x74, 0x80, 0x72, 0x87, 0x7E, 0x8D, 0x84, 0x89, 0x7B, 0x93, 0x91, 0xA0, 0x96, 0x89, 0x7D, 0x80, 0x73, 0x84, 0x78, 0x85, 0x74, 0x92, 0x92, 0x91, 0x8B, 0x9A, 0x99, 0x92, 0x8B, 0x92, 0x8E, 0x93, 0x8B, 0x85, 0x77, 0x8B, 0x83, 0x86, 0x7A, 0x86, 0x7F, 0x85, 0x77, 0x83, 0x72, 0x85, 0x79, 0x8A, 0x81, 0x85, 0x79, 0x86, 0x77, 0x83, 0x76, 0x82, 0x77, 0x83, 0x77, 0x7F, 0x74, 0x81, 0x79, 0x82, 0x75, 0x83, 0x77, 0x83, 0x76, 0x87, 0x7B, 0x83, 0x76, 0x80, 0x72, 0x81, 0x76, 0x81, 0x74, 0x7B, 0x6F, 0x74, 0x6A, 0x76, 0x6B, 0x77, 0x6C, 0x7A, 0x6D, 0x7C, 0x6E, 0x79, 0x6B, 0x74, 0x68, 0x78, 0x6A, 0x72, 0x67, 0x76, 0x68, 0x79, 0x6B, 0x7D, 0x6C, 0x7A, 0x6D, 0x7F, 0x75, 0x8D, 0x88, 0x8C, 0x80, 0x82, 0x79, 0x8C, 0x89, 0x86, 0x7B, 0x7F, 0x79, 0x81, 0x78, 0x82, 0x74, 0x7E, 0x6D, 0x79, 0x6D, 0x79, 0x6E, 0x7B, 0x6F, 0x7C, 0x6F, 0x7E, 0x74, 0x7F, 0x73, 0x7C, 0x6F, 0x7C, 0x6F, 0x7D, 0x70, 0x7B, 0x6E, 0x7F, 0x71, 0x79, 0x6C, 0x75, 0x68, 0x77, 0x68, 0x73, 0x68, 0x76, 0x6A, 0x77, 0x6A, 0x70, 0x66, 0x72, 0x64, 0x74, 0x69, 0x78, 0x6D, 0x76, 0x68, 0x71, 0x66, 0x74, 0x69, 0x74, 0x68, 0x72, 0x67, 0x73, 0x66, 0x71, 0x64, 0x6D, 0x62, 0x6F, 0x62, 0x6E, 0x62, 0x70, 0x65, 0x70, 0x62, 0x71, 0x65, 0x71, 0x65, 0x74, 0x65, 0x71, 0x62, 0x70, 0x61, 0x73, 0x68, 0x73, 0x65, 0x76, 0x6D, 0x78, 0x6B, 0x75, 0x6B, 0x76, 0x6A, 0x75, 0x68, 0x71, 0x62, 0x73, 0x67, 0x77, 0x69, 0x72, 0x68, 0x74, 0x69, 0x6F, 0x64, 0x73, 0x68, 0x73, 0x69, 0x71, 0x66, 0x6D, 0x61, 0x6C, 0x5F, 0x6E, 0x62, 0x71, 0x64, 0x70, 0x62, 0x71, 0x63, 0x6D, 0x62, 0x71, 0x65, 0x6F, 0x64, 0x6E, 0x63, 0x69, 0x5D, 0x67, 0x5C, 0x6C, 0x62, 0x6E, 0x63, 0x6E, 0x62, 0x69, 0x5F, 0x6B, 0x5F, 0x66, 0x5C, 0x45, 0x45, 0x31, 0x36, 0x40, 0x4C, 0x3A, 0x40, 0x34, 0x3C, 0x32, 0x39, 0x34, 0x3B, 0x31, 0x34, 0x30, 0x35, 0x31, 0x35, 0x35, 0x3D, 0x32, 0x36, 0x32, 0x37, 0x36, 0x40, 0x38, 0x40, 0x35, 0x3A, 0x39, 0x44, 0x3A, 0x43, 0x3A, 0x40, 0x30, 0x39, 0x37, 0x3D, 0x2F, 0x34, 0x39, 0x41, 0x37, 0x3F, 0x35, 0x38, 0x2D, 0x33, 0x2F, 0x34, 0x33, 0x3B, 0x38, 0x3A, 0x2E, 0x34, 0x34, 0x37, 0x31, 0x38, 0x3B, 0x41, 0x32, 0x3A, 0x3A, 0x42, 0x30, 0x37, 0x3C, 0x43, 0x35, 0x3A, 0x30, 0x36, 0x39, 0x40, 0x37, 0x3C, 0x37, 0x40, 0x40, 0x45, 0x3A, 0x41, 0x39, 0x40, 0x35, 0x3D, 0x45, 0x53, 0x4B, 0x5A
    },

    {
        0x5C, 0x21, 0x5D, 0x20, 0x5C, 0x21, 0x5E, 0x23, 0x60, 0x23, 0x61, 0x23, 0x61, 0x23, 0x5F, 0x23, 0x60, 0x23, 0x61, 0x23, 0x62, 0x23, 0x5F, 0x22, 0x5E, 0x23, 0x61, 0x24, 0x62, 0x26, 0x67, 0x26, 0x63, 0x24, 0x60, 0x23, 0x5F, 0x23, 0x61, 0x23, 0x60, 0x24, 0x62, 0x24, 0x61, 0x23, 0x61, 0x24, 0x63, 0x24, 0x61, 0x24, 0x63, 0x23, 0x60, 0x23, 0x62, 0x23, 0x63, 0x23, 0x60, 0x22, 0x5E, 0x21, 0x5E, 0x21, 0x5D, 0x22, 0x5D, 0x21, 0x60, 0x23, 0x63, 0x24, 0x65, 0x24, 0x65, 0x24, 0x63, 0x24, 0x62, 0x23, 0x5F, 0x22, 0x62, 0x24, 0x64, 0x25, 0x63, 0x24, 0x64, 0x24, 0x64, 0x24, 0x64, 0x24, 0x62, 0x23, 0x64, 0x24, 0x64, 0x24, 0x66, 0x25, 0x67, 0x25, 0x66, 0x25, 0x67, 0x25, 0x69, 0x26, 0x66, 0x25, 0x66, 0x25, 0x66, 0x26, 0x69, 0x26, 0x68, 0x26, 0x66, 0x27, 0x68, 0x26, 0x6E, 0x30, 0x7A, 0x32, 0x6A, 0x28, 0x6D, 0x2B, 0x6B, 0x29, 0x64, 0x27, 0x55, 0x23, 0x3E, 0x1E, 0x45, 0x21, 0x5D, 0x26, 0x62, 0x26, 0x62, 0x28, 0x4C, 0x20, 0x2F, 0x19, 0x28, 0x18, 0x23, 0x15, 0x20, 0x15, 0x1E, 0x14, 0x1D, 0x14, 0x20, 0x16, 0x20, 0x15, 0x21, 0x16, 0x20, 0x15, 0x2A, 0x19, 0x50, 0x23, 0x65, 0x26, 0x65, 0x27, 0x51, 0x23, 0x37, 0x1E, 0x54, 0x26, 0x68, 0x29, 0x6A, 0x28, 0x6E, 0x2A, 0x75, 0x2C, 0x73, 0x2D, 0x73, 0x2C, 0x72, 0x2B, 0x71, 0x2C, 0x71, 0x2D, 0x74, 0x2F, 0x72, 0x2E, 0x75, 0x2E, 0x73, 0x2D, 0x75, 0x2F, 0x70, 0x2C, 0x71, 0x2C, 0x71, 0x2B, 0x70, 0x2B, 0x6F, 0x2D, 0x75, 0x2F, 0x6E, 0x2B, 0x6D, 0x2B, 0x6D, 0x2B, 0x70, 0x2B, 0x72, 0x2C, 0x70, 0x2B, 0x74, 0x2F, 0x74, 0x2C, 0x71, 0x2C, 0x75, 0x2F, 0x6F, 0x2B, 0x75, 0x2E, 0x72, 0x2C, 0x72, 0x2D, 0x76, 0x2F, 0x75, 0x2E, 0x7B, 0x31, 0x73, 0x2D, 0x6F, 0x2A, 0x75, 0x2E, 0x75, 0x2E, 0x74, 0x2E, 0x75, 0x2E, 0x78, 0x2E, 0x7B, 0x32, 0x78, 0x31, 0x7D, 0x34, 0x86, 0x37, 0x80, 0x33, 0x79, 0x2F, 0x7A, 0x31, 0x7D, 0x34, 0x7F, 0x35, 0x78, 0x30, 0x7B, 0x32, 0x7F, 0x33, 0x7B, 0x35, 0x83, 0x38, 0x85, 0x38, 0x7C, 0x32, 0x82, 0x38, 0x83, 0x39, 0x95, 0x40, 0x83, 0x36, 0x79, 0x30, 0x71, 0x2B, 0x6E, 0x2B, 0x74, 0x2F, 0x77, 0x31, 0x7C, 0x32, 0x76, 0x31, 0x78, 0x30, 0x78, 0x2F, 0x76, 0x2E, 0x75, 0x31, 0x7E, 0x31, 0x77, 0x2E, 0x7A, 0x30, 0x72, 0x2C, 0x73, 0x2D, 0x74, 0x2D, 0x79, 0x30, 0x71, 0x2C, 0x70, 0x2B, 0x6D, 0x29, 0x6B, 0x29, 0x6B, 0x29, 0x6E, 0x2A, 0x69, 0x28, 0x6D, 0x29, 0x69, 0x27, 0x65, 0x24, 0x65, 0x25, 0x68, 0x27, 0x6A, 0x28, 0x76, 0x31, 0x7B, 0x30, 0x7F, 0x36, 0x86, 0x3B, 0x87, 0x38, 0x83, 0x37, 0x89, 0x3B, 0x81, 0x36, 0x7A, 0x36, 0x73, 0x2F, 0x77, 0x2E, 0x6E, 0x2A, 0x73, 0x2D, 0x6F, 0x29, 0x6C, 0x2A, 0x6C, 0x29, 0x6D, 0x29, 0x6C, 0x28, 0x68, 0x27, 0x68, 0x28, 0x68, 0x28, 0x6B, 0x29, 0x6D, 0x2B, 0x66, 0x27, 0x66, 0x26, 0x68, 0x26, 0x64, 0x26, 0x6B, 0x29, 0x6C, 0x28, 0x68, 0x27, 0x67, 0x28, 0x69, 0x27, 0x6C, 0x29, 0x66, 0x26, 0x68, 0x28, 0x63, 0x26, 0x65, 0x27, 0x66, 0x27, 0x66, 0x27, 0x63, 0x24, 0x5F, 0x24, 0x62, 0x25, 0x63, 0x25, 0x61, 0x25, 0x64, 0x27, 0x64, 0x26, 0x66, 0x26, 0x5F, 0x24, 0x62, 0x24, 0x5E, 0x23, 0x64, 0x27, 0x64, 0x27, 0x65, 0x25, 0x65, 0x26, 0x68, 0x28, 0x6B, 0x29, 0x64, 0x26, 0x60, 0x25, 0x63, 0x26, 0x68, 0x28, 0x63, 0x26, 0x5D, 0x24, 0x61, 0x26, 0x62, 0x26, 0x62, 0x25, 0x69, 0x29, 0x65, 0x25, 0x60, 0x24, 0x5E, 0x23, 0x60, 0x24, 0x62, 0x25, 0x60, 0x23, 0x61, 0x25, 0x62, 0x26, 0x5F, 0x24, 0x62, 0x26, 0x62, 0x26, 0x5E, 0x23, 0x5F, 0x25, 0x61, 0x25, 0x62, 0x26, 0x5F, 0x24, 0x60, 0x26, 0x5D, 0x25, 0x41, 0x21, 0x33, 0x1D, 0x45, 0x24, 0x3A, 0x20, 0x35, 0x1F, 0x38, 0x1F, 0x3A, 0x1F, 0x3A, 0x1F, 0x38, 0x1F, 0x44, 0x25, 0x3E, 0x21, 0x41, 0x24, 0x3F, 0x21, 0x3E, 0x22, 0x42, 0x23, 0x3B, 0x21, 0x46, 0x25, 0x3B, 0x21, 0x3D, 0x21, 0x39, 0x1F, 0x37, 0x1E, 0x31, 0x1B, 0x38, 0x1E, 0x35, 0x1D, 0x34, 0x1C, 0x32, 0x1C, 0x3B, 0x20, 0x3B, 0x21, 0x42, 0x22, 0x3C, 0x21, 0x40, 0x22, 0x39, 0x20, 0x42, 0x22, 0x32, 0x1C, 0x39, 0x1F, 0x34, 0x1E, 0x41, 0x26, 0x43, 0x2C, 0x4B, 0x32, 0x59, 0x3B, 0x68, 0x44, 0x6D, 0x48, 0x70, 0x49, 0x3F, 0x23, 0x3A, 0x20, 0x3C, 0x21, 0x4C, 0x35, 0x94, 0x68
    },

    {
        0x6A, 0x5C, 0x6A, 0x5E, 0x6A, 0x5E, 0x6B, 0x60, 0x6C, 0x62, 0x6E, 0x63, 0x6F, 0x61, 0x6D, 0x62, 0x6E, 0x62, 0x6F, 0x62, 0x70, 0x62, 0x6E, 0x5F, 0x6C, 0x60, 0x6F, 0x62, 0x70, 0x64, 0x75, 0x67, 0x71, 0x63, 0x70, 0x61, 0x6F, 0x61, 0x71, 0x62, 0x71, 0x62, 0x73, 0x64, 0x73, 0x63, 0x72, 0x63, 0x74, 0x64, 0x72, 0x62, 0x75, 0x64, 0x72, 0x64, 0x72, 0x63, 0x74, 0x64, 0x72, 0x61, 0x70, 0x60, 0x71, 0x60, 0x70, 0x60, 0x6E, 0x5F, 0x72, 0x63, 0x74, 0x64, 0x75, 0x66, 0x76, 0x66, 0x75, 0x65, 0x74, 0x62, 0x71, 0x62, 0x71, 0x63, 0x77, 0x66, 0x74, 0x64, 0x74, 0x66, 0x74, 0x67, 0x74, 0x65, 0x74, 0x64, 0x75, 0x65, 0x74, 0x66, 0x78, 0x67, 0x78, 0x67, 0x79, 0x67, 0x78, 0x69, 0x7B, 0x6A, 0x7B, 0x69, 0x78, 0x68, 0x79, 0x6A, 0x7B, 0x6A, 0x79, 0x68, 0x7A, 0x68, 0x7B, 0x6A, 0x7A, 0x70, 0x7D, 0x75, 0x7B, 0x6C, 0x7D, 0x6F, 0x7D, 0x6F, 0x75, 0x69, 0x68, 0x5B, 0x4C, 0x42, 0x43, 0x45, 0x5C, 0x5B, 0x6B, 0x63, 0x6D, 0x66, 0x5A, 0x51, 0x37, 0x31, 0x29, 0x2B, 0x22, 0x23, 0x1E, 0x20, 0x1C, 0x1F, 0x1A, 0x1F, 0x1C, 0x22, 0x1B, 0x21, 0x1D, 0x21, 0x20, 0x22, 0x31, 0x36, 0x5C, 0x5C, 0x6E, 0x66, 0x6A, 0x62, 0x51, 0x45, 0x3D, 0x3E, 0x63, 0x63, 0x74, 0x6D, 0x78, 0x6C, 0x7D, 0x71, 0x83, 0x76, 0x82, 0x78, 0x82, 0x76, 0x80, 0x72, 0x7E, 0x74, 0x7E, 0x72, 0x7E, 0x75, 0x80, 0x75, 0x83, 0x77, 0x82, 0x75, 0x81, 0x77, 0x81, 0x73, 0x81, 0x76, 0x82, 0x74, 0x7C, 0x6F, 0x80, 0x79, 0x81, 0x75, 0x7D, 0x71, 0x7C, 0x72, 0x78, 0x6F, 0x7D, 0x72, 0x80, 0x73, 0x82, 0x73, 0x84, 0x7B, 0x82, 0x74, 0x7F, 0x72, 0x81, 0x75, 0x7D, 0x71, 0x84, 0x7B, 0x80, 0x76, 0x80, 0x76, 0x84, 0x79, 0x85, 0x77, 0x8A, 0x82, 0x81, 0x73, 0x7E, 0x70, 0x83, 0x77, 0x84, 0x75, 0x84, 0x77, 0x81, 0x78, 0x83, 0x78, 0x88, 0x82, 0x88, 0x7B, 0x8A, 0x81, 0x90, 0x87, 0x88, 0x79, 0x85, 0x74, 0x83, 0x79, 0x8B, 0x83, 0x88, 0x81, 0x86, 0x7A, 0x89, 0x7D, 0x8A, 0x7D, 0x85, 0x7A, 0x8A, 0x81, 0x8B, 0x81, 0x88, 0x7D, 0x90, 0x89, 0x8C, 0x87, 0x98, 0x97, 0x90, 0x83, 0x87, 0x79, 0x82, 0x75, 0x80, 0x72, 0x83, 0x77, 0x84, 0x79, 0x87, 0x7D, 0x88, 0x7D, 0x88, 0x7F, 0x84, 0x7A, 0x84, 0x79, 0x81, 0x78, 0x8A, 0x7F, 0x87, 0x7A, 0x8C, 0x7E, 0x85, 0x74, 0x80, 0x74, 0x7F, 0x76, 0x84, 0x79, 0x7E, 0x72, 0x7E, 0x73, 0x7C, 0x70, 0x7A, 0x6D, 0x78, 0x6E, 0x7F, 0x71, 0x7C, 0x6E, 0x7D, 0x70, 0x79, 0x6A, 0x79, 0x69, 0x79, 0x69, 0x78, 0x69, 0x79, 0x6B, 0x82, 0x7B, 0x86, 0x7A, 0x8B, 0x84, 0x8F, 0x8A, 0x8E, 0x88, 0x8D, 0x8C, 0x96, 0x93, 0x90, 0x86, 0x85, 0x7D, 0x81, 0x76, 0x81, 0x76, 0x7C, 0x72, 0x81, 0x76, 0x7E, 0x70, 0x7C, 0x6E, 0x79, 0x6D, 0x7B, 0x6C, 0x7B, 0x6E, 0x79, 0x6A, 0x76, 0x6A, 0x78, 0x6B, 0x79, 0x6E, 0x7A, 0x6D, 0x77, 0x69, 0x78, 0x6B, 0x78, 0x6A, 0x74, 0x65, 0x7B, 0x6F, 0x7C, 0x6E, 0x76, 0x6A, 0x75, 0x6A, 0x77, 0x6B, 0x7A, 0x6E, 0x76, 0x6A, 0x75, 0x69, 0x71, 0x66, 0x73, 0x69, 0x73, 0x68, 0x74, 0x69, 0x72, 0x64, 0x6E, 0x5F, 0x70, 0x66, 0x70, 0x65, 0x6D, 0x62, 0x73, 0x69, 0x75, 0x68, 0x75, 0x68, 0x6F, 0x62, 0x70, 0x63, 0x6F, 0x60, 0x71, 0x66, 0x70, 0x65, 0x70, 0x64, 0x73, 0x68, 0x77, 0x6C, 0x79, 0x6D, 0x74, 0x68, 0x71, 0x63, 0x72, 0x65, 0x75, 0x6A, 0x71, 0x64, 0x69, 0x5E, 0x6E, 0x64, 0x72, 0x67, 0x72, 0x66, 0x79, 0x6F, 0x74, 0x66, 0x70, 0x63, 0x6D, 0x60, 0x71, 0x62, 0x71, 0x65, 0x70, 0x62, 0x70, 0x63, 0x72, 0x64, 0x6E, 0x62, 0x70, 0x66, 0x6F, 0x65, 0x6D, 0x62, 0x6E, 0x63, 0x6D, 0x61, 0x6E, 0x64, 0x6D, 0x61, 0x6E, 0x63, 0x68, 0x5D, 0x3E, 0x3C, 0x30, 0x36, 0x3B, 0x43, 0x34, 0x38, 0x31, 0x39, 0x35, 0x3C, 0x34, 0x3C, 0x39, 0x40, 0x33, 0x3B, 0x3F, 0x47, 0x37, 0x3F, 0x3B, 0x47, 0x35, 0x39, 0x37, 0x44, 0x37, 0x3C, 0x33, 0x3E, 0x3B, 0x43, 0x33, 0x3B, 0x34, 0x38, 0x33, 0x3A, 0x30, 0x35, 0x2E, 0x34, 0x32, 0x37, 0x31, 0x38, 0x32, 0x36, 0x2F, 0x37, 0x37, 0x3F, 0x37, 0x40, 0x3E, 0x43, 0x38, 0x40, 0x3A, 0x3F, 0x35, 0x3D, 0x3B, 0x40, 0x2E, 0x34, 0x31, 0x36, 0x30, 0x38, 0x3E, 0x47, 0x45, 0x52, 0x4D, 0x59, 0x56, 0x67, 0x62, 0x76, 0x65, 0x7C, 0x64, 0x74, 0x36, 0x39, 0x36, 0x3D, 0x38, 0x3F, 0x41, 0x58, 0x76, 0x9C
    },

    {
        0x5D, 0x21, 0x5C, 0x20, 0x5E, 0x22, 0x61, 0x24, 0x61, 0x24, 0x61, 0x22, 0x5F, 0x22, 0x60, 0x22, 0x60, 0x22, 0x61, 0x22, 0x62, 0x23, 0x60, 0x23, 0x5F, 0x22, 0x61, 0x24, 0x63, 0x24, 0x62, 0x24, 0x60, 0x23, 0x63, 0x24, 0x62, 0x24, 0x63, 0x24, 0x62, 0x23, 0x62, 0x25, 0x62, 0x25, 0x63, 0x24, 0x62, 0x24, 0x62, 0x23, 0x60, 0x23, 0x60, 0x23, 0x60, 0x22, 0x61, 0x23, 0x62, 0x22, 0x61, 0x22, 0x61, 0x22, 0x60, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x62, 0x23, 0x62, 0x23, 0x61, 0x23, 0x61, 0x23, 0x63, 0x23, 0x66, 0x24, 0x64, 0x24, 0x63, 0x23, 0x63, 0x23, 0x63, 0x23, 0x63, 0x24, 0x64, 0x24, 0x63, 0x23, 0x63, 0x24, 0x60, 0x23, 0x65, 0x25, 0x69, 0x26, 0x67, 0x25, 0x67, 0x25, 0x67, 0x25, 0x68, 0x25, 0x68, 0x26, 0x66, 0x25, 0x68, 0x26, 0x67, 0x25, 0x67, 0x26, 0x69, 0x27, 0x69, 0x27, 0x69, 0x27, 0x6E, 0x29, 0x6E, 0x29, 0x6B, 0x28, 0x68, 0x27, 0x5E, 0x24, 0x41, 0x1F, 0x40, 0x21, 0x5A, 0x26, 0x67, 0x28, 0x61, 0x25, 0x51, 0x21, 0x36, 0x1B, 0x28, 0x17, 0x23, 0x16, 0x21, 0x15, 0x20, 0x15, 0x22, 0x16, 0x1F, 0x15, 0x20, 0x15, 0x2A, 0x19, 0x50, 0x23, 0x60, 0x27, 0x65, 0x26, 0x4F, 0x22, 0x36, 0x1E, 0x54, 0x25, 0x66, 0x28, 0x6C, 0x29, 0x6E, 0x29, 0x71, 0x2B, 0x72, 0x2B, 0x70, 0x2A, 0x75, 0x2E, 0x73, 0x2C, 0x6D, 0x2A, 0x71, 0x2C, 0x70, 0x2B, 0x6E, 0x2B, 0x74, 0x2C, 0x71, 0x2B, 0x73, 0x2D, 0x74, 0x2E, 0x78, 0x31, 0x78, 0x2F, 0x70, 0x2C, 0x77, 0x30, 0x74, 0x2C, 0x73, 0x2E, 0x78, 0x31, 0x71, 0x2E, 0x76, 0x2F, 0x72, 0x2E, 0x7C, 0x32, 0x7B, 0x31, 0x73, 0x2C, 0x6F, 0x2C, 0x6F, 0x2D, 0x73, 0x2D, 0x76, 0x2F, 0x74, 0x2D, 0x75, 0x2E, 0x7B, 0x30, 0x77, 0x30, 0x7A, 0x30, 0x75, 0x2D, 0x76, 0x2E, 0x7A, 0x31, 0x7E, 0x32, 0x7E, 0x34, 0x74, 0x2F, 0x7E, 0x35, 0x7E, 0x35, 0x87, 0x38, 0x81, 0x35, 0x81, 0x37, 0x72, 0x2A, 0x67, 0x2A, 0x7C, 0x34, 0x8E, 0x3F, 0x95, 0x40, 0x83, 0x37, 0x7B, 0x31, 0x7C, 0x32, 0x72, 0x2D, 0x72, 0x2C, 0x75, 0x30, 0x7F, 0x33, 0x7D, 0x33, 0x79, 0x33, 0x80, 0x38, 0x80, 0x35, 0x7A, 0x31, 0x7B, 0x33, 0x87, 0x36, 0x82, 0x37, 0x86, 0x38, 0x7A, 0x30, 0x7A, 0x34, 0x84, 0x37, 0x7C, 0x32, 0x81, 0x35, 0x76, 0x2E, 0x78, 0x30, 0x78, 0x2F, 0x76, 0x2F, 0x73, 0x2C, 0x6D, 0x2A, 0x71, 0x2A, 0x6A, 0x29, 0x6E, 0x2A, 0x71, 0x2E, 0x6D, 0x2A, 0x72, 0x2C, 0x6B, 0x29, 0x6B, 0x29, 0x6C, 0x27, 0x69, 0x29, 0x6C, 0x27, 0x6B, 0x26, 0x68, 0x26, 0x62, 0x25, 0x69, 0x26, 0x6E, 0x2A, 0x70, 0x2C, 0x90, 0x45, 0x96, 0x3E, 0x8D, 0x42, 0xA3, 0x48, 0x94, 0x46, 0x99, 0x46, 0x90, 0x41, 0x7F, 0x32, 0x79, 0x2E, 0x74, 0x2E, 0x77, 0x2D, 0x6B, 0x29, 0x6B, 0x28, 0x6B, 0x29, 0x6A, 0x27, 0x6A, 0x27, 0x67, 0x27, 0x6B, 0x28, 0x6B, 0x27, 0x6F, 0x2B, 0x6B, 0x29, 0x6A, 0x29, 0x68, 0x26, 0x68, 0x28, 0x6C, 0x29, 0x68, 0x28, 0x69, 0x27, 0x66, 0x26, 0x68, 0x27, 0x67, 0x26, 0x64, 0x26, 0x64, 0x26, 0x64, 0x25, 0x63, 0x26, 0x62, 0x25, 0x62, 0x24, 0x5F, 0x25, 0x61, 0x24, 0x61, 0x24, 0x61, 0x25, 0x5F, 0x23, 0x62, 0x26, 0x68, 0x29, 0x6A, 0x29, 0x64, 0x25, 0x64, 0x25, 0x63, 0x24, 0x64, 0x25, 0x63, 0x25, 0x5D, 0x24, 0x5E, 0x24, 0x64, 0x27, 0x6B, 0x2A, 0x66, 0x27, 0x66, 0x29, 0x68, 0x27, 0x6B, 0x2A, 0x6B, 0x2A, 0x64, 0x26, 0x62, 0x26, 0x62, 0x27, 0x6A, 0x2A, 0x67, 0x27, 0x6B, 0x2A, 0x64, 0x27, 0x5F, 0x25, 0x5E, 0x23, 0x5B, 0x23, 0x5E, 0x25, 0x5F, 0x23, 0x5E, 0x23, 0x5F, 0x24, 0x64, 0x27, 0x63, 0x26, 0x63, 0x27, 0x61, 0x25, 0x5F, 0x24, 0x5A, 0x23, 0x5C, 0x23, 0x59, 0x22, 0x5E, 0x24, 0x5B, 0x23, 0x41, 0x20, 0x3C, 0x21, 0x3F, 0x21, 0x41, 0x22, 0x39, 0x20, 0x46, 0x24, 0x40, 0x23, 0x41, 0x22, 0x36, 0x1F, 0x40, 0x22, 0x3E, 0x22, 0x3C, 0x21, 0x34, 0x1E, 0x3C, 0x21, 0x36, 0x1E, 0x38, 0x20, 0x40, 0x21, 0x36, 0x1F, 0x3B, 0x20, 0x3B, 0x21, 0x46, 0x24, 0x37, 0x1F, 0x42, 0x22, 0x38, 0x1F, 0x41, 0x22, 0x31, 0x1D, 0x40, 0x26, 0x44, 0x2D, 0x4B, 0x31, 0x43, 0x31, 0x4E, 0x38, 0x4A, 0x38, 0x4F, 0x38, 0x38, 0x20, 0x41, 0x24, 0x40, 0x23, 0x5B, 0x42, 0x76, 0x5C, 0x7C, 0x5E, 0x83, 0x63, 0x88, 0x66, 0x89, 0x64, 0x7E, 0x59, 0x38, 0x23, 0x3F, 0x23, 0x41, 0x23, 0x4C, 0x36, 0x88, 0x60
    },

    {
        0x69, 0x5E, 0x69, 0x5E, 0x6B, 0x60, 0x6D, 0x62, 0x6E, 0x63, 0x6F, 0x62, 0x6E, 0x60, 0x6F, 0x61, 0x6E, 0x61, 0x70, 0x62, 0x70, 0x62, 0x6F, 0x60, 0x6D, 0x5F, 0x70, 0x62, 0x71, 0x63, 0x71, 0x63, 0x70, 0x63, 0x71, 0x64, 0x73, 0x65, 0x75, 0x64, 0x73, 0x64, 0x72, 0x66, 0x72, 0x64, 0x73, 0x64, 0x71, 0x64, 0x71, 0x63, 0x71, 0x61, 0x70, 0x61, 0x71, 0x61, 0x72, 0x62, 0x73, 0x63, 0x70, 0x61, 0x71, 0x62, 0x72, 0x62, 0x72, 0x62, 0x70, 0x60, 0x72, 0x61, 0x74, 0x64, 0x73, 0x63, 0x73, 0x62, 0x73, 0x62, 0x76, 0x66, 0x77, 0x66, 0x74, 0x66, 0x76, 0x64, 0x73, 0x65, 0x75, 0x65, 0x73, 0x65, 0x77, 0x66, 0x75, 0x66, 0x75, 0x64, 0x73, 0x63, 0x78, 0x68, 0x7B, 0x6B, 0x79, 0x67, 0x7A, 0x68, 0x79, 0x68, 0x7A, 0x6A, 0x7A, 0x6B, 0x79, 0x69, 0x7C, 0x6B, 0x7C, 0x6A, 0x7A, 0x69, 0x7B, 0x69, 0x7A, 0x6A, 0x7B, 0x6B, 0x7F, 0x70, 0x7E, 0x6F, 0x7D, 0x6F, 0x78, 0x6D, 0x6F, 0x61, 0x51, 0x45, 0x43, 0x43, 0x5A, 0x5D, 0x6E, 0x66, 0x6C, 0x63, 0x62, 0x57, 0x43, 0x3A, 0x2B, 0x2A, 0x23, 0x25, 0x1F, 0x21, 0x1D, 0x21, 0x1E, 0x22, 0x1C, 0x20, 0x20, 0x22, 0x32, 0x38, 0x5E, 0x5D, 0x6D, 0x66, 0x6E, 0x66, 0x4E, 0x44, 0x3E, 0x3D, 0x65, 0x61, 0x72, 0x69, 0x79, 0x6D, 0x7D, 0x72, 0x80, 0x74, 0x81, 0x73, 0x80, 0x72, 0x82, 0x77, 0x82, 0x73, 0x7C, 0x6F, 0x80, 0x73, 0x7E, 0x72, 0x81, 0x73, 0x83, 0x75, 0x7F, 0x72, 0x81, 0x76, 0x84, 0x79, 0x84, 0x7C, 0x86, 0x77, 0x80, 0x74, 0x82, 0x74, 0x82, 0x72, 0x81, 0x78, 0x86, 0x7B, 0x81, 0x77, 0x84, 0x77, 0x83, 0x77, 0x8C, 0x83, 0x88, 0x7B, 0x84, 0x79, 0x81, 0x76, 0x7C, 0x73, 0x83, 0x78, 0x81, 0x77, 0x81, 0x76, 0x81, 0x78, 0x88, 0x80, 0x87, 0x7D, 0x82, 0x77, 0x83, 0x77, 0x84, 0x7A, 0x86, 0x7A, 0x88, 0x7F, 0x88, 0x7F, 0x82, 0x7A, 0x88, 0x84, 0x89, 0x7F, 0x8D, 0x84, 0x8A, 0x80, 0x8D, 0x8A, 0x80, 0x6E, 0x77, 0x6F, 0x88, 0x81, 0x93, 0x90, 0x98, 0x92, 0x8E, 0x84, 0x89, 0x7C, 0x88, 0x7D, 0x84, 0x78, 0x84, 0x74, 0x84, 0x78, 0x89, 0x7F, 0x87, 0x7C, 0x88, 0x7E, 0x89, 0x7E, 0x88, 0x82, 0x8C, 0x81, 0x89, 0x81, 0x92, 0x8B, 0x8B, 0x84, 0x91, 0x8C, 0x8A, 0x7C, 0x85, 0x7C, 0x8A, 0x7F, 0x86, 0x7E, 0x8B, 0x83, 0x87, 0x78, 0x87, 0x7D, 0x86, 0x78, 0x81, 0x75, 0x84, 0x76, 0x7F, 0x70, 0x7F, 0x72, 0x78, 0x6C, 0x7A, 0x6C, 0x7B, 0x71, 0x7D, 0x70, 0x80, 0x73, 0x79, 0x6F, 0x7A, 0x6E, 0x7E, 0x6E, 0x7B, 0x6F, 0x7D, 0x6D, 0x7C, 0x6B, 0x79, 0x6B, 0x74, 0x67, 0x79, 0x69, 0x7D, 0x71, 0x80, 0x74, 0x94, 0x9C, 0x9D, 0x91, 0x93, 0x90, 0x9C, 0x96, 0x94, 0x8F, 0x94, 0x96, 0x99, 0x99, 0x8B, 0x80, 0x86, 0x78, 0x81, 0x75, 0x81, 0x74, 0x7B, 0x6E, 0x7A, 0x6E, 0x79, 0x6E, 0x78, 0x69, 0x7A, 0x6B, 0x78, 0x6C, 0x7D, 0x6E, 0x7F, 0x6E, 0x7D, 0x70, 0x7B, 0x6E, 0x7E, 0x70, 0x7A, 0x6B, 0x77, 0x6B, 0x7A, 0x6F, 0x79, 0x6E, 0x7A, 0x6B, 0x77, 0x6A, 0x79, 0x6B, 0x77, 0x69, 0x76, 0x69, 0x76, 0x67, 0x73, 0x64, 0x72, 0x65, 0x72, 0x64, 0x70, 0x64, 0x6F, 0x63, 0x6F, 0x63, 0x72, 0x64, 0x72, 0x64, 0x71, 0x63, 0x71, 0x66, 0x74, 0x6B, 0x74, 0x6A, 0x72, 0x67, 0x77, 0x69, 0x74, 0x65, 0x76, 0x68, 0x77, 0x67, 0x70, 0x62, 0x6E, 0x61, 0x73, 0x69, 0x76, 0x6A, 0x75, 0x69, 0x75, 0x6C, 0x77, 0x6C, 0x78, 0x6F, 0x7B, 0x6E, 0x73, 0x65, 0x6F, 0x63, 0x71, 0x65, 0x78, 0x6C, 0x76, 0x6B, 0x78, 0x6A, 0x73, 0x66, 0x6E, 0x63, 0x6E, 0x60, 0x6A, 0x5C, 0x6D, 0x61, 0x6D, 0x61, 0x6E, 0x62, 0x6C, 0x62, 0x75, 0x68, 0x73, 0x65, 0x71, 0x68, 0x6E, 0x63, 0x6D, 0x61, 0x6C, 0x5F, 0x6B, 0x5F, 0x67, 0x5B, 0x6A, 0x60, 0x66, 0x5A, 0x3F, 0x40, 0x39, 0x43, 0x39, 0x3F, 0x3C, 0x43, 0x35, 0x3F, 0x3D, 0x45, 0x37, 0x40, 0x38, 0x3C, 0x34, 0x3B, 0x39, 0x40, 0x38, 0x41, 0x37, 0x3D, 0x34, 0x3A, 0x39, 0x42, 0x32, 0x3A, 0x34, 0x3F, 0x3B, 0x40, 0x33, 0x39, 0x36, 0x3C, 0x39, 0x44, 0x3F, 0x46, 0x35, 0x3A, 0x3D, 0x40, 0x34, 0x3B, 0x38, 0x3C, 0x2E, 0x35, 0x3D, 0x44, 0x42, 0x4C, 0x48, 0x4E, 0x44, 0x4C, 0x4B, 0x52, 0x49, 0x53, 0x4A, 0x50, 0x33, 0x3A, 0x3B, 0x46, 0x3A, 0x43, 0x4F, 0x63, 0x62, 0x7A, 0x67, 0x7E, 0x6A, 0x82, 0x6D, 0x86, 0x6E, 0x87, 0x62, 0x73, 0x2F, 0x33, 0x37, 0x3F, 0x38, 0x3F, 0x3F, 0x55, 0x5F, 0x7B
    },

    {
        0x5C, 0x21, 0x5B, 0x20, 0x5C, 0x21, 0x5E, 0x22, 0x5F, 0x22, 0x60, 0x22, 0x60, 0x22, 0x5E, 0x22, 0x5F, 0x21, 0x5E, 0x21, 0x5F, 0x22, 0x5F, 0x22, 0x62, 0x24, 0x5F, 0x23, 0x5E, 0x22, 0x5F, 0x23, 0x61, 0x23, 0x62, 0x24, 0x62, 0x24, 0x63, 0x26, 0x64, 0x26, 0x63, 0x26, 0x60, 0x24, 0x60, 0x23, 0x61, 0x23, 0x60, 0x23, 0x61, 0x23, 0x63, 0x24, 0x61, 0x23, 0x61, 0x23, 0x60, 0x22, 0x61, 0x22, 0x5F, 0x23, 0x60, 0x23, 0x62, 0x23, 0x60, 0x22, 0x60, 0x23, 0x62, 0x23, 0x5F, 0x22, 0x60, 0x23, 0x62, 0x24, 0x64, 0x23, 0x62, 0x23, 0x63, 0x23, 0x62, 0x23, 0x63, 0x24, 0x63, 0x25, 0x63, 0x24, 0x66, 0x25, 0x67, 0x25, 0x65, 0x25, 0x66, 0x24, 0x64, 0x25, 0x64, 0x25, 0x69, 0x26, 0x69, 0x26, 0x67, 0x26, 0x66, 0x25, 0x66, 0x25, 0x67, 0x26, 0x6A, 0x26, 0x6A, 0x26, 0x68, 0x25, 0x66, 0x25, 0x64, 0x25, 0x68, 0x28, 0x6D, 0x2A, 0x6A, 0x28, 0x69, 0x27, 0x69, 0x27, 0x6A, 0x29, 0x62, 0x26, 0x4B, 0x23, 0x43, 0x23, 0x5A, 0x28, 0x65, 0x28, 0x67, 0x28, 0x5D, 0x26, 0x43, 0x1F, 0x2B, 0x18, 0x24, 0x16, 0x23, 0x17, 0x22, 0x16, 0x21, 0x16, 0x29, 0x19, 0x4F, 0x22, 0x62, 0x26, 0x66, 0x27, 0x54, 0x23, 0x38, 0x1E, 0x54, 0x25, 0x69, 0x29, 0x6D, 0x2A, 0x6E, 0x2A, 0x6F, 0x2B, 0x72, 0x2C, 0x72, 0x2C, 0x71, 0x2D, 0x70, 0x2C, 0x71, 0x2B, 0x6F, 0x2D, 0x73, 0x2E, 0x76, 0x2F, 0x76, 0x2F, 0x75, 0x30, 0x73, 0x2F, 0x71, 0x2D, 0x72, 0x2D, 0x6F, 0x2D, 0x74, 0x2D, 0x77, 0x31, 0x78, 0x30, 0x76, 0x30, 0x83, 0x36, 0x7B, 0x32, 0x7D, 0x33, 0x77, 0x2E, 0x7B, 0x35, 0x87, 0x38, 0x83, 0x36, 0x7D, 0x37, 0x84, 0x36, 0x79, 0x32, 0x7C, 0x32, 0x7D, 0x35, 0x81, 0x34, 0x79, 0x32, 0x7A, 0x33, 0x80, 0x34, 0x76, 0x2E, 0x75, 0x2F, 0x71, 0x2E, 0x78, 0x32, 0x80, 0x34, 0x74, 0x2F, 0x81, 0x35, 0x7D, 0x34, 0x80, 0x35, 0x7E, 0x33, 0x80, 0x36, 0x89, 0x3C, 0x7C, 0x31, 0x75, 0x30, 0x81, 0x37, 0x89, 0x3C, 0x88, 0x3C, 0x89, 0x3B, 0x93, 0x42, 0x83, 0x34, 0x7A, 0x34, 0x87, 0x3B, 0x8F, 0x3D, 0x83, 0x37, 0x82, 0x37, 0x86, 0x39, 0x90, 0x40, 0x81, 0x37, 0x84, 0x35, 0x7A, 0x31, 0x89, 0x3E, 0x84, 0x35, 0x80, 0x39, 0x81, 0x36, 0x71, 0x2B, 0x77, 0x32, 0x7D, 0x35, 0x82, 0x38, 0x84, 0x37, 0x81, 0x35, 0x76, 0x2D, 0x70, 0x2B, 0x6F, 0x29, 0x6F, 0x2B, 0x6E, 0x2A, 0x6B, 0x29, 0x6A, 0x28, 0x6F, 0x2B, 0x71, 0x2C, 0x6E, 0x2D, 0x71, 0x2C, 0x6E, 0x2A, 0x69, 0x27, 0x67, 0x27, 0x68, 0x27, 0x68, 0x26, 0x68, 0x27, 0x68, 0x27, 0x68, 0x26, 0x69, 0x28, 0x78, 0x31, 0x7A, 0x32, 0x93, 0x45, 0x76, 0x2E, 0x83, 0x3A, 0x92, 0x3F, 0x82, 0x39, 0x92, 0x44, 0x88, 0x38, 0x76, 0x2E, 0x72, 0x2C, 0x70, 0x2C, 0x6D, 0x2A, 0x6B, 0x29, 0x6B, 0x2A, 0x68, 0x27, 0x66, 0x26, 0x6E, 0x2B, 0x6B, 0x29, 0x66, 0x26, 0x6C, 0x29, 0x6B, 0x29, 0x6C, 0x29, 0x6B, 0x29, 0x67, 0x27, 0x6F, 0x2A, 0x6D, 0x29, 0x69, 0x27, 0x67, 0x27, 0x6A, 0x28, 0x67, 0x26, 0x66, 0x27, 0x64, 0x27, 0x65, 0x28, 0x60, 0x24, 0x5E, 0x23, 0x60, 0x24, 0x62, 0x26, 0x64, 0x26, 0x62, 0x25, 0x63, 0x25, 0x61, 0x24, 0x62, 0x25, 0x65, 0x27, 0x63, 0x26, 0x61, 0x25, 0x62, 0x24, 0x60, 0x23, 0x64, 0x27, 0x67, 0x28, 0x68, 0x29, 0x66, 0x28, 0x65, 0x27, 0x63, 0x26, 0x61, 0x25, 0x64, 0x26, 0x67, 0x29, 0x6A, 0x29, 0x6B, 0x2A, 0x66, 0x28, 0x65, 0x27, 0x62, 0x25, 0x5F, 0x25, 0x64, 0x27, 0x63, 0x27, 0x62, 0x26, 0x65, 0x27, 0x64, 0x26, 0x5D, 0x23, 0x5F, 0x25, 0x60, 0x25, 0x60, 0x24, 0x5F, 0x24, 0x60, 0x24, 0x5E, 0x23, 0x5D, 0x24, 0x5E, 0x23, 0x5C, 0x23, 0x5E, 0x24, 0x5D, 0x23, 0x58, 0x21, 0x59, 0x22, 0x55, 0x21, 0x47, 0x24, 0x3F, 0x22, 0x46, 0x25, 0x3C, 0x20, 0x3F, 0x22, 0x38, 0x1E, 0x39, 0x22, 0x43, 0x23, 0x42, 0x25, 0x47, 0x25, 0x43, 0x26, 0x52, 0x2C, 0x40, 0x22, 0x3D, 0x21, 0x3B, 0x20, 0x3C, 0x22, 0x3C, 0x23, 0x38, 0x29, 0x3F, 0x2D, 0x45, 0x35, 0x42, 0x34, 0x43, 0x38, 0x43, 0x31, 0x33, 0x1E, 0x37, 0x1E, 0x38, 0x1F, 0x49, 0x3E, 0x53, 0x4A, 0x54, 0x4A, 0x57, 0x4C, 0x59, 0x4C, 0x5B, 0x4D, 0x55, 0x41, 0x2C, 0x1E, 0x38, 0x20, 0x3C, 0x21, 0x52, 0x3F, 0x67, 0x50, 0x62, 0x4E, 0x61, 0x4A, 0x5E, 0x47, 0x54, 0x3F, 0x49, 0x35, 0x28, 0x1B, 0x2E, 0x1B, 0x36, 0x1E, 0x37, 0x20, 0x36, 0x21
    },

    {
        0x69, 0x5D, 0x67, 0x5C, 0x69, 0x5D, 0x6B, 0x5F, 0x6B, 0x60, 0x6E, 0x61, 0x6F, 0x61, 0x6D, 0x60, 0x6F, 0x5F, 0x6D, 0x60, 0x6D, 0x60, 0x6E, 0x62, 0x71, 0x64, 0x70, 0x62, 0x6E, 0x5F, 0x6F, 0x61, 0x6F, 0x60, 0x72, 0x63, 0x72, 0x63, 0x72, 0x65, 0x71, 0x65, 0x70, 0x64, 0x6E, 0x61, 0x6F, 0x62, 0x70, 0x62, 0x70, 0x61, 0x71, 0x62, 0x72, 0x64, 0x73, 0x63, 0x71, 0x61, 0x70, 0x61, 0x71, 0x62, 0x70, 0x61, 0x71, 0x63, 0x74, 0x63, 0x72, 0x63, 0x74, 0x63, 0x73, 0x61, 0x70, 0x60, 0x70, 0x62, 0x72, 0x64, 0x76, 0x66, 0x74, 0x63, 0x72, 0x62, 0x72, 0x62, 0x72, 0x63, 0x74, 0x66, 0x76, 0x67, 0x77, 0x68, 0x7A, 0x68, 0x78, 0x68, 0x79, 0x68, 0x78, 0x68, 0x79, 0x69, 0x7B, 0x6B, 0x78, 0x69, 0x79, 0x6A, 0x78, 0x69, 0x79, 0x68, 0x79, 0x6A, 0x7A, 0x6B, 0x7D, 0x6D, 0x7C, 0x69, 0x7B, 0x69, 0x7A, 0x68, 0x7A, 0x6A, 0x7C, 0x6E, 0x7C, 0x6C, 0x7B, 0x68, 0x79, 0x6B, 0x7A, 0x6C, 0x72, 0x66, 0x5E, 0x51, 0x46, 0x43, 0x58, 0x5A, 0x6D, 0x68, 0x73, 0x6B, 0x6B, 0x63, 0x50, 0x47, 0x2F, 0x2D, 0x25, 0x26, 0x22, 0x25, 0x20, 0x23, 0x21, 0x23, 0x30, 0x36, 0x5B, 0x59, 0x6E, 0x66, 0x6E, 0x65, 0x54, 0x49, 0x3E, 0x3D, 0x60, 0x61, 0x76, 0x6C, 0x7C, 0x71, 0x7E, 0x71, 0x7E, 0x74, 0x7F, 0x71, 0x80, 0x73, 0x7E, 0x74, 0x80, 0x73, 0x7F, 0x72, 0x7F, 0x75, 0x80, 0x75, 0x85, 0x79, 0x84, 0x78, 0x83, 0x78, 0x81, 0x76, 0x7E, 0x72, 0x7E, 0x71, 0x7D, 0x70, 0x83, 0x76, 0x86, 0x7D, 0x87, 0x7D, 0x85, 0x7B, 0x8B, 0x81, 0x89, 0x81, 0x8C, 0x81, 0x87, 0x79, 0x8B, 0x83, 0x90, 0x81, 0x8C, 0x82, 0x88, 0x7F, 0x89, 0x7F, 0x84, 0x7A, 0x87, 0x7D, 0x8D, 0x88, 0x8A, 0x7E, 0x85, 0x7E, 0x88, 0x7C, 0x8A, 0x7D, 0x82, 0x75, 0x81, 0x76, 0x80, 0x77, 0x85, 0x7D, 0x89, 0x7E, 0x80, 0x75, 0x87, 0x7D, 0x88, 0x7E, 0x88, 0x7D, 0x88, 0x7C, 0x8A, 0x80, 0x8A, 0x84, 0x83, 0x79, 0x85, 0x7D, 0x8C, 0x83, 0x94, 0x90, 0x94, 0x8D, 0x96, 0x8F, 0x98, 0x98, 0x8C, 0x7E, 0x88, 0x80, 0x90, 0x8F, 0x92, 0x92, 0x8B, 0x81, 0x8A, 0x81, 0x8E, 0x86, 0x98, 0x96, 0x8C, 0x81, 0x8C, 0x7F, 0x8A, 0x7F, 0x93, 0x92, 0x8E, 0x82, 0x8B, 0x81, 0x8A, 0x85, 0x84, 0x76, 0x89, 0x81, 0x8B, 0x82, 0x8C, 0x86, 0x88, 0x80, 0x89, 0x85, 0x81, 0x76, 0x80, 0x76, 0x7E, 0x72, 0x7F, 0x72, 0x7E, 0x73, 0x80, 0x71, 0x7B, 0x6E, 0x7F, 0x74, 0x7E, 0x75, 0x81, 0x75, 0x7D, 0x70, 0x7D, 0x70, 0x79, 0x6D, 0x76, 0x69, 0x79, 0x6A, 0x78, 0x6A, 0x7B, 0x6D, 0x77, 0x6B, 0x7A, 0x6B, 0x77, 0x6B, 0x7E, 0x74, 0x83, 0x76, 0x94, 0x93, 0x82, 0x74, 0x8E, 0x8B, 0x9B, 0x9B, 0x8D, 0x82, 0x8F, 0x8C, 0x8E, 0x83, 0x85, 0x78, 0x7E, 0x72, 0x7D, 0x70, 0x7F, 0x71, 0x7D, 0x6C, 0x78, 0x6C, 0x7C, 0x6C, 0x77, 0x6A, 0x7F, 0x72, 0x7C, 0x6D, 0x79, 0x6B, 0x7E, 0x70, 0x7D, 0x6F, 0x80, 0x71, 0x7B, 0x6E, 0x78, 0x6B, 0x80, 0x73, 0x7C, 0x6E, 0x7A, 0x6B, 0x77, 0x6A, 0x78, 0x6A, 0x78, 0x68, 0x74, 0x66, 0x73, 0x67, 0x73, 0x68, 0x70, 0x64, 0x6E, 0x62, 0x71, 0x63, 0x73, 0x65, 0x70, 0x66, 0x71, 0x63, 0x74, 0x66, 0x74, 0x67, 0x73, 0x67, 0x73, 0x67, 0x6C, 0x62, 0x6F, 0x63, 0x71, 0x63, 0x71, 0x65, 0x75, 0x68, 0x79, 0x6A, 0x76, 0x6C, 0x73, 0x6A, 0x72, 0x67, 0x71, 0x64, 0x70, 0x64, 0x73, 0x67, 0x75, 0x6C, 0x78, 0x6C, 0x78, 0x6D, 0x74, 0x68, 0x73, 0x66, 0x70, 0x62, 0x6F, 0x63, 0x73, 0x67, 0x71, 0x66, 0x6E, 0x64, 0x73, 0x68, 0x72, 0x64, 0x6F, 0x63, 0x70, 0x64, 0x6F, 0x63, 0x6F, 0x61, 0x6C, 0x61, 0x6F, 0x64, 0x6E, 0x5F, 0x6B, 0x61, 0x6C, 0x5E, 0x6B, 0x5F, 0x6B, 0x5F, 0x68, 0x5D, 0x66, 0x5A, 0x67, 0x5B, 0x5F, 0x54, 0x44, 0x46, 0x39, 0x3E, 0x3E, 0x46, 0x32, 0x38, 0x39, 0x44, 0x33, 0x37, 0x39, 0x44, 0x3F, 0x43, 0x3D, 0x48, 0x3E, 0x43, 0x3D, 0x49, 0x4A, 0x52, 0x37, 0x3B, 0x33, 0x3C, 0x31, 0x35, 0x38, 0x41, 0x37, 0x3A, 0x38, 0x3D, 0x3D, 0x40, 0x42, 0x48, 0x42, 0x46, 0x44, 0x49, 0x3D, 0x3F, 0x2D, 0x33, 0x33, 0x39, 0x37, 0x3F, 0x44, 0x4D, 0x4A, 0x53, 0x4B, 0x54, 0x4E, 0x56, 0x4E, 0x57, 0x50, 0x59, 0x46, 0x4B, 0x26, 0x2B, 0x31, 0x38, 0x34, 0x39, 0x44, 0x55, 0x4C, 0x5B, 0x48, 0x55, 0x44, 0x51, 0x3F, 0x4C, 0x39, 0x43, 0x32, 0x39, 0x22, 0x25, 0x2B, 0x32, 0x31, 0x36, 0x31, 0x39, 0x2C, 0x2F
    },

    {
        0x5B, 0x21, 0x5A, 0x20, 0x5B, 0x20, 0x5D, 0x21, 0x5D, 0x21, 0x5D, 0x21, 0x5D, 0x21, 0x5F, 0x22, 0x5E, 0x22, 0x5E, 0x21, 0x5F, 0x23, 0x62, 0x23, 0x61, 0x23, 0x61, 0x23, 0x61, 0x23, 0x61, 0x23, 0x63, 0x24, 0x65, 0x27, 0x68, 0x28, 0x65, 0x26, 0x62, 0x26, 0x63, 0x25, 0x61, 0x24, 0x60, 0x23, 0x60, 0x23, 0x60, 0x23, 0x5F, 0x23, 0x5F, 0x23, 0x61, 0x22, 0x5F, 0x22, 0x5C, 0x22, 0x5F, 0x23, 0x62, 0x23, 0x63, 0x23, 0x61, 0x23, 0x62, 0x23, 0x62, 0x23, 0x5F, 0x22, 0x62, 0x23, 0x63, 0x24, 0x62, 0x24, 0x62, 0x23, 0x61, 0x24, 0x61, 0x23, 0x5F, 0x22, 0x60, 0x24, 0x64, 0x25, 0x65, 0x24, 0x65, 0x24, 0x65, 0x24, 0x65, 0x25, 0x66, 0x25, 0x67, 0x26, 0x67, 0x25, 0x66, 0x25, 0x68, 0x26, 0x69, 0x26, 0x68, 0x26, 0x68, 0x26, 0x64, 0x25, 0x66, 0x25, 0x68, 0x26, 0x69, 0x26, 0x68, 0x26, 0x67, 0x26, 0x6B, 0x26, 0x68, 0x26, 0x6A, 0x27, 0x6A, 0x26, 0x68, 0x26, 0x6B, 0x28, 0x69, 0x28, 0x65, 0x27, 0x52, 0x23, 0x41, 0x22, 0x53, 0x27, 0x68, 0x2A, 0x6C, 0x2A, 0x64, 0x27, 0x44, 0x1E, 0x2C, 0x18, 0x25, 0x16, 0x24, 0x17, 0x2B, 0x1A, 0x4D, 0x22, 0x65, 0x28, 0x67, 0x28, 0x55, 0x23, 0x39, 0x1E, 0x51, 0x25, 0x69, 0x29, 0x6B, 0x29, 0x72, 0x2B, 0x6D, 0x2A, 0x70, 0x2C, 0x6B, 0x2A, 0x6D, 0x2B, 0x72, 0x2D, 0x76, 0x2E, 0x71, 0x2A, 0x73, 0x2E, 0x7A, 0x31, 0x77, 0x2F, 0x75, 0x2E, 0x76, 0x2F, 0x73, 0x2E, 0x71, 0x2C, 0x72, 0x2E, 0x76, 0x2F, 0x75, 0x2E, 0x7C, 0x33, 0x7F, 0x34, 0x7A, 0x31, 0x79, 0x35, 0x91, 0x42, 0x87, 0x37, 0x80, 0x35, 0x81, 0x38, 0x82, 0x35, 0x76, 0x30, 0x78, 0x30, 0x7A, 0x30, 0x78, 0x31, 0x7B, 0x32, 0x7F, 0x34, 0x7F, 0x33, 0x7A, 0x31, 0x79, 0x30, 0x79, 0x30, 0x76, 0x2F, 0x73, 0x2F, 0x75, 0x33, 0x7E, 0x35, 0x7B, 0x32, 0x79, 0x31, 0x76, 0x2D, 0x75, 0x32, 0x80, 0x34, 0x7F, 0x37, 0x80, 0x33, 0x75, 0x2F, 0x77, 0x32, 0x7B, 0x34, 0x81, 0x39, 0x8F, 0x3C, 0x80, 0x37, 0x8B, 0x40, 0x8C, 0x3C, 0x81, 0x37, 0x7D, 0x33, 0x79, 0x33, 0x79, 0x37, 0x83, 0x39, 0x8F, 0x3E, 0x90, 0x3D, 0x81, 0x35, 0x8A, 0x3B, 0x80, 0x34, 0x8A, 0x39, 0x80, 0x38, 0x85, 0x3C, 0xA2, 0x4D, 0x98, 0x44, 0x82, 0x35, 0x88, 0x3C, 0x8A, 0x3E, 0x80, 0x35, 0x6E, 0x33, 0x75, 0x38, 0x75, 0x39, 0x82, 0x37, 0x77, 0x2E, 0x71, 0x2B, 0x73, 0x2E, 0x71, 0x2A, 0x6F, 0x2B, 0x72, 0x2E, 0x6E, 0x2B, 0x70, 0x2D, 0x73, 0x2F, 0x6F, 0x2B, 0x6C, 0x29, 0x69, 0x27, 0x69, 0x27, 0x64, 0x25, 0x6A, 0x28, 0x69, 0x27, 0x6B, 0x29, 0x6D, 0x28, 0x6B, 0x27, 0x6A, 0x29, 0x70, 0x2C, 0x89, 0x3A, 0x86, 0x3B, 0x9A, 0x49, 0x8E, 0x3C, 0x82, 0x38, 0x7B, 0x32, 0x71, 0x2B, 0x6E, 0x2B, 0x73, 0x2B, 0x6D, 0x2A, 0x71, 0x2A, 0x68, 0x26, 0x6F, 0x29, 0x6E, 0x28, 0x6E, 0x2A, 0x6C, 0x29, 0x6A, 0x28, 0x6E, 0x2A, 0x74, 0x2C, 0x6F, 0x2B, 0x70, 0x2C, 0x6B, 0x27, 0x69, 0x27, 0x69, 0x28, 0x69, 0x27, 0x60, 0x26, 0x62, 0x26, 0x62, 0x25, 0x64, 0x27, 0x63, 0x26, 0x65, 0x28, 0x66, 0x27, 0x64, 0x25, 0x62, 0x24, 0x5E, 0x24, 0x62, 0x25, 0x5F, 0x26, 0x63, 0x25, 0x65, 0x27, 0x64, 0x26, 0x60, 0x25, 0x60, 0x24, 0x5F, 0x24, 0x60, 0x24, 0x63, 0x25, 0x66, 0x26, 0x69, 0x28, 0x67, 0x28, 0x64, 0x27, 0x65, 0x28, 0x66, 0x27, 0x62, 0x26, 0x64, 0x28, 0x67, 0x29, 0x69, 0x2A, 0x6A, 0x2B, 0x66, 0x2A, 0x68, 0x29, 0x66, 0x28, 0x64, 0x26, 0x64, 0x26, 0x61, 0x26, 0x61, 0x25, 0x62, 0x26, 0x5C, 0x23, 0x61, 0x26, 0x65, 0x27, 0x5F, 0x24, 0x5C, 0x23, 0x60, 0x24, 0x5D, 0x23, 0x5F, 0x25, 0x5D, 0x23, 0x5A, 0x21, 0x57, 0x21, 0x58, 0x22, 0x59, 0x22, 0x5D, 0x23, 0x5F, 0x25, 0x58, 0x22, 0x42, 0x21, 0x36, 0x1F, 0x49, 0x24, 0x3F, 0x22, 0x40, 0x22, 0x3C, 0x22, 0x49, 0x32, 0x4F, 0x35, 0x44, 0x33, 0x41, 0x34, 0x48, 0x3B, 0x4A, 0x3D, 0x3F, 0x2C, 0x3C, 0x22, 0x3C, 0x20, 0x3F, 0x23, 0x3E, 0x36, 0x44, 0x3F, 0x47, 0x44, 0x4A, 0x46, 0x4C, 0x45, 0x49, 0x44, 0x3C, 0x32, 0x25, 0x1A, 0x40, 0x23, 0x41, 0x22, 0x43, 0x37, 0x48, 0x3F, 0x44, 0x3B, 0x3F, 0x38, 0x3B, 0x33, 0x38, 0x31, 0x31, 0x27, 0x20, 0x18, 0x2B, 0x1A, 0x34, 0x1D, 0x40, 0x23, 0x2E, 0x1C, 0x26, 0x19, 0x23, 0x18, 0x2A, 0x19, 0x2B, 0x1A, 0x2F, 0x1B, 0x2E, 0x19, 0x36, 0x1E, 0x43, 0x23, 0x3E, 0x21, 0x3B, 0x20
    },

    {
        0x69, 0x5D, 0x68, 0x5B, 0x66, 0x5B, 0x69, 0x5C, 0x6B, 0x5D, 0x6B, 0x5D, 0x6C, 0x5F, 0x6F, 0x60, 0x6D, 0x5F, 0x6D, 0x5F, 0x6E, 0x60, 0x71, 0x62, 0x72, 0x63, 0x70, 0x62, 0x70, 0x62, 0x72, 0x62, 0x71, 0x64, 0x74, 0x67, 0x74, 0x69, 0x71, 0x64, 0x72, 0x64, 0x75, 0x67, 0x71, 0x63, 0x6E, 0x61, 0x6F, 0x61, 0x70, 0x62, 0x71, 0x61, 0x70, 0x62, 0x71, 0x61, 0x6F, 0x5F, 0x6E, 0x5E, 0x71, 0x63, 0x73, 0x63, 0x73, 0x63, 0x72, 0x63, 0x73, 0x63, 0x74, 0x63, 0x72, 0x61, 0x73, 0x63, 0x73, 0x63, 0x71, 0x63, 0x74, 0x65, 0x72, 0x64, 0x75, 0x63, 0x72, 0x61, 0x6E, 0x61, 0x73, 0x64, 0x76, 0x66, 0x77, 0x65, 0x76, 0x66, 0x77, 0x66, 0x77, 0x67, 0x7A, 0x69, 0x7A, 0x68, 0x7A, 0x6A, 0x7A, 0x6A, 0x7C, 0x6C, 0x7B, 0x69, 0x7A, 0x69, 0x77, 0x66, 0x79, 0x68, 0x7C, 0x6C, 0x7D, 0x6A, 0x7B, 0x6A, 0x7B, 0x6B, 0x7C, 0x6C, 0x7A, 0x6A, 0x7D, 0x6D, 0x7D, 0x6C, 0x79, 0x6A, 0x7C, 0x6D, 0x78, 0x6B, 0x74, 0x68, 0x65, 0x58, 0x48, 0x42, 0x4C, 0x4D, 0x68, 0x66, 0x75, 0x6F, 0x6F, 0x67, 0x56, 0x4A, 0x34, 0x2E, 0x27, 0x28, 0x27, 0x26, 0x34, 0x37, 0x5D, 0x5D, 0x72, 0x6B, 0x71, 0x67, 0x54, 0x49, 0x3E, 0x3C, 0x60, 0x5F, 0x76, 0x6C, 0x7B, 0x6E, 0x7E, 0x70, 0x7F, 0x70, 0x7E, 0x70, 0x7E, 0x6E, 0x7E, 0x72, 0x82, 0x76, 0x82, 0x76, 0x82, 0x72, 0x81, 0x77, 0x84, 0x7B, 0x85, 0x79, 0x83, 0x76, 0x81, 0x75, 0x7F, 0x74, 0x7F, 0x74, 0x80, 0x74, 0x83, 0x79, 0x7F, 0x73, 0x88, 0x81, 0x8C, 0x84, 0x8A, 0x7C, 0x88, 0x81, 0x94, 0x91, 0x8D, 0x82, 0x8E, 0x84, 0x8A, 0x85, 0x87, 0x7C, 0x82, 0x74, 0x82, 0x79, 0x86, 0x7C, 0x87, 0x7B, 0x85, 0x7A, 0x87, 0x79, 0x8D, 0x82, 0x86, 0x7A, 0x86, 0x7A, 0x84, 0x7A, 0x80, 0x76, 0x7F, 0x75, 0x7D, 0x77, 0x89, 0x80, 0x87, 0x7C, 0x88, 0x7E, 0x84, 0x77, 0x83, 0x7A, 0x89, 0x7F, 0x8A, 0x86, 0x89, 0x7F, 0x83, 0x76, 0x80, 0x78, 0x82, 0x7B, 0x8C, 0x85, 0x95, 0x88, 0x8B, 0x81, 0x92, 0x8B, 0x8F, 0x85, 0x88, 0x7E, 0x87, 0x7A, 0x82, 0x78, 0x7F, 0x78, 0x8C, 0x83, 0x94, 0x92, 0x9F, 0x9D, 0x91, 0x86, 0x91, 0x88, 0x89, 0x7E, 0x8C, 0x85, 0x8A, 0x82, 0x8D, 0x86, 0xA1, 0xA6, 0x9F, 0x9C, 0x8F, 0x82, 0x8F, 0x89, 0x93, 0x90, 0x82, 0x76, 0x6D, 0x6C, 0x6C, 0x72, 0x6E, 0x78, 0x7B, 0x79, 0x7F, 0x78, 0x80, 0x73, 0x85, 0x78, 0x81, 0x72, 0x7E, 0x72, 0x7A, 0x6F, 0x7A, 0x72, 0x7F, 0x74, 0x80, 0x75, 0x7E, 0x70, 0x7D, 0x6F, 0x79, 0x6C, 0x79, 0x6A, 0x76, 0x67, 0x77, 0x6B, 0x7A, 0x6B, 0x7C, 0x6F, 0x79, 0x6C, 0x7B, 0x6B, 0x79, 0x6D, 0x7E, 0x71, 0x92, 0x8B, 0x96, 0x91, 0x99, 0x96, 0x96, 0x8B, 0x90, 0x86, 0x87, 0x7D, 0x82, 0x73, 0x81, 0x73, 0x81, 0x75, 0x7C, 0x70, 0x7C, 0x70, 0x7B, 0x6B, 0x80, 0x71, 0x7F, 0x71, 0x80, 0x73, 0x7E, 0x6F, 0x7D, 0x6E, 0x7F, 0x71, 0x85, 0x76, 0x7F, 0x6F, 0x80, 0x74, 0x7A, 0x6B, 0x7A, 0x6A, 0x79, 0x6B, 0x7A, 0x6B, 0x72, 0x66, 0x75, 0x68, 0x74, 0x65, 0x74, 0x6B, 0x75, 0x69, 0x76, 0x69, 0x75, 0x69, 0x74, 0x64, 0x74, 0x65, 0x70, 0x62, 0x6F, 0x64, 0x6E, 0x63, 0x71, 0x65, 0x72, 0x69, 0x72, 0x67, 0x70, 0x64, 0x71, 0x63, 0x70, 0x63, 0x73, 0x64, 0x70, 0x66, 0x76, 0x6B, 0x76, 0x6A, 0x75, 0x69, 0x73, 0x65, 0x72, 0x68, 0x73, 0x67, 0x71, 0x66, 0x73, 0x69, 0x75, 0x68, 0x73, 0x6B, 0x75, 0x6C, 0x75, 0x6C, 0x75, 0x6B, 0x73, 0x6A, 0x72, 0x67, 0x71, 0x67, 0x6F, 0x64, 0x70, 0x63, 0x6E, 0x65, 0x6A, 0x5E, 0x6F, 0x65, 0x71, 0x66, 0x6D, 0x60, 0x6D, 0x60, 0x6E, 0x60, 0x69, 0x5E, 0x6E, 0x61, 0x6B, 0x60, 0x67, 0x5A, 0x65, 0x58, 0x68, 0x5C, 0x66, 0x5C, 0x6B, 0x5F, 0x6B, 0x60, 0x61, 0x55, 0x43, 0x45, 0x36, 0x3C, 0x42, 0x48, 0x39, 0x40, 0x36, 0x3D, 0x35, 0x3B, 0x45, 0x4E, 0x49, 0x4C, 0x42, 0x46, 0x43, 0x45, 0x45, 0x4A, 0x47, 0x4B, 0x3A, 0x3E, 0x36, 0x3F, 0x39, 0x42, 0x38, 0x3E, 0x3C, 0x41, 0x41, 0x46, 0x44, 0x48, 0x45, 0x49, 0x45, 0x48, 0x43, 0x48, 0x35, 0x34, 0x21, 0x25, 0x3C, 0x48, 0x37, 0x3C, 0x3B, 0x43, 0x3B, 0x40, 0x37, 0x3C, 0x32, 0x37, 0x2D, 0x32, 0x2A, 0x2F, 0x25, 0x28, 0x1F, 0x21, 0x29, 0x30, 0x31, 0x36, 0x38, 0x3F, 0x2A, 0x2C, 0x25, 0x27, 0x23, 0x27, 0x29, 0x2F, 0x2B, 0x31, 0x32, 0x38, 0x2E, 0x32, 0x33, 0x3F, 0x3D, 0x44, 0x38, 0x40, 0x36, 0x3C
    },

    {
        0x5B, 0x21, 0x5B, 0x1F, 0x59, 0x20, 0x59, 0x20, 0x5B, 0x20, 0x5D, 0x21, 0x5D, 0x21, 0x5F, 0x22, 0x5E, 0x21, 0x5E, 0x22, 0x60, 0x22, 0x61, 0x22, 0x5F, 0x23, 0x5F, 0x22, 0x5F, 0x22, 0x61, 0x23, 0x67, 0x26, 0x68, 0x27, 0x67, 0x28, 0x65, 0x26, 0x65, 0x25, 0x67, 0x27, 0x63, 0x25, 0x62, 0x24, 0x62, 0x24, 0x61, 0x23, 0x5E, 0x22, 0x5E, 0x22, 0x60, 0x22, 0x5E, 0x22, 0x5F, 0x23, 0x60, 0x23, 0x60, 0x23, 0x60, 0x22, 0x60, 0x23, 0x61, 0x23, 0x62, 0x23, 0x61, 0x24, 0x62, 0x23, 0x62, 0x23, 0x62, 0x23, 0x63, 0x23, 0x64, 0x25, 0x64, 0x24, 0x62, 0x23, 0x61, 0x24, 0x63, 0x24, 0x63, 0x24, 0x64, 0x24, 0x62, 0x23, 0x63, 0x24, 0x63, 0x24, 0x68, 0x25, 0x68, 0x25, 0x67, 0x25, 0x67, 0x25, 0x69, 0x26, 0x69, 0x26, 0x68, 0x26, 0x67, 0x26, 0x6A, 0x26, 0x69, 0x26, 0x67, 0x26, 0x6A, 0x28, 0x6D, 0x28, 0x69, 0x26, 0x67, 0x25, 0x66, 0x26, 0x67, 0x25, 0x69, 0x27, 0x69, 0x26, 0x69, 0x27, 0x67, 0x27, 0x6B, 0x2A, 0x5C, 0x26, 0x40, 0x1F, 0x4A, 0x23, 0x65, 0x28, 0x68, 0x28, 0x63, 0x26, 0x4D, 0x1F, 0x31, 0x1A, 0x30, 0x1C, 0x4F, 0x23, 0x63, 0x28, 0x66, 0x27, 0x56, 0x24, 0x38, 0x1E, 0x4D, 0x23, 0x68, 0x2A, 0x6B, 0x2A, 0x6F, 0x2A, 0x6D, 0x2A, 0x6E, 0x2A, 0x6F, 0x2B, 0x71, 0x2B, 0x73, 0x2E, 0x73, 0x2D, 0x72, 0x2C, 0x6F, 0x2A, 0x71, 0x2C, 0x71, 0x2D, 0x75, 0x2D, 0x77, 0x30, 0x7D, 0x33, 0x74, 0x2F, 0x7A, 0x30, 0x77, 0x30, 0x76, 0x2F, 0x7A, 0x34, 0x88, 0x3E, 0x85, 0x38, 0x7D, 0x34, 0x84, 0x38, 0x88, 0x3A, 0x86, 0x3A, 0x8D, 0x3B, 0x7C, 0x34, 0x7B, 0x33, 0x78, 0x31, 0x81, 0x38, 0x80, 0x34, 0x7A, 0x34, 0x88, 0x3A, 0x79, 0x31, 0x86, 0x39, 0x7D, 0x31, 0x80, 0x35, 0x7A, 0x31, 0x7B, 0x32, 0x79, 0x33, 0x7E, 0x37, 0x82, 0x37, 0x79, 0x31, 0x78, 0x30, 0x74, 0x2E, 0x77, 0x30, 0x7C, 0x34, 0x81, 0x36, 0x7E, 0x35, 0x86, 0x36, 0x7C, 0x31, 0x79, 0x32, 0x82, 0x37, 0x93, 0x41, 0x91, 0x3F, 0x88, 0x3B, 0x85, 0x3A, 0x80, 0x36, 0x82, 0x36, 0x79, 0x33, 0x7F, 0x37, 0x87, 0x3B, 0x86, 0x3A, 0xA9, 0x50, 0x9B, 0x47, 0x8A, 0x37, 0x73, 0x2E, 0x7B, 0x35, 0x8C, 0x3D, 0x88, 0x38, 0x87, 0x3D, 0x9B, 0x45, 0x84, 0x36, 0x87, 0x3B, 0x87, 0x41, 0x79, 0x3B, 0x6D, 0x38, 0x72, 0x3D, 0x6D, 0x3D, 0x67, 0x34, 0x68, 0x2D, 0x70, 0x2D, 0x76, 0x2F, 0x77, 0x2D, 0x6C, 0x29, 0x6B, 0x2B, 0x6A, 0x2A, 0x6A, 0x2A, 0x6F, 0x2B, 0x71, 0x2B, 0x75, 0x2C, 0x6B, 0x29, 0x68, 0x27, 0x64, 0x26, 0x66, 0x26, 0x68, 0x27, 0x66, 0x26, 0x68, 0x27, 0x69, 0x28, 0x6E, 0x2B, 0x73, 0x2F, 0x94, 0x43, 0x9E, 0x4D, 0xA3, 0x4B, 0x93, 0x46, 0xA2, 0x49, 0x8D, 0x3D, 0x76, 0x2F, 0x72, 0x2C, 0x6F, 0x2C, 0x6F, 0x2A, 0x6F, 0x2A, 0x6C, 0x28, 0x6B, 0x28, 0x6D, 0x28, 0x6D, 0x2A, 0x72, 0x2C, 0x6C, 0x29, 0x67, 0x27, 0x6A, 0x28, 0x6C, 0x28, 0x6C, 0x29, 0x67, 0x28, 0x68, 0x28, 0x69, 0x27, 0x64, 0x25, 0x65, 0x28, 0x69, 0x28, 0x68, 0x28, 0x68, 0x27, 0x67, 0x27, 0x61, 0x26, 0x66, 0x28, 0x69, 0x2A, 0x66, 0x28, 0x68, 0x28, 0x62, 0x25, 0x64, 0x26, 0x62, 0x24, 0x63, 0x26, 0x62, 0x25, 0x61, 0x26, 0x64, 0x26, 0x61, 0x24, 0x63, 0x25, 0x61, 0x24, 0x61, 0x25, 0x62, 0x25, 0x65, 0x28, 0x64, 0x27, 0x67, 0x2A, 0x6A, 0x29, 0x69, 0x29, 0x68, 0x2A, 0x70, 0x2F, 0x6E, 0x2D, 0x6C, 0x2B, 0x6A, 0x2B, 0x6A, 0x2A, 0x65, 0x28, 0x64, 0x26, 0x66, 0x28, 0x61, 0x25, 0x60, 0x25, 0x5C, 0x23, 0x5B, 0x22, 0x5D, 0x23, 0x60, 0x24, 0x5A, 0x22, 0x5C, 0x23, 0x59, 0x22, 0x5B, 0x22, 0x5E, 0x24, 0x60, 0x24, 0x5C, 0x22, 0x58, 0x21, 0x5F, 0x25, 0x5C, 0x23, 0x5A, 0x22, 0x5B, 0x22, 0x56, 0x22, 0x4C, 0x25, 0x3A, 0x20, 0x41, 0x22, 0x33, 0x1C, 0x3E, 0x22, 0x3F, 0x26, 0x47, 0x40, 0x48, 0x43, 0x49, 0x45, 0x48, 0x44, 0x46, 0x42, 0x42, 0x40, 0x32, 0x27, 0x28, 0x1B, 0x3D, 0x20, 0x3A, 0x21, 0x3F, 0x32, 0x3D, 0x38, 0x3A, 0x36, 0x39, 0x33, 0x35, 0x2F, 0x30, 0x29, 0x28, 0x1F, 0x21, 0x17, 0x3F, 0x22, 0x33, 0x1B, 0x38, 0x1F, 0x29, 0x19, 0x25, 0x18, 0x25, 0x17, 0x2B, 0x19, 0x28, 0x17, 0x27, 0x17, 0x32, 0x1C, 0x37, 0x1E, 0x44, 0x22, 0x3D, 0x21, 0x3A, 0x1F, 0x33, 0x1D, 0x33, 0x1D, 0x42, 0x23, 0x33, 0x1C, 0x3F, 0x22, 0x38, 0x1F, 0x3C, 0x21, 0x3E, 0x20, 0x38, 0x1F, 0x39, 0x1F
    },

    {
        0x67, 0x5D, 0x68, 0x5C, 0x69, 0x5B, 0x67, 0x5D, 0x69, 0x5D, 0x6C, 0x5F, 0x6C, 0x5F, 0x6E, 0x61, 0x6E, 0x61, 0x6C, 0x60, 0x6F, 0x62, 0x70, 0x62, 0x72, 0x61, 0x70, 0x61, 0x71, 0x61, 0x72, 0x61, 0x74, 0x68, 0x76, 0x68, 0x74, 0x69, 0x73, 0x65, 0x74, 0x67, 0x75, 0x69, 0x71, 0x65, 0x71, 0x62, 0x72, 0x64, 0x72, 0x62, 0x6F, 0x60, 0x6F, 0x60, 0x71, 0x61, 0x6F, 0x60, 0x71, 0x61, 0x71, 0x62, 0x72, 0x62, 0x72, 0x62, 0x72, 0x62, 0x72, 0x63, 0x74, 0x63, 0x74, 0x64, 0x74, 0x65, 0x74, 0x64, 0x72, 0x62, 0x73, 0x64, 0x74, 0x65, 0x76, 0x65, 0x75, 0x64, 0x72, 0x64, 0x75, 0x65, 0x74, 0x65, 0x75, 0x64, 0x74, 0x64, 0x74, 0x65, 0x74, 0x65, 0x79, 0x68, 0x7B, 0x6A, 0x7A, 0x67, 0x7A, 0x6A, 0x7C, 0x6C, 0x7B, 0x6B, 0x7B, 0x6A, 0x79, 0x6B, 0x7C, 0x6B, 0x7D, 0x6C, 0x7B, 0x6A, 0x7B, 0x6D, 0x7C, 0x6D, 0x7A, 0x69, 0x79, 0x68, 0x78, 0x69, 0x78, 0x69, 0x79, 0x6B, 0x7B, 0x6B, 0x7B, 0x6B, 0x79, 0x6B, 0x7A, 0x6F, 0x6B, 0x60, 0x4D, 0x42, 0x45, 0x49, 0x64, 0x62, 0x73, 0x6A, 0x6E, 0x64, 0x5E, 0x51, 0x3B, 0x35, 0x39, 0x3B, 0x5C, 0x5C, 0x6F, 0x6A, 0x6E, 0x66, 0x55, 0x4A, 0x3E, 0x3C, 0x5D, 0x5E, 0x75, 0x6B, 0x7B, 0x70, 0x7F, 0x72, 0x7D, 0x6E, 0x7D, 0x70, 0x7F, 0x72, 0x81, 0x74, 0x80, 0x75, 0x83, 0x73, 0x7F, 0x72, 0x81, 0x70, 0x81, 0x73, 0x81, 0x74, 0x82, 0x75, 0x84, 0x79, 0x86, 0x7E, 0x82, 0x79, 0x88, 0x7F, 0x89, 0x80, 0x85, 0x78, 0x86, 0x7E, 0x8B, 0x8B, 0x8E, 0x82, 0x8C, 0x83, 0x93, 0x8E, 0x97, 0x93, 0x8F, 0x87, 0x92, 0x89, 0x88, 0x7E, 0x8A, 0x7F, 0x85, 0x7B, 0x8B, 0x86, 0x8A, 0x7F, 0x87, 0x7C, 0x91, 0x8D, 0x8A, 0x7D, 0x8E, 0x82, 0x8C, 0x7E, 0x8E, 0x85, 0x87, 0x7D, 0x86, 0x7C, 0x84, 0x7D, 0x8A, 0x84, 0x8A, 0x80, 0x88, 0x7C, 0x86, 0x79, 0x80, 0x74, 0x84, 0x79, 0x85, 0x80, 0x8C, 0x82, 0x88, 0x81, 0x90, 0x88, 0x8C, 0x85, 0x89, 0x82, 0x8F, 0x8A, 0x9F, 0x9E, 0x9E, 0x9C, 0x98, 0x8D, 0x8F, 0x89, 0x8D, 0x82, 0x8A, 0x80, 0x84, 0x7F, 0x8B, 0x85, 0x8F, 0x8A, 0x8B, 0x84, 0x9E, 0xA2, 0xA1, 0x9D, 0x94, 0x89, 0x84, 0x78, 0x87, 0x7C, 0x93, 0x8B, 0x93, 0x88, 0x92, 0x8F, 0x9C, 0x97, 0x92, 0x87, 0x94, 0x8B, 0x8A, 0x8B, 0x70, 0x71, 0x64, 0x6B, 0x65, 0x6F, 0x65, 0x6C, 0x61, 0x68, 0x67, 0x67, 0x78, 0x73, 0x85, 0x7B, 0x86, 0x79, 0x7D, 0x6F, 0x7A, 0x6E, 0x78, 0x6E, 0x7A, 0x6F, 0x7B, 0x70, 0x81, 0x72, 0x84, 0x77, 0x7D, 0x70, 0x7A, 0x6A, 0x77, 0x69, 0x76, 0x68, 0x78, 0x6C, 0x7A, 0x6B, 0x78, 0x6A, 0x7A, 0x6D, 0x7D, 0x73, 0x82, 0x7E, 0x9D, 0xA0, 0x9D, 0x9C, 0x9E, 0x9B, 0x9A, 0x9A, 0xA1, 0xA1, 0x9B, 0x93, 0x87, 0x7B, 0x7F, 0x70, 0x7C, 0x71, 0x80, 0x74, 0x82, 0x72, 0x81, 0x72, 0x7F, 0x71, 0x80, 0x6F, 0x7C, 0x6E, 0x7E, 0x71, 0x7B, 0x6B, 0x79, 0x6A, 0x7B, 0x6D, 0x7B, 0x6F, 0x7D, 0x6F, 0x78, 0x6E, 0x77, 0x6B, 0x77, 0x67, 0x76, 0x67, 0x74, 0x6A, 0x74, 0x6A, 0x72, 0x69, 0x77, 0x6A, 0x77, 0x68, 0x71, 0x66, 0x73, 0x68, 0x77, 0x6D, 0x74, 0x6A, 0x74, 0x68, 0x73, 0x68, 0x72, 0x67, 0x71, 0x65, 0x72, 0x66, 0x73, 0x66, 0x71, 0x65, 0x73, 0x65, 0x70, 0x63, 0x73, 0x66, 0x71, 0x64, 0x71, 0x64, 0x70, 0x63, 0x73, 0x68, 0x70, 0x65, 0x74, 0x6A, 0x76, 0x6B, 0x75, 0x6C, 0x78, 0x6F, 0x79, 0x72, 0x7A, 0x71, 0x76, 0x6C, 0x76, 0x6B, 0x76, 0x6D, 0x71, 0x67, 0x71, 0x67, 0x72, 0x67, 0x6E, 0x61, 0x6E, 0x61, 0x69, 0x5E, 0x69, 0x5E, 0x6C, 0x60, 0x6D, 0x5F, 0x69, 0x5D, 0x6B, 0x60, 0x68, 0x5C, 0x6C, 0x60, 0x6E, 0x62, 0x6D, 0x62, 0x6C, 0x5E, 0x68, 0x5D, 0x6D, 0x63, 0x6C, 0x61, 0x69, 0x5D, 0x69, 0x5D, 0x60, 0x55, 0x45, 0x46, 0x37, 0x3D, 0x35, 0x3C, 0x31, 0x36, 0x3C, 0x47, 0x3F, 0x44, 0x44, 0x47, 0x44, 0x47, 0x44, 0x4A, 0x44, 0x47, 0x43, 0x47, 0x3F, 0x41, 0x2A, 0x29, 0x22, 0x29, 0x35, 0x3C, 0x33, 0x39, 0x39, 0x3D, 0x35, 0x36, 0x30, 0x36, 0x2D, 0x31, 0x2A, 0x2D, 0x26, 0x29, 0x21, 0x23, 0x21, 0x28, 0x37, 0x3F, 0x30, 0x35, 0x34, 0x3B, 0x27, 0x2A, 0x27, 0x2D, 0x27, 0x2A, 0x2E, 0x33, 0x2A, 0x2D, 0x28, 0x2D, 0x31, 0x39, 0x33, 0x3C, 0x3A, 0x41, 0x34, 0x3C, 0x34, 0x39, 0x2E, 0x33, 0x30, 0x3A, 0x3B, 0x42, 0x2E, 0x35, 0x37, 0x3D, 0x30, 0x37, 0x36, 0x3F, 0x36, 0x3A, 0x31, 0x38, 0x32, 0x39
    },

    {
        0x5B, 0x20, 0x5A, 0x20, 0x5B, 0x20, 0x5A, 0x20, 0x5C, 0x20, 0x5C, 0x20, 0x5C, 0x21, 0x5C, 0x21, 0x5D, 0x21, 0x5E, 0x22, 0x63, 0x23, 0x5F, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x60, 0x22, 0x61, 0x24, 0x64, 0x24, 0x62, 0x25, 0x64, 0x27, 0x65, 0x25, 0x61, 0x24, 0x61, 0x24, 0x60, 0x24, 0x61, 0x24, 0x62, 0x24, 0x60, 0x24, 0x5F, 0x24, 0x61, 0x25, 0x60, 0x23, 0x5F, 0x23, 0x5F, 0x23, 0x60, 0x23, 0x61, 0x23, 0x61, 0x23, 0x5F, 0x23, 0x5F, 0x23, 0x60, 0x23, 0x61, 0x24, 0x61, 0x23, 0x60, 0x23, 0x62, 0x23, 0x62, 0x24, 0x65, 0x24, 0x62, 0x24, 0x64, 0x24, 0x64, 0x24, 0x63, 0x24, 0x61, 0x23, 0x60, 0x23, 0x62, 0x24, 0x66, 0x25, 0x69, 0x26, 0x67, 0x25, 0x67, 0x25, 0x67, 0x25, 0x67, 0x25, 0x69, 0x25, 0x69, 0x26, 0x69, 0x27, 0x69, 0x27, 0x69, 0x27, 0x6A, 0x27, 0x68, 0x26, 0x69, 0x26, 0x6A, 0x26, 0x69, 0x26, 0x68, 0x25, 0x65, 0x26, 0x69, 0x26, 0x67, 0x26, 0x69, 0x27, 0x6D, 0x28, 0x6D, 0x28, 0x6E, 0x2A, 0x6A, 0x29, 0x5C, 0x23, 0x40, 0x1F, 0x44, 0x22, 0x5D, 0x25, 0x65, 0x27, 0x65, 0x27, 0x59, 0x23, 0x58, 0x24, 0x66, 0x28, 0x69, 0x29, 0x59, 0x25, 0x3A, 0x1F, 0x4E, 0x23, 0x65, 0x27, 0x69, 0x29, 0x71, 0x2D, 0x73, 0x2B, 0x74, 0x2D, 0x75, 0x2C, 0x6C, 0x28, 0x6D, 0x29, 0x6C, 0x29, 0x70, 0x2B, 0x6F, 0x2A, 0x6F, 0x2A, 0x70, 0x2B, 0x6F, 0x2C, 0x71, 0x2D, 0x76, 0x2F, 0x75, 0x2E, 0x7A, 0x32, 0x7D, 0x35, 0x87, 0x37, 0x80, 0x36, 0x7C, 0x32, 0x7B, 0x36, 0x84, 0x36, 0x87, 0x3A, 0x8D, 0x3F, 0x90, 0x3F, 0x82, 0x36, 0x77, 0x30, 0x7B, 0x33, 0x85, 0x39, 0x7F, 0x37, 0x9B, 0x44, 0x86, 0x37, 0x7D, 0x34, 0x7E, 0x35, 0x7D, 0x33, 0x88, 0x3A, 0x8D, 0x3D, 0x88, 0x39, 0x7D, 0x36, 0x7D, 0x35, 0x7D, 0x36, 0x7B, 0x35, 0x81, 0x33, 0x78, 0x31, 0x83, 0x36, 0x7D, 0x37, 0x88, 0x37, 0x81, 0x36, 0x92, 0x41, 0x89, 0x3B, 0x82, 0x38, 0x84, 0x39, 0x89, 0x3C, 0x93, 0x42, 0x9A, 0x48, 0xA2, 0x4F, 0x9F, 0x47, 0x8E, 0x3D, 0x87, 0x37, 0x78, 0x31, 0x7D, 0x36, 0x80, 0x31, 0x73, 0x30, 0x82, 0x38, 0x84, 0x38, 0x8F, 0x43, 0x9B, 0x41, 0x8F, 0x42, 0x8F, 0x3B, 0x80, 0x33, 0x7B, 0x32, 0x7A, 0x35, 0x79, 0x34, 0x84, 0x3A, 0x8C, 0x3D, 0x70, 0x39, 0x66, 0x35, 0x66, 0x37, 0x72, 0x3E, 0x70, 0x3C, 0x5D, 0x30, 0x62, 0x30, 0x63, 0x2B, 0x76, 0x2F, 0x79, 0x30, 0x72, 0x2E, 0x72, 0x2C, 0x6E, 0x2B, 0x6B, 0x28, 0x6C, 0x2A, 0x6E, 0x2A, 0x6F, 0x2A, 0x70, 0x2A, 0x6B, 0x29, 0x6C, 0x28, 0x69, 0x27, 0x66, 0x25, 0x6A, 0x27, 0x69, 0x27, 0x73, 0x30, 0x81, 0x33, 0x7B, 0x35, 0x81, 0x36, 0x78, 0x32, 0x84, 0x3D, 0x97, 0x48, 0x9C, 0x47, 0xA2, 0x48, 0x7C, 0x31, 0x74, 0x2D, 0x6E, 0x2B, 0x74, 0x2C, 0x6B, 0x28, 0x6C, 0x28, 0x6E, 0x2A, 0x6B, 0x28, 0x71, 0x2B, 0x6C, 0x28, 0x65, 0x25, 0x67, 0x27, 0x6D, 0x2A, 0x67, 0x26, 0x6B, 0x28, 0x6E, 0x2A, 0x65, 0x26, 0x65, 0x25, 0x65, 0x26, 0x66, 0x26, 0x65, 0x27, 0x69, 0x28, 0x67, 0x28, 0x64, 0x27, 0x67, 0x29, 0x66, 0x26, 0x66, 0x26, 0x65, 0x27, 0x61, 0x25, 0x62, 0x25, 0x67, 0x26, 0x62, 0x25, 0x63, 0x25, 0x65, 0x26, 0x62, 0x25, 0x61, 0x25, 0x64, 0x27, 0x63, 0x25, 0x62, 0x25, 0x65, 0x27, 0x64, 0x26, 0x65, 0x27, 0x63, 0x28, 0x6C, 0x2C, 0x6C, 0x2A, 0x66, 0x29, 0x6A, 0x2B, 0x6A, 0x2B, 0x6E, 0x2C, 0x6A, 0x2A, 0x6A, 0x2A, 0x6E, 0x2D, 0x63, 0x28, 0x63, 0x27, 0x66, 0x28, 0x65, 0x26, 0x63, 0x26, 0x5B, 0x24, 0x59, 0x21, 0x5B, 0x22, 0x5B, 0x22, 0x5A, 0x21, 0x5F, 0x25, 0x5E, 0x24, 0x5F, 0x24, 0x5C, 0x23, 0x5B, 0x22, 0x5D, 0x23, 0x5C, 0x24, 0x5E, 0x26, 0x5E, 0x25, 0x5E, 0x24, 0x5B, 0x23, 0x57, 0x24, 0x4A, 0x25, 0x42, 0x22, 0x3D, 0x22, 0x46, 0x25, 0x40, 0x22, 0x3E, 0x25, 0x40, 0x36, 0x3B, 0x36, 0x37, 0x31, 0x35, 0x30, 0x2E, 0x29, 0x2B, 0x27, 0x22, 0x1A, 0x23, 0x16, 0x3B, 0x20, 0x32, 0x1C, 0x38, 0x1E, 0x28, 0x19, 0x27, 0x19, 0x2A, 0x1A, 0x2F, 0x1A, 0x2A, 0x19, 0x32, 0x1C, 0x36, 0x1E, 0x40, 0x21, 0x39, 0x1E, 0x3C, 0x20, 0x3A, 0x1F, 0x3C, 0x20, 0x36, 0x1D, 0x3F, 0x21, 0x35, 0x1E, 0x3A, 0x1F, 0x38, 0x1E, 0x37, 0x1E, 0x34, 0x1C, 0x38, 0x1E, 0x34, 0x1D, 0x38, 0x1F, 0x3E, 0x22, 0x40, 0x22, 0x37, 0x1F, 0x39, 0x1E, 0x37, 0x1E, 0x3B, 0x1F, 0x37, 0x1D, 0x38, 0x1F, 0x45, 0x24
    },

    {
        0x68, 0x5C, 0x69, 0x5C, 0x68, 0x5C, 0x69, 0x5D, 0x6B, 0x5E, 0x69, 0x5D, 0x6A, 0x5D, 0x6B, 0x5E, 0x6C, 0x5E, 0x6D, 0x61, 0x72, 0x64, 0x6D, 0x5F, 0x70, 0x60, 0x6E, 0x60, 0x70, 0x62, 0x72, 0x65, 0x74, 0x65, 0x73, 0x64, 0x73, 0x67, 0x74, 0x66, 0x70, 0x63, 0x71, 0x64, 0x71, 0x63, 0x72, 0x63, 0x73, 0x64, 0x71, 0x62, 0x6F, 0x61, 0x72, 0x65, 0x70, 0x62, 0x70, 0x62, 0x72, 0x61, 0x72, 0x61, 0x72, 0x63, 0x73, 0x62, 0x71, 0x60, 0x6F, 0x61, 0x72, 0x62, 0x73, 0x62, 0x73, 0x62, 0x72, 0x63, 0x73, 0x65, 0x75, 0x65, 0x74, 0x66, 0x73, 0x64, 0x75, 0x65, 0x74, 0x66, 0x74, 0x63, 0x70, 0x62, 0x73, 0x63, 0x76, 0x67, 0x7B, 0x6A, 0x7C, 0x6C, 0x7A, 0x6A, 0x79, 0x69, 0x7A, 0x69, 0x7B, 0x69, 0x7C, 0x6B, 0x7B, 0x6A, 0x7C, 0x6B, 0x79, 0x6B, 0x7A, 0x6B, 0x7E, 0x6D, 0x7D, 0x6D, 0x7E, 0x6E, 0x7C, 0x6C, 0x7C, 0x6C, 0x7D, 0x6B, 0x78, 0x69, 0x7B, 0x6C, 0x7A, 0x6B, 0x7B, 0x6D, 0x7D, 0x6F, 0x7B, 0x6D, 0x7A, 0x6E, 0x77, 0x6B, 0x6C, 0x60, 0x52, 0x45, 0x45, 0x44, 0x59, 0x5A, 0x6E, 0x67, 0x71, 0x6A, 0x6A, 0x60, 0x69, 0x61, 0x73, 0x6A, 0x70, 0x68, 0x58, 0x4E, 0x3F, 0x3D, 0x5C, 0x5C, 0x72, 0x68, 0x78, 0x6D, 0x81, 0x77, 0x83, 0x75, 0x84, 0x79, 0x86, 0x78, 0x7D, 0x6D, 0x7E, 0x70, 0x7C, 0x6F, 0x80, 0x74, 0x82, 0x73, 0x7E, 0x71, 0x7F, 0x73, 0x80, 0x73, 0x83, 0x78, 0x87, 0x7A, 0x85, 0x79, 0x86, 0x7B, 0x89, 0x81, 0x8E, 0x83, 0x8B, 0x82, 0x87, 0x7E, 0x87, 0x7F, 0x8D, 0x83, 0x90, 0x8B, 0x94, 0x8B, 0x8F, 0x85, 0x8D, 0x84, 0x85, 0x77, 0x86, 0x7E, 0x8F, 0x8B, 0x96, 0x8C, 0xA3, 0xA2, 0x90, 0x86, 0x89, 0x7E, 0x89, 0x80, 0x8B, 0x86, 0x96, 0x93, 0x96, 0x91, 0x94, 0x8A, 0x8B, 0x83, 0x86, 0x80, 0x86, 0x80, 0x82, 0x7B, 0x8A, 0x81, 0x89, 0x82, 0x98, 0x8D, 0x8C, 0x86, 0x8F, 0x8B, 0x90, 0x8B, 0x9E, 0x9F, 0x9A, 0x93, 0x93, 0x88, 0x8A, 0x7E, 0x93, 0x92, 0x98, 0x92, 0x9B, 0x96, 0x9F, 0x9F, 0xA4, 0xA2, 0x9A, 0x95, 0x95, 0x8C, 0x89, 0x7D, 0x89, 0x80, 0x8F, 0x7E, 0x82, 0x74, 0x8A, 0x81, 0x8B, 0x82, 0x93, 0x91, 0x9C, 0x97, 0x9D, 0x98, 0x98, 0x92, 0x91, 0x86, 0x8B, 0x82, 0x86, 0x7C, 0x87, 0x79, 0x8A, 0x82, 0x8E, 0x8D, 0x6F, 0x71, 0x63, 0x67, 0x60, 0x65, 0x6B, 0x79, 0x6D, 0x7A, 0x5C, 0x5E, 0x5F, 0x64, 0x62, 0x61, 0x7D, 0x74, 0x86, 0x7B, 0x83, 0x76, 0x80, 0x74, 0x7C, 0x72, 0x7C, 0x6E, 0x7B, 0x70, 0x7E, 0x70, 0x7D, 0x72, 0x7F, 0x70, 0x7E, 0x70, 0x7B, 0x6D, 0x77, 0x6C, 0x77, 0x68, 0x7D, 0x6C, 0x7C, 0x6F, 0x84, 0x7B, 0x89, 0x7F, 0x84, 0x7C, 0x85, 0x77, 0x85, 0x76, 0x8A, 0x88, 0x97, 0x94, 0x9C, 0x96, 0xA3, 0x9E, 0x8A, 0x81, 0x85, 0x78, 0x7E, 0x74, 0x83, 0x76, 0x7D, 0x6C, 0x7C, 0x6D, 0x7E, 0x70, 0x7C, 0x6E, 0x82, 0x74, 0x7C, 0x6C, 0x78, 0x6A, 0x7D, 0x6F, 0x7A, 0x6D, 0x7A, 0x6A, 0x7A, 0x6E, 0x7C, 0x6F, 0x78, 0x69, 0x74, 0x66, 0x73, 0x69, 0x72, 0x68, 0x75, 0x6A, 0x78, 0x6C, 0x77, 0x6A, 0x75, 0x68, 0x76, 0x6C, 0x77, 0x6A, 0x76, 0x67, 0x74, 0x66, 0x72, 0x65, 0x71, 0x67, 0x72, 0x66, 0x71, 0x64, 0x72, 0x65, 0x75, 0x69, 0x73, 0x65, 0x72, 0x64, 0x73, 0x67, 0x72, 0x66, 0x71, 0x67, 0x71, 0x68, 0x72, 0x67, 0x74, 0x69, 0x73, 0x6A, 0x7A, 0x71, 0x78, 0x6C, 0x74, 0x68, 0x78, 0x6D, 0x79, 0x6E, 0x7A, 0x71, 0x78, 0x6C, 0x77, 0x6F, 0x79, 0x72, 0x72, 0x66, 0x71, 0x67, 0x73, 0x69, 0x74, 0x66, 0x6E, 0x63, 0x69, 0x5E, 0x69, 0x5E, 0x6C, 0x5E, 0x6B, 0x5D, 0x6D, 0x5E, 0x6D, 0x62, 0x6C, 0x62, 0x6F, 0x63, 0x6B, 0x5F, 0x6A, 0x5D, 0x69, 0x5E, 0x66, 0x5F, 0x6A, 0x62, 0x6B, 0x60, 0x6C, 0x62, 0x6A, 0x60, 0x5E, 0x55, 0x47, 0x4D, 0x3B, 0x3E, 0x38, 0x43, 0x3D, 0x45, 0x36, 0x3B, 0x37, 0x3C, 0x39, 0x3B, 0x32, 0x36, 0x2D, 0x30, 0x2A, 0x2E, 0x27, 0x2A, 0x24, 0x27, 0x1E, 0x20, 0x23, 0x29, 0x35, 0x41, 0x31, 0x36, 0x37, 0x3C, 0x2A, 0x2C, 0x2A, 0x2E, 0x2B, 0x31, 0x31, 0x38, 0x2A, 0x2F, 0x33, 0x3D, 0x32, 0x3A, 0x39, 0x42, 0x33, 0x39, 0x35, 0x3E, 0x33, 0x39, 0x34, 0x3C, 0x30, 0x35, 0x39, 0x40, 0x31, 0x37, 0x35, 0x3C, 0x30, 0x34, 0x33, 0x3A, 0x30, 0x34, 0x33, 0x3C, 0x30, 0x35, 0x36, 0x3E, 0x3A, 0x43, 0x38, 0x3D, 0x32, 0x3A, 0x35, 0x3C, 0x37, 0x3D, 0x36, 0x3C, 0x32, 0x38, 0x34, 0x3E, 0x3F, 0x46
    },

    {
        0x5D, 0x21, 0x5B, 0x20, 0x5B, 0x20, 0x5C, 0x20, 0x5E, 0x20, 0x5A, 0x20, 0x5B, 0x20, 0x5B, 0x21, 0x5C, 0x21, 0x5F, 0x21, 0x5F, 0x22, 0x60, 0x22, 0x60, 0x22, 0x5E, 0x22, 0x62, 0x24, 0x67, 0x27, 0x64, 0x25, 0x64, 0x27, 0x66, 0x28, 0x66, 0x26, 0x66, 0x26, 0x66, 0x26, 0x63, 0x25, 0x60, 0x25, 0x64, 0x25, 0x62, 0x25, 0x62, 0x25, 0x61, 0x23, 0x62, 0x24, 0x62, 0x24, 0x61, 0x23, 0x61, 0x22, 0x5D, 0x22, 0x60, 0x23, 0x61, 0x23, 0x5F, 0x23, 0x61, 0x24, 0x62, 0x24, 0x62, 0x24, 0x63, 0x24, 0x63, 0x24, 0x61, 0x24, 0x63, 0x24, 0x61, 0x24, 0x63, 0x24, 0x63, 0x24, 0x63, 0x24, 0x64, 0x24, 0x62, 0x24, 0x64, 0x24, 0x68, 0x26, 0x68, 0x26, 0x67, 0x26, 0x66, 0x26, 0x66, 0x25, 0x66, 0x26, 0x66, 0x26, 0x68, 0x27, 0x6A, 0x2B, 0x78, 0x34, 0x74, 0x2D, 0x6F, 0x29, 0x6A, 0x27, 0x69, 0x27, 0x6B, 0x28, 0x6D, 0x28, 0x6F, 0x29, 0x6D, 0x28, 0x6D, 0x28, 0x68, 0x26, 0x68, 0x27, 0x69, 0x27, 0x68, 0x27, 0x6A, 0x28, 0x6B, 0x29, 0x69, 0x28, 0x64, 0x26, 0x4A, 0x20, 0x3D, 0x20, 0x57, 0x25, 0x64, 0x27, 0x69, 0x28, 0x67, 0x28, 0x68, 0x28, 0x5C, 0x26, 0x3D, 0x1F, 0x4D, 0x24, 0x68, 0x29, 0x6C, 0x29, 0x6F, 0x2A, 0x71, 0x2B, 0x72, 0x2A, 0x74, 0x2D, 0x74, 0x2B, 0x6D, 0x2A, 0x6F, 0x2A, 0x6F, 0x2B, 0x6D, 0x2B, 0x6F, 0x2B, 0x71, 0x2C, 0x73, 0x2D, 0x77, 0x30, 0x79, 0x30, 0x7F, 0x34, 0x77, 0x2F, 0x7B, 0x32, 0x80, 0x35, 0x7E, 0x34, 0x7C, 0x32, 0x7E, 0x33, 0x83, 0x38, 0x8C, 0x3A, 0x8B, 0x3F, 0x80, 0x34, 0x7A, 0x33, 0x8C, 0x3C, 0x7A, 0x32, 0x87, 0x3B, 0x96, 0x46, 0xA4, 0x4C, 0x91, 0x40, 0x93, 0x40, 0x83, 0x38, 0x83, 0x38, 0x94, 0x41, 0x98, 0x45, 0x93, 0x42, 0x8E, 0x3E, 0x91, 0x3F, 0x8B, 0x3C, 0x82, 0x37, 0x7C, 0x33, 0x7B, 0x33, 0x83, 0x3B, 0x95, 0x44, 0x8F, 0x40, 0x8F, 0x40, 0x91, 0x44, 0xA6, 0x4B, 0xAE, 0x56, 0xA3, 0x4A, 0x8F, 0x3C, 0x89, 0x3D, 0x91, 0x3F, 0x83, 0x37, 0x8D, 0x3F, 0x96, 0x46, 0x98, 0x46, 0xA9, 0x55, 0xA8, 0x48, 0x86, 0x38, 0x8C, 0x3C, 0x8B, 0x39, 0x77, 0x31, 0x7D, 0x36, 0x8C, 0x3F, 0x9E, 0x48, 0x9F, 0x4A, 0x8E, 0x3F, 0x8E, 0x40, 0x98, 0x47, 0x8B, 0x3B, 0x78, 0x31, 0x73, 0x2E, 0x87, 0x3F, 0x74, 0x3D, 0x6A, 0x38, 0x65, 0x39, 0x79, 0x42, 0x8B, 0x4D, 0x6A, 0x36, 0x56, 0x2B, 0x4A, 0x23, 0x69, 0x2B, 0x77, 0x32, 0x79, 0x30, 0x72, 0x2B, 0x6F, 0x2A, 0x6D, 0x29, 0x6E, 0x2A, 0x6E, 0x2A, 0x6E, 0x2A, 0x68, 0x27, 0x6B, 0x29, 0x69, 0x28, 0x6A, 0x28, 0x67, 0x27, 0x68, 0x26, 0x69, 0x28, 0x6C, 0x29, 0x7B, 0x35, 0x80, 0x35, 0x74, 0x2F, 0x95, 0x42, 0x87, 0x3B, 0x7D, 0x34, 0x7B, 0x36, 0x97, 0x44, 0x80, 0x36, 0x7D, 0x31, 0x75, 0x2F, 0x6F, 0x29, 0x6A, 0x27, 0x6A, 0x28, 0x6D, 0x29, 0x6C, 0x28, 0x70, 0x2B, 0x6C, 0x28, 0x68, 0x26, 0x73, 0x32, 0x72, 0x2E, 0x6B, 0x28, 0x69, 0x27, 0x6A, 0x28, 0x69, 0x27, 0x69, 0x27, 0x63, 0x24, 0x63, 0x25, 0x68, 0x28, 0x6A, 0x28, 0x68, 0x27, 0x69, 0x27, 0x69, 0x29, 0x66, 0x27, 0x6B, 0x2B, 0x75, 0x30, 0x6A, 0x2A, 0x63, 0x26, 0x64, 0x26, 0x62, 0x25, 0x67, 0x26, 0x67, 0x27, 0x65, 0x27, 0x62, 0x26, 0x61, 0x25, 0x62, 0x26, 0x63, 0x25, 0x61, 0x24, 0x67, 0x28, 0x67, 0x28, 0x6B, 0x2B, 0x69, 0x28, 0x6A, 0x28, 0x6A, 0x29, 0x6C, 0x2B, 0x70, 0x2F, 0x76, 0x32, 0x70, 0x2E, 0x69, 0x2B, 0x6E, 0x2E, 0x69, 0x29, 0x65, 0x28, 0x66, 0x29, 0x63, 0x26, 0x5E, 0x25, 0x5F, 0x25, 0x5C, 0x23, 0x5E, 0x24, 0x5D, 0x24, 0x5E, 0x23, 0x5D, 0x23, 0x5A, 0x23, 0x5C, 0x23, 0x5C, 0x23, 0x5D, 0x24, 0x5A, 0x23, 0x5D, 0x24, 0x5E, 0x24, 0x5D, 0x24, 0x5E, 0x24, 0x5E, 0x24, 0x56, 0x24, 0x47, 0x23, 0x36, 0x1E, 0x39, 0x20, 0x3C, 0x20, 0x32, 0x1C, 0x3D, 0x21, 0x32, 0x1B, 0x28, 0x18, 0x27, 0x18, 0x2E, 0x1A, 0x32, 0x1D, 0x35, 0x1E, 0x36, 0x1E, 0x35, 0x1E, 0x46, 0x25, 0x40, 0x22, 0x43, 0x23, 0x38, 0x1D, 0x3F, 0x23, 0x38, 0x1F, 0x43, 0x23, 0x36, 0x1D, 0x41, 0x22, 0x30, 0x1B, 0x3C, 0x20, 0x31, 0x1B, 0x36, 0x1D, 0x2F, 0x1B, 0x36, 0x1E, 0x33, 0x1C, 0x38, 0x1E, 0x32, 0x1C, 0x3B, 0x20, 0x39, 0x1E, 0x40, 0x22, 0x3C, 0x20, 0x3F, 0x21, 0x3E, 0x21, 0x3F, 0x21, 0x3D, 0x22, 0x3E, 0x21, 0x36, 0x1D, 0x47, 0x25, 0x40, 0x22, 0x36, 0x1D, 0x39, 0x1E, 0x3E, 0x22, 0x3C, 0x1F
    },

    {
        0x6B, 0x5D, 0x69, 0x5C, 0x68, 0x5D, 0x6C, 0x5E, 0x6D, 0x5E, 0x6A, 0x5D, 0x6C, 0x5D, 0x6B, 0x5D, 0x6C, 0x5E, 0x6F, 0x60, 0x71, 0x61, 0x71, 0x63, 0x71, 0x62, 0x6E, 0x5F, 0x72, 0x65, 0x77, 0x6B, 0x73, 0x65, 0x73, 0x66, 0x73, 0x67, 0x74, 0x67, 0x74, 0x67, 0x73, 0x66, 0x72, 0x62, 0x72, 0x64, 0x74, 0x66, 0x75, 0x66, 0x73, 0x63, 0x73, 0x62, 0x74, 0x64, 0x74, 0x64, 0x73, 0x63, 0x72, 0x61, 0x6F, 0x5F, 0x70, 0x62, 0x73, 0x62, 0x71, 0x61, 0x73, 0x62, 0x73, 0x62, 0x73, 0x65, 0x73, 0x65, 0x74, 0x66, 0x73, 0x65, 0x74, 0x64, 0x72, 0x62, 0x76, 0x65, 0x75, 0x66, 0x75, 0x66, 0x72, 0x65, 0x71, 0x63, 0x75, 0x66, 0x79, 0x68, 0x79, 0x68, 0x79, 0x6A, 0x78, 0x69, 0x78, 0x67, 0x78, 0x69, 0x79, 0x68, 0x7A, 0x6C, 0x7D, 0x74, 0x86, 0x7F, 0x81, 0x71, 0x7C, 0x6E, 0x7B, 0x6A, 0x7C, 0x6A, 0x7D, 0x6D, 0x7F, 0x6E, 0x81, 0x71, 0x7F, 0x6F, 0x7E, 0x6F, 0x7B, 0x6C, 0x7D, 0x70, 0x7B, 0x6C, 0x79, 0x6C, 0x79, 0x6B, 0x7A, 0x6E, 0x7A, 0x6D, 0x75, 0x68, 0x5E, 0x4E, 0x43, 0x3F, 0x54, 0x55, 0x6C, 0x64, 0x73, 0x69, 0x73, 0x68, 0x71, 0x67, 0x5A, 0x50, 0x3F, 0x3C, 0x5B, 0x5B, 0x78, 0x6E, 0x7A, 0x6E, 0x7C, 0x71, 0x80, 0x74, 0x83, 0x73, 0x84, 0x75, 0x83, 0x73, 0x7E, 0x6F, 0x7F, 0x72, 0x7E, 0x71, 0x7F, 0x72, 0x81, 0x73, 0x82, 0x77, 0x81, 0x72, 0x83, 0x79, 0x81, 0x77, 0x8A, 0x80, 0x86, 0x79, 0x86, 0x7B, 0x8C, 0x81, 0x8B, 0x81, 0x88, 0x7E, 0x8A, 0x80, 0x8D, 0x88, 0x98, 0x95, 0x92, 0x8C, 0x8B, 0x7C, 0x89, 0x80, 0x94, 0x8C, 0x89, 0x7E, 0x94, 0x90, 0x9D, 0xA2, 0x9F, 0x9D, 0x91, 0x8C, 0x9B, 0x99, 0x8F, 0x87, 0x91, 0x8E, 0x9B, 0x95, 0xA2, 0xA0, 0x97, 0x90, 0x98, 0x90, 0x9B, 0x99, 0x93, 0x8E, 0x8B, 0x84, 0x86, 0x80, 0x87, 0x7D, 0x8C, 0x84, 0x97, 0x90, 0x9B, 0x98, 0x9C, 0x97, 0x9A, 0x98, 0x9E, 0x9C, 0xA5, 0xAD, 0xA3, 0xA2, 0x9A, 0x94, 0x91, 0x88, 0x93, 0x91, 0x91, 0x84, 0x96, 0x91, 0x97, 0x8F, 0x99, 0x9C, 0xA8, 0xB1, 0xA6, 0xA1, 0x8A, 0x82, 0x92, 0x8E, 0x97, 0x91, 0x8A, 0x80, 0x86, 0x80, 0x96, 0x94, 0xA3, 0xA2, 0xA2, 0xA6, 0x95, 0x8C, 0x92, 0x8A, 0x99, 0x9B, 0x96, 0x8E, 0x88, 0x7C, 0x83, 0x75, 0x8B, 0x8A, 0x6E, 0x74, 0x66, 0x69, 0x63, 0x72, 0x6B, 0x74, 0x74, 0x85, 0x64, 0x6C, 0x56, 0x59, 0x4F, 0x4E, 0x6F, 0x6B, 0x82, 0x7E, 0x84, 0x7A, 0x81, 0x73, 0x80, 0x72, 0x80, 0x70, 0x7E, 0x71, 0x7E, 0x71, 0x7E, 0x70, 0x7A, 0x6B, 0x7D, 0x70, 0x7C, 0x6D, 0x7C, 0x6E, 0x76, 0x68, 0x7B, 0x6C, 0x76, 0x6B, 0x7C, 0x71, 0x84, 0x7C, 0x88, 0x7F, 0x87, 0x7B, 0x9C, 0x99, 0x94, 0x8B, 0x8F, 0x84, 0x87, 0x80, 0xA0, 0x9C, 0x92, 0x85, 0x8A, 0x7A, 0x82, 0x76, 0x7E, 0x70, 0x7D, 0x6C, 0x7E, 0x70, 0x7E, 0x70, 0x7B, 0x6F, 0x7F, 0x72, 0x7D, 0x6D, 0x78, 0x6B, 0x80, 0x7A, 0x80, 0x75, 0x7B, 0x6C, 0x7C, 0x6A, 0x7B, 0x6D, 0x78, 0x6B, 0x7D, 0x6C, 0x72, 0x63, 0x73, 0x67, 0x7A, 0x6C, 0x79, 0x6B, 0x77, 0x6B, 0x79, 0x6C, 0x79, 0x6C, 0x78, 0x6A, 0x7A, 0x70, 0x7D, 0x73, 0x77, 0x6B, 0x72, 0x66, 0x72, 0x65, 0x73, 0x65, 0x76, 0x68, 0x79, 0x6B, 0x75, 0x68, 0x71, 0x65, 0x71, 0x65, 0x6F, 0x65, 0x72, 0x65, 0x6F, 0x65, 0x76, 0x6A, 0x76, 0x6A, 0x7A, 0x71, 0x78, 0x6C, 0x79, 0x6C, 0x78, 0x6D, 0x79, 0x6F, 0x7B, 0x72, 0x7F, 0x78, 0x79, 0x72, 0x76, 0x6D, 0x77, 0x6E, 0x74, 0x6A, 0x71, 0x65, 0x72, 0x69, 0x71, 0x64, 0x6D, 0x62, 0x6D, 0x63, 0x6C, 0x61, 0x6F, 0x61, 0x6D, 0x63, 0x6D, 0x60, 0x6C, 0x5F, 0x69, 0x5C, 0x69, 0x5E, 0x6A, 0x60, 0x6B, 0x61, 0x6A, 0x60, 0x6C, 0x61, 0x6B, 0x61, 0x6B, 0x5F, 0x6B, 0x62, 0x6C, 0x61, 0x5F, 0x56, 0x43, 0x44, 0x34, 0x38, 0x36, 0x3E, 0x39, 0x3F, 0x30, 0x35, 0x3B, 0x43, 0x32, 0x34, 0x2A, 0x2F, 0x28, 0x2C, 0x30, 0x38, 0x32, 0x38, 0x35, 0x3E, 0x35, 0x3D, 0x30, 0x38, 0x3E, 0x48, 0x37, 0x3F, 0x3A, 0x41, 0x32, 0x36, 0x37, 0x3F, 0x31, 0x38, 0x39, 0x40, 0x2F, 0x36, 0x36, 0x3C, 0x2D, 0x34, 0x35, 0x3A, 0x30, 0x35, 0x31, 0x34, 0x2D, 0x32, 0x33, 0x39, 0x30, 0x37, 0x33, 0x38, 0x2F, 0x33, 0x38, 0x40, 0x38, 0x42, 0x3A, 0x43, 0x37, 0x3D, 0x39, 0x43, 0x3A, 0x40, 0x38, 0x3F, 0x37, 0x3E, 0x37, 0x3E, 0x32, 0x3A, 0x3F, 0x48, 0x35, 0x3A, 0x32, 0x3A, 0x32, 0x36, 0x38, 0x41, 0x33, 0x37
    },

    {
        0x5C, 0x21, 0x5B, 0x21, 0x5B, 0x20, 0x5A, 0x20, 0x5C, 0x20, 0x5D, 0x20, 0x5C, 0x20, 0x5C, 0x21, 0x5C, 0x21, 0x5C, 0x22, 0x5F, 0x23, 0x61, 0x23, 0x63, 0x24, 0x65, 0x24, 0x64, 0x25, 0x63, 0x26, 0x62, 0x26, 0x63, 0x25, 0x63, 0x25, 0x61, 0x24, 0x61, 0x24, 0x61, 0x23, 0x5F, 0x23, 0x61, 0x23, 0x63, 0x24, 0x65, 0x25, 0x64, 0x25, 0x62, 0x24, 0x63, 0x24, 0x62, 0x24, 0x63, 0x24, 0x61, 0x24, 0x5F, 0x23, 0x62, 0x23, 0x62, 0x24, 0x62, 0x24, 0x60, 0x23, 0x63, 0x25, 0x66, 0x25, 0x64, 0x25, 0x64, 0x25, 0x65, 0x25, 0x63, 0x25, 0x62, 0x24, 0x64, 0x24, 0x66, 0x24, 0x66, 0x25, 0x62, 0x24, 0x63, 0x24, 0x64, 0x25, 0x66, 0x25, 0x66, 0x25, 0x65, 0x25, 0x64, 0x24, 0x66, 0x24, 0x64, 0x24, 0x66, 0x25, 0x6A, 0x2C, 0x7E, 0x36, 0x6F, 0x2B, 0x66, 0x28, 0x68, 0x28, 0x68, 0x26, 0x67, 0x26, 0x65, 0x25, 0x65, 0x25, 0x66, 0x26, 0x69, 0x27, 0x6B, 0x27, 0x6B, 0x27, 0x6E, 0x28, 0x6E, 0x28, 0x6A, 0x27, 0x6C, 0x28, 0x6F, 0x2A, 0x6A, 0x27, 0x6B, 0x27, 0x66, 0x25, 0x4F, 0x21, 0x3D, 0x1F, 0x4D, 0x22, 0x60, 0x26, 0x65, 0x28, 0x5B, 0x25, 0x39, 0x1E, 0x4A, 0x24, 0x6A, 0x29, 0x6E, 0x2A, 0x6D, 0x28, 0x6D, 0x29, 0x73, 0x2E, 0x73, 0x2C, 0x76, 0x2E, 0x72, 0x2A, 0x6D, 0x2A, 0x6E, 0x2A, 0x70, 0x2B, 0x73, 0x2E, 0x73, 0x2E, 0x75, 0x2E, 0x70, 0x2B, 0x75, 0x2E, 0x75, 0x2F, 0x78, 0x31, 0x79, 0x31, 0x77, 0x31, 0x7C, 0x34, 0x7B, 0x30, 0x77, 0x32, 0x7F, 0x35, 0x87, 0x3D, 0x95, 0x41, 0x85, 0x39, 0x79, 0x30, 0x8C, 0x44, 0x90, 0x39, 0x7C, 0x36, 0x97, 0x48, 0xBB, 0x5E, 0x9A, 0x45, 0xA8, 0x4E, 0x97, 0x46, 0x9C, 0x48, 0xBB, 0x5E, 0xAC, 0x4F, 0xA5, 0x4E, 0xA6, 0x4B, 0xA7, 0x4D, 0x95, 0x42, 0x9A, 0x45, 0x86, 0x3B, 0x8B, 0x3D, 0x80, 0x35, 0x85, 0x3B, 0x97, 0x43, 0x9D, 0x49, 0x9A, 0x47, 0xA2, 0x4F, 0xB0, 0x52, 0x91, 0x41, 0x99, 0x46, 0x91, 0x42, 0x98, 0x41, 0x7D, 0x36, 0x83, 0x3B, 0x94, 0x41, 0x8C, 0x3D, 0x99, 0x46, 0x90, 0x40, 0xA0, 0x48, 0x8B, 0x3B, 0x7A, 0x34, 0x94, 0x45, 0x8D, 0x40, 0x83, 0x37, 0x8F, 0x3E, 0x8D, 0x3E, 0x8A, 0x3B, 0x8D, 0x3C, 0x7A, 0x35, 0x89, 0x3A, 0x87, 0x37, 0x80, 0x35, 0x71, 0x2D, 0x75, 0x33, 0x70, 0x39, 0x64, 0x33, 0x6B, 0x44, 0x87, 0x48, 0x73, 0x3E, 0x73, 0x3E, 0x6B, 0x36, 0x4C, 0x28, 0x62, 0x2A, 0x7A, 0x33, 0x78, 0x2F, 0x74, 0x2C, 0x6F, 0x2B, 0x6F, 0x2B, 0x6D, 0x28, 0x6D, 0x2B, 0x6E, 0x2A, 0x70, 0x2B, 0x6D, 0x2A, 0x6D, 0x29, 0x6B, 0x28, 0x69, 0x29, 0x6D, 0x29, 0x66, 0x29, 0x6E, 0x2B, 0x73, 0x2F, 0x86, 0x3E, 0xA8, 0x4D, 0x8D, 0x3E, 0x92, 0x46, 0xA7, 0x51, 0x8A, 0x3B, 0x9D, 0x4B, 0x92, 0x3D, 0x7A, 0x2E, 0x71, 0x2D, 0x73, 0x2F, 0x6C, 0x28, 0x6A, 0x29, 0x6B, 0x29, 0x6C, 0x28, 0x6E, 0x2A, 0x6E, 0x29, 0x6F, 0x2A, 0x6D, 0x29, 0x6E, 0x2B, 0x6F, 0x29, 0x6B, 0x26, 0x6A, 0x27, 0x69, 0x27, 0x6D, 0x29, 0x68, 0x27, 0x65, 0x26, 0x67, 0x26, 0x64, 0x25, 0x64, 0x25, 0x68, 0x28, 0x67, 0x27, 0x67, 0x29, 0x68, 0x28, 0x69, 0x2A, 0x6B, 0x2A, 0x62, 0x25, 0x5F, 0x25, 0x63, 0x25, 0x64, 0x25, 0x64, 0x25, 0x63, 0x27, 0x62, 0x26, 0x6E, 0x2D, 0x68, 0x28, 0x61, 0x26, 0x65, 0x26, 0x62, 0x25, 0x6A, 0x2A, 0x71, 0x2F, 0x6E, 0x2C, 0x68, 0x2A, 0x6E, 0x2E, 0x71, 0x31, 0x77, 0x34, 0x74, 0x31, 0x77, 0x33, 0x70, 0x2D, 0x65, 0x28, 0x6C, 0x2C, 0x65, 0x27, 0x66, 0x27, 0x63, 0x27, 0x66, 0x28, 0x64, 0x27, 0x61, 0x25, 0x5E, 0x25, 0x5F, 0x24, 0x5C, 0x23, 0x5D, 0x23, 0x5D, 0x23, 0x5C, 0x24, 0x5F, 0x25, 0x5F, 0x26, 0x5C, 0x23, 0x5E, 0x24, 0x5D, 0x24, 0x60, 0x25, 0x5D, 0x25, 0x60, 0x25, 0x55, 0x23, 0x47, 0x24, 0x43, 0x23, 0x48, 0x25, 0x48, 0x25, 0x38, 0x1F, 0x4B, 0x27, 0x41, 0x22, 0x42, 0x23, 0x3A, 0x1F, 0x46, 0x25, 0x38, 0x1E, 0x3E, 0x21, 0x34, 0x1D, 0x33, 0x1D, 0x3C, 0x20, 0x31, 0x1B, 0x34, 0x1C, 0x34, 0x1E, 0x39, 0x1F, 0x35, 0x1E, 0x3E, 0x21, 0x3B, 0x1F, 0x35, 0x1C, 0x37, 0x1E, 0x3B, 0x1F, 0x47, 0x25, 0x44, 0x24, 0x3C, 0x20, 0x48, 0x24, 0x3B, 0x1F, 0x3F, 0x20, 0x34, 0x1D, 0x44, 0x23, 0x3D, 0x21, 0x3C, 0x20, 0x35, 0x1D, 0x40, 0x22, 0x3A, 0x1F, 0x33, 0x1C, 0x39, 0x1E, 0x37, 0x1D, 0x33, 0x1D, 0x3D, 0x21, 0x35, 0x1C, 0x39, 0x1F, 0x3B, 0x1F, 0x3C, 0x1F, 0x38, 0x1E
    },

    {
        0x6B, 0x5F, 0x6A, 0x5D, 0x69, 0x5C, 0x6B, 0x5C, 0x6D, 0x5F, 0x6D, 0x5E, 0x6B, 0x5D, 0x6C, 0x5D, 0x6D, 0x5E, 0x6D, 0x5F, 0x70, 0x62, 0x71, 0x63, 0x75, 0x66, 0x76, 0x68, 0x76, 0x66, 0x72, 0x64, 0x71, 0x64, 0x73, 0x65, 0x74, 0x64, 0x70, 0x62, 0x70, 0x63, 0x70, 0x62, 0x6F, 0x5F, 0x72, 0x63, 0x74, 0x65, 0x77, 0x66, 0x75, 0x64, 0x71, 0x63, 0x73, 0x63, 0x73, 0x65, 0x75, 0x65, 0x74, 0x65, 0x72, 0x62, 0x72, 0x62, 0x73, 0x64, 0x75, 0x64, 0x73, 0x64, 0x75, 0x65, 0x76, 0x67, 0x74, 0x65, 0x74, 0x66, 0x75, 0x67, 0x75, 0x66, 0x76, 0x65, 0x76, 0x65, 0x78, 0x68, 0x78, 0x68, 0x74, 0x66, 0x75, 0x66, 0x76, 0x66, 0x7A, 0x68, 0x77, 0x65, 0x76, 0x67, 0x78, 0x68, 0x79, 0x68, 0x78, 0x66, 0x79, 0x67, 0x78, 0x6E, 0x83, 0x7A, 0x7B, 0x6A, 0x78, 0x69, 0x79, 0x6A, 0x7A, 0x6A, 0x7B, 0x6A, 0x7A, 0x68, 0x78, 0x67, 0x77, 0x67, 0x7A, 0x6A, 0x7C, 0x6B, 0x7D, 0x6E, 0x80, 0x6F, 0x80, 0x6F, 0x7B, 0x6C, 0x7D, 0x6F, 0x80, 0x71, 0x7B, 0x6C, 0x7D, 0x6D, 0x76, 0x68, 0x65, 0x53, 0x46, 0x3E, 0x4A, 0x4B, 0x65, 0x61, 0x70, 0x67, 0x5D, 0x4E, 0x3D, 0x38, 0x57, 0x5A, 0x77, 0x6C, 0x7B, 0x70, 0x7D, 0x70, 0x7C, 0x70, 0x82, 0x77, 0x85, 0x73, 0x87, 0x7A, 0x83, 0x72, 0x81, 0x72, 0x80, 0x71, 0x82, 0x74, 0x7F, 0x73, 0x81, 0x77, 0x81, 0x75, 0x80, 0x73, 0x85, 0x78, 0x85, 0x7A, 0x87, 0x7A, 0x87, 0x7C, 0x84, 0x7B, 0x86, 0x7C, 0x86, 0x79, 0x86, 0x7C, 0x8D, 0x85, 0x93, 0x93, 0x94, 0x89, 0x8C, 0x84, 0x89, 0x7A, 0x95, 0x99, 0x98, 0x88, 0x89, 0x81, 0x98, 0x97, 0xAC, 0xB8, 0xA1, 0x99, 0xA3, 0xA3, 0x9A, 0x9A, 0xA1, 0xA1, 0xB5, 0xC2, 0xB4, 0xB1, 0xA9, 0xA6, 0xA6, 0xA2, 0xA5, 0xA7, 0x99, 0x93, 0x9B, 0x9A, 0x92, 0x8A, 0x95, 0x91, 0x8D, 0x86, 0x92, 0x90, 0xA2, 0x9E, 0xA2, 0x9B, 0x9A, 0x96, 0xA3, 0xAA, 0xAE, 0xAF, 0x99, 0x90, 0x9B, 0x9B, 0x98, 0x95, 0x95, 0x8F, 0x8A, 0x80, 0x91, 0x8E, 0x9E, 0x9C, 0x96, 0x90, 0x9E, 0x99, 0x99, 0x8F, 0xA3, 0xA5, 0x95, 0x8B, 0x87, 0x7F, 0x93, 0x90, 0x8F, 0x8C, 0x90, 0x89, 0x90, 0x88, 0x8F, 0x88, 0x90, 0x87, 0x96, 0x8D, 0x88, 0x7E, 0x93, 0x87, 0x8F, 0x85, 0x8B, 0x82, 0x81, 0x73, 0x7C, 0x70, 0x69, 0x6F, 0x63, 0x67, 0x64, 0x73, 0x7B, 0x8C, 0x67, 0x6E, 0x65, 0x71, 0x5D, 0x63, 0x48, 0x4C, 0x6B, 0x67, 0x81, 0x7A, 0x84, 0x79, 0x85, 0x78, 0x7E, 0x72, 0x7D, 0x71, 0x7D, 0x70, 0x7D, 0x75, 0x7F, 0x73, 0x7C, 0x6F, 0x7F, 0x72, 0x80, 0x71, 0x7D, 0x6D, 0x7A, 0x6D, 0x78, 0x6C, 0x76, 0x6C, 0x7F, 0x71, 0x83, 0x7B, 0x91, 0x91, 0xA8, 0xAC, 0x97, 0x8C, 0x8F, 0x8B, 0xA1, 0xAB, 0x90, 0x86, 0x96, 0x92, 0x96, 0x8E, 0x87, 0x79, 0x83, 0x75, 0x80, 0x76, 0x77, 0x6C, 0x7C, 0x6E, 0x7D, 0x6E, 0x7F, 0x6F, 0x7E, 0x71, 0x7A, 0x6D, 0x80, 0x73, 0x80, 0x70, 0x7D, 0x70, 0x7F, 0x72, 0x7E, 0x6E, 0x7C, 0x6D, 0x7E, 0x6E, 0x7C, 0x6E, 0x78, 0x6A, 0x74, 0x68, 0x76, 0x6A, 0x77, 0x68, 0x74, 0x67, 0x76, 0x6B, 0x75, 0x69, 0x77, 0x6E, 0x75, 0x6B, 0x77, 0x6B, 0x79, 0x6D, 0x71, 0x65, 0x70, 0x63, 0x75, 0x68, 0x76, 0x67, 0x77, 0x68, 0x71, 0x67, 0x73, 0x68, 0x79, 0x6E, 0x7B, 0x6E, 0x74, 0x68, 0x76, 0x68, 0x73, 0x68, 0x78, 0x6B, 0x7B, 0x74, 0x7A, 0x71, 0x78, 0x6D, 0x7C, 0x74, 0x7D, 0x74, 0x82, 0x7D, 0x7C, 0x73, 0x7C, 0x7A, 0x7C, 0x70, 0x72, 0x69, 0x79, 0x6E, 0x73, 0x67, 0x74, 0x69, 0x72, 0x68, 0x75, 0x6B, 0x70, 0x65, 0x6D, 0x63, 0x6D, 0x62, 0x6E, 0x62, 0x6C, 0x60, 0x6E, 0x60, 0x6D, 0x60, 0x6D, 0x60, 0x6D, 0x62, 0x6E, 0x66, 0x6E, 0x62, 0x6F, 0x61, 0x6B, 0x61, 0x6E, 0x62, 0x6C, 0x60, 0x6D, 0x64, 0x5D, 0x54, 0x48, 0x4D, 0x3C, 0x42, 0x41, 0x4B, 0x3E, 0x43, 0x35, 0x3B, 0x44, 0x4E, 0x38, 0x3E, 0x39, 0x40, 0x33, 0x3A, 0x3B, 0x41, 0x31, 0x39, 0x35, 0x3A, 0x2F, 0x33, 0x31, 0x37, 0x35, 0x3A, 0x2D, 0x35, 0x2F, 0x35, 0x32, 0x3A, 0x36, 0x3C, 0x33, 0x39, 0x39, 0x40, 0x38, 0x40, 0x35, 0x3B, 0x35, 0x3C, 0x38, 0x3D, 0x3F, 0x49, 0x3E, 0x46, 0x36, 0x3D, 0x42, 0x49, 0x35, 0x3B, 0x37, 0x3D, 0x31, 0x38, 0x3C, 0x43, 0x34, 0x39, 0x35, 0x3B, 0x2F, 0x34, 0x3A, 0x42, 0x33, 0x37, 0x2F, 0x33, 0x33, 0x3C, 0x31, 0x36, 0x2F, 0x36, 0x38, 0x40, 0x33, 0x36, 0x36, 0x3F, 0x38, 0x3E, 0x38, 0x3F, 0x33, 0x39
    },

    {
        0x5D, 0x21, 0x5C, 0x21, 0x5D, 0x21, 0x5C, 0x20, 0x5D, 0x21, 0x5C, 0x20, 0x5C, 0x21, 0x5E, 0x21, 0x60, 0x22, 0x5F, 0x23, 0x60, 0x23, 0x5F, 0x23, 0x63, 0x24, 0x65, 0x24, 0x5F, 0x23, 0x5F, 0x24, 0x62, 0x23, 0x60, 0x23, 0x61, 0x24, 0x61, 0x23, 0x61, 0x23, 0x62, 0x24, 0x62, 0x24, 0x62, 0x25, 0x64, 0x24, 0x62, 0x24, 0x64, 0x24, 0x61, 0x23, 0x62, 0x24, 0x63, 0x24, 0x63, 0x24, 0x63, 0x24, 0x64, 0x25, 0x62, 0x24, 0x65, 0x24, 0x64, 0x24, 0x62, 0x24, 0x63, 0x24, 0x65, 0x25, 0x63, 0x24, 0x63, 0x24, 0x64, 0x25, 0x64, 0x25, 0x63, 0x25, 0x63, 0x24, 0x66, 0x25, 0x65, 0x25, 0x68, 0x26, 0x64, 0x24, 0x63, 0x24, 0x64, 0x24, 0x64, 0x24, 0x64, 0x24, 0x65, 0x24, 0x65, 0x24, 0x64, 0x24, 0x66, 0x25, 0x69, 0x2A, 0x6B, 0x27, 0x67, 0x26, 0x67, 0x25, 0x66, 0x25, 0x68, 0x24, 0x68, 0x25, 0x67, 0x25, 0x69, 0x26, 0x67, 0x26, 0x69, 0x26, 0x69, 0x26, 0x6C, 0x27, 0x68, 0x26, 0x69, 0x27, 0x6B, 0x27, 0x6E, 0x29, 0x71, 0x2A, 0x6C, 0x28, 0x6C, 0x28, 0x6A, 0x28, 0x66, 0x27, 0x56, 0x22, 0x3D, 0x1D, 0x45, 0x22, 0x53, 0x24, 0x38, 0x1E, 0x4B, 0x24, 0x67, 0x2B, 0x70, 0x2B, 0x71, 0x2B, 0x71, 0x2B, 0x70, 0x2B, 0x75, 0x2E, 0x73, 0x2C, 0x71, 0x2C, 0x72, 0x2A, 0x6E, 0x2A, 0x6E, 0x2A, 0x73, 0x2C, 0x71, 0x2C, 0x74, 0x2E, 0x75, 0x2D, 0x70, 0x2C, 0x76, 0x2E, 0x74, 0x2F, 0x7B, 0x32, 0x7A, 0x31, 0x75, 0x2F, 0x7A, 0x31, 0x79, 0x30, 0x7F, 0x36, 0x8A, 0x3A, 0x8E, 0x3E, 0x80, 0x35, 0x78, 0x31, 0x7F, 0x36, 0x86, 0x39, 0x7E, 0x34, 0x94, 0x46, 0xA3, 0x4B, 0x90, 0x43, 0x97, 0x46, 0x99, 0x44, 0xA5, 0x4E, 0xAC, 0x52, 0xC3, 0x64, 0xD7, 0x6A, 0xB1, 0x4E, 0xA3, 0x4F, 0xA0, 0x49, 0x9F, 0x46, 0x89, 0x40, 0xA0, 0x4C, 0x97, 0x41, 0x8A, 0x3C, 0x99, 0x49, 0x9D, 0x47, 0x9C, 0x4B, 0xA7, 0x4F, 0xAA, 0x54, 0xBD, 0x5D, 0xB7, 0x56, 0xA7, 0x4D, 0xA0, 0x4B, 0x85, 0x38, 0x87, 0x39, 0x86, 0x3B, 0x96, 0x48, 0x91, 0x41, 0xAD, 0x53, 0xA9, 0x4B, 0xB3, 0x59, 0x98, 0x41, 0x90, 0x3C, 0x8F, 0x3F, 0x82, 0x36, 0x85, 0x37, 0x76, 0x30, 0x7A, 0x32, 0x8A, 0x3F, 0xA2, 0x47, 0x7F, 0x35, 0x8D, 0x3D, 0x80, 0x35, 0x80, 0x34, 0x7F, 0x34, 0x76, 0x30, 0x65, 0x34, 0x66, 0x33, 0x5E, 0x33, 0x78, 0x46, 0x7C, 0x41, 0x66, 0x33, 0x47, 0x27, 0x4E, 0x29, 0x64, 0x29, 0x77, 0x31, 0x77, 0x2F, 0x75, 0x2D, 0x71, 0x2B, 0x6D, 0x2A, 0x6B, 0x28, 0x69, 0x29, 0x6E, 0x2A, 0x66, 0x26, 0x69, 0x27, 0x68, 0x27, 0x69, 0x27, 0x66, 0x27, 0x65, 0x26, 0x66, 0x26, 0x6A, 0x2B, 0x7A, 0x32, 0x78, 0x2F, 0x7C, 0x36, 0x86, 0x38, 0x79, 0x30, 0x71, 0x32, 0x82, 0x37, 0x72, 0x2D, 0x78, 0x33, 0x6F, 0x2A, 0x72, 0x2E, 0x6D, 0x29, 0x6A, 0x2A, 0x6D, 0x29, 0x6B, 0x28, 0x65, 0x27, 0x6D, 0x29, 0x6D, 0x29, 0x6E, 0x29, 0x6A, 0x27, 0x6A, 0x28, 0x69, 0x28, 0x6C, 0x29, 0x6B, 0x27, 0x6A, 0x27, 0x66, 0x26, 0x67, 0x26, 0x64, 0x24, 0x61, 0x25, 0x66, 0x27, 0x65, 0x25, 0x64, 0x26, 0x68, 0x27, 0x6A, 0x28, 0x67, 0x28, 0x68, 0x28, 0x65, 0x27, 0x64, 0x26, 0x61, 0x25, 0x65, 0x27, 0x69, 0x29, 0x63, 0x26, 0x69, 0x2A, 0x67, 0x28, 0x65, 0x28, 0x6C, 0x2B, 0x63, 0x25, 0x5F, 0x24, 0x61, 0x25, 0x65, 0x27, 0x67, 0x27, 0x65, 0x29, 0x71, 0x2F, 0x72, 0x2F, 0x78, 0x36, 0x89, 0x3D, 0x7E, 0x36, 0x72, 0x2F, 0x6D, 0x2C, 0x66, 0x2A, 0x6B, 0x2B, 0x68, 0x2B, 0x63, 0x28, 0x66, 0x29, 0x68, 0x28, 0x62, 0x26, 0x61, 0x25, 0x5D, 0x23, 0x61, 0x24, 0x60, 0x24, 0x5E, 0x23, 0x5E, 0x23, 0x5E, 0x24, 0x5F, 0x26, 0x67, 0x29, 0x61, 0x27, 0x61, 0x26, 0x62, 0x26, 0x63, 0x27, 0x64, 0x27, 0x63, 0x27, 0x5A, 0x26, 0x53, 0x29, 0x36, 0x1D, 0x43, 0x23, 0x39, 0x20, 0x33, 0x1D, 0x40, 0x21, 0x37, 0x1F, 0x38, 0x1E, 0x38, 0x1F, 0x38, 0x1F, 0x36, 0x1E, 0x3F, 0x21, 0x41, 0x22, 0x43, 0x22, 0x3B, 0x1E, 0x39, 0x1F, 0x44, 0x24, 0x47, 0x25, 0x48, 0x25, 0x3C, 0x21, 0x49, 0x25, 0x42, 0x24, 0x43, 0x23, 0x3C, 0x20, 0x44, 0x23, 0x3B, 0x1F, 0x42, 0x22, 0x37, 0x1F, 0x40, 0x21, 0x31, 0x1B, 0x38, 0x1E, 0x37, 0x1E, 0x3B, 0x20, 0x33, 0x1C, 0x40, 0x21, 0x3A, 0x20, 0x41, 0x22, 0x40, 0x22, 0x39, 0x1E, 0x3A, 0x20, 0x3E, 0x20, 0x3B, 0x21, 0x49, 0x26, 0x3E, 0x21, 0x3D, 0x21, 0x3C, 0x20, 0x3D, 0x21, 0x36, 0x1E
    },

    {
        0x6B, 0x5F, 0x6C, 0x5F, 0x6C, 0x60, 0x6B, 0x5E, 0x6B, 0x5E, 0x6C, 0x5E, 0x6D, 0x60, 0x6E, 0x61, 0x70, 0x62, 0x6F, 0x60, 0x70, 0x61, 0x6F, 0x62, 0x72, 0x65, 0x74, 0x65, 0x6F, 0x5F, 0x6F, 0x61, 0x71, 0x63, 0x70, 0x62, 0x72, 0x63, 0x71, 0x62, 0x71, 0x62, 0x73, 0x65, 0x74, 0x64, 0x70, 0x64, 0x73, 0x64, 0x73, 0x65, 0x76, 0x66, 0x73, 0x65, 0x74, 0x64, 0x75, 0x65, 0x75, 0x65, 0x75, 0x66, 0x76, 0x68, 0x75, 0x66, 0x75, 0x66, 0x72, 0x65, 0x75, 0x65, 0x75, 0x65, 0x77, 0x67, 0x74, 0x64, 0x73, 0x63, 0x73, 0x66, 0x74, 0x66, 0x73, 0x65, 0x74, 0x67, 0x77, 0x67, 0x75, 0x67, 0x79, 0x69, 0x78, 0x68, 0x76, 0x65, 0x75, 0x65, 0x76, 0x65, 0x75, 0x65, 0x76, 0x68, 0x79, 0x68, 0x77, 0x68, 0x78, 0x68, 0x78, 0x6C, 0x7C, 0x6A, 0x7A, 0x69, 0x7B, 0x6A, 0x78, 0x69, 0x79, 0x69, 0x7B, 0x68, 0x7B, 0x6A, 0x7D, 0x6C, 0x79, 0x6A, 0x7B, 0x6C, 0x7C, 0x6C, 0x7E, 0x6D, 0x78, 0x67, 0x79, 0x6B, 0x7D, 0x6D, 0x81, 0x72, 0x81, 0x71, 0x7C, 0x6E, 0x7E, 0x6F, 0x7B, 0x6C, 0x78, 0x6B, 0x69, 0x5B, 0x4B, 0x3F, 0x43, 0x45, 0x50, 0x4B, 0x3B, 0x38, 0x5A, 0x5A, 0x73, 0x6E, 0x7B, 0x74, 0x80, 0x75, 0x84, 0x75, 0x85, 0x75, 0x85, 0x77, 0x83, 0x75, 0x82, 0x73, 0x81, 0x72, 0x81, 0x71, 0x80, 0x72, 0x81, 0x76, 0x7F, 0x73, 0x81, 0x78, 0x83, 0x76, 0x81, 0x75, 0x86, 0x76, 0x82, 0x78, 0x88, 0x7E, 0x8A, 0x7E, 0x87, 0x79, 0x87, 0x7D, 0x89, 0x7F, 0x87, 0x7E, 0x90, 0x87, 0x93, 0x89, 0x88, 0x7F, 0x85, 0x77, 0x8C, 0x86, 0x8E, 0x81, 0x89, 0x80, 0x9C, 0x9C, 0xA1, 0xA0, 0x96, 0x93, 0x9B, 0x98, 0x9E, 0x9B, 0xA4, 0xA4, 0xAC, 0xAE, 0xBD, 0xCE, 0xC1, 0xCA, 0xAB, 0xA9, 0xA4, 0xA5, 0xA0, 0x99, 0x9F, 0x99, 0x91, 0x8F, 0xA3, 0xA8, 0x99, 0x92, 0x94, 0x8C, 0x9B, 0x9B, 0xA2, 0x9D, 0xA4, 0xA3, 0xAA, 0xAB, 0xAE, 0xB5, 0xB5, 0xB7, 0xB3, 0xB9, 0xAA, 0xA6, 0xA5, 0xA4, 0x93, 0x8A, 0x93, 0x8B, 0x90, 0x85, 0x91, 0x8E, 0x96, 0x90, 0xA3, 0xA9, 0xAE, 0xAA, 0xB1, 0xBB, 0xA5, 0x98, 0x98, 0x92, 0x9A, 0x96, 0x8E, 0x82, 0x91, 0x8A, 0x85, 0x78, 0x89, 0x7E, 0x90, 0x8B, 0xA4, 0xA5, 0x8D, 0x81, 0x97, 0x8F, 0x8E, 0x82, 0x90, 0x80, 0x8F, 0x88, 0x85, 0x7B, 0x6C, 0x6B, 0x62, 0x65, 0x5D, 0x64, 0x6D, 0x7E, 0x74, 0x82, 0x5B, 0x60, 0x3D, 0x40, 0x51, 0x5C, 0x6C, 0x6A, 0x80, 0x7B, 0x84, 0x7A, 0x82, 0x77, 0x7F, 0x71, 0x7C, 0x70, 0x7D, 0x6D, 0x79, 0x6D, 0x7C, 0x6F, 0x77, 0x68, 0x78, 0x69, 0x79, 0x6C, 0x78, 0x6A, 0x74, 0x68, 0x74, 0x67, 0x77, 0x69, 0x7B, 0x72, 0x81, 0x78, 0x82, 0x75, 0x83, 0x75, 0x8B, 0x80, 0x88, 0x7C, 0x80, 0x75, 0x88, 0x7C, 0x81, 0x74, 0x80, 0x77, 0x7E, 0x70, 0x84, 0x7C, 0x7A, 0x6F, 0x7A, 0x71, 0x7E, 0x70, 0x79, 0x6C, 0x79, 0x6A, 0x80, 0x73, 0x80, 0x71, 0x7E, 0x6D, 0x7A, 0x6D, 0x7A, 0x6B, 0x77, 0x6B, 0x79, 0x6C, 0x7A, 0x6C, 0x7C, 0x6C, 0x7A, 0x6C, 0x7B, 0x6C, 0x72, 0x66, 0x70, 0x65, 0x78, 0x6A, 0x74, 0x66, 0x75, 0x69, 0x79, 0x6A, 0x78, 0x6D, 0x7A, 0x6C, 0x76, 0x6B, 0x75, 0x68, 0x75, 0x6A, 0x75, 0x66, 0x72, 0x66, 0x76, 0x6A, 0x70, 0x65, 0x75, 0x6B, 0x75, 0x69, 0x75, 0x69, 0x75, 0x6C, 0x74, 0x66, 0x6F, 0x63, 0x72, 0x66, 0x74, 0x68, 0x75, 0x67, 0x72, 0x69, 0x7E, 0x74, 0x83, 0x7A, 0x84, 0x81, 0x90, 0x8D, 0x84, 0x81, 0x7A, 0x72, 0x78, 0x6E, 0x75, 0x6C, 0x76, 0x6D, 0x76, 0x6B, 0x6F, 0x64, 0x75, 0x6A, 0x76, 0x68, 0x70, 0x65, 0x70, 0x66, 0x6D, 0x60, 0x71, 0x65, 0x70, 0x63, 0x71, 0x63, 0x6D, 0x60, 0x6B, 0x5F, 0x6D, 0x64, 0x73, 0x69, 0x70, 0x64, 0x71, 0x67, 0x71, 0x65, 0x71, 0x65, 0x73, 0x67, 0x72, 0x67, 0x62, 0x5C, 0x4E, 0x51, 0x34, 0x37, 0x3D, 0x46, 0x33, 0x36, 0x2F, 0x38, 0x39, 0x3D, 0x32, 0x39, 0x34, 0x3A, 0x36, 0x3E, 0x35, 0x3B, 0x32, 0x39, 0x3C, 0x45, 0x41, 0x4B, 0x3D, 0x42, 0x37, 0x3F, 0x37, 0x3F, 0x40, 0x49, 0x3E, 0x47, 0x3F, 0x46, 0x37, 0x41, 0x41, 0x48, 0x37, 0x3F, 0x3A, 0x41, 0x36, 0x3E, 0x3C, 0x43, 0x34, 0x38, 0x3C, 0x42, 0x32, 0x3A, 0x35, 0x39, 0x2E, 0x34, 0x35, 0x38, 0x33, 0x39, 0x36, 0x3C, 0x31, 0x39, 0x3C, 0x43, 0x37, 0x3E, 0x3B, 0x43, 0x3B, 0x43, 0x35, 0x3A, 0x35, 0x3E, 0x39, 0x3F, 0x37, 0x42, 0x40, 0x48, 0x34, 0x39, 0x37, 0x40, 0x33, 0x38, 0x36, 0x3D, 0x30, 0x36
    },

    {
        0x5D, 0x21, 0x5D, 0x21, 0x5F, 0x22, 0x5F, 0x21, 0x5F, 0x21, 0x5F, 0x21, 0x5F, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x5C, 0x22, 0x5F, 0x23, 0x61, 0x24, 0x64, 0x24, 0x62, 0x24, 0x62, 0x25, 0x64, 0x26, 0x65, 0x25, 0x63, 0x24, 0x62, 0x24, 0x61, 0x24, 0x62, 0x24, 0x64, 0x24, 0x64, 0x25, 0x63, 0x25, 0x66, 0x25, 0x64, 0x25, 0x65, 0x27, 0x67, 0x27, 0x64, 0x25, 0x65, 0x26, 0x65, 0x25, 0x64, 0x25, 0x64, 0x25, 0x62, 0x25, 0x67, 0x27, 0x66, 0x26, 0x66, 0x25, 0x65, 0x25, 0x62, 0x25, 0x61, 0x24, 0x63, 0x24, 0x65, 0x25, 0x64, 0x26, 0x66, 0x26, 0x65, 0x25, 0x64, 0x25, 0x63, 0x25, 0x67, 0x26, 0x66, 0x25, 0x66, 0x26, 0x65, 0x25, 0x65, 0x25, 0x68, 0x26, 0x68, 0x26, 0x67, 0x25, 0x63, 0x24, 0x66, 0x25, 0x68, 0x25, 0x67, 0x26, 0x6A, 0x27, 0x67, 0x26, 0x64, 0x25, 0x66, 0x25, 0x67, 0x25, 0x68, 0x25, 0x68, 0x25, 0x66, 0x26, 0x69, 0x27, 0x6B, 0x27, 0x6B, 0x27, 0x69, 0x27, 0x6C, 0x27, 0x6D, 0x27, 0x6B, 0x28, 0x6D, 0x29, 0x6B, 0x27, 0x6C, 0x29, 0x6E, 0x29, 0x6F, 0x2A, 0x68, 0x27, 0x5E, 0x24, 0x40, 0x1F, 0x33, 0x1C, 0x43, 0x20, 0x64, 0x29, 0x6B, 0x2A, 0x72, 0x2D, 0x74, 0x2C, 0x6E, 0x2A, 0x71, 0x2B, 0x71, 0x2C, 0x73, 0x2C, 0x72, 0x2B, 0x6B, 0x28, 0x72, 0x2C, 0x75, 0x2F, 0x74, 0x2D, 0x77, 0x30, 0x7D, 0x31, 0x76, 0x2E, 0x75, 0x2D, 0x75, 0x2F, 0x76, 0x30, 0x7A, 0x33, 0x7A, 0x33, 0x76, 0x2E, 0x78, 0x31, 0x7D, 0x34, 0x7B, 0x35, 0x82, 0x35, 0x81, 0x37, 0x83, 0x39, 0x89, 0x3B, 0x84, 0x3A, 0x84, 0x37, 0x81, 0x37, 0x80, 0x3B, 0x8F, 0x41, 0x97, 0x45, 0x91, 0x42, 0xA4, 0x4F, 0xB0, 0x58, 0xBA, 0x57, 0xAF, 0x54, 0x99, 0x47, 0xB3, 0x57, 0x9E, 0x4A, 0xA3, 0x4A, 0x97, 0x48, 0x9A, 0x4C, 0xA9, 0x50, 0x9C, 0x45, 0x97, 0x45, 0x9C, 0x4E, 0xBA, 0x56, 0xAD, 0x55, 0xB0, 0x58, 0xC5, 0x61, 0xA8, 0x4A, 0x9D, 0x4A, 0xA3, 0x4B, 0x8B, 0x3E, 0x92, 0x43, 0x96, 0x47, 0x95, 0x3E, 0x83, 0x36, 0x9A, 0x48, 0x9C, 0x4A, 0xAB, 0x56, 0xA7, 0x50, 0x92, 0x41, 0x91, 0x40, 0x91, 0x42, 0x8C, 0x39, 0x9D, 0x4C, 0x8F, 0x3B, 0x87, 0x37, 0x7B, 0x32, 0x8A, 0x3F, 0x86, 0x36, 0x8A, 0x3D, 0x89, 0x39, 0x7D, 0x33, 0x97, 0x45, 0x85, 0x3C, 0x76, 0x35, 0x58, 0x2B, 0x5B, 0x31, 0x69, 0x3E, 0x86, 0x4D, 0x54, 0x2B, 0x32, 0x1D, 0x4F, 0x27, 0x6A, 0x2A, 0x6B, 0x2A, 0x7C, 0x33, 0x73, 0x2B, 0x6D, 0x2B, 0x74, 0x2E, 0x6A, 0x28, 0x69, 0x27, 0x69, 0x29, 0x68, 0x27, 0x67, 0x26, 0x68, 0x27, 0x65, 0x26, 0x64, 0x29, 0x6A, 0x2A, 0x65, 0x29, 0x6C, 0x29, 0x6B, 0x2B, 0x77, 0x31, 0x81, 0x35, 0x87, 0x3E, 0xA5, 0x49, 0x85, 0x39, 0x82, 0x3A, 0x89, 0x39, 0x78, 0x31, 0x7A, 0x31, 0x79, 0x32, 0x6C, 0x29, 0x6A, 0x2A, 0x6E, 0x2A, 0x6F, 0x2A, 0x6B, 0x28, 0x6C, 0x2C, 0x6E, 0x28, 0x68, 0x27, 0x68, 0x28, 0x69, 0x27, 0x66, 0x26, 0x68, 0x26, 0x68, 0x27, 0x69, 0x28, 0x6A, 0x28, 0x6A, 0x27, 0x61, 0x25, 0x5F, 0x24, 0x62, 0x25, 0x67, 0x26, 0x64, 0x26, 0x67, 0x26, 0x67, 0x28, 0x6B, 0x29, 0x68, 0x28, 0x6A, 0x29, 0x6B, 0x28, 0x66, 0x27, 0x67, 0x27, 0x64, 0x26, 0x64, 0x25, 0x65, 0x28, 0x6B, 0x29, 0x6B, 0x29, 0x65, 0x27, 0x63, 0x26, 0x68, 0x2A, 0x66, 0x27, 0x65, 0x27, 0x69, 0x29, 0x6B, 0x2B, 0x72, 0x30, 0x79, 0x35, 0x79, 0x38, 0x83, 0x39, 0x7C, 0x37, 0x7B, 0x36, 0x77, 0x32, 0x6C, 0x2B, 0x67, 0x2A, 0x67, 0x29, 0x62, 0x28, 0x67, 0x2A, 0x72, 0x31, 0x6E, 0x2B, 0x65, 0x28, 0x62, 0x27, 0x5D, 0x24, 0x62, 0x26, 0x5D, 0x23, 0x5E, 0x25, 0x5F, 0x24, 0x5F, 0x25, 0x63, 0x28, 0x62, 0x27, 0x64, 0x28, 0x63, 0x29, 0x6C, 0x2C, 0x68, 0x29, 0x67, 0x2A, 0x60, 0x29, 0x4D, 0x27, 0x3B, 0x21, 0x44, 0x24, 0x41, 0x23, 0x46, 0x24, 0x3D, 0x20, 0x39, 0x20, 0x49, 0x27, 0x46, 0x23, 0x43, 0x23, 0x36, 0x20, 0x4F, 0x28, 0x40, 0x21, 0x34, 0x1D, 0x41, 0x22, 0x3B, 0x21, 0x46, 0x24, 0x36, 0x1E, 0x38, 0x1E, 0x37, 0x1F, 0x3A, 0x1F, 0x36, 0x1E, 0x3B, 0x1F, 0x35, 0x1D, 0x3C, 0x21, 0x34, 0x1E, 0x40, 0x22, 0x3B, 0x20, 0x3B, 0x20, 0x3B, 0x21, 0x42, 0x23, 0x35, 0x1E, 0x47, 0x25, 0x40, 0x23, 0x43, 0x24, 0x36, 0x1E, 0x3C, 0x20, 0x34, 0x1D, 0x35, 0x1D, 0x3E, 0x21, 0x3E, 0x21, 0x3B, 0x21, 0x3C, 0x21, 0x33, 0x1C, 0x3C, 0x20, 0x39, 0x1E, 0x3A, 0x1F, 0x3A, 0x21
    },

    {
        0x6C, 0x5F, 0x6C, 0x5F, 0x6E, 0x62, 0x6C, 0x60, 0x6F, 0x61, 0x6F, 0x61, 0x6E, 0x61, 0x6D, 0x5F, 0x6E, 0x61, 0x6B, 0x5E, 0x6F, 0x61, 0x6E, 0x62, 0x72, 0x64, 0x71, 0x63, 0x70, 0x66, 0x74, 0x68, 0x76, 0x67, 0x74, 0x64, 0x70, 0x64, 0x71, 0x64, 0x72, 0x64, 0x74, 0x64, 0x75, 0x66, 0x75, 0x67, 0x77, 0x68, 0x77, 0x67, 0x76, 0x67, 0x76, 0x68, 0x77, 0x66, 0x76, 0x67, 0x75, 0x67, 0x74, 0x65, 0x73, 0x65, 0x73, 0x66, 0x77, 0x68, 0x77, 0x67, 0x79, 0x69, 0x77, 0x67, 0x75, 0x65, 0x75, 0x65, 0x75, 0x66, 0x75, 0x67, 0x74, 0x67, 0x76, 0x69, 0x76, 0x68, 0x77, 0x66, 0x73, 0x66, 0x76, 0x68, 0x77, 0x69, 0x79, 0x69, 0x78, 0x68, 0x78, 0x69, 0x78, 0x6A, 0x77, 0x69, 0x77, 0x66, 0x77, 0x66, 0x79, 0x69, 0x7C, 0x69, 0x7C, 0x6B, 0x7A, 0x6C, 0x78, 0x68, 0x77, 0x68, 0x7A, 0x68, 0x7A, 0x69, 0x79, 0x6A, 0x7A, 0x69, 0x79, 0x6A, 0x7E, 0x6E, 0x7E, 0x70, 0x7D, 0x6D, 0x7C, 0x6C, 0x7F, 0x6F, 0x81, 0x70, 0x7E, 0x6F, 0x81, 0x71, 0x7E, 0x6F, 0x7D, 0x6D, 0x7F, 0x72, 0x7F, 0x71, 0x7B, 0x6C, 0x6E, 0x61, 0x51, 0x44, 0x3B, 0x37, 0x53, 0x53, 0x71, 0x6B, 0x7B, 0x6F, 0x80, 0x76, 0x82, 0x74, 0x7D, 0x70, 0x83, 0x73, 0x82, 0x75, 0x83, 0x74, 0x83, 0x71, 0x7C, 0x6E, 0x86, 0x77, 0x85, 0x78, 0x83, 0x77, 0x84, 0x7B, 0x88, 0x7C, 0x83, 0x79, 0x85, 0x76, 0x85, 0x79, 0x84, 0x7A, 0x86, 0x7D, 0x87, 0x7C, 0x84, 0x77, 0x87, 0x7D, 0x8A, 0x7F, 0x8A, 0x81, 0x8D, 0x82, 0x8E, 0x86, 0x95, 0x8F, 0x95, 0x8F, 0x8F, 0x86, 0x8C, 0x83, 0x8E, 0x85, 0x8A, 0x84, 0x9A, 0x96, 0x9A, 0x93, 0x99, 0x94, 0xA5, 0xA7, 0xAE, 0xBC, 0xB5, 0xB9, 0xA9, 0xAF, 0xA0, 0x9D, 0xAC, 0xAC, 0x9E, 0x9C, 0xA8, 0xA4, 0x9F, 0x9F, 0xA0, 0xA7, 0xB0, 0xB0, 0xA5, 0xA1, 0xA1, 0xA2, 0xA4, 0xAA, 0xB8, 0xB9, 0xAE, 0xB3, 0xB4, 0xBC, 0xB9, 0xBD, 0xAD, 0xA9, 0xA6, 0xA1, 0xA2, 0x9D, 0x90, 0x87, 0x95, 0x8E, 0x99, 0x96, 0x97, 0x92, 0x91, 0x8A, 0x9F, 0xA6, 0xA5, 0xA0, 0xA3, 0xA4, 0xA3, 0xA2, 0x94, 0x8F, 0x96, 0x93, 0x94, 0x91, 0x94, 0x89, 0x9B, 0xA0, 0x9B, 0x95, 0x91, 0x86, 0x88, 0x7F, 0x96, 0x8F, 0x91, 0x85, 0x93, 0x8E, 0x93, 0x89, 0x8E, 0x80, 0x9C, 0x9B, 0x90, 0x89, 0x79, 0x70, 0x57, 0x52, 0x54, 0x5A, 0x5B, 0x68, 0x68, 0x79, 0x46, 0x49, 0x37, 0x39, 0x5A, 0x5B, 0x77, 0x6D, 0x7B, 0x70, 0x85, 0x79, 0x83, 0x75, 0x7F, 0x73, 0x85, 0x78, 0x79, 0x6A, 0x7B, 0x6D, 0x7A, 0x6D, 0x7A, 0x6A, 0x79, 0x69, 0x77, 0x6C, 0x74, 0x69, 0x73, 0x69, 0x73, 0x6C, 0x6C, 0x65, 0x76, 0x6F, 0x7A, 0x72, 0x82, 0x7C, 0x8E, 0x86, 0x93, 0x92, 0xA3, 0xA2, 0x91, 0x8F, 0x90, 0x8A, 0x91, 0x86, 0x84, 0x7E, 0x84, 0x7B, 0x82, 0x79, 0x7B, 0x6C, 0x7B, 0x6E, 0x7D, 0x6F, 0x80, 0x72, 0x7F, 0x70, 0x7D, 0x70, 0x7D, 0x70, 0x78, 0x6B, 0x78, 0x6C, 0x7B, 0x6F, 0x76, 0x69, 0x7A, 0x6D, 0x7B, 0x6D, 0x7A, 0x6D, 0x7E, 0x70, 0x7A, 0x6B, 0x6F, 0x63, 0x72, 0x63, 0x77, 0x68, 0x79, 0x6C, 0x75, 0x67, 0x77, 0x69, 0x76, 0x6A, 0x7A, 0x6D, 0x74, 0x6A, 0x79, 0x6D, 0x7D, 0x6E, 0x76, 0x6B, 0x78, 0x69, 0x75, 0x67, 0x74, 0x65, 0x75, 0x6A, 0x7B, 0x6E, 0x79, 0x6E, 0x76, 0x6A, 0x72, 0x67, 0x73, 0x6B, 0x76, 0x68, 0x71, 0x67, 0x77, 0x6B, 0x79, 0x71, 0x7C, 0x74, 0x7D, 0x76, 0x7E, 0x7A, 0x82, 0x7A, 0x84, 0x80, 0x84, 0x7F, 0x7E, 0x76, 0x7B, 0x6E, 0x74, 0x68, 0x73, 0x68, 0x70, 0x65, 0x76, 0x6C, 0x7E, 0x78, 0x77, 0x6B, 0x6E, 0x65, 0x6F, 0x65, 0x6B, 0x61, 0x6E, 0x63, 0x6A, 0x5F, 0x6D, 0x64, 0x6E, 0x62, 0x6E, 0x64, 0x70, 0x64, 0x70, 0x65, 0x72, 0x68, 0x6F, 0x67, 0x77, 0x6E, 0x75, 0x6C, 0x75, 0x69, 0x63, 0x5D, 0x47, 0x4B, 0x36, 0x3C, 0x3F, 0x4A, 0x3E, 0x48, 0x3E, 0x44, 0x38, 0x40, 0x35, 0x3A, 0x43, 0x4D, 0x3B, 0x42, 0x39, 0x40, 0x34, 0x3D, 0x44, 0x4C, 0x36, 0x39, 0x2E, 0x35, 0x3A, 0x3F, 0x38, 0x41, 0x3C, 0x41, 0x30, 0x37, 0x32, 0x35, 0x33, 0x3B, 0x34, 0x3A, 0x30, 0x38, 0x35, 0x3C, 0x34, 0x3B, 0x3A, 0x3F, 0x31, 0x38, 0x3A, 0x42, 0x37, 0x3F, 0x37, 0x3E, 0x38, 0x41, 0x3A, 0x3E, 0x30, 0x38, 0x3E, 0x47, 0x37, 0x3F, 0x3A, 0x41, 0x2F, 0x35, 0x35, 0x3B, 0x30, 0x34, 0x32, 0x39, 0x37, 0x40, 0x34, 0x39, 0x35, 0x3F, 0x37, 0x3B, 0x33, 0x38, 0x39, 0x42, 0x34, 0x3B, 0x37, 0x3F, 0x38, 0x3F
    },

    {
        0x5D, 0x21, 0x5D, 0x21, 0x5E, 0x21, 0x5F, 0x21, 0x60, 0x21, 0x5E, 0x22, 0x5E, 0x22, 0x5E, 0x22, 0x5E, 0x21, 0x5D, 0x21, 0x5E, 0x23, 0x5E, 0x23, 0x5F, 0x22, 0x62, 0x23, 0x63, 0x24, 0x65, 0x26, 0x67, 0x27, 0x65, 0x26, 0x66, 0x27, 0x64, 0x25, 0x61, 0x24, 0x62, 0x23, 0x60, 0x23, 0x62, 0x24, 0x64, 0x25, 0x65, 0x27, 0x66, 0x26, 0x65, 0x25, 0x66, 0x26, 0x65, 0x26, 0x65, 0x25, 0x64, 0x25, 0x65, 0x25, 0x64, 0x25, 0x64, 0x25, 0x64, 0x24, 0x63, 0x25, 0x62, 0x24, 0x62, 0x24, 0x62, 0x24, 0x62, 0x24, 0x64, 0x25, 0x65, 0x25, 0x66, 0x25, 0x65, 0x25, 0x65, 0x24, 0x66, 0x26, 0x66, 0x25, 0x66, 0x24, 0x65, 0x25, 0x66, 0x25, 0x66, 0x26, 0x66, 0x26, 0x65, 0x24, 0x64, 0x24, 0x68, 0x26, 0x67, 0x24, 0x65, 0x25, 0x66, 0x26, 0x67, 0x26, 0x64, 0x25, 0x67, 0x26, 0x69, 0x26, 0x67, 0x25, 0x68, 0x25, 0x66, 0x25, 0x6A, 0x26, 0x6D, 0x27, 0x6B, 0x27, 0x6A, 0x26, 0x6A, 0x27, 0x6C, 0x27, 0x6C, 0x28, 0x6E, 0x28, 0x6B, 0x27, 0x6C, 0x28, 0x6C, 0x29, 0x72, 0x2A, 0x70, 0x29, 0x68, 0x27, 0x69, 0x27, 0x62, 0x25, 0x55, 0x24, 0x63, 0x27, 0x6C, 0x29, 0x6D, 0x2A, 0x6F, 0x2A, 0x71, 0x29, 0x6E, 0x29, 0x6D, 0x29, 0x70, 0x2A, 0x72, 0x2B, 0x73, 0x2C, 0x70, 0x2B, 0x71, 0x2A, 0x72, 0x2C, 0x73, 0x2D, 0x7B, 0x32, 0x80, 0x34, 0x7C, 0x30, 0x76, 0x2F, 0x7C, 0x32, 0x81, 0x34, 0x76, 0x30, 0x76, 0x31, 0x78, 0x30, 0x79, 0x30, 0x78, 0x31, 0x80, 0x36, 0x80, 0x39, 0x96, 0x44, 0xA4, 0x4A, 0x8D, 0x3E, 0x89, 0x41, 0x96, 0x41, 0x99, 0x44, 0x8F, 0x40, 0x96, 0x45, 0x93, 0x40, 0x9C, 0x4F, 0xB4, 0x55, 0xBB, 0x60, 0xBF, 0x5C, 0xAB, 0x58, 0xB9, 0x55, 0x9D, 0x4B, 0xBA, 0x62, 0xAF, 0x51, 0x9F, 0x4C, 0xA0, 0x4C, 0xA1, 0x4E, 0xB0, 0x55, 0xB0, 0x5A, 0xBB, 0x59, 0xB7, 0x5D, 0xB8, 0x5D, 0xBF, 0x63, 0xBD, 0x60, 0xCD, 0x67, 0xB6, 0x52, 0x9F, 0x49, 0x99, 0x48, 0x8D, 0x3C, 0x87, 0x38, 0x8B, 0x40, 0x96, 0x42, 0x85, 0x3E, 0x9C, 0x45, 0x8B, 0x41, 0x87, 0x39, 0x84, 0x3B, 0x8E, 0x41, 0x85, 0x3A, 0x86, 0x3B, 0x90, 0x42, 0x9A, 0x46, 0x94, 0x41, 0x80, 0x34, 0x8A, 0x3D, 0x8F, 0x3E, 0x91, 0x41, 0x8A, 0x3B, 0x85, 0x3A, 0x94, 0x44, 0x90, 0x3F, 0x7B, 0x35, 0x64, 0x2C, 0x50, 0x2A, 0x3F, 0x25, 0x50, 0x2E, 0x52, 0x2F, 0x56, 0x28, 0x64, 0x2A, 0x77, 0x33, 0x7C, 0x31, 0x73, 0x2D, 0x74, 0x2E, 0x71, 0x2C, 0x74, 0x2E, 0x6C, 0x29, 0x6A, 0x29, 0x6D, 0x29, 0x69, 0x27, 0x69, 0x27, 0x65, 0x26, 0x6A, 0x32, 0x72, 0x40, 0x6A, 0x3B, 0x5D, 0x33, 0x55, 0x2C, 0x79, 0x38, 0x8F, 0x41, 0x88, 0x3E, 0x99, 0x45, 0x93, 0x45, 0x8B, 0x3F, 0x89, 0x3A, 0x7B, 0x34, 0x72, 0x2E, 0x6F, 0x2C, 0x6C, 0x2A, 0x6D, 0x2A, 0x69, 0x28, 0x69, 0x27, 0x6A, 0x28, 0x6E, 0x2B, 0x6D, 0x29, 0x6B, 0x29, 0x6C, 0x29, 0x68, 0x27, 0x67, 0x27, 0x67, 0x27, 0x69, 0x29, 0x67, 0x27, 0x69, 0x29, 0x69, 0x28, 0x65, 0x27, 0x64, 0x26, 0x65, 0x26, 0x67, 0x27, 0x65, 0x26, 0x67, 0x27, 0x68, 0x27, 0x67, 0x27, 0x67, 0x26, 0x66, 0x27, 0x67, 0x28, 0x69, 0x28, 0x65, 0x26, 0x67, 0x27, 0x66, 0x25, 0x62, 0x25, 0x5E, 0x25, 0x65, 0x27, 0x65, 0x27, 0x65, 0x27, 0x61, 0x25, 0x63, 0x26, 0x62, 0x25, 0x63, 0x27, 0x67, 0x29, 0x6A, 0x2B, 0x67, 0x2A, 0x69, 0x2B, 0x6B, 0x2B, 0x66, 0x29, 0x72, 0x31, 0x77, 0x31, 0x6F, 0x2D, 0x70, 0x2F, 0x69, 0x29, 0x6C, 0x2C, 0x64, 0x28, 0x63, 0x26, 0x63, 0x27, 0x65, 0x27, 0x5D, 0x24, 0x5E, 0x25, 0x5E, 0x24, 0x59, 0x22, 0x54, 0x22, 0x5D, 0x24, 0x66, 0x29, 0x68, 0x29, 0x5D, 0x24, 0x60, 0x27, 0x64, 0x29, 0x66, 0x29, 0x65, 0x29, 0x64, 0x28, 0x65, 0x28, 0x54, 0x24, 0x49, 0x26, 0x3B, 0x20, 0x4C, 0x29, 0x44, 0x24, 0x32, 0x1C, 0x40, 0x23, 0x37, 0x1F, 0x43, 0x23, 0x34, 0x1E, 0x38, 0x1E, 0x38, 0x1F, 0x3C, 0x20, 0x33, 0x1C, 0x34, 0x1D, 0x40, 0x23, 0x43, 0x23, 0x3E, 0x20, 0x35, 0x1E, 0x40, 0x22, 0x41, 0x23, 0x47, 0x24, 0x37, 0x1F, 0x42, 0x22, 0x3C, 0x21, 0x3E, 0x20, 0x36, 0x1E, 0x44, 0x23, 0x36, 0x1E, 0x37, 0x1D, 0x33, 0x1D, 0x34, 0x1C, 0x36, 0x1D, 0x38, 0x1E, 0x32, 0x1C, 0x31, 0x1C, 0x36, 0x1E, 0x41, 0x23, 0x43, 0x24, 0x3E, 0x21, 0x3E, 0x22, 0x3A, 0x1F, 0x3D, 0x22, 0x47, 0x26, 0x3F, 0x22, 0x40, 0x23, 0x37, 0x1F, 0x44, 0x25, 0x3B, 0x21
    },

    {
        0x6D, 0x5F, 0x6B, 0x5E, 0x6E, 0x60, 0x6F, 0x61, 0x6D, 0x5F, 0x6D, 0x60, 0x6E, 0x60, 0x6E, 0x60, 0x6E, 0x60, 0x6D, 0x5F, 0x6E, 0x5E, 0x6D, 0x60, 0x6F, 0x60, 0x70, 0x62, 0x72, 0x63, 0x74, 0x67, 0x76, 0x68, 0x74, 0x67, 0x72, 0x68, 0x70, 0x64, 0x71, 0x62, 0x73, 0x63, 0x73, 0x63, 0x71, 0x63, 0x75, 0x67, 0x76, 0x69, 0x77, 0x66, 0x76, 0x66, 0x75, 0x66, 0x76, 0x66, 0x75, 0x67, 0x76, 0x67, 0x75, 0x66, 0x75, 0x65, 0x76, 0x66, 0x76, 0x66, 0x75, 0x64, 0x72, 0x64, 0x73, 0x64, 0x73, 0x65, 0x73, 0x65, 0x74, 0x67, 0x76, 0x67, 0x77, 0x68, 0x74, 0x67, 0x77, 0x67, 0x79, 0x67, 0x78, 0x68, 0x76, 0x63, 0x76, 0x67, 0x79, 0x6A, 0x78, 0x68, 0x76, 0x68, 0x79, 0x67, 0x76, 0x66, 0x7B, 0x6B, 0x7A, 0x69, 0x79, 0x69, 0x7A, 0x69, 0x78, 0x67, 0x75, 0x65, 0x79, 0x6B, 0x7B, 0x6B, 0x7C, 0x6B, 0x7C, 0x6A, 0x79, 0x67, 0x7D, 0x6D, 0x7F, 0x6E, 0x7F, 0x6D, 0x7E, 0x6C, 0x7D, 0x6D, 0x7F, 0x6E, 0x7F, 0x6E, 0x81, 0x71, 0x83, 0x6F, 0x7F, 0x6F, 0x7D, 0x6F, 0x81, 0x71, 0x82, 0x72, 0x7B, 0x6A, 0x7A, 0x6C, 0x75, 0x67, 0x6D, 0x61, 0x76, 0x69, 0x7C, 0x70, 0x7E, 0x71, 0x7F, 0x72, 0x81, 0x70, 0x80, 0x70, 0x81, 0x70, 0x83, 0x72, 0x84, 0x76, 0x85, 0x78, 0x80, 0x72, 0x7F, 0x71, 0x82, 0x76, 0x86, 0x77, 0x88, 0x80, 0x8E, 0x84, 0x8A, 0x7B, 0x89, 0x7B, 0x8A, 0x7E, 0x8C, 0x81, 0x84, 0x79, 0x84, 0x7C, 0x89, 0x7C, 0x88, 0x7B, 0x89, 0x7C, 0x8D, 0x83, 0x8F, 0x89, 0x9E, 0x9E, 0xA0, 0x9D, 0x96, 0x91, 0x96, 0x96, 0x9A, 0x94, 0x9E, 0x9D, 0x9A, 0x94, 0x9B, 0x9A, 0xA1, 0x97, 0xA3, 0xA8, 0xB9, 0xB9, 0xB8, 0xBE, 0xB8, 0xBB, 0xA7, 0xAF, 0xB5, 0xB5, 0xA2, 0xA3, 0xB5, 0xC4, 0xB6, 0xB3, 0xA8, 0xA9, 0xA3, 0xA2, 0x99, 0x99, 0xAE, 0xB0, 0xAD, 0xB3, 0xB6, 0xB7, 0xAE, 0xBA, 0xB3, 0xB8, 0xB4, 0xBC, 0xAF, 0xB8, 0xBA, 0xC4, 0xAF, 0xA9, 0xA5, 0xA3, 0x9A, 0x9D, 0x97, 0x8D, 0x90, 0x84, 0x92, 0x8C, 0x99, 0x92, 0x94, 0x8A, 0x9A, 0x94, 0x94, 0x8C, 0x94, 0x8D, 0x91, 0x88, 0x9A, 0x98, 0x92, 0x89, 0x93, 0x8A, 0x96, 0x94, 0x9A, 0x94, 0x9D, 0x95, 0x8E, 0x80, 0x94, 0x90, 0x99, 0x92, 0x97, 0x94, 0x96, 0x8C, 0x90, 0x8B, 0x98, 0x93, 0x95, 0x90, 0x87, 0x7F, 0x6F, 0x64, 0x53, 0x53, 0x40, 0x42, 0x4B, 0x55, 0x55, 0x5E, 0x64, 0x66, 0x74, 0x71, 0x82, 0x7F, 0x89, 0x7F, 0x84, 0x77, 0x83, 0x76, 0x82, 0x77, 0x82, 0x76, 0x7E, 0x6E, 0x7C, 0x6E, 0x7D, 0x6F, 0x7B, 0x6C, 0x7B, 0x6C, 0x76, 0x68, 0x72, 0x75, 0x6E, 0x74, 0x5E, 0x60, 0x57, 0x5A, 0x4F, 0x54, 0x7A, 0x7E, 0x93, 0x95, 0x8B, 0x89, 0x97, 0x92, 0x95, 0x90, 0x8D, 0x89, 0x91, 0x88, 0x82, 0x78, 0x81, 0x71, 0x7C, 0x71, 0x7B, 0x6F, 0x7C, 0x71, 0x7D, 0x6D, 0x7B, 0x6D, 0x7A, 0x6B, 0x7C, 0x6F, 0x7C, 0x70, 0x7B, 0x6E, 0x7C, 0x70, 0x78, 0x6A, 0x79, 0x6B, 0x76, 0x6A, 0x79, 0x6B, 0x78, 0x6A, 0x7A, 0x6E, 0x7C, 0x6C, 0x76, 0x68, 0x77, 0x69, 0x78, 0x67, 0x77, 0x69, 0x77, 0x68, 0x79, 0x6C, 0x7A, 0x6C, 0x79, 0x6C, 0x78, 0x6C, 0x76, 0x69, 0x75, 0x68, 0x77, 0x6C, 0x76, 0x67, 0x78, 0x6A, 0x76, 0x67, 0x73, 0x63, 0x6C, 0x63, 0x76, 0x69, 0x76, 0x68, 0x75, 0x68, 0x70, 0x63, 0x71, 0x67, 0x71, 0x65, 0x73, 0x68, 0x79, 0x6C, 0x79, 0x6F, 0x75, 0x68, 0x78, 0x6B, 0x77, 0x6C, 0x76, 0x6A, 0x7D, 0x73, 0x82, 0x77, 0x7B, 0x73, 0x7B, 0x72, 0x7B, 0x6F, 0x7A, 0x70, 0x72, 0x67, 0x71, 0x65, 0x73, 0x65, 0x72, 0x66, 0x6A, 0x5E, 0x6D, 0x60, 0x6E, 0x62, 0x65, 0x57, 0x64, 0x59, 0x6B, 0x61, 0x73, 0x6B, 0x72, 0x67, 0x6A, 0x5F, 0x6E, 0x62, 0x6F, 0x68, 0x73, 0x69, 0x71, 0x66, 0x6F, 0x65, 0x73, 0x66, 0x5A, 0x50, 0x43, 0x48, 0x36, 0x3A, 0x42, 0x4F, 0x39, 0x3E, 0x2E, 0x32, 0x3A, 0x41, 0x34, 0x3A, 0x3B, 0x40, 0x31, 0x38, 0x33, 0x38, 0x34, 0x3C, 0x37, 0x3E, 0x31, 0x36, 0x31, 0x3A, 0x3D, 0x45, 0x3E, 0x47, 0x38, 0x3E, 0x32, 0x3A, 0x3E, 0x46, 0x3B, 0x45, 0x3D, 0x44, 0x32, 0x3A, 0x3B, 0x40, 0x36, 0x3F, 0x36, 0x3B, 0x31, 0x38, 0x3B, 0x41, 0x31, 0x36, 0x30, 0x33, 0x2E, 0x34, 0x2F, 0x33, 0x34, 0x3A, 0x34, 0x36, 0x31, 0x37, 0x2E, 0x35, 0x33, 0x3B, 0x3D, 0x45, 0x40, 0x4A, 0x37, 0x3D, 0x37, 0x3F, 0x37, 0x3C, 0x3A, 0x44, 0x3F, 0x46, 0x35, 0x3B, 0x39, 0x41, 0x31, 0x38, 0x3B, 0x44, 0x33, 0x39
    },

    {
        0x5B, 0x20, 0x5E, 0x21, 0x61, 0x21, 0x5F, 0x21, 0x60, 0x21, 0x5D, 0x21, 0x5E, 0x21, 0x5E, 0x22, 0x60, 0x22, 0x61, 0x23, 0x60, 0x23, 0x5F, 0x23, 0x5E, 0x21, 0x5B, 0x21, 0x5D, 0x22, 0x61, 0x23, 0x64, 0x24, 0x64, 0x25, 0x63, 0x25, 0x62, 0x25, 0x64, 0x26, 0x66, 0x25, 0x63, 0x25, 0x62, 0x24, 0x62, 0x25, 0x62, 0x24, 0x63, 0x25, 0x65, 0x25, 0x62, 0x24, 0x64, 0x26, 0x66, 0x26, 0x68, 0x26, 0x66, 0x25, 0x61, 0x23, 0x63, 0x25, 0x68, 0x26, 0x63, 0x24, 0x62, 0x25, 0x65, 0x24, 0x63, 0x25, 0x64, 0x24, 0x62, 0x25, 0x67, 0x26, 0x66, 0x25, 0x65, 0x25, 0x67, 0x26, 0x66, 0x26, 0x67, 0x25, 0x64, 0x24, 0x66, 0x24, 0x66, 0x25, 0x65, 0x25, 0x66, 0x26, 0x68, 0x25, 0x66, 0x25, 0x68, 0x26, 0x66, 0x25, 0x65, 0x25, 0x66, 0x25, 0x66, 0x26, 0x6A, 0x28, 0x6D, 0x28, 0x6A, 0x25, 0x66, 0x25, 0x67, 0x24, 0x68, 0x26, 0x69, 0x26, 0x6B, 0x27, 0x68, 0x26, 0x67, 0x25, 0x6A, 0x27, 0x6A, 0x27, 0x6B, 0x28, 0x6B, 0x28, 0x6E, 0x29, 0x6D, 0x28, 0x6F, 0x29, 0x6E, 0x28, 0x6D, 0x2A, 0x6F, 0x29, 0x6F, 0x2A, 0x6D, 0x2A, 0x6D, 0x29, 0x6D, 0x29, 0x71, 0x2B, 0x72, 0x2B, 0x6D, 0x28, 0x6E, 0x2A, 0x71, 0x2B, 0x70, 0x2A, 0x71, 0x2C, 0x72, 0x2D, 0x74, 0x2D, 0x72, 0x2D, 0x71, 0x2B, 0x73, 0x2D, 0x75, 0x2D, 0x77, 0x30, 0x7C, 0x31, 0x7C, 0x31, 0x78, 0x30, 0x7A, 0x31, 0x78, 0x2F, 0x78, 0x30, 0x7E, 0x33, 0x7F, 0x34, 0x79, 0x31, 0x88, 0x3A, 0x88, 0x3A, 0x8D, 0x3E, 0x8F, 0x3B, 0x84, 0x3C, 0x93, 0x41, 0x92, 0x46, 0xA2, 0x4C, 0xA0, 0x4A, 0x8B, 0x3C, 0x92, 0x44, 0xA0, 0x4A, 0xAA, 0x54, 0xD0, 0x69, 0xC2, 0x5C, 0xB4, 0x58, 0xA9, 0x56, 0xC7, 0x63, 0xB1, 0x58, 0xB3, 0x57, 0xC0, 0x5D, 0xAE, 0x56, 0xAF, 0x4F, 0x94, 0x47, 0xA7, 0x4E, 0xA3, 0x4F, 0xAA, 0x53, 0xB5, 0x5A, 0xAB, 0x55, 0xA2, 0x49, 0xA9, 0x53, 0xAF, 0x55, 0xA9, 0x50, 0x94, 0x41, 0x96, 0x46, 0x95, 0x41, 0x94, 0x42, 0x91, 0x3E, 0x85, 0x3C, 0x94, 0x44, 0x8E, 0x40, 0x87, 0x3D, 0xA4, 0x4D, 0x97, 0x44, 0x9B, 0x48, 0x97, 0x46, 0x92, 0x3E, 0x98, 0x47, 0x92, 0x41, 0x94, 0x40, 0x88, 0x3A, 0x87, 0x3C, 0x8B, 0x3F, 0xA2, 0x4C, 0x8A, 0x3C, 0x90, 0x3F, 0x88, 0x3A, 0x82, 0x36, 0x8C, 0x43, 0x8C, 0x3B, 0x6C, 0x2F, 0x5A, 0x2A, 0x60, 0x33, 0x76, 0x39, 0x81, 0x3A, 0x84, 0x37, 0x79, 0x31, 0x82, 0x37, 0x7B, 0x30, 0x76, 0x2D, 0x6A, 0x2A, 0x72, 0x2D, 0x74, 0x2C, 0x6D, 0x28, 0x69, 0x27, 0x6B, 0x27, 0x66, 0x26, 0x65, 0x2A, 0x68, 0x3D, 0x58, 0x32, 0x3E, 0x24, 0x3C, 0x23, 0x38, 0x25, 0x5C, 0x34, 0x6B, 0x31, 0x80, 0x35, 0x75, 0x30, 0x96, 0x45, 0x82, 0x37, 0x92, 0x41, 0x77, 0x32, 0x87, 0x36, 0x72, 0x2D, 0x73, 0x2C, 0x70, 0x2A, 0x6B, 0x28, 0x69, 0x28, 0x67, 0x26, 0x69, 0x27, 0x6A, 0x28, 0x69, 0x28, 0x6F, 0x29, 0x6F, 0x29, 0x67, 0x27, 0x63, 0x26, 0x6B, 0x29, 0x66, 0x26, 0x69, 0x28, 0x6D, 0x29, 0x66, 0x27, 0x68, 0x26, 0x67, 0x27, 0x68, 0x27, 0x64, 0x26, 0x65, 0x27, 0x6B, 0x29, 0x67, 0x26, 0x67, 0x27, 0x68, 0x26, 0x61, 0x26, 0x63, 0x25, 0x64, 0x25, 0x6E, 0x2C, 0x69, 0x28, 0x63, 0x25, 0x66, 0x29, 0x70, 0x30, 0x71, 0x2C, 0x65, 0x27, 0x63, 0x25, 0x64, 0x27, 0x66, 0x27, 0x6C, 0x2B, 0x71, 0x2F, 0x72, 0x2F, 0x6A, 0x2B, 0x6D, 0x2A, 0x70, 0x2F, 0x7D, 0x35, 0x7D, 0x39, 0x87, 0x3C, 0x76, 0x30, 0x6B, 0x2D, 0x80, 0x39, 0x76, 0x30, 0x67, 0x28, 0x66, 0x28, 0x63, 0x26, 0x60, 0x26, 0x60, 0x26, 0x5C, 0x22, 0x54, 0x22, 0x55, 0x22, 0x5B, 0x24, 0x5F, 0x24, 0x5F, 0x24, 0x66, 0x2B, 0x67, 0x2A, 0x63, 0x28, 0x66, 0x29, 0x68, 0x2B, 0x67, 0x29, 0x68, 0x2A, 0x66, 0x29, 0x56, 0x25, 0x43, 0x23, 0x39, 0x20, 0x42, 0x24, 0x42, 0x22, 0x36, 0x1E, 0x42, 0x22, 0x44, 0x23, 0x43, 0x22, 0x39, 0x21, 0x46, 0x24, 0x41, 0x23, 0x4A, 0x25, 0x41, 0x22, 0x3C, 0x21, 0x47, 0x24, 0x3F, 0x23, 0x3B, 0x1F, 0x38, 0x20, 0x3E, 0x21, 0x37, 0x1F, 0x33, 0x1C, 0x3B, 0x20, 0x36, 0x1E, 0x3E, 0x22, 0x39, 0x1E, 0x36, 0x1E, 0x39, 0x1E, 0x38, 0x20, 0x3E, 0x21, 0x41, 0x23, 0x40, 0x21, 0x3B, 0x1F, 0x45, 0x24, 0x43, 0x24, 0x44, 0x25, 0x3F, 0x22, 0x47, 0x26, 0x38, 0x20, 0x35, 0x1F, 0x3C, 0x21, 0x3A, 0x1F, 0x3C, 0x21, 0x38, 0x1F, 0x34, 0x1C, 0x38, 0x1F, 0x39, 0x1F, 0x45, 0x27, 0x45, 0x28
    },

    {
        0x6A, 0x5D, 0x6C, 0x60, 0x6F, 0x62, 0x6E, 0x61, 0x6F, 0x61, 0x6D, 0x5F, 0x6C, 0x60, 0x6D, 0x5F, 0x6F, 0x63, 0x70, 0x62, 0x72, 0x63, 0x71, 0x61, 0x6E, 0x5F, 0x6B, 0x5D, 0x6D, 0x5E, 0x70, 0x61, 0x74, 0x65, 0x74, 0x64, 0x71, 0x64, 0x75, 0x65, 0x74, 0x66, 0x76, 0x67, 0x75, 0x67, 0x73, 0x64, 0x71, 0x64, 0x72, 0x63, 0x74, 0x64, 0x75, 0x66, 0x72, 0x63, 0x74, 0x67, 0x77, 0x68, 0x77, 0x68, 0x78, 0x66, 0x74, 0x63, 0x77, 0x67, 0x7A, 0x6A, 0x78, 0x66, 0x74, 0x65, 0x74, 0x65, 0x75, 0x64, 0x76, 0x64, 0x73, 0x66, 0x77, 0x69, 0x76, 0x66, 0x75, 0x66, 0x76, 0x68, 0x77, 0x68, 0x76, 0x68, 0x77, 0x66, 0x78, 0x67, 0x79, 0x68, 0x79, 0x68, 0x78, 0x69, 0x78, 0x68, 0x77, 0x6A, 0x7A, 0x6B, 0x79, 0x67, 0x78, 0x68, 0x79, 0x69, 0x79, 0x6A, 0x79, 0x6C, 0x7D, 0x6D, 0x7F, 0x6D, 0x7B, 0x68, 0x7A, 0x6A, 0x7B, 0x6A, 0x79, 0x69, 0x79, 0x6B, 0x7A, 0x69, 0x7B, 0x6A, 0x7C, 0x6D, 0x7D, 0x6D, 0x7E, 0x70, 0x7F, 0x70, 0x81, 0x72, 0x80, 0x70, 0x82, 0x71, 0x80, 0x6E, 0x7D, 0x6F, 0x81, 0x71, 0x81, 0x72, 0x80, 0x73, 0x7D, 0x6F, 0x81, 0x71, 0x82, 0x74, 0x84, 0x74, 0x82, 0x72, 0x84, 0x74, 0x83, 0x74, 0x82, 0x71, 0x83, 0x74, 0x85, 0x76, 0x82, 0x75, 0x81, 0x76, 0x83, 0x73, 0x84, 0x76, 0x87, 0x79, 0x84, 0x7A, 0x88, 0x7C, 0x8C, 0x7E, 0x88, 0x7A, 0x89, 0x7D, 0x88, 0x79, 0x86, 0x7A, 0x8B, 0x81, 0x8C, 0x80, 0x8B, 0x7E, 0x95, 0x8E, 0x93, 0x89, 0x96, 0x8E, 0x94, 0x8A, 0x93, 0x8D, 0x9A, 0x92, 0x99, 0x97, 0xA3, 0xA3, 0xA3, 0xA5, 0x94, 0x8A, 0x9C, 0x9B, 0xA2, 0xA3, 0xAE, 0xB3, 0xC5, 0xD6, 0xC0, 0xC6, 0xB2, 0xB8, 0xAC, 0xB4, 0xBF, 0xC4, 0xAE, 0xB1, 0xAE, 0xB0, 0xBD, 0xC2, 0xB6, 0xB6, 0xB2, 0xB0, 0x9F, 0x9B, 0xA2, 0x9F, 0xA8, 0xA8, 0xB0, 0xB0, 0xB6, 0xB6, 0xAB, 0xB0, 0xA1, 0x98, 0xAC, 0xB2, 0xAA, 0xA5, 0xA1, 0x9F, 0x9A, 0x8D, 0x9C, 0x9A, 0x9F, 0x9F, 0xA0, 0x99, 0xA1, 0x9A, 0x90, 0x85, 0x9C, 0x98, 0x98, 0x91, 0x96, 0x93, 0xAA, 0xA6, 0x9E, 0x9C, 0x9F, 0x9B, 0x9E, 0x9F, 0x9B, 0x8F, 0xA5, 0xA4, 0xA0, 0x9D, 0x9F, 0x96, 0x94, 0x8D, 0x92, 0x8A, 0x93, 0x97, 0xA4, 0xA2, 0x95, 0x8D, 0x97, 0x8D, 0x8E, 0x87, 0x90, 0x83, 0x98, 0x99, 0x92, 0x8B, 0x7A, 0x71, 0x6B, 0x66, 0x6B, 0x70, 0x7E, 0x81, 0x84, 0x80, 0x8F, 0x89, 0x88, 0x7E, 0x8C, 0x85, 0x89, 0x7C, 0x81, 0x74, 0x7C, 0x6F, 0x82, 0x74, 0x86, 0x79, 0x80, 0x71, 0x7C, 0x6E, 0x77, 0x6B, 0x76, 0x67, 0x6F, 0x65, 0x64, 0x67, 0x50, 0x4D, 0x3D, 0x38, 0x3A, 0x37, 0x38, 0x38, 0x4D, 0x56, 0x70, 0x6E, 0x86, 0x7D, 0x85, 0x79, 0x98, 0x99, 0x8C, 0x82, 0x95, 0x93, 0x86, 0x7B, 0x91, 0x88, 0x81, 0x77, 0x7E, 0x70, 0x82, 0x74, 0x7B, 0x6D, 0x78, 0x6D, 0x79, 0x6A, 0x7E, 0x6E, 0x7B, 0x6F, 0x7C, 0x6E, 0x7F, 0x71, 0x80, 0x72, 0x7A, 0x6B, 0x72, 0x68, 0x7B, 0x6F, 0x76, 0x68, 0x79, 0x6C, 0x7E, 0x70, 0x7C, 0x6D, 0x77, 0x69, 0x78, 0x6A, 0x79, 0x6B, 0x76, 0x69, 0x76, 0x69, 0x7B, 0x6E, 0x79, 0x6A, 0x78, 0x6B, 0x77, 0x68, 0x71, 0x64, 0x72, 0x64, 0x73, 0x68, 0x7E, 0x75, 0x77, 0x69, 0x76, 0x66, 0x7A, 0x6D, 0x80, 0x77, 0x7F, 0x73, 0x79, 0x68, 0x76, 0x66, 0x75, 0x69, 0x76, 0x6A, 0x79, 0x6F, 0x7B, 0x71, 0x7D, 0x75, 0x78, 0x6E, 0x7E, 0x70, 0x7E, 0x7D, 0x8A, 0x88, 0x89, 0x87, 0x8E, 0x88, 0x80, 0x74, 0x79, 0x70, 0x87, 0x84, 0x83, 0x77, 0x76, 0x69, 0x75, 0x68, 0x73, 0x66, 0x6C, 0x61, 0x6C, 0x62, 0x6B, 0x5C, 0x62, 0x54, 0x67, 0x5B, 0x6B, 0x60, 0x6E, 0x63, 0x6F, 0x62, 0x72, 0x6A, 0x76, 0x6C, 0x6F, 0x67, 0x70, 0x68, 0x77, 0x6C, 0x75, 0x69, 0x73, 0x6C, 0x75, 0x69, 0x5B, 0x52, 0x3F, 0x43, 0x35, 0x3B, 0x3E, 0x47, 0x40, 0x44, 0x34, 0x3B, 0x3D, 0x46, 0x3C, 0x44, 0x3F, 0x45, 0x36, 0x3E, 0x3D, 0x44, 0x3A, 0x44, 0x42, 0x49, 0x38, 0x3C, 0x37, 0x42, 0x3C, 0x3E, 0x38, 0x3F, 0x33, 0x37, 0x33, 0x3D, 0x35, 0x38, 0x33, 0x3A, 0x2E, 0x32, 0x3A, 0x42, 0x32, 0x35, 0x3B, 0x45, 0x33, 0x37, 0x35, 0x3B, 0x36, 0x39, 0x36, 0x3E, 0x3D, 0x45, 0x3B, 0x43, 0x3A, 0x41, 0x39, 0x40, 0x3E, 0x47, 0x3A, 0x43, 0x3D, 0x45, 0x3A, 0x41, 0x3C, 0x43, 0x30, 0x35, 0x31, 0x38, 0x37, 0x3C, 0x34, 0x38, 0x37, 0x40, 0x33, 0x39, 0x30, 0x35, 0x36, 0x3D, 0x36, 0x3E, 0x43, 0x4C, 0x45, 0x4F
    },

    {
        0x5C, 0x22, 0x5E, 0x21, 0x5E, 0x21, 0x5C, 0x21, 0x5E, 0x22, 0x5E, 0x23, 0x5E, 0x21, 0x5E, 0x22, 0x61, 0x24, 0x60, 0x22, 0x61, 0x23, 0x5F, 0x22, 0x60, 0x23, 0x5F, 0x23, 0x5E, 0x22, 0x60, 0x23, 0x63, 0x23, 0x5F, 0x24, 0x62, 0x24, 0x63, 0x25, 0x64, 0x24, 0x62, 0x24, 0x63, 0x24, 0x63, 0x26, 0x64, 0x27, 0x67, 0x28, 0x64, 0x26, 0x66, 0x25, 0x67, 0x26, 0x66, 0x26, 0x66, 0x25, 0x66, 0x26, 0x66, 0x25, 0x63, 0x23, 0x65, 0x25, 0x66, 0x26, 0x65, 0x25, 0x62, 0x24, 0x61, 0x24, 0x62, 0x23, 0x62, 0x23, 0x61, 0x23, 0x63, 0x25, 0x65, 0x25, 0x66, 0x26, 0x66, 0x25, 0x65, 0x25, 0x65, 0x25, 0x66, 0x25, 0x67, 0x26, 0x68, 0x26, 0x68, 0x25, 0x67, 0x26, 0x68, 0x27, 0x6C, 0x27, 0x67, 0x25, 0x67, 0x26, 0x67, 0x26, 0x66, 0x26, 0x66, 0x26, 0x66, 0x25, 0x66, 0x25, 0x6B, 0x27, 0x69, 0x26, 0x68, 0x26, 0x67, 0x26, 0x69, 0x26, 0x68, 0x25, 0x67, 0x25, 0x68, 0x26, 0x69, 0x27, 0x6C, 0x28, 0x6C, 0x28, 0x6B, 0x27, 0x6C, 0x27, 0x6D, 0x29, 0x6C, 0x28, 0x69, 0x27, 0x6D, 0x28, 0x6E, 0x2A, 0x6E, 0x28, 0x6E, 0x29, 0x6B, 0x29, 0x70, 0x2A, 0x6E, 0x2A, 0x73, 0x2B, 0x6D, 0x29, 0x71, 0x2A, 0x71, 0x2B, 0x74, 0x2C, 0x75, 0x2C, 0x75, 0x2B, 0x71, 0x2A, 0x71, 0x2C, 0x72, 0x2B, 0x75, 0x2D, 0x76, 0x2E, 0x76, 0x2E, 0x73, 0x2E, 0x7B, 0x33, 0x80, 0x33, 0x7A, 0x30, 0x7B, 0x30, 0x76, 0x30, 0x83, 0x37, 0x7B, 0x32, 0x7D, 0x33, 0x84, 0x39, 0x7F, 0x34, 0x82, 0x38, 0x8A, 0x3B, 0x8C, 0x3B, 0x8E, 0x42, 0x8F, 0x3E, 0x94, 0x44, 0x9C, 0x49, 0x93, 0x42, 0x9F, 0x4B, 0xB0, 0x57, 0xBF, 0x68, 0xE5, 0x79, 0xDE, 0x76, 0xDA, 0x6D, 0xAB, 0x4F, 0xAE, 0x52, 0xAA, 0x53, 0xB9, 0x5B, 0xBE, 0x5F, 0xB6, 0x55, 0xB4, 0x59, 0xA0, 0x4B, 0xA0, 0x4B, 0xAB, 0x58, 0xD5, 0x6E, 0xD4, 0x68, 0xA7, 0x4C, 0x9E, 0x4A, 0xA9, 0x51, 0xA5, 0x4F, 0xA3, 0x51, 0xA8, 0x4E, 0x97, 0x45, 0x9D, 0x4D, 0x9E, 0x49, 0xAE, 0x52, 0x98, 0x46, 0x9C, 0x4A, 0x9B, 0x45, 0x93, 0x45, 0xA2, 0x4A, 0x9B, 0x49, 0x91, 0x40, 0x9E, 0x4B, 0x96, 0x42, 0xA5, 0x4D, 0x95, 0x47, 0x99, 0x41, 0x98, 0x46, 0x86, 0x3A, 0xA0, 0x4A, 0x92, 0x42, 0x9A, 0x49, 0x92, 0x3D, 0x79, 0x30, 0x7D, 0x35, 0x95, 0x44, 0x8F, 0x3F, 0x8E, 0x42, 0x9F, 0x45, 0x83, 0x3F, 0xA2, 0x4E, 0x9B, 0x42, 0x80, 0x37, 0x7D, 0x35, 0x75, 0x32, 0x7C, 0x30, 0x78, 0x2E, 0x6C, 0x2A, 0x6C, 0x2B, 0x71, 0x2C, 0x6F, 0x2A, 0x6A, 0x27, 0x64, 0x27, 0x65, 0x26, 0x5D, 0x2C, 0x4E, 0x2A, 0x37, 0x1E, 0x2D, 0x1A, 0x32, 0x1D, 0x2D, 0x1B, 0x4E, 0x30, 0x68, 0x31, 0x86, 0x3B, 0x7D, 0x35, 0x91, 0x45, 0x85, 0x3A, 0x75, 0x33, 0x7D, 0x33, 0x73, 0x30, 0x6F, 0x2B, 0x70, 0x2C, 0x6E, 0x2C, 0x6E, 0x2A, 0x69, 0x27, 0x6A, 0x28, 0x6A, 0x29, 0x69, 0x28, 0x69, 0x27, 0x6B, 0x28, 0x6B, 0x28, 0x69, 0x28, 0x64, 0x26, 0x66, 0x27, 0x67, 0x26, 0x66, 0x27, 0x69, 0x28, 0x6E, 0x29, 0x67, 0x27, 0x6C, 0x2A, 0x6D, 0x2A, 0x67, 0x27, 0x67, 0x26, 0x6B, 0x29, 0x6C, 0x2A, 0x6E, 0x2C, 0x6B, 0x2A, 0x6A, 0x29, 0x66, 0x26, 0x63, 0x25, 0x69, 0x29, 0x64, 0x26, 0x69, 0x29, 0x6B, 0x2B, 0x6E, 0x2F, 0x78, 0x32, 0x65, 0x27, 0x69, 0x29, 0x6B, 0x2A, 0x66, 0x28, 0x67, 0x29, 0x6B, 0x2D, 0x71, 0x2C, 0x6F, 0x2F, 0x78, 0x35, 0x83, 0x3C, 0x89, 0x40, 0x8E, 0x40, 0x85, 0x40, 0x8A, 0x3B, 0x71, 0x2E, 0x79, 0x35, 0x7D, 0x35, 0x70, 0x2E, 0x67, 0x29, 0x6B, 0x29, 0x63, 0x26, 0x5D, 0x25, 0x5A, 0x23, 0x59, 0x22, 0x5A, 0x22, 0x57, 0x21, 0x59, 0x22, 0x5D, 0x23, 0x5B, 0x23, 0x67, 0x2A, 0x65, 0x29, 0x66, 0x2A, 0x68, 0x2A, 0x67, 0x29, 0x68, 0x2C, 0x67, 0x2B, 0x58, 0x27, 0x4F, 0x28, 0x40, 0x22, 0x50, 0x29, 0x43, 0x22, 0x37, 0x20, 0x42, 0x23, 0x38, 0x20, 0x3E, 0x21, 0x39, 0x20, 0x3A, 0x20, 0x3F, 0x23, 0x3B, 0x1F, 0x32, 0x1D, 0x3A, 0x20, 0x33, 0x1C, 0x38, 0x1E, 0x38, 0x1E, 0x3A, 0x1F, 0x3B, 0x20, 0x42, 0x23, 0x44, 0x24, 0x49, 0x25, 0x3E, 0x21, 0x40, 0x23, 0x40, 0x22, 0x45, 0x25, 0x45, 0x25, 0x3E, 0x22, 0x3F, 0x21, 0x35, 0x1F, 0x3B, 0x1F, 0x38, 0x1F, 0x39, 0x1F, 0x35, 0x1E, 0x3A, 0x21, 0x39, 0x22, 0x3A, 0x22, 0x3D, 0x26, 0x39, 0x24, 0x3C, 0x28, 0x3C, 0x2B, 0x42, 0x2F, 0x45, 0x28, 0x3A, 0x20, 0x47, 0x26, 0x41, 0x28, 0x60, 0x49, 0x6F, 0x55
    },

    {
        0x6D, 0x61, 0x6D, 0x5F, 0x6C, 0x5F, 0x6C, 0x5F, 0x6B, 0x61, 0x6C, 0x61, 0x6D, 0x60, 0x6D, 0x61, 0x70, 0x63, 0x6F, 0x62, 0x6E, 0x61, 0x70, 0x62, 0x6F, 0x61, 0x6C, 0x60, 0x6F, 0x61, 0x70, 0x62, 0x71, 0x63, 0x6E, 0x60, 0x71, 0x64, 0x74, 0x65, 0x73, 0x64, 0x71, 0x63, 0x73, 0x64, 0x74, 0x66, 0x74, 0x67, 0x78, 0x6D, 0x75, 0x67, 0x77, 0x68, 0x77, 0x68, 0x76, 0x66, 0x78, 0x68, 0x7B, 0x69, 0x78, 0x68, 0x77, 0x66, 0x77, 0x67, 0x77, 0x67, 0x7A, 0x68, 0x75, 0x65, 0x75, 0x65, 0x75, 0x64, 0x73, 0x62, 0x73, 0x63, 0x74, 0x68, 0x79, 0x68, 0x76, 0x68, 0x77, 0x67, 0x76, 0x67, 0x77, 0x69, 0x79, 0x69, 0x7B, 0x69, 0x7A, 0x69, 0x79, 0x69, 0x7A, 0x6A, 0x7C, 0x6D, 0x7B, 0x6B, 0x7A, 0x69, 0x7C, 0x6A, 0x79, 0x69, 0x7A, 0x68, 0x77, 0x6A, 0x78, 0x68, 0x7A, 0x69, 0x7D, 0x6C, 0x7B, 0x6A, 0x7B, 0x6C, 0x7A, 0x6B, 0x7C, 0x6D, 0x7B, 0x6A, 0x78, 0x68, 0x79, 0x6B, 0x7D, 0x6D, 0x7E, 0x6F, 0x7E, 0x6E, 0x7C, 0x6D, 0x7D, 0x6E, 0x81, 0x72, 0x7F, 0x6E, 0x7D, 0x6E, 0x81, 0x70, 0x80, 0x71, 0x7F, 0x6F, 0x7E, 0x6E, 0x7D, 0x6F, 0x81, 0x72, 0x7F, 0x70, 0x86, 0x75, 0x80, 0x71, 0x83, 0x76, 0x84, 0x74, 0x86, 0x79, 0x88, 0x77, 0x85, 0x77, 0x84, 0x75, 0x83, 0x75, 0x83, 0x75, 0x85, 0x77, 0x84, 0x79, 0x86, 0x77, 0x83, 0x77, 0x8A, 0x80, 0x8F, 0x82, 0x8B, 0x7B, 0x8B, 0x7D, 0x88, 0x7B, 0x91, 0x8B, 0x89, 0x7E, 0x8C, 0x82, 0x8B, 0x82, 0x8B, 0x81, 0x8C, 0x84, 0x95, 0x8D, 0x98, 0x8F, 0x95, 0x91, 0x95, 0x8F, 0x9C, 0x99, 0x9F, 0xA0, 0xA1, 0x9D, 0xAD, 0xAC, 0xB3, 0xB1, 0xB9, 0xC5, 0xD3, 0xE2, 0xD0, 0xDE, 0xCC, 0xD4, 0xB2, 0xAD, 0xB5, 0xB8, 0xB7, 0xBA, 0xBD, 0xC5, 0xBB, 0xBF, 0xAE, 0xAE, 0xB1, 0xBA, 0xA6, 0x9F, 0xA5, 0xA4, 0xA8, 0xB2, 0xC6, 0xD8, 0xCB, 0xD2, 0xAD, 0xAE, 0xA6, 0xA5, 0xAE, 0xAE, 0xAA, 0xA8, 0xAB, 0xAF, 0xAE, 0xB0, 0xA5, 0x9C, 0xA0, 0xA1, 0xA4, 0xA3, 0xB1, 0xB4, 0xA2, 0xA0, 0xA3, 0xA1, 0xA1, 0xA0, 0x9E, 0x9F, 0xA2, 0x9D, 0xA3, 0xA0, 0x97, 0x90, 0xA2, 0xA3, 0x9E, 0x9B, 0xA6, 0xA3, 0x9F, 0x9F, 0x9D, 0x94, 0x9F, 0x9E, 0x8F, 0x88, 0xA6, 0xA2, 0x9C, 0x96, 0xA1, 0xA4, 0x98, 0x90, 0x89, 0x7B, 0x8D, 0x84, 0x9D, 0x9C, 0x98, 0x93, 0x9D, 0x9C, 0xA0, 0x9F, 0x8E, 0x8E, 0xA0, 0xA7, 0x9D, 0x94, 0x89, 0x7F, 0x89, 0x81, 0x81, 0x79, 0x82, 0x79, 0x85, 0x79, 0x7E, 0x71, 0x7C, 0x70, 0x81, 0x72, 0x7B, 0x6F, 0x78, 0x6B, 0x74, 0x68, 0x76, 0x66, 0x61, 0x59, 0x49, 0x45, 0x38, 0x33, 0x33, 0x2E, 0x35, 0x32, 0x30, 0x2F, 0x41, 0x51, 0x6C, 0x77, 0x88, 0x89, 0x82, 0x7B, 0x92, 0x91, 0x8D, 0x83, 0x84, 0x77, 0x8A, 0x81, 0x80, 0x73, 0x7E, 0x73, 0x7F, 0x73, 0x80, 0x73, 0x7D, 0x6E, 0x79, 0x6A, 0x79, 0x6C, 0x7D, 0x6D, 0x7A, 0x6C, 0x7A, 0x6B, 0x7C, 0x6E, 0x7D, 0x6B, 0x78, 0x6D, 0x72, 0x68, 0x76, 0x69, 0x79, 0x69, 0x76, 0x69, 0x7A, 0x6C, 0x7E, 0x71, 0x7A, 0x6B, 0x7D, 0x70, 0x7B, 0x70, 0x79, 0x6C, 0x77, 0x6B, 0x7B, 0x6F, 0x7D, 0x72, 0x7F, 0x73, 0x7C, 0x71, 0x7B, 0x6D, 0x74, 0x68, 0x72, 0x67, 0x77, 0x6C, 0x72, 0x66, 0x78, 0x6E, 0x78, 0x6D, 0x7E, 0x76, 0x82, 0x78, 0x78, 0x68, 0x77, 0x6C, 0x79, 0x6B, 0x78, 0x6B, 0x78, 0x6D, 0x7D, 0x75, 0x7C, 0x73, 0x7B, 0x75, 0x80, 0x7C, 0x84, 0x80, 0x89, 0x8B, 0x8F, 0x8A, 0x8A, 0x8C, 0x8E, 0x88, 0x7D, 0x73, 0x83, 0x7C, 0x83, 0x7B, 0x7C, 0x73, 0x77, 0x6C, 0x79, 0x6C, 0x72, 0x65, 0x6E, 0x63, 0x6C, 0x5E, 0x6C, 0x5F, 0x69, 0x5D, 0x65, 0x59, 0x67, 0x5E, 0x6C, 0x60, 0x6B, 0x5F, 0x72, 0x6A, 0x70, 0x68, 0x74, 0x6A, 0x76, 0x6C, 0x76, 0x6D, 0x75, 0x6D, 0x73, 0x6A, 0x5B, 0x55, 0x4B, 0x51, 0x3A, 0x40, 0x45, 0x4F, 0x37, 0x3D, 0x31, 0x38, 0x39, 0x3F, 0x35, 0x3C, 0x36, 0x3B, 0x35, 0x3E, 0x33, 0x39, 0x39, 0x44, 0x36, 0x3A, 0x32, 0x39, 0x35, 0x3D, 0x30, 0x37, 0x35, 0x3C, 0x37, 0x3E, 0x38, 0x3F, 0x39, 0x40, 0x3F, 0x48, 0x41, 0x4A, 0x41, 0x48, 0x39, 0x3F, 0x3A, 0x44, 0x3B, 0x42, 0x3E, 0x47, 0x3C, 0x43, 0x37, 0x3E, 0x37, 0x39, 0x32, 0x39, 0x36, 0x3A, 0x32, 0x38, 0x33, 0x39, 0x32, 0x38, 0x36, 0x3C, 0x35, 0x3D, 0x36, 0x3B, 0x3C, 0x42, 0x38, 0x3D, 0x3B, 0x40, 0x3C, 0x42, 0x42, 0x47, 0x3E, 0x45, 0x35, 0x3B, 0x3F, 0x49, 0x39, 0x44, 0x53, 0x67, 0x5D, 0x72
    },

    {
        0x5F, 0x21, 0x5D, 0x20, 0x5D, 0x21, 0x5C, 0x20, 0x5D, 0x20, 0x5C, 0x20, 0x5C, 0x21, 0x5D, 0x22, 0x61, 0x23, 0x60, 0x23, 0x61, 0x24, 0x61, 0x23, 0x60, 0x22, 0x60, 0x22, 0x60, 0x23, 0x62, 0x24, 0x63, 0x25, 0x64, 0x26, 0x65, 0x26, 0x63, 0x23, 0x61, 0x23, 0x61, 0x24, 0x63, 0x25, 0x65, 0x25, 0x64, 0x25, 0x62, 0x24, 0x61, 0x25, 0x65, 0x26, 0x63, 0x26, 0x67, 0x27, 0x65, 0x25, 0x65, 0x25, 0x67, 0x26, 0x66, 0x26, 0x64, 0x25, 0x64, 0x25, 0x67, 0x26, 0x65, 0x24, 0x62, 0x23, 0x62, 0x23, 0x61, 0x23, 0x61, 0x24, 0x63, 0x24, 0x63, 0x24, 0x63, 0x24, 0x66, 0x25, 0x67, 0x26, 0x68, 0x25, 0x68, 0x25, 0x65, 0x24, 0x67, 0x25, 0x67, 0x25, 0x68, 0x26, 0x68, 0x25, 0x67, 0x25, 0x66, 0x25, 0x68, 0x26, 0x6A, 0x26, 0x69, 0x25, 0x67, 0x25, 0x67, 0x25, 0x67, 0x25, 0x68, 0x25, 0x66, 0x26, 0x6A, 0x27, 0x67, 0x25, 0x66, 0x26, 0x68, 0x26, 0x67, 0x26, 0x6A, 0x27, 0x6A, 0x28, 0x6D, 0x29, 0x70, 0x29, 0x6D, 0x28, 0x6E, 0x29, 0x6F, 0x28, 0x6E, 0x29, 0x71, 0x29, 0x6C, 0x28, 0x6C, 0x28, 0x68, 0x27, 0x6C, 0x28, 0x6E, 0x2A, 0x6F, 0x29, 0x6E, 0x2A, 0x72, 0x2A, 0x6D, 0x28, 0x73, 0x2F, 0x75, 0x2B, 0x72, 0x2D, 0x73, 0x2B, 0x70, 0x2A, 0x72, 0x2D, 0x74, 0x2C, 0x71, 0x2C, 0x70, 0x2C, 0x74, 0x2C, 0x77, 0x2E, 0x74, 0x2E, 0x7A, 0x32, 0x7D, 0x2F, 0x7A, 0x2F, 0x7B, 0x30, 0x7F, 0x32, 0x7F, 0x32, 0x7B, 0x31, 0x84, 0x38, 0x82, 0x34, 0x7E, 0x35, 0x82, 0x39, 0x8B, 0x3E, 0x91, 0x3F, 0x8B, 0x3C, 0x87, 0x3C, 0x9E, 0x49, 0xA1, 0x4A, 0x9F, 0x4E, 0xB7, 0x55, 0xB1, 0x54, 0xB9, 0x5B, 0xC9, 0x69, 0xD5, 0x70, 0xCA, 0x64, 0xB4, 0x55, 0xC8, 0x6C, 0xD0, 0x65, 0xB8, 0x59, 0xAE, 0x53, 0xAF, 0x57, 0xAB, 0x4F, 0xA9, 0x4D, 0x9F, 0x4B, 0xB2, 0x5B, 0xC4, 0x65, 0xCA, 0x64, 0xBA, 0x5F, 0xAB, 0x50, 0xB1, 0x58, 0xB1, 0x57, 0xBB, 0x5B, 0xBE, 0x5F, 0xB9, 0x5D, 0xB1, 0x52, 0xAC, 0x51, 0xBD, 0x60, 0xB7, 0x59, 0xA7, 0x4C, 0x98, 0x45, 0x9D, 0x4E, 0xAA, 0x50, 0x96, 0x42, 0x96, 0x43, 0x93, 0x43, 0xA4, 0x4C, 0xA4, 0x49, 0x8F, 0x3F, 0x88, 0x3A, 0x95, 0x43, 0x87, 0x3C, 0x94, 0x45, 0x88, 0x3A, 0x8E, 0x42, 0x87, 0x39, 0x76, 0x2F, 0x7F, 0x35, 0x88, 0x3C, 0xAA, 0x55, 0xB0, 0x52, 0xA1, 0x48, 0x84, 0x3C, 0x8A, 0x3E, 0x8F, 0x41, 0x7A, 0x31, 0x76, 0x2E, 0x6D, 0x2B, 0x73, 0x2E, 0x6E, 0x2C, 0x74, 0x2C, 0x6D, 0x2A, 0x6C, 0x2A, 0x6C, 0x29, 0x6E, 0x29, 0x65, 0x26, 0x65, 0x25, 0x48, 0x20, 0x37, 0x1E, 0x30, 0x1B, 0x2B, 0x19, 0x2E, 0x1A, 0x27, 0x16, 0x28, 0x1B, 0x5E, 0x2D, 0x71, 0x2F, 0x7E, 0x35, 0x82, 0x36, 0x78, 0x2F, 0x7E, 0x34, 0x76, 0x30, 0x74, 0x30, 0x74, 0x2E, 0x72, 0x2E, 0x73, 0x2B, 0x68, 0x28, 0x67, 0x27, 0x68, 0x28, 0x70, 0x2A, 0x6C, 0x28, 0x6B, 0x28, 0x68, 0x26, 0x6A, 0x27, 0x64, 0x25, 0x65, 0x27, 0x65, 0x25, 0x5F, 0x24, 0x62, 0x24, 0x61, 0x24, 0x66, 0x27, 0x68, 0x27, 0x6A, 0x28, 0x6A, 0x29, 0x6B, 0x29, 0x65, 0x26, 0x68, 0x27, 0x6A, 0x2A, 0x6E, 0x2A, 0x68, 0x2A, 0x70, 0x2B, 0x65, 0x26, 0x66, 0x27, 0x69, 0x29, 0x63, 0x25, 0x63, 0x27, 0x67, 0x29, 0x77, 0x32, 0x6A, 0x28, 0x66, 0x27, 0x66, 0x28, 0x6A, 0x29, 0x69, 0x2A, 0x6F, 0x2D, 0x74, 0x31, 0x76, 0x30, 0x71, 0x2F, 0x6F, 0x2F, 0x75, 0x34, 0x7A, 0x35, 0x76, 0x35, 0x78, 0x35, 0x86, 0x3F, 0x75, 0x30, 0x6D, 0x2D, 0x6E, 0x2E, 0x6A, 0x29, 0x62, 0x25, 0x61, 0x26, 0x63, 0x26, 0x63, 0x26, 0x61, 0x25, 0x60, 0x25, 0x5D, 0x23, 0x58, 0x20, 0x59, 0x22, 0x61, 0x26, 0x69, 0x2C, 0x6A, 0x2B, 0x68, 0x2A, 0x69, 0x2C, 0x6F, 0x2E, 0x6F, 0x2F, 0x71, 0x2E, 0x69, 0x2B, 0x5B, 0x2A, 0x4A, 0x27, 0x3B, 0x20, 0x46, 0x24, 0x3A, 0x1F, 0x3E, 0x21, 0x48, 0x25, 0x3E, 0x21, 0x44, 0x23, 0x43, 0x23, 0x41, 0x21, 0x42, 0x23, 0x48, 0x25, 0x47, 0x25, 0x3E, 0x21, 0x3F, 0x21, 0x41, 0x23, 0x44, 0x23, 0x3A, 0x20, 0x3E, 0x21, 0x40, 0x22, 0x3E, 0x21, 0x38, 0x1F, 0x33, 0x1C, 0x39, 0x20, 0x38, 0x1E, 0x35, 0x1E, 0x33, 0x1F, 0x33, 0x20, 0x31, 0x20, 0x37, 0x26, 0x39, 0x28, 0x34, 0x28, 0x42, 0x27, 0x3C, 0x20, 0x40, 0x23, 0x3B, 0x29, 0x40, 0x39, 0x44, 0x3F, 0x46, 0x3F, 0x4A, 0x42, 0x4C, 0x44, 0x50, 0x45, 0x3D, 0x2B, 0x35, 0x1F, 0x3C, 0x21, 0x36, 0x24, 0x5A, 0x48, 0x60, 0x4C
    },

    {
        0x6F, 0x62, 0x6D, 0x5F, 0x6C, 0x5F, 0x6C, 0x5F, 0x6D, 0x5F, 0x6B, 0x5E, 0x6C, 0x5E, 0x6D, 0x60, 0x6F, 0x62, 0x6F, 0x62, 0x6F, 0x63, 0x70, 0x62, 0x6F, 0x61, 0x70, 0x62, 0x72, 0x63, 0x72, 0x65, 0x72, 0x65, 0x73, 0x67, 0x72, 0x67, 0x74, 0x66, 0x72, 0x64, 0x73, 0x64, 0x75, 0x66, 0x76, 0x66, 0x75, 0x66, 0x73, 0x63, 0x73, 0x63, 0x77, 0x68, 0x75, 0x68, 0x78, 0x6A, 0x77, 0x67, 0x77, 0x68, 0x7A, 0x6A, 0x7A, 0x69, 0x78, 0x66, 0x76, 0x67, 0x79, 0x69, 0x78, 0x66, 0x77, 0x65, 0x74, 0x64, 0x75, 0x64, 0x72, 0x64, 0x74, 0x66, 0x77, 0x67, 0x76, 0x66, 0x77, 0x68, 0x79, 0x69, 0x7B, 0x6A, 0x79, 0x69, 0x79, 0x68, 0x79, 0x68, 0x7B, 0x6A, 0x7A, 0x6A, 0x7A, 0x6B, 0x79, 0x6A, 0x7C, 0x6A, 0x7B, 0x6A, 0x7B, 0x6C, 0x7C, 0x6B, 0x7B, 0x69, 0x7E, 0x6C, 0x7B, 0x6A, 0x7C, 0x6B, 0x79, 0x69, 0x7B, 0x6C, 0x78, 0x69, 0x7A, 0x6B, 0x7D, 0x6D, 0x7B, 0x6A, 0x7D, 0x6C, 0x7F, 0x70, 0x7F, 0x71, 0x84, 0x72, 0x81, 0x6F, 0x83, 0x72, 0x81, 0x70, 0x84, 0x74, 0x84, 0x73, 0x80, 0x6F, 0x7D, 0x6E, 0x7D, 0x6D, 0x81, 0x70, 0x81, 0x74, 0x84, 0x71, 0x81, 0x71, 0x84, 0x74, 0x80, 0x6E, 0x86, 0x7A, 0x86, 0x76, 0x81, 0x74, 0x85, 0x74, 0x82, 0x73, 0x84, 0x76, 0x86, 0x77, 0x83, 0x74, 0x83, 0x73, 0x86, 0x77, 0x89, 0x7B, 0x87, 0x7A, 0x89, 0x7E, 0x8E, 0x7D, 0x8A, 0x7B, 0x8C, 0x80, 0x8D, 0x81, 0x8C, 0x7C, 0x8D, 0x80, 0x90, 0x8A, 0x96, 0x88, 0x8E, 0x83, 0x8E, 0x88, 0x96, 0x94, 0x9B, 0x97, 0x94, 0x8F, 0x93, 0x8B, 0xA6, 0xA5, 0x9F, 0xA3, 0xA5, 0xA3, 0xAE, 0xAC, 0xAB, 0xB1, 0xBA, 0xC6, 0xBE, 0xC8, 0xBD, 0xC4, 0xB7, 0xBF, 0xB4, 0xB1, 0xC0, 0xCF, 0xC2, 0xCA, 0xB4, 0xB3, 0xAC, 0xA9, 0xAE, 0xB7, 0xAC, 0xA4, 0xAD, 0xAD, 0xA7, 0xA6, 0xB6, 0xC1, 0xC4, 0xC8, 0xC4, 0xC8, 0xB9, 0xBD, 0xAC, 0xA9, 0xAE, 0xB2, 0xB4, 0xBA, 0xB4, 0xBD, 0xBA, 0xC2, 0xB6, 0xBE, 0xAF, 0xAA, 0xAD, 0xAD, 0xBD, 0xCB, 0xB9, 0xBD, 0xAC, 0xAC, 0x9F, 0x99, 0xA3, 0xA6, 0xAC, 0xAD, 0x9F, 0x97, 0x9E, 0x9C, 0xA3, 0xA4, 0xAB, 0xA9, 0xAB, 0xA3, 0x98, 0x8D, 0x97, 0x8F, 0x99, 0x9A, 0x93, 0x8B, 0x97, 0x93, 0x92, 0x86, 0x98, 0x97, 0x91, 0x82, 0x84, 0x7B, 0x8F, 0x85, 0x92, 0x8C, 0xAD, 0xB5, 0xAB, 0xB1, 0xA5, 0x9D, 0x8F, 0x87, 0x91, 0x84, 0x8B, 0x88, 0x82, 0x76, 0x86, 0x76, 0x7E, 0x73, 0x82, 0x77, 0x7A, 0x6F, 0x82, 0x76, 0x7C, 0x71, 0x7E, 0x6E, 0x7D, 0x6E, 0x7E, 0x6F, 0x77, 0x6B, 0x77, 0x66, 0x51, 0x43, 0x3C, 0x36, 0x33, 0x2F, 0x30, 0x2D, 0x30, 0x2E, 0x29, 0x26, 0x28, 0x2B, 0x64, 0x69, 0x7E, 0x72, 0x89, 0x84, 0x93, 0x8D, 0x90, 0x84, 0x90, 0x87, 0x84, 0x7B, 0x83, 0x77, 0x81, 0x76, 0x7E, 0x77, 0x84, 0x75, 0x7A, 0x6E, 0x7A, 0x6B, 0x78, 0x6E, 0x80, 0x72, 0x7E, 0x6F, 0x7A, 0x6E, 0x78, 0x68, 0x7A, 0x6B, 0x76, 0x67, 0x77, 0x6B, 0x76, 0x68, 0x70, 0x63, 0x71, 0x63, 0x70, 0x64, 0x79, 0x6C, 0x78, 0x69, 0x7B, 0x6D, 0x7B, 0x6D, 0x79, 0x6E, 0x72, 0x67, 0x78, 0x6A, 0x79, 0x6E, 0x7E, 0x70, 0x79, 0x6D, 0x7E, 0x71, 0x78, 0x6A, 0x7B, 0x6D, 0x7C, 0x6F, 0x75, 0x66, 0x74, 0x68, 0x74, 0x6E, 0x81, 0x79, 0x79, 0x69, 0x77, 0x69, 0x76, 0x6B, 0x7D, 0x6E, 0x77, 0x6D, 0x7C, 0x72, 0x7E, 0x74, 0x82, 0x79, 0x7E, 0x70, 0x79, 0x71, 0x80, 0x7A, 0x83, 0x7B, 0x7C, 0x74, 0x7E, 0x78, 0x87, 0x87, 0x7C, 0x75, 0x78, 0x6E, 0x7B, 0x72, 0x78, 0x6B, 0x73, 0x64, 0x73, 0x65, 0x71, 0x65, 0x72, 0x66, 0x72, 0x65, 0x70, 0x63, 0x6D, 0x60, 0x69, 0x5B, 0x67, 0x5D, 0x6E, 0x65, 0x72, 0x6E, 0x73, 0x69, 0x74, 0x67, 0x74, 0x6D, 0x79, 0x72, 0x7A, 0x73, 0x7F, 0x77, 0x77, 0x6D, 0x5E, 0x5A, 0x43, 0x45, 0x37, 0x3F, 0x3F, 0x48, 0x39, 0x41, 0x3D, 0x45, 0x41, 0x4C, 0x38, 0x42, 0x3E, 0x4A, 0x3D, 0x44, 0x3C, 0x42, 0x3B, 0x45, 0x42, 0x4A, 0x3C, 0x45, 0x37, 0x3E, 0x37, 0x3D, 0x3C, 0x47, 0x39, 0x3E, 0x33, 0x3A, 0x35, 0x3A, 0x36, 0x3D, 0x37, 0x3B, 0x32, 0x37, 0x2F, 0x33, 0x35, 0x3D, 0x32, 0x36, 0x32, 0x35, 0x31, 0x32, 0x35, 0x36, 0x32, 0x33, 0x36, 0x39, 0x39, 0x39, 0x35, 0x37, 0x3D, 0x45, 0x36, 0x3E, 0x39, 0x3F, 0x36, 0x3D, 0x3E, 0x43, 0x42, 0x47, 0x44, 0x4A, 0x46, 0x4C, 0x47, 0x4E, 0x4B, 0x52, 0x32, 0x35, 0x30, 0x3A, 0x35, 0x39, 0x32, 0x3D, 0x4C, 0x59, 0x4C, 0x59
    },

    {
        0x5E, 0x21, 0x5D, 0x20, 0x5E, 0x22, 0x60, 0x22, 0x5E, 0x21, 0x5D, 0x21, 0x5C, 0x21, 0x60, 0x22, 0x62, 0x24, 0x61, 0x24, 0x60, 0x23, 0x60, 0x22, 0x60, 0x22, 0x5F, 0x21, 0x5E, 0x22, 0x60, 0x23, 0x60, 0x23, 0x63, 0x26, 0x63, 0x25, 0x63, 0x24, 0x62, 0x24, 0x63, 0x25, 0x66, 0x27, 0x68, 0x28, 0x66, 0x26, 0x63, 0x25, 0x63, 0x24, 0x65, 0x27, 0x69, 0x27, 0x66, 0x26, 0x67, 0x26, 0x66, 0x26, 0x67, 0x27, 0x69, 0x27, 0x66, 0x26, 0x64, 0x25, 0x66, 0x25, 0x66, 0x25, 0x67, 0x25, 0x63, 0x24, 0x65, 0x25, 0x65, 0x25, 0x65, 0x25, 0x65, 0x25, 0x65, 0x25, 0x66, 0x26, 0x66, 0x26, 0x68, 0x25, 0x65, 0x25, 0x63, 0x24, 0x65, 0x25, 0x67, 0x25, 0x69, 0x26, 0x69, 0x25, 0x68, 0x26, 0x69, 0x26, 0x67, 0x25, 0x67, 0x25, 0x66, 0x25, 0x6A, 0x27, 0x6A, 0x26, 0x67, 0x27, 0x69, 0x27, 0x6B, 0x28, 0x69, 0x26, 0x66, 0x25, 0x69, 0x27, 0x67, 0x26, 0x69, 0x27, 0x6C, 0x28, 0x6C, 0x28, 0x6C, 0x28, 0x6D, 0x28, 0x6C, 0x27, 0x6D, 0x29, 0x70, 0x29, 0x70, 0x29, 0x70, 0x29, 0x6E, 0x28, 0x6D, 0x29, 0x6F, 0x29, 0x70, 0x2A, 0x70, 0x2B, 0x6F, 0x29, 0x70, 0x2A, 0x72, 0x2B, 0x6E, 0x29, 0x6F, 0x2B, 0x73, 0x2C, 0x6F, 0x2A, 0x6F, 0x2B, 0x75, 0x2C, 0x75, 0x2C, 0x74, 0x2E, 0x75, 0x2D, 0x72, 0x2C, 0x76, 0x2E, 0x7A, 0x2F, 0x76, 0x2F, 0x72, 0x2E, 0x7A, 0x33, 0x7B, 0x2F, 0x77, 0x2D, 0x74, 0x2E, 0x77, 0x2E, 0x76, 0x30, 0x87, 0x3F, 0x97, 0x40, 0x88, 0x3A, 0x87, 0x38, 0x85, 0x3F, 0xAA, 0x4D, 0x81, 0x36, 0x8A, 0x3F, 0xA7, 0x4D, 0xA0, 0x4C, 0x95, 0x43, 0x92, 0x44, 0xA6, 0x55, 0xD9, 0x6D, 0xAF, 0x56, 0xC2, 0x63, 0xB8, 0x5D, 0xB3, 0x57, 0xC7, 0x66, 0xB9, 0x5D, 0xBB, 0x5E, 0xC4, 0x5F, 0xB9, 0x5D, 0xA6, 0x4D, 0xA1, 0x4E, 0xB5, 0x5A, 0xCD, 0x6C, 0xD3, 0x6A, 0xC2, 0x5F, 0xC5, 0x65, 0xB5, 0x56, 0xAF, 0x5A, 0xCF, 0x66, 0xB3, 0x5A, 0xBB, 0x5F, 0xB3, 0x56, 0xAA, 0x55, 0xB3, 0x5B, 0xC1, 0x63, 0xBB, 0x59, 0xA5, 0x4F, 0x9D, 0x4A, 0xA2, 0x4F, 0x97, 0x45, 0x96, 0x40, 0x96, 0x43, 0x9D, 0x4A, 0x9B, 0x47, 0x99, 0x45, 0x8B, 0x39, 0x89, 0x3D, 0x99, 0x43, 0x82, 0x37, 0x89, 0x3C, 0x86, 0x39, 0x91, 0x45, 0x8D, 0x3A, 0x8F, 0x40, 0x83, 0x37, 0x94, 0x4A, 0xB2, 0x52, 0xAC, 0x56, 0xA4, 0x4B, 0x8E, 0x3D, 0x84, 0x38, 0x73, 0x2D, 0x75, 0x2F, 0x76, 0x2F, 0x6A, 0x2A, 0x78, 0x33, 0x75, 0x2C, 0x6C, 0x2A, 0x6F, 0x2B, 0x69, 0x29, 0x6A, 0x28, 0x68, 0x27, 0x68, 0x28, 0x66, 0x26, 0x4B, 0x1F, 0x2B, 0x18, 0x28, 0x18, 0x2B, 0x19, 0x28, 0x17, 0x22, 0x15, 0x2D, 0x1A, 0x62, 0x28, 0x6F, 0x2F, 0x7F, 0x37, 0x8D, 0x44, 0xB7, 0x5D, 0x9D, 0x48, 0x8B, 0x3C, 0x85, 0x37, 0x7C, 0x35, 0x77, 0x2F, 0x75, 0x2E, 0x70, 0x2A, 0x6A, 0x2B, 0x6B, 0x2B, 0x67, 0x28, 0x69, 0x28, 0x67, 0x27, 0x67, 0x27, 0x68, 0x27, 0x62, 0x25, 0x68, 0x2A, 0x6A, 0x27, 0x6B, 0x29, 0x65, 0x26, 0x65, 0x27, 0x66, 0x26, 0x60, 0x23, 0x68, 0x27, 0x6A, 0x27, 0x6B, 0x2A, 0x63, 0x25, 0x66, 0x27, 0x68, 0x27, 0x6B, 0x28, 0x66, 0x26, 0x68, 0x28, 0x65, 0x26, 0x67, 0x27, 0x61, 0x25, 0x60, 0x25, 0x6B, 0x2A, 0x6D, 0x2D, 0x76, 0x31, 0x69, 0x28, 0x63, 0x28, 0x68, 0x29, 0x6C, 0x2A, 0x6B, 0x2B, 0x69, 0x2B, 0x6A, 0x2C, 0x6F, 0x2E, 0x74, 0x30, 0x6F, 0x2F, 0x73, 0x32, 0x7F, 0x38, 0x6D, 0x2D, 0x6E, 0x2E, 0x74, 0x32, 0x77, 0x35, 0x7B, 0x35, 0x77, 0x33, 0x74, 0x30, 0x68, 0x29, 0x67, 0x29, 0x61, 0x26, 0x61, 0x26, 0x64, 0x28, 0x61, 0x26, 0x61, 0x25, 0x5B, 0x23, 0x5D, 0x24, 0x5D, 0x25, 0x61, 0x27, 0x62, 0x27, 0x65, 0x29, 0x61, 0x27, 0x67, 0x2B, 0x6E, 0x2E, 0x74, 0x32, 0x6B, 0x2E, 0x5F, 0x2B, 0x4C, 0x27, 0x3F, 0x23, 0x52, 0x2A, 0x44, 0x24, 0x38, 0x20, 0x40, 0x22, 0x39, 0x22, 0x41, 0x23, 0x39, 0x20, 0x37, 0x1E, 0x38, 0x1F, 0x40, 0x22, 0x34, 0x1C, 0x39, 0x20, 0x35, 0x1D, 0x3C, 0x22, 0x33, 0x1E, 0x36, 0x22, 0x35, 0x24, 0x37, 0x29, 0x38, 0x2A, 0x32, 0x28, 0x3E, 0x25, 0x45, 0x24, 0x3D, 0x21, 0x37, 0x29, 0x34, 0x32, 0x36, 0x35, 0x34, 0x34, 0x34, 0x35, 0x37, 0x37, 0x36, 0x35, 0x2E, 0x21, 0x30, 0x1E, 0x39, 0x20, 0x37, 0x29, 0x40, 0x3C, 0x40, 0x3D, 0x43, 0x3E, 0x43, 0x3D, 0x41, 0x3A, 0x3E, 0x35, 0x2A, 0x1F, 0x3A, 0x21, 0x39, 0x1F, 0x3B, 0x22, 0x42, 0x26, 0x2A, 0x1C
    },

    {
        0x6C, 0x60, 0x6D, 0x60, 0x6E, 0x60, 0x6F, 0x61, 0x6E, 0x5F, 0x6D, 0x5F, 0x6D, 0x5E, 0x70, 0x62, 0x72, 0x64, 0x70, 0x63, 0x70, 0x63, 0x70, 0x62, 0x72, 0x61, 0x6F, 0x60, 0x6F, 0x60, 0x71, 0x62, 0x72, 0x63, 0x73, 0x66, 0x73, 0x66, 0x75, 0x66, 0x73, 0x62, 0x75, 0x66, 0x78, 0x6B, 0x76, 0x6C, 0x76, 0x66, 0x72, 0x66, 0x74, 0x66, 0x74, 0x68, 0x78, 0x6A, 0x77, 0x67, 0x79, 0x6A, 0x79, 0x67, 0x79, 0x6A, 0x7A, 0x6C, 0x79, 0x67, 0x76, 0x65, 0x76, 0x66, 0x7A, 0x68, 0x7B, 0x69, 0x77, 0x67, 0x76, 0x67, 0x76, 0x66, 0x76, 0x67, 0x77, 0x67, 0x78, 0x68, 0x7A, 0x6A, 0x7B, 0x6A, 0x78, 0x68, 0x79, 0x67, 0x77, 0x66, 0x77, 0x68, 0x7A, 0x6B, 0x7C, 0x6C, 0x7A, 0x69, 0x79, 0x69, 0x7D, 0x6A, 0x79, 0x6A, 0x7A, 0x6A, 0x77, 0x67, 0x7C, 0x6E, 0x7E, 0x6C, 0x79, 0x6B, 0x7A, 0x6B, 0x7D, 0x6F, 0x7C, 0x6B, 0x7A, 0x6A, 0x80, 0x6F, 0x7D, 0x6B, 0x7C, 0x6D, 0x7F, 0x70, 0x80, 0x6F, 0x80, 0x6F, 0x80, 0x70, 0x7E, 0x6E, 0x81, 0x70, 0x82, 0x72, 0x83, 0x70, 0x84, 0x73, 0x81, 0x70, 0x7F, 0x70, 0x83, 0x73, 0x85, 0x72, 0x81, 0x74, 0x83, 0x73, 0x80, 0x72, 0x83, 0x73, 0x81, 0x71, 0x81, 0x73, 0x86, 0x75, 0x84, 0x71, 0x81, 0x72, 0x83, 0x76, 0x85, 0x74, 0x84, 0x77, 0x86, 0x79, 0x88, 0x77, 0x88, 0x79, 0x89, 0x7C, 0x85, 0x78, 0x85, 0x77, 0x8B, 0x82, 0x8E, 0x7D, 0x86, 0x76, 0x87, 0x78, 0x88, 0x7A, 0x86, 0x7C, 0x92, 0x8D, 0x9A, 0x95, 0x96, 0x8F, 0x95, 0x89, 0x91, 0x8E, 0xA9, 0xAB, 0x91, 0x86, 0x95, 0x8D, 0xA8, 0xAB, 0xA8, 0xA9, 0x9E, 0x95, 0x9A, 0x95, 0xA7, 0xAC, 0xC7, 0xCE, 0xAD, 0xAD, 0xBB, 0xC5, 0xB7, 0xB7, 0xAD, 0xAC, 0xBE, 0xCA, 0xB5, 0xB6, 0xB8, 0xBE, 0xC9, 0xCA, 0xB7, 0xBC, 0xB0, 0xAB, 0xA6, 0xA3, 0xB7, 0xBE, 0xCC, 0xD8, 0xCB, 0xD5, 0xBC, 0xC1, 0xBD, 0xC7, 0xBA, 0xC2, 0xB6, 0xBE, 0xC5, 0xD1, 0xBA, 0xBB, 0xBF, 0xC3, 0xB5, 0xB2, 0xB2, 0xBA, 0xB8, 0xB8, 0xBA, 0xC2, 0xBD, 0xBB, 0xAE, 0xAF, 0xA1, 0xA1, 0xA8, 0xA8, 0x9F, 0x9A, 0x9F, 0x98, 0xA0, 0x9F, 0xA2, 0xA1, 0x9F, 0x9B, 0x9C, 0x97, 0x97, 0x8C, 0x99, 0x91, 0x9F, 0x99, 0x8F, 0x81, 0x98, 0x94, 0x95, 0x8B, 0x9F, 0x9B, 0x99, 0x92, 0x9D, 0x99, 0x95, 0x8C, 0x9B, 0xA3, 0xAD, 0xAB, 0xA0, 0xA5, 0xAA, 0xA7, 0x98, 0x94, 0x92, 0x8A, 0x83, 0x77, 0x85, 0x7A, 0x86, 0x7B, 0x7B, 0x70, 0x83, 0x7B, 0x83, 0x73, 0x7C, 0x70, 0x7E, 0x72, 0x79, 0x6D, 0x7B, 0x6B, 0x7A, 0x6C, 0x78, 0x6D, 0x78, 0x6A, 0x5B, 0x4B, 0x30, 0x2B, 0x2C, 0x27, 0x2B, 0x29, 0x2A, 0x26, 0x23, 0x22, 0x34, 0x3A, 0x6F, 0x6B, 0x7D, 0x78, 0x8A, 0x85, 0x95, 0x94, 0xB3, 0xBF, 0xA1, 0x9A, 0x8F, 0x8D, 0x8E, 0x87, 0x87, 0x82, 0x84, 0x78, 0x83, 0x77, 0x84, 0x73, 0x7C, 0x70, 0x7B, 0x6E, 0x79, 0x6A, 0x7C, 0x6D, 0x7B, 0x6C, 0x79, 0x6A, 0x79, 0x6A, 0x74, 0x67, 0x7A, 0x6D, 0x7A, 0x6D, 0x7A, 0x6D, 0x77, 0x69, 0x77, 0x6C, 0x79, 0x6B, 0x71, 0x62, 0x77, 0x6C, 0x7B, 0x6C, 0x79, 0x6E, 0x75, 0x67, 0x73, 0x67, 0x7A, 0x6B, 0x7B, 0x6C, 0x77, 0x69, 0x77, 0x69, 0x75, 0x67, 0x75, 0x6A, 0x73, 0x63, 0x72, 0x65, 0x7B, 0x70, 0x7B, 0x73, 0x7C, 0x73, 0x7A, 0x6B, 0x76, 0x6A, 0x77, 0x6C, 0x79, 0x6D, 0x78, 0x6C, 0x77, 0x6D, 0x78, 0x6F, 0x7D, 0x74, 0x81, 0x77, 0x7E, 0x73, 0x7F, 0x75, 0x84, 0x7E, 0x7B, 0x73, 0x7B, 0x74, 0x84, 0x7B, 0x82, 0x7E, 0x84, 0x80, 0x84, 0x7A, 0x80, 0x75, 0x78, 0x6D, 0x77, 0x6C, 0x70, 0x65, 0x70, 0x64, 0x73, 0x68, 0x71, 0x66, 0x71, 0x63, 0x6D, 0x60, 0x6D, 0x61, 0x6D, 0x62, 0x6F, 0x62, 0x6F, 0x65, 0x73, 0x68, 0x70, 0x66, 0x71, 0x67, 0x79, 0x6E, 0x7A, 0x71, 0x75, 0x70, 0x5E, 0x5A, 0x48, 0x4E, 0x3A, 0x41, 0x47, 0x51, 0x3B, 0x40, 0x34, 0x3B, 0x37, 0x3B, 0x37, 0x3F, 0x3B, 0x3E, 0x33, 0x3B, 0x32, 0x35, 0x33, 0x3D, 0x3A, 0x40, 0x30, 0x33, 0x37, 0x3D, 0x34, 0x39, 0x39, 0x3F, 0x34, 0x33, 0x36, 0x39, 0x36, 0x36, 0x37, 0x39, 0x3A, 0x38, 0x35, 0x37, 0x39, 0x3F, 0x3E, 0x47, 0x38, 0x3C, 0x35, 0x37, 0x37, 0x36, 0x37, 0x36, 0x37, 0x36, 0x37, 0x36, 0x38, 0x39, 0x37, 0x35, 0x27, 0x28, 0x2D, 0x36, 0x35, 0x3B, 0x35, 0x3B, 0x3D, 0x41, 0x3A, 0x3E, 0x3B, 0x40, 0x39, 0x3F, 0x35, 0x3B, 0x31, 0x35, 0x24, 0x29, 0x35, 0x3D, 0x34, 0x3A, 0x37, 0x41, 0x38, 0x3B, 0x24, 0x26
    },

    {
        0x5E, 0x21, 0x5C, 0x20, 0x5D, 0x21, 0x5E, 0x20, 0x5D, 0x21, 0x5D, 0x21, 0x5E, 0x21, 0x60, 0x21, 0x60, 0x22, 0x61, 0x22, 0x61, 0x22, 0x60, 0x22, 0x61, 0x22, 0x60, 0x23, 0x60, 0x23, 0x62, 0x23, 0x62, 0x24, 0x61, 0x24, 0x63, 0x24, 0x61, 0x23, 0x64, 0x24, 0x66, 0x26, 0x69, 0x27, 0x64, 0x26, 0x65, 0x26, 0x64, 0x26, 0x63, 0x26, 0x66, 0x27, 0x67, 0x27, 0x66, 0x26, 0x67, 0x26, 0x67, 0x25, 0x67, 0x26, 0x65, 0x25, 0x63, 0x24, 0x61, 0x23, 0x63, 0x24, 0x69, 0x26, 0x68, 0x26, 0x65, 0x24, 0x62, 0x24, 0x65, 0x24, 0x65, 0x25, 0x65, 0x25, 0x66, 0x25, 0x66, 0x25, 0x65, 0x25, 0x64, 0x23, 0x64, 0x24, 0x64, 0x24, 0x64, 0x25, 0x63, 0x25, 0x62, 0x24, 0x63, 0x24, 0x66, 0x25, 0x67, 0x26, 0x65, 0x25, 0x64, 0x26, 0x69, 0x28, 0x6B, 0x28, 0x6B, 0x28, 0x69, 0x26, 0x67, 0x27, 0x67, 0x27, 0x67, 0x26, 0x66, 0x25, 0x69, 0x27, 0x6C, 0x28, 0x6B, 0x28, 0x6B, 0x27, 0x6B, 0x27, 0x6A, 0x27, 0x68, 0x27, 0x6A, 0x27, 0x6C, 0x28, 0x6B, 0x28, 0x6D, 0x28, 0x6E, 0x27, 0x6C, 0x28, 0x6C, 0x27, 0x6C, 0x28, 0x6D, 0x29, 0x6E, 0x29, 0x6E, 0x29, 0x6F, 0x2A, 0x6E, 0x2A, 0x6F, 0x29, 0x6F, 0x2B, 0x71, 0x2A, 0x6E, 0x29, 0x70, 0x2B, 0x72, 0x2B, 0x71, 0x2A, 0x72, 0x2C, 0x75, 0x2B, 0x74, 0x2B, 0x74, 0x2C, 0x74, 0x2C, 0x75, 0x2E, 0x78, 0x2E, 0x7E, 0x33, 0x7D, 0x31, 0x70, 0x2B, 0x75, 0x2E, 0x77, 0x2F, 0x85, 0x38, 0x82, 0x34, 0x7E, 0x35, 0x90, 0x3F, 0x89, 0x38, 0x83, 0x39, 0xA2, 0x48, 0x80, 0x34, 0x89, 0x41, 0xAE, 0x56, 0x98, 0x44, 0x9F, 0x48, 0x97, 0x43, 0x99, 0x4A, 0xA9, 0x4F, 0x9F, 0x51, 0xB3, 0x55, 0xB0, 0x56, 0xB7, 0x59, 0xA1, 0x50, 0xBF, 0x60, 0xBC, 0x5B, 0xB8, 0x5B, 0xB5, 0x55, 0xAC, 0x4E, 0x9B, 0x4B, 0xB3, 0x5C, 0xC0, 0x64, 0xC3, 0x60, 0xAF, 0x54, 0xC0, 0x68, 0xCB, 0x63, 0xBB, 0x61, 0xC5, 0x64, 0xAD, 0x57, 0xC9, 0x62, 0xA4, 0x52, 0xC2, 0x67, 0xCB, 0x62, 0xD4, 0x71, 0xB8, 0x58, 0xC2, 0x5F, 0x9D, 0x48, 0x97, 0x46, 0xA2, 0x4C, 0x92, 0x43, 0x9B, 0x4A, 0x9B, 0x49, 0x96, 0x44, 0x99, 0x44, 0x8E, 0x42, 0x8B, 0x39, 0x86, 0x39, 0x85, 0x39, 0xA0, 0x4C, 0x9C, 0x47, 0x99, 0x43, 0x94, 0x45, 0x98, 0x46, 0x9B, 0x47, 0x8D, 0x40, 0xA3, 0x4D, 0x9A, 0x47, 0x9E, 0x4A, 0xA1, 0x49, 0x8D, 0x40, 0x83, 0x39, 0x7D, 0x35, 0x80, 0x38, 0x79, 0x30, 0x6F, 0x2B, 0x73, 0x2E, 0x6F, 0x2C, 0x79, 0x32, 0x68, 0x28, 0x69, 0x28, 0x70, 0x2A, 0x6D, 0x29, 0x6A, 0x29, 0x66, 0x26, 0x39, 0x19, 0x24, 0x15, 0x21, 0x14, 0x20, 0x14, 0x28, 0x18, 0x50, 0x22, 0x6C, 0x2C, 0x74, 0x30, 0x8B, 0x41, 0x8A, 0x3D, 0x99, 0x49, 0x8E, 0x3B, 0x74, 0x30, 0x7A, 0x32, 0x78, 0x34, 0x81, 0x33, 0x6C, 0x29, 0x6D, 0x2B, 0x6A, 0x2C, 0x6C, 0x2A, 0x6E, 0x29, 0x6B, 0x29, 0x6D, 0x2D, 0x6A, 0x28, 0x65, 0x26, 0x63, 0x26, 0x64, 0x26, 0x62, 0x24, 0x63, 0x25, 0x67, 0x27, 0x68, 0x27, 0x69, 0x28, 0x64, 0x25, 0x66, 0x27, 0x68, 0x28, 0x6F, 0x2C, 0x6A, 0x29, 0x63, 0x25, 0x65, 0x26, 0x63, 0x26, 0x63, 0x25, 0x66, 0x26, 0x64, 0x25, 0x62, 0x26, 0x62, 0x25, 0x61, 0x25, 0x66, 0x27, 0x69, 0x28, 0x63, 0x27, 0x68, 0x28, 0x65, 0x27, 0x66, 0x28, 0x66, 0x27, 0x68, 0x2A, 0x6A, 0x2C, 0x72, 0x2E, 0x73, 0x32, 0x7D, 0x3B, 0x82, 0x39, 0x81, 0x3A, 0x7C, 0x35, 0x75, 0x31, 0x7C, 0x38, 0x86, 0x3D, 0x91, 0x44, 0x8A, 0x41, 0x7F, 0x39, 0x73, 0x2E, 0x6C, 0x2E, 0x6F, 0x2E, 0x67, 0x29, 0x62, 0x26, 0x60, 0x25, 0x65, 0x29, 0x63, 0x27, 0x64, 0x27, 0x66, 0x29, 0x66, 0x2A, 0x6C, 0x2C, 0x66, 0x2A, 0x68, 0x2A, 0x67, 0x2A, 0x65, 0x29, 0x6A, 0x2D, 0x73, 0x2F, 0x68, 0x2D, 0x62, 0x2D, 0x46, 0x24, 0x3D, 0x23, 0x46, 0x25, 0x3F, 0x22, 0x39, 0x20, 0x3F, 0x22, 0x3F, 0x26, 0x42, 0x29, 0x3A, 0x28, 0x39, 0x29, 0x3D, 0x2E, 0x3C, 0x2C, 0x33, 0x1D, 0x42, 0x24, 0x40, 0x22, 0x3D, 0x29, 0x35, 0x33, 0x33, 0x34, 0x34, 0x35, 0x35, 0x36, 0x36, 0x37, 0x35, 0x33, 0x28, 0x1D, 0x37, 0x20, 0x34, 0x1D, 0x34, 0x28, 0x36, 0x35, 0x33, 0x35, 0x32, 0x34, 0x31, 0x31, 0x32, 0x32, 0x2F, 0x2B, 0x20, 0x17, 0x37, 0x20, 0x44, 0x24, 0x40, 0x25, 0x3E, 0x25, 0x25, 0x1C, 0x24, 0x1A, 0x28, 0x1A, 0x28, 0x19, 0x2B, 0x1A, 0x2D, 0x1C, 0x39, 0x20, 0x3C, 0x20, 0x3A, 0x20, 0x39, 0x1F, 0x30, 0x1C
    },

    {
        0x6E, 0x60, 0x6B, 0x5D, 0x6E, 0x5F, 0x6E, 0x5F, 0x6D, 0x5E, 0x6E, 0x5F, 0x6F, 0x62, 0x71, 0x63, 0x70, 0x63, 0x71, 0x62, 0x71, 0x62, 0x71, 0x63, 0x72, 0x62, 0x71, 0x63, 0x71, 0x64, 0x71, 0x63, 0x72, 0x63, 0x72, 0x63, 0x73, 0x65, 0x72, 0x64, 0x73, 0x66, 0x77, 0x69, 0x7A, 0x6A, 0x77, 0x67, 0x77, 0x68, 0x74, 0x65, 0x71, 0x63, 0x75, 0x66, 0x78, 0x67, 0x79, 0x6A, 0x7A, 0x6B, 0x7B, 0x69, 0x7A, 0x69, 0x79, 0x67, 0x78, 0x66, 0x75, 0x65, 0x78, 0x67, 0x7C, 0x6C, 0x7A, 0x6A, 0x77, 0x67, 0x77, 0x65, 0x79, 0x69, 0x79, 0x68, 0x7A, 0x69, 0x7A, 0x68, 0x7A, 0x69, 0x79, 0x69, 0x79, 0x68, 0x77, 0x66, 0x77, 0x66, 0x76, 0x66, 0x74, 0x65, 0x74, 0x66, 0x76, 0x67, 0x7A, 0x6A, 0x7B, 0x6C, 0x7B, 0x69, 0x78, 0x69, 0x79, 0x6C, 0x7C, 0x6D, 0x7E, 0x6E, 0x7D, 0x6C, 0x7B, 0x6B, 0x7A, 0x6A, 0x79, 0x6B, 0x79, 0x69, 0x7E, 0x6F, 0x7F, 0x70, 0x7E, 0x71, 0x7E, 0x6D, 0x7F, 0x6E, 0x7C, 0x6C, 0x7E, 0x6D, 0x82, 0x6E, 0x7F, 0x6E, 0x80, 0x6E, 0x80, 0x6F, 0x84, 0x71, 0x81, 0x6F, 0x82, 0x71, 0x82, 0x6F, 0x7E, 0x6F, 0x80, 0x6F, 0x81, 0x71, 0x81, 0x73, 0x83, 0x71, 0x82, 0x71, 0x7F, 0x72, 0x84, 0x73, 0x84, 0x70, 0x81, 0x75, 0x85, 0x78, 0x84, 0x74, 0x83, 0x77, 0x88, 0x78, 0x87, 0x75, 0x85, 0x75, 0x85, 0x76, 0x86, 0x7B, 0x8A, 0x7A, 0x8C, 0x81, 0x88, 0x7B, 0x81, 0x73, 0x84, 0x77, 0x86, 0x7B, 0x90, 0x90, 0x92, 0x84, 0x8E, 0x84, 0x9A, 0x93, 0x95, 0x8A, 0x8E, 0x82, 0xA3, 0xA3, 0x8D, 0x81, 0x93, 0x96, 0xA7, 0xAB, 0x9E, 0x96, 0xAA, 0xAE, 0xA4, 0x9D, 0x9F, 0x9F, 0xA8, 0xA4, 0xA0, 0x9F, 0xAA, 0xAA, 0xAE, 0xB1, 0xBA, 0xBC, 0xA6, 0xA9, 0xC0, 0xCC, 0xC2, 0xBE, 0xB7, 0xBC, 0xBC, 0xB9, 0xAC, 0xA7, 0xA3, 0xA2, 0xB7, 0xBA, 0xBF, 0xC5, 0xC1, 0xC1, 0xB2, 0xAB, 0xBE, 0xCE, 0xC1, 0xC0, 0xB5, 0xBF, 0xB6, 0xBC, 0xB1, 0xB5, 0xBC, 0xBD, 0xA9, 0xAA, 0xBB, 0xC7, 0xBF, 0xC3, 0xD0, 0xE0, 0xB9, 0xB6, 0xBB, 0xBE, 0xA2, 0x9F, 0xA5, 0x9F, 0xA8, 0xA8, 0x99, 0x97, 0xA1, 0xA1, 0x9F, 0x9D, 0x9C, 0x9B, 0x9A, 0x95, 0x99, 0x93, 0x93, 0x89, 0x96, 0x8D, 0x94, 0x8C, 0xA6, 0xAA, 0xAA, 0xA8, 0xA3, 0x9D, 0xA4, 0xA0, 0x9E, 0x99, 0xA1, 0xA2, 0x9A, 0x96, 0xA8, 0xAA, 0xA2, 0x9F, 0xA0, 0x9A, 0x9E, 0x97, 0x98, 0x94, 0x8D, 0x86, 0x8B, 0x81, 0x88, 0x80, 0x85, 0x7A, 0x81, 0x74, 0x81, 0x76, 0x7E, 0x75, 0x80, 0x7B, 0x7A, 0x6C, 0x7C, 0x6F, 0x7C, 0x70, 0x7A, 0x6F, 0x7D, 0x71, 0x78, 0x68, 0x4D, 0x40, 0x2D, 0x27, 0x24, 0x22, 0x23, 0x22, 0x34, 0x37, 0x63, 0x5D, 0x77, 0x6F, 0x7F, 0x76, 0x8E, 0x8B, 0x8C, 0x83, 0x91, 0x8D, 0x92, 0x87, 0x83, 0x77, 0x85, 0x78, 0x81, 0x7B, 0x88, 0x7E, 0x7C, 0x6C, 0x7D, 0x73, 0x7C, 0x6E, 0x7C, 0x6F, 0x80, 0x70, 0x7D, 0x70, 0x7E, 0x78, 0x7B, 0x71, 0x77, 0x68, 0x75, 0x68, 0x75, 0x68, 0x74, 0x66, 0x72, 0x65, 0x77, 0x6A, 0x7A, 0x6B, 0x7B, 0x6D, 0x77, 0x67, 0x76, 0x67, 0x79, 0x6C, 0x79, 0x72, 0x79, 0x6E, 0x75, 0x65, 0x77, 0x68, 0x74, 0x67, 0x75, 0x67, 0x77, 0x69, 0x74, 0x66, 0x72, 0x67, 0x75, 0x66, 0x74, 0x66, 0x71, 0x66, 0x78, 0x6A, 0x73, 0x69, 0x7B, 0x6D, 0x77, 0x6A, 0x72, 0x68, 0x78, 0x6C, 0x7C, 0x70, 0x7A, 0x71, 0x81, 0x78, 0x7F, 0x77, 0x84, 0x83, 0x8B, 0x86, 0x8B, 0x87, 0x88, 0x80, 0x81, 0x79, 0x85, 0x81, 0x89, 0x88, 0x95, 0x95, 0x8F, 0x8D, 0x8A, 0x84, 0x7F, 0x74, 0x77, 0x71, 0x7C, 0x71, 0x72, 0x68, 0x73, 0x66, 0x71, 0x62, 0x73, 0x6B, 0x73, 0x65, 0x75, 0x69, 0x75, 0x6B, 0x76, 0x6D, 0x7A, 0x6E, 0x76, 0x6D, 0x75, 0x6D, 0x75, 0x6B, 0x73, 0x69, 0x78, 0x71, 0x80, 0x76, 0x76, 0x6F, 0x60, 0x5C, 0x40, 0x42, 0x3B, 0x44, 0x40, 0x47, 0x3C, 0x44, 0x37, 0x40, 0x3D, 0x41, 0x3E, 0x42, 0x40, 0x43, 0x38, 0x3B, 0x39, 0x3A, 0x3C, 0x3E, 0x3A, 0x3B, 0x2E, 0x32, 0x3C, 0x48, 0x38, 0x3D, 0x3B, 0x3C, 0x37, 0x34, 0x35, 0x33, 0x36, 0x34, 0x37, 0x36, 0x38, 0x36, 0x34, 0x33, 0x23, 0x26, 0x31, 0x3A, 0x30, 0x34, 0x33, 0x35, 0x35, 0x36, 0x31, 0x32, 0x2E, 0x30, 0x2C, 0x2D, 0x2B, 0x2F, 0x29, 0x2B, 0x1E, 0x22, 0x31, 0x3B, 0x3D, 0x45, 0x3B, 0x47, 0x34, 0x37, 0x21, 0x23, 0x22, 0x27, 0x27, 0x2B, 0x28, 0x2B, 0x2B, 0x31, 0x2E, 0x36, 0x33, 0x3B, 0x35, 0x3B, 0x34, 0x3C, 0x33, 0x37, 0x2D, 0x34
    },

    {
        0x5B, 0x21, 0x5A, 0x1F, 0x5B, 0x20, 0x5C, 0x1F, 0x59, 0x1F, 0x5C, 0x20, 0x5D, 0x21, 0x5D, 0x21, 0x5F, 0x22, 0x5F, 0x22, 0x61, 0x22, 0x62, 0x23, 0x60, 0x22, 0x5F, 0x22, 0x62, 0x23, 0x62, 0x24, 0x62, 0x24, 0x62, 0x24, 0x61, 0x24, 0x65, 0x26, 0x66, 0x26, 0x66, 0x25, 0x65, 0x25, 0x64, 0x25, 0x64, 0x24, 0x60, 0x24, 0x62, 0x25, 0x64, 0x25, 0x66, 0x26, 0x66, 0x26, 0x67, 0x26, 0x67, 0x26, 0x68, 0x26, 0x66, 0x24, 0x64, 0x25, 0x65, 0x25, 0x63, 0x25, 0x65, 0x25, 0x65, 0x25, 0x63, 0x24, 0x61, 0x24, 0x63, 0x23, 0x65, 0x25, 0x64, 0x24, 0x66, 0x25, 0x67, 0x25, 0x65, 0x25, 0x67, 0x26, 0x67, 0x25, 0x65, 0x25, 0x65, 0x25, 0x63, 0x24, 0x63, 0x25, 0x65, 0x25, 0x68, 0x25, 0x67, 0x25, 0x68, 0x26, 0x69, 0x29, 0x6A, 0x2C, 0x68, 0x28, 0x69, 0x26, 0x68, 0x27, 0x67, 0x26, 0x68, 0x26, 0x67, 0x26, 0x6B, 0x27, 0x6E, 0x29, 0x6D, 0x2A, 0x71, 0x2A, 0x6C, 0x28, 0x6E, 0x28, 0x6C, 0x28, 0x6C, 0x27, 0x6F, 0x28, 0x6E, 0x29, 0x6D, 0x28, 0x6E, 0x28, 0x6F, 0x29, 0x70, 0x29, 0x6E, 0x28, 0x6D, 0x29, 0x6E, 0x28, 0x6F, 0x29, 0x6E, 0x29, 0x6D, 0x28, 0x72, 0x2A, 0x70, 0x2B, 0x70, 0x2A, 0x71, 0x2A, 0x73, 0x2B, 0x70, 0x2B, 0x72, 0x2C, 0x74, 0x2D, 0x73, 0x2E, 0x79, 0x2F, 0x6E, 0x29, 0x70, 0x2B, 0x72, 0x2B, 0x75, 0x2D, 0x76, 0x2E, 0x76, 0x2E, 0x77, 0x2F, 0x72, 0x2C, 0x76, 0x2F, 0x7A, 0x30, 0x84, 0x38, 0x87, 0x37, 0x7D, 0x36, 0x87, 0x39, 0x86, 0x38, 0x7E, 0x36, 0x8D, 0x3B, 0x82, 0x35, 0x84, 0x3A, 0x95, 0x45, 0xA2, 0x4C, 0xAB, 0x52, 0x98, 0x43, 0x93, 0x42, 0x95, 0x44, 0x94, 0x45, 0x9B, 0x47, 0xAA, 0x55, 0xAC, 0x50, 0xA4, 0x54, 0xC1, 0x60, 0xC2, 0x5F, 0xBF, 0x63, 0xC8, 0x63, 0xAC, 0x4F, 0xA2, 0x4E, 0xA2, 0x4E, 0xC1, 0x67, 0xE4, 0x7A, 0xCB, 0x5D, 0xB6, 0x59, 0xA7, 0x51, 0xB6, 0x58, 0xB5, 0x59, 0xB2, 0x54, 0xBC, 0x5E, 0xB9, 0x5A, 0xAD, 0x52, 0xA3, 0x51, 0xAA, 0x51, 0xA8, 0x50, 0xAC, 0x51, 0xA7, 0x50, 0xA3, 0x4C, 0x99, 0x46, 0xA1, 0x47, 0x90, 0x3F, 0x84, 0x37, 0x8A, 0x3C, 0x88, 0x3D, 0x85, 0x39, 0x85, 0x38, 0x8F, 0x42, 0xA1, 0x50, 0xB1, 0x56, 0xA7, 0x4E, 0xA3, 0x4F, 0xC2, 0x5B, 0xA8, 0x4D, 0x8C, 0x42, 0xB0, 0x5B, 0xC4, 0x62, 0xA5, 0x4C, 0x8B, 0x3A, 0x99, 0x47, 0x9F, 0x4D, 0x8F, 0x3E, 0x7D, 0x34, 0x83, 0x37, 0x79, 0x31, 0x74, 0x30, 0x75, 0x2D, 0x75, 0x30, 0x75, 0x30, 0x72, 0x2D, 0x6D, 0x2B, 0x6A, 0x28, 0x6A, 0x27, 0x69, 0x29, 0x6C, 0x2B, 0x6C, 0x28, 0x4E, 0x20, 0x43, 0x1D, 0x44, 0x1F, 0x5B, 0x24, 0x65, 0x27, 0x67, 0x28, 0x6B, 0x2B, 0x7A, 0x35, 0x7A, 0x34, 0x7D, 0x37, 0x8A, 0x3E, 0x7D, 0x2F, 0x6D, 0x2B, 0x6B, 0x2A, 0x6E, 0x2A, 0x6B, 0x27, 0x69, 0x29, 0x6A, 0x28, 0x6C, 0x2A, 0x6B, 0x29, 0x6D, 0x28, 0x6C, 0x2B, 0x72, 0x2D, 0x6C, 0x29, 0x67, 0x27, 0x66, 0x28, 0x66, 0x27, 0x68, 0x27, 0x69, 0x29, 0x69, 0x28, 0x67, 0x27, 0x62, 0x24, 0x63, 0x26, 0x67, 0x27, 0x65, 0x27, 0x66, 0x27, 0x65, 0x26, 0x67, 0x26, 0x67, 0x27, 0x66, 0x26, 0x67, 0x27, 0x62, 0x25, 0x62, 0x24, 0x63, 0x26, 0x66, 0x28, 0x61, 0x24, 0x62, 0x28, 0x6B, 0x2A, 0x6C, 0x2C, 0x6C, 0x2C, 0x6A, 0x2A, 0x72, 0x30, 0x73, 0x2D, 0x73, 0x30, 0x77, 0x31, 0x74, 0x31, 0x80, 0x39, 0x87, 0x3D, 0x7C, 0x37, 0x80, 0x39, 0x78, 0x35, 0x72, 0x30, 0x71, 0x2E, 0x7C, 0x39, 0x98, 0x49, 0x7F, 0x38, 0x8B, 0x40, 0x79, 0x31, 0x6E, 0x2D, 0x65, 0x29, 0x62, 0x25, 0x5B, 0x22, 0x5F, 0x27, 0x60, 0x24, 0x62, 0x26, 0x69, 0x2A, 0x69, 0x2B, 0x6C, 0x2E, 0x71, 0x31, 0x6A, 0x2B, 0x67, 0x29, 0x66, 0x2A, 0x6A, 0x2C, 0x76, 0x32, 0x68, 0x2B, 0x65, 0x33, 0x51, 0x2A, 0x4A, 0x27, 0x4D, 0x28, 0x46, 0x25, 0x4B, 0x2B, 0x4A, 0x37, 0x3A, 0x39, 0x38, 0x39, 0x36, 0x37, 0x35, 0x37, 0x34, 0x37, 0x31, 0x2F, 0x26, 0x1B, 0x3B, 0x20, 0x31, 0x1B, 0x3A, 0x2A, 0x36, 0x34, 0x32, 0x34, 0x31, 0x34, 0x32, 0x33, 0x2E, 0x2D, 0x29, 0x26, 0x1F, 0x18, 0x39, 0x20, 0x3E, 0x22, 0x3F, 0x22, 0x2F, 0x1E, 0x23, 0x1A, 0x20, 0x16, 0x21, 0x17, 0x22, 0x16, 0x28, 0x18, 0x26, 0x18, 0x33, 0x1D, 0x3B, 0x20, 0x3F, 0x23, 0x37, 0x1E, 0x2E, 0x1A, 0x37, 0x1F, 0x42, 0x22, 0x39, 0x1F, 0x3C, 0x21, 0x3F, 0x22, 0x37, 0x1E, 0x3C, 0x20, 0x3B, 0x1F, 0x3D, 0x20, 0x37, 0x1E
    },

    {
        0x6A, 0x5D, 0x6A, 0x5D, 0x6B, 0x5C, 0x6C, 0x5D, 0x6A, 0x5C, 0x6C, 0x5E, 0x6F, 0x5F, 0x6E, 0x60, 0x6E, 0x61, 0x71, 0x61, 0x71, 0x63, 0x71, 0x64, 0x71, 0x62, 0x71, 0x63, 0x71, 0x63, 0x73, 0x65, 0x75, 0x66, 0x72, 0x64, 0x72, 0x64, 0x77, 0x68, 0x79, 0x6A, 0x76, 0x66, 0x76, 0x65, 0x76, 0x66, 0x74, 0x64, 0x73, 0x64, 0x74, 0x65, 0x76, 0x67, 0x7A, 0x68, 0x79, 0x69, 0x7B, 0x6A, 0x7A, 0x6A, 0x7A, 0x68, 0x7B, 0x68, 0x79, 0x67, 0x7A, 0x68, 0x79, 0x69, 0x78, 0x68, 0x79, 0x68, 0x76, 0x63, 0x74, 0x64, 0x76, 0x64, 0x7B, 0x69, 0x79, 0x65, 0x77, 0x66, 0x79, 0x68, 0x77, 0x68, 0x7B, 0x6B, 0x7A, 0x68, 0x77, 0x67, 0x7A, 0x68, 0x77, 0x66, 0x77, 0x67, 0x77, 0x67, 0x79, 0x68, 0x79, 0x69, 0x7B, 0x6C, 0x7B, 0x6B, 0x7A, 0x6E, 0x79, 0x6B, 0x7A, 0x6A, 0x79, 0x69, 0x7A, 0x6A, 0x7B, 0x6A, 0x7C, 0x6C, 0x7E, 0x6E, 0x7F, 0x6E, 0x7D, 0x71, 0x83, 0x75, 0x83, 0x73, 0x81, 0x71, 0x81, 0x6F, 0x80, 0x6E, 0x81, 0x71, 0x83, 0x72, 0x82, 0x72, 0x81, 0x70, 0x83, 0x73, 0x82, 0x72, 0x82, 0x71, 0x81, 0x71, 0x82, 0x73, 0x82, 0x72, 0x82, 0x70, 0x82, 0x72, 0x82, 0x75, 0x82, 0x73, 0x84, 0x75, 0x83, 0x74, 0x86, 0x76, 0x83, 0x74, 0x84, 0x77, 0x85, 0x77, 0x85, 0x77, 0x87, 0x7B, 0x82, 0x71, 0x84, 0x77, 0x84, 0x75, 0x85, 0x76, 0x89, 0x7B, 0x88, 0x78, 0x87, 0x7B, 0x84, 0x77, 0x86, 0x7C, 0x8B, 0x81, 0x90, 0x88, 0x93, 0x89, 0x8D, 0x84, 0x94, 0x87, 0x96, 0x8B, 0x8E, 0x84, 0x93, 0x8C, 0x90, 0x87, 0x90, 0x89, 0x97, 0x95, 0xA0, 0xA0, 0xA7, 0xAB, 0x9F, 0x95, 0x9B, 0x94, 0x99, 0x94, 0x9E, 0x9D, 0xA1, 0x99, 0xAD, 0xB2, 0xAA, 0xA5, 0xAC, 0xAD, 0xC4, 0xC9, 0xBC, 0xC1, 0xBA, 0xC3, 0xC0, 0xC8, 0xAD, 0xAB, 0xAA, 0xA4, 0xA9, 0xAB, 0xC0, 0xC9, 0xD5, 0xF0, 0xC3, 0xC0, 0xB5, 0xB7, 0xA6, 0xA5, 0xB3, 0xB8, 0xB8, 0xBB, 0xAD, 0xAC, 0xBD, 0xC9, 0xBD, 0xC4, 0xB2, 0xAC, 0xAD, 0xA6, 0xA7, 0xAA, 0xAC, 0xA9, 0xAA, 0xAB, 0xAE, 0xAF, 0xAA, 0xA9, 0xA2, 0xA0, 0xA5, 0x9F, 0x92, 0x8F, 0x93, 0x85, 0x96, 0x8E, 0x92, 0x8E, 0x97, 0x8D, 0x96, 0x89, 0x9B, 0x96, 0xA5, 0xAD, 0xAE, 0xB6, 0xAB, 0xA9, 0xA9, 0xAD, 0xBB, 0xBC, 0xA8, 0xAA, 0x91, 0x8A, 0xAE, 0xBB, 0xBF, 0xC6, 0xAB, 0xA8, 0x97, 0x8E, 0xA2, 0xA1, 0xA8, 0xAD, 0x96, 0x91, 0x88, 0x81, 0x8E, 0x87, 0x85, 0x7C, 0x80, 0x79, 0x81, 0x76, 0x7F, 0x76, 0x7F, 0x75, 0x82, 0x75, 0x7B, 0x71, 0x78, 0x6B, 0x77, 0x6A, 0x78, 0x6A, 0x7B, 0x70, 0x79, 0x6C, 0x64, 0x59, 0x58, 0x50, 0x59, 0x54, 0x6D, 0x64, 0x74, 0x6A, 0x77, 0x6C, 0x7A, 0x71, 0x83, 0x7E, 0x83, 0x7A, 0x8B, 0x84, 0x90, 0x8C, 0x89, 0x7B, 0x7D, 0x70, 0x79, 0x70, 0x7B, 0x6E, 0x7C, 0x6B, 0x79, 0x6E, 0x7F, 0x71, 0x7C, 0x6E, 0x7B, 0x6E, 0x7E, 0x70, 0x7D, 0x70, 0x7B, 0x70, 0x7B, 0x6C, 0x75, 0x69, 0x78, 0x6D, 0x77, 0x6B, 0x78, 0x6B, 0x7C, 0x6E, 0x7B, 0x6E, 0x79, 0x6A, 0x75, 0x67, 0x76, 0x68, 0x78, 0x6B, 0x76, 0x68, 0x79, 0x6A, 0x77, 0x6A, 0x78, 0x67, 0x77, 0x69, 0x7A, 0x6C, 0x79, 0x6B, 0x76, 0x67, 0x72, 0x65, 0x73, 0x66, 0x78, 0x6B, 0x74, 0x65, 0x73, 0x68, 0x79, 0x6F, 0x79, 0x72, 0x7A, 0x6E, 0x79, 0x6E, 0x80, 0x78, 0x82, 0x75, 0x83, 0x7B, 0x84, 0x79, 0x84, 0x7E, 0x8E, 0x88, 0x93, 0x8D, 0x83, 0x7C, 0x85, 0x7E, 0x7F, 0x7B, 0x7E, 0x76, 0x7E, 0x74, 0x83, 0x7F, 0x92, 0x91, 0x85, 0x7F, 0x8F, 0x8F, 0x84, 0x79, 0x7A, 0x6F, 0x71, 0x67, 0x72, 0x64, 0x6A, 0x5D, 0x6D, 0x63, 0x6E, 0x61, 0x6E, 0x67, 0x77, 0x6E, 0x79, 0x6D, 0x76, 0x6E, 0x7A, 0x74, 0x77, 0x6C, 0x72, 0x67, 0x74, 0x69, 0x77, 0x6B, 0x7B, 0x73, 0x74, 0x6A, 0x64, 0x66, 0x4D, 0x54, 0x40, 0x49, 0x45, 0x4F, 0x3A, 0x40, 0x42, 0x52, 0x43, 0x45, 0x3C, 0x39, 0x3A, 0x38, 0x38, 0x37, 0x37, 0x36, 0x37, 0x36, 0x30, 0x2E, 0x23, 0x29, 0x33, 0x3A, 0x2F, 0x33, 0x3B, 0x3D, 0x36, 0x35, 0x31, 0x31, 0x2E, 0x2F, 0x2C, 0x2D, 0x28, 0x2A, 0x23, 0x25, 0x1E, 0x23, 0x36, 0x41, 0x3B, 0x44, 0x3A, 0x42, 0x2B, 0x2B, 0x22, 0x24, 0x21, 0x23, 0x22, 0x26, 0x23, 0x27, 0x29, 0x2D, 0x28, 0x2C, 0x32, 0x39, 0x35, 0x39, 0x38, 0x43, 0x32, 0x37, 0x2F, 0x34, 0x35, 0x3E, 0x3C, 0x45, 0x34, 0x3A, 0x38, 0x40, 0x38, 0x3E, 0x33, 0x39, 0x39, 0x41, 0x38, 0x3F, 0x39, 0x3F, 0x34, 0x3B
    },

    {
        0x5D, 0x21, 0x5C, 0x20, 0x5C, 0x20, 0x5C, 0x20, 0x5D, 0x20, 0x5C, 0x20, 0x5D, 0x21, 0x5E, 0x21, 0x5E, 0x22, 0x62, 0x23, 0x63, 0x24, 0x61, 0x23, 0x60, 0x23, 0x62, 0x23, 0x61, 0x23, 0x62, 0x25, 0x66, 0x26, 0x63, 0x25, 0x62, 0x24, 0x64, 0x25, 0x64, 0x24, 0x62, 0x23, 0x63, 0x24, 0x62, 0x24, 0x61, 0x23, 0x61, 0x24, 0x65, 0x25, 0x64, 0x25, 0x66, 0x25, 0x67, 0x26, 0x69, 0x27, 0x69, 0x28, 0x67, 0x26, 0x65, 0x25, 0x65, 0x25, 0x64, 0x24, 0x65, 0x25, 0x66, 0x26, 0x65, 0x25, 0x66, 0x25, 0x64, 0x24, 0x65, 0x25, 0x67, 0x25, 0x64, 0x25, 0x64, 0x25, 0x63, 0x24, 0x66, 0x24, 0x66, 0x25, 0x63, 0x24, 0x63, 0x24, 0x65, 0x25, 0x66, 0x25, 0x66, 0x25, 0x66, 0x25, 0x63, 0x24, 0x62, 0x24, 0x65, 0x28, 0x70, 0x33, 0x7C, 0x34, 0x6C, 0x29, 0x6A, 0x27, 0x69, 0x26, 0x66, 0x26, 0x64, 0x25, 0x67, 0x26, 0x67, 0x27, 0x6A, 0x27, 0x6D, 0x29, 0x71, 0x2A, 0x6D, 0x29, 0x6D, 0x29, 0x6E, 0x28, 0x6E, 0x29, 0x71, 0x2A, 0x6F, 0x2A, 0x6C, 0x28, 0x6E, 0x29, 0x70, 0x2A, 0x70, 0x29, 0x6D, 0x28, 0x6D, 0x28, 0x6F, 0x28, 0x6E, 0x2A, 0x6F, 0x29, 0x70, 0x29, 0x70, 0x2A, 0x72, 0x2C, 0x78, 0x2F, 0x76, 0x2C, 0x74, 0x2B, 0x72, 0x2B, 0x74, 0x2C, 0x71, 0x2A, 0x71, 0x2A, 0x75, 0x2C, 0x73, 0x2B, 0x6E, 0x2A, 0x72, 0x2C, 0x76, 0x2E, 0x77, 0x2E, 0x74, 0x2D, 0x73, 0x2D, 0x74, 0x2C, 0x77, 0x2F, 0x7A, 0x31, 0x7D, 0x33, 0x82, 0x36, 0x7F, 0x34, 0x85, 0x38, 0x84, 0x36, 0x7F, 0x35, 0x82, 0x35, 0x7B, 0x33, 0x86, 0x3A, 0x81, 0x35, 0x84, 0x3B, 0x9C, 0x48, 0x93, 0x40, 0x93, 0x42, 0x8A, 0x3C, 0x92, 0x41, 0x94, 0x42, 0x90, 0x40, 0x91, 0x44, 0x9F, 0x4D, 0xB4, 0x5E, 0xB3, 0x5A, 0xBB, 0x5A, 0xBB, 0x5D, 0xAE, 0x50, 0xA5, 0x4F, 0xC4, 0x65, 0xC0, 0x5D, 0xC3, 0x6A, 0xB8, 0x5A, 0xA9, 0x4D, 0x8E, 0x41, 0x9E, 0x4C, 0xAE, 0x54, 0xA7, 0x4F, 0xB6, 0x5B, 0xB7, 0x5B, 0xB2, 0x5A, 0xAF, 0x55, 0xBC, 0x62, 0xC6, 0x65, 0xB8, 0x57, 0x9C, 0x47, 0x9F, 0x49, 0xA6, 0x51, 0x8F, 0x39, 0x80, 0x39, 0x86, 0x3A, 0x88, 0x3C, 0x8A, 0x3E, 0xAA, 0x55, 0x92, 0x40, 0xA0, 0x4D, 0x95, 0x43, 0xAB, 0x56, 0xB2, 0x54, 0x99, 0x46, 0xB6, 0x59, 0xA7, 0x4E, 0x81, 0x35, 0x97, 0x4A, 0xA0, 0x4F, 0xA4, 0x50, 0xAC, 0x52, 0x9D, 0x4C, 0xAB, 0x53, 0x8F, 0x3E, 0x79, 0x32, 0x7D, 0x37, 0x7A, 0x34, 0x76, 0x30, 0x73, 0x2D, 0x6C, 0x2C, 0x6E, 0x2C, 0x71, 0x2C, 0x66, 0x28, 0x67, 0x27, 0x69, 0x27, 0x64, 0x26, 0x62, 0x25, 0x63, 0x25, 0x63, 0x26, 0x61, 0x25, 0x61, 0x24, 0x65, 0x27, 0x64, 0x26, 0x68, 0x29, 0x6B, 0x2C, 0x79, 0x34, 0x7A, 0x36, 0x7E, 0x36, 0x76, 0x37, 0x8D, 0x3D, 0x7A, 0x32, 0x68, 0x2A, 0x6E, 0x2A, 0x66, 0x27, 0x67, 0x27, 0x68, 0x28, 0x68, 0x28, 0x6A, 0x29, 0x6C, 0x29, 0x6B, 0x29, 0x6A, 0x28, 0x69, 0x27, 0x64, 0x27, 0x68, 0x2A, 0x6B, 0x29, 0x67, 0x27, 0x68, 0x28, 0x6B, 0x28, 0x68, 0x29, 0x6A, 0x28, 0x6B, 0x29, 0x69, 0x28, 0x69, 0x28, 0x6B, 0x28, 0x64, 0x25, 0x64, 0x25, 0x64, 0x27, 0x65, 0x28, 0x66, 0x29, 0x68, 0x27, 0x67, 0x26, 0x66, 0x27, 0x65, 0x29, 0x66, 0x28, 0x6C, 0x29, 0x6F, 0x2E, 0x71, 0x2F, 0x6F, 0x2C, 0x6E, 0x2E, 0x75, 0x30, 0x74, 0x31, 0x7E, 0x3A, 0x74, 0x30, 0x83, 0x3A, 0x80, 0x38, 0x99, 0x4B, 0x89, 0x3B, 0x78, 0x36, 0x7D, 0x38, 0x7D, 0x38, 0x7F, 0x39, 0x8A, 0x3E, 0x7E, 0x39, 0x84, 0x3C, 0x81, 0x3A, 0x80, 0x3A, 0x75, 0x30, 0x6D, 0x2D, 0x68, 0x28, 0x5F, 0x25, 0x60, 0x26, 0x5C, 0x24, 0x60, 0x28, 0x6B, 0x2D, 0x75, 0x33, 0x68, 0x2C, 0x6E, 0x30, 0x6F, 0x2F, 0x6B, 0x2C, 0x69, 0x2B, 0x6C, 0x2D, 0x6C, 0x2C, 0x6C, 0x2F, 0x6C, 0x36, 0x56, 0x2B, 0x44, 0x26, 0x43, 0x23, 0x36, 0x1F, 0x45, 0x26, 0x3D, 0x33, 0x38, 0x39, 0x35, 0x36, 0x33, 0x34, 0x2F, 0x2F, 0x2D, 0x2E, 0x27, 0x22, 0x21, 0x17, 0x37, 0x1E, 0x3E, 0x20, 0x43, 0x24, 0x32, 0x1F, 0x23, 0x18, 0x22, 0x17, 0x24, 0x18, 0x24, 0x17, 0x2A, 0x19, 0x28, 0x18, 0x44, 0x24, 0x3C, 0x20, 0x3D, 0x20, 0x34, 0x1C, 0x37, 0x1E, 0x33, 0x1C, 0x36, 0x1E, 0x33, 0x1C, 0x37, 0x1F, 0x36, 0x1D, 0x38, 0x20, 0x3D, 0x22, 0x40, 0x23, 0x46, 0x24, 0x40, 0x21, 0x40, 0x23, 0x46, 0x24, 0x3B, 0x20, 0x3E, 0x20, 0x3D, 0x20, 0x3A, 0x20, 0x45, 0x23, 0x3B, 0x20, 0x3C, 0x1F, 0x39, 0x1F
    },

    {
        0x6F, 0x5F, 0x6E, 0x5F, 0x6E, 0x5F, 0x6E, 0x5F, 0x6E, 0x5E, 0x6C, 0x5D, 0x6E, 0x5E, 0x6F, 0x5F, 0x6E, 0x62, 0x71, 0x63, 0x70, 0x64, 0x70, 0x61, 0x70, 0x61, 0x74, 0x65, 0x75, 0x64, 0x74, 0x67, 0x75, 0x67, 0x74, 0x66, 0x72, 0x66, 0x77, 0x66, 0x79, 0x67, 0x77, 0x66, 0x77, 0x63, 0x75, 0x64, 0x76, 0x64, 0x76, 0x64, 0x77, 0x68, 0x7A, 0x67, 0x7A, 0x68, 0x79, 0x69, 0x7C, 0x6A, 0x7C, 0x6B, 0x7D, 0x6A, 0x7B, 0x67, 0x7A, 0x66, 0x78, 0x66, 0x79, 0x68, 0x77, 0x68, 0x76, 0x67, 0x79, 0x67, 0x76, 0x67, 0x78, 0x69, 0x79, 0x68, 0x79, 0x67, 0x74, 0x65, 0x75, 0x65, 0x79, 0x66, 0x78, 0x67, 0x78, 0x67, 0x78, 0x66, 0x79, 0x68, 0x78, 0x68, 0x7A, 0x6A, 0x7B, 0x69, 0x77, 0x65, 0x78, 0x66, 0x7A, 0x6B, 0x81, 0x7C, 0x89, 0x7E, 0x7D, 0x6E, 0x7B, 0x6B, 0x7D, 0x6B, 0x7B, 0x68, 0x7A, 0x67, 0x7B, 0x68, 0x7C, 0x6B, 0x7D, 0x6A, 0x7C, 0x6F, 0x80, 0x71, 0x7F, 0x6F, 0x80, 0x70, 0x81, 0x71, 0x81, 0x70, 0x84, 0x74, 0x84, 0x71, 0x81, 0x70, 0x81, 0x70, 0x81, 0x71, 0x7F, 0x71, 0x7F, 0x70, 0x7E, 0x70, 0x82, 0x72, 0x82, 0x71, 0x83, 0x74, 0x86, 0x74, 0x85, 0x75, 0x86, 0x78, 0x89, 0x7C, 0x86, 0x76, 0x88, 0x77, 0x86, 0x75, 0x86, 0x78, 0x84, 0x72, 0x84, 0x73, 0x88, 0x78, 0x89, 0x75, 0x80, 0x71, 0x81, 0x75, 0x88, 0x7A, 0x88, 0x7A, 0x86, 0x77, 0x87, 0x77, 0x84, 0x76, 0x88, 0x7C, 0x8A, 0x7D, 0x8D, 0x82, 0x8F, 0x87, 0x8E, 0x80, 0x8F, 0x84, 0x8F, 0x84, 0x8E, 0x80, 0x8F, 0x84, 0x8B, 0x7C, 0x90, 0x8A, 0x90, 0x85, 0x90, 0x89, 0xA0, 0x9F, 0x9D, 0x94, 0x9C, 0x97, 0x99, 0x8D, 0x9A, 0x8F, 0x9C, 0x93, 0x9E, 0x94, 0x9F, 0x98, 0xA5, 0xA4, 0xA3, 0xA7, 0xB4, 0xB7, 0xB8, 0xBD, 0xBD, 0xC3, 0xB0, 0xAE, 0xAE, 0xAC, 0xC2, 0xCF, 0xC5, 0xC6, 0xC3, 0xCC, 0xB9, 0xB9, 0xAE, 0xA7, 0x9D, 0x93, 0xA2, 0xA1, 0xAC, 0xAD, 0xAD, 0xAA, 0xB2, 0xB1, 0xBB, 0xC5, 0xB7, 0xB9, 0xB1, 0xB6, 0xC3, 0xD3, 0xC9, 0xD9, 0xBB, 0xBD, 0xA4, 0xA0, 0xA2, 0x9A, 0xA4, 0xA8, 0x97, 0x85, 0x8E, 0x89, 0x92, 0x8A, 0x97, 0x93, 0x9C, 0x94, 0xAA, 0xB0, 0x9F, 0x9A, 0xAA, 0xAC, 0x9C, 0x95, 0xAC, 0xB2, 0xAD, 0xAE, 0xA2, 0x9C, 0xB6, 0xBA, 0xA6, 0xA7, 0x8F, 0x82, 0x9A, 0x99, 0xA2, 0xAC, 0xA4, 0xA5, 0xA7, 0xA5, 0xA2, 0xA3, 0xAA, 0xA8, 0x97, 0x8D, 0x85, 0x78, 0x87, 0x82, 0x89, 0x7F, 0x83, 0x78, 0x81, 0x76, 0x80, 0x74, 0x80, 0x73, 0x81, 0x73, 0x79, 0x69, 0x7C, 0x6C, 0x78, 0x6A, 0x76, 0x68, 0x74, 0x65, 0x73, 0x64, 0x72, 0x65, 0x71, 0x64, 0x71, 0x66, 0x75, 0x69, 0x76, 0x69, 0x76, 0x6B, 0x79, 0x71, 0x83, 0x7B, 0x83, 0x7A, 0x84, 0x7A, 0x83, 0x7E, 0x93, 0x89, 0x85, 0x7B, 0x78, 0x6E, 0x7E, 0x73, 0x79, 0x69, 0x78, 0x6B, 0x77, 0x6B, 0x79, 0x6C, 0x7A, 0x6B, 0x7C, 0x6F, 0x7D, 0x6F, 0x7D, 0x6F, 0x79, 0x6A, 0x75, 0x68, 0x78, 0x6C, 0x7B, 0x6E, 0x76, 0x68, 0x7A, 0x6E, 0x7D, 0x6C, 0x79, 0x6D, 0x7B, 0x6F, 0x7F, 0x70, 0x7C, 0x6D, 0x79, 0x6C, 0x7B, 0x6E, 0x77, 0x68, 0x76, 0x68, 0x76, 0x68, 0x78, 0x6D, 0x78, 0x6B, 0x78, 0x6C, 0x76, 0x68, 0x79, 0x69, 0x76, 0x6A, 0x78, 0x6E, 0x7C, 0x6E, 0x7B, 0x73, 0x81, 0x77, 0x81, 0x74, 0x7C, 0x76, 0x81, 0x77, 0x80, 0x76, 0x88, 0x85, 0x83, 0x79, 0x8B, 0x83, 0x8B, 0x84, 0x96, 0x98, 0x8E, 0x85, 0x83, 0x7B, 0x83, 0x80, 0x86, 0x80, 0x8B, 0x87, 0x8E, 0x8B, 0x88, 0x81, 0x8B, 0x87, 0x86, 0x7D, 0x82, 0x7C, 0x7E, 0x76, 0x7B, 0x6F, 0x76, 0x69, 0x6F, 0x64, 0x6E, 0x63, 0x6C, 0x60, 0x6E, 0x65, 0x75, 0x71, 0x7D, 0x76, 0x75, 0x6B, 0x78, 0x6F, 0x79, 0x6F, 0x79, 0x6F, 0x76, 0x6F, 0x7A, 0x72, 0x77, 0x6C, 0x76, 0x6E, 0x68, 0x6E, 0x4C, 0x4F, 0x40, 0x49, 0x3B, 0x3E, 0x32, 0x3A, 0x3F, 0x45, 0x3A, 0x3C, 0x36, 0x36, 0x31, 0x33, 0x2E, 0x30, 0x29, 0x2C, 0x27, 0x29, 0x21, 0x23, 0x1F, 0x24, 0x34, 0x3E, 0x38, 0x3E, 0x40, 0x47, 0x2E, 0x2F, 0x25, 0x26, 0x22, 0x24, 0x27, 0x2C, 0x26, 0x2A, 0x2E, 0x33, 0x29, 0x2D, 0x3D, 0x48, 0x33, 0x38, 0x39, 0x40, 0x32, 0x34, 0x36, 0x3D, 0x2F, 0x35, 0x33, 0x3A, 0x33, 0x38, 0x37, 0x3C, 0x35, 0x39, 0x34, 0x3D, 0x3C, 0x43, 0x3E, 0x46, 0x41, 0x48, 0x3C, 0x42, 0x3B, 0x45, 0x3F, 0x45, 0x37, 0x3E, 0x3A, 0x40, 0x39, 0x40, 0x36, 0x3F, 0x3C, 0x41, 0x35, 0x3D, 0x34, 0x38, 0x34, 0x3C
    },

    {
        0x5A, 0x20, 0x5C, 0x20, 0x5E, 0x20, 0x5C, 0x20, 0x5D, 0x20, 0x5C, 0x20, 0x5E, 0x21, 0x5B, 0x20, 0x5D, 0x20, 0x5F, 0x21, 0x5E, 0x21, 0x5C, 0x21, 0x60, 0x22, 0x63, 0x23, 0x62, 0x23, 0x62, 0x23, 0x63, 0x24, 0x63, 0x24, 0x64, 0x24, 0x66, 0x24, 0x65, 0x24, 0x63, 0x23, 0x63, 0x24, 0x63, 0x23, 0x65, 0x24, 0x64, 0x24, 0x64, 0x25, 0x65, 0x25, 0x67, 0x26, 0x66, 0x24, 0x66, 0x24, 0x66, 0x25, 0x66, 0x25, 0x63, 0x23, 0x66, 0x24, 0x65, 0x25, 0x66, 0x26, 0x64, 0x25, 0x65, 0x24, 0x63, 0x24, 0x64, 0x24, 0x63, 0x24, 0x62, 0x24, 0x62, 0x23, 0x61, 0x23, 0x60, 0x23, 0x61, 0x24, 0x62, 0x23, 0x63, 0x24, 0x66, 0x24, 0x67, 0x25, 0x66, 0x25, 0x65, 0x24, 0x65, 0x25, 0x67, 0x25, 0x66, 0x28, 0x7A, 0x3E, 0xAB, 0x51, 0x76, 0x2D, 0x6C, 0x28, 0x67, 0x26, 0x6A, 0x26, 0x6A, 0x26, 0x68, 0x26, 0x68, 0x25, 0x68, 0x26, 0x68, 0x26, 0x69, 0x27, 0x6B, 0x27, 0x6C, 0x27, 0x70, 0x29, 0x6D, 0x27, 0x6D, 0x28, 0x70, 0x28, 0x6C, 0x28, 0x6D, 0x28, 0x6D, 0x29, 0x6C, 0x29, 0x6C, 0x28, 0x69, 0x27, 0x6A, 0x27, 0x6D, 0x28, 0x69, 0x29, 0x6F, 0x2A, 0x78, 0x2D, 0x74, 0x2D, 0x75, 0x2C, 0x74, 0x2C, 0x73, 0x2B, 0x73, 0x2B, 0x70, 0x2B, 0x76, 0x2C, 0x71, 0x2A, 0x72, 0x2A, 0x74, 0x2C, 0x72, 0x2B, 0x70, 0x2A, 0x6E, 0x2A, 0x74, 0x2D, 0x78, 0x2F, 0x75, 0x2C, 0x6F, 0x2A, 0x76, 0x2D, 0x74, 0x2E, 0x75, 0x2E, 0x78, 0x2F, 0x7E, 0x33, 0x87, 0x36, 0x7B, 0x31, 0x7E, 0x33, 0x81, 0x37, 0x8A, 0x39, 0x84, 0x35, 0x7C, 0x32, 0x80, 0x35, 0x87, 0x3A, 0x8C, 0x3F, 0x8E, 0x3F, 0x96, 0x44, 0x8F, 0x3D, 0x8C, 0x3D, 0x94, 0x41, 0x93, 0x42, 0x9B, 0x45, 0x8F, 0x3E, 0x87, 0x3F, 0xA4, 0x4E, 0xA1, 0x51, 0xB5, 0x57, 0xA7, 0x4D, 0xB2, 0x5A, 0xC9, 0x68, 0xE3, 0x79, 0xCD, 0x67, 0xB3, 0x53, 0xAA, 0x50, 0x8E, 0x3E, 0xB1, 0x57, 0xB4, 0x58, 0xA8, 0x4E, 0xAF, 0x56, 0xBB, 0x61, 0xAF, 0x52, 0xB1, 0x5A, 0xCF, 0x6A, 0xD0, 0x72, 0xBE, 0x60, 0xAF, 0x53, 0x8C, 0x3E, 0x8B, 0x3C, 0x84, 0x37, 0x84, 0x38, 0x85, 0x37, 0x8A, 0x3D, 0x93, 0x41, 0x9C, 0x49, 0xA1, 0x4B, 0xA3, 0x4E, 0xA4, 0x4A, 0xAC, 0x52, 0x87, 0x3A, 0xA8, 0x52, 0xAF, 0x52, 0xA9, 0x50, 0x86, 0x37, 0x7A, 0x34, 0x8E, 0x42, 0x88, 0x38, 0x89, 0x3D, 0xA1, 0x4B, 0xA6, 0x4E, 0x8C, 0x3D, 0x84, 0x37, 0x82, 0x3C, 0x7F, 0x35, 0x79, 0x31, 0x74, 0x30, 0x75, 0x2D, 0x6D, 0x29, 0x6B, 0x29, 0x6B, 0x28, 0x6A, 0x27, 0x62, 0x26, 0x65, 0x26, 0x63, 0x26, 0x61, 0x24, 0x62, 0x25, 0x63, 0x26, 0x62, 0x25, 0x66, 0x26, 0x65, 0x26, 0x6E, 0x2B, 0x71, 0x2B, 0x70, 0x2E, 0x75, 0x31, 0x7A, 0x33, 0x7B, 0x32, 0x7C, 0x34, 0x75, 0x2E, 0x6A, 0x29, 0x75, 0x30, 0x72, 0x2B, 0x69, 0x29, 0x6A, 0x29, 0x65, 0x27, 0x69, 0x28, 0x6D, 0x2A, 0x68, 0x28, 0x6C, 0x2D, 0x6C, 0x28, 0x6A, 0x28, 0x68, 0x28, 0x64, 0x26, 0x67, 0x27, 0x66, 0x25, 0x66, 0x26, 0x68, 0x26, 0x67, 0x27, 0x70, 0x2C, 0x68, 0x27, 0x66, 0x27, 0x68, 0x2A, 0x6E, 0x2B, 0x6B, 0x2A, 0x6B, 0x29, 0x6D, 0x29, 0x6A, 0x29, 0x68, 0x28, 0x65, 0x26, 0x68, 0x27, 0x65, 0x26, 0x69, 0x29, 0x6B, 0x2A, 0x76, 0x31, 0x73, 0x2F, 0x71, 0x2D, 0x75, 0x2F, 0x68, 0x2A, 0x72, 0x32, 0x77, 0x32, 0x7A, 0x37, 0x85, 0x3C, 0x86, 0x3E, 0x85, 0x3C, 0x7D, 0x37, 0x7D, 0x38, 0x7B, 0x37, 0x7D, 0x37, 0x76, 0x32, 0x76, 0x37, 0x7C, 0x36, 0x77, 0x35, 0x77, 0x33, 0x68, 0x2A, 0x6C, 0x2D, 0x6C, 0x2C, 0x65, 0x29, 0x65, 0x29, 0x61, 0x26, 0x60, 0x25, 0x61, 0x27, 0x6B, 0x2D, 0x6E, 0x30, 0x74, 0x32, 0x71, 0x31, 0x70, 0x30, 0x6B, 0x2C, 0x65, 0x29, 0x6D, 0x2E, 0x6C, 0x2B, 0x60, 0x26, 0x63, 0x32, 0x4F, 0x2A, 0x49, 0x28, 0x44, 0x25, 0x50, 0x29, 0x47, 0x25, 0x40, 0x26, 0x2C, 0x1D, 0x23, 0x18, 0x21, 0x17, 0x22, 0x16, 0x28, 0x18, 0x27, 0x18, 0x2B, 0x1A, 0x3F, 0x21, 0x37, 0x1E, 0x4B, 0x27, 0x3B, 0x1F, 0x3E, 0x22, 0x34, 0x1D, 0x41, 0x22, 0x32, 0x1B, 0x39, 0x1F, 0x32, 0x1B, 0x39, 0x1F, 0x34, 0x1C, 0x45, 0x24, 0x3D, 0x20, 0x42, 0x22, 0x3B, 0x20, 0x45, 0x24, 0x40, 0x21, 0x45, 0x25, 0x40, 0x21, 0x40, 0x23, 0x40, 0x23, 0x42, 0x24, 0x3B, 0x1F, 0x3B, 0x20, 0x3D, 0x22, 0x4A, 0x28, 0x40, 0x22, 0x44, 0x23, 0x3B, 0x1F, 0x37, 0x1E, 0x35, 0x1D, 0x3A, 0x1F, 0x39, 0x1E, 0x3B, 0x1F
    },

    {
        0x6B, 0x5D, 0x6D, 0x60, 0x70, 0x61, 0x6D, 0x5F, 0x6C, 0x5E, 0x6D, 0x60, 0x71, 0x60, 0x6C, 0x5D, 0x6E, 0x60, 0x70, 0x61, 0x6F, 0x5F, 0x6E, 0x5E, 0x71, 0x61, 0x73, 0x63, 0x70, 0x63, 0x73, 0x65, 0x75, 0x67, 0x75, 0x65, 0x74, 0x66, 0x77, 0x66, 0x78, 0x67, 0x77, 0x66, 0x76, 0x66, 0x75, 0x66, 0x78, 0x67, 0x78, 0x66, 0x77, 0x67, 0x77, 0x67, 0x7A, 0x69, 0x79, 0x65, 0x7A, 0x68, 0x7A, 0x68, 0x7A, 0x68, 0x77, 0x66, 0x79, 0x67, 0x78, 0x68, 0x78, 0x67, 0x7A, 0x69, 0x7A, 0x67, 0x76, 0x65, 0x75, 0x65, 0x76, 0x65, 0x76, 0x64, 0x74, 0x64, 0x73, 0x63, 0x73, 0x63, 0x75, 0x62, 0x75, 0x64, 0x78, 0x69, 0x79, 0x68, 0x79, 0x69, 0x7B, 0x68, 0x7A, 0x67, 0x78, 0x68, 0x7B, 0x6A, 0x7B, 0x6D, 0x89, 0x8F, 0xAB, 0xA9, 0x87, 0x73, 0x7C, 0x6E, 0x78, 0x6A, 0x7B, 0x6D, 0x7E, 0x6D, 0x7C, 0x6A, 0x7C, 0x6B, 0x7D, 0x6C, 0x7D, 0x6C, 0x7D, 0x6F, 0x7F, 0x6F, 0x81, 0x71, 0x83, 0x71, 0x7F, 0x6E, 0x82, 0x70, 0x83, 0x71, 0x82, 0x71, 0x84, 0x72, 0x82, 0x74, 0x7D, 0x70, 0x7C, 0x6E, 0x7C, 0x6B, 0x7D, 0x6E, 0x82, 0x72, 0x80, 0x6F, 0x82, 0x73, 0x89, 0x78, 0x86, 0x78, 0x87, 0x77, 0x85, 0x77, 0x87, 0x76, 0x86, 0x73, 0x81, 0x74, 0x89, 0x7A, 0x85, 0x76, 0x85, 0x75, 0x86, 0x77, 0x88, 0x77, 0x86, 0x77, 0x82, 0x71, 0x85, 0x77, 0x87, 0x7B, 0x86, 0x76, 0x81, 0x70, 0x87, 0x7B, 0x85, 0x79, 0x88, 0x79, 0x89, 0x7B, 0x8D, 0x82, 0x94, 0x8A, 0x8F, 0x7F, 0x8D, 0x83, 0x90, 0x89, 0x93, 0x8A, 0x92, 0x87, 0x8D, 0x80, 0x8E, 0x85, 0x95, 0x8D, 0x95, 0x90, 0x96, 0x91, 0x9D, 0x9B, 0x99, 0x90, 0x9D, 0x99, 0xA4, 0x9B, 0x9D, 0x96, 0xA0, 0x9B, 0x99, 0x8E, 0x95, 0x8C, 0xAB, 0xAB, 0xA8, 0xAD, 0xB8, 0xB8, 0xB5, 0xB5, 0xB9, 0xBC, 0xC8, 0xD2, 0xD7, 0xEB, 0xC7, 0xC8, 0xB5, 0xB8, 0xAE, 0xAD, 0x99, 0x94, 0xB1, 0xB7, 0xB5, 0xB8, 0xB2, 0xAF, 0xB3, 0xB7, 0xB3, 0xBA, 0xAE, 0xB0, 0xBA, 0xC0, 0xC3, 0xD3, 0xC3, 0xDB, 0xB5, 0xC2, 0xA9, 0xB3, 0x94, 0x8D, 0x99, 0x96, 0x93, 0x8C, 0x97, 0x90, 0x96, 0x89, 0x98, 0x8F, 0x9A, 0x95, 0xA0, 0xA6, 0xAB, 0xAB, 0xA7, 0xA6, 0xA4, 0x9C, 0xA9, 0xAC, 0x95, 0x88, 0xA5, 0xAB, 0xA5, 0x9F, 0xA0, 0xA2, 0x91, 0x84, 0x85, 0x76, 0x91, 0x8B, 0x92, 0x86, 0x95, 0x91, 0x9E, 0x97, 0xA1, 0x9F, 0x90, 0x8C, 0x8E, 0x86, 0x8D, 0x8B, 0x8C, 0x84, 0x88, 0x7F, 0x86, 0x7D, 0x82, 0x76, 0x7D, 0x6F, 0x7C, 0x6E, 0x7D, 0x6F, 0x7B, 0x69, 0x73, 0x68, 0x73, 0x66, 0x73, 0x67, 0x71, 0x66, 0x72, 0x67, 0x74, 0x68, 0x73, 0x68, 0x75, 0x68, 0x75, 0x6A, 0x7E, 0x74, 0x7F, 0x72, 0x7E, 0x76, 0x85, 0x7D, 0x88, 0x7D, 0x87, 0x7A, 0x88, 0x7D, 0x86, 0x7A, 0x7E, 0x72, 0x81, 0x7A, 0x82, 0x73, 0x7A, 0x6C, 0x7B, 0x70, 0x77, 0x6B, 0x7A, 0x6B, 0x7C, 0x6E, 0x79, 0x6D, 0x79, 0x73, 0x7C, 0x6E, 0x7A, 0x6B, 0x79, 0x6C, 0x77, 0x6A, 0x78, 0x6B, 0x79, 0x6A, 0x77, 0x69, 0x7A, 0x6A, 0x79, 0x6B, 0x80, 0x71, 0x79, 0x69, 0x78, 0x69, 0x79, 0x6F, 0x7E, 0x73, 0x7C, 0x6D, 0x7C, 0x6E, 0x7D, 0x70, 0x7C, 0x6E, 0x78, 0x69, 0x76, 0x68, 0x79, 0x6C, 0x77, 0x6A, 0x7A, 0x6D, 0x7B, 0x6F, 0x85, 0x7D, 0x84, 0x77, 0x81, 0x75, 0x81, 0x76, 0x76, 0x6C, 0x81, 0x7C, 0x81, 0x75, 0x87, 0x86, 0x8D, 0x8A, 0x92, 0x8F, 0x89, 0x84, 0x88, 0x81, 0x88, 0x82, 0x86, 0x81, 0x88, 0x82, 0x7A, 0x73, 0x7D, 0x78, 0x80, 0x78, 0x7E, 0x78, 0x7D, 0x75, 0x77, 0x6C, 0x78, 0x70, 0x79, 0x6F, 0x75, 0x6A, 0x70, 0x67, 0x6F, 0x66, 0x70, 0x63, 0x70, 0x66, 0x76, 0x70, 0x77, 0x71, 0x7E, 0x76, 0x7B, 0x77, 0x7B, 0x72, 0x76, 0x6C, 0x71, 0x68, 0x76, 0x6E, 0x78, 0x6C, 0x6E, 0x61, 0x5A, 0x5C, 0x47, 0x4F, 0x42, 0x4B, 0x43, 0x4D, 0x49, 0x56, 0x3F, 0x47, 0x3A, 0x41, 0x2B, 0x2E, 0x22, 0x23, 0x22, 0x27, 0x24, 0x27, 0x2A, 0x2E, 0x29, 0x2D, 0x2B, 0x32, 0x39, 0x42, 0x32, 0x38, 0x42, 0x49, 0x35, 0x3A, 0x39, 0x42, 0x31, 0x37, 0x3A, 0x3F, 0x2E, 0x33, 0x35, 0x3C, 0x30, 0x35, 0x36, 0x3D, 0x34, 0x39, 0x3F, 0x49, 0x39, 0x40, 0x3D, 0x43, 0x36, 0x3D, 0x3F, 0x49, 0x39, 0x3F, 0x3E, 0x46, 0x38, 0x3C, 0x3B, 0x45, 0x38, 0x3E, 0x3A, 0x44, 0x34, 0x39, 0x38, 0x3F, 0x39, 0x41, 0x41, 0x49, 0x3A, 0x42, 0x3D, 0x43, 0x34, 0x39, 0x32, 0x39, 0x31, 0x36, 0x37, 0x3E, 0x37, 0x3D, 0x39, 0x40
    },

    {
        0x5C, 0x21, 0x5E, 0x22, 0x5C, 0x20, 0x5A, 0x1F, 0x5A, 0x20, 0x5C, 0x21, 0x5C, 0x20, 0x5B, 0x20, 0x5D, 0x21, 0x5E, 0x21, 0x5D, 0x21, 0x5C, 0x20, 0x5E, 0x21, 0x5F, 0x21, 0x5E, 0x21, 0x62, 0x23, 0x65, 0x25, 0x63, 0x24, 0x64, 0x24, 0x66, 0x25, 0x65, 0x25, 0x63, 0x23, 0x62, 0x24, 0x64, 0x25, 0x66, 0x24, 0x63, 0x24, 0x63, 0x24, 0x63, 0x24, 0x64, 0x23, 0x63, 0x24, 0x65, 0x25, 0x68, 0x25, 0x65, 0x25, 0x61, 0x23, 0x65, 0x25, 0x67, 0x26, 0x68, 0x26, 0x67, 0x27, 0x67, 0x27, 0x67, 0x26, 0x66, 0x25, 0x65, 0x25, 0x64, 0x24, 0x64, 0x24, 0x63, 0x24, 0x62, 0x24, 0x61, 0x23, 0x63, 0x24, 0x63, 0x24, 0x65, 0x28, 0x6C, 0x28, 0x66, 0x25, 0x67, 0x26, 0x67, 0x26, 0x6B, 0x29, 0x74, 0x3B, 0xBF, 0x5E, 0x7D, 0x31, 0x6F, 0x2B, 0x6A, 0x27, 0x6A, 0x27, 0x6B, 0x27, 0x6B, 0x28, 0x6A, 0x27, 0x67, 0x26, 0x69, 0x27, 0x6C, 0x28, 0x6B, 0x27, 0x69, 0x26, 0x6C, 0x28, 0x6C, 0x28, 0x6C, 0x28, 0x71, 0x28, 0x6C, 0x27, 0x6C, 0x27, 0x6A, 0x29, 0x76, 0x2D, 0x70, 0x2A, 0x6D, 0x2A, 0x6A, 0x28, 0x6D, 0x28, 0x71, 0x2A, 0x71, 0x2A, 0x71, 0x29, 0x70, 0x2A, 0x72, 0x2A, 0x6F, 0x2A, 0x6E, 0x29, 0x71, 0x2A, 0x73, 0x2C, 0x71, 0x2C, 0x75, 0x2B, 0x6F, 0x2A, 0x76, 0x2C, 0x78, 0x30, 0x7B, 0x2E, 0x76, 0x2D, 0x74, 0x2C, 0x73, 0x2C, 0x76, 0x2D, 0x72, 0x2C, 0x71, 0x2B, 0x76, 0x2D, 0x73, 0x2C, 0x72, 0x2C, 0x74, 0x2D, 0x76, 0x2F, 0x7B, 0x31, 0x79, 0x31, 0x7C, 0x31, 0x79, 0x31, 0x7A, 0x30, 0x80, 0x35, 0x89, 0x39, 0x84, 0x37, 0x7D, 0x34, 0x84, 0x37, 0x84, 0x38, 0x89, 0x38, 0x8A, 0x3B, 0x98, 0x49, 0xA2, 0x46, 0x8F, 0x3F, 0x8B, 0x3A, 0x87, 0x39, 0x8C, 0x41, 0xB0, 0x52, 0xA0, 0x4D, 0xB8, 0x5D, 0xB8, 0x56, 0xA2, 0x4C, 0xA6, 0x4D, 0xB1, 0x57, 0xA7, 0x53, 0xAC, 0x53, 0xA6, 0x4A, 0x89, 0x3A, 0x8F, 0x40, 0xA6, 0x54, 0xCD, 0x64, 0xA8, 0x4F, 0xA3, 0x53, 0xB9, 0x5F, 0xC2, 0x63, 0xAA, 0x61, 0xB0, 0x60, 0x99, 0x56, 0x90, 0x48, 0x7D, 0x38, 0x94, 0x45, 0x81, 0x37, 0x83, 0x36, 0x91, 0x42, 0x96, 0x40, 0x7E, 0x36, 0x85, 0x3D, 0x98, 0x47, 0x96, 0x47, 0x9A, 0x46, 0x99, 0x46, 0x8E, 0x3E, 0x82, 0x37, 0x88, 0x3C, 0x8E, 0x43, 0x94, 0x45, 0x8C, 0x3B, 0x86, 0x3B, 0x8D, 0x3F, 0x83, 0x3A, 0x86, 0x37, 0x76, 0x31, 0x84, 0x3B, 0x88, 0x3B, 0x83, 0x3B, 0x8A, 0x3D, 0x80, 0x33, 0x79, 0x30, 0x70, 0x2C, 0x71, 0x2D, 0x6C, 0x29, 0x67, 0x27, 0x6A, 0x27, 0x65, 0x26, 0x67, 0x27, 0x67, 0x27, 0x65, 0x28, 0x66, 0x26, 0x5F, 0x25, 0x69, 0x2B, 0x62, 0x25, 0x68, 0x28, 0x6D, 0x2C, 0x71, 0x2D, 0x6C, 0x2B, 0x81, 0x39, 0x7C, 0x32, 0x75, 0x30, 0x85, 0x3A, 0x86, 0x39, 0x79, 0x32, 0x75, 0x2F, 0x70, 0x2B, 0x6A, 0x29, 0x6D, 0x2A, 0x6E, 0x2B, 0x68, 0x27, 0x68, 0x28, 0x69, 0x28, 0x6A, 0x29, 0x69, 0x27, 0x67, 0x28, 0x6A, 0x27, 0x68, 0x27, 0x66, 0x26, 0x6B, 0x28, 0x64, 0x26, 0x68, 0x26, 0x66, 0x25, 0x68, 0x28, 0x65, 0x26, 0x64, 0x26, 0x67, 0x27, 0x6B, 0x29, 0x6B, 0x28, 0x6B, 0x28, 0x6D, 0x2A, 0x6C, 0x2B, 0x6B, 0x29, 0x68, 0x29, 0x6B, 0x2A, 0x69, 0x29, 0x68, 0x28, 0x6E, 0x2D, 0x7A, 0x34, 0x70, 0x2C, 0x70, 0x2D, 0x70, 0x2C, 0x6A, 0x2B, 0x72, 0x2F, 0x71, 0x2F, 0x83, 0x3F, 0x8E, 0x41, 0x8B, 0x41, 0x81, 0x39, 0x8A, 0x3D, 0x82, 0x3C, 0x83, 0x3A, 0x7D, 0x38, 0x79, 0x36, 0x73, 0x32, 0x79, 0x34, 0x70, 0x2E, 0x6E, 0x2E, 0x70, 0x30, 0x71, 0x2F, 0x71, 0x2F, 0x6C, 0x2B, 0x64, 0x27, 0x61, 0x26, 0x5F, 0x28, 0x61, 0x27, 0x63, 0x2A, 0x73, 0x31, 0x73, 0x34, 0x6A, 0x2D, 0x6A, 0x2D, 0x6C, 0x2D, 0x62, 0x27, 0x6A, 0x2B, 0x6C, 0x2D, 0x63, 0x26, 0x4B, 0x24, 0x54, 0x2B, 0x41, 0x23, 0x4F, 0x2A, 0x4A, 0x26, 0x3E, 0x22, 0x3C, 0x20, 0x3F, 0x22, 0x34, 0x1D, 0x38, 0x1F, 0x37, 0x1E, 0x3B, 0x20, 0x39, 0x1E, 0x36, 0x1D, 0x3B, 0x1F, 0x38, 0x1F, 0x3D, 0x20, 0x3D, 0x20, 0x41, 0x22, 0x3F, 0x22, 0x44, 0x22, 0x3E, 0x21, 0x44, 0x23, 0x41, 0x22, 0x48, 0x26, 0x3E, 0x20, 0x47, 0x25, 0x3C, 0x20, 0x41, 0x23, 0x3E, 0x21, 0x44, 0x24, 0x36, 0x1E, 0x3F, 0x22, 0x35, 0x1D, 0x3F, 0x22, 0x3C, 0x21, 0x43, 0x24, 0x47, 0x25, 0x43, 0x24, 0x3E, 0x22, 0x3F, 0x22, 0x3C, 0x21, 0x3E, 0x21, 0x3F, 0x22, 0x40, 0x22, 0x3A, 0x1E, 0x45, 0x24, 0x3D, 0x20, 0x38, 0x1E
    },

    {
        0x6C, 0x5F, 0x6B, 0x5D, 0x6A, 0x5D, 0x69, 0x5C, 0x6A, 0x5D, 0x6C, 0x5E, 0x6C, 0x5D, 0x6C, 0x5C, 0x6F, 0x60, 0x6F, 0x60, 0x6E, 0x60, 0x6E, 0x5E, 0x6F, 0x5F, 0x6F, 0x60, 0x6F, 0x60, 0x74, 0x65, 0x77, 0x68, 0x75, 0x64, 0x76, 0x65, 0x76, 0x67, 0x78, 0x66, 0x76, 0x65, 0x76, 0x65, 0x76, 0x66, 0x77, 0x67, 0x73, 0x63, 0x73, 0x64, 0x77, 0x65, 0x78, 0x66, 0x77, 0x65, 0x77, 0x67, 0x7C, 0x6A, 0x79, 0x66, 0x75, 0x64, 0x7A, 0x6A, 0x7A, 0x69, 0x79, 0x68, 0x7A, 0x68, 0x7A, 0x6A, 0x7C, 0x6A, 0x7A, 0x68, 0x78, 0x67, 0x77, 0x66, 0x78, 0x67, 0x76, 0x66, 0x75, 0x65, 0x77, 0x65, 0x78, 0x67, 0x77, 0x66, 0x78, 0x6B, 0x7C, 0x6C, 0x78, 0x68, 0x78, 0x6C, 0x7B, 0x69, 0x7C, 0x6E, 0x89, 0x8E, 0xB9, 0xBF, 0x87, 0x77, 0x80, 0x6E, 0x7C, 0x6C, 0x7D, 0x6D, 0x7C, 0x6C, 0x7F, 0x6D, 0x7B, 0x6C, 0x7A, 0x6A, 0x7D, 0x6E, 0x80, 0x71, 0x7E, 0x6D, 0x7C, 0x6D, 0x7F, 0x6F, 0x81, 0x70, 0x82, 0x72, 0x87, 0x73, 0x7E, 0x6E, 0x80, 0x6D, 0x80, 0x70, 0x87, 0x7A, 0x82, 0x72, 0x7F, 0x72, 0x80, 0x71, 0x83, 0x71, 0x87, 0x75, 0x86, 0x74, 0x83, 0x72, 0x82, 0x72, 0x84, 0x73, 0x81, 0x73, 0x83, 0x73, 0x83, 0x72, 0x86, 0x75, 0x86, 0x75, 0x86, 0x74, 0x83, 0x74, 0x89, 0x77, 0x87, 0x80, 0x8B, 0x7C, 0x86, 0x78, 0x87, 0x78, 0x86, 0x76, 0x87, 0x78, 0x82, 0x75, 0x84, 0x74, 0x8B, 0x7C, 0x86, 0x76, 0x86, 0x75, 0x86, 0x7B, 0x8B, 0x7B, 0x8C, 0x7E, 0x88, 0x7D, 0x8B, 0x7C, 0x89, 0x7A, 0x8A, 0x7A, 0x8D, 0x80, 0x97, 0x8F, 0x92, 0x88, 0x8C, 0x84, 0x91, 0x88, 0x92, 0x89, 0x9C, 0x91, 0x9C, 0x95, 0x9E, 0x9E, 0xA4, 0x9A, 0x9B, 0x94, 0x9B, 0x91, 0x96, 0x8A, 0x9A, 0x96, 0xAE, 0xAE, 0xA1, 0x9C, 0xB3, 0xBB, 0xB0, 0xAC, 0xA6, 0xA5, 0xAA, 0xA3, 0xAE, 0xAC, 0xAF, 0xB1, 0xA8, 0xA6, 0xA5, 0xA3, 0x95, 0x8C, 0x9D, 0x97, 0xB2, 0xBB, 0xC7, 0xCE, 0xAC, 0xA7, 0xA9, 0xAC, 0xBB, 0xC7, 0xB0, 0xB8, 0x92, 0xA8, 0x96, 0xA8, 0x86, 0x91, 0x7D, 0x8B, 0x7D, 0x7C, 0x98, 0x98, 0x8B, 0x80, 0x8E, 0x84, 0x9C, 0x9E, 0x9C, 0x94, 0x92, 0x87, 0x92, 0x86, 0x9A, 0x9A, 0xA0, 0x9E, 0xA6, 0xA3, 0x99, 0x97, 0x99, 0x93, 0x8C, 0x7E, 0x94, 0x92, 0x99, 0x9A, 0x98, 0x9A, 0x97, 0x90, 0x92, 0x90, 0x92, 0x8F, 0x8F, 0x88, 0x8F, 0x83, 0x87, 0x7E, 0x8E, 0x8A, 0x90, 0x8E, 0x88, 0x81, 0x91, 0x8A, 0x8A, 0x7F, 0x87, 0x7B, 0x7E, 0x70, 0x7D, 0x74, 0x7B, 0x6C, 0x78, 0x6B, 0x7C, 0x6E, 0x76, 0x69, 0x73, 0x69, 0x7A, 0x6D, 0x73, 0x69, 0x77, 0x67, 0x6E, 0x64, 0x77, 0x71, 0x73, 0x67, 0x78, 0x6D, 0x7B, 0x6F, 0x7D, 0x72, 0x79, 0x6D, 0x85, 0x81, 0x87, 0x7D, 0x85, 0x7B, 0x8D, 0x87, 0x8F, 0x87, 0x86, 0x7D, 0x82, 0x76, 0x7D, 0x71, 0x7B, 0x6D, 0x7E, 0x70, 0x7D, 0x70, 0x7A, 0x69, 0x7B, 0x6C, 0x7A, 0x6D, 0x7B, 0x6F, 0x7C, 0x6B, 0x76, 0x6C, 0x7A, 0x6E, 0x77, 0x6B, 0x77, 0x69, 0x79, 0x6D, 0x76, 0x69, 0x77, 0x69, 0x7A, 0x6A, 0x79, 0x6B, 0x75, 0x66, 0x78, 0x6A, 0x78, 0x6A, 0x7E, 0x6F, 0x7D, 0x6E, 0x7D, 0x6F, 0x7C, 0x72, 0x7D, 0x72, 0x7C, 0x70, 0x78, 0x6B, 0x7A, 0x6E, 0x79, 0x6D, 0x78, 0x6C, 0x7E, 0x73, 0x86, 0x7D, 0x82, 0x72, 0x80, 0x75, 0x81, 0x74, 0x7A, 0x6E, 0x7F, 0x73, 0x81, 0x77, 0x8A, 0x88, 0x94, 0x94, 0x99, 0x99, 0x8D, 0x89, 0x95, 0x8E, 0x8B, 0x87, 0x86, 0x80, 0x82, 0x7B, 0x83, 0x7B, 0x7E, 0x77, 0x82, 0x7B, 0x80, 0x73, 0x7A, 0x71, 0x7D, 0x77, 0x7C, 0x74, 0x7F, 0x75, 0x7B, 0x71, 0x74, 0x68, 0x73, 0x64, 0x6D, 0x64, 0x6C, 0x62, 0x70, 0x67, 0x79, 0x70, 0x78, 0x70, 0x73, 0x6B, 0x76, 0x6D, 0x78, 0x70, 0x72, 0x67, 0x74, 0x6B, 0x77, 0x6E, 0x6E, 0x60, 0x4E, 0x4F, 0x4D, 0x54, 0x3D, 0x44, 0x45, 0x4F, 0x3D, 0x43, 0x38, 0x40, 0x35, 0x3A, 0x38, 0x3E, 0x30, 0x37, 0x33, 0x3D, 0x34, 0x3A, 0x37, 0x3D, 0x36, 0x3E, 0x32, 0x39, 0x36, 0x3B, 0x36, 0x3F, 0x3A, 0x3F, 0x3A, 0x40, 0x3D, 0x45, 0x3B, 0x45, 0x3F, 0x45, 0x39, 0x40, 0x3F, 0x49, 0x3C, 0x40, 0x40, 0x4B, 0x35, 0x3C, 0x3F, 0x46, 0x38, 0x3F, 0x3B, 0x40, 0x36, 0x3E, 0x3A, 0x40, 0x32, 0x3A, 0x3A, 0x3F, 0x33, 0x39, 0x3B, 0x46, 0x38, 0x3E, 0x41, 0x4A, 0x43, 0x4C, 0x3C, 0x41, 0x39, 0x43, 0x38, 0x40, 0x37, 0x3E, 0x3C, 0x43, 0x3C, 0x43, 0x3B, 0x44, 0x36, 0x3A, 0x3E, 0x49, 0x36, 0x38, 0x33, 0x3A
    },

    {
        0x5E, 0x21, 0x5D, 0x20, 0x5C, 0x20, 0x5B, 0x20, 0x59, 0x1F, 0x5B, 0x1F, 0x5B, 0x20, 0x5C, 0x21, 0x5E, 0x21, 0x5E, 0x21, 0x5E, 0x21, 0x5C, 0x21, 0x5D, 0x21, 0x5F, 0x22, 0x61, 0x22, 0x63, 0x23, 0x63, 0x23, 0x60, 0x22, 0x62, 0x24, 0x61, 0x23, 0x64, 0x25, 0x64, 0x24, 0x64, 0x24, 0x64, 0x23, 0x64, 0x23, 0x66, 0x25, 0x65, 0x25, 0x66, 0x24, 0x65, 0x24, 0x64, 0x24, 0x63, 0x24, 0x64, 0x24, 0x65, 0x24, 0x65, 0x24, 0x65, 0x26, 0x66, 0x26, 0x65, 0x26, 0x67, 0x29, 0x69, 0x28, 0x68, 0x26, 0x68, 0x25, 0x67, 0x26, 0x66, 0x25, 0x64, 0x24, 0x64, 0x25, 0x64, 0x25, 0x66, 0x25, 0x67, 0x24, 0x66, 0x24, 0x65, 0x25, 0x63, 0x24, 0x63, 0x25, 0x66, 0x26, 0x66, 0x26, 0x72, 0x3A, 0xC7, 0x6C, 0x8F, 0x3A, 0x70, 0x2C, 0x6C, 0x28, 0x67, 0x26, 0x67, 0x26, 0x66, 0x25, 0x66, 0x26, 0x67, 0x26, 0x6B, 0x28, 0x6A, 0x26, 0x66, 0x26, 0x69, 0x26, 0x69, 0x27, 0x6C, 0x28, 0x6A, 0x27, 0x6A, 0x27, 0x6E, 0x29, 0x6B, 0x28, 0x6B, 0x28, 0x70, 0x2B, 0x73, 0x2B, 0x6E, 0x29, 0x70, 0x2A, 0x6E, 0x28, 0x6B, 0x28, 0x6E, 0x29, 0x6F, 0x2B, 0x70, 0x2A, 0x71, 0x2A, 0x70, 0x2A, 0x6F, 0x29, 0x6F, 0x29, 0x6C, 0x29, 0x70, 0x29, 0x70, 0x2A, 0x70, 0x29, 0x6F, 0x2A, 0x70, 0x2B, 0x73, 0x2C, 0x76, 0x2C, 0x70, 0x2A, 0x6E, 0x2A, 0x73, 0x2C, 0x74, 0x2C, 0x71, 0x2A, 0x70, 0x2C, 0x76, 0x2D, 0x74, 0x2C, 0x75, 0x2D, 0x76, 0x2E, 0x7D, 0x30, 0x79, 0x2E, 0x74, 0x2F, 0x7A, 0x30, 0x76, 0x2F, 0x75, 0x2D, 0x76, 0x2E, 0x7B, 0x31, 0x7D, 0x33, 0x81, 0x35, 0x7C, 0x33, 0x89, 0x3A, 0x89, 0x39, 0x92, 0x40, 0x8A, 0x3B, 0x8A, 0x38, 0x87, 0x38, 0x8A, 0x3C, 0x93, 0x3E, 0x88, 0x3C, 0x99, 0x41, 0x83, 0x37, 0x8A, 0x3E, 0xA1, 0x4A, 0xAB, 0x4D, 0xA7, 0x4F, 0xA8, 0x50, 0xBF, 0x59, 0x9F, 0x46, 0x9E, 0x4A, 0x91, 0x40, 0x9A, 0x4A, 0xAD, 0x56, 0xA9, 0x52, 0xAB, 0x51, 0xA2, 0x4A, 0xA6, 0x55, 0x9D, 0x57, 0xB0, 0x67, 0xA6, 0x5D, 0x90, 0x4E, 0x7E, 0x47, 0x69, 0x35, 0x80, 0x3A, 0x77, 0x34, 0x80, 0x38, 0x87, 0x3A, 0x87, 0x38, 0x7E, 0x34, 0x8C, 0x43, 0xA5, 0x50, 0x99, 0x45, 0xA4, 0x4C, 0xA5, 0x4C, 0x97, 0x45, 0x99, 0x49, 0x92, 0x43, 0xA2, 0x4B, 0x92, 0x40, 0x8D, 0x3F, 0x8E, 0x41, 0x92, 0x43, 0x8E, 0x3F, 0x8B, 0x3E, 0x7F, 0x37, 0x89, 0x40, 0x8C, 0x3F, 0x85, 0x3C, 0x8B, 0x40, 0x8A, 0x39, 0x76, 0x30, 0x6E, 0x2C, 0x67, 0x28, 0x6E, 0x2C, 0x6C, 0x2A, 0x6E, 0x2B, 0x6D, 0x2B, 0x69, 0x2A, 0x69, 0x28, 0x65, 0x25, 0x6B, 0x2B, 0x67, 0x29, 0x6E, 0x2F, 0x66, 0x27, 0x66, 0x26, 0x65, 0x27, 0x66, 0x27, 0x64, 0x27, 0x6F, 0x2F, 0x6C, 0x2B, 0x6D, 0x2C, 0x76, 0x34, 0x83, 0x37, 0x72, 0x30, 0x70, 0x2C, 0x6B, 0x2A, 0x68, 0x28, 0x6B, 0x28, 0x6A, 0x29, 0x68, 0x29, 0x6A, 0x28, 0x6A, 0x29, 0x69, 0x2A, 0x6A, 0x29, 0x6A, 0x29, 0x69, 0x28, 0x66, 0x27, 0x67, 0x27, 0x68, 0x28, 0x6A, 0x29, 0x66, 0x27, 0x66, 0x27, 0x6B, 0x2B, 0x6B, 0x2B, 0x66, 0x26, 0x63, 0x25, 0x67, 0x27, 0x69, 0x27, 0x66, 0x28, 0x6F, 0x2C, 0x6E, 0x2C, 0x6D, 0x2B, 0x78, 0x35, 0x6F, 0x29, 0x66, 0x27, 0x67, 0x29, 0x6D, 0x2C, 0x82, 0x3A, 0x7C, 0x34, 0x6E, 0x2C, 0x75, 0x30, 0x68, 0x28, 0x6C, 0x2B, 0x74, 0x33, 0x85, 0x3D, 0x8C, 0x44, 0x9D, 0x4B, 0x82, 0x3B, 0x8D, 0x43, 0x80, 0x38, 0x7F, 0x39, 0x7D, 0x36, 0x80, 0x38, 0x80, 0x3C, 0x81, 0x3C, 0x87, 0x3B, 0x72, 0x30, 0x70, 0x31, 0x79, 0x36, 0x6D, 0x2C, 0x6C, 0x2D, 0x6D, 0x2D, 0x67, 0x2A, 0x67, 0x29, 0x62, 0x28, 0x64, 0x29, 0x6B, 0x2E, 0x72, 0x30, 0x69, 0x2C, 0x67, 0x2B, 0x69, 0x2C, 0x63, 0x28, 0x61, 0x29, 0x69, 0x2D, 0x62, 0x28, 0x4E, 0x26, 0x4C, 0x29, 0x46, 0x27, 0x4A, 0x27, 0x3C, 0x21, 0x40, 0x23, 0x3F, 0x21, 0x42, 0x23, 0x42, 0x22, 0x42, 0x24, 0x45, 0x23, 0x47, 0x26, 0x48, 0x25, 0x36, 0x1D, 0x48, 0x26, 0x40, 0x22, 0x46, 0x25, 0x43, 0x24, 0x49, 0x27, 0x3D, 0x21, 0x42, 0x24, 0x3A, 0x20, 0x41, 0x24, 0x36, 0x1F, 0x41, 0x23, 0x35, 0x1D, 0x40, 0x22, 0x38, 0x1F, 0x3E, 0x21, 0x3D, 0x21, 0x41, 0x22, 0x3D, 0x21, 0x4C, 0x28, 0x44, 0x23, 0x49, 0x26, 0x41, 0x23, 0x48, 0x26, 0x42, 0x23, 0x37, 0x20, 0x40, 0x23, 0x49, 0x27, 0x40, 0x23, 0x4C, 0x28, 0x3B, 0x20, 0x3C, 0x21, 0x39, 0x1E, 0x3F, 0x21, 0x36, 0x1D, 0x3C, 0x20
    },

    {
        0x6D, 0x5F, 0x6E, 0x5E, 0x6D, 0x5D, 0x6B, 0x5D, 0x69, 0x5B, 0x6B, 0x5D, 0x6C, 0x5F, 0x6D, 0x60, 0x6F, 0x60, 0x6F, 0x5F, 0x6D, 0x60, 0x6E, 0x5F, 0x6E, 0x61, 0x70, 0x62, 0x72, 0x63, 0x75, 0x64, 0x75, 0x63, 0x72, 0x63, 0x73, 0x64, 0x72, 0x63, 0x73, 0x65, 0x74, 0x66, 0x79, 0x66, 0x78, 0x66, 0x79, 0x66, 0x7A, 0x68, 0x78, 0x67, 0x7A, 0x69, 0x79, 0x67, 0x79, 0x67, 0x79, 0x66, 0x76, 0x65, 0x77, 0x66, 0x79, 0x67, 0x7A, 0x68, 0x7A, 0x68, 0x7A, 0x67, 0x7A, 0x6B, 0x7D, 0x6D, 0x7B, 0x6B, 0x7B, 0x6A, 0x78, 0x68, 0x79, 0x67, 0x77, 0x66, 0x77, 0x66, 0x79, 0x68, 0x7A, 0x68, 0x78, 0x67, 0x7A, 0x67, 0x78, 0x66, 0x76, 0x65, 0x75, 0x67, 0x79, 0x68, 0x7A, 0x67, 0x87, 0x8B, 0xBD, 0xC8, 0x91, 0x7D, 0x81, 0x71, 0x7E, 0x6D, 0x7A, 0x6A, 0x7B, 0x69, 0x7A, 0x69, 0x7B, 0x69, 0x7C, 0x6B, 0x7D, 0x6D, 0x7D, 0x6B, 0x7C, 0x6B, 0x7E, 0x6D, 0x7E, 0x6D, 0x7C, 0x6B, 0x7D, 0x6C, 0x7C, 0x6D, 0x81, 0x73, 0x7D, 0x6E, 0x7E, 0x6F, 0x80, 0x72, 0x82, 0x71, 0x82, 0x71, 0x82, 0x72, 0x80, 0x6D, 0x7E, 0x6E, 0x81, 0x72, 0x83, 0x74, 0x85, 0x74, 0x87, 0x75, 0x85, 0x76, 0x82, 0x71, 0x83, 0x72, 0x83, 0x72, 0x86, 0x73, 0x82, 0x72, 0x84, 0x72, 0x82, 0x72, 0x84, 0x75, 0x85, 0x78, 0x87, 0x75, 0x82, 0x72, 0x81, 0x71, 0x85, 0x78, 0x87, 0x78, 0x85, 0x73, 0x82, 0x73, 0x8B, 0x79, 0x88, 0x77, 0x8A, 0x7B, 0x88, 0x7B, 0x8E, 0x7D, 0x8C, 0x7A, 0x84, 0x79, 0x89, 0x7D, 0x87, 0x7A, 0x89, 0x78, 0x89, 0x78, 0x8A, 0x7D, 0x8E, 0x81, 0x8F, 0x82, 0x8A, 0x81, 0x93, 0x8A, 0x97, 0x8B, 0xA0, 0x9A, 0x98, 0x8F, 0x9C, 0x8E, 0x9A, 0x8A, 0x98, 0x92, 0xA3, 0x97, 0x97, 0x8B, 0x9E, 0x97, 0x95, 0x86, 0x93, 0x8B, 0xA5, 0xA9, 0xB3, 0xB1, 0xB2, 0xB3, 0xB4, 0xB8, 0xB9, 0xBA, 0xA7, 0xA1, 0xAA, 0xAC, 0x9C, 0x98, 0xAA, 0xAC, 0xB1, 0xB4, 0xAA, 0xA8, 0xAD, 0xB2, 0xA9, 0xA4, 0xA2, 0xA5, 0x8B, 0x97, 0x97, 0xB5, 0x88, 0x96, 0x7B, 0x8C, 0x71, 0x7E, 0x66, 0x69, 0x7C, 0x7F, 0x83, 0x7D, 0x8F, 0x89, 0x8D, 0x85, 0x91, 0x87, 0x8F, 0x83, 0x9D, 0x9F, 0xA6, 0xA6, 0x9B, 0x94, 0xA4, 0xA0, 0xA7, 0xA8, 0x9F, 0x9C, 0xA0, 0xA1, 0x99, 0x97, 0x9E, 0x9C, 0x96, 0x8C, 0x8C, 0x83, 0x8E, 0x8C, 0x97, 0x94, 0x94, 0x8C, 0x92, 0x8E, 0x88, 0x7F, 0x90, 0x8B, 0x95, 0x90, 0x95, 0x93, 0x95, 0x8D, 0x91, 0x87, 0x82, 0x77, 0x7D, 0x70, 0x77, 0x69, 0x7D, 0x71, 0x7B, 0x72, 0x7C, 0x70, 0x7C, 0x6F, 0x78, 0x6D, 0x7A, 0x6C, 0x73, 0x66, 0x79, 0x71, 0x76, 0x6A, 0x73, 0x6B, 0x76, 0x67, 0x74, 0x67, 0x71, 0x66, 0x74, 0x6A, 0x75, 0x67, 0x7B, 0x6F, 0x78, 0x6B, 0x7A, 0x6D, 0x82, 0x7B, 0x8A, 0x81, 0x83, 0x77, 0x7F, 0x72, 0x7C, 0x6A, 0x79, 0x6A, 0x7C, 0x6D, 0x7A, 0x6D, 0x77, 0x6B, 0x7A, 0x6C, 0x7C, 0x6F, 0x79, 0x6E, 0x7A, 0x6E, 0x7B, 0x6D, 0x78, 0x6D, 0x79, 0x6B, 0x78, 0x6B, 0x79, 0x6C, 0x7A, 0x6C, 0x75, 0x69, 0x7B, 0x6D, 0x7C, 0x6D, 0x79, 0x6C, 0x78, 0x68, 0x77, 0x69, 0x7B, 0x6D, 0x79, 0x69, 0x79, 0x6A, 0x7F, 0x74, 0x7D, 0x73, 0x7D, 0x71, 0x7F, 0x7C, 0x7C, 0x6C, 0x79, 0x6B, 0x7B, 0x6D, 0x7D, 0x75, 0x8A, 0x83, 0x89, 0x7C, 0x7C, 0x70, 0x80, 0x7A, 0x7C, 0x6D, 0x7B, 0x72, 0x81, 0x7B, 0x8F, 0x8A, 0x93, 0x91, 0x94, 0x93, 0x89, 0x84, 0x92, 0x93, 0x8D, 0x83, 0x8B, 0x83, 0x8A, 0x86, 0x8D, 0x85, 0x88, 0x84, 0x8C, 0x8A, 0x91, 0x8A, 0x80, 0x76, 0x7D, 0x74, 0x7F, 0x7B, 0x7B, 0x6E, 0x78, 0x6F, 0x7B, 0x70, 0x79, 0x6E, 0x77, 0x6C, 0x71, 0x69, 0x74, 0x68, 0x78, 0x6F, 0x7B, 0x72, 0x75, 0x6C, 0x75, 0x6A, 0x71, 0x65, 0x6F, 0x63, 0x6E, 0x64, 0x72, 0x6C, 0x6D, 0x63, 0x4E, 0x50, 0x43, 0x48, 0x3F, 0x49, 0x42, 0x4A, 0x39, 0x3C, 0x3C, 0x46, 0x3C, 0x44, 0x3F, 0x48, 0x3C, 0x41, 0x3E, 0x4A, 0x3D, 0x43, 0x40, 0x4C, 0x3E, 0x46, 0x32, 0x3A, 0x42, 0x4C, 0x37, 0x3D, 0x3F, 0x4A, 0x3A, 0x40, 0x41, 0x4A, 0x37, 0x3A, 0x39, 0x44, 0x34, 0x3A, 0x3B, 0x41, 0x33, 0x39, 0x3A, 0x41, 0x34, 0x3B, 0x3C, 0x40, 0x35, 0x3D, 0x3D, 0x44, 0x39, 0x41, 0x3B, 0x42, 0x39, 0x42, 0x47, 0x51, 0x3B, 0x42, 0x40, 0x49, 0x3B, 0x41, 0x3F, 0x46, 0x37, 0x3D, 0x34, 0x3A, 0x3B, 0x42, 0x42, 0x4C, 0x3A, 0x43, 0x43, 0x4A, 0x34, 0x3A, 0x38, 0x40, 0x38, 0x3F, 0x3A, 0x3F, 0x33, 0x38, 0x39, 0x43
    },

    {
        0x5B, 0x20, 0x5A, 0x20, 0x5C, 0x20, 0x5B, 0x20, 0x5A, 0x20, 0x5B, 0x20, 0x5A, 0x21, 0x5E, 0x22, 0x60, 0x22, 0x5F, 0x22, 0x5E, 0x22, 0x5E, 0x21, 0x5D, 0x22, 0x61, 0x23, 0x60, 0x22, 0x60, 0x22, 0x60, 0x22, 0x63, 0x23, 0x61, 0x23, 0x61, 0x23, 0x62, 0x24, 0x64, 0x25, 0x63, 0x23, 0x62, 0x24, 0x66, 0x25, 0x67, 0x25, 0x64, 0x24, 0x62, 0x23, 0x61, 0x23, 0x61, 0x23, 0x63, 0x24, 0x64, 0x24, 0x64, 0x24, 0x64, 0x23, 0x67, 0x26, 0x66, 0x26, 0x68, 0x26, 0x69, 0x26, 0x67, 0x25, 0x66, 0x25, 0x65, 0x25, 0x64, 0x25, 0x63, 0x25, 0x63, 0x24, 0x63, 0x24, 0x64, 0x25, 0x64, 0x25, 0x63, 0x24, 0x64, 0x24, 0x63, 0x24, 0x64, 0x24, 0x61, 0x24, 0x64, 0x25, 0x6C, 0x31, 0xB2, 0x5F, 0x89, 0x36, 0x6E, 0x2A, 0x6B, 0x29, 0x67, 0x28, 0x6A, 0x28, 0x67, 0x26, 0x65, 0x25, 0x64, 0x25, 0x68, 0x26, 0x67, 0x26, 0x69, 0x26, 0x68, 0x26, 0x6A, 0x26, 0x68, 0x26, 0x69, 0x26, 0x6A, 0x27, 0x67, 0x26, 0x6B, 0x27, 0x69, 0x27, 0x6B, 0x28, 0x6E, 0x29, 0x6D, 0x28, 0x6C, 0x28, 0x6B, 0x28, 0x6A, 0x28, 0x6F, 0x29, 0x6F, 0x29, 0x6C, 0x29, 0x6E, 0x2A, 0x72, 0x2B, 0x72, 0x2A, 0x6F, 0x29, 0x6F, 0x2A, 0x71, 0x2B, 0x6F, 0x29, 0x70, 0x2A, 0x73, 0x2C, 0x73, 0x2B, 0x70, 0x2A, 0x73, 0x2C, 0x71, 0x2A, 0x6F, 0x2A, 0x6B, 0x29, 0x71, 0x2B, 0x72, 0x2B, 0x72, 0x2B, 0x71, 0x2B, 0x74, 0x2B, 0x6E, 0x2A, 0x73, 0x2C, 0x73, 0x2C, 0x78, 0x2F, 0x77, 0x2D, 0x78, 0x30, 0x79, 0x2F, 0x78, 0x2D, 0x77, 0x2D, 0x76, 0x2D, 0x78, 0x2F, 0x7E, 0x32, 0x7D, 0x31, 0x7A, 0x2F, 0x86, 0x39, 0x8A, 0x39, 0x8B, 0x3C, 0x8A, 0x3B, 0x95, 0x41, 0x8A, 0x3B, 0x81, 0x38, 0x8F, 0x3D, 0x87, 0x37, 0x80, 0x34, 0x86, 0x37, 0x87, 0x3A, 0x84, 0x39, 0x96, 0x44, 0x95, 0x42, 0x9C, 0x4B, 0x95, 0x40, 0x96, 0x44, 0x9D, 0x48, 0x9D, 0x4C, 0xBD, 0x5C, 0xA5, 0x50, 0xA3, 0x4B, 0x9F, 0x4A, 0x9B, 0x46, 0x8A, 0x43, 0x7C, 0x4A, 0x8A, 0x4A, 0x7A, 0x43, 0x71, 0x3F, 0x7C, 0x43, 0x6F, 0x3A, 0x66, 0x33, 0x6E, 0x31, 0x7C, 0x35, 0x81, 0x3A, 0x8C, 0x3C, 0xAA, 0x50, 0x9C, 0x4B, 0x99, 0x46, 0x9F, 0x53, 0xB1, 0x4F, 0x9E, 0x4A, 0xA1, 0x4E, 0x98, 0x46, 0x95, 0x43, 0x88, 0x40, 0x96, 0x44, 0x84, 0x38, 0x83, 0x3B, 0x8E, 0x42, 0x8B, 0x3D, 0x86, 0x41, 0x85, 0x39, 0x80, 0x37, 0x8B, 0x3D, 0x89, 0x41, 0x8F, 0x3B, 0x77, 0x31, 0x76, 0x2E, 0x6B, 0x2C, 0x6C, 0x29, 0x66, 0x28, 0x6A, 0x2B, 0x6A, 0x29, 0x6D, 0x29, 0x67, 0x27, 0x68, 0x28, 0x63, 0x26, 0x66, 0x2A, 0x65, 0x27, 0x66, 0x27, 0x64, 0x25, 0x64, 0x26, 0x64, 0x28, 0x6B, 0x2C, 0x74, 0x2F, 0x76, 0x30, 0x6D, 0x2A, 0x64, 0x28, 0x71, 0x2F, 0x79, 0x35, 0x74, 0x2C, 0x6D, 0x2C, 0x6E, 0x2B, 0x6A, 0x29, 0x68, 0x28, 0x67, 0x28, 0x69, 0x29, 0x6E, 0x2A, 0x6C, 0x2C, 0x6E, 0x2B, 0x6C, 0x2A, 0x6D, 0x2C, 0x69, 0x27, 0x64, 0x26, 0x68, 0x27, 0x68, 0x28, 0x6A, 0x29, 0x65, 0x26, 0x67, 0x27, 0x69, 0x27, 0x65, 0x26, 0x64, 0x24, 0x62, 0x25, 0x64, 0x26, 0x64, 0x26, 0x68, 0x28, 0x6A, 0x2A, 0x6E, 0x2B, 0x6B, 0x28, 0x6E, 0x2D, 0x68, 0x28, 0x6D, 0x2D, 0x6D, 0x2A, 0x6D, 0x2C, 0x71, 0x2E, 0x74, 0x31, 0x71, 0x2D, 0x70, 0x2D, 0x6E, 0x2B, 0x79, 0x36, 0x71, 0x2F, 0x86, 0x3F, 0x87, 0x3C, 0x7E, 0x37, 0x8A, 0x42, 0x8F, 0x44, 0x86, 0x3D, 0x88, 0x3F, 0x92, 0x47, 0x9A, 0x48, 0x89, 0x40, 0x82, 0x3C, 0x8A, 0x40, 0x80, 0x3A, 0x85, 0x3B, 0x79, 0x36, 0x74, 0x31, 0x6E, 0x2E, 0x6A, 0x2C, 0x6B, 0x2D, 0x6C, 0x2B, 0x64, 0x29, 0x61, 0x28, 0x66, 0x2C, 0x65, 0x29, 0x66, 0x29, 0x64, 0x28, 0x5E, 0x25, 0x5E, 0x26, 0x5D, 0x24, 0x5C, 0x24, 0x61, 0x28, 0x58, 0x2A, 0x44, 0x24, 0x4D, 0x2C, 0x4A, 0x28, 0x46, 0x24, 0x47, 0x27, 0x44, 0x23, 0x43, 0x25, 0x3C, 0x1F, 0x3F, 0x22, 0x38, 0x1F, 0x43, 0x24, 0x39, 0x1E, 0x3A, 0x1F, 0x3C, 0x21, 0x34, 0x1D, 0x40, 0x23, 0x3D, 0x21, 0x44, 0x24, 0x38, 0x20, 0x43, 0x25, 0x3D, 0x21, 0x44, 0x24, 0x3E, 0x22, 0x49, 0x26, 0x3D, 0x22, 0x49, 0x25, 0x3E, 0x22, 0x4D, 0x26, 0x39, 0x1F, 0x3F, 0x21, 0x3E, 0x21, 0x43, 0x23, 0x35, 0x1E, 0x3D, 0x21, 0x40, 0x24, 0x42, 0x25, 0x44, 0x26, 0x43, 0x26, 0x40, 0x22, 0x3D, 0x20, 0x3E, 0x23, 0x43, 0x25, 0x41, 0x22, 0x41, 0x22, 0x45, 0x23, 0x41, 0x22, 0x37, 0x1E, 0x45, 0x24
    },

    {
        0x6B, 0x5C, 0x6C, 0x5E, 0x6C, 0x5E, 0x6C, 0x5D, 0x6B, 0x5C, 0x6D, 0x5E, 0x6D, 0x5E, 0x6E, 0x61, 0x6F, 0x61, 0x6E, 0x60, 0x6E, 0x60, 0x6E, 0x60, 0x6D, 0x61, 0x70, 0x63, 0x71, 0x62, 0x72, 0x61, 0x71, 0x62, 0x74, 0x64, 0x73, 0x64, 0x73, 0x63, 0x76, 0x65, 0x76, 0x66, 0x77, 0x66, 0x77, 0x67, 0x7B, 0x69, 0x7B, 0x6A, 0x7A, 0x67, 0x72, 0x61, 0x74, 0x63, 0x76, 0x64, 0x77, 0x65, 0x76, 0x66, 0x77, 0x64, 0x79, 0x67, 0x7C, 0x6B, 0x7D, 0x6B, 0x7C, 0x6C, 0x7B, 0x6A, 0x7A, 0x66, 0x77, 0x67, 0x78, 0x68, 0x78, 0x69, 0x75, 0x66, 0x77, 0x65, 0x76, 0x66, 0x75, 0x65, 0x77, 0x66, 0x77, 0x66, 0x77, 0x66, 0x77, 0x67, 0x78, 0x67, 0x76, 0x66, 0x79, 0x68, 0x80, 0x79, 0xAA, 0xB8, 0x8C, 0x76, 0x80, 0x70, 0x7E, 0x6C, 0x7A, 0x6B, 0x7C, 0x6E, 0x7A, 0x6A, 0x79, 0x6A, 0x79, 0x67, 0x7D, 0x6D, 0x7D, 0x6C, 0x7C, 0x6A, 0x7B, 0x6B, 0x7D, 0x6B, 0x7D, 0x6D, 0x7E, 0x6C, 0x7D, 0x6C, 0x7C, 0x6A, 0x80, 0x6D, 0x7E, 0x6D, 0x7B, 0x6D, 0x80, 0x71, 0x82, 0x6D, 0x7F, 0x70, 0x81, 0x70, 0x7F, 0x70, 0x83, 0x73, 0x81, 0x70, 0x82, 0x71, 0x85, 0x74, 0x85, 0x76, 0x86, 0x74, 0x81, 0x72, 0x85, 0x74, 0x85, 0x74, 0x84, 0x73, 0x84, 0x73, 0x84, 0x77, 0x85, 0x75, 0x84, 0x73, 0x88, 0x77, 0x84, 0x72, 0x81, 0x70, 0x81, 0x73, 0x86, 0x74, 0x86, 0x76, 0x87, 0x76, 0x87, 0x74, 0x88, 0x76, 0x85, 0x75, 0x88, 0x77, 0x87, 0x76, 0x89, 0x79, 0x8B, 0x79, 0x8A, 0x7B, 0x8A, 0x7B, 0x8C, 0x7A, 0x8B, 0x7B, 0x8C, 0x7C, 0x8E, 0x7E, 0x90, 0x83, 0x8E, 0x81, 0x8B, 0x7C, 0x95, 0x90, 0x99, 0x8C, 0x99, 0x8E, 0x9B, 0x8F, 0x9D, 0x98, 0x99, 0x8D, 0x91, 0x87, 0x98, 0x92, 0x96, 0x89, 0x90, 0x86, 0x95, 0x8A, 0x9A, 0x8F, 0x94, 0x88, 0x9C, 0x95, 0xA2, 0x9D, 0xA5, 0xA7, 0x9C, 0x8F, 0xA0, 0x99, 0x9F, 0x9C, 0x9F, 0x9F, 0xBA, 0xBF, 0xAE, 0xAD, 0xAB, 0xA7, 0xA7, 0xA4, 0xA4, 0xA1, 0x89, 0x89, 0x79, 0x8B, 0x77, 0x7F, 0x71, 0x7B, 0x69, 0x75, 0x76, 0x86, 0x69, 0x71, 0x64, 0x68, 0x76, 0x73, 0x86, 0x83, 0x8F, 0x8C, 0x98, 0x93, 0xAC, 0xAC, 0xA7, 0xAA, 0xA7, 0xA4, 0xAB, 0xB2, 0xB1, 0xAB, 0xA1, 0x9F, 0xAD, 0xAF, 0xA3, 0xA1, 0x9E, 0x99, 0x94, 0x8F, 0x96, 0x91, 0x96, 0x8E, 0x8C, 0x85, 0x8F, 0x8C, 0x92, 0x8D, 0x91, 0x96, 0x8D, 0x88, 0x95, 0x86, 0x8A, 0x87, 0x8E, 0x8A, 0x96, 0x8D, 0x81, 0x76, 0x83, 0x75, 0x7B, 0x71, 0x7E, 0x6F, 0x7A, 0x6D, 0x7A, 0x6F, 0x79, 0x6C, 0x7B, 0x6E, 0x76, 0x6A, 0x76, 0x68, 0x73, 0x67, 0x76, 0x6D, 0x76, 0x6A, 0x77, 0x6B, 0x76, 0x67, 0x76, 0x68, 0x73, 0x6A, 0x7B, 0x73, 0x82, 0x7B, 0x85, 0x80, 0x7D, 0x6F, 0x75, 0x69, 0x7A, 0x6F, 0x83, 0x7B, 0x82, 0x74, 0x80, 0x74, 0x7D, 0x71, 0x7D, 0x6D, 0x7A, 0x6D, 0x78, 0x6C, 0x7B, 0x6C, 0x80, 0x71, 0x7C, 0x71, 0x7E, 0x73, 0x7D, 0x71, 0x7C, 0x70, 0x78, 0x6A, 0x74, 0x68, 0x7B, 0x6C, 0x78, 0x6B, 0x7A, 0x6A, 0x76, 0x6B, 0x79, 0x6C, 0x7B, 0x6C, 0x77, 0x66, 0x74, 0x67, 0x74, 0x68, 0x75, 0x67, 0x77, 0x69, 0x76, 0x6A, 0x78, 0x6D, 0x80, 0x72, 0x7A, 0x6D, 0x7D, 0x72, 0x79, 0x6C, 0x7F, 0x76, 0x7F, 0x72, 0x7E, 0x72, 0x83, 0x79, 0x86, 0x7B, 0x82, 0x75, 0x7F, 0x74, 0x80, 0x71, 0x86, 0x81, 0x82, 0x78, 0x8F, 0x8E, 0x8C, 0x83, 0x87, 0x81, 0x90, 0x91, 0x90, 0x8C, 0x8E, 0x8D, 0x90, 0x93, 0x9A, 0x9C, 0x9A, 0x99, 0x91, 0x8D, 0x8B, 0x86, 0x8B, 0x8D, 0x8A, 0x88, 0x8D, 0x87, 0x81, 0x7C, 0x7B, 0x75, 0x7A, 0x73, 0x76, 0x6D, 0x77, 0x70, 0x76, 0x6B, 0x71, 0x69, 0x6E, 0x67, 0x70, 0x67, 0x71, 0x69, 0x73, 0x69, 0x73, 0x65, 0x6E, 0x61, 0x6B, 0x62, 0x6A, 0x5F, 0x6A, 0x61, 0x6E, 0x63, 0x55, 0x5A, 0x40, 0x45, 0x47, 0x54, 0x45, 0x4D, 0x40, 0x46, 0x40, 0x4B, 0x38, 0x3E, 0x3E, 0x47, 0x36, 0x39, 0x39, 0x41, 0x33, 0x3B, 0x3C, 0x42, 0x34, 0x39, 0x36, 0x3C, 0x36, 0x3C, 0x32, 0x39, 0x3D, 0x45, 0x39, 0x42, 0x3F, 0x48, 0x35, 0x3A, 0x40, 0x4A, 0x39, 0x3F, 0x40, 0x48, 0x39, 0x40, 0x43, 0x4C, 0x38, 0x3F, 0x41, 0x47, 0x3A, 0x44, 0x43, 0x48, 0x35, 0x3B, 0x37, 0x3D, 0x39, 0x41, 0x3C, 0x40, 0x31, 0x37, 0x38, 0x40, 0x3C, 0x43, 0x3E, 0x47, 0x42, 0x4C, 0x3D, 0x44, 0x3A, 0x42, 0x36, 0x3C, 0x3A, 0x44, 0x40, 0x48, 0x3D, 0x43, 0x3C, 0x45, 0x3E, 0x44, 0x3B, 0x43, 0x33, 0x39, 0x3C, 0x46
    },

    {
        0x5A, 0x20, 0x5A, 0x20, 0x5C, 0x20, 0x5C, 0x20, 0x5E, 0x21, 0x5C, 0x21, 0x5D, 0x22, 0x5E, 0x22, 0x5F, 0x22, 0x5D, 0x21, 0x5F, 0x22, 0x5D, 0x23, 0x5D, 0x22, 0x5F, 0x23, 0x60, 0x22, 0x61, 0x22, 0x61, 0x22, 0x61, 0x23, 0x62, 0x23, 0x61, 0x23, 0x64, 0x23, 0x65, 0x24, 0x66, 0x25, 0x67, 0x25, 0x65, 0x25, 0x64, 0x24, 0x64, 0x25, 0x62, 0x23, 0x62, 0x23, 0x62, 0x24, 0x62, 0x25, 0x62, 0x24, 0x62, 0x24, 0x67, 0x26, 0x68, 0x26, 0x66, 0x25, 0x65, 0x25, 0x66, 0x25, 0x65, 0x25, 0x64, 0x25, 0x64, 0x25, 0x67, 0x26, 0x66, 0x25, 0x62, 0x24, 0x62, 0x25, 0x62, 0x23, 0x60, 0x23, 0x63, 0x24, 0x63, 0x24, 0x64, 0x24, 0x5F, 0x23, 0x62, 0x25, 0x68, 0x29, 0x87, 0x4A, 0x92, 0x3A, 0x6C, 0x29, 0x6A, 0x28, 0x65, 0x26, 0x66, 0x27, 0x68, 0x27, 0x6A, 0x26, 0x66, 0x25, 0x67, 0x26, 0x68, 0x26, 0x69, 0x26, 0x68, 0x26, 0x66, 0x26, 0x65, 0x25, 0x64, 0x26, 0x69, 0x26, 0x68, 0x27, 0x69, 0x28, 0x67, 0x26, 0x6B, 0x27, 0x68, 0x27, 0x6B, 0x28, 0x6D, 0x27, 0x6A, 0x27, 0x6F, 0x29, 0x6F, 0x29, 0x6D, 0x28, 0x6D, 0x28, 0x6E, 0x28, 0x6F, 0x29, 0x6E, 0x29, 0x70, 0x29, 0x6F, 0x28, 0x6E, 0x28, 0x6F, 0x28, 0x70, 0x2A, 0x74, 0x2B, 0x70, 0x2A, 0x70, 0x2A, 0x73, 0x2B, 0x71, 0x2B, 0x72, 0x2A, 0x70, 0x2B, 0x71, 0x2B, 0x72, 0x2A, 0x6F, 0x2B, 0x72, 0x2B, 0x70, 0x2A, 0x70, 0x2B, 0x71, 0x2A, 0x6E, 0x29, 0x6F, 0x29, 0x73, 0x2B, 0x77, 0x2D, 0x77, 0x2D, 0x76, 0x2E, 0x76, 0x2B, 0x73, 0x2A, 0x79, 0x2F, 0x7E, 0x32, 0x7A, 0x2F, 0x7B, 0x30, 0x79, 0x33, 0x83, 0x38, 0x83, 0x38, 0x90, 0x3B, 0x84, 0x37, 0x89, 0x3B, 0x87, 0x38, 0x83, 0x35, 0x80, 0x34, 0x7D, 0x33, 0x80, 0x35, 0x7E, 0x33, 0x8B, 0x3B, 0x84, 0x37, 0x8C, 0x3E, 0x9A, 0x45, 0x91, 0x3F, 0x83, 0x37, 0x86, 0x39, 0x8C, 0x3C, 0x90, 0x43, 0xB8, 0x5A, 0xB9, 0x55, 0x9E, 0x47, 0x94, 0x41, 0x91, 0x42, 0x7B, 0x3D, 0x89, 0x4B, 0x7C, 0x40, 0x74, 0x3D, 0x6E, 0x42, 0x83, 0x45, 0x73, 0x3E, 0x54, 0x2A, 0x5F, 0x2C, 0x71, 0x2F, 0x8B, 0x3D, 0x98, 0x46, 0x9A, 0x48, 0xC2, 0x64, 0xC0, 0x5D, 0xB8, 0x5C, 0xA5, 0x50, 0xA2, 0x4E, 0xB5, 0x5E, 0xC2, 0x5F, 0xAB, 0x4F, 0x95, 0x41, 0x8F, 0x42, 0x8E, 0x3F, 0x73, 0x2F, 0x80, 0x39, 0x91, 0x44, 0x8D, 0x40, 0x8B, 0x3F, 0x93, 0x41, 0x8B, 0x3E, 0x81, 0x3A, 0x79, 0x34, 0x71, 0x2D, 0x6E, 0x2C, 0x6E, 0x2C, 0x6B, 0x2B, 0x72, 0x2E, 0x68, 0x29, 0x69, 0x28, 0x67, 0x28, 0x63, 0x26, 0x64, 0x27, 0x6B, 0x2A, 0x68, 0x2A, 0x6F, 0x2D, 0x68, 0x27, 0x67, 0x27, 0x64, 0x27, 0x6C, 0x2A, 0x67, 0x29, 0x74, 0x32, 0x87, 0x3D, 0x7A, 0x31, 0x69, 0x28, 0x66, 0x28, 0x6A, 0x2B, 0x67, 0x28, 0x67, 0x2A, 0x67, 0x28, 0x6D, 0x29, 0x69, 0x29, 0x66, 0x28, 0x6E, 0x2B, 0x6D, 0x2A, 0x6F, 0x2C, 0x6A, 0x29, 0x6A, 0x29, 0x65, 0x27, 0x63, 0x26, 0x65, 0x26, 0x66, 0x27, 0x63, 0x26, 0x65, 0x26, 0x63, 0x25, 0x66, 0x26, 0x65, 0x26, 0x64, 0x25, 0x61, 0x24, 0x65, 0x25, 0x67, 0x26, 0x66, 0x27, 0x63, 0x26, 0x67, 0x29, 0x68, 0x28, 0x6C, 0x2A, 0x68, 0x28, 0x66, 0x27, 0x6C, 0x2B, 0x6E, 0x2D, 0x70, 0x2D, 0x6D, 0x2B, 0x78, 0x33, 0x6D, 0x29, 0x6D, 0x2C, 0x73, 0x2F, 0x73, 0x30, 0x77, 0x34, 0x7A, 0x35, 0x7C, 0x36, 0x7E, 0x38, 0x82, 0x3D, 0x89, 0x40, 0x8A, 0x40, 0x98, 0x4C, 0x9E, 0x4C, 0x94, 0x4B, 0x8F, 0x41, 0x8B, 0x3F, 0x88, 0x42, 0x92, 0x45, 0x83, 0x3B, 0x79, 0x36, 0x76, 0x32, 0x6F, 0x2F, 0x74, 0x33, 0x6E, 0x30, 0x67, 0x2A, 0x6C, 0x2F, 0x72, 0x32, 0x6A, 0x2C, 0x66, 0x2A, 0x67, 0x2A, 0x64, 0x28, 0x64, 0x28, 0x5D, 0x26, 0x60, 0x26, 0x5E, 0x24, 0x5B, 0x25, 0x5C, 0x2D, 0x4A, 0x29, 0x4F, 0x2C, 0x4A, 0x27, 0x40, 0x24, 0x3D, 0x21, 0x38, 0x1F, 0x42, 0x23, 0x3F, 0x21, 0x43, 0x23, 0x3F, 0x22, 0x4B, 0x26, 0x42, 0x23, 0x3B, 0x21, 0x44, 0x24, 0x3C, 0x20, 0x4A, 0x27, 0x3B, 0x20, 0x45, 0x25, 0x37, 0x1F, 0x4B, 0x28, 0x38, 0x1F, 0x43, 0x23, 0x33, 0x1D, 0x3C, 0x20, 0x34, 0x1D, 0x3D, 0x20, 0x3B, 0x21, 0x41, 0x23, 0x3C, 0x21, 0x41, 0x22, 0x40, 0x22, 0x46, 0x26, 0x40, 0x23, 0x4A, 0x27, 0x40, 0x22, 0x46, 0x26, 0x42, 0x24, 0x3B, 0x21, 0x45, 0x25, 0x49, 0x26, 0x42, 0x24, 0x48, 0x26, 0x3C, 0x20, 0x3E, 0x21, 0x35, 0x1D, 0x3C, 0x21, 0x39, 0x20, 0x41, 0x23
    },

    {
        0x68, 0x5A, 0x6A, 0x5C, 0x6D, 0x5F, 0x6B, 0x5E, 0x6C, 0x60, 0x6D, 0x5E, 0x6F, 0x5F, 0x6F, 0x61, 0x6E, 0x61, 0x6D, 0x60, 0x6E, 0x60, 0x6C, 0x60, 0x6E, 0x60, 0x6E, 0x62, 0x71, 0x62, 0x72, 0x63, 0x70, 0x62, 0x72, 0x64, 0x73, 0x63, 0x73, 0x63, 0x79, 0x66, 0x77, 0x68, 0x77, 0x66, 0x79, 0x68, 0x79, 0x68, 0x78, 0x67, 0x77, 0x66, 0x75, 0x65, 0x75, 0x64, 0x75, 0x64, 0x75, 0x65, 0x74, 0x66, 0x78, 0x66, 0x77, 0x68, 0x7A, 0x68, 0x78, 0x67, 0x79, 0x68, 0x7A, 0x68, 0x79, 0x67, 0x77, 0x66, 0x76, 0x66, 0x7A, 0x69, 0x7A, 0x6A, 0x77, 0x65, 0x73, 0x63, 0x75, 0x64, 0x73, 0x62, 0x77, 0x67, 0x78, 0x67, 0x78, 0x64, 0x72, 0x62, 0x76, 0x66, 0x7A, 0x6D, 0x8F, 0x9C, 0x8F, 0x7C, 0x7D, 0x6C, 0x7C, 0x69, 0x79, 0x69, 0x7A, 0x69, 0x79, 0x69, 0x7C, 0x6C, 0x7A, 0x69, 0x7B, 0x6D, 0x7E, 0x6C, 0x7B, 0x6B, 0x7B, 0x68, 0x7A, 0x6A, 0x79, 0x67, 0x7A, 0x6C, 0x7E, 0x6C, 0x7D, 0x6B, 0x7D, 0x6C, 0x7C, 0x6C, 0x7E, 0x6C, 0x7E, 0x6D, 0x7F, 0x6E, 0x7F, 0x6E, 0x7E, 0x6E, 0x84, 0x76, 0x84, 0x72, 0x7F, 0x70, 0x81, 0x72, 0x83, 0x71, 0x83, 0x73, 0x84, 0x74, 0x84, 0x74, 0x83, 0x73, 0x82, 0x71, 0x81, 0x71, 0x85, 0x75, 0x87, 0x76, 0x80, 0x73, 0x85, 0x75, 0x86, 0x75, 0x85, 0x77, 0x86, 0x75, 0x83, 0x75, 0x84, 0x74, 0x85, 0x75, 0x81, 0x73, 0x86, 0x75, 0x83, 0x74, 0x82, 0x74, 0x87, 0x75, 0x85, 0x73, 0x86, 0x74, 0x88, 0x78, 0x8B, 0x7B, 0x8B, 0x79, 0x88, 0x7C, 0x89, 0x77, 0x86, 0x75, 0x8A, 0x7C, 0x8C, 0x80, 0x89, 0x7C, 0x8D, 0x7F, 0x8E, 0x81, 0x91, 0x88, 0x93, 0x88, 0x9B, 0x93, 0x96, 0x8A, 0x97, 0x90, 0x98, 0x8B, 0x94, 0x87, 0x90, 0x82, 0x8F, 0x82, 0x90, 0x85, 0x8E, 0x7D, 0x98, 0x8E, 0x92, 0x8A, 0x97, 0x90, 0x9A, 0x95, 0x98, 0x8F, 0x96, 0x8A, 0x9B, 0x8D, 0x9D, 0x93, 0xA0, 0x9A, 0xB2, 0xBB, 0xB5, 0xB7, 0xA3, 0xA4, 0x9A, 0x95, 0xA0, 0x9E, 0x85, 0x80, 0x7D, 0x93, 0x75, 0x7C, 0x6A, 0x71, 0x6B, 0x7C, 0x75, 0x7E, 0x6B, 0x77, 0x50, 0x52, 0x66, 0x68, 0x83, 0x7C, 0x96, 0x93, 0xA8, 0xAA, 0xA9, 0xAA, 0xBD, 0xD2, 0xBD, 0xC5, 0xB3, 0xB9, 0xA0, 0x9E, 0xA0, 0xA0, 0xAE, 0xB8, 0xB9, 0xC0, 0xA8, 0xA4, 0x9D, 0x99, 0x9B, 0x9B, 0x92, 0x89, 0x82, 0x77, 0x89, 0x84, 0x92, 0x92, 0x94, 0x8D, 0x95, 0x92, 0x98, 0x92, 0x96, 0x94, 0x92, 0x88, 0x84, 0x7C, 0x7E, 0x73, 0x7E, 0x73, 0x7C, 0x6F, 0x7B, 0x70, 0x81, 0x71, 0x74, 0x69, 0x79, 0x6C, 0x79, 0x6B, 0x74, 0x66, 0x75, 0x68, 0x7B, 0x6E, 0x76, 0x6C, 0x7A, 0x73, 0x77, 0x6B, 0x78, 0x69, 0x74, 0x69, 0x7B, 0x6E, 0x77, 0x6A, 0x81, 0x74, 0x8A, 0x86, 0x85, 0x7B, 0x7A, 0x6D, 0x76, 0x68, 0x7B, 0x6D, 0x78, 0x6A, 0x76, 0x6C, 0x79, 0x6B, 0x7A, 0x6D, 0x7A, 0x6F, 0x7B, 0x6F, 0x7E, 0x73, 0x80, 0x71, 0x80, 0x71, 0x7A, 0x6D, 0x7C, 0x6F, 0x78, 0x69, 0x73, 0x67, 0x77, 0x6E, 0x7A, 0x6B, 0x78, 0x68, 0x76, 0x67, 0x76, 0x68, 0x7A, 0x6B, 0x75, 0x68, 0x75, 0x66, 0x75, 0x65, 0x77, 0x6A, 0x7C, 0x6D, 0x77, 0x68, 0x78, 0x6A, 0x79, 0x6C, 0x7A, 0x6D, 0x7C, 0x6F, 0x77, 0x69, 0x76, 0x69, 0x7B, 0x6F, 0x81, 0x76, 0x7D, 0x74, 0x7E, 0x6F, 0x84, 0x7C, 0x7C, 0x6D, 0x7D, 0x72, 0x80, 0x75, 0x83, 0x79, 0x85, 0x7E, 0x84, 0x7C, 0x85, 0x7F, 0x8A, 0x85, 0x8E, 0x8B, 0x8F, 0x8C, 0x90, 0x8B, 0x9E, 0xAA, 0x9E, 0x9D, 0x95, 0x9A, 0x92, 0x8E, 0x95, 0x8E, 0x8D, 0x91, 0x96, 0x97, 0x8F, 0x86, 0x80, 0x7A, 0x7D, 0x75, 0x7B, 0x71, 0x7C, 0x78, 0x79, 0x71, 0x73, 0x6A, 0x75, 0x6F, 0x7B, 0x76, 0x76, 0x6E, 0x72, 0x69, 0x75, 0x6A, 0x74, 0x69, 0x73, 0x67, 0x6F, 0x62, 0x70, 0x68, 0x6E, 0x64, 0x68, 0x5D, 0x57, 0x5A, 0x41, 0x49, 0x43, 0x4F, 0x3F, 0x45, 0x38, 0x41, 0x39, 0x40, 0x36, 0x3B, 0x3F, 0x47, 0x3B, 0x42, 0x3E, 0x47, 0x3A, 0x43, 0x47, 0x50, 0x3A, 0x41, 0x35, 0x3D, 0x3D, 0x43, 0x37, 0x40, 0x41, 0x48, 0x33, 0x3B, 0x3D, 0x44, 0x32, 0x39, 0x43, 0x4C, 0x34, 0x3B, 0x3B, 0x40, 0x31, 0x37, 0x39, 0x3E, 0x32, 0x39, 0x38, 0x3D, 0x39, 0x41, 0x3E, 0x44, 0x39, 0x42, 0x3D, 0x43, 0x3C, 0x44, 0x42, 0x4B, 0x3B, 0x41, 0x45, 0x4D, 0x3B, 0x41, 0x3E, 0x47, 0x39, 0x40, 0x36, 0x40, 0x41, 0x4C, 0x41, 0x47, 0x3C, 0x45, 0x3E, 0x46, 0x34, 0x3A, 0x36, 0x3D, 0x30, 0x37, 0x39, 0x3F, 0x37, 0x3F, 0x3B, 0x41
    },

    {
        0x59, 0x20, 0x5B, 0x1F, 0x5A, 0x20, 0x59, 0x20, 0x5D, 0x21, 0x5D, 0x21, 0x5E, 0x22, 0x60, 0x22, 0x5F, 0x23, 0x5D, 0x23, 0x5D, 0x23, 0x59, 0x22, 0x5B, 0x22, 0x5A, 0x22, 0x5F, 0x22, 0x62, 0x23, 0x61, 0x22, 0x61, 0x23, 0x61, 0x23, 0x60, 0x22, 0x60, 0x22, 0x5F, 0x23, 0x63, 0x24, 0x64, 0x26, 0x65, 0x25, 0x64, 0x24, 0x63, 0x25, 0x64, 0x24, 0x62, 0x23, 0x62, 0x23, 0x62, 0x23, 0x5F, 0x23, 0x61, 0x23, 0x60, 0x24, 0x62, 0x24, 0x62, 0x24, 0x65, 0x24, 0x65, 0x25, 0x63, 0x24, 0x63, 0x23, 0x64, 0x24, 0x65, 0x24, 0x63, 0x24, 0x63, 0x25, 0x61, 0x24, 0x63, 0x24, 0x63, 0x24, 0x65, 0x25, 0x65, 0x25, 0x64, 0x25, 0x64, 0x25, 0x65, 0x26, 0x6E, 0x36, 0x9B, 0x47, 0x6F, 0x2B, 0x68, 0x27, 0x67, 0x27, 0x69, 0x26, 0x68, 0x27, 0x6A, 0x27, 0x69, 0x27, 0x68, 0x26, 0x66, 0x25, 0x65, 0x25, 0x68, 0x26, 0x68, 0x26, 0x69, 0x26, 0x67, 0x26, 0x6B, 0x26, 0x6A, 0x26, 0x68, 0x26, 0x6A, 0x27, 0x6B, 0x27, 0x6A, 0x26, 0x6C, 0x28, 0x6B, 0x28, 0x6B, 0x27, 0x6B, 0x27, 0x6E, 0x27, 0x6E, 0x28, 0x6D, 0x29, 0x73, 0x2A, 0x6F, 0x29, 0x6F, 0x29, 0x6E, 0x29, 0x6E, 0x29, 0x6F, 0x29, 0x6E, 0x28, 0x6A, 0x28, 0x6F, 0x29, 0x6F, 0x2A, 0x6F, 0x2A, 0x72, 0x2A, 0x73, 0x2C, 0x73, 0x2A, 0x75, 0x2B, 0x70, 0x2A, 0x73, 0x2B, 0x70, 0x2B, 0x75, 0x2C, 0x73, 0x2C, 0x72, 0x2B, 0x71, 0x2A, 0x72, 0x2A, 0x70, 0x2A, 0x72, 0x2B, 0x74, 0x2D, 0x73, 0x2D, 0x72, 0x2B, 0x70, 0x2B, 0x71, 0x2A, 0x72, 0x2B, 0x74, 0x2C, 0x77, 0x2F, 0x78, 0x2E, 0x75, 0x2D, 0x7A, 0x32, 0x7E, 0x32, 0x7D, 0x31, 0x7D, 0x32, 0x7E, 0x33, 0x7F, 0x33, 0x88, 0x38, 0x82, 0x33, 0x7F, 0x32, 0x7A, 0x31, 0x7F, 0x33, 0x7E, 0x33, 0x83, 0x35, 0x79, 0x31, 0x7B, 0x31, 0x7E, 0x33, 0x85, 0x38, 0x8C, 0x41, 0x98, 0x42, 0x92, 0x43, 0x8B, 0x3A, 0x8E, 0x40, 0x94, 0x42, 0x8A, 0x3A, 0x83, 0x38, 0x8E, 0x40, 0x8A, 0x41, 0x77, 0x40, 0x6E, 0x3B, 0x7A, 0x42, 0x6F, 0x3D, 0x6B, 0x39, 0x65, 0x32, 0x4B, 0x2A, 0x67, 0x34, 0x86, 0x3E, 0x94, 0x45, 0xC0, 0x67, 0xC5, 0x64, 0xD5, 0x72, 0xCE, 0x6A, 0xB3, 0x58, 0xA5, 0x4D, 0x91, 0x42, 0xA3, 0x52, 0xA9, 0x55, 0xA7, 0x51, 0xA9, 0x56, 0xA4, 0x51, 0x9D, 0x45, 0x89, 0x3A, 0x83, 0x3B, 0x85, 0x3B, 0x95, 0x43, 0x8B, 0x3E, 0x81, 0x36, 0x77, 0x33, 0x76, 0x34, 0x77, 0x31, 0x7B, 0x35, 0x78, 0x30, 0x6F, 0x2C, 0x6E, 0x2B, 0x68, 0x28, 0x67, 0x28, 0x69, 0x29, 0x6A, 0x2A, 0x68, 0x28, 0x67, 0x28, 0x69, 0x2A, 0x6E, 0x2D, 0x72, 0x31, 0x72, 0x2D, 0x68, 0x2A, 0x6A, 0x28, 0x66, 0x27, 0x63, 0x26, 0x65, 0x27, 0x69, 0x2B, 0x6C, 0x2C, 0x67, 0x28, 0x67, 0x28, 0x6A, 0x2A, 0x69, 0x2A, 0x66, 0x29, 0x6E, 0x2C, 0x6A, 0x29, 0x6C, 0x2B, 0x6A, 0x29, 0x6C, 0x29, 0x6E, 0x2C, 0x6F, 0x2D, 0x6B, 0x2A, 0x6C, 0x29, 0x69, 0x29, 0x67, 0x27, 0x64, 0x26, 0x64, 0x26, 0x63, 0x25, 0x63, 0x25, 0x61, 0x24, 0x66, 0x27, 0x64, 0x26, 0x64, 0x27, 0x61, 0x24, 0x65, 0x26, 0x69, 0x28, 0x65, 0x26, 0x68, 0x2A, 0x6B, 0x29, 0x6B, 0x2A, 0x68, 0x29, 0x64, 0x26, 0x66, 0x27, 0x6B, 0x2B, 0x68, 0x28, 0x6A, 0x2C, 0x73, 0x2E, 0x79, 0x34, 0x75, 0x2F, 0x68, 0x29, 0x6A, 0x2A, 0x76, 0x31, 0x78, 0x34, 0x76, 0x30, 0x73, 0x32, 0x8B, 0x44, 0x88, 0x3D, 0x7F, 0x39, 0x8E, 0x43, 0x9C, 0x50, 0xAC, 0x56, 0xA1, 0x4F, 0x90, 0x42, 0x88, 0x3E, 0x80, 0x3C, 0x86, 0x3F, 0x8E, 0x44, 0x7E, 0x38, 0x77, 0x33, 0x75, 0x33, 0x7A, 0x37, 0x6D, 0x2C, 0x65, 0x2A, 0x63, 0x28, 0x69, 0x2D, 0x69, 0x2D, 0x75, 0x34, 0x6B, 0x2E, 0x69, 0x2B, 0x6B, 0x2C, 0x68, 0x2B, 0x69, 0x2D, 0x65, 0x29, 0x5B, 0x24, 0x49, 0x24, 0x40, 0x23, 0x44, 0x26, 0x4C, 0x27, 0x44, 0x24, 0x4D, 0x27, 0x3D, 0x20, 0x4F, 0x2A, 0x3A, 0x20, 0x3F, 0x23, 0x41, 0x23, 0x4A, 0x26, 0x35, 0x1C, 0x3A, 0x20, 0x40, 0x21, 0x41, 0x22, 0x3E, 0x22, 0x3D, 0x21, 0x3F, 0x22, 0x3F, 0x22, 0x45, 0x24, 0x3E, 0x21, 0x46, 0x24, 0x43, 0x24, 0x4A, 0x25, 0x3D, 0x22, 0x49, 0x26, 0x46, 0x26, 0x49, 0x27, 0x3F, 0x23, 0x3F, 0x21, 0x40, 0x23, 0x43, 0x23, 0x38, 0x20, 0x43, 0x25, 0x40, 0x25, 0x49, 0x27, 0x44, 0x24, 0x44, 0x24, 0x43, 0x24, 0x37, 0x1F, 0x3F, 0x22, 0x41, 0x23, 0x41, 0x22, 0x40, 0x23, 0x3F, 0x22, 0x4B, 0x29, 0x43, 0x27, 0x46, 0x2A
    },

    {
        0x6A, 0x5B, 0x69, 0x5B, 0x6A, 0x5B, 0x6A, 0x5C, 0x6D, 0x60, 0x6E, 0x60, 0x70, 0x62, 0x70, 0x63, 0x6C, 0x61, 0x68, 0x5E, 0x64, 0x5B, 0x60, 0x59, 0x66, 0x5B, 0x67, 0x5C, 0x6D, 0x61, 0x71, 0x62, 0x70, 0x62, 0x70, 0x61, 0x71, 0x63, 0x71, 0x62, 0x75, 0x62, 0x73, 0x64, 0x76, 0x64, 0x76, 0x67, 0x75, 0x66, 0x75, 0x66, 0x75, 0x67, 0x76, 0x67, 0x75, 0x65, 0x76, 0x65, 0x75, 0x64, 0x73, 0x64, 0x74, 0x63, 0x73, 0x64, 0x76, 0x65, 0x76, 0x65, 0x7A, 0x67, 0x79, 0x67, 0x78, 0x67, 0x76, 0x64, 0x78, 0x66, 0x7A, 0x67, 0x77, 0x67, 0x75, 0x65, 0x74, 0x64, 0x77, 0x67, 0x77, 0x68, 0x78, 0x69, 0x79, 0x68, 0x79, 0x67, 0x78, 0x68, 0x78, 0x68, 0x81, 0x7E, 0x9C, 0x97, 0x80, 0x6F, 0x79, 0x6A, 0x7A, 0x69, 0x7E, 0x6A, 0x7D, 0x6B, 0x7E, 0x6C, 0x7E, 0x70, 0x7B, 0x69, 0x7A, 0x68, 0x79, 0x68, 0x7C, 0x6C, 0x7D, 0x6B, 0x7C, 0x6A, 0x7C, 0x6B, 0x7F, 0x6C, 0x7F, 0x6D, 0x7C, 0x6C, 0x7E, 0x6D, 0x7F, 0x6D, 0x80, 0x6E, 0x83, 0x71, 0x81, 0x71, 0x7F, 0x6E, 0x7D, 0x6F, 0x84, 0x72, 0x84, 0x71, 0x82, 0x72, 0x85, 0x77, 0x84, 0x72, 0x83, 0x73, 0x83, 0x72, 0x83, 0x72, 0x84, 0x72, 0x84, 0x70, 0x80, 0x6F, 0x85, 0x74, 0x85, 0x73, 0x81, 0x75, 0x86, 0x74, 0x88, 0x78, 0x86, 0x74, 0x88, 0x78, 0x84, 0x74, 0x87, 0x76, 0x82, 0x72, 0x88, 0x79, 0x87, 0x76, 0x84, 0x74, 0x88, 0x76, 0x86, 0x75, 0x85, 0x75, 0x83, 0x76, 0x84, 0x77, 0x86, 0x75, 0x86, 0x73, 0x85, 0x74, 0x85, 0x76, 0x88, 0x7B, 0x8B, 0x78, 0x88, 0x7B, 0x88, 0x7A, 0x88, 0x78, 0x8B, 0x7E, 0x8C, 0x7F, 0x8B, 0x7F, 0x8C, 0x80, 0x8E, 0x82, 0x91, 0x81, 0x95, 0x8C, 0x92, 0x85, 0x8F, 0x83, 0x8D, 0x7E, 0x8E, 0x82, 0x91, 0x85, 0x92, 0x83, 0x8B, 0x7D, 0x8D, 0x7E, 0x8F, 0x83, 0x96, 0x8C, 0x98, 0x94, 0x9E, 0x96, 0xA3, 0xA1, 0x92, 0x87, 0x95, 0x91, 0x99, 0x94, 0x95, 0x8A, 0x8F, 0x86, 0x94, 0x91, 0x84, 0x83, 0x6A, 0x75, 0x66, 0x6B, 0x70, 0x7D, 0x65, 0x70, 0x63, 0x6B, 0x58, 0x5A, 0x46, 0x4E, 0x6D, 0x73, 0x91, 0x96, 0xA2, 0xA5, 0xC2, 0xCF, 0xBD, 0xC6, 0xC7, 0xD2, 0xC4, 0xC9, 0xAF, 0xB3, 0xA4, 0xA5, 0x9A, 0x98, 0xA6, 0xAA, 0xA8, 0xAB, 0xA1, 0xA1, 0xA5, 0xA6, 0x9D, 0x9E, 0x98, 0x96, 0x92, 0x8A, 0x8C, 0x85, 0x8F, 0x89, 0x9C, 0x9B, 0x94, 0x89, 0x87, 0x7E, 0x82, 0x77, 0x84, 0x7B, 0x86, 0x75, 0x85, 0x7E, 0x84, 0x79, 0x7F, 0x73, 0x7F, 0x72, 0x76, 0x69, 0x79, 0x6C, 0x7B, 0x6D, 0x78, 0x6E, 0x78, 0x6B, 0x74, 0x69, 0x79, 0x6D, 0x7B, 0x72, 0x7C, 0x78, 0x7F, 0x73, 0x77, 0x6E, 0x79, 0x6D, 0x76, 0x68, 0x76, 0x68, 0x75, 0x67, 0x77, 0x6C, 0x77, 0x6C, 0x77, 0x6A, 0x76, 0x69, 0x7A, 0x6F, 0x7B, 0x70, 0x76, 0x6D, 0x7C, 0x72, 0x7A, 0x6B, 0x7C, 0x71, 0x7C, 0x6F, 0x7B, 0x6E, 0x7F, 0x73, 0x81, 0x75, 0x7D, 0x71, 0x7E, 0x70, 0x78, 0x6E, 0x74, 0x68, 0x75, 0x68, 0x75, 0x66, 0x77, 0x68, 0x75, 0x66, 0x71, 0x64, 0x78, 0x6C, 0x75, 0x68, 0x76, 0x68, 0x73, 0x64, 0x78, 0x6B, 0x7B, 0x6D, 0x79, 0x6C, 0x78, 0x6E, 0x7B, 0x6E, 0x7F, 0x71, 0x7A, 0x6E, 0x7A, 0x6B, 0x79, 0x69, 0x7A, 0x75, 0x79, 0x6E, 0x7A, 0x74, 0x80, 0x77, 0x83, 0x83, 0x83, 0x79, 0x79, 0x6D, 0x7B, 0x6E, 0x84, 0x7E, 0x86, 0x7E, 0x85, 0x7A, 0x84, 0x7D, 0x8F, 0x90, 0x89, 0x85, 0x8A, 0x87, 0x94, 0x94, 0x99, 0x9E, 0xAA, 0xB3, 0xA4, 0xA3, 0x94, 0x90, 0x89, 0x82, 0x87, 0x81, 0x8A, 0x85, 0x92, 0x94, 0x89, 0x84, 0x81, 0x79, 0x81, 0x7A, 0x80, 0x7C, 0x76, 0x6B, 0x72, 0x67, 0x71, 0x66, 0x73, 0x6A, 0x76, 0x6E, 0x7D, 0x76, 0x78, 0x72, 0x75, 0x6B, 0x79, 0x6D, 0x77, 0x6C, 0x75, 0x6B, 0x72, 0x68, 0x69, 0x5D, 0x48, 0x46, 0x3E, 0x45, 0x3F, 0x4B, 0x47, 0x4E, 0x3E, 0x45, 0x44, 0x4D, 0x37, 0x3F, 0x46, 0x4D, 0x34, 0x37, 0x3A, 0x42, 0x3B, 0x47, 0x3F, 0x45, 0x34, 0x38, 0x37, 0x41, 0x3F, 0x46, 0x3F, 0x46, 0x3B, 0x43, 0x39, 0x3F, 0x3F, 0x45, 0x3D, 0x44, 0x43, 0x4B, 0x3B, 0x42, 0x44, 0x4A, 0x3F, 0x49, 0x44, 0x4C, 0x38, 0x40, 0x43, 0x4A, 0x3E, 0x47, 0x3F, 0x43, 0x38, 0x43, 0x37, 0x3C, 0x3D, 0x46, 0x3C, 0x41, 0x34, 0x3D, 0x3C, 0x43, 0x3C, 0x47, 0x44, 0x4B, 0x41, 0x48, 0x3E, 0x44, 0x3B, 0x42, 0x33, 0x37, 0x3A, 0x43, 0x3D, 0x45, 0x3D, 0x44, 0x3C, 0x46, 0x3A, 0x42, 0x45, 0x4D, 0x3D, 0x44, 0x41, 0x47
    },

    {
        0x5B, 0x21, 0x58, 0x20, 0x58, 0x20, 0x5C, 0x20, 0x5B, 0x20, 0x5E, 0x22, 0x61, 0x22, 0x61, 0x22, 0x5D, 0x23, 0x53, 0x23, 0x4D, 0x23, 0x4D, 0x22, 0x51, 0x22, 0x56, 0x22, 0x5B, 0x22, 0x5E, 0x22, 0x5F, 0x22, 0x60, 0x23, 0x60, 0x23, 0x61, 0x22, 0x5E, 0x22, 0x61, 0x23, 0x63, 0x23, 0x63, 0x24, 0x64, 0x24, 0x63, 0x24, 0x63, 0x24, 0x61, 0x23, 0x63, 0x24, 0x64, 0x23, 0x62, 0x23, 0x62, 0x24, 0x62, 0x23, 0x63, 0x24, 0x65, 0x24, 0x63, 0x23, 0x62, 0x24, 0x63, 0x24, 0x67, 0x26, 0x64, 0x24, 0x65, 0x24, 0x63, 0x24, 0x64, 0x24, 0x61, 0x24, 0x63, 0x25, 0x66, 0x25, 0x66, 0x26, 0x63, 0x25, 0x65, 0x24, 0x64, 0x25, 0x64, 0x26, 0x6B, 0x2E, 0xA1, 0x54, 0x87, 0x34, 0x69, 0x28, 0x66, 0x26, 0x67, 0x26, 0x66, 0x26, 0x67, 0x26, 0x6B, 0x2A, 0x6E, 0x28, 0x64, 0x25, 0x65, 0x25, 0x69, 0x27, 0x6A, 0x27, 0x69, 0x26, 0x67, 0x26, 0x6C, 0x27, 0x67, 0x26, 0x67, 0x26, 0x69, 0x26, 0x68, 0x26, 0x69, 0x26, 0x68, 0x26, 0x6B, 0x27, 0x68, 0x26, 0x6E, 0x2A, 0x70, 0x28, 0x71, 0x29, 0x6C, 0x29, 0x6F, 0x29, 0x73, 0x2A, 0x6F, 0x2A, 0x6F, 0x29, 0x71, 0x2A, 0x72, 0x2A, 0x6F, 0x29, 0x6D, 0x28, 0x6F, 0x29, 0x71, 0x2B, 0x70, 0x29, 0x71, 0x2A, 0x71, 0x2B, 0x73, 0x2C, 0x70, 0x29, 0x70, 0x2B, 0x6F, 0x29, 0x72, 0x2B, 0x70, 0x2C, 0x78, 0x2F, 0x73, 0x2C, 0x73, 0x2C, 0x77, 0x2E, 0x74, 0x2B, 0x70, 0x2A, 0x71, 0x2B, 0x70, 0x2A, 0x6F, 0x29, 0x6E, 0x2A, 0x72, 0x2B, 0x70, 0x2A, 0x73, 0x2D, 0x72, 0x2C, 0x75, 0x2D, 0x73, 0x2D, 0x77, 0x2F, 0x77, 0x2E, 0x79, 0x30, 0x79, 0x2F, 0x78, 0x2E, 0x79, 0x30, 0x7B, 0x2F, 0x79, 0x2E, 0x78, 0x2E, 0x78, 0x2E, 0x77, 0x2E, 0x7E, 0x32, 0x7A, 0x2F, 0x77, 0x2E, 0x78, 0x2F, 0x7B, 0x2F, 0x7A, 0x30, 0x7F, 0x31, 0x7F, 0x32, 0x81, 0x37, 0x91, 0x3C, 0x82, 0x36, 0x86, 0x37, 0x80, 0x32, 0x7B, 0x32, 0x7E, 0x32, 0x7A, 0x32, 0x6D, 0x2E, 0x61, 0x2F, 0x62, 0x34, 0x63, 0x32, 0x60, 0x33, 0x5C, 0x2D, 0x3D, 0x22, 0x44, 0x25, 0x69, 0x35, 0x89, 0x3E, 0x9C, 0x4A, 0xB6, 0x61, 0xC4, 0x63, 0xC4, 0x63, 0xB9, 0x59, 0x99, 0x49, 0x9E, 0x4D, 0x9F, 0x49, 0x96, 0x46, 0xA3, 0x4C, 0xA1, 0x4D, 0x7D, 0x35, 0x7D, 0x3A, 0x90, 0x43, 0x8C, 0x41, 0x7F, 0x37, 0x7B, 0x35, 0x9E, 0x4F, 0xA2, 0x4C, 0x99, 0x47, 0x93, 0x47, 0x94, 0x41, 0x87, 0x39, 0x72, 0x2E, 0x73, 0x2F, 0x76, 0x30, 0x74, 0x32, 0x70, 0x2C, 0x6D, 0x2C, 0x69, 0x29, 0x68, 0x29, 0x67, 0x27, 0x67, 0x28, 0x68, 0x28, 0x68, 0x29, 0x63, 0x28, 0x68, 0x28, 0x66, 0x27, 0x66, 0x28, 0x62, 0x26, 0x66, 0x28, 0x66, 0x27, 0x69, 0x2B, 0x6E, 0x2C, 0x65, 0x27, 0x67, 0x28, 0x70, 0x2F, 0x6D, 0x2C, 0x6C, 0x2B, 0x6F, 0x2C, 0x6A, 0x29, 0x6F, 0x2C, 0x6C, 0x2A, 0x6C, 0x2A, 0x6F, 0x2C, 0x70, 0x2D, 0x6B, 0x29, 0x68, 0x28, 0x66, 0x26, 0x63, 0x25, 0x5F, 0x24, 0x5E, 0x23, 0x5E, 0x24, 0x5E, 0x24, 0x61, 0x24, 0x65, 0x27, 0x65, 0x26, 0x65, 0x25, 0x64, 0x25, 0x64, 0x26, 0x67, 0x26, 0x67, 0x27, 0x65, 0x26, 0x63, 0x25, 0x66, 0x28, 0x6E, 0x2C, 0x64, 0x26, 0x64, 0x26, 0x69, 0x2C, 0x69, 0x29, 0x69, 0x2C, 0x78, 0x36, 0x88, 0x3C, 0x75, 0x2F, 0x6C, 0x29, 0x6C, 0x2C, 0x76, 0x34, 0x7D, 0x37, 0x76, 0x32, 0x75, 0x30, 0x7B, 0x37, 0x7C, 0x36, 0x99, 0x4E, 0xA3, 0x4E, 0x98, 0x4D, 0xAB, 0x56, 0x9A, 0x49, 0x8C, 0x42, 0x90, 0x44, 0x89, 0x40, 0x8F, 0x43, 0x88, 0x42, 0x8A, 0x41, 0x7C, 0x34, 0x79, 0x36, 0x70, 0x30, 0x72, 0x2F, 0x65, 0x29, 0x66, 0x29, 0x69, 0x2C, 0x70, 0x30, 0x72, 0x30, 0x70, 0x30, 0x6B, 0x2C, 0x6A, 0x2C, 0x6B, 0x2C, 0x67, 0x29, 0x66, 0x29, 0x5C, 0x25, 0x48, 0x24, 0x4C, 0x28, 0x4D, 0x2A, 0x4A, 0x26, 0x3B, 0x21, 0x42, 0x23, 0x41, 0x24, 0x42, 0x22, 0x3A, 0x20, 0x47, 0x25, 0x48, 0x25, 0x42, 0x23, 0x44, 0x23, 0x40, 0x24, 0x50, 0x29, 0x42, 0x23, 0x49, 0x26, 0x3C, 0x21, 0x4C, 0x28, 0x3E, 0x22, 0x4E, 0x28, 0x40, 0x23, 0x44, 0x24, 0x3A, 0x21, 0x40, 0x22, 0x35, 0x1F, 0x3D, 0x21, 0x3D, 0x22, 0x3A, 0x20, 0x3D, 0x22, 0x3E, 0x22, 0x44, 0x25, 0x49, 0x27, 0x44, 0x25, 0x4C, 0x28, 0x46, 0x27, 0x4C, 0x29, 0x41, 0x25, 0x39, 0x23, 0x3F, 0x29, 0x3D, 0x28, 0x40, 0x2C, 0x46, 0x2C, 0x38, 0x20, 0x40, 0x21, 0x3D, 0x22, 0x45, 0x36, 0x47, 0x3E, 0x4B, 0x42
    },

    {
        0x6A, 0x5D, 0x6A, 0x5D, 0x6A, 0x5C, 0x6E, 0x5F, 0x6C, 0x5E, 0x6E, 0x62, 0x72, 0x64, 0x6F, 0x61, 0x66, 0x5C, 0x57, 0x52, 0x51, 0x4D, 0x50, 0x4E, 0x53, 0x51, 0x5A, 0x56, 0x66, 0x5B, 0x6C, 0x60, 0x70, 0x61, 0x71, 0x61, 0x6F, 0x61, 0x72, 0x62, 0x71, 0x60, 0x74, 0x65, 0x75, 0x63, 0x74, 0x65, 0x76, 0x65, 0x77, 0x66, 0x76, 0x66, 0x76, 0x65, 0x77, 0x66, 0x78, 0x66, 0x76, 0x65, 0x76, 0x66, 0x77, 0x66, 0x79, 0x67, 0x78, 0x67, 0x77, 0x65, 0x76, 0x64, 0x76, 0x67, 0x79, 0x69, 0x77, 0x66, 0x78, 0x66, 0x76, 0x67, 0x77, 0x66, 0x76, 0x66, 0x76, 0x67, 0x79, 0x69, 0x79, 0x68, 0x77, 0x66, 0x79, 0x68, 0x78, 0x67, 0x78, 0x68, 0x7C, 0x74, 0x9B, 0xAA, 0x8C, 0x78, 0x7B, 0x6C, 0x7A, 0x6A, 0x7C, 0x6A, 0x7B, 0x6B, 0x79, 0x69, 0x7E, 0x70, 0x80, 0x6C, 0x78, 0x67, 0x79, 0x68, 0x7D, 0x6D, 0x80, 0x6E, 0x7F, 0x6C, 0x7B, 0x69, 0x7C, 0x6C, 0x7D, 0x6B, 0x7D, 0x6A, 0x7E, 0x6E, 0x7B, 0x69, 0x7C, 0x6C, 0x7D, 0x6C, 0x80, 0x6E, 0x7E, 0x6D, 0x82, 0x74, 0x82, 0x6F, 0x85, 0x72, 0x7F, 0x70, 0x85, 0x75, 0x88, 0x76, 0x85, 0x72, 0x85, 0x71, 0x88, 0x77, 0x88, 0x74, 0x83, 0x71, 0x80, 0x6F, 0x84, 0x73, 0x85, 0x75, 0x87, 0x74, 0x85, 0x74, 0x85, 0x74, 0x87, 0x77, 0x86, 0x74, 0x83, 0x72, 0x82, 0x73, 0x83, 0x72, 0x83, 0x75, 0x89, 0x7B, 0x86, 0x77, 0x84, 0x75, 0x88, 0x7B, 0x86, 0x76, 0x81, 0x71, 0x86, 0x75, 0x83, 0x73, 0x84, 0x74, 0x81, 0x73, 0x86, 0x76, 0x85, 0x75, 0x84, 0x75, 0x85, 0x76, 0x87, 0x78, 0x84, 0x75, 0x89, 0x7C, 0x87, 0x7A, 0x8C, 0x7E, 0x8C, 0x7D, 0x8D, 0x7D, 0x8C, 0x7C, 0x8B, 0x7D, 0x89, 0x7A, 0x8A, 0x79, 0x8A, 0x7C, 0x8C, 0x7C, 0x8E, 0x81, 0x8B, 0x7A, 0x8D, 0x7D, 0x8D, 0x7E, 0x8E, 0x7D, 0x8F, 0x80, 0x91, 0x80, 0x8F, 0x80, 0x92, 0x86, 0x96, 0x8E, 0x92, 0x89, 0x92, 0x88, 0x94, 0x83, 0x8D, 0x7F, 0x90, 0x84, 0x87, 0x79, 0x78, 0x6E, 0x64, 0x61, 0x62, 0x68, 0x5E, 0x60, 0x57, 0x5E, 0x53, 0x59, 0x3F, 0x41, 0x4A, 0x4F, 0x75, 0x7E, 0x8E, 0x8C, 0xA0, 0xA1, 0xB3, 0xC2, 0xC1, 0xC6, 0xB8, 0xC0, 0xA8, 0xA7, 0x98, 0x99, 0xA4, 0xA4, 0x9D, 0x98, 0x9D, 0x9A, 0xA0, 0x9D, 0xA2, 0xA5, 0x89, 0x80, 0x8E, 0x8C, 0x9A, 0x99, 0x98, 0x97, 0x92, 0x8A, 0x84, 0x7B, 0x9E, 0xA5, 0xA7, 0xAB, 0xA1, 0x9F, 0xA0, 0x9F, 0x9E, 0x9D, 0x94, 0x8F, 0x86, 0x7A, 0x7E, 0x75, 0x85, 0x7C, 0x83, 0x7D, 0x7E, 0x74, 0x7B, 0x72, 0x78, 0x6B, 0x75, 0x6C, 0x79, 0x6B, 0x76, 0x69, 0x76, 0x69, 0x77, 0x6B, 0x76, 0x6A, 0x76, 0x69, 0x74, 0x67, 0x76, 0x67, 0x72, 0x65, 0x77, 0x6A, 0x75, 0x6A, 0x77, 0x6C, 0x7A, 0x70, 0x74, 0x67, 0x77, 0x6B, 0x7E, 0x73, 0x7A, 0x70, 0x7C, 0x70, 0x7F, 0x72, 0x7D, 0x6F, 0x7E, 0x71, 0x7D, 0x70, 0x7E, 0x70, 0x80, 0x72, 0x80, 0x73, 0x79, 0x6D, 0x79, 0x6C, 0x77, 0x68, 0x77, 0x66, 0x72, 0x66, 0x6F, 0x63, 0x6D, 0x60, 0x72, 0x62, 0x75, 0x66, 0x78, 0x6B, 0x7A, 0x6B, 0x77, 0x68, 0x78, 0x69, 0x76, 0x6A, 0x78, 0x6C, 0x77, 0x6A, 0x75, 0x67, 0x74, 0x67, 0x75, 0x69, 0x7B, 0x74, 0x74, 0x68, 0x76, 0x68, 0x77, 0x6C, 0x79, 0x6E, 0x7C, 0x74, 0x82, 0x7D, 0x91, 0x8D, 0x86, 0x77, 0x7F, 0x6C, 0x7C, 0x70, 0x83, 0x7F, 0x88, 0x82, 0x84, 0x7A, 0x83, 0x7A, 0x87, 0x81, 0x88, 0x82, 0xA5, 0xB1, 0xAA, 0xAD, 0x9E, 0xA7, 0xA3, 0xA5, 0x9B, 0x99, 0x90, 0x8C, 0x9B, 0x95, 0x94, 0x90, 0x96, 0x91, 0x8A, 0x8D, 0x91, 0x8F, 0x85, 0x7B, 0x82, 0x78, 0x7A, 0x71, 0x81, 0x78, 0x78, 0x6B, 0x77, 0x6D, 0x78, 0x70, 0x7C, 0x76, 0x80, 0x76, 0x7C, 0x73, 0x79, 0x6F, 0x77, 0x6D, 0x79, 0x6F, 0x75, 0x6B, 0x70, 0x67, 0x68, 0x5C, 0x49, 0x4C, 0x44, 0x48, 0x46, 0x51, 0x3F, 0x44, 0x36, 0x3D, 0x3D, 0x43, 0x3E, 0x48, 0x3F, 0x44, 0x37, 0x3D, 0x41, 0x4C, 0x40, 0x47, 0x3E, 0x46, 0x3D, 0x42, 0x3C, 0x49, 0x47, 0x4E, 0x3B, 0x41, 0x42, 0x4A, 0x38, 0x40, 0x42, 0x49, 0x39, 0x42, 0x44, 0x4B, 0x39, 0x3F, 0x39, 0x40, 0x33, 0x3C, 0x38, 0x3D, 0x33, 0x3A, 0x39, 0x3E, 0x39, 0x41, 0x38, 0x3C, 0x3A, 0x42, 0x3B, 0x42, 0x41, 0x4C, 0x44, 0x4C, 0x3F, 0x49, 0x45, 0x4A, 0x3E, 0x49, 0x42, 0x46, 0x3A, 0x3F, 0x37, 0x3A, 0x3C, 0x42, 0x3B, 0x3E, 0x3C, 0x41, 0x3E, 0x43, 0x32, 0x38, 0x37, 0x3E, 0x38, 0x40, 0x41, 0x46, 0x44, 0x4A, 0x47, 0x4D
    },

    {
        0x5D, 0x21, 0x5B, 0x20, 0x5B, 0x21, 0x5D, 0x20, 0x5C, 0x20, 0x5E, 0x21, 0x5D, 0x22, 0x5E, 0x23, 0x54, 0x24, 0x4D, 0x24, 0x4B, 0x23, 0x49, 0x23, 0x4C, 0x24, 0x4D, 0x23, 0x51, 0x21, 0x5A, 0x22, 0x5D, 0x23, 0x5F, 0x22, 0x5E, 0x22, 0x5E, 0x22, 0x60, 0x23, 0x63, 0x23, 0x61, 0x23, 0x63, 0x23, 0x62, 0x24, 0x63, 0x23, 0x64, 0x24, 0x63, 0x23, 0x62, 0x23, 0x63, 0x24, 0x63, 0x23, 0x64, 0x25, 0x65, 0x24, 0x63, 0x23, 0x65, 0x25, 0x66, 0x25, 0x66, 0x26, 0x66, 0x25, 0x62, 0x24, 0x62, 0x24, 0x65, 0x25, 0x64, 0x24, 0x63, 0x24, 0x65, 0x25, 0x65, 0x26, 0x64, 0x25, 0x63, 0x24, 0x64, 0x25, 0x65, 0x25, 0x65, 0x25, 0x66, 0x27, 0x72, 0x37, 0x80, 0x38, 0x6B, 0x29, 0x65, 0x26, 0x64, 0x26, 0x65, 0x25, 0x65, 0x26, 0x66, 0x25, 0x64, 0x25, 0x68, 0x27, 0x68, 0x26, 0x6A, 0x26, 0x6A, 0x26, 0x6B, 0x27, 0x68, 0x26, 0x68, 0x26, 0x65, 0x26, 0x6A, 0x27, 0x6C, 0x28, 0x6A, 0x27, 0x68, 0x26, 0x6A, 0x27, 0x68, 0x26, 0x67, 0x26, 0x6B, 0x27, 0x6E, 0x29, 0x6D, 0x27, 0x6C, 0x27, 0x6A, 0x27, 0x6F, 0x29, 0x6D, 0x27, 0x6D, 0x28, 0x6E, 0x29, 0x71, 0x29, 0x6E, 0x28, 0x70, 0x28, 0x6B, 0x28, 0x6F, 0x2A, 0x72, 0x2C, 0x77, 0x2D, 0x72, 0x2B, 0x74, 0x2D, 0x77, 0x2E, 0x76, 0x2C, 0x6F, 0x2A, 0x70, 0x2A, 0x6F, 0x2A, 0x71, 0x2B, 0x74, 0x2D, 0x76, 0x2D, 0x72, 0x2C, 0x72, 0x2B, 0x71, 0x2B, 0x6F, 0x2B, 0x70, 0x2A, 0x73, 0x2D, 0x75, 0x2C, 0x71, 0x2A, 0x70, 0x2B, 0x73, 0x2B, 0x71, 0x2B, 0x74, 0x2C, 0x71, 0x2B, 0x6E, 0x2A, 0x78, 0x2E, 0x75, 0x2F, 0x7C, 0x32, 0x79, 0x2F, 0x72, 0x2C, 0x76, 0x2E, 0x77, 0x2C, 0x7A, 0x2F, 0x77, 0x2D, 0x76, 0x2E, 0x7C, 0x31, 0x7B, 0x2F, 0x75, 0x2D, 0x76, 0x2D, 0x7A, 0x2F, 0x7B, 0x30, 0x7B, 0x30, 0x7D, 0x2F, 0x78, 0x2E, 0x79, 0x31, 0x80, 0x32, 0x7D, 0x31, 0x74, 0x2F, 0x7D, 0x31, 0x79, 0x2E, 0x73, 0x2E, 0x75, 0x2F, 0x71, 0x2C, 0x5A, 0x27, 0x49, 0x25, 0x4D, 0x27, 0x42, 0x24, 0x3C, 0x23, 0x4C, 0x2C, 0x66, 0x36, 0x88, 0x41, 0x97, 0x48, 0xA3, 0x50, 0xBB, 0x62, 0xB3, 0x58, 0x9E, 0x4C, 0x9D, 0x4B, 0x8E, 0x41, 0x92, 0x40, 0x84, 0x3F, 0xA0, 0x4A, 0x8F, 0x45, 0x9A, 0x4C, 0x9F, 0x48, 0x99, 0x47, 0x97, 0x46, 0x95, 0x46, 0x8B, 0x3A, 0x7F, 0x36, 0x7C, 0x36, 0x99, 0x49, 0x9A, 0x4D, 0x98, 0x46, 0xA4, 0x54, 0x9B, 0x44, 0x8C, 0x3E, 0x7C, 0x33, 0x81, 0x3A, 0x82, 0x36, 0x79, 0x34, 0x72, 0x2D, 0x6F, 0x2D, 0x69, 0x29, 0x67, 0x29, 0x61, 0x26, 0x65, 0x28, 0x69, 0x2C, 0x6E, 0x2B, 0x65, 0x27, 0x66, 0x28, 0x6B, 0x2A, 0x64, 0x26, 0x67, 0x29, 0x6A, 0x28, 0x65, 0x26, 0x61, 0x26, 0x66, 0x29, 0x63, 0x27, 0x6E, 0x2E, 0x6A, 0x29, 0x69, 0x2A, 0x6A, 0x2A, 0x6B, 0x2A, 0x66, 0x28, 0x6C, 0x2B, 0x6D, 0x2C, 0x6F, 0x2B, 0x6F, 0x2C, 0x6A, 0x2A, 0x6B, 0x2A, 0x6C, 0x2A, 0x69, 0x27, 0x67, 0x27, 0x65, 0x26, 0x60, 0x25, 0x61, 0x25, 0x63, 0x25, 0x64, 0x26, 0x63, 0x25, 0x65, 0x25, 0x64, 0x25, 0x66, 0x26, 0x64, 0x26, 0x61, 0x24, 0x67, 0x27, 0x65, 0x26, 0x65, 0x27, 0x68, 0x29, 0x68, 0x28, 0x61, 0x27, 0x64, 0x27, 0x68, 0x29, 0x6E, 0x2D, 0x71, 0x32, 0x88, 0x40, 0x7C, 0x33, 0x69, 0x29, 0x6F, 0x2C, 0x6D, 0x2D, 0x7D, 0x39, 0x7F, 0x36, 0x77, 0x33, 0x7F, 0x37, 0x76, 0x35, 0xA8, 0x59, 0xAA, 0x50, 0x8D, 0x45, 0x9D, 0x4C, 0x99, 0x4A, 0x8D, 0x43, 0x8D, 0x42, 0x98, 0x4B, 0x8F, 0x41, 0x81, 0x3B, 0x8C, 0x43, 0x87, 0x3E, 0x82, 0x3B, 0x76, 0x32, 0x7C, 0x3A, 0x73, 0x2F, 0x75, 0x35, 0x80, 0x3B, 0x78, 0x33, 0x82, 0x3B, 0x76, 0x33, 0x76, 0x34, 0x72, 0x30, 0x6E, 0x2F, 0x6D, 0x2C, 0x60, 0x27, 0x5E, 0x26, 0x47, 0x24, 0x3F, 0x22, 0x4C, 0x27, 0x4A, 0x27, 0x43, 0x23, 0x4C, 0x29, 0x48, 0x25, 0x49, 0x27, 0x3A, 0x20, 0x4D, 0x28, 0x3F, 0x22, 0x45, 0x25, 0x3A, 0x20, 0x44, 0x25, 0x44, 0x23, 0x3C, 0x22, 0x43, 0x24, 0x38, 0x20, 0x3B, 0x21, 0x3E, 0x23, 0x3F, 0x23, 0x3E, 0x22, 0x42, 0x24, 0x3C, 0x21, 0x44, 0x24, 0x40, 0x23, 0x44, 0x27, 0x45, 0x29, 0x45, 0x28, 0x3F, 0x28, 0x41, 0x2A, 0x44, 0x2F, 0x43, 0x2A, 0x3B, 0x21, 0x3D, 0x21, 0x40, 0x26, 0x3A, 0x32, 0x3B, 0x38, 0x3B, 0x37, 0x39, 0x38, 0x39, 0x38, 0x3A, 0x38, 0x34, 0x2A, 0x2D, 0x1D, 0x44, 0x23, 0x41, 0x24, 0x40, 0x32, 0x3B, 0x33, 0x38, 0x31
    },

    {
        0x6E, 0x5E, 0x6A, 0x5C, 0x6B, 0x5E, 0x6D, 0x5F, 0x6C, 0x5F, 0x6F, 0x60, 0x6D, 0x61, 0x6A, 0x5D, 0x58, 0x51, 0x4F, 0x4E, 0x4D, 0x4C, 0x4B, 0x4C, 0x4C, 0x4C, 0x4F, 0x4D, 0x56, 0x50, 0x63, 0x59, 0x6D, 0x61, 0x71, 0x61, 0x71, 0x61, 0x70, 0x60, 0x72, 0x63, 0x76, 0x64, 0x74, 0x64, 0x77, 0x65, 0x76, 0x64, 0x76, 0x65, 0x78, 0x66, 0x75, 0x64, 0x74, 0x65, 0x75, 0x65, 0x77, 0x65, 0x76, 0x66, 0x77, 0x65, 0x75, 0x66, 0x77, 0x67, 0x78, 0x67, 0x77, 0x68, 0x78, 0x67, 0x74, 0x64, 0x76, 0x65, 0x77, 0x68, 0x79, 0x65, 0x77, 0x66, 0x7A, 0x69, 0x79, 0x67, 0x77, 0x66, 0x79, 0x67, 0x78, 0x67, 0x79, 0x68, 0x79, 0x68, 0x7A, 0x6A, 0x7E, 0x7A, 0x8E, 0x83, 0x7E, 0x6D, 0x79, 0x67, 0x76, 0x68, 0x76, 0x68, 0x78, 0x67, 0x7A, 0x69, 0x7B, 0x68, 0x7D, 0x6D, 0x7A, 0x6B, 0x7D, 0x6C, 0x7F, 0x6C, 0x81, 0x6E, 0x7E, 0x6C, 0x7D, 0x6A, 0x78, 0x69, 0x7E, 0x6D, 0x82, 0x6F, 0x7F, 0x6D, 0x7C, 0x6B, 0x7D, 0x6D, 0x7B, 0x6A, 0x7C, 0x6C, 0x80, 0x6F, 0x80, 0x6F, 0x80, 0x6F, 0x81, 0x6E, 0x80, 0x6E, 0x82, 0x71, 0x82, 0x6C, 0x80, 0x70, 0x83, 0x70, 0x83, 0x71, 0x81, 0x72, 0x86, 0x73, 0x83, 0x70, 0x83, 0x73, 0x85, 0x76, 0x88, 0x7A, 0x88, 0x76, 0x88, 0x77, 0x8A, 0x7B, 0x8A, 0x7A, 0x86, 0x74, 0x85, 0x74, 0x82, 0x74, 0x83, 0x74, 0x88, 0x78, 0x86, 0x75, 0x86, 0x78, 0x86, 0x75, 0x86, 0x75, 0x83, 0x73, 0x82, 0x74, 0x85, 0x77, 0x85, 0x75, 0x84, 0x73, 0x84, 0x75, 0x87, 0x77, 0x86, 0x77, 0x8B, 0x78, 0x85, 0x75, 0x84, 0x75, 0x88, 0x79, 0x84, 0x79, 0x8C, 0x7F, 0x8D, 0x7B, 0x88, 0x76, 0x8B, 0x7A, 0x8C, 0x79, 0x89, 0x7D, 0x8E, 0x7A, 0x8B, 0x7B, 0x90, 0x81, 0x8F, 0x7E, 0x89, 0x78, 0x8B, 0x7B, 0x8D, 0x7D, 0x8F, 0x80, 0x8E, 0x80, 0x91, 0x82, 0x8C, 0x7C, 0x8C, 0x80, 0x90, 0x82, 0x8E, 0x81, 0x84, 0x77, 0x90, 0x82, 0x8C, 0x7C, 0x89, 0x79, 0x88, 0x7B, 0x82, 0x72, 0x6C, 0x5E, 0x4E, 0x4B, 0x48, 0x47, 0x3D, 0x3D, 0x3B, 0x40, 0x4D, 0x54, 0x70, 0x78, 0x8E, 0x90, 0x9D, 0xA2, 0xA8, 0xB3, 0xB3, 0xBC, 0xAA, 0xA5, 0x9B, 0x9C, 0x9F, 0xA2, 0x93, 0x8A, 0x8D, 0x87, 0x95, 0x97, 0xA2, 0xA1, 0x9E, 0x9E, 0x9F, 0xA2, 0x9F, 0xA0, 0x9D, 0x9A, 0x95, 0x94, 0x97, 0x96, 0x91, 0x83, 0x89, 0x80, 0x8C, 0x7D, 0x93, 0x94, 0x98, 0x9B, 0x97, 0x92, 0x9F, 0xA6, 0x99, 0x91, 0x91, 0x8F, 0x87, 0x7D, 0x8A, 0x88, 0x8D, 0x83, 0x85, 0x80, 0x80, 0x75, 0x7D, 0x71, 0x76, 0x6C, 0x77, 0x6B, 0x73, 0x66, 0x76, 0x6C, 0x79, 0x70, 0x7D, 0x71, 0x77, 0x6A, 0x76, 0x69, 0x7E, 0x74, 0x77, 0x6B, 0x79, 0x6C, 0x78, 0x6B, 0x75, 0x67, 0x73, 0x65, 0x77, 0x6D, 0x71, 0x65, 0x7D, 0x77, 0x7A, 0x6C, 0x7C, 0x71, 0x7A, 0x6F, 0x7B, 0x6C, 0x77, 0x6B, 0x81, 0x71, 0x7B, 0x71, 0x80, 0x71, 0x7E, 0x72, 0x7D, 0x70, 0x7C, 0x6F, 0x80, 0x6F, 0x7D, 0x6C, 0x7A, 0x6C, 0x78, 0x69, 0x70, 0x65, 0x74, 0x64, 0x72, 0x65, 0x75, 0x67, 0x74, 0x67, 0x75, 0x66, 0x73, 0x65, 0x78, 0x69, 0x77, 0x69, 0x75, 0x65, 0x7B, 0x6C, 0x75, 0x68, 0x76, 0x69, 0x7C, 0x6F, 0x78, 0x67, 0x70, 0x66, 0x76, 0x66, 0x79, 0x6B, 0x7D, 0x72, 0x80, 0x7B, 0x8E, 0x8B, 0x87, 0x7D, 0x7C, 0x6F, 0x7E, 0x72, 0x7E, 0x72, 0x85, 0x83, 0x89, 0x82, 0x83, 0x79, 0x87, 0x83, 0x80, 0x7E, 0x9D, 0xA3, 0x9C, 0x9C, 0x8F, 0x91, 0x9C, 0x9C, 0x98, 0x9A, 0x96, 0x95, 0x95, 0x8F, 0x9B, 0x9E, 0x92, 0x8E, 0x8B, 0x84, 0x94, 0x94, 0x8D, 0x88, 0x88, 0x86, 0x83, 0x79, 0x81, 0x7D, 0x7D, 0x72, 0x7D, 0x78, 0x88, 0x86, 0x84, 0x7C, 0x8D, 0x8C, 0x83, 0x7C, 0x81, 0x7C, 0x80, 0x76, 0x7A, 0x72, 0x77, 0x6D, 0x6E, 0x63, 0x69, 0x5D, 0x47, 0x4A, 0x3D, 0x43, 0x47, 0x4F, 0x46, 0x50, 0x3F, 0x44, 0x47, 0x53, 0x3E, 0x45, 0x41, 0x4A, 0x36, 0x3D, 0x44, 0x4C, 0x3B, 0x42, 0x3F, 0x44, 0x34, 0x3A, 0x3E, 0x4A, 0x3B, 0x3F, 0x3B, 0x45, 0x3D, 0x40, 0x34, 0x3A, 0x38, 0x3D, 0x39, 0x42, 0x3D, 0x43, 0x3C, 0x43, 0x3D, 0x44, 0x3A, 0x42, 0x43, 0x49, 0x39, 0x40, 0x3E, 0x45, 0x41, 0x46, 0x3E, 0x41, 0x3B, 0x3F, 0x3B, 0x3D, 0x3F, 0x43, 0x3D, 0x41, 0x34, 0x3D, 0x37, 0x3D, 0x3D, 0x43, 0x3A, 0x39, 0x3B, 0x3D, 0x3C, 0x3B, 0x3A, 0x39, 0x39, 0x38, 0x3A, 0x3A, 0x2E, 0x2F, 0x2A, 0x34, 0x3F, 0x48, 0x3B, 0x41, 0x3B, 0x3E, 0x32, 0x36, 0x2D, 0x31
    },

    {
        0x5E, 0x21, 0x5D, 0x20, 0x5E, 0x21, 0x60, 0x21, 0x5E, 0x21, 0x5F, 0x22, 0x61, 0x23, 0x59, 0x23, 0x4F, 0x23, 0x4C, 0x23, 0x4B, 0x24, 0x4A, 0x24, 0x49, 0x24, 0x49, 0x22, 0x4A, 0x20, 0x4E, 0x20, 0x5C, 0x22, 0x61, 0x23, 0x62, 0x23, 0x60, 0x22, 0x62, 0x23, 0x65, 0x23, 0x62, 0x23, 0x62, 0x22, 0x61, 0x21, 0x5F, 0x22, 0x62, 0x23, 0x60, 0x22, 0x5F, 0x23, 0x5F, 0x22, 0x62, 0x23, 0x63, 0x23, 0x63, 0x23, 0x66, 0x26, 0x62, 0x25, 0x62, 0x24, 0x62, 0x23, 0x64, 0x24, 0x66, 0x24, 0x63, 0x24, 0x65, 0x25, 0x65, 0x25, 0x67, 0x26, 0x65, 0x25, 0x63, 0x24, 0x63, 0x24, 0x62, 0x24, 0x66, 0x24, 0x64, 0x24, 0x63, 0x25, 0x66, 0x29, 0x95, 0x50, 0x8C, 0x36, 0x69, 0x27, 0x65, 0x26, 0x63, 0x24, 0x5E, 0x22, 0x61, 0x23, 0x66, 0x26, 0x67, 0x25, 0x68, 0x25, 0x66, 0x25, 0x67, 0x25, 0x69, 0x26, 0x6B, 0x28, 0x68, 0x26, 0x66, 0x25, 0x68, 0x26, 0x6B, 0x26, 0x6B, 0x26, 0x6B, 0x27, 0x6A, 0x26, 0x6A, 0x26, 0x68, 0x26, 0x6C, 0x28, 0x6B, 0x27, 0x6B, 0x28, 0x6D, 0x28, 0x6D, 0x27, 0x6B, 0x27, 0x6C, 0x27, 0x68, 0x26, 0x6C, 0x28, 0x70, 0x29, 0x6E, 0x28, 0x6C, 0x28, 0x6F, 0x29, 0x6C, 0x28, 0x6C, 0x28, 0x74, 0x2B, 0x74, 0x2C, 0x74, 0x2C, 0x75, 0x2D, 0x71, 0x2B, 0x75, 0x2B, 0x71, 0x2A, 0x70, 0x2A, 0x72, 0x2B, 0x73, 0x2A, 0x72, 0x29, 0x6D, 0x29, 0x6E, 0x2A, 0x74, 0x2C, 0x71, 0x2B, 0x71, 0x29, 0x6B, 0x28, 0x6F, 0x2A, 0x72, 0x2A, 0x76, 0x2F, 0x77, 0x2D, 0x75, 0x2C, 0x72, 0x2B, 0x74, 0x2B, 0x72, 0x2C, 0x75, 0x2C, 0x74, 0x2C, 0x75, 0x2C, 0x74, 0x2E, 0x7A, 0x31, 0x79, 0x2D, 0x75, 0x2C, 0x77, 0x2D, 0x76, 0x2E, 0x77, 0x2D, 0x78, 0x2D, 0x76, 0x2D, 0x7B, 0x2F, 0x76, 0x30, 0x75, 0x2D, 0x77, 0x2D, 0x7B, 0x30, 0x77, 0x30, 0x7D, 0x2E, 0x75, 0x2D, 0x7C, 0x32, 0x7F, 0x33, 0x7A, 0x2F, 0x77, 0x2F, 0x78, 0x30, 0x78, 0x30, 0x7A, 0x30, 0x7B, 0x30, 0x7A, 0x33, 0x6E, 0x2B, 0x55, 0x24, 0x45, 0x20, 0x47, 0x24, 0x4E, 0x29, 0x62, 0x32, 0x95, 0x4D, 0x94, 0x40, 0xA7, 0x53, 0xA1, 0x4B, 0x9B, 0x4A, 0xBB, 0x60, 0x8F, 0x3E, 0x8B, 0x43, 0x96, 0x44, 0x8C, 0x43, 0xB4, 0x58, 0xBB, 0x60, 0xAD, 0x55, 0x98, 0x48, 0x92, 0x41, 0x8F, 0x44, 0x98, 0x43, 0x98, 0x46, 0x94, 0x42, 0x8F, 0x41, 0x8B, 0x3A, 0x88, 0x45, 0x99, 0x46, 0x88, 0x3B, 0x7A, 0x35, 0x8C, 0x40, 0x7C, 0x39, 0x82, 0x38, 0x7A, 0x32, 0x7B, 0x38, 0x83, 0x3A, 0x79, 0x30, 0x6B, 0x2B, 0x6A, 0x2C, 0x68, 0x28, 0x6A, 0x2A, 0x6E, 0x2C, 0x6E, 0x2F, 0x70, 0x2D, 0x6A, 0x2A, 0x6A, 0x29, 0x6E, 0x2C, 0x71, 0x2D, 0x6C, 0x2A, 0x6A, 0x2A, 0x69, 0x29, 0x64, 0x27, 0x65, 0x2A, 0x6A, 0x28, 0x6A, 0x29, 0x6A, 0x28, 0x6B, 0x2A, 0x70, 0x2C, 0x6D, 0x2A, 0x67, 0x26, 0x67, 0x28, 0x6C, 0x2B, 0x6B, 0x29, 0x6E, 0x2A, 0x6E, 0x2A, 0x6A, 0x29, 0x6C, 0x2A, 0x67, 0x27, 0x67, 0x27, 0x63, 0x25, 0x67, 0x26, 0x5F, 0x23, 0x61, 0x24, 0x60, 0x23, 0x64, 0x25, 0x62, 0x25, 0x64, 0x26, 0x63, 0x25, 0x64, 0x26, 0x62, 0x25, 0x66, 0x26, 0x66, 0x26, 0x67, 0x28, 0x69, 0x27, 0x64, 0x26, 0x61, 0x25, 0x66, 0x28, 0x68, 0x28, 0x6E, 0x2D, 0x76, 0x34, 0x6F, 0x2D, 0x73, 0x2E, 0x71, 0x2C, 0x70, 0x2E, 0x76, 0x32, 0x80, 0x37, 0x7E, 0x36, 0x81, 0x39, 0x91, 0x45, 0x76, 0x31, 0x8B, 0x44, 0x95, 0x46, 0x81, 0x3B, 0x95, 0x4A, 0x92, 0x45, 0x8E, 0x46, 0x8F, 0x44, 0x9F, 0x50, 0x82, 0x39, 0x7F, 0x3A, 0x82, 0x3C, 0x85, 0x3E, 0x79, 0x34, 0x7D, 0x37, 0x6F, 0x2E, 0x6B, 0x2D, 0x6B, 0x2C, 0x6E, 0x31, 0x71, 0x32, 0x7B, 0x38, 0x77, 0x36, 0x77, 0x36, 0x79, 0x36, 0x6F, 0x2E, 0x6B, 0x2C, 0x68, 0x29, 0x5E, 0x27, 0x5B, 0x2B, 0x45, 0x23, 0x4C, 0x27, 0x47, 0x25, 0x41, 0x26, 0x47, 0x27, 0x3B, 0x22, 0x43, 0x25, 0x42, 0x26, 0x49, 0x26, 0x42, 0x25, 0x49, 0x28, 0x43, 0x24, 0x43, 0x25, 0x42, 0x22, 0x49, 0x29, 0x44, 0x26, 0x3E, 0x29, 0x42, 0x2A, 0x3D, 0x2C, 0x49, 0x33, 0x3C, 0x2E, 0x3B, 0x27, 0x41, 0x24, 0x47, 0x25, 0x33, 0x21, 0x37, 0x35, 0x38, 0x39, 0x37, 0x36, 0x36, 0x35, 0x36, 0x37, 0x36, 0x35, 0x36, 0x2B, 0x35, 0x21, 0x47, 0x26, 0x41, 0x27, 0x38, 0x31, 0x33, 0x30, 0x33, 0x2F, 0x2F, 0x2A, 0x2B, 0x25, 0x2A, 0x24, 0x27, 0x1D, 0x31, 0x1E, 0x3F, 0x21, 0x3A, 0x1E, 0x35, 0x1D, 0x26, 0x17, 0x28, 0x17
    },

    {
        0x6E, 0x5E, 0x6C, 0x5F, 0x6F, 0x61, 0x71, 0x61, 0x70, 0x62, 0x70, 0x63, 0x70, 0x63, 0x66, 0x58, 0x53, 0x4F, 0x4C, 0x4C, 0x4C, 0x4C, 0x4B, 0x4C, 0x4B, 0x4B, 0x4B, 0x4A, 0x4D, 0x48, 0x55, 0x4E, 0x6B, 0x60, 0x75, 0x64, 0x75, 0x65, 0x74, 0x64, 0x74, 0x65, 0x73, 0x65, 0x74, 0x65, 0x74, 0x63, 0x74, 0x63, 0x71, 0x61, 0x73, 0x63, 0x73, 0x64, 0x73, 0x62, 0x73, 0x62, 0x77, 0x65, 0x75, 0x64, 0x76, 0x65, 0x77, 0x67, 0x77, 0x66, 0x77, 0x66, 0x76, 0x64, 0x77, 0x67, 0x78, 0x68, 0x77, 0x66, 0x76, 0x67, 0x78, 0x68, 0x79, 0x69, 0x7A, 0x68, 0x78, 0x67, 0x7A, 0x67, 0x78, 0x66, 0x7A, 0x67, 0x78, 0x66, 0x79, 0x68, 0x79, 0x6E, 0xA1, 0xB2, 0x90, 0x7B, 0x78, 0x69, 0x78, 0x68, 0x77, 0x65, 0x71, 0x5F, 0x74, 0x65, 0x77, 0x69, 0x79, 0x68, 0x7B, 0x6B, 0x7B, 0x69, 0x7C, 0x6C, 0x7E, 0x6D, 0x80, 0x6E, 0x7D, 0x6D, 0x7B, 0x69, 0x7A, 0x6D, 0x7E, 0x6D, 0x7F, 0x6E, 0x7E, 0x6E, 0x7E, 0x6C, 0x7E, 0x6D, 0x7D, 0x6D, 0x80, 0x6F, 0x7F, 0x6E, 0x80, 0x6E, 0x7F, 0x71, 0x80, 0x6D, 0x7F, 0x6E, 0x83, 0x71, 0x7E, 0x6D, 0x83, 0x71, 0x84, 0x72, 0x86, 0x71, 0x82, 0x70, 0x84, 0x71, 0x80, 0x70, 0x82, 0x70, 0x88, 0x77, 0x86, 0x76, 0x86, 0x77, 0x89, 0x79, 0x88, 0x76, 0x87, 0x75, 0x84, 0x74, 0x85, 0x74, 0x86, 0x77, 0x88, 0x74, 0x88, 0x75, 0x83, 0x71, 0x83, 0x72, 0x88, 0x78, 0x83, 0x74, 0x81, 0x6F, 0x80, 0x71, 0x85, 0x75, 0x87, 0x76, 0x85, 0x78, 0x88, 0x7A, 0x86, 0x79, 0x85, 0x77, 0x89, 0x77, 0x85, 0x79, 0x89, 0x7A, 0x88, 0x78, 0x88, 0x76, 0x88, 0x7B, 0x8B, 0x7F, 0x8A, 0x7B, 0x89, 0x7C, 0x8D, 0x7D, 0x8D, 0x7C, 0x8A, 0x7A, 0x8D, 0x7B, 0x8A, 0x7A, 0x8F, 0x80, 0x8C, 0x7D, 0x88, 0x79, 0x8C, 0x7B, 0x8F, 0x7F, 0x91, 0x88, 0x91, 0x7C, 0x88, 0x7A, 0x8D, 0x7F, 0x90, 0x86, 0x8E, 0x7D, 0x8B, 0x7B, 0x8A, 0x7C, 0x87, 0x7C, 0x8D, 0x81, 0x8C, 0x7A, 0x89, 0x81, 0x7D, 0x6F, 0x66, 0x5A, 0x57, 0x4F, 0x55, 0x54, 0x5E, 0x5F, 0x73, 0x77, 0x96, 0x9E, 0x97, 0x8E, 0xA8, 0xAF, 0xA2, 0x9C, 0x97, 0x95, 0xB4, 0xBF, 0x93, 0x8A, 0x94, 0x97, 0xA1, 0x9F, 0x9B, 0x9E, 0xB3, 0xB9, 0xB3, 0xBD, 0xAC, 0xAE, 0x9F, 0x98, 0x95, 0x90, 0x93, 0x92, 0x9F, 0x9A, 0x9A, 0x9C, 0x98, 0x8F, 0x94, 0x92, 0x90, 0x87, 0x93, 0x98, 0x98, 0x94, 0x8D, 0x89, 0x84, 0x79, 0x8D, 0x89, 0x86, 0x7E, 0x86, 0x80, 0x84, 0x78, 0x83, 0x7F, 0x8C, 0x87, 0x85, 0x7B, 0x7A, 0x6C, 0x78, 0x6E, 0x78, 0x6B, 0x78, 0x6F, 0x7A, 0x6E, 0x78, 0x72, 0x7D, 0x74, 0x7A, 0x6F, 0x7A, 0x6D, 0x7B, 0x6D, 0x7D, 0x75, 0x7C, 0x70, 0x76, 0x6E, 0x7B, 0x6B, 0x76, 0x6A, 0x74, 0x6D, 0x7D, 0x6F, 0x78, 0x6D, 0x7A, 0x6C, 0x7B, 0x6E, 0x7F, 0x72, 0x81, 0x71, 0x77, 0x68, 0x7A, 0x6D, 0x7D, 0x70, 0x7E, 0x70, 0x81, 0x72, 0x80, 0x71, 0x80, 0x72, 0x7C, 0x6F, 0x77, 0x67, 0x77, 0x6A, 0x76, 0x67, 0x79, 0x6A, 0x73, 0x64, 0x71, 0x61, 0x72, 0x63, 0x75, 0x68, 0x73, 0x64, 0x75, 0x68, 0x75, 0x66, 0x76, 0x68, 0x73, 0x67, 0x75, 0x68, 0x75, 0x68, 0x79, 0x6E, 0x7B, 0x6D, 0x79, 0x6B, 0x74, 0x66, 0x78, 0x6C, 0x7C, 0x6D, 0x7D, 0x75, 0x85, 0x7F, 0x7D, 0x73, 0x81, 0x78, 0x83, 0x78, 0x7F, 0x75, 0x83, 0x81, 0x8C, 0x85, 0x8E, 0x88, 0x88, 0x83, 0x96, 0x9C, 0x85, 0x7A, 0x90, 0x95, 0x96, 0x95, 0x8B, 0x84, 0x96, 0x98, 0x92, 0x94, 0x93, 0x93, 0x98, 0x97, 0x9D, 0xA3, 0x8A, 0x83, 0x89, 0x85, 0x84, 0x7F, 0x8A, 0x8B, 0x84, 0x7C, 0x85, 0x7E, 0x7A, 0x71, 0x77, 0x71, 0x79, 0x6E, 0x79, 0x6F, 0x7B, 0x72, 0x7F, 0x7A, 0x7E, 0x78, 0x81, 0x7B, 0x81, 0x7B, 0x7B, 0x72, 0x78, 0x6F, 0x75, 0x6A, 0x69, 0x60, 0x57, 0x5A, 0x3D, 0x44, 0x46, 0x4F, 0x3E, 0x42, 0x3B, 0x44, 0x40, 0x46, 0x39, 0x41, 0x40, 0x48, 0x3F, 0x48, 0x43, 0x4B, 0x3E, 0x49, 0x45, 0x4C, 0x3D, 0x43, 0x3E, 0x4A, 0x3C, 0x41, 0x42, 0x4D, 0x3D, 0x42, 0x3A, 0x44, 0x3D, 0x3E, 0x3B, 0x42, 0x42, 0x46, 0x38, 0x3C, 0x35, 0x39, 0x3C, 0x47, 0x3B, 0x41, 0x32, 0x35, 0x38, 0x39, 0x38, 0x38, 0x39, 0x37, 0x38, 0x37, 0x38, 0x36, 0x38, 0x38, 0x31, 0x33, 0x30, 0x3C, 0x40, 0x4A, 0x3B, 0x3F, 0x37, 0x36, 0x30, 0x30, 0x2D, 0x30, 0x2A, 0x2B, 0x26, 0x28, 0x25, 0x27, 0x22, 0x25, 0x2E, 0x3B, 0x38, 0x3E, 0x36, 0x3D, 0x34, 0x37, 0x27, 0x2A, 0x29, 0x2F
    },

    {
        0x5D, 0x21, 0x5B, 0x20, 0x5E, 0x21, 0x61, 0x21, 0x60, 0x23, 0x64, 0x24, 0x61, 0x23, 0x58, 0x24, 0x4E, 0x23, 0x4C, 0x23, 0x4B, 0x24, 0x48, 0x23, 0x49, 0x24, 0x47, 0x22, 0x43, 0x1C, 0x41, 0x1D, 0x55, 0x21, 0x5F, 0x23, 0x60, 0x23, 0x64, 0x24, 0x65, 0x24, 0x60, 0x22, 0x5E, 0x22, 0x60, 0x22, 0x61, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x5F, 0x21, 0x5F, 0x23, 0x61, 0x23, 0x62, 0x23, 0x60, 0x23, 0x61, 0x23, 0x64, 0x24, 0x65, 0x23, 0x64, 0x24, 0x65, 0x24, 0x65, 0x25, 0x65, 0x25, 0x64, 0x24, 0x64, 0x24, 0x65, 0x25, 0x65, 0x25, 0x64, 0x24, 0x67, 0x25, 0x63, 0x24, 0x64, 0x24, 0x65, 0x25, 0x66, 0x29, 0x7C, 0x3E, 0x8E, 0x3D, 0x6A, 0x27, 0x64, 0x25, 0x64, 0x25, 0x5F, 0x23, 0x61, 0x23, 0x63, 0x23, 0x64, 0x24, 0x65, 0x26, 0x64, 0x24, 0x64, 0x25, 0x67, 0x25, 0x69, 0x27, 0x6E, 0x28, 0x6A, 0x26, 0x69, 0x26, 0x69, 0x26, 0x6B, 0x27, 0x6B, 0x26, 0x69, 0x25, 0x69, 0x26, 0x69, 0x27, 0x6A, 0x27, 0x67, 0x26, 0x66, 0x26, 0x69, 0x27, 0x68, 0x26, 0x69, 0x26, 0x6B, 0x27, 0x6D, 0x28, 0x6E, 0x28, 0x6E, 0x28, 0x70, 0x29, 0x6C, 0x28, 0x6C, 0x28, 0x6F, 0x28, 0x6C, 0x28, 0x6F, 0x29, 0x6C, 0x28, 0x6C, 0x29, 0x71, 0x2A, 0x72, 0x2B, 0x74, 0x2B, 0x70, 0x2A, 0x6F, 0x29, 0x73, 0x2A, 0x73, 0x2A, 0x72, 0x2C, 0x73, 0x2B, 0x70, 0x29, 0x76, 0x2C, 0x75, 0x2C, 0x73, 0x2C, 0x72, 0x2B, 0x71, 0x2B, 0x74, 0x2D, 0x75, 0x2C, 0x71, 0x2B, 0x73, 0x2B, 0x73, 0x2B, 0x73, 0x2B, 0x72, 0x2A, 0x73, 0x2B, 0x76, 0x2C, 0x75, 0x2C, 0x72, 0x2B, 0x76, 0x2D, 0x79, 0x2E, 0x7A, 0x2E, 0x79, 0x2E, 0x77, 0x2C, 0x74, 0x2D, 0x75, 0x2C, 0x79, 0x2D, 0x79, 0x2D, 0x7A, 0x32, 0x7E, 0x31, 0x77, 0x2E, 0x79, 0x30, 0x7E, 0x32, 0x7D, 0x34, 0x71, 0x2B, 0x75, 0x2C, 0x79, 0x2D, 0x79, 0x2F, 0x78, 0x2E, 0x7A, 0x2F, 0x78, 0x2E, 0x75, 0x2E, 0x75, 0x2E, 0x72, 0x2C, 0x78, 0x2D, 0x75, 0x2D, 0x6E, 0x2B, 0x74, 0x33, 0x6C, 0x2D, 0x73, 0x31, 0x8E, 0x41, 0x8B, 0x3C, 0x9C, 0x4F, 0xA7, 0x52, 0xAB, 0x4F, 0x87, 0x3F, 0x8D, 0x3C, 0x83, 0x3B, 0x94, 0x4B, 0x9E, 0x4E, 0xA8, 0x54, 0xAC, 0x56, 0xB6, 0x5A, 0xAC, 0x56, 0xA6, 0x52, 0xB1, 0x57, 0x8D, 0x3D, 0x8B, 0x42, 0x91, 0x42, 0x7D, 0x35, 0x80, 0x39, 0x89, 0x3D, 0x81, 0x38, 0x7B, 0x3B, 0x9B, 0x49, 0x81, 0x33, 0x74, 0x32, 0x7D, 0x34, 0x74, 0x31, 0x77, 0x32, 0x70, 0x2D, 0x7F, 0x39, 0x81, 0x37, 0x74, 0x2D, 0x6C, 0x2B, 0x6C, 0x2C, 0x6E, 0x2A, 0x64, 0x27, 0x64, 0x29, 0x7B, 0x3A, 0x78, 0x2F, 0x6C, 0x2C, 0x68, 0x27, 0x67, 0x29, 0x6B, 0x2B, 0x6D, 0x2D, 0x74, 0x31, 0x73, 0x2D, 0x67, 0x2A, 0x76, 0x2F, 0x6C, 0x2B, 0x68, 0x27, 0x65, 0x28, 0x66, 0x26, 0x68, 0x28, 0x66, 0x26, 0x6A, 0x29, 0x6A, 0x29, 0x6F, 0x2B, 0x70, 0x2B, 0x6A, 0x29, 0x6E, 0x2A, 0x69, 0x28, 0x68, 0x28, 0x68, 0x28, 0x69, 0x28, 0x69, 0x29, 0x64, 0x25, 0x60, 0x24, 0x60, 0x23, 0x63, 0x25, 0x65, 0x26, 0x66, 0x28, 0x63, 0x26, 0x62, 0x25, 0x65, 0x28, 0x66, 0x25, 0x68, 0x29, 0x72, 0x2F, 0x6C, 0x28, 0x65, 0x25, 0x63, 0x25, 0x65, 0x27, 0x6F, 0x2C, 0x70, 0x2E, 0x73, 0x2E, 0x70, 0x30, 0x79, 0x32, 0x75, 0x31, 0x74, 0x2F, 0x74, 0x35, 0x80, 0x36, 0x7A, 0x36, 0x7B, 0x36, 0x86, 0x3E, 0x77, 0x33, 0x85, 0x3D, 0x92, 0x45, 0x8A, 0x40, 0x8A, 0x3F, 0x87, 0x3F, 0x90, 0x49, 0x95, 0x46, 0x8C, 0x41, 0x8E, 0x44, 0x8F, 0x41, 0x81, 0x3C, 0x7F, 0x3A, 0x81, 0x3C, 0x78, 0x34, 0x79, 0x37, 0x73, 0x32, 0x76, 0x34, 0x70, 0x30, 0x6D, 0x2E, 0x74, 0x35, 0x71, 0x2F, 0x75, 0x34, 0x71, 0x31, 0x6B, 0x2C, 0x6A, 0x2C, 0x6E, 0x30, 0x5E, 0x27, 0x49, 0x25, 0x3E, 0x23, 0x50, 0x29, 0x48, 0x27, 0x4A, 0x28, 0x4C, 0x29, 0x46, 0x2A, 0x56, 0x32, 0x45, 0x2C, 0x47, 0x31, 0x3E, 0x30, 0x43, 0x34, 0x37, 0x23, 0x44, 0x25, 0x3D, 0x20, 0x43, 0x27, 0x3B, 0x3C, 0x39, 0x44, 0x3A, 0x46, 0x3B, 0x48, 0x3B, 0x47, 0x39, 0x42, 0x31, 0x2B, 0x39, 0x22, 0x43, 0x23, 0x38, 0x23, 0x37, 0x34, 0x31, 0x31, 0x2E, 0x2D, 0x2C, 0x28, 0x2A, 0x27, 0x2A, 0x25, 0x29, 0x1F, 0x31, 0x20, 0x3B, 0x21, 0x3F, 0x23, 0x3C, 0x21, 0x27, 0x18, 0x28, 0x19, 0x2A, 0x19, 0x2A, 0x19, 0x2E, 0x1A, 0x38, 0x20, 0x47, 0x27, 0x4A, 0x26, 0x43, 0x23, 0x3F, 0x21, 0x37, 0x1E, 0x3C, 0x1F
    },

    {
        0x6D, 0x60, 0x6D, 0x5F, 0x6E, 0x61, 0x72, 0x63, 0x73, 0x66, 0x73, 0x66, 0x70, 0x63, 0x63, 0x58, 0x51, 0x4E, 0x4C, 0x4B, 0x4B, 0x4C, 0x4A, 0x4B, 0x4B, 0x4C, 0x48, 0x49, 0x45, 0x40, 0x48, 0x43, 0x60, 0x58, 0x6E, 0x60, 0x74, 0x64, 0x78, 0x67, 0x76, 0x66, 0x72, 0x62, 0x71, 0x61, 0x72, 0x62, 0x75, 0x63, 0x71, 0x62, 0x70, 0x61, 0x71, 0x62, 0x74, 0x61, 0x74, 0x63, 0x74, 0x64, 0x72, 0x63, 0x72, 0x63, 0x75, 0x65, 0x76, 0x67, 0x79, 0x67, 0x77, 0x66, 0x78, 0x68, 0x75, 0x66, 0x78, 0x68, 0x77, 0x66, 0x77, 0x66, 0x78, 0x67, 0x76, 0x67, 0x77, 0x66, 0x7A, 0x69, 0x7A, 0x69, 0x7A, 0x68, 0x77, 0x68, 0x7B, 0x71, 0x8B, 0x8C, 0x8B, 0x7B, 0x7D, 0x6C, 0x75, 0x66, 0x74, 0x66, 0x75, 0x64, 0x78, 0x66, 0x78, 0x65, 0x74, 0x64, 0x79, 0x6A, 0x76, 0x67, 0x79, 0x69, 0x7A, 0x69, 0x7C, 0x6A, 0x7E, 0x6F, 0x7C, 0x6B, 0x7E, 0x6E, 0x7F, 0x6C, 0x7E, 0x6E, 0x7B, 0x6C, 0x7D, 0x6D, 0x7E, 0x6C, 0x7C, 0x6D, 0x7C, 0x6B, 0x79, 0x69, 0x7A, 0x6A, 0x7C, 0x6C, 0x7F, 0x6D, 0x80, 0x6F, 0x82, 0x6F, 0x7F, 0x70, 0x83, 0x72, 0x82, 0x70, 0x85, 0x74, 0x83, 0x71, 0x84, 0x71, 0x81, 0x72, 0x84, 0x73, 0x84, 0x70, 0x7F, 0x6E, 0x81, 0x6F, 0x83, 0x75, 0x85, 0x77, 0x84, 0x75, 0x86, 0x75, 0x85, 0x74, 0x89, 0x78, 0x88, 0x75, 0x84, 0x76, 0x84, 0x74, 0x82, 0x74, 0x87, 0x78, 0x87, 0x79, 0x84, 0x77, 0x86, 0x75, 0x82, 0x74, 0x84, 0x75, 0x86, 0x77, 0x84, 0x76, 0x86, 0x75, 0x8B, 0x78, 0x86, 0x76, 0x84, 0x75, 0x87, 0x78, 0x8B, 0x78, 0x88, 0x77, 0x86, 0x77, 0x8A, 0x79, 0x8C, 0x7C, 0x8D, 0x7C, 0x8B, 0x7C, 0x86, 0x78, 0x86, 0x77, 0x87, 0x78, 0x8B, 0x7C, 0x8D, 0x7E, 0x8C, 0x80, 0x8D, 0x7F, 0x8D, 0x7C, 0x8E, 0x7F, 0x91, 0x81, 0x88, 0x77, 0x86, 0x75, 0x88, 0x78, 0x8A, 0x7A, 0x8C, 0x7D, 0x88, 0x7B, 0x8B, 0x7E, 0x89, 0x79, 0x87, 0x7A, 0x8A, 0x7A, 0x86, 0x77, 0x8A, 0x7A, 0x8B, 0x7B, 0x81, 0x76, 0x83, 0x7D, 0x80, 0x73, 0x87, 0x81, 0x9E, 0x9B, 0x99, 0x8E, 0xA4, 0xAD, 0xA2, 0xA8, 0xA9, 0xA8, 0x98, 0x95, 0x93, 0x8B, 0x8C, 0x89, 0x96, 0x95, 0x9C, 0x9B, 0x9F, 0xA7, 0xAC, 0xB1, 0xAF, 0xB2, 0xB1, 0xB4, 0xA9, 0xAC, 0xB1, 0xBC, 0x93, 0x85, 0x96, 0x96, 0x91, 0x8B, 0x8B, 0x81, 0x8E, 0x8D, 0x98, 0x91, 0x8B, 0x85, 0x81, 0x7E, 0x9C, 0xA1, 0x86, 0x7A, 0x80, 0x7A, 0x8A, 0x7D, 0x82, 0x78, 0x84, 0x7D, 0x7C, 0x71, 0x88, 0x82, 0x83, 0x7E, 0x83, 0x76, 0x79, 0x71, 0x79, 0x72, 0x7D, 0x71, 0x70, 0x64, 0x74, 0x6A, 0x81, 0x82, 0x85, 0x79, 0x78, 0x6B, 0x7C, 0x6A, 0x79, 0x6C, 0x7C, 0x71, 0x7C, 0x72, 0x81, 0x79, 0x7F, 0x74, 0x77, 0x6E, 0x83, 0x78, 0x7A, 0x70, 0x79, 0x6D, 0x77, 0x6A, 0x79, 0x69, 0x78, 0x6B, 0x79, 0x6B, 0x7B, 0x6F, 0x7C, 0x6E, 0x84, 0x73, 0x83, 0x73, 0x7C, 0x6E, 0x7E, 0x71, 0x78, 0x6C, 0x7A, 0x6D, 0x7A, 0x6D, 0x7C, 0x6F, 0x79, 0x6C, 0x76, 0x66, 0x73, 0x62, 0x73, 0x66, 0x74, 0x67, 0x77, 0x69, 0x76, 0x69, 0x71, 0x66, 0x73, 0x66, 0x77, 0x6C, 0x78, 0x69, 0x7B, 0x6E, 0x7F, 0x77, 0x7A, 0x6E, 0x76, 0x67, 0x78, 0x68, 0x76, 0x6B, 0x81, 0x74, 0x7F, 0x78, 0x83, 0x74, 0x7C, 0x77, 0x84, 0x7B, 0x83, 0x79, 0x82, 0x77, 0x80, 0x7C, 0x88, 0x80, 0x84, 0x7D, 0x82, 0x7E, 0x8A, 0x85, 0x82, 0x79, 0x8A, 0x85, 0x96, 0x96, 0x93, 0x8D, 0x8D, 0x87, 0x8A, 0x88, 0x90, 0x92, 0x93, 0x8F, 0x8E, 0x8F, 0x92, 0x95, 0x91, 0x8F, 0x89, 0x85, 0x84, 0x80, 0x89, 0x85, 0x83, 0x7E, 0x85, 0x80, 0x7F, 0x77, 0x84, 0x7E, 0x80, 0x76, 0x7B, 0x70, 0x7F, 0x79, 0x7F, 0x75, 0x7F, 0x77, 0x7D, 0x73, 0x78, 0x6F, 0x79, 0x6E, 0x78, 0x71, 0x68, 0x5D, 0x46, 0x49, 0x3C, 0x43, 0x48, 0x51, 0x48, 0x50, 0x41, 0x4A, 0x45, 0x4C, 0x41, 0x4C, 0x4D, 0x54, 0x3C, 0x42, 0x3E, 0x42, 0x39, 0x40, 0x3C, 0x3E, 0x33, 0x38, 0x3D, 0x48, 0x37, 0x3E, 0x3E, 0x44, 0x3A, 0x3A, 0x37, 0x39, 0x37, 0x39, 0x3A, 0x3B, 0x39, 0x3B, 0x37, 0x38, 0x2B, 0x2D, 0x33, 0x40, 0x3E, 0x43, 0x36, 0x3B, 0x36, 0x35, 0x2D, 0x2D, 0x2A, 0x2B, 0x28, 0x28, 0x26, 0x28, 0x24, 0x29, 0x24, 0x27, 0x2E, 0x38, 0x37, 0x3D, 0x3D, 0x46, 0x3A, 0x3E, 0x26, 0x29, 0x28, 0x2D, 0x2B, 0x30, 0x2B, 0x32, 0x31, 0x39, 0x3A, 0x43, 0x40, 0x4B, 0x40, 0x4A, 0x3C, 0x45, 0x37, 0x3B, 0x34, 0x3E, 0x34, 0x3A
    },

    {
        0x5F, 0x23, 0x5E, 0x21, 0x60, 0x21, 0x61, 0x22, 0x63, 0x23, 0x62, 0x23, 0x5F, 0x23, 0x57, 0x23, 0x4D, 0x23, 0x4B, 0x23, 0x4A, 0x23, 0x49, 0x24, 0x48, 0x23, 0x44, 0x20, 0x3B, 0x1A, 0x3C, 0x1B, 0x4F, 0x1F, 0x5C, 0x22, 0x60, 0x24, 0x62, 0x24, 0x62, 0x23, 0x5F, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x61, 0x22, 0x60, 0x22, 0x60, 0x23, 0x62, 0x22, 0x63, 0x23, 0x61, 0x23, 0x5F, 0x23, 0x62, 0x23, 0x61, 0x23, 0x62, 0x24, 0x61, 0x24, 0x60, 0x23, 0x62, 0x24, 0x63, 0x24, 0x64, 0x24, 0x65, 0x24, 0x5F, 0x23, 0x63, 0x26, 0x67, 0x27, 0x64, 0x25, 0x64, 0x25, 0x66, 0x24, 0x65, 0x25, 0x66, 0x26, 0x6A, 0x29, 0x71, 0x2F, 0x6F, 0x2C, 0x67, 0x27, 0x66, 0x26, 0x65, 0x25, 0x61, 0x24, 0x63, 0x25, 0x62, 0x24, 0x61, 0x24, 0x5F, 0x24, 0x62, 0x25, 0x66, 0x24, 0x66, 0x25, 0x65, 0x25, 0x61, 0x24, 0x66, 0x24, 0x62, 0x24, 0x67, 0x25, 0x68, 0x26, 0x6B, 0x27, 0x69, 0x26, 0x6A, 0x27, 0x68, 0x26, 0x65, 0x26, 0x6A, 0x26, 0x68, 0x26, 0x69, 0x27, 0x67, 0x28, 0x6A, 0x28, 0x6C, 0x27, 0x6A, 0x27, 0x6D, 0x29, 0x6E, 0x28, 0x6F, 0x29, 0x6E, 0x29, 0x6F, 0x29, 0x6F, 0x28, 0x6C, 0x28, 0x6F, 0x29, 0x6F, 0x2A, 0x6E, 0x29, 0x6C, 0x29, 0x71, 0x2B, 0x75, 0x2C, 0x71, 0x2B, 0x72, 0x2A, 0x72, 0x2A, 0x72, 0x2A, 0x6D, 0x28, 0x6E, 0x2A, 0x72, 0x2B, 0x70, 0x2B, 0x71, 0x2B, 0x73, 0x2C, 0x75, 0x2C, 0x70, 0x2A, 0x6F, 0x2A, 0x74, 0x2B, 0x74, 0x2C, 0x72, 0x2C, 0x76, 0x2D, 0x76, 0x2C, 0x72, 0x2C, 0x70, 0x29, 0x72, 0x2A, 0x75, 0x2C, 0x72, 0x2B, 0x71, 0x2A, 0x78, 0x2D, 0x77, 0x2D, 0x71, 0x2C, 0x77, 0x2C, 0x75, 0x2D, 0x71, 0x2B, 0x72, 0x2D, 0x77, 0x2E, 0x7D, 0x2F, 0x77, 0x2D, 0x7D, 0x33, 0x7A, 0x2F, 0x78, 0x2E, 0x7A, 0x2F, 0x75, 0x2D, 0x77, 0x2E, 0x77, 0x2E, 0x76, 0x2D, 0x73, 0x2D, 0x74, 0x2C, 0x76, 0x2D, 0x77, 0x2E, 0x71, 0x2C, 0x74, 0x2D, 0x74, 0x2B, 0x73, 0x2C, 0x77, 0x2F, 0x7E, 0x33, 0x7A, 0x30, 0x78, 0x31, 0x92, 0x47, 0xA5, 0x4D, 0xA0, 0x4C, 0xA8, 0x50, 0xBC, 0x62, 0xB7, 0x5D, 0xBC, 0x59, 0x92, 0x43, 0x89, 0x3E, 0x88, 0x3F, 0x99, 0x48, 0xA7, 0x57, 0xB8, 0x5B, 0xAB, 0x50, 0x9B, 0x4B, 0x95, 0x44, 0x9F, 0x51, 0xA4, 0x4D, 0x9F, 0x4E, 0x8F, 0x45, 0x93, 0x43, 0x84, 0x3E, 0x7F, 0x38, 0x77, 0x37, 0x6F, 0x2D, 0x80, 0x3A, 0x83, 0x37, 0x74, 0x31, 0x7E, 0x37, 0x6F, 0x2D, 0x74, 0x2F, 0x6E, 0x2C, 0x69, 0x2A, 0x76, 0x35, 0x7F, 0x34, 0x73, 0x32, 0x75, 0x30, 0x77, 0x2F, 0x6C, 0x2A, 0x6A, 0x2B, 0x72, 0x30, 0x71, 0x2E, 0x6E, 0x2D, 0x6D, 0x2A, 0x6E, 0x2B, 0x67, 0x28, 0x6D, 0x2C, 0x6E, 0x2D, 0x70, 0x2C, 0x64, 0x27, 0x6A, 0x2B, 0x6D, 0x2C, 0x70, 0x2B, 0x6B, 0x28, 0x65, 0x27, 0x64, 0x26, 0x68, 0x29, 0x6D, 0x2B, 0x6B, 0x2A, 0x6B, 0x29, 0x6C, 0x2B, 0x6A, 0x27, 0x65, 0x27, 0x68, 0x28, 0x6D, 0x2C, 0x6C, 0x29, 0x68, 0x29, 0x67, 0x28, 0x64, 0x26, 0x64, 0x24, 0x63, 0x24, 0x65, 0x25, 0x65, 0x26, 0x64, 0x26, 0x67, 0x27, 0x67, 0x29, 0x69, 0x2A, 0x67, 0x27, 0x69, 0x29, 0x69, 0x28, 0x67, 0x28, 0x66, 0x26, 0x66, 0x26, 0x6A, 0x29, 0x6B, 0x29, 0x6C, 0x2C, 0x73, 0x2F, 0x68, 0x2A, 0x75, 0x32, 0x74, 0x31, 0x76, 0x30, 0x74, 0x34, 0x80, 0x3A, 0x70, 0x2F, 0x6F, 0x30, 0x7C, 0x35, 0x75, 0x31, 0x7B, 0x37, 0x87, 0x3D, 0x83, 0x3B, 0x7D, 0x39, 0x85, 0x3E, 0x7D, 0x3B, 0x88, 0x40, 0x88, 0x41, 0x85, 0x3D, 0x80, 0x39, 0x7A, 0x36, 0x77, 0x35, 0x7B, 0x36, 0x75, 0x35, 0x7A, 0x3A, 0x74, 0x34, 0x80, 0x3C, 0x7E, 0x37, 0x72, 0x30, 0x7A, 0x38, 0x73, 0x31, 0x6E, 0x2D, 0x75, 0x33, 0x6F, 0x2F, 0x71, 0x32, 0x72, 0x2F, 0x5C, 0x26, 0x54, 0x2B, 0x47, 0x26, 0x5A, 0x2E, 0x4E, 0x29, 0x3B, 0x22, 0x45, 0x2C, 0x3C, 0x45, 0x3F, 0x49, 0x3C, 0x4A, 0x3C, 0x4B, 0x3B, 0x4A, 0x39, 0x47, 0x30, 0x28, 0x41, 0x24, 0x47, 0x25, 0x44, 0x28, 0x38, 0x3A, 0x33, 0x3A, 0x30, 0x36, 0x30, 0x34, 0x2E, 0x2E, 0x2A, 0x2A, 0x23, 0x1C, 0x34, 0x20, 0x36, 0x1E, 0x3A, 0x20, 0x33, 0x1C, 0x24, 0x17, 0x2B, 0x19, 0x29, 0x19, 0x2D, 0x1B, 0x35, 0x1D, 0x37, 0x1F, 0x40, 0x25, 0x46, 0x26, 0x4E, 0x2A, 0x47, 0x25, 0x38, 0x1E, 0x3D, 0x22, 0x44, 0x24, 0x42, 0x23, 0x47, 0x26, 0x47, 0x25, 0x3F, 0x23, 0x41, 0x23, 0x3C, 0x20, 0x34, 0x1D, 0x3C, 0x21, 0x3A, 0x1E
    },

    {
        0x70, 0x62, 0x6E, 0x62, 0x71, 0x62, 0x71, 0x63, 0x75, 0x65, 0x72, 0x63, 0x70, 0x60, 0x63, 0x58, 0x54, 0x50, 0x4D, 0x4C, 0x4B, 0x49, 0x4A, 0x48, 0x49, 0x48, 0x44, 0x44, 0x3D, 0x38, 0x40, 0x3E, 0x5A, 0x52, 0x6D, 0x5E, 0x71, 0x62, 0x75, 0x66, 0x73, 0x63, 0x72, 0x64, 0x72, 0x61, 0x72, 0x62, 0x76, 0x64, 0x74, 0x62, 0x75, 0x63, 0x76, 0x64, 0x77, 0x65, 0x75, 0x64, 0x75, 0x63, 0x76, 0x65, 0x73, 0x64, 0x74, 0x64, 0x72, 0x63, 0x74, 0x62, 0x75, 0x64, 0x74, 0x65, 0x74, 0x65, 0x75, 0x63, 0x72, 0x60, 0x76, 0x68, 0x77, 0x6A, 0x79, 0x66, 0x79, 0x66, 0x7A, 0x68, 0x79, 0x69, 0x7C, 0x6B, 0x7C, 0x6C, 0x7D, 0x6F, 0x7C, 0x6A, 0x79, 0x68, 0x78, 0x68, 0x78, 0x66, 0x73, 0x63, 0x78, 0x68, 0x76, 0x65, 0x75, 0x64, 0x71, 0x62, 0x72, 0x65, 0x7A, 0x68, 0x79, 0x68, 0x78, 0x67, 0x77, 0x65, 0x77, 0x66, 0x77, 0x66, 0x7C, 0x6A, 0x7B, 0x6C, 0x81, 0x6E, 0x7C, 0x6B, 0x7C, 0x6B, 0x7B, 0x6A, 0x79, 0x6A, 0x7D, 0x6C, 0x7B, 0x6C, 0x7D, 0x6A, 0x7C, 0x6C, 0x7F, 0x6F, 0x82, 0x70, 0x7F, 0x6C, 0x82, 0x70, 0x82, 0x70, 0x84, 0x72, 0x82, 0x70, 0x82, 0x71, 0x84, 0x71, 0x7F, 0x70, 0x85, 0x71, 0x84, 0x76, 0x82, 0x71, 0x82, 0x71, 0x86, 0x76, 0x89, 0x7A, 0x88, 0x78, 0x84, 0x75, 0x87, 0x75, 0x86, 0x76, 0x82, 0x70, 0x84, 0x75, 0x88, 0x77, 0x82, 0x72, 0x84, 0x74, 0x87, 0x76, 0x88, 0x75, 0x85, 0x73, 0x81, 0x73, 0x85, 0x77, 0x87, 0x79, 0x85, 0x75, 0x8A, 0x79, 0x88, 0x75, 0x84, 0x75, 0x84, 0x75, 0x8A, 0x78, 0x8C, 0x78, 0x88, 0x78, 0x87, 0x76, 0x8E, 0x7B, 0x8B, 0x7B, 0x84, 0x74, 0x89, 0x7A, 0x87, 0x79, 0x86, 0x75, 0x86, 0x78, 0x86, 0x7B, 0x91, 0x82, 0x8C, 0x7B, 0x91, 0x87, 0x8D, 0x7C, 0x89, 0x7A, 0x8F, 0x80, 0x8D, 0x7B, 0x87, 0x79, 0x8B, 0x7D, 0x8C, 0x7B, 0x88, 0x78, 0x88, 0x7A, 0x8A, 0x78, 0x8A, 0x7C, 0x85, 0x75, 0x88, 0x7A, 0x88, 0x77, 0x85, 0x77, 0x89, 0x7D, 0x90, 0x84, 0x8D, 0x7D, 0x8B, 0x80, 0x9A, 0x9E, 0xAB, 0xAC, 0xAA, 0xAC, 0xAC, 0xAC, 0xBB, 0xCA, 0xB7, 0xC2, 0xB6, 0xB5, 0x95, 0x8E, 0x8D, 0x8B, 0x91, 0x90, 0x9D, 0xA0, 0xA8, 0xB2, 0xB3, 0xB6, 0xAB, 0xA8, 0x9C, 0x99, 0x9B, 0x97, 0x9D, 0xA0, 0xAB, 0xAC, 0x9D, 0x9F, 0x96, 0x98, 0x98, 0x91, 0x87, 0x89, 0x80, 0x78, 0x7C, 0x7A, 0x7E, 0x73, 0x83, 0x7B, 0x8A, 0x84, 0x83, 0x77, 0x86, 0x7F, 0x7B, 0x72, 0x83, 0x75, 0x80, 0x72, 0x7C, 0x71, 0x82, 0x7E, 0x89, 0x7D, 0x7E, 0x7B, 0x86, 0x7B, 0x83, 0x7A, 0x7A, 0x70, 0x79, 0x71, 0x7C, 0x73, 0x7B, 0x72, 0x7F, 0x73, 0x7E, 0x70, 0x80, 0x71, 0x7B, 0x6D, 0x7B, 0x6D, 0x7B, 0x73, 0x7F, 0x71, 0x78, 0x69, 0x76, 0x6D, 0x7B, 0x72, 0x81, 0x74, 0x81, 0x70, 0x7A, 0x6B, 0x76, 0x66, 0x7B, 0x70, 0x7E, 0x71, 0x7A, 0x6E, 0x7E, 0x6E, 0x7C, 0x6F, 0x7D, 0x6E, 0x79, 0x6B, 0x79, 0x6C, 0x7E, 0x72, 0x7D, 0x6F, 0x7A, 0x6D, 0x79, 0x6A, 0x74, 0x67, 0x75, 0x65, 0x77, 0x69, 0x78, 0x69, 0x77, 0x68, 0x77, 0x68, 0x79, 0x6C, 0x78, 0x6C, 0x79, 0x6E, 0x78, 0x6B, 0x79, 0x6B, 0x7B, 0x6F, 0x76, 0x6B, 0x77, 0x6A, 0x78, 0x6A, 0x7D, 0x70, 0x7E, 0x6F, 0x78, 0x6E, 0x7F, 0x73, 0x79, 0x6E, 0x7E, 0x76, 0x81, 0x77, 0x81, 0x75, 0x7E, 0x7C, 0x87, 0x82, 0x7D, 0x71, 0x7E, 0x77, 0x83, 0x7C, 0x81, 0x7D, 0x87, 0x83, 0x8F, 0x8B, 0x89, 0x85, 0x85, 0x7F, 0x8B, 0x87, 0x88, 0x84, 0x8D, 0x8B, 0x8B, 0x89, 0x8A, 0x87, 0x86, 0x7D, 0x7F, 0x7B, 0x81, 0x7A, 0x8B, 0x83, 0x80, 0x78, 0x82, 0x7E, 0x7E, 0x7A, 0x87, 0x86, 0x87, 0x82, 0x7F, 0x77, 0x83, 0x7F, 0x80, 0x75, 0x7E, 0x72, 0x85, 0x7C, 0x7F, 0x73, 0x7A, 0x77, 0x7B, 0x71, 0x67, 0x5D, 0x4F, 0x54, 0x43, 0x4C, 0x50, 0x5A, 0x41, 0x46, 0x34, 0x3D, 0x3D, 0x43, 0x3B, 0x3E, 0x3A, 0x3C, 0x38, 0x3C, 0x38, 0x3C, 0x36, 0x3B, 0x33, 0x37, 0x27, 0x2D, 0x3C, 0x49, 0x3F, 0x47, 0x3F, 0x44, 0x36, 0x37, 0x2E, 0x30, 0x2C, 0x2E, 0x2A, 0x2D, 0x27, 0x2B, 0x25, 0x28, 0x20, 0x21, 0x30, 0x3A, 0x32, 0x37, 0x36, 0x3E, 0x31, 0x33, 0x27, 0x2B, 0x2E, 0x32, 0x2C, 0x32, 0x2D, 0x34, 0x35, 0x3D, 0x37, 0x3E, 0x3A, 0x46, 0x40, 0x49, 0x47, 0x52, 0x3F, 0x45, 0x34, 0x38, 0x3A, 0x44, 0x3E, 0x45, 0x3C, 0x44, 0x3E, 0x46, 0x3D, 0x43, 0x37, 0x40, 0x39, 0x3F, 0x35, 0x3C, 0x32, 0x37, 0x38, 0x41, 0x38, 0x3F
    },

    {
        0x60, 0x23, 0x5F, 0x22, 0x60, 0x22, 0x61, 0x23, 0x63, 0x22, 0x63, 0x23, 0x60, 0x22, 0x58, 0x22, 0x4F, 0x21, 0x49, 0x22, 0x49, 0x22, 0x47, 0x22, 0x47, 0x20, 0x3C, 0x1A, 0x30, 0x16, 0x3B, 0x1A, 0x50, 0x1F, 0x5C, 0x22, 0x60, 0x23, 0x65, 0x25, 0x63, 0x24, 0x65, 0x24, 0x63, 0x24, 0x62, 0x23, 0x61, 0x23, 0x61, 0x24, 0x63, 0x24, 0x63, 0x23, 0x62, 0x23, 0x62, 0x23, 0x62, 0x24, 0x62, 0x24, 0x61, 0x24, 0x63, 0x23, 0x5F, 0x23, 0x5F, 0x22, 0x5F, 0x23, 0x5F, 0x23, 0x61, 0x24, 0x62, 0x25, 0x62, 0x24, 0x68, 0x2B, 0x6E, 0x2C, 0x66, 0x25, 0x66, 0x25, 0x62, 0x24, 0x65, 0x25, 0x66, 0x25, 0x67, 0x26, 0x67, 0x26, 0x64, 0x24, 0x64, 0x25, 0x64, 0x25, 0x63, 0x24, 0x63, 0x24, 0x64, 0x24, 0x64, 0x24, 0x63, 0x23, 0x64, 0x24, 0x63, 0x24, 0x65, 0x24, 0x63, 0x24, 0x63, 0x24, 0x63, 0x23, 0x62, 0x24, 0x67, 0x25, 0x66, 0x25, 0x66, 0x25, 0x68, 0x26, 0x67, 0x26, 0x6A, 0x27, 0x69, 0x26, 0x6A, 0x26, 0x68, 0x26, 0x6A, 0x28, 0x6B, 0x28, 0x6C, 0x28, 0x6B, 0x27, 0x6A, 0x27, 0x69, 0x27, 0x69, 0x27, 0x6A, 0x27, 0x6C, 0x28, 0x6B, 0x28, 0x6D, 0x28, 0x6E, 0x28, 0x6C, 0x29, 0x6B, 0x28, 0x71, 0x2A, 0x71, 0x2B, 0x6E, 0x2A, 0x70, 0x2A, 0x72, 0x2B, 0x74, 0x2B, 0x6D, 0x28, 0x71, 0x29, 0x6E, 0x2A, 0x6B, 0x27, 0x70, 0x2D, 0x73, 0x2B, 0x6C, 0x28, 0x6C, 0x29, 0x6E, 0x29, 0x6F, 0x29, 0x6E, 0x29, 0x6F, 0x2A, 0x72, 0x2B, 0x72, 0x2C, 0x72, 0x2B, 0x6F, 0x2B, 0x72, 0x2C, 0x75, 0x2D, 0x75, 0x2C, 0x71, 0x2A, 0x74, 0x2C, 0x77, 0x2D, 0x72, 0x2A, 0x75, 0x2D, 0x77, 0x2D, 0x73, 0x2C, 0x70, 0x2C, 0x6D, 0x2B, 0x70, 0x2C, 0x73, 0x2B, 0x73, 0x2C, 0x78, 0x2F, 0x78, 0x2D, 0x7B, 0x31, 0x7B, 0x2F, 0x7D, 0x31, 0x7C, 0x2F, 0x79, 0x2E, 0x76, 0x2C, 0x75, 0x2C, 0x75, 0x2D, 0x74, 0x2D, 0x76, 0x2D, 0x76, 0x2C, 0x77, 0x2D, 0x74, 0x2E, 0x79, 0x2F, 0x73, 0x2B, 0x75, 0x2C, 0x77, 0x2E, 0x86, 0x39, 0x81, 0x36, 0x83, 0x3A, 0xA4, 0x51, 0xB7, 0x59, 0xAC, 0x55, 0xB2, 0x5C, 0xD1, 0x6F, 0xC0, 0x5D, 0xAF, 0x50, 0x93, 0x45, 0xA6, 0x51, 0x9F, 0x4A, 0x9E, 0x4D, 0x9E, 0x4B, 0xAC, 0x57, 0xA8, 0x50, 0xA7, 0x54, 0xA5, 0x4D, 0x8D, 0x3E, 0x8D, 0x40, 0x7F, 0x3A, 0x8D, 0x4C, 0xA2, 0x57, 0x8C, 0x52, 0x84, 0x46, 0x5A, 0x31, 0x93, 0x49, 0x7A, 0x35, 0x78, 0x33, 0x72, 0x2E, 0x71, 0x30, 0x6B, 0x2C, 0x7B, 0x33, 0x77, 0x30, 0x78, 0x33, 0x75, 0x34, 0x7F, 0x34, 0x6B, 0x2B, 0x70, 0x2F, 0x74, 0x32, 0x6A, 0x2B, 0x78, 0x31, 0x6A, 0x2B, 0x6B, 0x2B, 0x6D, 0x2B, 0x71, 0x2E, 0x72, 0x30, 0x69, 0x28, 0x6A, 0x29, 0x6B, 0x2A, 0x69, 0x28, 0x65, 0x27, 0x68, 0x29, 0x67, 0x27, 0x6A, 0x2A, 0x69, 0x27, 0x68, 0x28, 0x68, 0x27, 0x6D, 0x2B, 0x6E, 0x2A, 0x67, 0x27, 0x68, 0x27, 0x6B, 0x29, 0x6C, 0x28, 0x65, 0x26, 0x6A, 0x29, 0x68, 0x29, 0x6D, 0x29, 0x66, 0x27, 0x60, 0x26, 0x61, 0x25, 0x60, 0x24, 0x65, 0x25, 0x67, 0x27, 0x66, 0x27, 0x64, 0x26, 0x6A, 0x29, 0x67, 0x28, 0x63, 0x28, 0x65, 0x26, 0x69, 0x29, 0x6B, 0x2A, 0x67, 0x28, 0x69, 0x29, 0x69, 0x29, 0x6B, 0x2B, 0x6A, 0x28, 0x68, 0x29, 0x6C, 0x2B, 0x69, 0x2A, 0x6D, 0x2E, 0x73, 0x2F, 0x6B, 0x2C, 0x76, 0x33, 0x79, 0x37, 0x71, 0x2E, 0x6E, 0x2D, 0x6E, 0x2F, 0x77, 0x36, 0x75, 0x34, 0x87, 0x3D, 0x7C, 0x38, 0x7A, 0x35, 0x82, 0x3D, 0x83, 0x3D, 0x84, 0x3A, 0x73, 0x32, 0x7B, 0x38, 0x75, 0x34, 0x74, 0x32, 0x71, 0x33, 0x92, 0x48, 0x7C, 0x37, 0x7C, 0x3B, 0x7D, 0x38, 0x79, 0x37, 0x7C, 0x36, 0x70, 0x31, 0x71, 0x32, 0x73, 0x33, 0x72, 0x32, 0x78, 0x35, 0x79, 0x37, 0x78, 0x34, 0x66, 0x29, 0x5E, 0x29, 0x4F, 0x28, 0x47, 0x27, 0x4F, 0x2A, 0x44, 0x24, 0x40, 0x24, 0x48, 0x2F, 0x3E, 0x43, 0x35, 0x3B, 0x31, 0x37, 0x2E, 0x32, 0x2E, 0x2F, 0x2A, 0x2A, 0x23, 0x1B, 0x39, 0x21, 0x37, 0x1F, 0x3A, 0x20, 0x35, 0x1F, 0x2A, 0x1B, 0x2F, 0x1D, 0x32, 0x1D, 0x38, 0x20, 0x33, 0x1C, 0x35, 0x1D, 0x42, 0x24, 0x47, 0x25, 0x44, 0x23, 0x40, 0x23, 0x43, 0x24, 0x42, 0x23, 0x44, 0x25, 0x3F, 0x22, 0x46, 0x26, 0x3E, 0x21, 0x3E, 0x22, 0x3E, 0x21, 0x49, 0x27, 0x3E, 0x23, 0x3B, 0x20, 0x40, 0x22, 0x3A, 0x1F, 0x3A, 0x20, 0x39, 0x1F, 0x39, 0x1F, 0x38, 0x20, 0x3E, 0x20, 0x42, 0x22, 0x45, 0x23, 0x48, 0x25, 0x47, 0x24
    },

    {
        0x70, 0x62, 0x6E, 0x62, 0x71, 0x63, 0x72, 0x65, 0x72, 0x64, 0x73, 0x66, 0x71, 0x62, 0x66, 0x5B, 0x58, 0x4F, 0x4D, 0x4A, 0x4C, 0x4A, 0x49, 0x47, 0x47, 0x46, 0x3B, 0x36, 0x33, 0x30, 0x45, 0x41, 0x5E, 0x57, 0x6F, 0x60, 0x70, 0x64, 0x75, 0x68, 0x74, 0x67, 0x76, 0x67, 0x75, 0x66, 0x75, 0x63, 0x73, 0x63, 0x75, 0x66, 0x77, 0x67, 0x77, 0x64, 0x73, 0x62, 0x74, 0x63, 0x73, 0x64, 0x76, 0x65, 0x77, 0x66, 0x78, 0x66, 0x74, 0x63, 0x74, 0x64, 0x75, 0x63, 0x74, 0x64, 0x72, 0x63, 0x73, 0x65, 0x76, 0x67, 0x78, 0x6D, 0x7D, 0x70, 0x7A, 0x68, 0x78, 0x67, 0x76, 0x66, 0x78, 0x68, 0x7B, 0x69, 0x7E, 0x6C, 0x7A, 0x68, 0x77, 0x67, 0x76, 0x67, 0x75, 0x67, 0x78, 0x65, 0x77, 0x66, 0x76, 0x66, 0x75, 0x68, 0x76, 0x66, 0x76, 0x67, 0x79, 0x67, 0x76, 0x65, 0x78, 0x67, 0x78, 0x67, 0x76, 0x66, 0x78, 0x68, 0x7B, 0x6A, 0x7A, 0x6A, 0x7A, 0x69, 0x7D, 0x6C, 0x7C, 0x6A, 0x80, 0x6F, 0x7E, 0x6D, 0x7F, 0x6D, 0x7F, 0x6D, 0x7F, 0x70, 0x81, 0x70, 0x80, 0x6F, 0x7F, 0x6E, 0x7F, 0x6E, 0x80, 0x6F, 0x7F, 0x6D, 0x7F, 0x6D, 0x81, 0x70, 0x81, 0x71, 0x82, 0x70, 0x80, 0x6E, 0x7E, 0x6F, 0x80, 0x6F, 0x86, 0x74, 0x83, 0x73, 0x82, 0x71, 0x86, 0x77, 0x85, 0x78, 0x84, 0x73, 0x7F, 0x70, 0x85, 0x73, 0x84, 0x74, 0x81, 0x70, 0x83, 0x74, 0x84, 0x73, 0x81, 0x6F, 0x80, 0x70, 0x83, 0x74, 0x87, 0x72, 0x82, 0x73, 0x82, 0x74, 0x86, 0x75, 0x87, 0x77, 0x87, 0x75, 0x83, 0x73, 0x84, 0x78, 0x8A, 0x79, 0x8A, 0x7B, 0x87, 0x75, 0x89, 0x7A, 0x88, 0x7A, 0x83, 0x74, 0x88, 0x7A, 0x89, 0x78, 0x7F, 0x72, 0x79, 0x6E, 0x76, 0x6E, 0x7C, 0x72, 0x85, 0x76, 0x86, 0x77, 0x8B, 0x7B, 0x8C, 0x7C, 0x8F, 0x80, 0x8D, 0x7E, 0x8D, 0x83, 0x90, 0x80, 0x8C, 0x7D, 0x89, 0x7A, 0x88, 0x78, 0x87, 0x78, 0x89, 0x7C, 0x8B, 0x7B, 0x8B, 0x79, 0x8B, 0x79, 0x87, 0x7C, 0x8B, 0x7D, 0x87, 0x77, 0x88, 0x79, 0x8C, 0x7D, 0x94, 0x8C, 0x99, 0x92, 0x9A, 0x91, 0xB4, 0xBC, 0xB6, 0xBE, 0xA6, 0xAE, 0xA4, 0xB4, 0xC0, 0xD3, 0xB2, 0xB7, 0xA6, 0xA7, 0x9C, 0x9D, 0xA8, 0xAC, 0xA2, 0xA0, 0xA4, 0xA7, 0x9C, 0x9A, 0xA8, 0xAF, 0xA6, 0xA4, 0xA2, 0xAD, 0x9E, 0x9C, 0x98, 0x90, 0x90, 0x8B, 0x8E, 0x89, 0x90, 0x9E, 0x94, 0xA1, 0x79, 0x85, 0x6F, 0x76, 0x54, 0x57, 0x85, 0x91, 0x81, 0x7A, 0x81, 0x76, 0x7F, 0x73, 0x80, 0x75, 0x7B, 0x6E, 0x85, 0x80, 0x87, 0x7B, 0x87, 0x7D, 0x82, 0x7E, 0x89, 0x80, 0x7C, 0x6F, 0x7B, 0x72, 0x7D, 0x76, 0x7A, 0x6F, 0x83, 0x79, 0x7A, 0x6E, 0x7A, 0x71, 0x7D, 0x71, 0x81, 0x74, 0x7F, 0x79, 0x7C, 0x6D, 0x7D, 0x70, 0x76, 0x6D, 0x7A, 0x6D, 0x75, 0x69, 0x77, 0x6B, 0x78, 0x6A, 0x7A, 0x6E, 0x79, 0x6B, 0x79, 0x6D, 0x7A, 0x69, 0x7C, 0x70, 0x7D, 0x6E, 0x7B, 0x6C, 0x7D, 0x6D, 0x7D, 0x6E, 0x7F, 0x6F, 0x78, 0x6A, 0x7C, 0x6D, 0x78, 0x6F, 0x7E, 0x6E, 0x77, 0x69, 0x73, 0x65, 0x77, 0x67, 0x72, 0x65, 0x78, 0x69, 0x78, 0x6B, 0x77, 0x6B, 0x76, 0x69, 0x7B, 0x6D, 0x79, 0x6B, 0x76, 0x68, 0x77, 0x68, 0x7A, 0x6E, 0x7C, 0x70, 0x79, 0x6A, 0x79, 0x6E, 0x79, 0x6F, 0x7D, 0x70, 0x7C, 0x6E, 0x77, 0x6E, 0x7D, 0x70, 0x79, 0x6E, 0x7E, 0x78, 0x81, 0x76, 0x7D, 0x72, 0x7E, 0x79, 0x7E, 0x78, 0x7F, 0x76, 0x7E, 0x72, 0x7F, 0x76, 0x82, 0x7E, 0x7F, 0x77, 0x8E, 0x89, 0x88, 0x81, 0x83, 0x7B, 0x8C, 0x8A, 0x8B, 0x88, 0x8A, 0x80, 0x7F, 0x76, 0x83, 0x7B, 0x81, 0x79, 0x83, 0x7A, 0x7F, 0x7B, 0x96, 0x98, 0x85, 0x7C, 0x84, 0x82, 0x87, 0x81, 0x82, 0x7E, 0x81, 0x78, 0x7C, 0x75, 0x7D, 0x73, 0x81, 0x7A, 0x7C, 0x75, 0x82, 0x7B, 0x84, 0x81, 0x81, 0x77, 0x74, 0x69, 0x6A, 0x61, 0x4C, 0x4E, 0x42, 0x4D, 0x47, 0x51, 0x40, 0x46, 0x3E, 0x49, 0x43, 0x45, 0x37, 0x3B, 0x2D, 0x31, 0x29, 0x2E, 0x28, 0x2C, 0x25, 0x29, 0x23, 0x27, 0x20, 0x26, 0x31, 0x3A, 0x32, 0x39, 0x36, 0x3B, 0x35, 0x3A, 0x2C, 0x33, 0x30, 0x37, 0x35, 0x3D, 0x39, 0x41, 0x33, 0x3A, 0x37, 0x3E, 0x3F, 0x4A, 0x41, 0x49, 0x3E, 0x45, 0x39, 0x41, 0x3F, 0x4B, 0x39, 0x3E, 0x3F, 0x4A, 0x38, 0x3F, 0x41, 0x49, 0x37, 0x3B, 0x3A, 0x42, 0x38, 0x40, 0x40, 0x48, 0x37, 0x3E, 0x38, 0x3E, 0x3C, 0x43, 0x36, 0x3A, 0x37, 0x3E, 0x36, 0x3B, 0x36, 0x3C, 0x36, 0x3E, 0x3A, 0x42, 0x3F, 0x48, 0x43, 0x4A, 0x42, 0x4E, 0x3F, 0x47
    },

    {
        0x63, 0x25, 0x64, 0x24, 0x62, 0x23, 0x61, 0x22, 0x63, 0x22, 0x63, 0x22, 0x61, 0x23, 0x61, 0x22, 0x50, 0x1E, 0x42, 0x1C, 0x40, 0x1D, 0x3D, 0x1C, 0x34, 0x17, 0x2A, 0x15, 0x32, 0x17, 0x44, 0x1D, 0x56, 0x20, 0x5E, 0x22, 0x5E, 0x23, 0x60, 0x23, 0x62, 0x24, 0x63, 0x23, 0x63, 0x23, 0x61, 0x23, 0x61, 0x23, 0x64, 0x24, 0x64, 0x23, 0x61, 0x22, 0x60, 0x22, 0x60, 0x23, 0x62, 0x24, 0x64, 0x25, 0x63, 0x24, 0x65, 0x24, 0x65, 0x24, 0x63, 0x24, 0x65, 0x26, 0x62, 0x25, 0x63, 0x25, 0x65, 0x26, 0x67, 0x27, 0x68, 0x28, 0x67, 0x25, 0x63, 0x24, 0x63, 0x25, 0x63, 0x24, 0x63, 0x24, 0x63, 0x23, 0x62, 0x23, 0x66, 0x27, 0x64, 0x25, 0x64, 0x26, 0x65, 0x25, 0x63, 0x24, 0x63, 0x24, 0x63, 0x24, 0x62, 0x25, 0x66, 0x25, 0x64, 0x25, 0x64, 0x25, 0x63, 0x24, 0x67, 0x25, 0x62, 0x24, 0x64, 0x24, 0x64, 0x25, 0x66, 0x24, 0x65, 0x25, 0x65, 0x26, 0x69, 0x26, 0x66, 0x25, 0x68, 0x27, 0x68, 0x26, 0x6A, 0x26, 0x6A, 0x26, 0x6D, 0x27, 0x6B, 0x27, 0x68, 0x26, 0x68, 0x26, 0x66, 0x27, 0x6B, 0x28, 0x68, 0x27, 0x66, 0x26, 0x69, 0x27, 0x6C, 0x27, 0x6B, 0x27, 0x6C, 0x28, 0x6C, 0x28, 0x6E, 0x29, 0x6C, 0x29, 0x6C, 0x28, 0x70, 0x2A, 0x6F, 0x29, 0x6F, 0x29, 0x6D, 0x28, 0x6D, 0x29, 0x73, 0x2A, 0x6E, 0x28, 0x6E, 0x28, 0x6F, 0x2A, 0x71, 0x29, 0x71, 0x2A, 0x70, 0x2A, 0x6F, 0x2A, 0x73, 0x2B, 0x70, 0x29, 0x70, 0x2A, 0x70, 0x2A, 0x75, 0x2D, 0x72, 0x2A, 0x6F, 0x29, 0x6F, 0x2A, 0x72, 0x2C, 0x73, 0x2C, 0x74, 0x2B, 0x74, 0x2B, 0x75, 0x2A, 0x6F, 0x29, 0x70, 0x2B, 0x66, 0x2B, 0x5E, 0x2B, 0x5B, 0x2B, 0x5B, 0x2A, 0x5E, 0x2A, 0x6B, 0x2A, 0x6F, 0x2C, 0x75, 0x2E, 0x7B, 0x2F, 0x76, 0x2E, 0x7C, 0x2E, 0x77, 0x2E, 0x7A, 0x2E, 0x77, 0x2D, 0x76, 0x2C, 0x73, 0x2B, 0x76, 0x2D, 0x78, 0x2D, 0x76, 0x2C, 0x75, 0x2C, 0x75, 0x2D, 0x76, 0x2E, 0x75, 0x2D, 0x7A, 0x2F, 0x78, 0x2E, 0x7C, 0x30, 0x7F, 0x37, 0x9D, 0x4F, 0xAB, 0x56, 0xBC, 0x5C, 0xB5, 0x5C, 0xAF, 0x56, 0x94, 0x47, 0x98, 0x45, 0x99, 0x4A, 0x93, 0x4A, 0xA9, 0x52, 0xA4, 0x4F, 0x9D, 0x47, 0xAB, 0x57, 0x94, 0x43, 0x8D, 0x43, 0x92, 0x41, 0x8B, 0x45, 0x91, 0x44, 0xAB, 0x52, 0x9C, 0x47, 0x97, 0x4E, 0x9C, 0x60, 0x87, 0x4E, 0x59, 0x33, 0x50, 0x2F, 0x3F, 0x26, 0x4F, 0x2C, 0x72, 0x35, 0x7E, 0x36, 0x79, 0x30, 0x75, 0x32, 0x73, 0x2E, 0x7C, 0x35, 0x7E, 0x36, 0x80, 0x35, 0x7A, 0x37, 0x85, 0x38, 0x6D, 0x2A, 0x68, 0x29, 0x6B, 0x2C, 0x71, 0x2E, 0x69, 0x2A, 0x6D, 0x2D, 0x72, 0x2F, 0x6A, 0x2A, 0x69, 0x29, 0x7D, 0x38, 0x6E, 0x2C, 0x6F, 0x2D, 0x6F, 0x2B, 0x6C, 0x2A, 0x67, 0x27, 0x67, 0x27, 0x66, 0x28, 0x6C, 0x2A, 0x68, 0x28, 0x61, 0x25, 0x66, 0x27, 0x68, 0x27, 0x64, 0x27, 0x64, 0x27, 0x67, 0x26, 0x64, 0x25, 0x68, 0x29, 0x67, 0x28, 0x6A, 0x27, 0x6B, 0x2A, 0x6E, 0x2A, 0x63, 0x27, 0x64, 0x26, 0x66, 0x26, 0x62, 0x24, 0x64, 0x26, 0x65, 0x26, 0x64, 0x26, 0x67, 0x27, 0x6A, 0x28, 0x6C, 0x28, 0x6C, 0x2A, 0x64, 0x26, 0x65, 0x26, 0x66, 0x26, 0x68, 0x28, 0x67, 0x27, 0x66, 0x28, 0x67, 0x28, 0x6A, 0x29, 0x6B, 0x2B, 0x6A, 0x2B, 0x6D, 0x2B, 0x77, 0x34, 0x6B, 0x29, 0x6D, 0x2D, 0x6F, 0x2D, 0x6E, 0x2D, 0x71, 0x31, 0x79, 0x33, 0x7A, 0x33, 0x71, 0x31, 0x6E, 0x2F, 0x80, 0x38, 0x7C, 0x37, 0x7A, 0x35, 0x7F, 0x3A, 0x7D, 0x38, 0x78, 0x34, 0x71, 0x2F, 0x7B, 0x37, 0x75, 0x31, 0x75, 0x33, 0x71, 0x31, 0x85, 0x3D, 0x7A, 0x35, 0x7F, 0x3B, 0x85, 0x3C, 0x79, 0x34, 0x70, 0x2F, 0x79, 0x37, 0x75, 0x32, 0x6F, 0x2E, 0x73, 0x33, 0x76, 0x34, 0x78, 0x36, 0x6B, 0x2B, 0x64, 0x29, 0x68, 0x2F, 0x5C, 0x2E, 0x4E, 0x29, 0x4A, 0x26, 0x3E, 0x22, 0x44, 0x25, 0x46, 0x26, 0x3B, 0x22, 0x2B, 0x1B, 0x2B, 0x1A, 0x33, 0x1E, 0x35, 0x1F, 0x3C, 0x21, 0x36, 0x1E, 0x44, 0x24, 0x40, 0x22, 0x4F, 0x29, 0x49, 0x26, 0x47, 0x26, 0x45, 0x25, 0x45, 0x24, 0x44, 0x23, 0x3E, 0x22, 0x41, 0x22, 0x45, 0x24, 0x39, 0x1E, 0x36, 0x1E, 0x37, 0x1E, 0x3E, 0x21, 0x38, 0x1F, 0x45, 0x25, 0x3B, 0x21, 0x43, 0x22, 0x3A, 0x1F, 0x44, 0x24, 0x3E, 0x23, 0x42, 0x24, 0x3D, 0x21, 0x46, 0x25, 0x3F, 0x22, 0x42, 0x23, 0x47, 0x24, 0x3F, 0x21, 0x43, 0x22, 0x42, 0x23, 0x49, 0x25, 0x4C, 0x28, 0x44, 0x23, 0x43, 0x23, 0x3A, 0x1F
    },

    {
        0x71, 0x66, 0x72, 0x66, 0x71, 0x64, 0x71, 0x64, 0x73, 0x66, 0x75, 0x66, 0x72, 0x65, 0x70, 0x62, 0x5F, 0x50, 0x4C, 0x43, 0x42, 0x3E, 0x3C, 0x39, 0x34, 0x2F, 0x30, 0x2E, 0x3C, 0x39, 0x52, 0x4B, 0x64, 0x5A, 0x6D, 0x5F, 0x6F, 0x5F, 0x71, 0x62, 0x73, 0x64, 0x76, 0x67, 0x77, 0x66, 0x73, 0x62, 0x74, 0x64, 0x77, 0x67, 0x77, 0x66, 0x75, 0x63, 0x73, 0x64, 0x72, 0x63, 0x74, 0x65, 0x75, 0x66, 0x74, 0x65, 0x78, 0x67, 0x79, 0x66, 0x75, 0x67, 0x77, 0x6A, 0x74, 0x66, 0x73, 0x67, 0x76, 0x67, 0x77, 0x6B, 0x7A, 0x6B, 0x78, 0x68, 0x76, 0x66, 0x77, 0x67, 0x76, 0x66, 0x77, 0x67, 0x77, 0x66, 0x76, 0x64, 0x76, 0x68, 0x78, 0x67, 0x76, 0x69, 0x78, 0x69, 0x77, 0x65, 0x77, 0x67, 0x76, 0x68, 0x74, 0x67, 0x7B, 0x6A, 0x78, 0x69, 0x76, 0x66, 0x74, 0x66, 0x79, 0x6A, 0x77, 0x66, 0x78, 0x67, 0x79, 0x68, 0x77, 0x67, 0x7A, 0x69, 0x7C, 0x6B, 0x7D, 0x6B, 0x79, 0x68, 0x7B, 0x6C, 0x7C, 0x6D, 0x7F, 0x6C, 0x81, 0x6E, 0x80, 0x6F, 0x7E, 0x6C, 0x7B, 0x6B, 0x7D, 0x6A, 0x7D, 0x6D, 0x80, 0x6F, 0x7C, 0x6C, 0x78, 0x6A, 0x7D, 0x6D, 0x7F, 0x6E, 0x82, 0x70, 0x82, 0x70, 0x80, 0x72, 0x81, 0x71, 0x81, 0x71, 0x81, 0x72, 0x83, 0x73, 0x82, 0x74, 0x83, 0x72, 0x82, 0x71, 0x81, 0x71, 0x86, 0x77, 0x86, 0x73, 0x83, 0x71, 0x82, 0x73, 0x87, 0x75, 0x85, 0x74, 0x85, 0x75, 0x84, 0x74, 0x86, 0x77, 0x83, 0x72, 0x84, 0x72, 0x83, 0x74, 0x86, 0x78, 0x88, 0x77, 0x85, 0x73, 0x83, 0x73, 0x87, 0x76, 0x84, 0x76, 0x88, 0x79, 0x8B, 0x79, 0x86, 0x76, 0x83, 0x72, 0x80, 0x72, 0x6D, 0x65, 0x61, 0x5B, 0x5C, 0x5D, 0x5D, 0x5D, 0x62, 0x5F, 0x75, 0x6D, 0x7F, 0x72, 0x85, 0x79, 0x8C, 0x7D, 0x8C, 0x7C, 0x8D, 0x7D, 0x8C, 0x7D, 0x8D, 0x7E, 0x8E, 0x7E, 0x8C, 0x79, 0x86, 0x75, 0x8A, 0x79, 0x8D, 0x7C, 0x8B, 0x7B, 0x8C, 0x7B, 0x88, 0x78, 0x89, 0x7B, 0x89, 0x7C, 0x90, 0x80, 0x8E, 0x7E, 0x91, 0x80, 0x95, 0x8C, 0xA6, 0xAB, 0xAF, 0xB5, 0xB5, 0xB9, 0xB6, 0xC0, 0xB2, 0xB0, 0x9A, 0x95, 0x91, 0x88, 0x97, 0x98, 0x97, 0x96, 0xA3, 0xA7, 0x9C, 0x9C, 0x9C, 0x97, 0xA8, 0xB4, 0xA0, 0x98, 0x91, 0x8D, 0x97, 0x8E, 0x90, 0x90, 0x9C, 0x9B, 0xAC, 0xAC, 0x9D, 0x9D, 0x91, 0x99, 0x89, 0x9C, 0x72, 0x77, 0x52, 0x4F, 0x49, 0x48, 0x40, 0x3E, 0x46, 0x4E, 0x78, 0x80, 0x86, 0x81, 0x88, 0x7B, 0x89, 0x7F, 0x82, 0x75, 0x88, 0x7E, 0x87, 0x80, 0x8D, 0x84, 0x8A, 0x88, 0x90, 0x86, 0x7B, 0x70, 0x7A, 0x6D, 0x7A, 0x6E, 0x7D, 0x73, 0x78, 0x6D, 0x7B, 0x73, 0x80, 0x77, 0x7A, 0x6B, 0x7A, 0x6C, 0x84, 0x7F, 0x7C, 0x71, 0x7E, 0x74, 0x7F, 0x74, 0x7A, 0x6E, 0x79, 0x6A, 0x78, 0x6A, 0x79, 0x6B, 0x79, 0x6D, 0x79, 0x6B, 0x73, 0x68, 0x79, 0x6A, 0x7B, 0x6A, 0x77, 0x6A, 0x73, 0x69, 0x79, 0x6C, 0x76, 0x69, 0x7C, 0x6F, 0x7B, 0x6F, 0x7D, 0x6C, 0x7D, 0x6D, 0x7F, 0x72, 0x78, 0x69, 0x7B, 0x6B, 0x79, 0x6A, 0x73, 0x67, 0x76, 0x69, 0x79, 0x69, 0x76, 0x69, 0x78, 0x6B, 0x7C, 0x6F, 0x80, 0x72, 0x80, 0x70, 0x75, 0x67, 0x76, 0x69, 0x7A, 0x6C, 0x7C, 0x6C, 0x79, 0x6D, 0x77, 0x6A, 0x7B, 0x6E, 0x7A, 0x6F, 0x79, 0x6F, 0x78, 0x6E, 0x80, 0x72, 0x82, 0x7C, 0x79, 0x6D, 0x7B, 0x77, 0x7C, 0x72, 0x7D, 0x74, 0x7E, 0x78, 0x83, 0x7B, 0x85, 0x7D, 0x7B, 0x78, 0x7E, 0x76, 0x8A, 0x82, 0x8B, 0x87, 0x89, 0x81, 0x89, 0x83, 0x88, 0x82, 0x86, 0x7A, 0x81, 0x76, 0x84, 0x7F, 0x84, 0x79, 0x84, 0x7E, 0x82, 0x7C, 0x8E, 0x89, 0x86, 0x7E, 0x89, 0x88, 0x8A, 0x86, 0x82, 0x7F, 0x7E, 0x77, 0x87, 0x82, 0x84, 0x7B, 0x7D, 0x70, 0x82, 0x7E, 0x7F, 0x79, 0x80, 0x79, 0x7A, 0x6B, 0x73, 0x6B, 0x6E, 0x6C, 0x52, 0x58, 0x43, 0x4E, 0x3F, 0x46, 0x37, 0x3E, 0x3D, 0x49, 0x40, 0x49, 0x38, 0x3D, 0x2E, 0x32, 0x2D, 0x33, 0x32, 0x3A, 0x38, 0x43, 0x3B, 0x42, 0x33, 0x3A, 0x3E, 0x4A, 0x3B, 0x44, 0x49, 0x55, 0x40, 0x46, 0x3F, 0x4A, 0x3C, 0x44, 0x3D, 0x44, 0x3B, 0x41, 0x3A, 0x43, 0x3A, 0x40, 0x3D, 0x44, 0x34, 0x39, 0x32, 0x39, 0x33, 0x3A, 0x39, 0x3E, 0x37, 0x3D, 0x3E, 0x48, 0x39, 0x42, 0x3F, 0x44, 0x39, 0x3F, 0x3F, 0x47, 0x3A, 0x44, 0x3B, 0x43, 0x3B, 0x44, 0x41, 0x47, 0x3B, 0x43, 0x3E, 0x4A, 0x42, 0x4A, 0x3C, 0x43, 0x42, 0x48, 0x3E, 0x46, 0x43, 0x4E, 0x43, 0x4C, 0x3A, 0x41, 0x39, 0x40, 0x35, 0x3C
    },

    {
        0x61, 0x25, 0x61, 0x23, 0x62, 0x23, 0x61, 0x22, 0x61, 0x22, 0x62, 0x23, 0x63, 0x23, 0x61, 0x22, 0x58, 0x20, 0x4B, 0x1C, 0x3E, 0x18, 0x34, 0x16, 0x31, 0x17, 0x37, 0x18, 0x43, 0x1C, 0x51, 0x1F, 0x5A, 0x21, 0x5E, 0x22, 0x5D, 0x21, 0x61, 0x23, 0x63, 0x23, 0x64, 0x24, 0x64, 0x24, 0x63, 0x24, 0x62, 0x23, 0x63, 0x22, 0x62, 0x23, 0x62, 0x23, 0x63, 0x24, 0x62, 0x24, 0x64, 0x24, 0x66, 0x26, 0x6B, 0x28, 0x64, 0x24, 0x63, 0x25, 0x65, 0x26, 0x69, 0x29, 0x64, 0x27, 0x61, 0x25, 0x63, 0x26, 0x67, 0x28, 0x68, 0x27, 0x65, 0x26, 0x64, 0x26, 0x65, 0x25, 0x65, 0x25, 0x64, 0x24, 0x62, 0x23, 0x62, 0x23, 0x61, 0x23, 0x64, 0x24, 0x65, 0x26, 0x65, 0x25, 0x63, 0x24, 0x65, 0x28, 0x69, 0x28, 0x67, 0x26, 0x66, 0x26, 0x64, 0x25, 0x64, 0x25, 0x67, 0x27, 0x6A, 0x26, 0x68, 0x26, 0x67, 0x27, 0x6A, 0x26, 0x65, 0x25, 0x67, 0x25, 0x67, 0x26, 0x67, 0x26, 0x68, 0x26, 0x6A, 0x26, 0x69, 0x26, 0x6A, 0x27, 0x6B, 0x27, 0x6B, 0x28, 0x6B, 0x27, 0x6B, 0x28, 0x69, 0x27, 0x69, 0x28, 0x6C, 0x29, 0x6F, 0x2A, 0x6B, 0x28, 0x69, 0x27, 0x6B, 0x29, 0x6A, 0x29, 0x6E, 0x2A, 0x6C, 0x2A, 0x6E, 0x2A, 0x6E, 0x29, 0x6C, 0x28, 0x6F, 0x2A, 0x74, 0x2C, 0x72, 0x2A, 0x6B, 0x28, 0x70, 0x2C, 0x72, 0x2B, 0x70, 0x2A, 0x6E, 0x2A, 0x6D, 0x2B, 0x71, 0x2B, 0x70, 0x29, 0x6F, 0x2A, 0x74, 0x2D, 0x75, 0x2B, 0x71, 0x2A, 0x6E, 0x29, 0x71, 0x2A, 0x72, 0x2B, 0x72, 0x2B, 0x74, 0x2A, 0x70, 0x2A, 0x74, 0x2C, 0x6F, 0x2A, 0x71, 0x2A, 0x73, 0x29, 0x6D, 0x29, 0x6E, 0x28, 0x66, 0x2B, 0x5C, 0x2C, 0x5A, 0x2C, 0x58, 0x2B, 0x56, 0x2B, 0x57, 0x2C, 0x5C, 0x2A, 0x69, 0x29, 0x71, 0x2C, 0x75, 0x2E, 0x77, 0x2E, 0x74, 0x2C, 0x7A, 0x30, 0x7A, 0x2F, 0x78, 0x2D, 0x75, 0x2D, 0x75, 0x2C, 0x79, 0x2E, 0x74, 0x2C, 0x75, 0x2B, 0x76, 0x2D, 0x78, 0x2D, 0x79, 0x2D, 0x74, 0x2C, 0x7D, 0x32, 0x78, 0x31, 0x92, 0x43, 0xAD, 0x54, 0xA7, 0x51, 0xBD, 0x5E, 0xBD, 0x62, 0xC5, 0x64, 0xB4, 0x5C, 0xAE, 0x51, 0x95, 0x45, 0x94, 0x3F, 0x85, 0x3B, 0x7F, 0x3C, 0x8A, 0x41, 0xAB, 0x53, 0x95, 0x4D, 0xB1, 0x58, 0xAC, 0x53, 0xA4, 0x4C, 0x8F, 0x46, 0xA1, 0x4B, 0x9D, 0x4B, 0x9B, 0x4A, 0x94, 0x55, 0x82, 0x4C, 0x5C, 0x36, 0x4C, 0x2C, 0x4D, 0x31, 0x4F, 0x2B, 0x3B, 0x23, 0x70, 0x40, 0xA4, 0x4C, 0x8A, 0x3C, 0x88, 0x3C, 0x71, 0x2D, 0x6F, 0x2D, 0x71, 0x2F, 0x77, 0x36, 0x8F, 0x44, 0x8F, 0x40, 0x77, 0x30, 0x6D, 0x2B, 0x69, 0x28, 0x68, 0x27, 0x72, 0x31, 0x72, 0x2D, 0x70, 0x2F, 0x6F, 0x2B, 0x6B, 0x2A, 0x73, 0x30, 0x6E, 0x2B, 0x6C, 0x2B, 0x77, 0x32, 0x6E, 0x2A, 0x63, 0x26, 0x61, 0x25, 0x62, 0x26, 0x66, 0x27, 0x69, 0x2A, 0x69, 0x27, 0x65, 0x27, 0x67, 0x26, 0x67, 0x25, 0x62, 0x27, 0x67, 0x27, 0x64, 0x26, 0x69, 0x27, 0x6A, 0x29, 0x65, 0x25, 0x63, 0x26, 0x6E, 0x2A, 0x6A, 0x28, 0x68, 0x27, 0x63, 0x25, 0x61, 0x24, 0x63, 0x26, 0x64, 0x26, 0x67, 0x26, 0x69, 0x27, 0x69, 0x28, 0x67, 0x27, 0x68, 0x26, 0x63, 0x26, 0x67, 0x29, 0x66, 0x27, 0x65, 0x26, 0x65, 0x25, 0x62, 0x24, 0x63, 0x27, 0x6B, 0x2B, 0x71, 0x2D, 0x6A, 0x2B, 0x6E, 0x2C, 0x6A, 0x2A, 0x69, 0x29, 0x6E, 0x2C, 0x6D, 0x2E, 0x72, 0x2F, 0x6C, 0x2E, 0x74, 0x31, 0x76, 0x32, 0x70, 0x30, 0x84, 0x3B, 0x78, 0x34, 0x7F, 0x3A, 0x84, 0x3C, 0x7F, 0x37, 0x7F, 0x39, 0x78, 0x33, 0x75, 0x32, 0x75, 0x32, 0x77, 0x34, 0x8F, 0x43, 0x93, 0x45, 0x88, 0x40, 0x81, 0x3C, 0x83, 0x3D, 0x80, 0x3B, 0x86, 0x3E, 0x72, 0x32, 0x77, 0x35, 0x73, 0x31, 0x66, 0x2B, 0x82, 0x3D, 0x77, 0x35, 0x75, 0x32, 0x68, 0x29, 0x64, 0x2A, 0x61, 0x2C, 0x50, 0x2A, 0x43, 0x23, 0x44, 0x25, 0x49, 0x27, 0x49, 0x26, 0x4E, 0x28, 0x4A, 0x27, 0x43, 0x24, 0x3F, 0x24, 0x46, 0x24, 0x48, 0x27, 0x42, 0x23, 0x34, 0x1D, 0x45, 0x25, 0x42, 0x24, 0x4A, 0x26, 0x37, 0x1F, 0x42, 0x23, 0x3E, 0x20, 0x43, 0x23, 0x3C, 0x1F, 0x3D, 0x21, 0x3C, 0x20, 0x3F, 0x21, 0x3F, 0x22, 0x41, 0x22, 0x4A, 0x26, 0x46, 0x25, 0x46, 0x25, 0x45, 0x24, 0x47, 0x25, 0x43, 0x23, 0x46, 0x25, 0x4D, 0x27, 0x40, 0x23, 0x47, 0x26, 0x46, 0x25, 0x42, 0x23, 0x47, 0x26, 0x4D, 0x29, 0x49, 0x27, 0x46, 0x26, 0x47, 0x24, 0x44, 0x25, 0x44, 0x23, 0x3A, 0x1F, 0x39, 0x20, 0x39, 0x1E, 0x3B, 0x20
    },

    {
        0x6E, 0x62, 0x6E, 0x61, 0x72, 0x65, 0x71, 0x63, 0x72, 0x64, 0x73, 0x65, 0x75, 0x65, 0x72, 0x61, 0x69, 0x59, 0x5B, 0x4D, 0x4B, 0x41, 0x3F, 0x37, 0x3D, 0x37, 0x44, 0x3F, 0x53, 0x4C, 0x63, 0x58, 0x6C, 0x5F, 0x70, 0x60, 0x6F, 0x5F, 0x72, 0x64, 0x74, 0x65, 0x76, 0x67, 0x77, 0x66, 0x74, 0x64, 0x74, 0x64, 0x76, 0x66, 0x76, 0x65, 0x77, 0x66, 0x77, 0x67, 0x75, 0x65, 0x79, 0x67, 0x79, 0x6A, 0x7C, 0x6D, 0x76, 0x66, 0x76, 0x67, 0x76, 0x67, 0x79, 0x6A, 0x74, 0x67, 0x71, 0x65, 0x74, 0x67, 0x74, 0x68, 0x77, 0x69, 0x76, 0x66, 0x77, 0x67, 0x7A, 0x69, 0x7A, 0x6B, 0x76, 0x65, 0x74, 0x64, 0x75, 0x65, 0x76, 0x65, 0x75, 0x65, 0x77, 0x67, 0x77, 0x66, 0x78, 0x67, 0x76, 0x67, 0x74, 0x67, 0x7A, 0x6A, 0x7A, 0x67, 0x79, 0x67, 0x77, 0x68, 0x7A, 0x6A, 0x7A, 0x69, 0x7D, 0x6C, 0x7D, 0x6C, 0x7E, 0x6B, 0x77, 0x68, 0x7B, 0x68, 0x7D, 0x6C, 0x7C, 0x6C, 0x7C, 0x6C, 0x7E, 0x6C, 0x7E, 0x6D, 0x7E, 0x6A, 0x7F, 0x70, 0x80, 0x6E, 0x7D, 0x6F, 0x7E, 0x6D, 0x7C, 0x6D, 0x7C, 0x6E, 0x7D, 0x6F, 0x7F, 0x71, 0x80, 0x6E, 0x7E, 0x6C, 0x7F, 0x70, 0x7F, 0x6E, 0x7E, 0x71, 0x7E, 0x6F, 0x81, 0x73, 0x81, 0x72, 0x80, 0x6F, 0x83, 0x74, 0x84, 0x78, 0x83, 0x74, 0x81, 0x70, 0x82, 0x72, 0x84, 0x75, 0x84, 0x72, 0x80, 0x71, 0x81, 0x75, 0x84, 0x73, 0x85, 0x73, 0x85, 0x74, 0x87, 0x7A, 0x8A, 0x79, 0x86, 0x74, 0x80, 0x71, 0x84, 0x73, 0x86, 0x74, 0x88, 0x78, 0x88, 0x77, 0x84, 0x75, 0x89, 0x77, 0x86, 0x74, 0x86, 0x75, 0x86, 0x75, 0x80, 0x73, 0x84, 0x72, 0x74, 0x67, 0x62, 0x60, 0x5E, 0x5E, 0x59, 0x5A, 0x59, 0x5A, 0x5A, 0x5B, 0x5C, 0x60, 0x71, 0x69, 0x81, 0x75, 0x87, 0x7B, 0x89, 0x7B, 0x8A, 0x77, 0x8B, 0x7F, 0x8C, 0x7B, 0x8D, 0x7B, 0x8D, 0x7B, 0x8B, 0x7B, 0x8F, 0x7B, 0x8B, 0x7A, 0x8B, 0x7A, 0x8B, 0x7B, 0x8E, 0x7C, 0x8F, 0x7D, 0x88, 0x79, 0x91, 0x85, 0x89, 0x7E, 0x9D, 0xA0, 0xB1, 0xB7, 0xB0, 0xB5, 0xB4, 0xC1, 0xB3, 0xC6, 0xBA, 0xC4, 0xB0, 0xBC, 0xB6, 0xB8, 0xA1, 0xA5, 0x97, 0x8C, 0x8D, 0x85, 0x8B, 0x83, 0x90, 0x92, 0xA9, 0xAC, 0x97, 0x9B, 0xA8, 0xB1, 0xA9, 0xB0, 0xA6, 0xA1, 0x9E, 0xA2, 0xA6, 0xA6, 0xA2, 0xA1, 0xA2, 0xA3, 0x96, 0xA1, 0x74, 0x79, 0x54, 0x58, 0x4D, 0x4C, 0x4D, 0x57, 0x49, 0x4D, 0x38, 0x3C, 0x73, 0x8B, 0x9D, 0xA1, 0x94, 0x8C, 0x8F, 0x89, 0x81, 0x74, 0x7D, 0x71, 0x80, 0x74, 0x84, 0x80, 0x96, 0x93, 0x92, 0x8D, 0x83, 0x79, 0x7B, 0x71, 0x7E, 0x6F, 0x7A, 0x6C, 0x7E, 0x7A, 0x84, 0x79, 0x7F, 0x74, 0x80, 0x71, 0x80, 0x73, 0x81, 0x78, 0x7D, 0x71, 0x77, 0x6D, 0x85, 0x7D, 0x7C, 0x6E, 0x76, 0x68, 0x72, 0x65, 0x74, 0x67, 0x79, 0x6C, 0x7B, 0x6E, 0x7B, 0x6C, 0x76, 0x67, 0x78, 0x6B, 0x79, 0x69, 0x75, 0x69, 0x7C, 0x6D, 0x79, 0x69, 0x7A, 0x6B, 0x7B, 0x6E, 0x77, 0x6A, 0x77, 0x68, 0x7F, 0x70, 0x7E, 0x6E, 0x7A, 0x6B, 0x74, 0x66, 0x72, 0x64, 0x75, 0x68, 0x78, 0x6B, 0x78, 0x6C, 0x7A, 0x6B, 0x79, 0x6B, 0x7A, 0x6B, 0x7C, 0x6C, 0x75, 0x67, 0x76, 0x6A, 0x76, 0x6B, 0x78, 0x69, 0x79, 0x67, 0x76, 0x66, 0x75, 0x68, 0x7B, 0x72, 0x7E, 0x75, 0x77, 0x6E, 0x7C, 0x71, 0x7A, 0x6C, 0x77, 0x6D, 0x7B, 0x71, 0x7B, 0x72, 0x7D, 0x75, 0x7A, 0x70, 0x7E, 0x76, 0x81, 0x79, 0x81, 0x7B, 0x8D, 0x89, 0x86, 0x7D, 0x88, 0x85, 0x91, 0x8D, 0x8C, 0x83, 0x88, 0x86, 0x84, 0x7D, 0x88, 0x80, 0x86, 0x7E, 0x84, 0x80, 0x90, 0x91, 0x94, 0x96, 0x8F, 0x8A, 0x88, 0x86, 0x89, 0x85, 0x86, 0x80, 0x88, 0x88, 0x7D, 0x77, 0x80, 0x7B, 0x7E, 0x73, 0x75, 0x6B, 0x83, 0x83, 0x7F, 0x7C, 0x7D, 0x75, 0x76, 0x6A, 0x71, 0x69, 0x67, 0x62, 0x4B, 0x50, 0x40, 0x48, 0x41, 0x4C, 0x46, 0x52, 0x43, 0x4B, 0x45, 0x50, 0x42, 0x4C, 0x3C, 0x40, 0x3A, 0x47, 0x3D, 0x43, 0x3F, 0x49, 0x3A, 0x3F, 0x31, 0x38, 0x3D, 0x45, 0x3F, 0x4A, 0x41, 0x44, 0x33, 0x3A, 0x3D, 0x44, 0x3B, 0x44, 0x3D, 0x44, 0x37, 0x3C, 0x3A, 0x42, 0x3A, 0x41, 0x3B, 0x41, 0x3E, 0x45, 0x3E, 0x47, 0x44, 0x4E, 0x40, 0x4A, 0x41, 0x49, 0x3F, 0x47, 0x41, 0x4C, 0x3D, 0x44, 0x41, 0x4A, 0x44, 0x4C, 0x39, 0x3F, 0x42, 0x4D, 0x3D, 0x44, 0x3B, 0x44, 0x41, 0x4A, 0x45, 0x50, 0x41, 0x48, 0x3F, 0x49, 0x3E, 0x44, 0x3C, 0x47, 0x3A, 0x40, 0x33, 0x38, 0x36, 0x3C, 0x35, 0x3D, 0x38, 0x3F
    },

    {
        0x62, 0x27, 0x60, 0x24, 0x62, 0x24, 0x61, 0x22, 0x5F, 0x21, 0x60, 0x22, 0x60, 0x22, 0x60, 0x21, 0x5F, 0x21, 0x59, 0x1F, 0x50, 0x1E, 0x4C, 0x1C, 0x4B, 0x1C, 0x50, 0x1E, 0x56, 0x1F, 0x5A, 0x20, 0x5D, 0x21, 0x5E, 0x22, 0x60, 0x23, 0x62, 0x24, 0x61, 0x23, 0x63, 0x24, 0x62, 0x24, 0x61, 0x24, 0x60, 0x22, 0x61, 0x22, 0x62, 0x23, 0x66, 0x25, 0x65, 0x24, 0x63, 0x23, 0x67, 0x25, 0x66, 0x26, 0x64, 0x24, 0x62, 0x24, 0x63, 0x24, 0x62, 0x25, 0x63, 0x25, 0x61, 0x26, 0x5F, 0x25, 0x62, 0x26, 0x65, 0x26, 0x63, 0x25, 0x66, 0x27, 0x67, 0x26, 0x67, 0x26, 0x68, 0x26, 0x65, 0x25, 0x62, 0x24, 0x61, 0x24, 0x63, 0x24, 0x62, 0x24, 0x62, 0x24, 0x64, 0x24, 0x63, 0x24, 0x63, 0x24, 0x63, 0x23, 0x62, 0x24, 0x64, 0x24, 0x64, 0x24, 0x63, 0x24, 0x64, 0x24, 0x64, 0x24, 0x64, 0x25, 0x66, 0x25, 0x63, 0x24, 0x65, 0x25, 0x67, 0x26, 0x69, 0x26, 0x67, 0x25, 0x67, 0x25, 0x67, 0x26, 0x6B, 0x27, 0x66, 0x25, 0x6A, 0x28, 0x6B, 0x28, 0x6C, 0x28, 0x6C, 0x28, 0x6B, 0x28, 0x6A, 0x27, 0x6C, 0x28, 0x69, 0x27, 0x6D, 0x29, 0x71, 0x2A, 0x6E, 0x2A, 0x70, 0x2B, 0x71, 0x2A, 0x70, 0x2A, 0x6F, 0x29, 0x6C, 0x27, 0x6C, 0x28, 0x72, 0x2B, 0x6E, 0x2A, 0x6E, 0x28, 0x6B, 0x28, 0x6D, 0x29, 0x6F, 0x2A, 0x6C, 0x29, 0x6F, 0x2B, 0x72, 0x2C, 0x73, 0x2B, 0x6F, 0x29, 0x6F, 0x2A, 0x73, 0x2B, 0x71, 0x2B, 0x75, 0x2A, 0x6F, 0x28, 0x6F, 0x2A, 0x72, 0x2A, 0x74, 0x2C, 0x71, 0x2B, 0x73, 0x2C, 0x78, 0x2C, 0x71, 0x2A, 0x6F, 0x2A, 0x71, 0x2A, 0x72, 0x2B, 0x72, 0x2B, 0x61, 0x2C, 0x5C, 0x2D, 0x5C, 0x2D, 0x59, 0x2C, 0x59, 0x2C, 0x5A, 0x2D, 0x56, 0x29, 0x53, 0x24, 0x68, 0x2B, 0x74, 0x2E, 0x7F, 0x30, 0x78, 0x2D, 0x77, 0x2D, 0x76, 0x2D, 0x74, 0x2B, 0x72, 0x2B, 0x78, 0x2C, 0x78, 0x2C, 0x72, 0x2A, 0x6F, 0x2A, 0x76, 0x2C, 0x77, 0x2D, 0x71, 0x2D, 0x7E, 0x33, 0x81, 0x35, 0x85, 0x39, 0x8F, 0x45, 0xB4, 0x5C, 0xBF, 0x5B, 0xA4, 0x54, 0xA4, 0x4F, 0x9A, 0x4A, 0x98, 0x48, 0x97, 0x4B, 0x95, 0x45, 0x8F, 0x44, 0x98, 0x45, 0x8A, 0x3E, 0x8A, 0x45, 0x9E, 0x4D, 0x8F, 0x42, 0x87, 0x43, 0xA1, 0x50, 0x91, 0x44, 0x9A, 0x4B, 0xA8, 0x56, 0xA2, 0x4C, 0xA2, 0x51, 0x90, 0x4E, 0x69, 0x3D, 0x5B, 0x38, 0x60, 0x36, 0x47, 0x2B, 0x40, 0x27, 0x3A, 0x26, 0x73, 0x42, 0x9D, 0x4B, 0x91, 0x40, 0x82, 0x37, 0x74, 0x2F, 0x73, 0x2E, 0x7A, 0x35, 0x7C, 0x3A, 0x99, 0x44, 0x7F, 0x37, 0x83, 0x3C, 0x80, 0x35, 0x7D, 0x32, 0x6F, 0x2C, 0x6F, 0x2F, 0x71, 0x2F, 0x70, 0x31, 0x75, 0x2E, 0x75, 0x31, 0x76, 0x2F, 0x6A, 0x2C, 0x73, 0x30, 0x7F, 0x36, 0x6E, 0x29, 0x65, 0x26, 0x65, 0x25, 0x65, 0x26, 0x66, 0x27, 0x66, 0x26, 0x67, 0x26, 0x68, 0x28, 0x64, 0x26, 0x63, 0x25, 0x63, 0x25, 0x68, 0x27, 0x66, 0x26, 0x67, 0x26, 0x69, 0x28, 0x66, 0x26, 0x63, 0x25, 0x63, 0x25, 0x61, 0x26, 0x5F, 0x24, 0x66, 0x27, 0x68, 0x27, 0x65, 0x26, 0x64, 0x25, 0x63, 0x26, 0x64, 0x26, 0x68, 0x27, 0x65, 0x25, 0x65, 0x25, 0x63, 0x25, 0x61, 0x26, 0x62, 0x25, 0x63, 0x25, 0x63, 0x25, 0x62, 0x25, 0x63, 0x26, 0x6B, 0x2C, 0x70, 0x2D, 0x75, 0x32, 0x66, 0x29, 0x6A, 0x29, 0x65, 0x28, 0x76, 0x34, 0x6C, 0x2A, 0x6A, 0x2B, 0x68, 0x2A, 0x70, 0x2E, 0x75, 0x33, 0x7C, 0x38, 0x7A, 0x36, 0x78, 0x32, 0x7A, 0x36, 0x8D, 0x43, 0x8D, 0x41, 0x91, 0x48, 0x8C, 0x3E, 0x8A, 0x44, 0x97, 0x45, 0x7F, 0x37, 0x75, 0x33, 0x7B, 0x38, 0x7E, 0x37, 0x81, 0x3E, 0x92, 0x47, 0x7D, 0x38, 0x7A, 0x36, 0x71, 0x33, 0x76, 0x35, 0x71, 0x2F, 0x6C, 0x30, 0x78, 0x36, 0x7B, 0x39, 0x6B, 0x2C, 0x6F, 0x31, 0x6B, 0x2E, 0x5F, 0x29, 0x51, 0x29, 0x52, 0x2C, 0x50, 0x2A, 0x47, 0x25, 0x3D, 0x22, 0x41, 0x23, 0x3F, 0x22, 0x37, 0x1F, 0x42, 0x25, 0x43, 0x23, 0x48, 0x26, 0x47, 0x24, 0x3D, 0x22, 0x47, 0x25, 0x4B, 0x27, 0x40, 0x21, 0x43, 0x23, 0x49, 0x26, 0x49, 0x27, 0x44, 0x24, 0x47, 0x25, 0x43, 0x23, 0x44, 0x24, 0x48, 0x25, 0x4B, 0x26, 0x4A, 0x27, 0x45, 0x25, 0x4A, 0x27, 0x43, 0x24, 0x47, 0x26, 0x3B, 0x20, 0x3E, 0x21, 0x3D, 0x22, 0x3E, 0x20, 0x37, 0x1E, 0x46, 0x25, 0x3F, 0x23, 0x47, 0x25, 0x44, 0x24, 0x46, 0x25, 0x3F, 0x22, 0x40, 0x22, 0x3A, 0x20, 0x39, 0x1F, 0x36, 0x1D, 0x3E, 0x21, 0x41, 0x22, 0x46, 0x24, 0x41, 0x22
    },

    {
        0x6C, 0x64, 0x6D, 0x63, 0x6F, 0x63, 0x70, 0x64, 0x71, 0x63, 0x72, 0x62, 0x72, 0x61, 0x71, 0x61, 0x71, 0x62, 0x6C, 0x5D, 0x62, 0x56, 0x5E, 0x53, 0x5F, 0x54, 0x63, 0x57, 0x68, 0x5B, 0x6D, 0x5E, 0x70, 0x61, 0x71, 0x61, 0x73, 0x64, 0x76, 0x65, 0x72, 0x63, 0x76, 0x66, 0x76, 0x66, 0x73, 0x64, 0x74, 0x62, 0x74, 0x63, 0x76, 0x67, 0x7A, 0x69, 0x79, 0x67, 0x79, 0x66, 0x7A, 0x6A, 0x78, 0x69, 0x77, 0x66, 0x74, 0x66, 0x75, 0x65, 0x72, 0x65, 0x71, 0x63, 0x6D, 0x61, 0x6C, 0x61, 0x70, 0x65, 0x75, 0x66, 0x74, 0x66, 0x77, 0x6A, 0x7B, 0x6B, 0x7B, 0x6C, 0x7A, 0x69, 0x77, 0x68, 0x75, 0x64, 0x77, 0x68, 0x78, 0x66, 0x77, 0x65, 0x77, 0x65, 0x77, 0x67, 0x7A, 0x67, 0x75, 0x66, 0x77, 0x65, 0x75, 0x64, 0x79, 0x69, 0x78, 0x68, 0x76, 0x67, 0x76, 0x66, 0x77, 0x65, 0x77, 0x66, 0x7C, 0x68, 0x78, 0x67, 0x7C, 0x6C, 0x7F, 0x6C, 0x7E, 0x6D, 0x7D, 0x69, 0x7D, 0x6D, 0x7B, 0x6A, 0x7C, 0x6B, 0x7A, 0x69, 0x7F, 0x6C, 0x7D, 0x6D, 0x7F, 0x6F, 0x80, 0x70, 0x7D, 0x6E, 0x80, 0x6F, 0x7F, 0x6E, 0x7E, 0x6F, 0x7F, 0x70, 0x82, 0x75, 0x82, 0x70, 0x85, 0x77, 0x85, 0x75, 0x83, 0x74, 0x86, 0x74, 0x7F, 0x6D, 0x82, 0x71, 0x85, 0x75, 0x83, 0x70, 0x82, 0x71, 0x80, 0x71, 0x7F, 0x70, 0x82, 0x72, 0x81, 0x70, 0x84, 0x75, 0x87, 0x79, 0x8A, 0x78, 0x82, 0x73, 0x83, 0x74, 0x8A, 0x77, 0x86, 0x77, 0x89, 0x78, 0x87, 0x72, 0x86, 0x76, 0x87, 0x75, 0x86, 0x78, 0x86, 0x77, 0x86, 0x74, 0x8A, 0x7A, 0x84, 0x74, 0x84, 0x74, 0x85, 0x76, 0x85, 0x76, 0x83, 0x74, 0x69, 0x63, 0x60, 0x60, 0x5C, 0x5D, 0x59, 0x5D, 0x5A, 0x5C, 0x5A, 0x5D, 0x58, 0x56, 0x56, 0x53, 0x75, 0x6E, 0x84, 0x7B, 0x91, 0x85, 0x8F, 0x80, 0x8B, 0x7C, 0x8A, 0x7A, 0x8A, 0x77, 0x89, 0x79, 0x91, 0x7C, 0x8F, 0x7B, 0x87, 0x76, 0x86, 0x77, 0x8B, 0x79, 0x89, 0x79, 0x88, 0x7A, 0x91, 0x85, 0x90, 0x87, 0x91, 0x8B, 0x9D, 0x9D, 0xAB, 0xB6, 0xB1, 0xAF, 0xA0, 0x9D, 0x9A, 0x94, 0x95, 0x8F, 0x94, 0x8F, 0x93, 0x8D, 0x8F, 0x88, 0x96, 0x91, 0x9A, 0x96, 0x91, 0x8B, 0x92, 0x90, 0x98, 0x96, 0x97, 0x93, 0x8E, 0x8A, 0x9E, 0xA1, 0x95, 0x96, 0x9D, 0x9F, 0xAB, 0xB4, 0xA5, 0xA7, 0xA2, 0xAA, 0x83, 0x83, 0x5F, 0x63, 0x56, 0x61, 0x54, 0x5C, 0x41, 0x41, 0x39, 0x38, 0x35, 0x3E, 0x6E, 0x7F, 0x9A, 0xA2, 0x93, 0x8B, 0x8A, 0x82, 0x84, 0x79, 0x86, 0x77, 0x8A, 0x80, 0x8B, 0x83, 0x9A, 0x99, 0x86, 0x81, 0x8A, 0x88, 0x8C, 0x82, 0x8A, 0x7F, 0x7D, 0x6F, 0x7D, 0x72, 0x7E, 0x74, 0x7F, 0x75, 0x82, 0x76, 0x81, 0x78, 0x81, 0x74, 0x7A, 0x75, 0x81, 0x78, 0x89, 0x81, 0x7E, 0x6F, 0x76, 0x69, 0x77, 0x69, 0x77, 0x69, 0x78, 0x6B, 0x7B, 0x6C, 0x7D, 0x6D, 0x7B, 0x6C, 0x74, 0x66, 0x75, 0x68, 0x76, 0x67, 0x7B, 0x6B, 0x77, 0x68, 0x78, 0x6A, 0x7A, 0x6C, 0x7A, 0x6B, 0x76, 0x66, 0x74, 0x64, 0x73, 0x66, 0x72, 0x65, 0x79, 0x6D, 0x7C, 0x6C, 0x77, 0x68, 0x78, 0x69, 0x74, 0x67, 0x77, 0x6A, 0x7B, 0x6C, 0x78, 0x67, 0x7A, 0x69, 0x77, 0x66, 0x75, 0x68, 0x74, 0x66, 0x77, 0x68, 0x77, 0x67, 0x74, 0x64, 0x76, 0x67, 0x7B, 0x72, 0x7C, 0x72, 0x81, 0x79, 0x79, 0x6D, 0x7B, 0x6D, 0x78, 0x6C, 0x81, 0x7B, 0x7C, 0x70, 0x79, 0x6E, 0x79, 0x6D, 0x7D, 0x74, 0x83, 0x7A, 0x85, 0x82, 0x87, 0x7F, 0x8A, 0x81, 0x88, 0x81, 0x94, 0x92, 0x95, 0x9B, 0x99, 0x9D, 0x94, 0x8E, 0x92, 0x95, 0x94, 0x95, 0x89, 0x84, 0x82, 0x7B, 0x86, 0x80, 0x8A, 0x80, 0x8E, 0x8E, 0x95, 0x96, 0x8A, 0x82, 0x83, 0x7C, 0x7F, 0x79, 0x82, 0x7E, 0x7B, 0x71, 0x79, 0x73, 0x80, 0x7B, 0x81, 0x7F, 0x79, 0x6E, 0x7C, 0x75, 0x78, 0x6E, 0x67, 0x5F, 0x48, 0x4B, 0x48, 0x56, 0x44, 0x4D, 0x3D, 0x43, 0x38, 0x40, 0x39, 0x41, 0x38, 0x3E, 0x35, 0x3B, 0x3F, 0x4B, 0x3D, 0x47, 0x43, 0x4D, 0x43, 0x48, 0x3A, 0x42, 0x41, 0x4C, 0x44, 0x4E, 0x3C, 0x42, 0x40, 0x48, 0x44, 0x4D, 0x43, 0x4B, 0x3E, 0x46, 0x42, 0x4A, 0x3E, 0x47, 0x3D, 0x46, 0x42, 0x4C, 0x43, 0x49, 0x43, 0x4E, 0x3A, 0x42, 0x42, 0x4B, 0x3C, 0x43, 0x3F, 0x44, 0x35, 0x39, 0x39, 0x40, 0x3A, 0x43, 0x3A, 0x3E, 0x36, 0x3D, 0x40, 0x48, 0x3D, 0x47, 0x43, 0x49, 0x3F, 0x4A, 0x3D, 0x44, 0x39, 0x40, 0x39, 0x40, 0x36, 0x3C, 0x36, 0x3B, 0x35, 0x3C, 0x3D, 0x45, 0x3E, 0x47, 0x40, 0x49, 0x3C, 0x45
    },

    {
        0x6B, 0x2C, 0x61, 0x26, 0x61, 0x25, 0x61, 0x24, 0x60, 0x23, 0x60, 0x22, 0x5F, 0x21, 0x5F, 0x22, 0x60, 0x22, 0x5D, 0x21, 0x5A, 0x20, 0x5B, 0x20, 0x5D, 0x20, 0x5D, 0x20, 0x5D, 0x21, 0x5F, 0x22, 0x5E, 0x22, 0x60, 0x22, 0x63, 0x24, 0x63, 0x23, 0x60, 0x23, 0x63, 0x24, 0x65, 0x25, 0x62, 0x23, 0x60, 0x23, 0x63, 0x23, 0x64, 0x24, 0x63, 0x24, 0x62, 0x23, 0x64, 0x24, 0x64, 0x24, 0x64, 0x24, 0x64, 0x24, 0x62, 0x23, 0x61, 0x24, 0x5F, 0x25, 0x59, 0x26, 0x55, 0x25, 0x53, 0x25, 0x57, 0x25, 0x5B, 0x25, 0x61, 0x26, 0x65, 0x26, 0x63, 0x25, 0x68, 0x27, 0x66, 0x26, 0x65, 0x26, 0x66, 0x26, 0x67, 0x25, 0x63, 0x24, 0x63, 0x25, 0x63, 0x24, 0x66, 0x24, 0x64, 0x25, 0x62, 0x24, 0x62, 0x24, 0x63, 0x24, 0x64, 0x26, 0x67, 0x26, 0x64, 0x25, 0x65, 0x25, 0x63, 0x24, 0x67, 0x26, 0x68, 0x26, 0x66, 0x25, 0x68, 0x25, 0x66, 0x25, 0x65, 0x24, 0x67, 0x25, 0x69, 0x26, 0x66, 0x25, 0x67, 0x26, 0x66, 0x25, 0x66, 0x26, 0x69, 0x27, 0x69, 0x28, 0x6C, 0x28, 0x6B, 0x28, 0x6B, 0x28, 0x6D, 0x2A, 0x6D, 0x28, 0x68, 0x28, 0x68, 0x28, 0x6B, 0x29, 0x6C, 0x29, 0x6D, 0x29, 0x70, 0x2A, 0x6B, 0x28, 0x6A, 0x28, 0x6C, 0x28, 0x6C, 0x2A, 0x6D, 0x29, 0x73, 0x2D, 0x6D, 0x2B, 0x6B, 0x29, 0x71, 0x2A, 0x6F, 0x2A, 0x6E, 0x2C, 0x76, 0x30, 0x78, 0x2E, 0x6E, 0x29, 0x6E, 0x2A, 0x73, 0x2C, 0x72, 0x2E, 0x72, 0x2A, 0x7B, 0x30, 0x73, 0x2C, 0x73, 0x2B, 0x71, 0x2B, 0x78, 0x2E, 0x75, 0x2B, 0x73, 0x2B, 0x6E, 0x29, 0x72, 0x29, 0x72, 0x2C, 0x75, 0x2D, 0x6F, 0x29, 0x5C, 0x2A, 0x5D, 0x2D, 0x5C, 0x2D, 0x5A, 0x2D, 0x5D, 0x2E, 0x5A, 0x2D, 0x56, 0x29, 0x43, 0x20, 0x61, 0x2A, 0x78, 0x2E, 0x7D, 0x2F, 0x7A, 0x2E, 0x75, 0x2D, 0x77, 0x2C, 0x72, 0x2B, 0x74, 0x2B, 0x79, 0x2D, 0x75, 0x2B, 0x76, 0x2D, 0x77, 0x2C, 0x79, 0x2E, 0x79, 0x31, 0x84, 0x39, 0x85, 0x3B, 0x95, 0x45, 0x93, 0x47, 0xAD, 0x51, 0x94, 0x47, 0xA4, 0x4F, 0xBC, 0x59, 0x94, 0x42, 0x95, 0x44, 0x99, 0x44, 0x79, 0x33, 0x74, 0x32, 0x84, 0x3B, 0x86, 0x3B, 0x8B, 0x3F, 0x94, 0x46, 0x8C, 0x3F, 0x97, 0x48, 0x99, 0x45, 0x9A, 0x48, 0xA0, 0x50, 0xAB, 0x57, 0xAC, 0x56, 0xA9, 0x56, 0xA8, 0x51, 0x8C, 0x44, 0x4F, 0x2E, 0x57, 0x34, 0x50, 0x2F, 0x47, 0x2A, 0x42, 0x28, 0x41, 0x29, 0x88, 0x43, 0x8E, 0x43, 0x89, 0x3F, 0x8C, 0x42, 0x7A, 0x31, 0x75, 0x33, 0x85, 0x3B, 0x78, 0x37, 0x8B, 0x42, 0x82, 0x36, 0x85, 0x3A, 0x7A, 0x34, 0x85, 0x39, 0x75, 0x2D, 0x6A, 0x2C, 0x71, 0x2E, 0x6D, 0x2E, 0x6D, 0x2B, 0x6B, 0x2A, 0x68, 0x29, 0x72, 0x32, 0x6D, 0x2B, 0x6A, 0x2C, 0x6E, 0x2B, 0x70, 0x2D, 0x66, 0x26, 0x67, 0x25, 0x65, 0x26, 0x65, 0x25, 0x67, 0x27, 0x66, 0x27, 0x66, 0x26, 0x61, 0x26, 0x65, 0x25, 0x6A, 0x29, 0x67, 0x27, 0x66, 0x27, 0x62, 0x25, 0x64, 0x25, 0x62, 0x26, 0x63, 0x24, 0x63, 0x26, 0x62, 0x26, 0x66, 0x27, 0x6D, 0x2A, 0x68, 0x27, 0x66, 0x27, 0x67, 0x28, 0x67, 0x26, 0x67, 0x26, 0x62, 0x24, 0x60, 0x23, 0x62, 0x23, 0x61, 0x26, 0x6A, 0x28, 0x65, 0x25, 0x62, 0x24, 0x61, 0x24, 0x63, 0x27, 0x67, 0x29, 0x69, 0x28, 0x6D, 0x2C, 0x71, 0x2E, 0x69, 0x29, 0x6C, 0x2D, 0x79, 0x36, 0x6B, 0x2B, 0x66, 0x28, 0x6B, 0x2D, 0x6C, 0x2B, 0x72, 0x2E, 0x76, 0x35, 0x7D, 0x38, 0x89, 0x40, 0x85, 0x3D, 0x82, 0x3C, 0xA7, 0x5A, 0x9B, 0x4B, 0x8E, 0x46, 0x9D, 0x4A, 0x84, 0x3C, 0x7F, 0x3A, 0x7C, 0x39, 0x7C, 0x35, 0x7D, 0x38, 0x89, 0x42, 0x89, 0x40, 0x86, 0x3F, 0x79, 0x35, 0x79, 0x35, 0x76, 0x37, 0x73, 0x31, 0x72, 0x31, 0x6C, 0x2E, 0x6F, 0x31, 0x6B, 0x2D, 0x6D, 0x30, 0x6D, 0x2E, 0x55, 0x26, 0x3F, 0x22, 0x46, 0x26, 0x41, 0x23, 0x3B, 0x1F, 0x3C, 0x21, 0x41, 0x23, 0x4B, 0x27, 0x4C, 0x28, 0x50, 0x2B, 0x4F, 0x29, 0x4C, 0x27, 0x46, 0x25, 0x49, 0x28, 0x52, 0x29, 0x49, 0x26, 0x45, 0x24, 0x42, 0x24, 0x44, 0x24, 0x3C, 0x21, 0x45, 0x24, 0x41, 0x22, 0x40, 0x22, 0x3D, 0x21, 0x46, 0x25, 0x3F, 0x21, 0x3D, 0x21, 0x38, 0x1E, 0x42, 0x22, 0x42, 0x24, 0x3D, 0x20, 0x3B, 0x20, 0x48, 0x26, 0x4F, 0x2A, 0x48, 0x26, 0x41, 0x23, 0x50, 0x29, 0x48, 0x26, 0x3D, 0x22, 0x46, 0x25, 0x3C, 0x20, 0x3D, 0x22, 0x3F, 0x21, 0x47, 0x25, 0x48, 0x25, 0x4B, 0x27, 0x4A, 0x26, 0x43, 0x23, 0x44, 0x24, 0x41, 0x23
    },

    {
        0x75, 0x6E, 0x6C, 0x63, 0x70, 0x65, 0x73, 0x64, 0x72, 0x64, 0x71, 0x63, 0x72, 0x61, 0x72, 0x62, 0x70, 0x61, 0x6F, 0x5F, 0x6D, 0x5C, 0x6E, 0x60, 0x6F, 0x60, 0x6E, 0x5F, 0x6E, 0x60, 0x71, 0x62, 0x70, 0x61, 0x71, 0x63, 0x75, 0x66, 0x76, 0x64, 0x76, 0x66, 0x76, 0x67, 0x77, 0x6A, 0x76, 0x65, 0x75, 0x65, 0x76, 0x64, 0x76, 0x64, 0x78, 0x66, 0x77, 0x65, 0x77, 0x67, 0x76, 0x65, 0x75, 0x65, 0x77, 0x65, 0x75, 0x64, 0x73, 0x64, 0x6C, 0x61, 0x5D, 0x55, 0x56, 0x53, 0x57, 0x54, 0x5B, 0x56, 0x63, 0x5D, 0x6D, 0x64, 0x71, 0x64, 0x74, 0x66, 0x79, 0x6A, 0x7B, 0x6B, 0x7A, 0x67, 0x78, 0x6A, 0x78, 0x69, 0x78, 0x66, 0x76, 0x66, 0x76, 0x68, 0x77, 0x67, 0x7A, 0x69, 0x76, 0x66, 0x78, 0x66, 0x76, 0x68, 0x77, 0x67, 0x79, 0x68, 0x79, 0x69, 0x79, 0x6A, 0x7B, 0x69, 0x79, 0x69, 0x7C, 0x6C, 0x7A, 0x6A, 0x7B, 0x6B, 0x7A, 0x6A, 0x7A, 0x68, 0x7B, 0x6A, 0x7E, 0x6D, 0x7A, 0x6B, 0x7A, 0x6B, 0x7B, 0x6A, 0x7D, 0x6B, 0x7F, 0x6E, 0x7D, 0x6D, 0x7F, 0x6F, 0x7E, 0x6F, 0x7D, 0x6E, 0x81, 0x74, 0x81, 0x6F, 0x79, 0x6C, 0x7A, 0x6C, 0x7E, 0x71, 0x82, 0x70, 0x82, 0x70, 0x82, 0x71, 0x82, 0x6E, 0x81, 0x6F, 0x81, 0x70, 0x81, 0x70, 0x80, 0x70, 0x83, 0x75, 0x7F, 0x70, 0x80, 0x73, 0x84, 0x74, 0x80, 0x70, 0x7F, 0x73, 0x85, 0x79, 0x87, 0x79, 0x83, 0x71, 0x81, 0x74, 0x87, 0x79, 0x85, 0x77, 0x84, 0x73, 0x8B, 0x80, 0x86, 0x75, 0x87, 0x76, 0x87, 0x77, 0x8C, 0x7C, 0x87, 0x7A, 0x87, 0x76, 0x85, 0x75, 0x8A, 0x76, 0x86, 0x79, 0x88, 0x79, 0x7F, 0x6E, 0x66, 0x5F, 0x60, 0x60, 0x5C, 0x5F, 0x5B, 0x5E, 0x5A, 0x5C, 0x59, 0x5F, 0x53, 0x55, 0x47, 0x45, 0x6E, 0x69, 0x88, 0x7C, 0x91, 0x81, 0x90, 0x80, 0x8C, 0x7D, 0x8B, 0x7A, 0x86, 0x77, 0x8B, 0x78, 0x8E, 0x7B, 0x88, 0x78, 0x8C, 0x7C, 0x8E, 0x7E, 0x8F, 0x7D, 0x8B, 0x7F, 0x90, 0x8B, 0x92, 0x8B, 0xA0, 0xA1, 0xA1, 0xA8, 0xAC, 0xAC, 0xA1, 0xA2, 0xAE, 0xB5, 0xBA, 0xC0, 0xA1, 0x9E, 0x9A, 0x9A, 0xA0, 0x9E, 0x8A, 0x7F, 0x88, 0x7F, 0x91, 0x8E, 0x93, 0x8E, 0x97, 0x92, 0x9F, 0xA1, 0x97, 0x8D, 0x9A, 0x9C, 0x9F, 0x9B, 0x9D, 0x9B, 0xA4, 0xA5, 0xA8, 0xB1, 0xA2, 0xA2, 0xA5, 0xAE, 0xA2, 0xA2, 0x8C, 0x86, 0x51, 0x4E, 0x49, 0x4D, 0x45, 0x48, 0x42, 0x4A, 0x40, 0x4A, 0x46, 0x52, 0x88, 0x8B, 0x91, 0x8E, 0x8F, 0x8C, 0x97, 0x96, 0x89, 0x7B, 0x84, 0x7B, 0x8A, 0x84, 0x88, 0x86, 0x92, 0x93, 0x8B, 0x81, 0x8D, 0x8A, 0x88, 0x7E, 0x91, 0x8B, 0x85, 0x78, 0x78, 0x6E, 0x80, 0x75, 0x7F, 0x75, 0x7F, 0x73, 0x7A, 0x6D, 0x78, 0x6C, 0x7D, 0x76, 0x7D, 0x6F, 0x7C, 0x6D, 0x7D, 0x73, 0x80, 0x76, 0x78, 0x69, 0x7A, 0x6C, 0x78, 0x69, 0x78, 0x69, 0x79, 0x6C, 0x76, 0x68, 0x77, 0x68, 0x72, 0x66, 0x77, 0x6A, 0x7A, 0x6D, 0x79, 0x6A, 0x79, 0x6C, 0x76, 0x68, 0x78, 0x67, 0x74, 0x65, 0x72, 0x63, 0x75, 0x68, 0x74, 0x68, 0x77, 0x6B, 0x7B, 0x6F, 0x7A, 0x6C, 0x78, 0x6B, 0x79, 0x6F, 0x78, 0x69, 0x7B, 0x6C, 0x77, 0x67, 0x73, 0x64, 0x76, 0x65, 0x71, 0x65, 0x7A, 0x70, 0x77, 0x67, 0x76, 0x66, 0x74, 0x65, 0x78, 0x6A, 0x79, 0x6F, 0x7B, 0x6F, 0x7B, 0x6E, 0x7E, 0x72, 0x79, 0x6A, 0x7A, 0x73, 0x84, 0x81, 0x78, 0x6B, 0x76, 0x6A, 0x7B, 0x73, 0x7C, 0x71, 0x84, 0x76, 0x82, 0x7B, 0x8D, 0x8C, 0x90, 0x8E, 0x8C, 0x8A, 0x8B, 0x88, 0xA2, 0xAC, 0x9D, 0x9B, 0x94, 0x96, 0x9C, 0x9C, 0x8A, 0x84, 0x83, 0x80, 0x86, 0x83, 0x86, 0x7F, 0x86, 0x83, 0x8F, 0x90, 0x8D, 0x8B, 0x8F, 0x8B, 0x86, 0x7D, 0x82, 0x7A, 0x83, 0x7E, 0x81, 0x77, 0x80, 0x7A, 0x77, 0x6C, 0x78, 0x72, 0x77, 0x71, 0x78, 0x74, 0x78, 0x6E, 0x5C, 0x52, 0x3F, 0x41, 0x41, 0x4B, 0x3B, 0x42, 0x38, 0x3E, 0x3A, 0x43, 0x3F, 0x4A, 0x47, 0x4F, 0x46, 0x50, 0x46, 0x54, 0x46, 0x4F, 0x44, 0x4B, 0x40, 0x47, 0x43, 0x50, 0x46, 0x4F, 0x40, 0x48, 0x40, 0x48, 0x3C, 0x43, 0x3C, 0x3F, 0x3A, 0x42, 0x42, 0x49, 0x3B, 0x42, 0x3A, 0x40, 0x38, 0x41, 0x3F, 0x45, 0x3A, 0x41, 0x36, 0x3C, 0x36, 0x3D, 0x3F, 0x45, 0x40, 0x49, 0x3B, 0x41, 0x3A, 0x41, 0x47, 0x52, 0x48, 0x50, 0x42, 0x4A, 0x3E, 0x47, 0x49, 0x51, 0x40, 0x45, 0x37, 0x3F, 0x3F, 0x46, 0x37, 0x3C, 0x3A, 0x43, 0x3C, 0x43, 0x41, 0x4C, 0x42, 0x4B, 0x44, 0x4B, 0x43, 0x4A, 0x3B, 0x42, 0x3B, 0x42, 0x3A, 0x44
    },

    {
        0x9C, 0x44, 0x69, 0x2A, 0x62, 0x27, 0x61, 0x24, 0x5F, 0x22, 0x60, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x5E, 0x21, 0x5D, 0x21, 0x60, 0x21, 0x62, 0x22, 0x61, 0x21, 0x60, 0x22, 0x61, 0x22, 0x5E, 0x22, 0x61, 0x22, 0x60, 0x22, 0x61, 0x23, 0x64, 0x23, 0x65, 0x24, 0x64, 0x25, 0x65, 0x24, 0x62, 0x23, 0x62, 0x23, 0x65, 0x23, 0x61, 0x23, 0x64, 0x23, 0x62, 0x22, 0x64, 0x23, 0x61, 0x23, 0x63, 0x25, 0x66, 0x24, 0x64, 0x25, 0x62, 0x26, 0x54, 0x26, 0x51, 0x26, 0x4E, 0x26, 0x50, 0x26, 0x4F, 0x26, 0x52, 0x25, 0x59, 0x24, 0x5E, 0x24, 0x60, 0x24, 0x64, 0x25, 0x65, 0x24, 0x65, 0x25, 0x62, 0x24, 0x67, 0x25, 0x64, 0x25, 0x66, 0x25, 0x64, 0x24, 0x63, 0x24, 0x66, 0x25, 0x61, 0x23, 0x64, 0x25, 0x67, 0x25, 0x65, 0x25, 0x68, 0x26, 0x68, 0x27, 0x6A, 0x26, 0x67, 0x26, 0x67, 0x27, 0x67, 0x25, 0x63, 0x25, 0x64, 0x24, 0x67, 0x26, 0x63, 0x24, 0x64, 0x25, 0x66, 0x26, 0x64, 0x26, 0x67, 0x26, 0x66, 0x26, 0x6C, 0x27, 0x6B, 0x28, 0x6C, 0x2A, 0x6E, 0x29, 0x6F, 0x2B, 0x71, 0x2B, 0x70, 0x2B, 0x6D, 0x28, 0x6A, 0x28, 0x6E, 0x2A, 0x6E, 0x29, 0x6D, 0x29, 0x6B, 0x28, 0x6C, 0x28, 0x6D, 0x28, 0x6A, 0x27, 0x6A, 0x28, 0x6C, 0x29, 0x70, 0x2B, 0x6F, 0x2A, 0x70, 0x2A, 0x70, 0x29, 0x6D, 0x29, 0x6D, 0x28, 0x6A, 0x29, 0x70, 0x2C, 0x73, 0x2C, 0x70, 0x2B, 0x72, 0x2B, 0x71, 0x2A, 0x71, 0x2A, 0x6F, 0x2A, 0x73, 0x2C, 0x72, 0x2B, 0x75, 0x2C, 0x70, 0x2A, 0x73, 0x2C, 0x72, 0x2A, 0x6F, 0x2A, 0x75, 0x2B, 0x72, 0x2A, 0x73, 0x2B, 0x76, 0x2C, 0x6C, 0x28, 0x60, 0x2A, 0x5A, 0x2C, 0x5B, 0x2D, 0x5B, 0x2D, 0x5B, 0x2D, 0x5B, 0x2E, 0x52, 0x25, 0x3C, 0x1E, 0x5F, 0x27, 0x73, 0x2C, 0x79, 0x2E, 0x7B, 0x2F, 0x7E, 0x30, 0x7A, 0x2C, 0x71, 0x2C, 0x77, 0x2D, 0x76, 0x2E, 0x77, 0x2E, 0x76, 0x2E, 0x7A, 0x30, 0x7B, 0x31, 0x7A, 0x34, 0x8C, 0x3E, 0x92, 0x41, 0xAC, 0x58, 0xA5, 0x4F, 0x9D, 0x4D, 0xA5, 0x52, 0xAC, 0x58, 0xAD, 0x57, 0xB9, 0x5B, 0x8D, 0x3E, 0x9E, 0x4C, 0xAA, 0x4F, 0x96, 0x48, 0x9A, 0x48, 0x9D, 0x4C, 0x9F, 0x4A, 0x92, 0x45, 0x9D, 0x49, 0xA4, 0x4F, 0xA1, 0x54, 0xAB, 0x50, 0x9C, 0x48, 0x90, 0x44, 0x92, 0x43, 0x9F, 0x4F, 0xAC, 0x53, 0x9D, 0x46, 0x73, 0x39, 0x4B, 0x2A, 0x43, 0x2A, 0x49, 0x2E, 0x62, 0x3D, 0x71, 0x39, 0x7C, 0x3A, 0x90, 0x47, 0x93, 0x48, 0x91, 0x46, 0x83, 0x35, 0x7A, 0x35, 0x7C, 0x38, 0x90, 0x47, 0x9C, 0x45, 0x7A, 0x33, 0x83, 0x3F, 0x81, 0x36, 0x89, 0x3F, 0x80, 0x37, 0x74, 0x2F, 0x6D, 0x2B, 0x6F, 0x30, 0x7B, 0x34, 0x75, 0x2D, 0x69, 0x28, 0x67, 0x2A, 0x64, 0x27, 0x6F, 0x2D, 0x72, 0x2E, 0x71, 0x2E, 0x66, 0x26, 0x68, 0x27, 0x63, 0x25, 0x62, 0x25, 0x69, 0x29, 0x66, 0x26, 0x61, 0x25, 0x64, 0x25, 0x64, 0x26, 0x68, 0x27, 0x62, 0x25, 0x68, 0x28, 0x64, 0x25, 0x62, 0x25, 0x63, 0x25, 0x61, 0x24, 0x62, 0x26, 0x65, 0x27, 0x66, 0x26, 0x67, 0x26, 0x69, 0x28, 0x64, 0x25, 0x65, 0x27, 0x66, 0x26, 0x65, 0x26, 0x64, 0x25, 0x60, 0x24, 0x63, 0x25, 0x5F, 0x24, 0x68, 0x29, 0x66, 0x26, 0x61, 0x24, 0x60, 0x24, 0x64, 0x26, 0x69, 0x2A, 0x69, 0x29, 0x67, 0x28, 0x6B, 0x2B, 0x69, 0x27, 0x69, 0x2A, 0x71, 0x2E, 0x67, 0x28, 0x67, 0x2A, 0x6C, 0x2A, 0x6B, 0x2B, 0x73, 0x30, 0x79, 0x39, 0x94, 0x47, 0x8F, 0x44, 0x91, 0x42, 0x7D, 0x37, 0x80, 0x3B, 0x91, 0x45, 0x86, 0x3E, 0x84, 0x3F, 0x79, 0x35, 0x6E, 0x2E, 0x7C, 0x38, 0x72, 0x31, 0x74, 0x36, 0x83, 0x40, 0x81, 0x3C, 0x79, 0x35, 0x77, 0x36, 0x72, 0x31, 0x7A, 0x3A, 0x79, 0x35, 0x7A, 0x36, 0x6C, 0x2E, 0x6C, 0x2F, 0x6A, 0x2D, 0x69, 0x2D, 0x70, 0x2E, 0x5A, 0x26, 0x4C, 0x26, 0x4C, 0x27, 0x48, 0x26, 0x4C, 0x26, 0x4A, 0x27, 0x51, 0x29, 0x53, 0x2A, 0x49, 0x26, 0x45, 0x24, 0x3E, 0x23, 0x45, 0x25, 0x40, 0x22, 0x43, 0x23, 0x3B, 0x1F, 0x3A, 0x1F, 0x41, 0x23, 0x40, 0x22, 0x39, 0x1E, 0x3F, 0x23, 0x47, 0x24, 0x39, 0x1F, 0x3D, 0x20, 0x39, 0x20, 0x41, 0x23, 0x46, 0x24, 0x3F, 0x22, 0x43, 0x23, 0x53, 0x2B, 0x43, 0x24, 0x47, 0x26, 0x41, 0x24, 0x56, 0x2D, 0x41, 0x23, 0x43, 0x24, 0x3C, 0x21, 0x40, 0x22, 0x3D, 0x22, 0x41, 0x24, 0x4C, 0x28, 0x42, 0x23, 0x44, 0x25, 0x4B, 0x27, 0x42, 0x22, 0x40, 0x22, 0x3B, 0x21, 0x3A, 0x1F, 0x36, 0x1F, 0x3C, 0x21, 0x42, 0x25
    },

    {
        0xA1, 0x9D, 0x74, 0x6A, 0x6B, 0x64, 0x6E, 0x62, 0x6E, 0x62, 0x72, 0x64, 0x71, 0x61, 0x6E, 0x60, 0x6F, 0x60, 0x70, 0x60, 0x72, 0x63, 0x75, 0x65, 0x74, 0x63, 0x72, 0x63, 0x71, 0x61, 0x71, 0x61, 0x73, 0x63, 0x75, 0x62, 0x76, 0x65, 0x77, 0x68, 0x77, 0x66, 0x77, 0x67, 0x78, 0x66, 0x78, 0x65, 0x75, 0x64, 0x77, 0x65, 0x74, 0x64, 0x78, 0x66, 0x77, 0x64, 0x77, 0x66, 0x74, 0x65, 0x73, 0x67, 0x77, 0x66, 0x76, 0x67, 0x71, 0x62, 0x5C, 0x56, 0x54, 0x51, 0x51, 0x50, 0x52, 0x51, 0x53, 0x52, 0x56, 0x55, 0x5D, 0x57, 0x6A, 0x60, 0x73, 0x63, 0x75, 0x67, 0x77, 0x67, 0x7A, 0x68, 0x77, 0x66, 0x79, 0x68, 0x78, 0x68, 0x7B, 0x69, 0x76, 0x65, 0x78, 0x66, 0x78, 0x68, 0x77, 0x64, 0x7A, 0x69, 0x7C, 0x6B, 0x78, 0x69, 0x7C, 0x6B, 0x7D, 0x6D, 0x7F, 0x6C, 0x7E, 0x6C, 0x7D, 0x6C, 0x79, 0x68, 0x78, 0x67, 0x7A, 0x68, 0x7C, 0x6B, 0x78, 0x65, 0x76, 0x66, 0x7A, 0x6B, 0x79, 0x69, 0x7B, 0x6B, 0x7B, 0x69, 0x80, 0x6E, 0x80, 0x70, 0x7E, 0x73, 0x82, 0x71, 0x7E, 0x72, 0x82, 0x75, 0x82, 0x73, 0x81, 0x6F, 0x7D, 0x6F, 0x81, 0x71, 0x82, 0x73, 0x83, 0x71, 0x81, 0x70, 0x83, 0x70, 0x81, 0x70, 0x7D, 0x6B, 0x80, 0x6F, 0x81, 0x71, 0x83, 0x75, 0x80, 0x72, 0x82, 0x74, 0x81, 0x72, 0x80, 0x71, 0x80, 0x6E, 0x7F, 0x6F, 0x84, 0x73, 0x84, 0x77, 0x83, 0x75, 0x84, 0x73, 0x83, 0x74, 0x86, 0x77, 0x82, 0x72, 0x86, 0x77, 0x86, 0x78, 0x87, 0x78, 0x85, 0x74, 0x8A, 0x77, 0x87, 0x74, 0x84, 0x76, 0x8A, 0x78, 0x88, 0x78, 0x8A, 0x79, 0x8B, 0x79, 0x7E, 0x70, 0x6C, 0x62, 0x5D, 0x5E, 0x5C, 0x5E, 0x57, 0x5B, 0x5A, 0x5C, 0x59, 0x5E, 0x4E, 0x4A, 0x41, 0x43, 0x69, 0x67, 0x86, 0x79, 0x8B, 0x7D, 0x90, 0x80, 0x92, 0x82, 0x8F, 0x79, 0x88, 0x7B, 0x8D, 0x7B, 0x8B, 0x7C, 0x8A, 0x7D, 0x8A, 0x7B, 0x91, 0x82, 0x8E, 0x81, 0x8E, 0x83, 0x99, 0x9B, 0x9D, 0x9B, 0xAE, 0xB2, 0xA2, 0x9F, 0x9E, 0x9D, 0xA5, 0xA7, 0xA8, 0xA8, 0xB0, 0xB4, 0xB0, 0xB7, 0x99, 0x8D, 0x9D, 0xA0, 0xAD, 0xB2, 0xA0, 0x9F, 0x9F, 0x99, 0x9B, 0xA4, 0x9D, 0x9E, 0x95, 0x94, 0xA3, 0xA3, 0xA5, 0xA8, 0xA6, 0xB1, 0xB3, 0xB2, 0xA2, 0x9E, 0x95, 0x92, 0x99, 0x96, 0x9E, 0xA0, 0xAC, 0xB2, 0xA0, 0x9E, 0x7F, 0x7A, 0x4D, 0x49, 0x40, 0x49, 0x48, 0x53, 0x5E, 0x70, 0x7B, 0x82, 0x88, 0x84, 0x96, 0x96, 0x9D, 0x9A, 0x96, 0x94, 0x8F, 0x81, 0x86, 0x7F, 0x8A, 0x87, 0x95, 0x9D, 0x9D, 0x98, 0x89, 0x7D, 0x8D, 0x8A, 0x8D, 0x81, 0x8E, 0x91, 0x8B, 0x80, 0x84, 0x7A, 0x7F, 0x71, 0x7F, 0x74, 0x89, 0x81, 0x83, 0x78, 0x7D, 0x6F, 0x7A, 0x6D, 0x76, 0x67, 0x7F, 0x74, 0x82, 0x75, 0x7C, 0x71, 0x77, 0x6A, 0x7A, 0x6C, 0x77, 0x68, 0x76, 0x66, 0x7C, 0x70, 0x78, 0x69, 0x73, 0x63, 0x74, 0x68, 0x76, 0x69, 0x7A, 0x6B, 0x72, 0x66, 0x79, 0x6B, 0x76, 0x69, 0x73, 0x66, 0x74, 0x66, 0x75, 0x64, 0x74, 0x68, 0x72, 0x68, 0x78, 0x6A, 0x79, 0x6A, 0x7C, 0x6F, 0x78, 0x69, 0x76, 0x67, 0x77, 0x68, 0x78, 0x69, 0x75, 0x66, 0x75, 0x64, 0x74, 0x66, 0x70, 0x66, 0x79, 0x6D, 0x77, 0x67, 0x75, 0x66, 0x74, 0x64, 0x76, 0x6B, 0x77, 0x6C, 0x7D, 0x6C, 0x7A, 0x6B, 0x7C, 0x73, 0x7D, 0x6C, 0x77, 0x6C, 0x7C, 0x73, 0x78, 0x6B, 0x78, 0x72, 0x7E, 0x70, 0x7D, 0x72, 0x83, 0x7B, 0x89, 0x8A, 0x96, 0x8F, 0x92, 0x96, 0x96, 0x93, 0x8D, 0x83, 0x8D, 0x86, 0x93, 0x90, 0x8D, 0x89, 0x87, 0x84, 0x83, 0x7B, 0x7D, 0x72, 0x86, 0x81, 0x7D, 0x77, 0x7D, 0x7A, 0x83, 0x82, 0x82, 0x80, 0x80, 0x79, 0x82, 0x7F, 0x7D, 0x74, 0x87, 0x84, 0x84, 0x7E, 0x82, 0x7D, 0x78, 0x6F, 0x77, 0x71, 0x75, 0x6E, 0x73, 0x6C, 0x7F, 0x74, 0x63, 0x59, 0x4B, 0x52, 0x45, 0x4C, 0x43, 0x4E, 0x48, 0x50, 0x43, 0x4F, 0x4B, 0x56, 0x48, 0x50, 0x3E, 0x46, 0x3D, 0x45, 0x37, 0x40, 0x3F, 0x46, 0x3A, 0x43, 0x3B, 0x42, 0x36, 0x3A, 0x37, 0x3F, 0x3B, 0x45, 0x3D, 0x43, 0x37, 0x3B, 0x3A, 0x44, 0x40, 0x46, 0x37, 0x3F, 0x3A, 0x3E, 0x36, 0x3F, 0x40, 0x46, 0x41, 0x47, 0x3E, 0x47, 0x3E, 0x48, 0x4C, 0x55, 0x3C, 0x42, 0x40, 0x49, 0x3E, 0x48, 0x4B, 0x53, 0x39, 0x3E, 0x3B, 0x41, 0x39, 0x3F, 0x3A, 0x40, 0x3A, 0x42, 0x3E, 0x46, 0x48, 0x50, 0x3D, 0x42, 0x40, 0x4B, 0x44, 0x4A, 0x3A, 0x3F, 0x39, 0x3F, 0x37, 0x3E, 0x34, 0x39, 0x33, 0x39, 0x37, 0x40, 0x3E, 0x45
    },

    {
        0x96, 0x4C, 0x8A, 0x3B, 0x67, 0x2A, 0x5E, 0x25, 0x5E, 0x24, 0x5F, 0x23, 0x5E, 0x22, 0x5E, 0x22, 0x5E, 0x21, 0x5F, 0x22, 0x61, 0x22, 0x5E, 0x21, 0x60, 0x22, 0x61, 0x23, 0x61, 0x22, 0x62, 0x23, 0x63, 0x23, 0x61, 0x23, 0x64, 0x23, 0x62, 0x23, 0x62, 0x23, 0x62, 0x23, 0x64, 0x24, 0x60, 0x22, 0x62, 0x23, 0x63, 0x23, 0x61, 0x22, 0x63, 0x24, 0x63, 0x24, 0x64, 0x25, 0x62, 0x24, 0x64, 0x25, 0x63, 0x24, 0x64, 0x25, 0x5A, 0x26, 0x52, 0x26, 0x4E, 0x26, 0x4D, 0x26, 0x4F, 0x27, 0x4D, 0x26, 0x4C, 0x23, 0x47, 0x1F, 0x52, 0x21, 0x5D, 0x24, 0x62, 0x24, 0x61, 0x23, 0x60, 0x24, 0x64, 0x24, 0x65, 0x25, 0x66, 0x26, 0x65, 0x25, 0x61, 0x24, 0x66, 0x26, 0x69, 0x27, 0x65, 0x25, 0x67, 0x25, 0x67, 0x26, 0x69, 0x28, 0x6A, 0x28, 0x6A, 0x27, 0x69, 0x27, 0x68, 0x27, 0x67, 0x26, 0x65, 0x25, 0x66, 0x25, 0x66, 0x25, 0x66, 0x26, 0x66, 0x25, 0x64, 0x25, 0x67, 0x26, 0x69, 0x26, 0x67, 0x26, 0x67, 0x26, 0x68, 0x28, 0x6F, 0x2A, 0x6F, 0x2B, 0x70, 0x2B, 0x6D, 0x29, 0x6F, 0x29, 0x6D, 0x29, 0x6B, 0x29, 0x6B, 0x29, 0x6D, 0x2A, 0x6C, 0x29, 0x69, 0x28, 0x6C, 0x28, 0x6C, 0x29, 0x6D, 0x27, 0x6C, 0x28, 0x69, 0x27, 0x6D, 0x28, 0x6F, 0x2A, 0x6F, 0x2B, 0x6E, 0x2B, 0x68, 0x29, 0x6B, 0x28, 0x6A, 0x2A, 0x6F, 0x2C, 0x72, 0x2B, 0x71, 0x2D, 0x6F, 0x2C, 0x70, 0x2B, 0x74, 0x2B, 0x72, 0x2A, 0x6F, 0x29, 0x6F, 0x2A, 0x73, 0x2B, 0x73, 0x2B, 0x6F, 0x2B, 0x76, 0x2D, 0x71, 0x2A, 0x71, 0x2A, 0x70, 0x29, 0x6F, 0x2B, 0x73, 0x2B, 0x73, 0x2A, 0x71, 0x2A, 0x68, 0x2A, 0x56, 0x2A, 0x5B, 0x2B, 0x56, 0x2A, 0x5B, 0x2B, 0x4D, 0x26, 0x36, 0x1C, 0x41, 0x20, 0x60, 0x28, 0x71, 0x2B, 0x76, 0x2D, 0x76, 0x2D, 0x79, 0x2E, 0x79, 0x2D, 0x7A, 0x2E, 0x78, 0x2D, 0x75, 0x2D, 0x75, 0x30, 0x7D, 0x34, 0x84, 0x36, 0x80, 0x36, 0x95, 0x42, 0xA6, 0x51, 0xB5, 0x5A, 0xA0, 0x4B, 0x99, 0x47, 0xA6, 0x56, 0xAA, 0x52, 0xA5, 0x54, 0xAF, 0x54, 0x93, 0x49, 0xAD, 0x4F, 0x97, 0x49, 0xAF, 0x59, 0xAD, 0x55, 0xA4, 0x4E, 0xA6, 0x50, 0x8D, 0x3E, 0x96, 0x48, 0xAC, 0x58, 0x9E, 0x4D, 0xA0, 0x51, 0xAC, 0x52, 0xA6, 0x52, 0xA5, 0x53, 0xA5, 0x4E, 0x9F, 0x4B, 0xA2, 0x51, 0xA6, 0x55, 0x98, 0x46, 0x7F, 0x3C, 0x76, 0x3E, 0x85, 0x4A, 0x9D, 0x4D, 0x86, 0x40, 0x81, 0x3D, 0x95, 0x49, 0xA3, 0x4E, 0x9A, 0x49, 0x89, 0x3E, 0x7F, 0x33, 0x89, 0x40, 0x84, 0x3D, 0x9B, 0x48, 0x7D, 0x35, 0x88, 0x41, 0x8C, 0x3A, 0x7C, 0x39, 0x7F, 0x36, 0x76, 0x31, 0x74, 0x2F, 0x6E, 0x2E, 0x75, 0x31, 0x70, 0x2B, 0x6A, 0x2A, 0x69, 0x28, 0x68, 0x27, 0x66, 0x28, 0x71, 0x30, 0x6D, 0x2D, 0x66, 0x26, 0x68, 0x28, 0x62, 0x25, 0x60, 0x25, 0x63, 0x27, 0x63, 0x26, 0x63, 0x25, 0x63, 0x25, 0x63, 0x26, 0x68, 0x27, 0x62, 0x26, 0x65, 0x26, 0x66, 0x27, 0x63, 0x26, 0x64, 0x25, 0x5F, 0x24, 0x5E, 0x24, 0x5F, 0x24, 0x60, 0x24, 0x66, 0x28, 0x6A, 0x28, 0x66, 0x26, 0x63, 0x24, 0x5F, 0x23, 0x63, 0x26, 0x64, 0x26, 0x64, 0x25, 0x60, 0x24, 0x64, 0x26, 0x67, 0x28, 0x65, 0x26, 0x63, 0x25, 0x63, 0x26, 0x6C, 0x2B, 0x64, 0x27, 0x65, 0x26, 0x68, 0x28, 0x68, 0x28, 0x68, 0x28, 0x6A, 0x2A, 0x68, 0x2A, 0x70, 0x2C, 0x66, 0x29, 0x6B, 0x2A, 0x73, 0x32, 0x7F, 0x39, 0x7D, 0x38, 0x80, 0x38, 0x7D, 0x39, 0x7B, 0x37, 0x81, 0x3B, 0x7C, 0x38, 0x89, 0x42, 0x89, 0x3F, 0x7B, 0x37, 0x74, 0x35, 0x75, 0x32, 0x76, 0x33, 0x71, 0x32, 0x70, 0x2F, 0x73, 0x35, 0x77, 0x36, 0x77, 0x34, 0x82, 0x3C, 0x78, 0x33, 0x7C, 0x3B, 0x7C, 0x37, 0x7E, 0x38, 0x70, 0x2E, 0x70, 0x32, 0x6A, 0x2D, 0x69, 0x2D, 0x72, 0x2E, 0x5D, 0x28, 0x53, 0x29, 0x4B, 0x27, 0x4E, 0x29, 0x48, 0x25, 0x4C, 0x2A, 0x47, 0x25, 0x3D, 0x20, 0x3D, 0x22, 0x3C, 0x20, 0x3C, 0x21, 0x44, 0x22, 0x3F, 0x22, 0x42, 0x22, 0x3E, 0x21, 0x49, 0x27, 0x47, 0x24, 0x42, 0x23, 0x3C, 0x20, 0x43, 0x24, 0x4B, 0x27, 0x44, 0x24, 0x44, 0x24, 0x40, 0x23, 0x4C, 0x27, 0x3F, 0x21, 0x46, 0x25, 0x40, 0x24, 0x4C, 0x29, 0x3B, 0x21, 0x45, 0x25, 0x4B, 0x29, 0x41, 0x22, 0x3A, 0x1F, 0x3F, 0x21, 0x46, 0x24, 0x4A, 0x28, 0x47, 0x27, 0x45, 0x27, 0x4D, 0x2A, 0x3E, 0x22, 0x42, 0x24, 0x42, 0x24, 0x3C, 0x21, 0x44, 0x25, 0x42, 0x24, 0x42, 0x25, 0x3B, 0x27, 0x43, 0x2E, 0x45, 0x32
    },

    {
        0x88, 0x93, 0x90, 0x8E, 0x72, 0x6B, 0x69, 0x60, 0x6B, 0x61, 0x6D, 0x61, 0x6D, 0x5F, 0x70, 0x61, 0x70, 0x5F, 0x73, 0x63, 0x73, 0x62, 0x72, 0x60, 0x73, 0x62, 0x72, 0x63, 0x74, 0x63, 0x74, 0x64, 0x77, 0x65, 0x76, 0x65, 0x78, 0x65, 0x75, 0x63, 0x76, 0x65, 0x78, 0x66, 0x77, 0x65, 0x75, 0x63, 0x76, 0x65, 0x78, 0x65, 0x75, 0x62, 0x78, 0x64, 0x76, 0x66, 0x78, 0x67, 0x77, 0x67, 0x78, 0x68, 0x75, 0x66, 0x77, 0x66, 0x66, 0x5A, 0x56, 0x53, 0x51, 0x50, 0x4F, 0x4D, 0x4F, 0x4F, 0x4E, 0x4F, 0x4F, 0x4C, 0x4C, 0x48, 0x5B, 0x53, 0x6E, 0x5E, 0x74, 0x67, 0x75, 0x64, 0x75, 0x65, 0x77, 0x67, 0x78, 0x66, 0x7A, 0x69, 0x7A, 0x67, 0x79, 0x68, 0x7C, 0x6D, 0x7D, 0x6D, 0x78, 0x67, 0x7B, 0x6A, 0x7E, 0x6D, 0x7C, 0x6C, 0x7D, 0x6D, 0x7E, 0x6C, 0x7C, 0x6B, 0x7C, 0x6A, 0x78, 0x67, 0x78, 0x67, 0x7A, 0x6A, 0x7A, 0x69, 0x79, 0x6A, 0x79, 0x69, 0x76, 0x66, 0x7B, 0x6B, 0x7C, 0x6B, 0x7A, 0x6B, 0x7B, 0x6A, 0x7B, 0x6B, 0x80, 0x72, 0x80, 0x73, 0x81, 0x73, 0x7F, 0x70, 0x83, 0x73, 0x81, 0x70, 0x7F, 0x72, 0x7D, 0x6F, 0x82, 0x73, 0x7E, 0x6F, 0x7D, 0x6E, 0x82, 0x71, 0x82, 0x72, 0x83, 0x70, 0x81, 0x6E, 0x7D, 0x6D, 0x81, 0x71, 0x80, 0x72, 0x7D, 0x70, 0x76, 0x6D, 0x75, 0x6B, 0x7B, 0x6D, 0x7A, 0x6E, 0x7C, 0x72, 0x83, 0x73, 0x83, 0x77, 0x85, 0x75, 0x84, 0x73, 0x8A, 0x78, 0x87, 0x75, 0x85, 0x74, 0x81, 0x73, 0x86, 0x77, 0x84, 0x73, 0x86, 0x76, 0x89, 0x79, 0x87, 0x75, 0x88, 0x75, 0x86, 0x73, 0x86, 0x76, 0x8B, 0x78, 0x8A, 0x76, 0x87, 0x75, 0x76, 0x66, 0x5B, 0x58, 0x5B, 0x5D, 0x57, 0x58, 0x58, 0x57, 0x47, 0x45, 0x35, 0x34, 0x49, 0x48, 0x6E, 0x6B, 0x87, 0x78, 0x8C, 0x7C, 0x8A, 0x7B, 0x8E, 0x7D, 0x8E, 0x7B, 0x8E, 0x7E, 0x8D, 0x7D, 0x88, 0x78, 0x88, 0x7E, 0x93, 0x8A, 0x91, 0x86, 0x9A, 0x99, 0xA6, 0xA0, 0xAA, 0xB3, 0xB5, 0xBD, 0xA2, 0x9F, 0x9E, 0x9D, 0xA5, 0xAF, 0xA6, 0xAA, 0xA7, 0xAD, 0xAD, 0xA6, 0x9C, 0xA2, 0xAB, 0xAA, 0x9E, 0x9F, 0xAC, 0xB1, 0xAC, 0xAF, 0xA5, 0xA6, 0xA3, 0xA6, 0x97, 0x8D, 0x99, 0x96, 0xA8, 0xAF, 0xA5, 0xA4, 0xA9, 0xB1, 0xA9, 0xAB, 0xAA, 0xAF, 0xAC, 0xB0, 0xAE, 0xB0, 0xA7, 0xA6, 0xAE, 0xB3, 0xA9, 0xA9, 0x9C, 0x93, 0x90, 0x91, 0x86, 0x89, 0x86, 0x95, 0x97, 0x9E, 0x92, 0x92, 0x8E, 0x87, 0x99, 0x9B, 0xAA, 0xAF, 0xA4, 0xAA, 0x94, 0x90, 0x88, 0x7D, 0x91, 0x91, 0x8C, 0x8B, 0x9E, 0x98, 0x8B, 0x82, 0x90, 0x8F, 0x95, 0x8A, 0x88, 0x82, 0x8C, 0x83, 0x85, 0x7A, 0x81, 0x79, 0x7F, 0x74, 0x82, 0x76, 0x7D, 0x6F, 0x77, 0x69, 0x79, 0x6E, 0x7B, 0x6B, 0x79, 0x6A, 0x80, 0x78, 0x7E, 0x73, 0x77, 0x68, 0x79, 0x69, 0x75, 0x66, 0x72, 0x67, 0x76, 0x6B, 0x76, 0x68, 0x77, 0x67, 0x76, 0x66, 0x73, 0x68, 0x75, 0x68, 0x72, 0x66, 0x75, 0x69, 0x78, 0x6B, 0x78, 0x6A, 0x79, 0x67, 0x70, 0x62, 0x71, 0x63, 0x72, 0x64, 0x71, 0x65, 0x76, 0x6C, 0x7C, 0x6D, 0x79, 0x6B, 0x77, 0x66, 0x73, 0x64, 0x78, 0x69, 0x77, 0x68, 0x77, 0x68, 0x72, 0x64, 0x74, 0x6A, 0x77, 0x6B, 0x77, 0x69, 0x75, 0x67, 0x75, 0x69, 0x7C, 0x6D, 0x74, 0x69, 0x78, 0x69, 0x7B, 0x6F, 0x7A, 0x6B, 0x7A, 0x69, 0x7B, 0x70, 0x7B, 0x70, 0x80, 0x71, 0x7A, 0x6B, 0x7A, 0x6D, 0x80, 0x7A, 0x8A, 0x82, 0x86, 0x80, 0x89, 0x81, 0x85, 0x7F, 0x85, 0x7F, 0x8A, 0x84, 0x89, 0x84, 0x94, 0x97, 0x91, 0x8C, 0x82, 0x7A, 0x7F, 0x7B, 0x82, 0x77, 0x83, 0x77, 0x80, 0x77, 0x7E, 0x74, 0x7E, 0x79, 0x82, 0x7C, 0x85, 0x7E, 0x89, 0x8A, 0x85, 0x7B, 0x84, 0x83, 0x82, 0x7A, 0x87, 0x85, 0x7B, 0x72, 0x7B, 0x74, 0x77, 0x6C, 0x7A, 0x76, 0x7B, 0x70, 0x63, 0x5B, 0x4B, 0x53, 0x43, 0x4B, 0x44, 0x4D, 0x3F, 0x44, 0x42, 0x4E, 0x3D, 0x43, 0x37, 0x3B, 0x3A, 0x42, 0x39, 0x40, 0x39, 0x41, 0x3D, 0x43, 0x3D, 0x48, 0x40, 0x47, 0x3C, 0x44, 0x44, 0x50, 0x3F, 0x45, 0x3E, 0x45, 0x38, 0x3E, 0x40, 0x4B, 0x44, 0x4D, 0x3F, 0x45, 0x3F, 0x46, 0x3C, 0x45, 0x44, 0x49, 0x39, 0x3E, 0x3F, 0x45, 0x3B, 0x43, 0x45, 0x4A, 0x37, 0x40, 0x40, 0x46, 0x44, 0x50, 0x3C, 0x41, 0x39, 0x3F, 0x3D, 0x46, 0x40, 0x47, 0x45, 0x4C, 0x3E, 0x45, 0x3E, 0x46, 0x41, 0x49, 0x36, 0x3C, 0x3B, 0x43, 0x3C, 0x42, 0x37, 0x40, 0x40, 0x4A, 0x40, 0x48, 0x41, 0x45, 0x3C, 0x3F, 0x3F, 0x45, 0x41, 0x48
    },

    {
        0x70, 0x37, 0x96, 0x4D, 0x9F, 0x45, 0x70, 0x2D, 0x60, 0x26, 0x5E, 0x23, 0x5C, 0x22, 0x5D, 0x21, 0x5E, 0x21, 0x5F, 0x21, 0x5F, 0x22, 0x5C, 0x20, 0x5F, 0x22, 0x5F, 0x22, 0x5F, 0x23, 0x5F, 0x22, 0x61, 0x22, 0x60, 0x22, 0x5E, 0x22, 0x60, 0x22, 0x61, 0x23, 0x65, 0x24, 0x61, 0x23, 0x62, 0x23, 0x62, 0x22, 0x60, 0x22, 0x62, 0x22, 0x61, 0x23, 0x64, 0x24, 0x62, 0x24, 0x62, 0x24, 0x61, 0x23, 0x62, 0x24, 0x61, 0x24, 0x56, 0x24, 0x4D, 0x25, 0x4D, 0x26, 0x4F, 0x27, 0x4F, 0x27, 0x4D, 0x25, 0x4A, 0x23, 0x41, 0x1D, 0x46, 0x1E, 0x57, 0x22, 0x5F, 0x23, 0x5F, 0x24, 0x60, 0x24, 0x62, 0x24, 0x63, 0x24, 0x63, 0x24, 0x67, 0x25, 0x69, 0x27, 0x6B, 0x28, 0x68, 0x27, 0x63, 0x24, 0x65, 0x26, 0x68, 0x27, 0x69, 0x27, 0x68, 0x28, 0x67, 0x25, 0x65, 0x25, 0x65, 0x26, 0x68, 0x26, 0x67, 0x25, 0x66, 0x26, 0x63, 0x25, 0x63, 0x26, 0x62, 0x25, 0x65, 0x25, 0x69, 0x26, 0x65, 0x26, 0x65, 0x25, 0x69, 0x26, 0x67, 0x26, 0x6A, 0x27, 0x6C, 0x29, 0x6C, 0x28, 0x6B, 0x29, 0x6C, 0x29, 0x6D, 0x28, 0x6A, 0x28, 0x6B, 0x29, 0x6F, 0x2B, 0x6F, 0x2B, 0x69, 0x27, 0x6C, 0x28, 0x6C, 0x29, 0x6E, 0x28, 0x6A, 0x28, 0x6C, 0x28, 0x6C, 0x28, 0x63, 0x28, 0x5C, 0x2A, 0x57, 0x2A, 0x59, 0x29, 0x5D, 0x29, 0x65, 0x29, 0x69, 0x2A, 0x6F, 0x29, 0x70, 0x2C, 0x75, 0x2D, 0x70, 0x2B, 0x73, 0x2B, 0x71, 0x2B, 0x6E, 0x2B, 0x6F, 0x2B, 0x6E, 0x2B, 0x71, 0x2B, 0x6F, 0x2A, 0x70, 0x2A, 0x70, 0x2A, 0x74, 0x2B, 0x73, 0x2B, 0x6D, 0x29, 0x71, 0x2B, 0x73, 0x2B, 0x73, 0x2A, 0x67, 0x28, 0x52, 0x22, 0x44, 0x20, 0x42, 0x1F, 0x38, 0x1C, 0x33, 0x1A, 0x39, 0x1C, 0x4F, 0x23, 0x68, 0x2A, 0x78, 0x2E, 0x78, 0x2F, 0x77, 0x30, 0x7F, 0x34, 0x81, 0x33, 0x7E, 0x33, 0x7B, 0x31, 0x7F, 0x33, 0x82, 0x38, 0x8B, 0x3B, 0x7A, 0x34, 0xB1, 0x58, 0xA5, 0x50, 0xB4, 0x57, 0x9D, 0x47, 0x8A, 0x3F, 0x9C, 0x4D, 0x9C, 0x45, 0x9F, 0x50, 0xA1, 0x4C, 0x96, 0x44, 0xA5, 0x55, 0xBD, 0x5C, 0xA1, 0x4E, 0xAD, 0x59, 0xB5, 0x57, 0x9D, 0x4A, 0x9B, 0x4A, 0xA2, 0x51, 0x95, 0x44, 0xA0, 0x4F, 0x9F, 0x49, 0x9B, 0x46, 0xA0, 0x52, 0xA9, 0x51, 0xB5, 0x60, 0xBF, 0x5D, 0xB6, 0x59, 0xAF, 0x5A, 0xB0, 0x54, 0xAA, 0x50, 0x9C, 0x4E, 0xA8, 0x51, 0x96, 0x46, 0x92, 0x46, 0x9B, 0x4B, 0x92, 0x45, 0x90, 0x43, 0xA9, 0x53, 0xA6, 0x50, 0x88, 0x3A, 0x72, 0x34, 0x8C, 0x41, 0x85, 0x39, 0x8A, 0x3F, 0x83, 0x38, 0x85, 0x41, 0x8B, 0x3A, 0x78, 0x34, 0x7C, 0x33, 0x7A, 0x35, 0x75, 0x2E, 0x6E, 0x2D, 0x7B, 0x32, 0x68, 0x28, 0x62, 0x26, 0x68, 0x29, 0x66, 0x27, 0x64, 0x26, 0x66, 0x2A, 0x71, 0x2D, 0x66, 0x26, 0x68, 0x26, 0x64, 0x26, 0x65, 0x26, 0x65, 0x27, 0x6A, 0x28, 0x61, 0x24, 0x60, 0x24, 0x62, 0x26, 0x63, 0x24, 0x60, 0x24, 0x65, 0x27, 0x68, 0x28, 0x67, 0x27, 0x65, 0x25, 0x63, 0x24, 0x61, 0x25, 0x60, 0x24, 0x61, 0x24, 0x65, 0x26, 0x66, 0x27, 0x63, 0x25, 0x66, 0x26, 0x62, 0x24, 0x63, 0x25, 0x5F, 0x24, 0x60, 0x24, 0x63, 0x24, 0x62, 0x27, 0x6A, 0x2B, 0x66, 0x26, 0x62, 0x25, 0x65, 0x26, 0x66, 0x26, 0x61, 0x25, 0x61, 0x25, 0x65, 0x29, 0x66, 0x27, 0x64, 0x26, 0x66, 0x28, 0x68, 0x28, 0x65, 0x28, 0x67, 0x28, 0x66, 0x29, 0x6D, 0x2C, 0x78, 0x32, 0x70, 0x31, 0x7E, 0x3A, 0x7E, 0x37, 0x73, 0x30, 0x84, 0x3E, 0x87, 0x40, 0x93, 0x47, 0x86, 0x40, 0x85, 0x3C, 0x78, 0x33, 0x6C, 0x2E, 0x77, 0x35, 0x78, 0x34, 0x70, 0x2F, 0x75, 0x34, 0x75, 0x33, 0x7A, 0x37, 0x7C, 0x3D, 0x84, 0x3E, 0x7E, 0x3B, 0x76, 0x33, 0x76, 0x36, 0x72, 0x30, 0x6C, 0x2D, 0x64, 0x29, 0x68, 0x2F, 0x69, 0x2B, 0x55, 0x27, 0x47, 0x26, 0x45, 0x27, 0x40, 0x22, 0x3A, 0x20, 0x3D, 0x21, 0x39, 0x20, 0x41, 0x23, 0x46, 0x26, 0x4D, 0x28, 0x46, 0x24, 0x4C, 0x28, 0x4F, 0x29, 0x4D, 0x27, 0x4A, 0x26, 0x40, 0x23, 0x44, 0x24, 0x3E, 0x22, 0x45, 0x24, 0x49, 0x27, 0x46, 0x25, 0x3D, 0x21, 0x40, 0x22, 0x40, 0x22, 0x3E, 0x21, 0x3E, 0x22, 0x3C, 0x21, 0x42, 0x24, 0x4A, 0x26, 0x41, 0x24, 0x4B, 0x28, 0x4B, 0x28, 0x45, 0x25, 0x43, 0x25, 0x48, 0x26, 0x41, 0x23, 0x41, 0x25, 0x35, 0x22, 0x37, 0x26, 0x36, 0x28, 0x36, 0x2A, 0x37, 0x2C, 0x43, 0x32, 0x48, 0x28, 0x53, 0x2E, 0x48, 0x29, 0x49, 0x37, 0x46, 0x3E, 0x45, 0x3F, 0x49, 0x42
    },

    {
        0x74, 0x71, 0x89, 0x99, 0xA2, 0xA5, 0x7F, 0x74, 0x6E, 0x63, 0x6B, 0x61, 0x6D, 0x60, 0x6E, 0x61, 0x70, 0x61, 0x70, 0x61, 0x70, 0x62, 0x6E, 0x5F, 0x71, 0x61, 0x71, 0x63, 0x71, 0x62, 0x75, 0x63, 0x73, 0x62, 0x72, 0x61, 0x72, 0x61, 0x74, 0x64, 0x78, 0x66, 0x7B, 0x68, 0x76, 0x64, 0x75, 0x67, 0x77, 0x65, 0x74, 0x63, 0x76, 0x65, 0x77, 0x64, 0x76, 0x67, 0x77, 0x66, 0x75, 0x65, 0x73, 0x62, 0x73, 0x65, 0x70, 0x60, 0x60, 0x55, 0x54, 0x51, 0x52, 0x50, 0x51, 0x51, 0x4F, 0x51, 0x4C, 0x4C, 0x4A, 0x49, 0x47, 0x40, 0x4E, 0x4A, 0x66, 0x5B, 0x70, 0x63, 0x72, 0x64, 0x74, 0x67, 0x79, 0x68, 0x78, 0x66, 0x79, 0x68, 0x7C, 0x6B, 0x80, 0x6F, 0x7D, 0x6D, 0x7A, 0x69, 0x78, 0x66, 0x7B, 0x6A, 0x7D, 0x6C, 0x7D, 0x6C, 0x7B, 0x6C, 0x79, 0x67, 0x78, 0x68, 0x7B, 0x6C, 0x7C, 0x6C, 0x7A, 0x6A, 0x76, 0x69, 0x70, 0x64, 0x70, 0x64, 0x6E, 0x63, 0x76, 0x68, 0x7A, 0x6C, 0x78, 0x69, 0x7B, 0x6A, 0x7D, 0x6E, 0x7D, 0x6C, 0x83, 0x71, 0x7F, 0x6F, 0x7F, 0x6F, 0x7E, 0x70, 0x7E, 0x6E, 0x80, 0x6F, 0x7E, 0x6D, 0x7F, 0x70, 0x81, 0x70, 0x7F, 0x72, 0x7E, 0x6F, 0x81, 0x6F, 0x82, 0x71, 0x83, 0x70, 0x81, 0x6E, 0x82, 0x71, 0x7D, 0x6E, 0x6B, 0x63, 0x5E, 0x59, 0x5A, 0x5B, 0x5D, 0x5B, 0x61, 0x5E, 0x6F, 0x67, 0x77, 0x6E, 0x80, 0x71, 0x84, 0x77, 0x86, 0x78, 0x84, 0x75, 0x85, 0x78, 0x87, 0x76, 0x80, 0x72, 0x83, 0x75, 0x81, 0x73, 0x82, 0x74, 0x85, 0x74, 0x86, 0x77, 0x85, 0x75, 0x8B, 0x7A, 0x8A, 0x77, 0x87, 0x73, 0x8A, 0x76, 0x8B, 0x78, 0x87, 0x76, 0x7D, 0x6D, 0x63, 0x56, 0x4C, 0x43, 0x42, 0x3C, 0x39, 0x36, 0x3A, 0x37, 0x46, 0x45, 0x63, 0x60, 0x7C, 0x71, 0x8B, 0x80, 0x91, 0x80, 0x8A, 0x81, 0x91, 0x88, 0x94, 0x87, 0x8E, 0x83, 0x8E, 0x85, 0x92, 0x85, 0x93, 0x90, 0x90, 0x86, 0x8B, 0x81, 0xAE, 0xBE, 0xAE, 0xB5, 0xB0, 0xB1, 0xA1, 0x9B, 0x95, 0x90, 0xA1, 0xA4, 0x9E, 0x99, 0xA3, 0xA5, 0x9C, 0x9E, 0x9D, 0x9C, 0xA7, 0xAF, 0xBB, 0xBD, 0xAC, 0xA7, 0xB1, 0xB8, 0xB7, 0xB9, 0xA0, 0x9D, 0x9F, 0x9E, 0xA6, 0xAA, 0xA1, 0x9D, 0xA4, 0xA9, 0xA0, 0x98, 0x99, 0x91, 0xA0, 0xA5, 0xAF, 0xB2, 0xB8, 0xC8, 0xB6, 0xB7, 0xAF, 0xAF, 0xAA, 0xB2, 0xB3, 0xBB, 0xAE, 0xB5, 0xA5, 0xA8, 0xA4, 0xA6, 0x9E, 0x9C, 0x9B, 0x9E, 0xA0, 0xA6, 0x9A, 0x9D, 0x97, 0x8F, 0xA4, 0xA2, 0xA6, 0xAB, 0x93, 0x88, 0x81, 0x78, 0x8F, 0x8C, 0x8F, 0x85, 0x96, 0x8F, 0x8F, 0x82, 0x92, 0x93, 0x8E, 0x86, 0x86, 0x7C, 0x89, 0x7D, 0x8A, 0x80, 0x87, 0x78, 0x81, 0x78, 0x86, 0x7C, 0x79, 0x6A, 0x75, 0x67, 0x79, 0x6D, 0x7A, 0x6A, 0x75, 0x67, 0x77, 0x6E, 0x80, 0x74, 0x7A, 0x6B, 0x7D, 0x6C, 0x78, 0x69, 0x79, 0x6B, 0x7A, 0x6C, 0x7C, 0x6A, 0x72, 0x62, 0x72, 0x66, 0x76, 0x6A, 0x76, 0x69, 0x72, 0x64, 0x75, 0x6A, 0x7B, 0x6D, 0x7A, 0x6D, 0x79, 0x69, 0x78, 0x67, 0x74, 0x66, 0x72, 0x64, 0x74, 0x67, 0x76, 0x68, 0x76, 0x6A, 0x73, 0x66, 0x7A, 0x6C, 0x77, 0x66, 0x75, 0x67, 0x72, 0x63, 0x71, 0x63, 0x77, 0x67, 0x76, 0x6A, 0x78, 0x72, 0x77, 0x69, 0x76, 0x67, 0x77, 0x68, 0x79, 0x69, 0x72, 0x66, 0x75, 0x67, 0x77, 0x6D, 0x77, 0x6A, 0x78, 0x6A, 0x78, 0x6C, 0x79, 0x6B, 0x74, 0x6A, 0x77, 0x6C, 0x77, 0x6E, 0x80, 0x74, 0x84, 0x7A, 0x81, 0x79, 0x8A, 0x85, 0x8B, 0x85, 0x84, 0x7C, 0x93, 0x91, 0x90, 0x8E, 0x94, 0x91, 0x8A, 0x87, 0x92, 0x8B, 0x85, 0x7A, 0x7D, 0x73, 0x84, 0x7F, 0x86, 0x82, 0x7B, 0x76, 0x80, 0x7F, 0x84, 0x7D, 0x85, 0x81, 0x82, 0x83, 0x89, 0x88, 0x85, 0x80, 0x82, 0x77, 0x81, 0x79, 0x7F, 0x74, 0x7C, 0x71, 0x74, 0x69, 0x73, 0x6E, 0x75, 0x67, 0x5C, 0x57, 0x41, 0x46, 0x3E, 0x46, 0x3B, 0x40, 0x38, 0x40, 0x39, 0x3E, 0x36, 0x3F, 0x40, 0x49, 0x40, 0x4D, 0x48, 0x52, 0x41, 0x4A, 0x47, 0x51, 0x46, 0x51, 0x43, 0x4B, 0x41, 0x47, 0x3B, 0x43, 0x40, 0x46, 0x39, 0x41, 0x40, 0x49, 0x43, 0x4A, 0x3F, 0x43, 0x37, 0x3D, 0x3A, 0x41, 0x3D, 0x46, 0x3C, 0x41, 0x3A, 0x42, 0x39, 0x3E, 0x40, 0x49, 0x44, 0x4B, 0x3D, 0x45, 0x45, 0x4D, 0x42, 0x49, 0x3E, 0x45, 0x3D, 0x47, 0x3E, 0x44, 0x3D, 0x45, 0x3D, 0x3E, 0x34, 0x36, 0x36, 0x37, 0x34, 0x37, 0x36, 0x38, 0x38, 0x39, 0x40, 0x4B, 0x40, 0x4A, 0x49, 0x52, 0x3F, 0x4B, 0x45, 0x4A, 0x44, 0x47, 0x44, 0x47, 0x44, 0x49
    },

    {
        0x5D, 0x27, 0x6C, 0x35, 0x8B, 0x48, 0x9B, 0x46, 0x75, 0x2F, 0x5F, 0x25, 0x59, 0x23, 0x5B, 0x21, 0x5D, 0x21, 0x5F, 0x21, 0x5F, 0x22, 0x5E, 0x21, 0x5F, 0x21, 0x60, 0x22, 0x62, 0x23, 0x63, 0x23, 0x60, 0x22, 0x60, 0x22, 0x60, 0x23, 0x61, 0x23, 0x61, 0x23, 0x61, 0x24, 0x63, 0x23, 0x63, 0x23, 0x62, 0x23, 0x61, 0x22, 0x62, 0x23, 0x62, 0x22, 0x62, 0x23, 0x63, 0x24, 0x5E, 0x22, 0x5D, 0x22, 0x5F, 0x23, 0x5C, 0x22, 0x54, 0x24, 0x4E, 0x25, 0x4F, 0x27, 0x4E, 0x27, 0x4E, 0x26, 0x4C, 0x25, 0x48, 0x22, 0x39, 0x1A, 0x40, 0x1D, 0x54, 0x21, 0x5F, 0x23, 0x63, 0x24, 0x64, 0x25, 0x66, 0x25, 0x63, 0x24, 0x65, 0x25, 0x69, 0x27, 0x67, 0x26, 0x66, 0x26, 0x66, 0x26, 0x66, 0x25, 0x63, 0x24, 0x63, 0x25, 0x65, 0x25, 0x66, 0x26, 0x65, 0x25, 0x68, 0x26, 0x6A, 0x28, 0x68, 0x26, 0x62, 0x26, 0x5B, 0x26, 0x54, 0x25, 0x55, 0x26, 0x56, 0x25, 0x5C, 0x25, 0x64, 0x26, 0x65, 0x26, 0x67, 0x26, 0x68, 0x26, 0x69, 0x26, 0x6B, 0x28, 0x68, 0x26, 0x66, 0x26, 0x69, 0x28, 0x69, 0x27, 0x6B, 0x27, 0x6C, 0x28, 0x69, 0x27, 0x6E, 0x2A, 0x6C, 0x28, 0x6D, 0x28, 0x6A, 0x27, 0x6B, 0x27, 0x6C, 0x27, 0x6C, 0x28, 0x6B, 0x27, 0x60, 0x27, 0x58, 0x2A, 0x57, 0x2A, 0x55, 0x2A, 0x56, 0x2B, 0x59, 0x2C, 0x57, 0x2A, 0x67, 0x2A, 0x6B, 0x29, 0x71, 0x2B, 0x70, 0x2C, 0x73, 0x2C, 0x72, 0x2B, 0x71, 0x2C, 0x71, 0x2C, 0x74, 0x2C, 0x6F, 0x2B, 0x6E, 0x2B, 0x76, 0x2E, 0x73, 0x2C, 0x6E, 0x2B, 0x74, 0x2D, 0x71, 0x2C, 0x70, 0x2B, 0x75, 0x2C, 0x75, 0x2D, 0x77, 0x2D, 0x71, 0x2B, 0x65, 0x27, 0x52, 0x22, 0x48, 0x21, 0x4A, 0x23, 0x4D, 0x23, 0x5A, 0x26, 0x72, 0x2F, 0x76, 0x2E, 0x7B, 0x31, 0x8E, 0x40, 0x88, 0x3A, 0x8D, 0x3E, 0x8D, 0x3C, 0x7A, 0x34, 0x80, 0x39, 0x8B, 0x3B, 0x8B, 0x42, 0x8E, 0x3C, 0x8B, 0x3C, 0xAB, 0x5A, 0xA6, 0x50, 0xAA, 0x51, 0x9B, 0x4D, 0x9B, 0x4B, 0x99, 0x47, 0x94, 0x48, 0x96, 0x46, 0x8C, 0x3F, 0xA5, 0x55, 0xB7, 0x61, 0xCF, 0x69, 0xBB, 0x5F, 0xC8, 0x65, 0xB9, 0x58, 0x94, 0x41, 0x8F, 0x43, 0xAB, 0x57, 0xAC, 0x53, 0xA0, 0x4D, 0x9D, 0x4C, 0x99, 0x46, 0x98, 0x4B, 0xBB, 0x60, 0xAA, 0x58, 0xBD, 0x62, 0xA6, 0x50, 0xA7, 0x55, 0xB4, 0x5D, 0xAF, 0x57, 0xA7, 0x51, 0xB4, 0x5B, 0x9F, 0x4A, 0x96, 0x46, 0x9F, 0x4A, 0x94, 0x45, 0x89, 0x3D, 0x7E, 0x36, 0xA6, 0x56, 0x8F, 0x3A, 0x7B, 0x35, 0x86, 0x3D, 0x98, 0x47, 0xA0, 0x4A, 0x83, 0x36, 0x86, 0x3D, 0x7F, 0x36, 0x77, 0x34, 0x73, 0x2E, 0x6E, 0x2E, 0x79, 0x30, 0x79, 0x37, 0x79, 0x31, 0x6A, 0x28, 0x67, 0x29, 0x6A, 0x2A, 0x6B, 0x29, 0x63, 0x26, 0x65, 0x29, 0x6A, 0x2A, 0x64, 0x25, 0x67, 0x27, 0x67, 0x27, 0x67, 0x28, 0x67, 0x28, 0x67, 0x28, 0x65, 0x25, 0x63, 0x27, 0x65, 0x25, 0x68, 0x27, 0x66, 0x28, 0x66, 0x27, 0x65, 0x27, 0x65, 0x27, 0x64, 0x25, 0x64, 0x26, 0x64, 0x26, 0x5C, 0x25, 0x60, 0x24, 0x61, 0x25, 0x60, 0x25, 0x62, 0x24, 0x61, 0x25, 0x65, 0x24, 0x65, 0x26, 0x62, 0x24, 0x60, 0x25, 0x61, 0x24, 0x65, 0x27, 0x66, 0x28, 0x63, 0x26, 0x64, 0x26, 0x64, 0x25, 0x62, 0x24, 0x63, 0x25, 0x63, 0x26, 0x68, 0x2A, 0x63, 0x26, 0x63, 0x27, 0x65, 0x29, 0x60, 0x25, 0x5D, 0x25, 0x6D, 0x2D, 0x66, 0x2A, 0x77, 0x33, 0x75, 0x31, 0x6F, 0x2F, 0x7E, 0x3A, 0x80, 0x38, 0x7D, 0x37, 0x80, 0x3C, 0x8A, 0x42, 0x8E, 0x43, 0x7C, 0x37, 0x81, 0x3C, 0x7C, 0x36, 0x77, 0x35, 0x7F, 0x3B, 0x86, 0x40, 0x93, 0x44, 0x73, 0x32, 0x71, 0x32, 0x78, 0x3A, 0x8C, 0x44, 0x87, 0x3D, 0x75, 0x33, 0x73, 0x32, 0x71, 0x2F, 0x68, 0x2B, 0x6D, 0x2E, 0x6B, 0x2C, 0x65, 0x2A, 0x62, 0x27, 0x53, 0x26, 0x3F, 0x22, 0x42, 0x24, 0x42, 0x23, 0x4C, 0x29, 0x4A, 0x27, 0x50, 0x2A, 0x4E, 0x28, 0x47, 0x26, 0x4A, 0x27, 0x44, 0x25, 0x47, 0x25, 0x3D, 0x21, 0x3B, 0x21, 0x3A, 0x1F, 0x42, 0x25, 0x3B, 0x21, 0x3D, 0x22, 0x42, 0x24, 0x3E, 0x23, 0x3E, 0x22, 0x37, 0x1F, 0x3F, 0x21, 0x44, 0x25, 0x48, 0x26, 0x42, 0x24, 0x43, 0x28, 0x3F, 0x28, 0x41, 0x2C, 0x3A, 0x2B, 0x3E, 0x2D, 0x36, 0x2C, 0x38, 0x2B, 0x3A, 0x22, 0x3E, 0x21, 0x3F, 0x24, 0x3A, 0x31, 0x36, 0x35, 0x36, 0x35, 0x37, 0x35, 0x36, 0x36, 0x38, 0x36, 0x3C, 0x33, 0x3E, 0x28, 0x49, 0x28, 0x4A, 0x28, 0x4D, 0x31, 0x35, 0x2A, 0x31, 0x28, 0x2E, 0x24
    },

    {
        0x68, 0x5C, 0x6E, 0x6B, 0x7F, 0x86, 0x98, 0x9E, 0x84, 0x79, 0x6E, 0x63, 0x66, 0x5B, 0x67, 0x5B, 0x6C, 0x60, 0x6F, 0x60, 0x71, 0x60, 0x71, 0x61, 0x72, 0x62, 0x74, 0x63, 0x74, 0x65, 0x74, 0x64, 0x75, 0x64, 0x76, 0x63, 0x75, 0x64, 0x76, 0x63, 0x75, 0x64, 0x73, 0x61, 0x72, 0x62, 0x74, 0x63, 0x75, 0x64, 0x75, 0x65, 0x78, 0x65, 0x76, 0x64, 0x75, 0x65, 0x78, 0x66, 0x74, 0x61, 0x71, 0x61, 0x72, 0x62, 0x6B, 0x5D, 0x61, 0x56, 0x57, 0x51, 0x52, 0x52, 0x51, 0x52, 0x4F, 0x4F, 0x4C, 0x4C, 0x49, 0x48, 0x3E, 0x38, 0x49, 0x45, 0x63, 0x5B, 0x70, 0x63, 0x77, 0x66, 0x7A, 0x69, 0x7A, 0x68, 0x7A, 0x67, 0x7D, 0x6B, 0x7B, 0x6A, 0x7C, 0x6A, 0x7A, 0x69, 0x79, 0x69, 0x7A, 0x68, 0x7A, 0x68, 0x79, 0x66, 0x7A, 0x69, 0x7A, 0x6A, 0x7C, 0x69, 0x7E, 0x6D, 0x7E, 0x6E, 0x7A, 0x6C, 0x6C, 0x60, 0x5D, 0x57, 0x57, 0x53, 0x58, 0x55, 0x5C, 0x58, 0x67, 0x5F, 0x71, 0x64, 0x75, 0x68, 0x77, 0x69, 0x7C, 0x6A, 0x7D, 0x6C, 0x80, 0x6D, 0x7D, 0x6C, 0x7C, 0x6B, 0x7C, 0x6E, 0x7D, 0x6C, 0x7D, 0x6C, 0x80, 0x6F, 0x7E, 0x6D, 0x80, 0x71, 0x7F, 0x6F, 0x7F, 0x6E, 0x80, 0x70, 0x80, 0x6F, 0x7F, 0x70, 0x81, 0x70, 0x7D, 0x6C, 0x6B, 0x61, 0x5B, 0x59, 0x58, 0x58, 0x55, 0x58, 0x57, 0x5A, 0x59, 0x5B, 0x58, 0x5C, 0x6C, 0x66, 0x78, 0x6E, 0x81, 0x76, 0x85, 0x74, 0x86, 0x77, 0x84, 0x76, 0x84, 0x73, 0x86, 0x7B, 0x86, 0x75, 0x82, 0x74, 0x81, 0x75, 0x8B, 0x7C, 0x87, 0x77, 0x83, 0x74, 0x88, 0x76, 0x89, 0x77, 0x87, 0x78, 0x8C, 0x79, 0x8C, 0x7B, 0x8B, 0x79, 0x85, 0x75, 0x7A, 0x6A, 0x65, 0x5B, 0x5B, 0x55, 0x59, 0x55, 0x60, 0x59, 0x6E, 0x66, 0x80, 0x7C, 0x8B, 0x7F, 0x8F, 0x81, 0x9B, 0x9A, 0x99, 0x8F, 0x99, 0x92, 0x95, 0x8E, 0x8B, 0x81, 0x8E, 0x87, 0x96, 0x8E, 0x94, 0x90, 0xA1, 0x9D, 0x98, 0x8E, 0xA8, 0xB6, 0xA6, 0xA1, 0xA4, 0xA4, 0x98, 0x9E, 0xA1, 0xA3, 0x9E, 0x9A, 0x9C, 0x9B, 0x9A, 0x9A, 0x95, 0x90, 0xAC, 0xB4, 0xB6, 0xC2, 0xC0, 0xC4, 0xB5, 0xBD, 0xC4, 0xCC, 0xB9, 0xBE, 0x9C, 0x94, 0x9D, 0x9A, 0xB1, 0xBB, 0xB0, 0xA9, 0xA3, 0xA0, 0xA1, 0xA3, 0xA3, 0x9D, 0x9A, 0x9A, 0xB8, 0xC3, 0xB5, 0xBB, 0xB8, 0xC1, 0xAE, 0xAC, 0xAF, 0xB1, 0xAF, 0xB2, 0xAD, 0xB0, 0xA9, 0xA8, 0xB2, 0xBA, 0xA5, 0xA1, 0x9B, 0x98, 0xA0, 0x9D, 0x9A, 0x95, 0x94, 0x8D, 0x8D, 0x83, 0xA4, 0xAB, 0x9A, 0x8B, 0x8D, 0x85, 0x93, 0x90, 0xA3, 0xA2, 0xA0, 0x9D, 0x8C, 0x81, 0x8F, 0x8B, 0x86, 0x7F, 0x86, 0x7F, 0x83, 0x73, 0x7F, 0x76, 0x85, 0x7A, 0x86, 0x82, 0x84, 0x79, 0x7B, 0x6D, 0x78, 0x6B, 0x7B, 0x6E, 0x78, 0x6D, 0x73, 0x66, 0x78, 0x6D, 0x7A, 0x6F, 0x78, 0x69, 0x79, 0x6B, 0x79, 0x6B, 0x79, 0x6F, 0x78, 0x6A, 0x78, 0x6B, 0x77, 0x67, 0x74, 0x69, 0x77, 0x69, 0x77, 0x6B, 0x79, 0x6A, 0x79, 0x6D, 0x7A, 0x6B, 0x7B, 0x6C, 0x77, 0x67, 0x78, 0x69, 0x73, 0x65, 0x6E, 0x62, 0x71, 0x63, 0x73, 0x65, 0x73, 0x66, 0x76, 0x66, 0x74, 0x66, 0x77, 0x68, 0x79, 0x6A, 0x76, 0x66, 0x74, 0x65, 0x73, 0x63, 0x75, 0x6B, 0x78, 0x6B, 0x74, 0x68, 0x76, 0x67, 0x78, 0x69, 0x75, 0x65, 0x74, 0x65, 0x74, 0x68, 0x76, 0x6D, 0x74, 0x66, 0x74, 0x69, 0x77, 0x6C, 0x72, 0x64, 0x70, 0x64, 0x7A, 0x70, 0x75, 0x6C, 0x80, 0x7B, 0x81, 0x77, 0x84, 0x7A, 0x8B, 0x84, 0x8A, 0x82, 0x8F, 0x83, 0x8D, 0x89, 0x94, 0x93, 0x93, 0x8C, 0x8C, 0x83, 0x8C, 0x87, 0x89, 0x7E, 0x86, 0x80, 0x84, 0x7F, 0x8B, 0x8E, 0x93, 0x92, 0x7C, 0x75, 0x7A, 0x74, 0x80, 0x80, 0x8F, 0x93, 0x8C, 0x86, 0x82, 0x79, 0x80, 0x78, 0x7F, 0x73, 0x7A, 0x70, 0x7C, 0x73, 0x7A, 0x6D, 0x74, 0x6B, 0x73, 0x66, 0x57, 0x50, 0x3D, 0x41, 0x3D, 0x48, 0x3F, 0x47, 0x47, 0x54, 0x44, 0x4F, 0x49, 0x51, 0x46, 0x4E, 0x3F, 0x47, 0x41, 0x4A, 0x3D, 0x45, 0x3E, 0x44, 0x37, 0x3C, 0x37, 0x3E, 0x35, 0x3A, 0x3B, 0x46, 0x35, 0x3B, 0x39, 0x42, 0x3D, 0x44, 0x37, 0x3E, 0x38, 0x3E, 0x33, 0x3B, 0x3A, 0x41, 0x3E, 0x48, 0x3E, 0x46, 0x3B, 0x43, 0x3E, 0x43, 0x3A, 0x3E, 0x3D, 0x3D, 0x38, 0x3C, 0x3A, 0x3B, 0x36, 0x37, 0x37, 0x39, 0x37, 0x3F, 0x3B, 0x40, 0x3A, 0x41, 0x3C, 0x3A, 0x39, 0x37, 0x38, 0x37, 0x38, 0x36, 0x38, 0x37, 0x39, 0x39, 0x36, 0x38, 0x35, 0x41, 0x41, 0x4A, 0x45, 0x50, 0x46, 0x4A, 0x2F, 0x30, 0x29, 0x2D, 0x28, 0x2B
    },

    {
        0x55, 0x1F, 0x56, 0x22, 0x63, 0x2D, 0x7C, 0x41, 0x9D, 0x4C, 0x81, 0x37, 0x6B, 0x2B, 0x5D, 0x24, 0x56, 0x21, 0x58, 0x21, 0x5F, 0x22, 0x60, 0x21, 0x5E, 0x21, 0x61, 0x23, 0x62, 0x23, 0x60, 0x23, 0x63, 0x23, 0x62, 0x23, 0x5F, 0x26, 0x61, 0x23, 0x60, 0x24, 0x66, 0x28, 0x63, 0x24, 0x60, 0x24, 0x61, 0x23, 0x5E, 0x23, 0x62, 0x24, 0x63, 0x24, 0x63, 0x24, 0x63, 0x23, 0x60, 0x23, 0x5F, 0x23, 0x5F, 0x23, 0x60, 0x24, 0x59, 0x24, 0x51, 0x24, 0x4F, 0x26, 0x4D, 0x25, 0x4C, 0x26, 0x4C, 0x25, 0x41, 0x1D, 0x34, 0x1A, 0x44, 0x1E, 0x56, 0x22, 0x5E, 0x23, 0x64, 0x25, 0x66, 0x25, 0x61, 0x24, 0x66, 0x27, 0x69, 0x27, 0x64, 0x25, 0x65, 0x26, 0x65, 0x26, 0x65, 0x25, 0x63, 0x24, 0x68, 0x25, 0x65, 0x25, 0x66, 0x25, 0x67, 0x25, 0x68, 0x27, 0x6A, 0x28, 0x69, 0x28, 0x64, 0x27, 0x58, 0x28, 0x53, 0x28, 0x50, 0x27, 0x4F, 0x28, 0x4F, 0x25, 0x4F, 0x22, 0x58, 0x24, 0x62, 0x26, 0x66, 0x27, 0x68, 0x27, 0x65, 0x25, 0x69, 0x27, 0x6A, 0x27, 0x67, 0x27, 0x69, 0x28, 0x6B, 0x28, 0x6A, 0x27, 0x69, 0x26, 0x68, 0x26, 0x6B, 0x28, 0x6B, 0x28, 0x69, 0x29, 0x6C, 0x29, 0x6B, 0x28, 0x69, 0x27, 0x6C, 0x28, 0x67, 0x27, 0x5A, 0x2A, 0x56, 0x29, 0x56, 0x2B, 0x56, 0x2B, 0x58, 0x2B, 0x58, 0x2C, 0x53, 0x29, 0x52, 0x25, 0x66, 0x2A, 0x70, 0x2D, 0x73, 0x2D, 0x73, 0x2D, 0x72, 0x2B, 0x71, 0x2D, 0x77, 0x30, 0x73, 0x2C, 0x74, 0x2E, 0x76, 0x30, 0x7D, 0x32, 0x7A, 0x33, 0x73, 0x2F, 0x73, 0x2D, 0x74, 0x2F, 0x77, 0x2F, 0x77, 0x30, 0x7B, 0x2E, 0x71, 0x2D, 0x76, 0x2E, 0x75, 0x2E, 0x6C, 0x2C, 0x6F, 0x2E, 0x73, 0x2E, 0x7B, 0x36, 0x73, 0x30, 0x82, 0x37, 0x85, 0x38, 0x85, 0x39, 0x8D, 0x40, 0x92, 0x46, 0x89, 0x3B, 0x88, 0x3D, 0x98, 0x49, 0xA5, 0x4B, 0x95, 0x49, 0x9C, 0x4B, 0xC6, 0x5D, 0x9A, 0x4B, 0x9D, 0x48, 0x89, 0x41, 0x9A, 0x4B, 0x9E, 0x49, 0xA2, 0x52, 0xB5, 0x58, 0x9B, 0x48, 0x96, 0x45, 0x9B, 0x4D, 0xAE, 0x57, 0xB1, 0x5D, 0xB3, 0x59, 0xB8, 0x5F, 0xC7, 0x65, 0xBD, 0x5E, 0x9A, 0x4A, 0xA4, 0x50, 0xAF, 0x56, 0x9F, 0x4B, 0x99, 0x47, 0xA0, 0x4F, 0xAD, 0x52, 0xA4, 0x50, 0xB2, 0x60, 0xC1, 0x61, 0xA5, 0x53, 0xAF, 0x54, 0xAD, 0x53, 0x94, 0x43, 0x9A, 0x4B, 0xAC, 0x54, 0xAA, 0x51, 0xA0, 0x4D, 0x90, 0x41, 0xA9, 0x55, 0x91, 0x42, 0x94, 0x46, 0x8C, 0x42, 0x92, 0x44, 0x95, 0x43, 0x88, 0x3F, 0x9B, 0x48, 0xA0, 0x50, 0xA0, 0x4A, 0x79, 0x35, 0x91, 0x44, 0x86, 0x3B, 0x7C, 0x35, 0x72, 0x2C, 0x6B, 0x2B, 0x75, 0x32, 0x7E, 0x38, 0x7A, 0x32, 0x6D, 0x29, 0x66, 0x28, 0x62, 0x27, 0x62, 0x24, 0x64, 0x28, 0x70, 0x2F, 0x6A, 0x29, 0x65, 0x27, 0x66, 0x27, 0x68, 0x28, 0x68, 0x29, 0x6B, 0x2B, 0x67, 0x27, 0x63, 0x25, 0x63, 0x26, 0x64, 0x28, 0x68, 0x28, 0x67, 0x27, 0x6A, 0x28, 0x64, 0x27, 0x67, 0x27, 0x65, 0x25, 0x62, 0x26, 0x65, 0x28, 0x63, 0x27, 0x62, 0x26, 0x61, 0x24, 0x61, 0x25, 0x64, 0x26, 0x63, 0x24, 0x64, 0x25, 0x62, 0x25, 0x62, 0x25, 0x60, 0x24, 0x63, 0x24, 0x63, 0x25, 0x62, 0x25, 0x64, 0x26, 0x62, 0x25, 0x63, 0x24, 0x61, 0x25, 0x60, 0x24, 0x61, 0x26, 0x67, 0x2A, 0x64, 0x27, 0x6F, 0x30, 0x67, 0x28, 0x64, 0x27, 0x68, 0x29, 0x6E, 0x2D, 0x6B, 0x2D, 0x79, 0x36, 0x7B, 0x38, 0x8E, 0x43, 0x84, 0x3A, 0x81, 0x3A, 0x86, 0x3B, 0x7F, 0x3B, 0x87, 0x3E, 0x83, 0x3E, 0x8C, 0x42, 0x90, 0x46, 0x7D, 0x38, 0x79, 0x36, 0x72, 0x32, 0x7E, 0x3E, 0x85, 0x3E, 0x7B, 0x37, 0x7C, 0x39, 0x7F, 0x3B, 0x7D, 0x39, 0x84, 0x3C, 0x75, 0x32, 0x6B, 0x2C, 0x6C, 0x2D, 0x6C, 0x2E, 0x6F, 0x31, 0x6E, 0x2E, 0x68, 0x2A, 0x63, 0x29, 0x55, 0x28, 0x48, 0x26, 0x4D, 0x2A, 0x4F, 0x28, 0x43, 0x24, 0x41, 0x23, 0x43, 0x24, 0x40, 0x23, 0x39, 0x21, 0x3F, 0x24, 0x45, 0x26, 0x40, 0x23, 0x40, 0x24, 0x43, 0x25, 0x48, 0x26, 0x41, 0x24, 0x45, 0x28, 0x41, 0x29, 0x3D, 0x2B, 0x39, 0x2D, 0x3B, 0x30, 0x35, 0x30, 0x3A, 0x31, 0x40, 0x25, 0x3D, 0x22, 0x3C, 0x23, 0x38, 0x3B, 0x38, 0x41, 0x39, 0x41, 0x37, 0x3E, 0x39, 0x3C, 0x36, 0x38, 0x34, 0x30, 0x33, 0x21, 0x41, 0x23, 0x3D, 0x22, 0x3C, 0x2D, 0x2F, 0x2A, 0x2B, 0x27, 0x29, 0x23, 0x27, 0x21, 0x29, 0x1F, 0x28, 0x1C, 0x31, 0x1F, 0x42, 0x25, 0x49, 0x28, 0x44, 0x24, 0x36, 0x1E, 0x38, 0x1E, 0x37, 0x1F
    },

    {
        0x63, 0x56, 0x64, 0x57, 0x6B, 0x63, 0x78, 0x7B, 0x96, 0xA1, 0x94, 0x8F, 0x7A, 0x71, 0x6D, 0x61, 0x66, 0x5B, 0x6A, 0x5D, 0x6F, 0x61, 0x73, 0x61, 0x71, 0x60, 0x75, 0x66, 0x76, 0x64, 0x72, 0x63, 0x74, 0x64, 0x74, 0x62, 0x73, 0x63, 0x74, 0x63, 0x73, 0x64, 0x78, 0x6D, 0x75, 0x65, 0x73, 0x63, 0x76, 0x63, 0x74, 0x64, 0x79, 0x66, 0x76, 0x66, 0x77, 0x66, 0x77, 0x67, 0x75, 0x65, 0x76, 0x64, 0x73, 0x63, 0x73, 0x65, 0x69, 0x5A, 0x58, 0x51, 0x54, 0x51, 0x52, 0x51, 0x4F, 0x4F, 0x4D, 0x4C, 0x42, 0x3C, 0x39, 0x37, 0x4D, 0x4A, 0x66, 0x5C, 0x70, 0x61, 0x77, 0x68, 0x7A, 0x67, 0x76, 0x67, 0x79, 0x69, 0x7B, 0x6A, 0x7A, 0x69, 0x7A, 0x69, 0x7A, 0x6B, 0x79, 0x67, 0x78, 0x68, 0x7F, 0x6A, 0x7C, 0x6A, 0x7E, 0x6C, 0x7E, 0x6C, 0x7A, 0x6C, 0x7E, 0x6E, 0x7C, 0x6D, 0x73, 0x65, 0x5D, 0x57, 0x56, 0x56, 0x54, 0x52, 0x55, 0x53, 0x56, 0x54, 0x56, 0x51, 0x62, 0x5B, 0x6F, 0x64, 0x76, 0x6B, 0x7B, 0x6C, 0x7C, 0x69, 0x7F, 0x6F, 0x7F, 0x6D, 0x7C, 0x6B, 0x7D, 0x6E, 0x7C, 0x6D, 0x7E, 0x6E, 0x7D, 0x6C, 0x7E, 0x6C, 0x82, 0x71, 0x81, 0x70, 0x7E, 0x6E, 0x82, 0x73, 0x81, 0x6F, 0x80, 0x6E, 0x81, 0x6F, 0x79, 0x6A, 0x64, 0x5C, 0x5A, 0x59, 0x59, 0x58, 0x56, 0x59, 0x56, 0x5A, 0x56, 0x5B, 0x54, 0x56, 0x57, 0x54, 0x72, 0x6A, 0x7E, 0x73, 0x84, 0x75, 0x86, 0x79, 0x89, 0x77, 0x87, 0x78, 0x8B, 0x80, 0x87, 0x78, 0x8A, 0x7C, 0x8A, 0x7E, 0x90, 0x83, 0x90, 0x86, 0x8E, 0x7B, 0x8B, 0x7A, 0x89, 0x7D, 0x8B, 0x7D, 0x8D, 0x7F, 0x92, 0x80, 0x87, 0x7A, 0x8C, 0x7C, 0x8B, 0x7C, 0x81, 0x76, 0x83, 0x78, 0x83, 0x78, 0x86, 0x84, 0x88, 0x81, 0x95, 0x8B, 0x9A, 0x8F, 0x96, 0x8C, 0xA3, 0x9F, 0xA0, 0x9C, 0x94, 0x89, 0x99, 0x98, 0xA8, 0xAD, 0xAA, 0xA9, 0xA1, 0xA5, 0xA0, 0xA2, 0xB5, 0xB8, 0x9F, 0xA6, 0xA7, 0xA4, 0x91, 0x8A, 0x9C, 0xA4, 0xA2, 0x9E, 0xA7, 0xAE, 0xAF, 0xB8, 0xA0, 0x9C, 0x9A, 0x99, 0xA3, 0xA8, 0xB0, 0xAC, 0xB0, 0xB7, 0xB4, 0xB8, 0xB4, 0xC2, 0xBF, 0xC8, 0xB1, 0xB5, 0xA0, 0xA0, 0xA3, 0xA8, 0xAA, 0xAD, 0xA4, 0xA1, 0x9E, 0x9D, 0xA5, 0xAF, 0xB0, 0xB0, 0xAA, 0xB5, 0xB0, 0xB7, 0xB7, 0xBB, 0xA9, 0xAA, 0xAD, 0xAE, 0xB0, 0xB7, 0xA2, 0x9C, 0x9E, 0x9D, 0xAD, 0xAD, 0xA3, 0xA6, 0x9F, 0x9F, 0x98, 0x95, 0xAA, 0xB4, 0x9E, 0x97, 0x9C, 0x9A, 0x97, 0x96, 0x9B, 0x96, 0x9E, 0x9A, 0x93, 0x8F, 0x9F, 0x9F, 0x9B, 0xA0, 0xA2, 0xA5, 0x89, 0x7D, 0x90, 0x92, 0x8E, 0x85, 0x89, 0x80, 0x82, 0x74, 0x7F, 0x70, 0x81, 0x79, 0x8B, 0x84, 0x87, 0x7D, 0x7F, 0x6E, 0x77, 0x6C, 0x72, 0x66, 0x76, 0x64, 0x73, 0x68, 0x7C, 0x74, 0x7A, 0x6B, 0x79, 0x69, 0x7A, 0x68, 0x78, 0x6C, 0x7B, 0x6F, 0x7A, 0x6F, 0x7A, 0x6B, 0x77, 0x68, 0x74, 0x68, 0x78, 0x6C, 0x77, 0x6B, 0x7B, 0x6B, 0x7A, 0x6D, 0x77, 0x6A, 0x79, 0x6B, 0x78, 0x67, 0x76, 0x68, 0x76, 0x6A, 0x76, 0x69, 0x76, 0x67, 0x74, 0x66, 0x76, 0x68, 0x77, 0x6A, 0x76, 0x65, 0x79, 0x6A, 0x74, 0x67, 0x78, 0x68, 0x74, 0x65, 0x76, 0x67, 0x76, 0x68, 0x73, 0x66, 0x76, 0x66, 0x76, 0x67, 0x75, 0x66, 0x71, 0x63, 0x74, 0x66, 0x74, 0x67, 0x78, 0x6C, 0x76, 0x67, 0x7D, 0x73, 0x78, 0x6C, 0x77, 0x69, 0x7B, 0x6F, 0x7F, 0x73, 0x7B, 0x70, 0x87, 0x86, 0x89, 0x82, 0x9D, 0x9A, 0x9D, 0x93, 0x94, 0x8F, 0x90, 0x89, 0x8B, 0x86, 0x95, 0x8D, 0x93, 0x92, 0x94, 0x93, 0x94, 0x95, 0x87, 0x80, 0x86, 0x7D, 0x7D, 0x76, 0x89, 0x86, 0x8C, 0x89, 0x8A, 0x81, 0x88, 0x81, 0x89, 0x87, 0x84, 0x7D, 0x8F, 0x88, 0x7E, 0x76, 0x7A, 0x6E, 0x7E, 0x75, 0x7C, 0x6F, 0x80, 0x78, 0x7B, 0x71, 0x78, 0x6A, 0x74, 0x68, 0x5A, 0x58, 0x43, 0x48, 0x48, 0x54, 0x46, 0x4C, 0x3A, 0x40, 0x3A, 0x42, 0x3B, 0x44, 0x37, 0x3E, 0x35, 0x3D, 0x39, 0x42, 0x3F, 0x4A, 0x3B, 0x42, 0x3C, 0x45, 0x3F, 0x4A, 0x44, 0x4C, 0x3C, 0x43, 0x3F, 0x48, 0x36, 0x3F, 0x32, 0x3A, 0x2F, 0x39, 0x31, 0x38, 0x2E, 0x37, 0x32, 0x39, 0x38, 0x43, 0x38, 0x3E, 0x37, 0x3E, 0x38, 0x3A, 0x39, 0x39, 0x3A, 0x3A, 0x39, 0x39, 0x3A, 0x39, 0x38, 0x36, 0x31, 0x32, 0x2D, 0x37, 0x38, 0x3F, 0x3B, 0x43, 0x3C, 0x3D, 0x2D, 0x2C, 0x28, 0x29, 0x25, 0x28, 0x24, 0x27, 0x25, 0x28, 0x23, 0x28, 0x2F, 0x3A, 0x3C, 0x45, 0x41, 0x49, 0x3D, 0x44, 0x36, 0x3E, 0x3A, 0x41, 0x35, 0x3D
    },

    {
        0x51, 0x1E, 0x52, 0x1E, 0x54, 0x21, 0x5F, 0x2B, 0x78, 0x3E, 0x9F, 0x53, 0x8A, 0x3A, 0x65, 0x29, 0x60, 0x26, 0x5D, 0x22, 0x5D, 0x21, 0x5F, 0x21, 0x5F, 0x22, 0x60, 0x22, 0x60, 0x22, 0x60, 0x23, 0x62, 0x24, 0x62, 0x23, 0x5F, 0x22, 0x61, 0x23, 0x62, 0x24, 0x60, 0x23, 0x5E, 0x22, 0x60, 0x22, 0x61, 0x22, 0x64, 0x23, 0x64, 0x25, 0x63, 0x24, 0x63, 0x24, 0x62, 0x25, 0x63, 0x25, 0x62, 0x25, 0x65, 0x25, 0x63, 0x25, 0x5C, 0x23, 0x4F, 0x21, 0x49, 0x22, 0x46, 0x22, 0x45, 0x21, 0x3C, 0x1C, 0x30, 0x19, 0x39, 0x1B, 0x4B, 0x20, 0x58, 0x22, 0x62, 0x25, 0x64, 0x25, 0x63, 0x24, 0x63, 0x24, 0x63, 0x24, 0x64, 0x26, 0x65, 0x26, 0x65, 0x25, 0x67, 0x25, 0x64, 0x25, 0x63, 0x24, 0x63, 0x24, 0x64, 0x25, 0x69, 0x26, 0x69, 0x26, 0x69, 0x27, 0x6A, 0x28, 0x6B, 0x29, 0x61, 0x2A, 0x54, 0x29, 0x53, 0x29, 0x53, 0x28, 0x50, 0x28, 0x4D, 0x26, 0x4E, 0x25, 0x4D, 0x23, 0x5A, 0x25, 0x66, 0x27, 0x67, 0x27, 0x6A, 0x27, 0x6B, 0x28, 0x69, 0x27, 0x6B, 0x27, 0x6A, 0x27, 0x6A, 0x27, 0x6A, 0x28, 0x69, 0x28, 0x6E, 0x28, 0x6C, 0x28, 0x6B, 0x27, 0x6A, 0x28, 0x6D, 0x29, 0x6C, 0x28, 0x6F, 0x2A, 0x6C, 0x28, 0x67, 0x28, 0x58, 0x2A, 0x59, 0x2B, 0x59, 0x2C, 0x5D, 0x2F, 0x59, 0x2C, 0x5D, 0x30, 0x50, 0x25, 0x42, 0x1F, 0x5D, 0x28, 0x6A, 0x2A, 0x72, 0x2F, 0x85, 0x36, 0x7A, 0x31, 0x74, 0x30, 0x79, 0x31, 0x79, 0x34, 0x95, 0x46, 0x8B, 0x39, 0x77, 0x2F, 0x7D, 0x36, 0x80, 0x37, 0x8C, 0x3D, 0x83, 0x37, 0x7E, 0x35, 0x8B, 0x3C, 0x87, 0x39, 0x81, 0x36, 0x7C, 0x32, 0x79, 0x32, 0x7A, 0x32, 0x76, 0x30, 0x7B, 0x34, 0x80, 0x35, 0x88, 0x3E, 0x95, 0x41, 0x9E, 0x4D, 0xB1, 0x58, 0xB1, 0x55, 0x8C, 0x3D, 0x91, 0x43, 0xA1, 0x50, 0x9E, 0x47, 0x92, 0x46, 0x92, 0x41, 0x8A, 0x44, 0x91, 0x43, 0xA7, 0x52, 0xAD, 0x51, 0x86, 0x3D, 0x9D, 0x4C, 0x95, 0x47, 0xAA, 0x58, 0xBE, 0x5D, 0xA2, 0x4F, 0xA2, 0x52, 0xAC, 0x58, 0xAE, 0x59, 0xCC, 0x6C, 0xC9, 0x65, 0xB8, 0x61, 0xAE, 0x55, 0x95, 0x46, 0x96, 0x46, 0x91, 0x44, 0x9E, 0x50, 0xBA, 0x60, 0xA3, 0x4D, 0x99, 0x4B, 0xB5, 0x5A, 0xB8, 0x64, 0xB0, 0x57, 0xA9, 0x54, 0xB7, 0x5D, 0xA4, 0x50, 0xA7, 0x52, 0x9E, 0x49, 0x9C, 0x4A, 0x9E, 0x4B, 0x95, 0x4B, 0x95, 0x43, 0x85, 0x3D, 0x91, 0x45, 0x8E, 0x44, 0xA4, 0x4D, 0x9E, 0x51, 0x9C, 0x44, 0x8E, 0x41, 0x85, 0x3C, 0x9A, 0x4B, 0x8F, 0x44, 0x91, 0x46, 0x86, 0x3C, 0x80, 0x3A, 0x7E, 0x36, 0x7A, 0x33, 0x72, 0x2E, 0x78, 0x33, 0x6D, 0x2F, 0x7F, 0x37, 0x78, 0x32, 0x70, 0x2C, 0x6C, 0x2B, 0x64, 0x26, 0x63, 0x25, 0x63, 0x27, 0x63, 0x26, 0x65, 0x27, 0x67, 0x26, 0x66, 0x27, 0x5F, 0x24, 0x65, 0x28, 0x68, 0x28, 0x65, 0x27, 0x63, 0x26, 0x62, 0x26, 0x65, 0x27, 0x65, 0x27, 0x64, 0x25, 0x64, 0x25, 0x65, 0x27, 0x6C, 0x2D, 0x61, 0x25, 0x69, 0x29, 0x64, 0x27, 0x61, 0x26, 0x61, 0x25, 0x60, 0x25, 0x61, 0x26, 0x64, 0x26, 0x60, 0x23, 0x65, 0x26, 0x5F, 0x25, 0x62, 0x26, 0x65, 0x27, 0x63, 0x25, 0x61, 0x25, 0x62, 0x25, 0x60, 0x25, 0x62, 0x25, 0x61, 0x23, 0x5E, 0x23, 0x5E, 0x23, 0x6C, 0x2D, 0x67, 0x27, 0x61, 0x27, 0x69, 0x2A, 0x65, 0x28, 0x68, 0x2A, 0x6B, 0x29, 0x6B, 0x2B, 0x6B, 0x2B, 0x80, 0x3E, 0x86, 0x3D, 0x98, 0x4B, 0xAE, 0x57, 0x9E, 0x4D, 0x8F, 0x42, 0x80, 0x38, 0x8F, 0x49, 0x9E, 0x4C, 0x8D, 0x45, 0x8A, 0x42, 0x85, 0x3D, 0x7B, 0x36, 0x77, 0x34, 0x79, 0x37, 0x81, 0x3D, 0x79, 0x37, 0x71, 0x31, 0x74, 0x34, 0x7B, 0x39, 0x7F, 0x38, 0x6C, 0x2E, 0x6A, 0x2C, 0x6E, 0x31, 0x69, 0x2B, 0x6C, 0x2C, 0x67, 0x2A, 0x67, 0x2A, 0x67, 0x2B, 0x51, 0x25, 0x3F, 0x22, 0x4C, 0x29, 0x45, 0x23, 0x3B, 0x20, 0x40, 0x23, 0x40, 0x27, 0x41, 0x2C, 0x3B, 0x2A, 0x3E, 0x2F, 0x3F, 0x34, 0x3C, 0x36, 0x3B, 0x30, 0x45, 0x28, 0x48, 0x25, 0x41, 0x25, 0x40, 0x37, 0x35, 0x43, 0x34, 0x43, 0x36, 0x47, 0x35, 0x47, 0x38, 0x48, 0x34, 0x39, 0x30, 0x21, 0x43, 0x24, 0x3E, 0x23, 0x3D, 0x35, 0x31, 0x33, 0x2F, 0x30, 0x2A, 0x28, 0x2C, 0x2B, 0x28, 0x21, 0x28, 0x1D, 0x2F, 0x1E, 0x41, 0x24, 0x48, 0x27, 0x45, 0x25, 0x30, 0x1A, 0x34, 0x1D, 0x31, 0x1B, 0x36, 0x1E, 0x35, 0x1D, 0x3D, 0x21, 0x4B, 0x29, 0x51, 0x2B, 0x43, 0x23, 0x49, 0x25, 0x44, 0x25, 0x49, 0x27, 0x3C, 0x21
    },

    {
        0x61, 0x54, 0x60, 0x53, 0x63, 0x56, 0x69, 0x61, 0x76, 0x78, 0x86, 0x93, 0x87, 0x7E, 0x6E, 0x65, 0x6C, 0x62, 0x6E, 0x60, 0x6F, 0x60, 0x71, 0x60, 0x71, 0x60, 0x73, 0x63, 0x73, 0x63, 0x75, 0x65, 0x75, 0x65, 0x74, 0x63, 0x74, 0x63, 0x75, 0x65, 0x74, 0x64, 0x73, 0x64, 0x73, 0x62, 0x74, 0x62, 0x77, 0x65, 0x78, 0x67, 0x78, 0x67, 0x76, 0x65, 0x75, 0x65, 0x75, 0x66, 0x75, 0x65, 0x77, 0x66, 0x7A, 0x69, 0x75, 0x66, 0x6E, 0x5E, 0x5C, 0x51, 0x4F, 0x49, 0x48, 0x46, 0x46, 0x40, 0x3C, 0x37, 0x37, 0x33, 0x44, 0x40, 0x5B, 0x54, 0x6A, 0x5F, 0x73, 0x66, 0x76, 0x66, 0x77, 0x67, 0x79, 0x67, 0x7A, 0x68, 0x78, 0x67, 0x79, 0x68, 0x7B, 0x6A, 0x7C, 0x6C, 0x7A, 0x69, 0x79, 0x68, 0x77, 0x65, 0x76, 0x67, 0x7E, 0x6C, 0x7E, 0x6C, 0x7F, 0x6D, 0x7E, 0x6D, 0x7A, 0x6C, 0x68, 0x60, 0x59, 0x58, 0x56, 0x56, 0x53, 0x53, 0x51, 0x52, 0x4E, 0x4E, 0x50, 0x50, 0x4F, 0x4F, 0x65, 0x5D, 0x76, 0x6A, 0x7F, 0x6D, 0x7E, 0x6D, 0x7F, 0x6D, 0x7E, 0x6D, 0x7E, 0x6F, 0x81, 0x6F, 0x7F, 0x6E, 0x80, 0x6F, 0x7F, 0x6F, 0x83, 0x72, 0x80, 0x70, 0x81, 0x6E, 0x7E, 0x6E, 0x82, 0x70, 0x81, 0x6F, 0x82, 0x72, 0x7E, 0x6D, 0x7A, 0x68, 0x64, 0x5E, 0x5C, 0x5A, 0x5A, 0x61, 0x5B, 0x5E, 0x58, 0x5B, 0x5B, 0x62, 0x53, 0x4F, 0x47, 0x44, 0x65, 0x64, 0x79, 0x71, 0x84, 0x79, 0x95, 0x8A, 0x8C, 0x7A, 0x88, 0x7B, 0x8B, 0x81, 0x8A, 0x82, 0xA2, 0xA5, 0x9E, 0x93, 0x8A, 0x7A, 0x8F, 0x86, 0x8D, 0x88, 0x9D, 0x94, 0x95, 0x8B, 0x8C, 0x84, 0x98, 0x96, 0x9A, 0x92, 0x93, 0x88, 0x8C, 0x7C, 0x88, 0x7E, 0x8E, 0x83, 0x8B, 0x80, 0x8E, 0x88, 0x8F, 0x84, 0x96, 0x95, 0x9F, 0x99, 0xA1, 0xA3, 0xAE, 0xBB, 0xAF, 0xB4, 0xA0, 0x96, 0x9E, 0xA3, 0xA0, 0xA6, 0xA6, 0xA3, 0x9E, 0x9D, 0x97, 0x8C, 0x9C, 0x9C, 0x9A, 0x93, 0xA8, 0xB2, 0xAD, 0xAC, 0x9A, 0x97, 0xA8, 0xA3, 0x9F, 0x9C, 0xB2, 0xBB, 0xB7, 0xBD, 0xAE, 0xAF, 0xAA, 0xB3, 0xAF, 0xB4, 0xB9, 0xC1, 0xD1, 0xDF, 0xC2, 0xCB, 0xBA, 0xC3, 0xB1, 0xAE, 0xA1, 0x9B, 0x9D, 0x9D, 0x98, 0x97, 0xA3, 0xA3, 0xB6, 0xC4, 0xAB, 0xA8, 0x99, 0x9C, 0xAF, 0xAE, 0xB3, 0xC2, 0xB4, 0xB4, 0xAA, 0xAB, 0xB3, 0xBD, 0xA8, 0xA6, 0xA8, 0xA6, 0xA3, 0x9E, 0xA6, 0xA8, 0xA6, 0xA3, 0xA2, 0xA4, 0xA0, 0x98, 0x91, 0x8D, 0x99, 0x97, 0x9F, 0xA4, 0xAA, 0xAD, 0x9D, 0xA5, 0xA1, 0x9B, 0x95, 0x8E, 0x8E, 0x8A, 0x98, 0x99, 0x99, 0x97, 0x98, 0x97, 0x93, 0x8B, 0x90, 0x88, 0x8B, 0x80, 0x87, 0x7A, 0x85, 0x7C, 0x8C, 0x82, 0x7E, 0x75, 0x88, 0x80, 0x88, 0x7F, 0x81, 0x76, 0x7E, 0x72, 0x77, 0x69, 0x76, 0x68, 0x7A, 0x6A, 0x74, 0x66, 0x77, 0x6A, 0x7A, 0x6C, 0x79, 0x69, 0x73, 0x65, 0x79, 0x6C, 0x7A, 0x6E, 0x76, 0x68, 0x77, 0x67, 0x76, 0x69, 0x7A, 0x6C, 0x76, 0x69, 0x77, 0x68, 0x76, 0x6A, 0x7A, 0x6C, 0x7D, 0x76, 0x73, 0x65, 0x7B, 0x6D, 0x73, 0x64, 0x74, 0x68, 0x74, 0x65, 0x74, 0x66, 0x72, 0x67, 0x79, 0x69, 0x73, 0x64, 0x79, 0x69, 0x71, 0x65, 0x75, 0x68, 0x7A, 0x6A, 0x75, 0x67, 0x74, 0x66, 0x75, 0x6B, 0x72, 0x66, 0x74, 0x67, 0x73, 0x64, 0x70, 0x62, 0x6F, 0x64, 0x7F, 0x76, 0x78, 0x69, 0x76, 0x69, 0x75, 0x69, 0x74, 0x6A, 0x79, 0x71, 0x7F, 0x6E, 0x7C, 0x71, 0x7E, 0x71, 0x89, 0x8D, 0x91, 0x8E, 0x9E, 0xA6, 0xAF, 0xB3, 0x9D, 0xA2, 0x97, 0x95, 0x8E, 0x89, 0x96, 0x9C, 0xA0, 0xA4, 0x91, 0x91, 0x8F, 0x8E, 0x8A, 0x87, 0x86, 0x7F, 0x86, 0x7E, 0x84, 0x7D, 0x86, 0x81, 0x84, 0x7A, 0x7E, 0x72, 0x80, 0x7D, 0x89, 0x88, 0x86, 0x7D, 0x7A, 0x72, 0x7A, 0x6D, 0x7B, 0x73, 0x78, 0x6C, 0x7B, 0x6F, 0x79, 0x6C, 0x7A, 0x6D, 0x78, 0x6A, 0x53, 0x4D, 0x3B, 0x41, 0x44, 0x4D, 0x3D, 0x43, 0x36, 0x3E, 0x3D, 0x44, 0x37, 0x41, 0x36, 0x44, 0x30, 0x3A, 0x30, 0x3E, 0x2F, 0x3D, 0x2C, 0x3A, 0x2C, 0x37, 0x3A, 0x4A, 0x3D, 0x43, 0x3C, 0x47, 0x36, 0x3E, 0x27, 0x34, 0x26, 0x34, 0x28, 0x36, 0x29, 0x35, 0x2D, 0x38, 0x2C, 0x33, 0x2C, 0x36, 0x40, 0x48, 0x39, 0x41, 0x3C, 0x3E, 0x2D, 0x2D, 0x2A, 0x2C, 0x27, 0x29, 0x26, 0x2B, 0x26, 0x2B, 0x25, 0x2A, 0x2E, 0x38, 0x41, 0x4A, 0x44, 0x4E, 0x41, 0x45, 0x32, 0x35, 0x36, 0x3D, 0x34, 0x39, 0x37, 0x3F, 0x35, 0x3C, 0x3E, 0x47, 0x47, 0x53, 0x4A, 0x54, 0x3D, 0x43, 0x45, 0x4E, 0x3D, 0x43, 0x40, 0x47, 0x38, 0x42
    },

    {
        0x51, 0x1E, 0x52, 0x1D, 0x54, 0x20, 0x60, 0x2B, 0x6A, 0x2B, 0x5E, 0x28, 0x5F, 0x2A, 0x63, 0x2B, 0x62, 0x28, 0x5D, 0x23, 0x60, 0x23, 0x5C, 0x21, 0x5C, 0x21, 0x5E, 0x21, 0x60, 0x21, 0x5F, 0x22, 0x5E, 0x23, 0x60, 0x22, 0x62, 0x23, 0x64, 0x24, 0x61, 0x22, 0x5F, 0x22, 0x60, 0x22, 0x5F, 0x22, 0x61, 0x23, 0x5F, 0x22, 0x63, 0x23, 0x61, 0x23, 0x62, 0x23, 0x62, 0x24, 0x62, 0x25, 0x65, 0x24, 0x65, 0x24, 0x62, 0x23, 0x61, 0x23, 0x57, 0x21, 0x49, 0x1D, 0x3D, 0x1B, 0x38, 0x1B, 0x3A, 0x1C, 0x40, 0x1D, 0x4D, 0x20, 0x5C, 0x24, 0x60, 0x24, 0x61, 0x25, 0x63, 0x24, 0x64, 0x24, 0x62, 0x24, 0x63, 0x24, 0x63, 0x24, 0x65, 0x25, 0x68, 0x26, 0x68, 0x26, 0x66, 0x25, 0x66, 0x25, 0x65, 0x24, 0x63, 0x24, 0x63, 0x25, 0x64, 0x25, 0x65, 0x26, 0x65, 0x25, 0x64, 0x27, 0x5B, 0x27, 0x51, 0x28, 0x51, 0x28, 0x51, 0x28, 0x4F, 0x27, 0x4E, 0x26, 0x4D, 0x25, 0x41, 0x1E, 0x52, 0x23, 0x64, 0x27, 0x66, 0x27, 0x6B, 0x28, 0x6B, 0x28, 0x6B, 0x27, 0x6A, 0x28, 0x6D, 0x29, 0x6C, 0x27, 0x6B, 0x27, 0x6D, 0x27, 0x6B, 0x27, 0x6B, 0x28, 0x6A, 0x27, 0x69, 0x27, 0x6C, 0x27, 0x66, 0x26, 0x6A, 0x28, 0x6B, 0x28, 0x67, 0x28, 0x5D, 0x29, 0x58, 0x2A, 0x58, 0x2C, 0x59, 0x2C, 0x59, 0x2D, 0x57, 0x2C, 0x4B, 0x23, 0x3E, 0x1F, 0x5A, 0x27, 0x6E, 0x2E, 0x72, 0x2E, 0x78, 0x31, 0x7A, 0x32, 0x7D, 0x32, 0x78, 0x30, 0x77, 0x32, 0x86, 0x3B, 0x94, 0x45, 0x8F, 0x3B, 0x8B, 0x3C, 0x89, 0x3F, 0x92, 0x3F, 0x8C, 0x3F, 0x81, 0x36, 0x87, 0x3D, 0x8D, 0x42, 0x93, 0x3F, 0x82, 0x39, 0x82, 0x36, 0x85, 0x3A, 0x86, 0x3C, 0x8A, 0x3A, 0x7B, 0x34, 0x87, 0x40, 0x96, 0x42, 0x88, 0x3D, 0x9F, 0x4F, 0xAC, 0x55, 0xBB, 0x59, 0x9B, 0x48, 0x98, 0x4A, 0xB2, 0x57, 0xAC, 0x57, 0xC3, 0x65, 0xCD, 0x6A, 0x9B, 0x44, 0x9D, 0x4C, 0xAA, 0x52, 0xA2, 0x52, 0xB6, 0x57, 0xB0, 0x57, 0xBA, 0x64, 0xCF, 0x6F, 0xC2, 0x60, 0xB1, 0x5A, 0xB4, 0x5B, 0xBB, 0x66, 0xCD, 0x68, 0xA6, 0x53, 0xAC, 0x55, 0x9B, 0x48, 0xA2, 0x4B, 0x93, 0x4A, 0x9A, 0x45, 0x9D, 0x4E, 0xAE, 0x57, 0xA4, 0x4C, 0x8E, 0x44, 0x9D, 0x4A, 0xA9, 0x51, 0x9B, 0x4C, 0x9F, 0x4B, 0xA9, 0x58, 0x9F, 0x4C, 0xA1, 0x4C, 0xA1, 0x50, 0xA7, 0x53, 0xA5, 0x52, 0xA3, 0x4B, 0x92, 0x45, 0x93, 0x45, 0x98, 0x45, 0xA9, 0x58, 0xAF, 0x53, 0x98, 0x4A, 0x97, 0x44, 0x85, 0x3A, 0x91, 0x43, 0x7C, 0x35, 0x98, 0x50, 0x9F, 0x47, 0x8D, 0x3F, 0x8F, 0x42, 0x7F, 0x35, 0x78, 0x31, 0x77, 0x31, 0x7C, 0x35, 0x74, 0x31, 0x79, 0x32, 0x7F, 0x39, 0x7F, 0x38, 0x7F, 0x35, 0x6C, 0x29, 0x67, 0x27, 0x67, 0x27, 0x58, 0x23, 0x63, 0x26, 0x66, 0x26, 0x69, 0x28, 0x6A, 0x28, 0x6C, 0x2A, 0x6B, 0x2A, 0x68, 0x29, 0x67, 0x27, 0x65, 0x25, 0x65, 0x28, 0x67, 0x27, 0x66, 0x26, 0x64, 0x25, 0x63, 0x26, 0x6C, 0x2D, 0x5F, 0x24, 0x60, 0x27, 0x69, 0x28, 0x65, 0x27, 0x64, 0x25, 0x60, 0x25, 0x64, 0x27, 0x69, 0x29, 0x63, 0x25, 0x63, 0x25, 0x61, 0x25, 0x61, 0x25, 0x65, 0x26, 0x69, 0x29, 0x65, 0x26, 0x6E, 0x2C, 0x62, 0x26, 0x5C, 0x22, 0x5A, 0x21, 0x5A, 0x21, 0x5E, 0x24, 0x77, 0x33, 0x63, 0x25, 0x64, 0x28, 0x66, 0x28, 0x6F, 0x2E, 0x67, 0x2A, 0x70, 0x2E, 0x68, 0x2A, 0x72, 0x32, 0x7A, 0x38, 0x8F, 0x46, 0x94, 0x48, 0xA4, 0x56, 0x9D, 0x4B, 0x8C, 0x42, 0x91, 0x47, 0x88, 0x3D, 0x90, 0x48, 0x8A, 0x40, 0x8A, 0x42, 0x82, 0x3D, 0x89, 0x41, 0x8A, 0x40, 0x7D, 0x38, 0x7F, 0x3A, 0x71, 0x32, 0x70, 0x30, 0x77, 0x37, 0x77, 0x33, 0x6D, 0x2E, 0x67, 0x2C, 0x6A, 0x2B, 0x64, 0x28, 0x65, 0x29, 0x69, 0x2A, 0x6A, 0x2B, 0x68, 0x2A, 0x62, 0x27, 0x51, 0x26, 0x45, 0x25, 0x4C, 0x28, 0x4D, 0x29, 0x42, 0x24, 0x50, 0x2B, 0x38, 0x3A, 0x39, 0x48, 0x36, 0x47, 0x37, 0x47, 0x38, 0x49, 0x36, 0x47, 0x31, 0x35, 0x31, 0x20, 0x45, 0x26, 0x4A, 0x28, 0x44, 0x35, 0x33, 0x38, 0x2D, 0x32, 0x2A, 0x2D, 0x29, 0x29, 0x2A, 0x27, 0x27, 0x1F, 0x2F, 0x1E, 0x3E, 0x22, 0x3E, 0x21, 0x3D, 0x21, 0x2D, 0x1A, 0x2F, 0x1B, 0x34, 0x1E, 0x3D, 0x22, 0x43, 0x25, 0x40, 0x23, 0x4D, 0x29, 0x51, 0x29, 0x47, 0x25, 0x47, 0x26, 0x43, 0x22, 0x3F, 0x22, 0x44, 0x25, 0x47, 0x24, 0x41, 0x23, 0x4B, 0x26, 0x41, 0x22, 0x44, 0x25, 0x3D, 0x21, 0x43, 0x25, 0x3C, 0x20, 0x40, 0x22, 0x44, 0x24
    },

    {
        0x60, 0x55, 0x60, 0x54, 0x61, 0x58, 0x68, 0x65, 0x70, 0x64, 0x67, 0x5D, 0x69, 0x61, 0x6A, 0x64, 0x6B, 0x63, 0x6A, 0x60, 0x6F, 0x61, 0x6D, 0x5D, 0x6D, 0x5D, 0x6E, 0x5F, 0x73, 0x62, 0x72, 0x62, 0x71, 0x62, 0x71, 0x61, 0x74, 0x65, 0x76, 0x66, 0x73, 0x64, 0x74, 0x63, 0x74, 0x63, 0x74, 0x63, 0x76, 0x63, 0x71, 0x64, 0x78, 0x65, 0x75, 0x66, 0x78, 0x66, 0x76, 0x65, 0x77, 0x67, 0x79, 0x67, 0x78, 0x67, 0x74, 0x65, 0x75, 0x63, 0x6A, 0x5C, 0x59, 0x4A, 0x4B, 0x41, 0x45, 0x3E, 0x43, 0x40, 0x4F, 0x49, 0x5D, 0x56, 0x6E, 0x61, 0x74, 0x65, 0x77, 0x68, 0x78, 0x66, 0x79, 0x68, 0x78, 0x66, 0x7A, 0x68, 0x79, 0x67, 0x7B, 0x69, 0x7D, 0x6C, 0x7B, 0x6A, 0x7A, 0x6B, 0x7B, 0x69, 0x79, 0x68, 0x78, 0x66, 0x77, 0x67, 0x79, 0x68, 0x7B, 0x6A, 0x78, 0x69, 0x74, 0x67, 0x66, 0x5B, 0x57, 0x57, 0x53, 0x52, 0x52, 0x52, 0x50, 0x50, 0x4E, 0x50, 0x4B, 0x4C, 0x44, 0x3F, 0x5C, 0x59, 0x74, 0x69, 0x77, 0x69, 0x80, 0x70, 0x82, 0x6E, 0x7F, 0x6D, 0x7E, 0x6F, 0x80, 0x71, 0x7F, 0x6D, 0x80, 0x6F, 0x82, 0x70, 0x7F, 0x6F, 0x81, 0x6F, 0x7D, 0x6C, 0x7C, 0x6E, 0x81, 0x6E, 0x7C, 0x6A, 0x7D, 0x6E, 0x80, 0x6D, 0x77, 0x69, 0x68, 0x60, 0x59, 0x5A, 0x58, 0x5A, 0x57, 0x57, 0x55, 0x59, 0x55, 0x59, 0x49, 0x46, 0x42, 0x44, 0x64, 0x60, 0x7F, 0x78, 0x88, 0x7A, 0x8A, 0x7A, 0x8C, 0x7E, 0x8C, 0x7F, 0x88, 0x7B, 0x85, 0x7C, 0x8C, 0x82, 0x93, 0x96, 0x9D, 0x94, 0x9D, 0x95, 0x98, 0x98, 0xA0, 0x9A, 0x99, 0x95, 0x91, 0x87, 0x94, 0x90, 0x93, 0x95, 0xA0, 0x99, 0x90, 0x8D, 0x8F, 0x85, 0x93, 0x8A, 0x94, 0x8F, 0x95, 0x8C, 0x86, 0x7A, 0x8D, 0x8E, 0x9D, 0x9A, 0x9B, 0x8E, 0x9E, 0xA1, 0xAA, 0xB2, 0xB0, 0xAF, 0x98, 0x97, 0xA0, 0xA2, 0xA9, 0xB3, 0xAD, 0xB9, 0xC8, 0xDA, 0xBC, 0xC2, 0xA1, 0x96, 0xA5, 0xA4, 0xA5, 0xA4, 0xA3, 0xA9, 0xAE, 0xBA, 0xB3, 0xBD, 0xB5, 0xC3, 0xCA, 0xDC, 0xBD, 0xC0, 0xB8, 0xBA, 0xB2, 0xBB, 0xB5, 0xC2, 0xBD, 0xC5, 0xA9, 0xAF, 0xB7, 0xB5, 0xA3, 0xA2, 0xAD, 0xAE, 0x9D, 0xA1, 0xA1, 0x9D, 0xA3, 0xA5, 0xAB, 0xB1, 0xA7, 0xA3, 0x99, 0x99, 0xA5, 0xA4, 0xA8, 0xA7, 0x9C, 0x9D, 0x9F, 0x9E, 0xA7, 0xB3, 0xAB, 0xAA, 0xA2, 0xA4, 0xA5, 0xA5, 0xA9, 0xAA, 0xA7, 0xB1, 0xA7, 0xA7, 0x98, 0x93, 0x97, 0x97, 0x9B, 0x96, 0xA9, 0xAD, 0xA5, 0xA3, 0x9B, 0x9F, 0x9F, 0x99, 0x95, 0x89, 0x99, 0x98, 0x84, 0x78, 0xA0, 0xAC, 0x9F, 0x97, 0x94, 0x8E, 0x98, 0x95, 0x8F, 0x84, 0x89, 0x7B, 0x88, 0x7B, 0x8B, 0x81, 0x82, 0x79, 0x88, 0x7D, 0x8C, 0x85, 0x8B, 0x88, 0x89, 0x82, 0x7C, 0x6D, 0x79, 0x6B, 0x79, 0x6A, 0x68, 0x5C, 0x75, 0x69, 0x79, 0x6C, 0x7C, 0x6E, 0x80, 0x6F, 0x7B, 0x70, 0x7A, 0x70, 0x7A, 0x6B, 0x7A, 0x6B, 0x79, 0x69, 0x7A, 0x6B, 0x79, 0x6A, 0x75, 0x69, 0x75, 0x66, 0x75, 0x67, 0x79, 0x6D, 0x71, 0x64, 0x70, 0x66, 0x78, 0x6C, 0x78, 0x6A, 0x76, 0x67, 0x72, 0x64, 0x76, 0x69, 0x7C, 0x6E, 0x76, 0x65, 0x76, 0x67, 0x73, 0x68, 0x76, 0x6A, 0x79, 0x6A, 0x7E, 0x70, 0x78, 0x6A, 0x7B, 0x72, 0x73, 0x67, 0x70, 0x5F, 0x6D, 0x5D, 0x6C, 0x5F, 0x6E, 0x65, 0x80, 0x78, 0x77, 0x67, 0x74, 0x68, 0x74, 0x6C, 0x79, 0x71, 0x74, 0x6B, 0x7A, 0x70, 0x78, 0x6E, 0x81, 0x7C, 0x83, 0x82, 0x8F, 0x92, 0x93, 0x94, 0xA0, 0xAA, 0xA4, 0xA5, 0x96, 0x91, 0x97, 0x96, 0x91, 0x8A, 0x8F, 0x8D, 0x92, 0x8D, 0x8F, 0x8C, 0x88, 0x89, 0x91, 0x8E, 0x90, 0x8E, 0x86, 0x82, 0x8A, 0x82, 0x81, 0x77, 0x7E, 0x77, 0x84, 0x81, 0x83, 0x7A, 0x78, 0x70, 0x73, 0x6B, 0x78, 0x6D, 0x74, 0x67, 0x76, 0x6B, 0x7A, 0x6E, 0x7B, 0x6F, 0x79, 0x6C, 0x71, 0x63, 0x56, 0x53, 0x43, 0x4A, 0x45, 0x4D, 0x48, 0x53, 0x3F, 0x46, 0x48, 0x4F, 0x2B, 0x37, 0x27, 0x38, 0x25, 0x36, 0x25, 0x36, 0x26, 0x37, 0x24, 0x34, 0x22, 0x2E, 0x2A, 0x37, 0x3F, 0x48, 0x43, 0x51, 0x3C, 0x43, 0x27, 0x30, 0x22, 0x2A, 0x21, 0x28, 0x21, 0x28, 0x22, 0x29, 0x23, 0x28, 0x2A, 0x35, 0x37, 0x3D, 0x3B, 0x45, 0x39, 0x3D, 0x2F, 0x32, 0x33, 0x3A, 0x36, 0x3E, 0x3E, 0x48, 0x40, 0x47, 0x41, 0x4A, 0x4A, 0x55, 0x47, 0x51, 0x40, 0x47, 0x43, 0x4C, 0x3E, 0x43, 0x3A, 0x41, 0x3E, 0x4A, 0x3F, 0x44, 0x3C, 0x46, 0x42, 0x49, 0x38, 0x3F, 0x3D, 0x46, 0x37, 0x3F, 0x3E, 0x46, 0x38, 0x3F, 0x3C, 0x45, 0x42, 0x4C
    },

    {
        0x52, 0x1E, 0x53, 0x1E, 0x52, 0x1E, 0x52, 0x1E, 0x53, 0x1F, 0x58, 0x24, 0x5B, 0x27, 0x5A, 0x26, 0x5B, 0x27, 0x5E, 0x24, 0x5D, 0x23, 0x5B, 0x21, 0x5C, 0x21, 0x5B, 0x20, 0x5D, 0x21, 0x5D, 0x22, 0x60, 0x23, 0x5F, 0x23, 0x63, 0x23, 0x64, 0x24, 0x62, 0x24, 0x62, 0x23, 0x63, 0x23, 0x60, 0x22, 0x5F, 0x21, 0x5E, 0x21, 0x5E, 0x23, 0x62, 0x24, 0x61, 0x24, 0x61, 0x24, 0x61, 0x24, 0x62, 0x24, 0x65, 0x25, 0x66, 0x26, 0x62, 0x25, 0x61, 0x24, 0x59, 0x21, 0x54, 0x21, 0x50, 0x20, 0x51, 0x20, 0x58, 0x23, 0x5C, 0x24, 0x64, 0x26, 0x64, 0x26, 0x66, 0x25, 0x63, 0x25, 0x66, 0x25, 0x64, 0x23, 0x64, 0x24, 0x61, 0x24, 0x62, 0x24, 0x65, 0x25, 0x67, 0x25, 0x67, 0x26, 0x64, 0x25, 0x64, 0x25, 0x66, 0x25, 0x64, 0x25, 0x64, 0x25, 0x64, 0x25, 0x67, 0x26, 0x69, 0x28, 0x5B, 0x26, 0x52, 0x27, 0x50, 0x28, 0x4F, 0x27, 0x4D, 0x26, 0x4E, 0x27, 0x48, 0x21, 0x38, 0x1C, 0x4E, 0x23, 0x61, 0x24, 0x65, 0x26, 0x69, 0x28, 0x6C, 0x28, 0x6B, 0x27, 0x67, 0x26, 0x6A, 0x27, 0x69, 0x26, 0x69, 0x26, 0x6B, 0x28, 0x6C, 0x2A, 0x6C, 0x29, 0x68, 0x26, 0x68, 0x26, 0x69, 0x26, 0x66, 0x26, 0x69, 0x28, 0x6A, 0x28, 0x67, 0x26, 0x5C, 0x26, 0x52, 0x27, 0x57, 0x2B, 0x54, 0x2A, 0x53, 0x29, 0x4F, 0x25, 0x38, 0x1C, 0x3F, 0x1F, 0x5D, 0x29, 0x70, 0x2D, 0x77, 0x31, 0x78, 0x2F, 0x77, 0x2F, 0x77, 0x2E, 0x73, 0x2F, 0x74, 0x31, 0x84, 0x38, 0x7E, 0x37, 0x95, 0x45, 0x97, 0x45, 0x91, 0x43, 0xA8, 0x4B, 0x80, 0x38, 0x7D, 0x36, 0x7F, 0x39, 0x8C, 0x43, 0xA9, 0x4E, 0x81, 0x35, 0x89, 0x3E, 0xA7, 0x52, 0x98, 0x44, 0x9E, 0x45, 0x77, 0x32, 0x80, 0x3D, 0x9D, 0x4F, 0x94, 0x3D, 0x8A, 0x42, 0x90, 0x43, 0x9D, 0x4C, 0xA8, 0x59, 0xAC, 0x52, 0xA9, 0x5A, 0xD1, 0x6F, 0xD8, 0x73, 0xBF, 0x5D, 0xBA, 0x60, 0xA7, 0x4D, 0xA3, 0x51, 0xAC, 0x52, 0xA8, 0x55, 0xB4, 0x5B, 0xAD, 0x55, 0xB9, 0x60, 0xB8, 0x62, 0xC2, 0x63, 0xAB, 0x55, 0xC0, 0x60, 0xAA, 0x53, 0xBC, 0x63, 0xC0, 0x58, 0x97, 0x45, 0xA7, 0x55, 0x9B, 0x47, 0x97, 0x46, 0xA0, 0x4A, 0x9D, 0x4A, 0xA6, 0x52, 0x91, 0x42, 0x97, 0x4D, 0xA5, 0x4B, 0x97, 0x4B, 0x96, 0x45, 0x8B, 0x43, 0x9B, 0x4C, 0xA1, 0x4A, 0x97, 0x48, 0xAC, 0x56, 0xA1, 0x4C, 0x8C, 0x3E, 0x82, 0x3B, 0x91, 0x42, 0x87, 0x3D, 0x9F, 0x4E, 0x9B, 0x49, 0x86, 0x3D, 0x94, 0x45, 0x8F, 0x41, 0x8D, 0x40, 0x76, 0x30, 0x91, 0x4B, 0x9A, 0x47, 0x8D, 0x3B, 0x84, 0x3C, 0x87, 0x3B, 0x7C, 0x32, 0x72, 0x31, 0x7D, 0x35, 0x77, 0x32, 0x83, 0x38, 0x7B, 0x35, 0x86, 0x3B, 0x79, 0x33, 0x6C, 0x2A, 0x69, 0x29, 0x6A, 0x29, 0x66, 0x26, 0x64, 0x28, 0x66, 0x28, 0x6B, 0x28, 0x6F, 0x2A, 0x6E, 0x2B, 0x6B, 0x2B, 0x64, 0x26, 0x65, 0x26, 0x66, 0x26, 0x64, 0x26, 0x62, 0x27, 0x63, 0x26, 0x66, 0x26, 0x60, 0x25, 0x5E, 0x24, 0x60, 0x25, 0x5E, 0x24, 0x62, 0x26, 0x68, 0x28, 0x62, 0x26, 0x61, 0x25, 0x61, 0x27, 0x6A, 0x28, 0x64, 0x25, 0x63, 0x26, 0x66, 0x26, 0x66, 0x26, 0x65, 0x26, 0x69, 0x29, 0x68, 0x29, 0x65, 0x28, 0x62, 0x26, 0x5C, 0x23, 0x5D, 0x23, 0x5F, 0x24, 0x62, 0x27, 0x73, 0x30, 0x64, 0x27, 0x62, 0x27, 0x61, 0x27, 0x62, 0x26, 0x62, 0x26, 0x63, 0x28, 0x69, 0x2B, 0x73, 0x34, 0x76, 0x36, 0x7A, 0x37, 0x8E, 0x46, 0x9C, 0x51, 0x9C, 0x4A, 0x93, 0x48, 0x90, 0x3E, 0x8D, 0x47, 0x89, 0x40, 0x84, 0x3E, 0x7C, 0x37, 0x79, 0x38, 0x8F, 0x46, 0x85, 0x3C, 0x78, 0x37, 0x7E, 0x36, 0x74, 0x34, 0x78, 0x35, 0x80, 0x3B, 0x7E, 0x39, 0x6D, 0x2E, 0x6E, 0x2F, 0x65, 0x29, 0x60, 0x27, 0x6C, 0x2E, 0x69, 0x29, 0x64, 0x28, 0x64, 0x28, 0x60, 0x26, 0x53, 0x27, 0x48, 0x26, 0x4E, 0x29, 0x47, 0x26, 0x48, 0x26, 0x47, 0x24, 0x3A, 0x37, 0x35, 0x3B, 0x31, 0x37, 0x2F, 0x30, 0x2C, 0x2E, 0x29, 0x27, 0x28, 0x20, 0x30, 0x20, 0x3B, 0x20, 0x46, 0x26, 0x40, 0x24, 0x39, 0x20, 0x36, 0x20, 0x32, 0x1D, 0x39, 0x21, 0x3A, 0x1F, 0x42, 0x24, 0x42, 0x24, 0x4B, 0x28, 0x4D, 0x28, 0x48, 0x26, 0x48, 0x26, 0x51, 0x2B, 0x47, 0x26, 0x4C, 0x29, 0x47, 0x27, 0x4F, 0x29, 0x43, 0x25, 0x45, 0x27, 0x46, 0x27, 0x4D, 0x29, 0x44, 0x24, 0x45, 0x25, 0x45, 0x26, 0x44, 0x23, 0x45, 0x24, 0x4C, 0x27, 0x3C, 0x20, 0x4C, 0x28, 0x47, 0x25, 0x49, 0x26, 0x42, 0x23, 0x4C, 0x27, 0x45, 0x24
    },

    {
        0x61, 0x56, 0x5F, 0x54, 0x60, 0x54, 0x60, 0x54, 0x64, 0x56, 0x64, 0x5A, 0x63, 0x5B, 0x62, 0x5B, 0x67, 0x61, 0x6A, 0x5F, 0x6F, 0x60, 0x6E, 0x5E, 0x6E, 0x60, 0x6E, 0x5D, 0x6D, 0x5F, 0x71, 0x61, 0x73, 0x63, 0x72, 0x64, 0x76, 0x67, 0x78, 0x67, 0x74, 0x64, 0x75, 0x66, 0x77, 0x67, 0x72, 0x61, 0x72, 0x61, 0x71, 0x60, 0x71, 0x61, 0x73, 0x63, 0x75, 0x65, 0x76, 0x65, 0x74, 0x62, 0x74, 0x67, 0x7A, 0x67, 0x7A, 0x69, 0x76, 0x67, 0x74, 0x64, 0x6D, 0x5E, 0x65, 0x59, 0x64, 0x59, 0x65, 0x59, 0x69, 0x5E, 0x71, 0x63, 0x76, 0x69, 0x76, 0x68, 0x78, 0x68, 0x77, 0x67, 0x78, 0x67, 0x77, 0x65, 0x78, 0x66, 0x79, 0x66, 0x76, 0x66, 0x78, 0x67, 0x7D, 0x6A, 0x7C, 0x6B, 0x7A, 0x69, 0x79, 0x69, 0x7A, 0x67, 0x7A, 0x69, 0x7A, 0x68, 0x78, 0x68, 0x7A, 0x6C, 0x7D, 0x6D, 0x69, 0x5B, 0x59, 0x55, 0x54, 0x54, 0x52, 0x52, 0x4F, 0x4E, 0x50, 0x51, 0x4A, 0x46, 0x3B, 0x3A, 0x57, 0x54, 0x6E, 0x62, 0x79, 0x6A, 0x7E, 0x6E, 0x82, 0x70, 0x7F, 0x6C, 0x7C, 0x6C, 0x7D, 0x6D, 0x7D, 0x6E, 0x7D, 0x6B, 0x7C, 0x6F, 0x80, 0x73, 0x80, 0x70, 0x79, 0x68, 0x7C, 0x6B, 0x7E, 0x6C, 0x7C, 0x6B, 0x7B, 0x6C, 0x7A, 0x6D, 0x76, 0x68, 0x6A, 0x5A, 0x58, 0x56, 0x5A, 0x5A, 0x56, 0x59, 0x55, 0x56, 0x4E, 0x4D, 0x3B, 0x38, 0x4A, 0x49, 0x6A, 0x67, 0x7E, 0x74, 0x86, 0x7C, 0x89, 0x7B, 0x8A, 0x7E, 0x89, 0x77, 0x85, 0x7A, 0x86, 0x7F, 0x93, 0x8C, 0x8E, 0x87, 0x9C, 0x97, 0x9B, 0x97, 0x9B, 0x99, 0xAA, 0xAA, 0x90, 0x83, 0x8B, 0x80, 0x8D, 0x85, 0x94, 0x92, 0xA5, 0xAA, 0x90, 0x84, 0x98, 0x93, 0xA5, 0xB2, 0xA0, 0xA0, 0xA0, 0x9D, 0x89, 0x7D, 0x89, 0x88, 0x9B, 0x9B, 0x99, 0x8D, 0x9A, 0x92, 0x9B, 0x95, 0xA5, 0xAB, 0xB1, 0xC1, 0xAC, 0xAC, 0xA7, 0xAE, 0xC4, 0xD8, 0xC5, 0xD7, 0xBA, 0xBC, 0xBB, 0xC6, 0xAD, 0xAA, 0xB0, 0xBA, 0xB3, 0xB1, 0xA6, 0xAC, 0xAD, 0xB8, 0xB5, 0xB4, 0xB4, 0xC0, 0xB5, 0xBB, 0xB9, 0xBD, 0xA8, 0xAF, 0xC0, 0xCB, 0xB8, 0xBC, 0xB8, 0xC0, 0xB4, 0xB7, 0xA0, 0x9C, 0xAB, 0xB4, 0xA4, 0x9E, 0x9E, 0x9D, 0xA6, 0xA5, 0xA4, 0x9E, 0xA7, 0xAD, 0x99, 0x8E, 0x98, 0x99, 0xA8, 0xAA, 0x9F, 0xA0, 0x9E, 0x98, 0x96, 0x8F, 0x9C, 0x9F, 0xA1, 0x9C, 0x9F, 0xA0, 0xA9, 0xAE, 0xA1, 0x9C, 0x91, 0x8B, 0x8D, 0x86, 0x9A, 0x96, 0x92, 0x8B, 0xA4, 0xAA, 0xA0, 0xA0, 0x8D, 0x86, 0x97, 0x97, 0x95, 0x8D, 0x97, 0x95, 0x86, 0x79, 0x9C, 0xA5, 0xA3, 0xA0, 0x95, 0x87, 0x8C, 0x86, 0x93, 0x8B, 0x8A, 0x7B, 0x81, 0x77, 0x8C, 0x84, 0x87, 0x7C, 0x91, 0x8A, 0x87, 0x7E, 0x8C, 0x86, 0x86, 0x7C, 0x7D, 0x71, 0x7E, 0x6F, 0x7D, 0x6D, 0x78, 0x69, 0x76, 0x6C, 0x79, 0x6C, 0x80, 0x71, 0x87, 0x78, 0x82, 0x74, 0x7C, 0x6F, 0x76, 0x68, 0x75, 0x68, 0x78, 0x67, 0x7A, 0x67, 0x76, 0x67, 0x74, 0x67, 0x76, 0x69, 0x72, 0x66, 0x72, 0x64, 0x73, 0x66, 0x71, 0x63, 0x72, 0x67, 0x76, 0x68, 0x71, 0x66, 0x74, 0x66, 0x74, 0x68, 0x7B, 0x6D, 0x79, 0x68, 0x75, 0x68, 0x79, 0x6A, 0x79, 0x6A, 0x77, 0x68, 0x7B, 0x6E, 0x7B, 0x6B, 0x78, 0x6A, 0x73, 0x65, 0x72, 0x62, 0x72, 0x64, 0x73, 0x66, 0x76, 0x6A, 0x7E, 0x78, 0x77, 0x68, 0x73, 0x68, 0x71, 0x63, 0x73, 0x68, 0x74, 0x65, 0x74, 0x67, 0x7B, 0x72, 0x81, 0x7A, 0x83, 0x82, 0x88, 0x83, 0x96, 0x99, 0xA1, 0xAA, 0x9F, 0x9C, 0x98, 0x9D, 0x9B, 0x91, 0x99, 0x98, 0x96, 0x94, 0x8D, 0x87, 0x85, 0x7E, 0x85, 0x82, 0x92, 0x97, 0x8C, 0x85, 0x84, 0x80, 0x89, 0x7D, 0x82, 0x7C, 0x86, 0x80, 0x87, 0x85, 0x87, 0x80, 0x7A, 0x72, 0x7B, 0x74, 0x74, 0x66, 0x71, 0x67, 0x7A, 0x73, 0x7B, 0x6D, 0x75, 0x6A, 0x75, 0x69, 0x71, 0x63, 0x54, 0x53, 0x41, 0x45, 0x47, 0x51, 0x42, 0x47, 0x44, 0x4D, 0x40, 0x45, 0x33, 0x3E, 0x27, 0x31, 0x24, 0x2F, 0x23, 0x2C, 0x22, 0x2C, 0x22, 0x29, 0x22, 0x29, 0x2F, 0x3B, 0x39, 0x3E, 0x40, 0x49, 0x3D, 0x44, 0x3A, 0x42, 0x38, 0x40, 0x34, 0x3A, 0x3A, 0x42, 0x3C, 0x44, 0x43, 0x4E, 0x3F, 0x46, 0x4A, 0x54, 0x47, 0x4D, 0x44, 0x4C, 0x43, 0x4B, 0x48, 0x53, 0x3E, 0x45, 0x45, 0x4C, 0x40, 0x4A, 0x45, 0x4C, 0x3C, 0x41, 0x40, 0x49, 0x43, 0x4D, 0x47, 0x50, 0x41, 0x4B, 0x40, 0x44, 0x40, 0x4B, 0x41, 0x48, 0x43, 0x4D, 0x49, 0x4D, 0x39, 0x40, 0x47, 0x51, 0x40, 0x49, 0x42, 0x4A, 0x3D, 0x47, 0x43, 0x49, 0x3E, 0x48
    },

    {
        0x55, 0x1E, 0x53, 0x1E, 0x50, 0x1D, 0x52, 0x1E, 0x51, 0x1F, 0x53, 0x22, 0x57, 0x24, 0x57, 0x25, 0x5B, 0x25, 0x5A, 0x22, 0x5B, 0x22, 0x59, 0x21, 0x5A, 0x21, 0x5B, 0x20, 0x5C, 0x21, 0x5F, 0x23, 0x63, 0x24, 0x61, 0x24, 0x63, 0x25, 0x65, 0x24, 0x63, 0x23, 0x63, 0x24, 0x61, 0x23, 0x5E, 0x22, 0x60, 0x23, 0x5F, 0x23, 0x5F, 0x23, 0x60, 0x24, 0x62, 0x24, 0x61, 0x25, 0x63, 0x25, 0x64, 0x25, 0x64, 0x25, 0x62, 0x24, 0x64, 0x26, 0x67, 0x26, 0x63, 0x26, 0x64, 0x26, 0x63, 0x26, 0x65, 0x27, 0x64, 0x26, 0x61, 0x24, 0x64, 0x26, 0x65, 0x25, 0x65, 0x26, 0x64, 0x25, 0x61, 0x24, 0x61, 0x24, 0x65, 0x25, 0x66, 0x25, 0x63, 0x24, 0x62, 0x24, 0x64, 0x24, 0x65, 0x25, 0x64, 0x25, 0x64, 0x26, 0x66, 0x26, 0x66, 0x25, 0x66, 0x25, 0x65, 0x25, 0x66, 0x26, 0x67, 0x26, 0x5B, 0x24, 0x52, 0x26, 0x51, 0x27, 0x51, 0x29, 0x55, 0x2B, 0x51, 0x26, 0x3F, 0x1E, 0x38, 0x1C, 0x4E, 0x23, 0x5F, 0x24, 0x63, 0x25, 0x68, 0x26, 0x69, 0x26, 0x68, 0x26, 0x69, 0x26, 0x69, 0x26, 0x68, 0x27, 0x6B, 0x27, 0x68, 0x28, 0x6B, 0x28, 0x67, 0x28, 0x66, 0x26, 0x65, 0x25, 0x69, 0x26, 0x68, 0x26, 0x69, 0x27, 0x66, 0x26, 0x65, 0x27, 0x5D, 0x24, 0x4D, 0x21, 0x4B, 0x23, 0x43, 0x21, 0x3F, 0x1F, 0x37, 0x1D, 0x3C, 0x1F, 0x4D, 0x23, 0x64, 0x29, 0x6C, 0x2B, 0x70, 0x2C, 0x72, 0x2D, 0x73, 0x2E, 0x71, 0x2C, 0x70, 0x2D, 0x76, 0x32, 0x7A, 0x37, 0x8C, 0x3D, 0x7F, 0x38, 0x87, 0x3F, 0x98, 0x49, 0xB6, 0x5F, 0x96, 0x40, 0x87, 0x3A, 0x80, 0x38, 0x85, 0x3E, 0x97, 0x4A, 0x88, 0x3B, 0x9E, 0x48, 0x8D, 0x44, 0xA6, 0x4E, 0x8B, 0x3E, 0x7C, 0x34, 0x80, 0x38, 0x7E, 0x39, 0x9F, 0x51, 0xBA, 0x56, 0xA2, 0x4F, 0xBE, 0x5E, 0xCB, 0x6A, 0xAB, 0x51, 0x98, 0x4C, 0xC5, 0x64, 0xA5, 0x50, 0xA7, 0x54, 0x9F, 0x4B, 0xA0, 0x52, 0xBB, 0x61, 0xC2, 0x63, 0xB6, 0x5E, 0xBF, 0x60, 0xB3, 0x57, 0xAE, 0x59, 0xB5, 0x5D, 0xB5, 0x57, 0xAB, 0x56, 0xC8, 0x6C, 0xC3, 0x67, 0xAD, 0x52, 0x9C, 0x4E, 0xA9, 0x52, 0xA2, 0x4E, 0x92, 0x42, 0x8C, 0x42, 0x9F, 0x4C, 0xA0, 0x4E, 0x9A, 0x4B, 0x8B, 0x3F, 0x86, 0x3D, 0x9A, 0x4E, 0x93, 0x41, 0x92, 0x46, 0x91, 0x44, 0x9D, 0x4D, 0x94, 0x42, 0xA3, 0x52, 0x99, 0x41, 0x81, 0x35, 0x83, 0x37, 0x84, 0x3B, 0x8D, 0x41, 0x8D, 0x41, 0xA2, 0x53, 0x99, 0x4A, 0x87, 0x3F, 0x89, 0x3D, 0x89, 0x41, 0x95, 0x43, 0x7E, 0x37, 0x9F, 0x53, 0x99, 0x46, 0x83, 0x39, 0x84, 0x3D, 0x8B, 0x40, 0x7A, 0x32, 0x71, 0x2F, 0x76, 0x32, 0x7B, 0x37, 0x7E, 0x36, 0x72, 0x30, 0x7D, 0x35, 0x73, 0x2F, 0x6C, 0x2A, 0x69, 0x29, 0x6A, 0x29, 0x63, 0x25, 0x63, 0x28, 0x6C, 0x2B, 0x6C, 0x29, 0x70, 0x2B, 0x6D, 0x2D, 0x6C, 0x2A, 0x66, 0x28, 0x63, 0x26, 0x65, 0x27, 0x63, 0x26, 0x63, 0x26, 0x64, 0x26, 0x64, 0x26, 0x66, 0x28, 0x66, 0x27, 0x64, 0x27, 0x64, 0x27, 0x66, 0x28, 0x62, 0x27, 0x63, 0x26, 0x61, 0x26, 0x63, 0x26, 0x66, 0x27, 0x64, 0x26, 0x63, 0x26, 0x63, 0x26, 0x65, 0x26, 0x63, 0x26, 0x64, 0x29, 0x65, 0x26, 0x61, 0x25, 0x60, 0x25, 0x5E, 0x23, 0x5D, 0x23, 0x5D, 0x23, 0x61, 0x26, 0x66, 0x2A, 0x64, 0x29, 0x65, 0x28, 0x61, 0x25, 0x65, 0x29, 0x69, 0x2B, 0x65, 0x29, 0x76, 0x35, 0x76, 0x35, 0x7B, 0x3A, 0x8A, 0x40, 0x92, 0x47, 0x90, 0x48, 0x94, 0x47, 0x97, 0x4C, 0x91, 0x43, 0x8B, 0x42, 0x99, 0x4C, 0x84, 0x3C, 0x7F, 0x3C, 0x88, 0x41, 0x87, 0x40, 0x7A, 0x38, 0x77, 0x37, 0x7E, 0x38, 0x79, 0x37, 0x7E, 0x38, 0x75, 0x32, 0x6B, 0x2D, 0x6B, 0x2D, 0x68, 0x2A, 0x60, 0x28, 0x67, 0x2A, 0x66, 0x2A, 0x63, 0x28, 0x63, 0x28, 0x64, 0x28, 0x61, 0x26, 0x55, 0x29, 0x4A, 0x27, 0x54, 0x2C, 0x4C, 0x28, 0x43, 0x24, 0x44, 0x25, 0x45, 0x25, 0x30, 0x1D, 0x2E, 0x1C, 0x38, 0x21, 0x38, 0x21, 0x3C, 0x22, 0x4A, 0x27, 0x51, 0x2B, 0x52, 0x2C, 0x4C, 0x28, 0x55, 0x2D, 0x55, 0x2D, 0x4E, 0x29, 0x43, 0x25, 0x53, 0x2D, 0x48, 0x27, 0x50, 0x2C, 0x43, 0x26, 0x56, 0x2E, 0x3F, 0x22, 0x48, 0x28, 0x44, 0x24, 0x45, 0x25, 0x3D, 0x22, 0x4A, 0x27, 0x47, 0x26, 0x40, 0x24, 0x49, 0x27, 0x4B, 0x29, 0x54, 0x2E, 0x51, 0x2C, 0x4C, 0x2A, 0x3F, 0x21, 0x49, 0x28, 0x47, 0x24, 0x47, 0x26, 0x48, 0x25, 0x3D, 0x20, 0x4C, 0x28, 0x3F, 0x22, 0x3F, 0x21, 0x3F, 0x23, 0x3D, 0x20, 0x3E, 0x21
    },

    {
        0x62, 0x57, 0x62, 0x56, 0x60, 0x54, 0x5F, 0x54, 0x61, 0x55, 0x61, 0x57, 0x61, 0x59, 0x62, 0x5A, 0x66, 0x5A, 0x69, 0x5B, 0x6C, 0x5C, 0x69, 0x5B, 0x6C, 0x5D, 0x6C, 0x5C, 0x6D, 0x60, 0x72, 0x63, 0x73, 0x65, 0x73, 0x65, 0x76, 0x67, 0x76, 0x67, 0x75, 0x65, 0x76, 0x67, 0x76, 0x65, 0x72, 0x63, 0x74, 0x64, 0x71, 0x62, 0x73, 0x60, 0x75, 0x66, 0x76, 0x64, 0x75, 0x65, 0x77, 0x67, 0x78, 0x66, 0x78, 0x67, 0x78, 0x66, 0x7A, 0x68, 0x7B, 0x6A, 0x75, 0x66, 0x76, 0x67, 0x76, 0x69, 0x75, 0x69, 0x79, 0x69, 0x74, 0x64, 0x77, 0x68, 0x79, 0x69, 0x79, 0x68, 0x76, 0x67, 0x74, 0x64, 0x75, 0x66, 0x79, 0x68, 0x79, 0x69, 0x77, 0x67, 0x77, 0x64, 0x78, 0x67, 0x7B, 0x68, 0x7A, 0x69, 0x79, 0x6A, 0x7A, 0x6A, 0x79, 0x68, 0x78, 0x6A, 0x7B, 0x69, 0x7B, 0x69, 0x7B, 0x6A, 0x6C, 0x5C, 0x5A, 0x56, 0x55, 0x53, 0x51, 0x54, 0x54, 0x55, 0x4E, 0x4C, 0x3D, 0x39, 0x3F, 0x3D, 0x59, 0x57, 0x6E, 0x62, 0x76, 0x66, 0x7C, 0x6C, 0x7E, 0x6B, 0x7D, 0x6C, 0x7E, 0x6B, 0x7D, 0x6D, 0x80, 0x70, 0x81, 0x6D, 0x7B, 0x6D, 0x7C, 0x6D, 0x7A, 0x6B, 0x7D, 0x6D, 0x7B, 0x6B, 0x7F, 0x6C, 0x7C, 0x6C, 0x7E, 0x6D, 0x79, 0x6A, 0x7A, 0x69, 0x71, 0x61, 0x5D, 0x4F, 0x4E, 0x49, 0x41, 0x3D, 0x3C, 0x3D, 0x39, 0x38, 0x43, 0x43, 0x5C, 0x59, 0x73, 0x6A, 0x7C, 0x71, 0x81, 0x74, 0x84, 0x75, 0x86, 0x7A, 0x88, 0x75, 0x83, 0x74, 0x87, 0x7E, 0x8B, 0x81, 0x95, 0x8E, 0x8C, 0x85, 0x94, 0x8D, 0x9F, 0x9E, 0xAF, 0xBF, 0x9C, 0x90, 0x93, 0x8A, 0x8C, 0x85, 0x8F, 0x8B, 0x9B, 0xA0, 0x94, 0x88, 0xA1, 0x9F, 0x95, 0x8F, 0xA4, 0x9F, 0x8E, 0x85, 0x88, 0x7F, 0x8E, 0x86, 0x8D, 0x88, 0xAC, 0xB9, 0xBB, 0xC1, 0xAF, 0xAB, 0xB7, 0xBE, 0xBB, 0xCC, 0xB0, 0xAD, 0xA5, 0xA5, 0xC1, 0xC6, 0xA6, 0xA1, 0xA8, 0xAE, 0x9B, 0x94, 0x9F, 0xA1, 0xB9, 0xBF, 0xBE, 0xC7, 0xBE, 0xC6, 0xC0, 0xC7, 0xAF, 0xB1, 0xAC, 0xAD, 0xB3, 0xC5, 0xB5, 0xB3, 0xAD, 0xB2, 0xC0, 0xCB, 0xB5, 0xC0, 0xAF, 0xAC, 0x9E, 0xA0, 0xAD, 0xB0, 0xA5, 0xA2, 0x9B, 0x94, 0x96, 0x95, 0xA7, 0xA8, 0xA3, 0xA8, 0xA2, 0x9F, 0x94, 0x8F, 0x95, 0x8A, 0x9C, 0xA4, 0x9C, 0x92, 0xA1, 0x9E, 0x9A, 0x9A, 0xA3, 0xA5, 0x9A, 0x94, 0xA1, 0xAB, 0x9F, 0x96, 0x90, 0x84, 0x93, 0x88, 0x9A, 0x97, 0x97, 0x96, 0x9A, 0x96, 0xA2, 0xA3, 0x9F, 0xA0, 0x96, 0x92, 0x93, 0x8C, 0x8F, 0x90, 0x9A, 0x96, 0x8D, 0x87, 0xA7, 0xB0, 0xA2, 0x9B, 0x8E, 0x85, 0x8D, 0x8D, 0x97, 0x96, 0x89, 0x7B, 0x83, 0x77, 0x83, 0x7B, 0x8C, 0x85, 0x88, 0x7F, 0x85, 0x7A, 0x88, 0x7C, 0x83, 0x76, 0x79, 0x6D, 0x7D, 0x6D, 0x7D, 0x6F, 0x77, 0x68, 0x73, 0x69, 0x7B, 0x71, 0x7B, 0x70, 0x7B, 0x6E, 0x7E, 0x74, 0x7C, 0x6E, 0x79, 0x6B, 0x76, 0x68, 0x7A, 0x6A, 0x78, 0x68, 0x76, 0x67, 0x75, 0x69, 0x76, 0x68, 0x7A, 0x6D, 0x78, 0x6C, 0x76, 0x6A, 0x78, 0x68, 0x76, 0x6A, 0x71, 0x66, 0x76, 0x69, 0x72, 0x66, 0x77, 0x69, 0x79, 0x69, 0x77, 0x68, 0x76, 0x69, 0x75, 0x68, 0x76, 0x6A, 0x77, 0x6A, 0x76, 0x6A, 0x76, 0x67, 0x73, 0x63, 0x72, 0x65, 0x72, 0x63, 0x6E, 0x61, 0x6F, 0x61, 0x6F, 0x64, 0x71, 0x69, 0x74, 0x6A, 0x77, 0x6A, 0x72, 0x65, 0x77, 0x6B, 0x77, 0x6E, 0x76, 0x6B, 0x7F, 0x7B, 0x80, 0x7B, 0x86, 0x86, 0x92, 0x8B, 0x95, 0x94, 0x97, 0x97, 0x97, 0x98, 0x9C, 0xA0, 0x94, 0x91, 0x94, 0x93, 0x97, 0x98, 0x8E, 0x87, 0x8A, 0x85, 0x8C, 0x8F, 0x87, 0x83, 0x83, 0x7F, 0x86, 0x83, 0x88, 0x81, 0x87, 0x83, 0x86, 0x7F, 0x80, 0x77, 0x79, 0x6E, 0x7A, 0x70, 0x77, 0x6B, 0x71, 0x65, 0x75, 0x6D, 0x74, 0x69, 0x74, 0x68, 0x74, 0x67, 0x75, 0x6A, 0x70, 0x63, 0x5D, 0x5E, 0x47, 0x4E, 0x4C, 0x58, 0x43, 0x4A, 0x3B, 0x44, 0x3E, 0x45, 0x3F, 0x46, 0x30, 0x34, 0x30, 0x37, 0x3A, 0x43, 0x38, 0x3F, 0x3E, 0x48, 0x47, 0x53, 0x49, 0x54, 0x4C, 0x57, 0x46, 0x4D, 0x4F, 0x5C, 0x4A, 0x53, 0x45, 0x4F, 0x3D, 0x46, 0x4C, 0x56, 0x40, 0x46, 0x46, 0x51, 0x3D, 0x47, 0x4D, 0x55, 0x39, 0x3F, 0x43, 0x4D, 0x3E, 0x45, 0x41, 0x49, 0x3B, 0x44, 0x45, 0x4D, 0x41, 0x4C, 0x3D, 0x46, 0x45, 0x4C, 0x48, 0x55, 0x4A, 0x54, 0x48, 0x51, 0x43, 0x4B, 0x3A, 0x40, 0x45, 0x51, 0x3D, 0x43, 0x42, 0x4B, 0x3E, 0x46, 0x3A, 0x41, 0x42, 0x4A, 0x39, 0x40, 0x3A, 0x40, 0x3B, 0x44, 0x39, 0x3E, 0x3C, 0x44
    },

    {
        0x55, 0x1F, 0x53, 0x1E, 0x53, 0x1E, 0x52, 0x1D, 0x53, 0x1F, 0x56, 0x22, 0x58, 0x26, 0x5A, 0x25, 0x58, 0x22, 0x57, 0x20, 0x56, 0x21, 0x55, 0x1F, 0x57, 0x20, 0x5A, 0x20, 0x5B, 0x22, 0x5F, 0x23, 0x60, 0x22, 0x5E, 0x23, 0x63, 0x25, 0x65, 0x24, 0x66, 0x26, 0x62, 0x24, 0x63, 0x23, 0x62, 0x24, 0x60, 0x23, 0x5F, 0x22, 0x62, 0x23, 0x62, 0x23, 0x61, 0x24, 0x62, 0x25, 0x64, 0x24, 0x63, 0x24, 0x64, 0x24, 0x67, 0x26, 0x67, 0x26, 0x68, 0x27, 0x67, 0x28, 0x66, 0x27, 0x69, 0x29, 0x66, 0x26, 0x65, 0x26, 0x66, 0x25, 0x68, 0x27, 0x66, 0x25, 0x64, 0x25, 0x61, 0x24, 0x64, 0x24, 0x61, 0x23, 0x62, 0x23, 0x64, 0x25, 0x64, 0x24, 0x63, 0x23, 0x61, 0x24, 0x64, 0x24, 0x63, 0x24, 0x65, 0x24, 0x65, 0x25, 0x66, 0x25, 0x64, 0x24, 0x65, 0x25, 0x67, 0x26, 0x68, 0x28, 0x61, 0x25, 0x4F, 0x21, 0x49, 0x22, 0x45, 0x21, 0x43, 0x1F, 0x36, 0x1A, 0x30, 0x18, 0x3E, 0x1C, 0x57, 0x23, 0x62, 0x24, 0x63, 0x25, 0x66, 0x25, 0x66, 0x26, 0x67, 0x25, 0x6B, 0x27, 0x69, 0x26, 0x6B, 0x26, 0x6A, 0x27, 0x6A, 0x27, 0x6D, 0x27, 0x6B, 0x27, 0x67, 0x26, 0x67, 0x26, 0x6A, 0x27, 0x68, 0x27, 0x67, 0x26, 0x67, 0x25, 0x68, 0x27, 0x68, 0x28, 0x5D, 0x24, 0x4E, 0x21, 0x46, 0x1F, 0x42, 0x1E, 0x45, 0x20, 0x50, 0x22, 0x5F, 0x27, 0x6B, 0x2A, 0x6D, 0x2B, 0x71, 0x2A, 0x6E, 0x2B, 0x73, 0x30, 0x84, 0x38, 0x7B, 0x34, 0x7D, 0x33, 0x85, 0x3F, 0x83, 0x34, 0x7B, 0x36, 0x88, 0x3C, 0x8E, 0x44, 0xA8, 0x50, 0x8F, 0x41, 0x80, 0x38, 0x83, 0x38, 0x82, 0x3D, 0x90, 0x44, 0x87, 0x3E, 0x96, 0x43, 0x7C, 0x34, 0x81, 0x3B, 0x80, 0x36, 0x81, 0x3C, 0x86, 0x39, 0x86, 0x42, 0xB3, 0x5C, 0xAE, 0x59, 0xC3, 0x63, 0xB3, 0x59, 0xC7, 0x6B, 0xC8, 0x5F, 0xA2, 0x50, 0xAC, 0x55, 0x9C, 0x4B, 0xAB, 0x50, 0x9E, 0x4A, 0xA2, 0x4F, 0xB7, 0x64, 0xB3, 0x55, 0xAB, 0x5A, 0xAF, 0x56, 0x9C, 0x49, 0x9A, 0x49, 0xB1, 0x59, 0x9D, 0x4A, 0x9B, 0x4C, 0xAF, 0x60, 0xA4, 0x4F, 0xAB, 0x55, 0xA5, 0x50, 0xA2, 0x4E, 0x92, 0x3F, 0xA2, 0x4E, 0x8B, 0x3F, 0xA7, 0x53, 0xA3, 0x4C, 0x96, 0x46, 0x9B, 0x49, 0xA6, 0x51, 0xA7, 0x50, 0xA4, 0x4D, 0xB1, 0x5B, 0xAE, 0x58, 0x95, 0x45, 0x8C, 0x42, 0x92, 0x44, 0x9C, 0x4B, 0x91, 0x41, 0x94, 0x46, 0x9C, 0x4C, 0x97, 0x43, 0x93, 0x48, 0xA5, 0x4D, 0x91, 0x41, 0x8C, 0x46, 0x98, 0x47, 0x88, 0x3C, 0x8B, 0x40, 0x81, 0x3A, 0x9A, 0x49, 0x93, 0x41, 0x87, 0x3B, 0x87, 0x41, 0x86, 0x38, 0x75, 0x2F, 0x75, 0x31, 0x72, 0x31, 0x86, 0x3B, 0x7C, 0x35, 0x79, 0x2F, 0x75, 0x32, 0x6F, 0x2D, 0x6D, 0x2B, 0x68, 0x29, 0x6B, 0x2B, 0x65, 0x26, 0x60, 0x24, 0x64, 0x26, 0x61, 0x25, 0x5F, 0x26, 0x6C, 0x2E, 0x67, 0x27, 0x66, 0x27, 0x65, 0x27, 0x69, 0x29, 0x63, 0x26, 0x66, 0x27, 0x63, 0x25, 0x65, 0x26, 0x68, 0x28, 0x64, 0x26, 0x61, 0x24, 0x61, 0x26, 0x66, 0x28, 0x63, 0x27, 0x65, 0x28, 0x63, 0x26, 0x62, 0x26, 0x66, 0x26, 0x65, 0x25, 0x63, 0x25, 0x63, 0x25, 0x67, 0x27, 0x65, 0x26, 0x6A, 0x2B, 0x6A, 0x29, 0x63, 0x25, 0x62, 0x25, 0x5F, 0x24, 0x60, 0x24, 0x61, 0x26, 0x64, 0x27, 0x61, 0x27, 0x6A, 0x2B, 0x72, 0x2E, 0x62, 0x25, 0x6C, 0x2C, 0x66, 0x29, 0x6B, 0x2A, 0x71, 0x2F, 0x74, 0x32, 0x76, 0x32, 0x81, 0x3B, 0x82, 0x3C, 0x91, 0x46, 0x91, 0x48, 0x92, 0x45, 0x7E, 0x37, 0x86, 0x3F, 0x7D, 0x3A, 0x87, 0x40, 0x7C, 0x38, 0x7F, 0x3C, 0x7A, 0x39, 0x78, 0x35, 0x7B, 0x39, 0x7B, 0x36, 0x74, 0x32, 0x76, 0x36, 0x75, 0x34, 0x6F, 0x2F, 0x68, 0x2A, 0x65, 0x29, 0x5F, 0x27, 0x65, 0x29, 0x65, 0x28, 0x64, 0x28, 0x64, 0x26, 0x61, 0x26, 0x5F, 0x26, 0x58, 0x2B, 0x4C, 0x27, 0x4A, 0x28, 0x47, 0x26, 0x4E, 0x29, 0x52, 0x29, 0x47, 0x25, 0x49, 0x28, 0x4C, 0x27, 0x4D, 0x2A, 0x46, 0x25, 0x53, 0x2C, 0x4A, 0x27, 0x40, 0x22, 0x4E, 0x2B, 0x49, 0x27, 0x4E, 0x2A, 0x43, 0x25, 0x49, 0x27, 0x3E, 0x23, 0x4B, 0x28, 0x44, 0x26, 0x4C, 0x2A, 0x4C, 0x29, 0x52, 0x2A, 0x46, 0x24, 0x4B, 0x27, 0x48, 0x26, 0x4F, 0x29, 0x49, 0x27, 0x51, 0x2A, 0x4A, 0x28, 0x50, 0x2A, 0x48, 0x26, 0x4B, 0x29, 0x44, 0x26, 0x4B, 0x29, 0x3D, 0x21, 0x44, 0x24, 0x4F, 0x2A, 0x3D, 0x21, 0x46, 0x25, 0x40, 0x21, 0x45, 0x25, 0x44, 0x25, 0x3E, 0x21, 0x4C, 0x27, 0x4B, 0x27, 0x45, 0x23, 0x48, 0x27
    },

    {
        0x61, 0x56, 0x61, 0x55, 0x61, 0x55, 0x61, 0x55, 0x62, 0x56, 0x64, 0x59, 0x64, 0x5D, 0x63, 0x5D, 0x66, 0x5B, 0x66, 0x5A, 0x66, 0x57, 0x65, 0x58, 0x68, 0x5B, 0x6C, 0x5C, 0x6B, 0x5E, 0x70, 0x62, 0x73, 0x62, 0x71, 0x62, 0x74, 0x66, 0x75, 0x67, 0x77, 0x68, 0x78, 0x66, 0x75, 0x65, 0x76, 0x67, 0x74, 0x63, 0x73, 0x61, 0x75, 0x65, 0x77, 0x64, 0x76, 0x65, 0x77, 0x67, 0x7A, 0x66, 0x77, 0x65, 0x77, 0x67, 0x79, 0x69, 0x7D, 0x6B, 0x7D, 0x6B, 0x7A, 0x6A, 0x7A, 0x6A, 0x7B, 0x6D, 0x79, 0x6A, 0x7B, 0x69, 0x7C, 0x6B, 0x7D, 0x6C, 0x7B, 0x69, 0x7A, 0x68, 0x7A, 0x67, 0x7B, 0x68, 0x78, 0x66, 0x79, 0x66, 0x7A, 0x69, 0x78, 0x67, 0x75, 0x64, 0x77, 0x66, 0x7A, 0x67, 0x7A, 0x68, 0x7A, 0x69, 0x77, 0x67, 0x79, 0x69, 0x7A, 0x69, 0x7A, 0x6A, 0x7D, 0x6B, 0x79, 0x6A, 0x72, 0x64, 0x5E, 0x50, 0x4F, 0x47, 0x47, 0x43, 0x41, 0x3C, 0x38, 0x34, 0x37, 0x34, 0x4B, 0x47, 0x66, 0x5F, 0x73, 0x66, 0x75, 0x66, 0x7A, 0x6A, 0x7B, 0x6A, 0x7E, 0x6C, 0x7E, 0x6B, 0x7E, 0x6E, 0x80, 0x6D, 0x80, 0x6E, 0x81, 0x70, 0x83, 0x6E, 0x81, 0x71, 0x7D, 0x6B, 0x7C, 0x6A, 0x7E, 0x6E, 0x7F, 0x6D, 0x7D, 0x6C, 0x7C, 0x6C, 0x7C, 0x6C, 0x7A, 0x6B, 0x70, 0x64, 0x60, 0x56, 0x53, 0x4E, 0x4F, 0x48, 0x56, 0x50, 0x63, 0x5E, 0x72, 0x69, 0x7C, 0x71, 0x80, 0x74, 0x84, 0x75, 0x85, 0x75, 0x88, 0x7A, 0x92, 0x8D, 0x8E, 0x83, 0x8D, 0x81, 0x93, 0x99, 0x91, 0x82, 0x8A, 0x82, 0x97, 0x92, 0x98, 0x96, 0xAB, 0xAC, 0x99, 0x8D, 0x90, 0x88, 0x94, 0x8C, 0x90, 0x8D, 0x97, 0x96, 0x8E, 0x8D, 0x99, 0x8E, 0x89, 0x7E, 0x93, 0x96, 0x8F, 0x88, 0x8B, 0x8A, 0x91, 0x89, 0x94, 0x97, 0xAF, 0xB7, 0xA8, 0xB0, 0xBA, 0xC4, 0xB3, 0xB4, 0xBD, 0xCD, 0xC1, 0xC0, 0xA8, 0xA5, 0xA2, 0xA3, 0xA7, 0xAB, 0xAA, 0xA9, 0xAA, 0xA8, 0xAF, 0xB2, 0xB8, 0xC5, 0xAE, 0xAF, 0xAB, 0xB0, 0xA9, 0xA9, 0xA3, 0x9F, 0xA1, 0xA3, 0xB4, 0xB9, 0xA2, 0x9E, 0xA0, 0xA2, 0xA5, 0xB0, 0xA4, 0xA1, 0xA5, 0xAF, 0xA9, 0xAB, 0xA6, 0xA6, 0x9D, 0x96, 0xA7, 0xA8, 0x98, 0x92, 0xA8, 0xAC, 0xA7, 0xA6, 0xA2, 0x9C, 0xA4, 0xA0, 0xAB, 0xB4, 0xA9, 0xAA, 0xAA, 0xAE, 0xB6, 0xC6, 0xAE, 0xB9, 0x9A, 0x97, 0x90, 0x91, 0x9D, 0x98, 0xA6, 0xA8, 0xA2, 0xA0, 0xA4, 0xA3, 0x9F, 0xA2, 0xA0, 0x98, 0x9C, 0x9F, 0xB2, 0xB6, 0xA5, 0xA0, 0x98, 0x98, 0x9F, 0x99, 0x92, 0x89, 0x99, 0x95, 0x94, 0x8C, 0xA1, 0x9F, 0x99, 0x92, 0x94, 0x8F, 0x90, 0x92, 0x8C, 0x82, 0x87, 0x79, 0x82, 0x7A, 0x84, 0x7B, 0x91, 0x8A, 0x8A, 0x82, 0x85, 0x77, 0x84, 0x7B, 0x81, 0x75, 0x7F, 0x72, 0x7C, 0x6E, 0x7C, 0x6D, 0x77, 0x67, 0x73, 0x64, 0x79, 0x6A, 0x71, 0x62, 0x73, 0x69, 0x7E, 0x75, 0x7B, 0x6C, 0x7A, 0x6C, 0x7A, 0x6B, 0x78, 0x6B, 0x75, 0x69, 0x78, 0x6B, 0x77, 0x67, 0x79, 0x6A, 0x7A, 0x6B, 0x76, 0x69, 0x74, 0x65, 0x75, 0x68, 0x78, 0x6B, 0x73, 0x67, 0x78, 0x6B, 0x75, 0x6A, 0x75, 0x69, 0x79, 0x6B, 0x76, 0x69, 0x74, 0x68, 0x78, 0x69, 0x7B, 0x6D, 0x7A, 0x6A, 0x7F, 0x72, 0x7A, 0x6C, 0x76, 0x67, 0x76, 0x67, 0x72, 0x65, 0x73, 0x65, 0x73, 0x67, 0x75, 0x68, 0x71, 0x67, 0x79, 0x6F, 0x83, 0x76, 0x77, 0x69, 0x79, 0x70, 0x78, 0x6D, 0x7D, 0x71, 0x80, 0x75, 0x85, 0x7D, 0x84, 0x7D, 0x8A, 0x85, 0x91, 0x8E, 0x94, 0x93, 0x92, 0x96, 0x96, 0x94, 0x8C, 0x84, 0x8D, 0x87, 0x89, 0x83, 0x8F, 0x8D, 0x87, 0x81, 0x86, 0x87, 0x87, 0x83, 0x81, 0x79, 0x85, 0x80, 0x85, 0x7E, 0x81, 0x78, 0x7F, 0x7C, 0x80, 0x7A, 0x7F, 0x75, 0x7B, 0x6F, 0x76, 0x69, 0x72, 0x66, 0x76, 0x6B, 0x74, 0x69, 0x76, 0x69, 0x76, 0x68, 0x72, 0x65, 0x6E, 0x62, 0x5A, 0x58, 0x48, 0x50, 0x41, 0x4C, 0x46, 0x4E, 0x4A, 0x55, 0x4A, 0x54, 0x40, 0x48, 0x44, 0x52, 0x44, 0x49, 0x44, 0x52, 0x3F, 0x45, 0x4A, 0x55, 0x41, 0x48, 0x38, 0x3E, 0x45, 0x51, 0x41, 0x4A, 0x47, 0x4F, 0x3E, 0x45, 0x44, 0x4C, 0x3D, 0x45, 0x47, 0x4F, 0x40, 0x48, 0x46, 0x54, 0x46, 0x51, 0x4C, 0x54, 0x40, 0x48, 0x44, 0x4E, 0x41, 0x49, 0x47, 0x50, 0x43, 0x4C, 0x49, 0x50, 0x44, 0x4F, 0x49, 0x53, 0x3F, 0x46, 0x43, 0x4D, 0x3F, 0x46, 0x44, 0x4E, 0x38, 0x3F, 0x42, 0x4C, 0x47, 0x51, 0x3A, 0x3F, 0x41, 0x49, 0x3E, 0x46, 0x43, 0x4B, 0x3F, 0x47, 0x3A, 0x43, 0x49, 0x52, 0x44, 0x4D, 0x3E, 0x42, 0x42, 0x50
    },

    {
        0x52, 0x1E, 0x52, 0x1D, 0x53, 0x1E, 0x55, 0x1F, 0x55, 0x1F, 0x57, 0x23, 0x5A, 0x26, 0x5B, 0x26, 0x5A, 0x22, 0x54, 0x20, 0x54, 0x20, 0x56, 0x21, 0x57, 0x20, 0x57, 0x20, 0x5A, 0x21, 0x5D, 0x21, 0x5D, 0x21, 0x5E, 0x22, 0x5F, 0x23, 0x62, 0x24, 0x64, 0x24, 0x62, 0x23, 0x60, 0x23, 0x61, 0x23, 0x60, 0x22, 0x61, 0x24, 0x62, 0x23, 0x61, 0x24, 0x62, 0x23, 0x61, 0x24, 0x67, 0x26, 0x63, 0x25, 0x5F, 0x24, 0x63, 0x24, 0x64, 0x26, 0x67, 0x28, 0x68, 0x27, 0x66, 0x27, 0x6C, 0x2B, 0x6A, 0x28, 0x68, 0x27, 0x6A, 0x27, 0x64, 0x26, 0x67, 0x26, 0x67, 0x26, 0x65, 0x25, 0x64, 0x24, 0x67, 0x25, 0x66, 0x25, 0x6A, 0x26, 0x65, 0x25, 0x5F, 0x23, 0x64, 0x25, 0x66, 0x25, 0x64, 0x24, 0x66, 0x25, 0x61, 0x25, 0x64, 0x25, 0x65, 0x26, 0x65, 0x25, 0x65, 0x26, 0x68, 0x27, 0x65, 0x25, 0x5A, 0x23, 0x48, 0x1E, 0x3C, 0x1A, 0x36, 0x1A, 0x3A, 0x1B, 0x43, 0x1D, 0x53, 0x21, 0x5F, 0x24, 0x64, 0x25, 0x64, 0x25, 0x66, 0x25, 0x68, 0x27, 0x6D, 0x28, 0x6A, 0x27, 0x6B, 0x27, 0x69, 0x27, 0x69, 0x27, 0x68, 0x26, 0x69, 0x26, 0x6A, 0x28, 0x67, 0x26, 0x65, 0x25, 0x68, 0x27, 0x6A, 0x27, 0x69, 0x26, 0x66, 0x26, 0x69, 0x28, 0x6B, 0x2A, 0x6B, 0x29, 0x66, 0x27, 0x5C, 0x25, 0x60, 0x26, 0x62, 0x28, 0x67, 0x28, 0x6B, 0x2A, 0x70, 0x2A, 0x70, 0x2C, 0x73, 0x2D, 0x79, 0x33, 0x70, 0x2D, 0x7B, 0x38, 0x7B, 0x32, 0x72, 0x30, 0x8D, 0x42, 0x79, 0x32, 0x7C, 0x34, 0x7A, 0x33, 0x8A, 0x40, 0x9E, 0x48, 0x96, 0x44, 0x7F, 0x38, 0x8D, 0x3D, 0x81, 0x39, 0x92, 0x44, 0x83, 0x38, 0x78, 0x34, 0x84, 0x3F, 0xAF, 0x52, 0x95, 0x44, 0x8A, 0x41, 0x90, 0x45, 0xAD, 0x51, 0x9C, 0x4B, 0xA9, 0x55, 0xBA, 0x62, 0xB2, 0x53, 0xAF, 0x5B, 0xB3, 0x54, 0x97, 0x43, 0xA5, 0x53, 0xC6, 0x6D, 0xBE, 0x5C, 0xBB, 0x5E, 0xC8, 0x6D, 0xD0, 0x64, 0x98, 0x49, 0x9A, 0x4C, 0x96, 0x46, 0x9F, 0x4E, 0x97, 0x48, 0xA8, 0x53, 0x9D, 0x50, 0x9B, 0x57, 0x8F, 0x52, 0xA8, 0x5E, 0x8F, 0x4B, 0x97, 0x4A, 0xA4, 0x4F, 0x9A, 0x4B, 0xA2, 0x4C, 0x93, 0x43, 0x95, 0x45, 0x99, 0x4B, 0xA1, 0x4B, 0x9A, 0x4A, 0x9E, 0x4F, 0xA3, 0x55, 0xB9, 0x5B, 0xBC, 0x64, 0xA5, 0x50, 0x96, 0x46, 0x95, 0x49, 0x97, 0x46, 0xA5, 0x52, 0xA5, 0x4F, 0xA8, 0x55, 0x9E, 0x4B, 0x89, 0x3E, 0x9A, 0x4A, 0x99, 0x4A, 0x92, 0x48, 0xA1, 0x4D, 0x8F, 0x42, 0x8B, 0x3F, 0x96, 0x45, 0x83, 0x3F, 0x9F, 0x4D, 0x8F, 0x41, 0x81, 0x3C, 0x86, 0x3A, 0x7E, 0x36, 0x79, 0x30, 0x72, 0x30, 0x76, 0x33, 0x87, 0x38, 0x76, 0x31, 0x73, 0x30, 0x6F, 0x31, 0x7E, 0x35, 0x6D, 0x2D, 0x6C, 0x2B, 0x6C, 0x29, 0x65, 0x26, 0x68, 0x27, 0x68, 0x29, 0x64, 0x27, 0x64, 0x27, 0x6A, 0x29, 0x62, 0x26, 0x68, 0x29, 0x69, 0x29, 0x63, 0x25, 0x66, 0x28, 0x65, 0x26, 0x63, 0x26, 0x66, 0x27, 0x63, 0x26, 0x66, 0x27, 0x65, 0x26, 0x64, 0x26, 0x68, 0x29, 0x69, 0x2A, 0x68, 0x28, 0x65, 0x28, 0x5F, 0x26, 0x64, 0x28, 0x65, 0x27, 0x64, 0x26, 0x66, 0x28, 0x65, 0x27, 0x63, 0x26, 0x69, 0x29, 0x62, 0x25, 0x62, 0x25, 0x61, 0x25, 0x5F, 0x25, 0x5F, 0x25, 0x62, 0x26, 0x62, 0x26, 0x65, 0x28, 0x69, 0x2A, 0x62, 0x27, 0x61, 0x28, 0x66, 0x2B, 0x68, 0x2B, 0x6F, 0x2E, 0x71, 0x2E, 0x7B, 0x37, 0x75, 0x34, 0x79, 0x36, 0x88, 0x43, 0x90, 0x45, 0x85, 0x3F, 0x8C, 0x44, 0x8B, 0x3E, 0x7B, 0x39, 0x8A, 0x42, 0x7D, 0x38, 0x78, 0x34, 0x77, 0x37, 0x77, 0x35, 0x73, 0x33, 0x83, 0x3D, 0x78, 0x34, 0x71, 0x2F, 0x75, 0x36, 0x6D, 0x2E, 0x68, 0x2C, 0x68, 0x2A, 0x66, 0x29, 0x66, 0x29, 0x63, 0x26, 0x63, 0x28, 0x65, 0x29, 0x63, 0x29, 0x64, 0x29, 0x62, 0x27, 0x54, 0x2A, 0x51, 0x2A, 0x4B, 0x2B, 0x56, 0x2D, 0x43, 0x23, 0x43, 0x25, 0x40, 0x23, 0x46, 0x27, 0x3F, 0x22, 0x43, 0x26, 0x43, 0x25, 0x51, 0x2A, 0x48, 0x26, 0x42, 0x23, 0x4E, 0x2B, 0x53, 0x2B, 0x58, 0x2F, 0x50, 0x2A, 0x52, 0x2B, 0x4A, 0x28, 0x56, 0x2E, 0x47, 0x27, 0x56, 0x2E, 0x45, 0x26, 0x4D, 0x29, 0x41, 0x24, 0x45, 0x25, 0x3E, 0x22, 0x44, 0x25, 0x44, 0x26, 0x46, 0x25, 0x45, 0x27, 0x4C, 0x28, 0x4C, 0x29, 0x4A, 0x27, 0x47, 0x26, 0x50, 0x2B, 0x49, 0x26, 0x48, 0x26, 0x46, 0x26, 0x40, 0x22, 0x4A, 0x27, 0x4E, 0x27, 0x3E, 0x20, 0x46, 0x25, 0x42, 0x24, 0x4A, 0x27, 0x3F, 0x21, 0x3B, 0x1E, 0x46, 0x26
    },

    {
        0x5F, 0x54, 0x5F, 0x55, 0x62, 0x56, 0x64, 0x57, 0x63, 0x57, 0x61, 0x57, 0x63, 0x5C, 0x65, 0x5C, 0x67, 0x5B, 0x62, 0x55, 0x63, 0x57, 0x67, 0x59, 0x66, 0x59, 0x67, 0x59, 0x6A, 0x5D, 0x6D, 0x5D, 0x6F, 0x5F, 0x72, 0x61, 0x72, 0x62, 0x73, 0x65, 0x76, 0x66, 0x75, 0x63, 0x74, 0x63, 0x75, 0x64, 0x74, 0x64, 0x74, 0x63, 0x73, 0x63, 0x73, 0x63, 0x77, 0x65, 0x77, 0x66, 0x7A, 0x69, 0x79, 0x65, 0x70, 0x61, 0x75, 0x65, 0x7A, 0x68, 0x7C, 0x6C, 0x7B, 0x6A, 0x7A, 0x6A, 0x7F, 0x72, 0x7C, 0x6D, 0x7D, 0x6D, 0x7F, 0x6D, 0x7A, 0x69, 0x7A, 0x69, 0x7A, 0x69, 0x7C, 0x69, 0x79, 0x67, 0x7B, 0x69, 0x7B, 0x69, 0x7D, 0x6D, 0x7B, 0x68, 0x76, 0x63, 0x79, 0x68, 0x7B, 0x68, 0x78, 0x67, 0x7B, 0x6B, 0x79, 0x6A, 0x77, 0x68, 0x7A, 0x67, 0x7A, 0x6A, 0x7A, 0x69, 0x7C, 0x6D, 0x79, 0x68, 0x6C, 0x5C, 0x5A, 0x4D, 0x4B, 0x42, 0x45, 0x3D, 0x48, 0x42, 0x55, 0x4E, 0x66, 0x5E, 0x74, 0x66, 0x77, 0x68, 0x79, 0x69, 0x7D, 0x6B, 0x7F, 0x6D, 0x81, 0x6F, 0x7F, 0x6E, 0x81, 0x6D, 0x80, 0x6F, 0x80, 0x6D, 0x7D, 0x6D, 0x7E, 0x6A, 0x7F, 0x6E, 0x7C, 0x69, 0x7A, 0x68, 0x7A, 0x6A, 0x7E, 0x6E, 0x7F, 0x6C, 0x7C, 0x6A, 0x7F, 0x6E, 0x7F, 0x73, 0x7E, 0x70, 0x78, 0x6B, 0x6F, 0x66, 0x76, 0x69, 0x75, 0x6A, 0x78, 0x6C, 0x7D, 0x71, 0x82, 0x74, 0x84, 0x77, 0x87, 0x78, 0x88, 0x7D, 0x83, 0x76, 0x86, 0x80, 0x8A, 0x7C, 0x81, 0x78, 0x95, 0x8F, 0x8C, 0x7E, 0x8D, 0x84, 0x8E, 0x80, 0x98, 0x93, 0x9F, 0x9E, 0xA0, 0x9E, 0x8F, 0x85, 0x93, 0x8B, 0x8D, 0x85, 0x98, 0x95, 0x8C, 0x82, 0x88, 0x7B, 0x90, 0x95, 0xA6, 0xA6, 0x98, 0x98, 0x94, 0x91, 0x97, 0x99, 0xB2, 0xB3, 0xA2, 0x9E, 0xB4, 0xBE, 0xBC, 0xCA, 0xB5, 0xB2, 0xB1, 0xB7, 0xAC, 0xAE, 0x9B, 0x8C, 0xAC, 0xB3, 0xC1, 0xD6, 0xC6, 0xC4, 0xB9, 0xB7, 0xC3, 0xCD, 0xC2, 0xC3, 0xA1, 0x9B, 0xA2, 0x9F, 0x9D, 0x9A, 0xAA, 0xB0, 0x9F, 0x9B, 0xA9, 0xAA, 0x9E, 0xAB, 0x91, 0xA3, 0x7F, 0x88, 0x93, 0xA8, 0x84, 0x91, 0x96, 0x9D, 0xA6, 0xA8, 0xA0, 0xA4, 0xA7, 0xA4, 0x9E, 0x97, 0x9B, 0x96, 0xA2, 0xA5, 0xAB, 0xAA, 0xA7, 0xA6, 0xA4, 0xA4, 0xA6, 0xB0, 0xB3, 0xC0, 0xB2, 0xBD, 0xA2, 0xA1, 0x99, 0x97, 0x9E, 0xA3, 0x9C, 0x9A, 0xA8, 0xAD, 0xA7, 0xA5, 0xA8, 0xA9, 0x9E, 0x9D, 0x9A, 0x99, 0xA7, 0xA3, 0x97, 0x92, 0x95, 0x95, 0xA6, 0xA8, 0x9C, 0x99, 0x9B, 0x99, 0x9C, 0x96, 0x93, 0x91, 0x9F, 0x9F, 0x97, 0x8E, 0x8D, 0x8A, 0x8F, 0x87, 0x8B, 0x83, 0x86, 0x78, 0x7E, 0x77, 0x86, 0x7F, 0x8F, 0x84, 0x84, 0x7B, 0x85, 0x77, 0x81, 0x7A, 0x8A, 0x7F, 0x80, 0x74, 0x7C, 0x71, 0x7C, 0x6E, 0x79, 0x69, 0x7E, 0x6F, 0x7D, 0x6F, 0x78, 0x6A, 0x75, 0x68, 0x7B, 0x6E, 0x79, 0x68, 0x79, 0x6A, 0x7A, 0x6B, 0x73, 0x66, 0x7B, 0x6C, 0x79, 0x6B, 0x79, 0x69, 0x76, 0x69, 0x74, 0x66, 0x78, 0x6B, 0x79, 0x69, 0x79, 0x6A, 0x79, 0x6D, 0x7B, 0x6D, 0x77, 0x6A, 0x79, 0x6C, 0x72, 0x65, 0x77, 0x6C, 0x76, 0x68, 0x74, 0x69, 0x7A, 0x6C, 0x77, 0x68, 0x77, 0x68, 0x79, 0x6D, 0x73, 0x64, 0x77, 0x67, 0x74, 0x66, 0x73, 0x66, 0x71, 0x66, 0x72, 0x67, 0x74, 0x68, 0x77, 0x6B, 0x7C, 0x71, 0x71, 0x65, 0x71, 0x65, 0x76, 0x69, 0x78, 0x6C, 0x7B, 0x71, 0x7D, 0x73, 0x85, 0x7D, 0x81, 0x7A, 0x85, 0x82, 0x8D, 0x90, 0x94, 0x96, 0x8A, 0x85, 0x92, 0x93, 0x93, 0x8D, 0x85, 0x81, 0x95, 0x93, 0x87, 0x80, 0x82, 0x79, 0x7F, 0x7A, 0x83, 0x79, 0x80, 0x79, 0x8A, 0x87, 0x82, 0x7E, 0x80, 0x76, 0x7E, 0x78, 0x7A, 0x6F, 0x77, 0x6E, 0x78, 0x6D, 0x77, 0x6B, 0x79, 0x6B, 0x75, 0x69, 0x76, 0x6B, 0x76, 0x69, 0x75, 0x69, 0x75, 0x6B, 0x70, 0x64, 0x54, 0x57, 0x48, 0x4D, 0x43, 0x50, 0x49, 0x51, 0x3B, 0x40, 0x3D, 0x46, 0x39, 0x40, 0x40, 0x49, 0x3B, 0x40, 0x3E, 0x48, 0x3F, 0x4B, 0x4C, 0x55, 0x45, 0x4E, 0x3F, 0x47, 0x4A, 0x59, 0x4C, 0x58, 0x51, 0x5C, 0x48, 0x50, 0x4A, 0x55, 0x43, 0x4D, 0x4D, 0x56, 0x42, 0x4B, 0x4A, 0x52, 0x3F, 0x4A, 0x45, 0x4C, 0x3C, 0x45, 0x3E, 0x44, 0x3B, 0x43, 0x41, 0x46, 0x40, 0x4A, 0x3F, 0x45, 0x41, 0x4C, 0x47, 0x4F, 0x49, 0x54, 0x47, 0x4E, 0x43, 0x4B, 0x4C, 0x56, 0x45, 0x4C, 0x40, 0x48, 0x41, 0x4C, 0x3D, 0x43, 0x45, 0x51, 0x45, 0x4C, 0x3A, 0x3F, 0x41, 0x48, 0x3F, 0x48, 0x40, 0x47, 0x3A, 0x43, 0x38, 0x3E, 0x3F, 0x49
    },

    {
        0x50, 0x1E, 0x51, 0x1D, 0x52, 0x1E, 0x53, 0x1E, 0x53, 0x1E, 0x54, 0x22, 0x58, 0x25, 0x5A, 0x24, 0x57, 0x22, 0x57, 0x21, 0x57, 0x21, 0x56, 0x20, 0x54, 0x20, 0x56, 0x1F, 0x57, 0x20, 0x59, 0x20, 0x5B, 0x21, 0x5F, 0x22, 0x5E, 0x21, 0x5D, 0x21, 0x5E, 0x22, 0x5D, 0x22, 0x5D, 0x22, 0x5D, 0x22, 0x60, 0x22, 0x5E, 0x22, 0x5F, 0x23, 0x63, 0x23, 0x61, 0x24, 0x62, 0x24, 0x60, 0x23, 0x61, 0x23, 0x60, 0x23, 0x61, 0x24, 0x63, 0x26, 0x66, 0x28, 0x6A, 0x27, 0x68, 0x28, 0x6A, 0x29, 0x6A, 0x29, 0x6A, 0x29, 0x66, 0x27, 0x66, 0x27, 0x66, 0x25, 0x62, 0x24, 0x63, 0x24, 0x64, 0x24, 0x64, 0x25, 0x64, 0x24, 0x66, 0x25, 0x65, 0x25, 0x65, 0x24, 0x65, 0x24, 0x64, 0x24, 0x64, 0x26, 0x68, 0x2A, 0x6F, 0x2B, 0x64, 0x25, 0x63, 0x25, 0x66, 0x26, 0x6A, 0x26, 0x68, 0x27, 0x66, 0x26, 0x63, 0x24, 0x5C, 0x22, 0x56, 0x21, 0x51, 0x21, 0x57, 0x22, 0x5B, 0x23, 0x62, 0x27, 0x65, 0x26, 0x65, 0x25, 0x68, 0x26, 0x66, 0x26, 0x6A, 0x27, 0x67, 0x26, 0x67, 0x27, 0x68, 0x26, 0x69, 0x26, 0x66, 0x25, 0x67, 0x26, 0x67, 0x27, 0x68, 0x26, 0x63, 0x25, 0x66, 0x25, 0x67, 0x26, 0x68, 0x27, 0x66, 0x26, 0x6B, 0x28, 0x6B, 0x28, 0x69, 0x29, 0x6E, 0x2A, 0x6A, 0x29, 0x6C, 0x29, 0x6A, 0x29, 0x69, 0x28, 0x6D, 0x2A, 0x70, 0x2B, 0x71, 0x2C, 0x72, 0x2B, 0x72, 0x2D, 0x71, 0x2C, 0x6F, 0x2D, 0x74, 0x30, 0x6A, 0x2B, 0x74, 0x2F, 0x7B, 0x34, 0x82, 0x38, 0x8C, 0x3C, 0x8C, 0x42, 0xA2, 0x49, 0x93, 0x49, 0xAB, 0x50, 0x7D, 0x31, 0x7E, 0x38, 0x7A, 0x32, 0x86, 0x3C, 0x82, 0x3B, 0x84, 0x39, 0x98, 0x4A, 0xA2, 0x4B, 0x8C, 0x42, 0x81, 0x36, 0x87, 0x46, 0xC6, 0x67, 0xA0, 0x44, 0x9E, 0x51, 0xB3, 0x5E, 0xBD, 0x5D, 0xA6, 0x4E, 0xA3, 0x4C, 0x87, 0x3E, 0xB4, 0x5D, 0xCD, 0x75, 0xE0, 0x75, 0xC0, 0x5C, 0xBA, 0x61, 0xAA, 0x51, 0x8E, 0x40, 0x8D, 0x40, 0x8E, 0x44, 0xA7, 0x50, 0x95, 0x47, 0x92, 0x49, 0xA1, 0x61, 0x7D, 0x4A, 0x66, 0x3D, 0x6E, 0x45, 0x66, 0x3C, 0x78, 0x44, 0x96, 0x45, 0x8D, 0x41, 0x91, 0x43, 0x96, 0x48, 0xA3, 0x4E, 0xA2, 0x4F, 0xA6, 0x54, 0xB8, 0x5D, 0xAA, 0x55, 0xA9, 0x55, 0xA2, 0x52, 0xA3, 0x50, 0x95, 0x45, 0x87, 0x3C, 0x89, 0x3F, 0x89, 0x3F, 0x9E, 0x4C, 0x98, 0x45, 0x95, 0x48, 0x8E, 0x40, 0x9A, 0x4F, 0xAB, 0x56, 0x93, 0x40, 0x87, 0x40, 0x95, 0x46, 0x8D, 0x41, 0x91, 0x45, 0x8E, 0x41, 0x97, 0x45, 0x88, 0x3D, 0x87, 0x3B, 0x86, 0x3C, 0x7E, 0x36, 0x80, 0x37, 0x75, 0x31, 0x6F, 0x2D, 0x7C, 0x36, 0x7A, 0x34, 0x74, 0x2F, 0x71, 0x30, 0x7D, 0x37, 0x84, 0x39, 0x75, 0x2F, 0x6F, 0x2B, 0x68, 0x27, 0x63, 0x25, 0x63, 0x26, 0x6A, 0x29, 0x6A, 0x28, 0x68, 0x29, 0x67, 0x27, 0x66, 0x28, 0x64, 0x27, 0x69, 0x29, 0x63, 0x26, 0x66, 0x28, 0x65, 0x26, 0x62, 0x25, 0x68, 0x28, 0x67, 0x26, 0x63, 0x26, 0x63, 0x26, 0x64, 0x27, 0x67, 0x29, 0x66, 0x28, 0x63, 0x27, 0x69, 0x2C, 0x6C, 0x2B, 0x68, 0x29, 0x64, 0x27, 0x63, 0x26, 0x63, 0x24, 0x60, 0x24, 0x61, 0x26, 0x6C, 0x2C, 0x63, 0x25, 0x63, 0x25, 0x5E, 0x24, 0x5F, 0x25, 0x62, 0x26, 0x61, 0x26, 0x62, 0x26, 0x67, 0x28, 0x6C, 0x2C, 0x67, 0x28, 0x63, 0x27, 0x63, 0x27, 0x63, 0x27, 0x63, 0x2B, 0x68, 0x2A, 0x65, 0x2A, 0x70, 0x30, 0x80, 0x3B, 0x80, 0x3B, 0x78, 0x35, 0x72, 0x32, 0x80, 0x3B, 0x89, 0x40, 0x85, 0x3D, 0x8A, 0x42, 0x7F, 0x38, 0x78, 0x34, 0x6F, 0x30, 0x76, 0x34, 0x72, 0x32, 0x7D, 0x39, 0x74, 0x33, 0x6F, 0x2F, 0x67, 0x2A, 0x66, 0x29, 0x68, 0x29, 0x67, 0x2A, 0x6A, 0x2B, 0x69, 0x2B, 0x65, 0x27, 0x68, 0x2A, 0x65, 0x29, 0x62, 0x27, 0x5F, 0x26, 0x60, 0x26, 0x55, 0x2A, 0x4A, 0x27, 0x4A, 0x29, 0x57, 0x2E, 0x45, 0x25, 0x4E, 0x29, 0x4B, 0x27, 0x4F, 0x2A, 0x4B, 0x27, 0x53, 0x2C, 0x4B, 0x28, 0x51, 0x2A, 0x4B, 0x27, 0x41, 0x24, 0x55, 0x2C, 0x44, 0x26, 0x4A, 0x28, 0x45, 0x26, 0x48, 0x27, 0x42, 0x26, 0x4B, 0x29, 0x47, 0x28, 0x42, 0x24, 0x48, 0x28, 0x47, 0x26, 0x50, 0x2A, 0x49, 0x27, 0x46, 0x26, 0x50, 0x29, 0x4B, 0x29, 0x46, 0x25, 0x47, 0x27, 0x56, 0x2D, 0x4D, 0x2A, 0x4C, 0x29, 0x45, 0x27, 0x52, 0x2D, 0x41, 0x23, 0x3E, 0x21, 0x48, 0x26, 0x3F, 0x22, 0x46, 0x25, 0x47, 0x24, 0x3D, 0x21, 0x4A, 0x27, 0x4E, 0x28, 0x49, 0x26, 0x44, 0x25, 0x46, 0x24, 0x4D, 0x28
    },

    {
        0x5E, 0x54, 0x5E, 0x54, 0x60, 0x54, 0x62, 0x56, 0x61, 0x54, 0x61, 0x56, 0x63, 0x5B, 0x68, 0x5E, 0x64, 0x5B, 0x66, 0x5B, 0x65, 0x59, 0x64, 0x58, 0x64, 0x59, 0x66, 0x59, 0x68, 0x5A, 0x67, 0x5A, 0x6D, 0x5F, 0x70, 0x5F, 0x71, 0x60, 0x71, 0x61, 0x71, 0x61, 0x6E, 0x5E, 0x6F, 0x5F, 0x72, 0x5F, 0x72, 0x62, 0x71, 0x61, 0x71, 0x62, 0x77, 0x66, 0x77, 0x66, 0x76, 0x65, 0x76, 0x64, 0x76, 0x65, 0x74, 0x64, 0x75, 0x65, 0x76, 0x67, 0x78, 0x69, 0x7D, 0x6C, 0x7C, 0x6B, 0x7B, 0x6D, 0x7E, 0x6E, 0x7F, 0x6E, 0x7A, 0x69, 0x7B, 0x6A, 0x7B, 0x68, 0x78, 0x65, 0x78, 0x65, 0x79, 0x67, 0x79, 0x67, 0x75, 0x66, 0x7A, 0x69, 0x7A, 0x6A, 0x79, 0x68, 0x7A, 0x67, 0x76, 0x64, 0x7A, 0x69, 0x7B, 0x6D, 0x7C, 0x6D, 0x76, 0x66, 0x78, 0x6A, 0x7A, 0x69, 0x7D, 0x6E, 0x7C, 0x6D, 0x7D, 0x6A, 0x78, 0x68, 0x72, 0x61, 0x6B, 0x5D, 0x68, 0x5D, 0x6B, 0x60, 0x6F, 0x62, 0x73, 0x69, 0x79, 0x69, 0x7C, 0x6C, 0x7C, 0x6C, 0x7E, 0x6C, 0x80, 0x6C, 0x7F, 0x6D, 0x7D, 0x6C, 0x7C, 0x6B, 0x7E, 0x6D, 0x7A, 0x6A, 0x7B, 0x6B, 0x7D, 0x6C, 0x7D, 0x6B, 0x79, 0x6A, 0x7A, 0x6B, 0x7D, 0x69, 0x7C, 0x6A, 0x7D, 0x6C, 0x81, 0x6F, 0x7E, 0x70, 0x7D, 0x70, 0x83, 0x73, 0x7E, 0x70, 0x82, 0x73, 0x7C, 0x6E, 0x80, 0x71, 0x7F, 0x72, 0x82, 0x75, 0x82, 0x77, 0x86, 0x75, 0x85, 0x76, 0x84, 0x75, 0x81, 0x74, 0x83, 0x77, 0x7E, 0x71, 0x86, 0x7A, 0x87, 0x7C, 0x90, 0x85, 0x97, 0x8D, 0x96, 0x97, 0xA8, 0xA4, 0x9A, 0x9E, 0xA7, 0xAA, 0x90, 0x7B, 0x8E, 0x86, 0x8A, 0x7C, 0x95, 0x91, 0x92, 0x91, 0x93, 0x88, 0x9C, 0xA0, 0xA0, 0xA1, 0x8F, 0x92, 0x8B, 0x7D, 0x91, 0x98, 0xBA, 0xC4, 0xA7, 0xA0, 0x9F, 0xA0, 0xAD, 0xB5, 0xB6, 0xBB, 0xA4, 0x9E, 0xA2, 0xA4, 0x97, 0x90, 0xB3, 0xBB, 0xCD, 0xDD, 0xCD, 0xD9, 0xC2, 0xC7, 0xB8, 0xC4, 0xAD, 0xA9, 0x9F, 0x97, 0x9D, 0x9A, 0x99, 0x94, 0x9D, 0x9F, 0x9A, 0x9D, 0x91, 0x98, 0x90, 0xA0, 0x6C, 0x6E, 0x5C, 0x61, 0x61, 0x6A, 0x5A, 0x60, 0x6B, 0x7D, 0xA3, 0x9F, 0x96, 0x95, 0xA5, 0xA3, 0xA9, 0xAA, 0xA9, 0xAE, 0xA5, 0xA3, 0xA7, 0xAA, 0xB1, 0xC1, 0xB0, 0xB5, 0xB0, 0xB2, 0xA3, 0xA6, 0xA8, 0xAA, 0x9B, 0x96, 0x93, 0x8C, 0x97, 0x8D, 0x93, 0x8C, 0xA1, 0xA0, 0xA3, 0x9F, 0xA1, 0xAA, 0x9C, 0x98, 0x9E, 0xAB, 0xA9, 0xAD, 0x99, 0x97, 0x97, 0x96, 0x99, 0x97, 0x99, 0x92, 0x9E, 0x9B, 0x93, 0x8F, 0x9E, 0x9A, 0x96, 0x8D, 0x95, 0x8A, 0x98, 0x92, 0x8C, 0x80, 0x91, 0x8A, 0x82, 0x7A, 0x82, 0x78, 0x89, 0x82, 0x87, 0x7D, 0x83, 0x78, 0x7F, 0x78, 0x88, 0x7F, 0x8C, 0x85, 0x85, 0x76, 0x81, 0x71, 0x7A, 0x6A, 0x75, 0x68, 0x79, 0x6A, 0x7D, 0x6E, 0x7A, 0x6D, 0x7A, 0x6D, 0x7D, 0x6E, 0x7A, 0x6E, 0x79, 0x6A, 0x7C, 0x6F, 0x79, 0x6A, 0x77, 0x69, 0x77, 0x69, 0x74, 0x67, 0x7A, 0x6F, 0x7A, 0x6A, 0x76, 0x68, 0x76, 0x67, 0x79, 0x6D, 0x79, 0x6C, 0x76, 0x69, 0x75, 0x68, 0x78, 0x70, 0x7E, 0x72, 0x79, 0x6B, 0x77, 0x69, 0x78, 0x68, 0x76, 0x67, 0x75, 0x66, 0x75, 0x68, 0x7D, 0x72, 0x76, 0x67, 0x74, 0x64, 0x6F, 0x61, 0x71, 0x66, 0x75, 0x67, 0x75, 0x66, 0x75, 0x67, 0x7A, 0x6C, 0x7C, 0x6D, 0x7A, 0x6D, 0x77, 0x68, 0x78, 0x6A, 0x76, 0x68, 0x76, 0x6A, 0x7B, 0x6E, 0x74, 0x69, 0x7F, 0x77, 0x89, 0x85, 0x8D, 0x88, 0x86, 0x80, 0x81, 0x79, 0x87, 0x84, 0x8E, 0x8C, 0x8D, 0x8D, 0x8E, 0x8C, 0x8B, 0x84, 0x87, 0x7E, 0x7E, 0x74, 0x84, 0x7D, 0x80, 0x78, 0x84, 0x80, 0x7D, 0x75, 0x7A, 0x71, 0x77, 0x6B, 0x78, 0x6A, 0x77, 0x6B, 0x77, 0x6C, 0x77, 0x6F, 0x77, 0x6C, 0x75, 0x68, 0x7A, 0x6E, 0x74, 0x6A, 0x73, 0x66, 0x72, 0x64, 0x6E, 0x62, 0x56, 0x58, 0x47, 0x4E, 0x47, 0x53, 0x4F, 0x5B, 0x41, 0x47, 0x4A, 0x57, 0x48, 0x50, 0x49, 0x55, 0x46, 0x4D, 0x4C, 0x57, 0x42, 0x4A, 0x48, 0x52, 0x42, 0x48, 0x3B, 0x45, 0x4A, 0x53, 0x3E, 0x48, 0x42, 0x49, 0x40, 0x4A, 0x42, 0x4A, 0x40, 0x49, 0x45, 0x4D, 0x43, 0x4C, 0x3E, 0x46, 0x43, 0x50, 0x44, 0x4B, 0x4C, 0x56, 0x46, 0x4E, 0x42, 0x4D, 0x49, 0x51, 0x43, 0x4D, 0x3F, 0x46, 0x43, 0x4F, 0x4B, 0x53, 0x42, 0x4B, 0x44, 0x4B, 0x40, 0x4A, 0x48, 0x51, 0x3C, 0x41, 0x39, 0x43, 0x41, 0x49, 0x3B, 0x41, 0x41, 0x4C, 0x43, 0x4A, 0x3A, 0x44, 0x47, 0x50, 0x46, 0x4F, 0x42, 0x4A, 0x3F, 0x4D, 0x3E, 0x45, 0x46, 0x53
    },

    {
        0x51, 0x1D, 0x51, 0x1D, 0x52, 0x1E, 0x51, 0x1D, 0x51, 0x1F, 0x54, 0x22, 0x5A, 0x27, 0x6C, 0x32, 0x67, 0x29, 0x59, 0x22, 0x59, 0x23, 0x5C, 0x24, 0x59, 0x22, 0x57, 0x1F, 0x54, 0x1F, 0x54, 0x20, 0x5B, 0x21, 0x5B, 0x21, 0x5D, 0x21, 0x5B, 0x21, 0x5D, 0x22, 0x5E, 0x22, 0x5C, 0x21, 0x5E, 0x21, 0x5E, 0x22, 0x62, 0x23, 0x61, 0x23, 0x62, 0x23, 0x62, 0x24, 0x61, 0x24, 0x61, 0x24, 0x62, 0x24, 0x61, 0x24, 0x62, 0x24, 0x66, 0x26, 0x67, 0x27, 0x66, 0x27, 0x6B, 0x29, 0x6B, 0x29, 0x6C, 0x2B, 0x74, 0x2E, 0x6C, 0x29, 0x66, 0x26, 0x63, 0x24, 0x63, 0x24, 0x63, 0x24, 0x64, 0x25, 0x63, 0x24, 0x62, 0x24, 0x63, 0x24, 0x66, 0x25, 0x65, 0x25, 0x62, 0x25, 0x64, 0x24, 0x65, 0x25, 0x62, 0x24, 0x64, 0x25, 0x61, 0x24, 0x67, 0x27, 0x67, 0x27, 0x66, 0x26, 0x67, 0x26, 0x66, 0x26, 0x68, 0x26, 0x68, 0x26, 0x65, 0x26, 0x68, 0x28, 0x67, 0x27, 0x67, 0x27, 0x68, 0x2C, 0x66, 0x26, 0x65, 0x25, 0x67, 0x25, 0x68, 0x25, 0x66, 0x26, 0x69, 0x27, 0x67, 0x28, 0x6A, 0x27, 0x68, 0x26, 0x68, 0x26, 0x68, 0x26, 0x67, 0x26, 0x69, 0x27, 0x69, 0x26, 0x64, 0x25, 0x63, 0x25, 0x66, 0x25, 0x67, 0x26, 0x69, 0x27, 0x6B, 0x28, 0x6C, 0x2A, 0x6E, 0x29, 0x6A, 0x27, 0x6A, 0x2A, 0x6E, 0x2B, 0x74, 0x2D, 0x70, 0x2A, 0x6A, 0x28, 0x6B, 0x2B, 0x73, 0x2D, 0x6F, 0x2D, 0x71, 0x2E, 0x72, 0x2D, 0x6F, 0x2D, 0x6E, 0x2B, 0x74, 0x2E, 0x7B, 0x33, 0x7A, 0x34, 0x83, 0x37, 0x83, 0x3B, 0x90, 0x43, 0x89, 0x3D, 0x89, 0x42, 0x89, 0x37, 0x78, 0x32, 0x71, 0x34, 0xA3, 0x49, 0x90, 0x45, 0x8C, 0x3C, 0x8C, 0x41, 0x88, 0x3D, 0x89, 0x40, 0x78, 0x33, 0x80, 0x41, 0xB6, 0x55, 0x90, 0x42, 0xA8, 0x53, 0xAB, 0x55, 0xB0, 0x54, 0xA1, 0x54, 0xC9, 0x60, 0xA1, 0x4F, 0xB9, 0x61, 0xDC, 0x75, 0xC5, 0x65, 0xB4, 0x5D, 0xB2, 0x57, 0x97, 0x45, 0x90, 0x45, 0x93, 0x42, 0x86, 0x3B, 0x88, 0x40, 0x8C, 0x3E, 0x7F, 0x4B, 0x7C, 0x47, 0x61, 0x38, 0x4E, 0x30, 0x5B, 0x38, 0x51, 0x2E, 0x5E, 0x41, 0xBA, 0x60, 0xAB, 0x53, 0xB8, 0x5B, 0xA4, 0x53, 0x9F, 0x4F, 0x9A, 0x4B, 0xA4, 0x4E, 0xA7, 0x52, 0xAA, 0x58, 0xB5, 0x58, 0x9B, 0x49, 0x98, 0x47, 0x8C, 0x3F, 0x8B, 0x3F, 0x95, 0x46, 0x8E, 0x40, 0x8D, 0x3E, 0x96, 0x46, 0x9A, 0x4D, 0x98, 0x46, 0x87, 0x42, 0x9A, 0x49, 0x8C, 0x41, 0x9B, 0x48, 0x88, 0x3A, 0x86, 0x42, 0x9E, 0x4C, 0x88, 0x3E, 0x8A, 0x41, 0x8D, 0x3F, 0x92, 0x43, 0x93, 0x45, 0x7B, 0x35, 0x84, 0x3C, 0x79, 0x34, 0x7C, 0x33, 0x7D, 0x38, 0x7B, 0x33, 0x7B, 0x35, 0x79, 0x34, 0x77, 0x33, 0x77, 0x34, 0x72, 0x2C, 0x6A, 0x2A, 0x66, 0x28, 0x60, 0x26, 0x67, 0x27, 0x65, 0x27, 0x6D, 0x2A, 0x64, 0x27, 0x68, 0x29, 0x6B, 0x29, 0x6A, 0x29, 0x6B, 0x2A, 0x68, 0x28, 0x61, 0x27, 0x66, 0x27, 0x63, 0x26, 0x64, 0x25, 0x63, 0x26, 0x5F, 0x25, 0x5F, 0x24, 0x6A, 0x2C, 0x6C, 0x2B, 0x68, 0x2A, 0x63, 0x27, 0x65, 0x28, 0x63, 0x27, 0x66, 0x28, 0x64, 0x26, 0x64, 0x26, 0x61, 0x23, 0x60, 0x25, 0x61, 0x27, 0x6B, 0x2A, 0x61, 0x24, 0x5F, 0x24, 0x61, 0x26, 0x64, 0x27, 0x63, 0x27, 0x63, 0x26, 0x63, 0x27, 0x64, 0x27, 0x6A, 0x2B, 0x65, 0x28, 0x64, 0x2A, 0x6A, 0x2B, 0x64, 0x27, 0x66, 0x27, 0x68, 0x29, 0x65, 0x29, 0x72, 0x32, 0x82, 0x3C, 0x7C, 0x3A, 0x82, 0x3A, 0x74, 0x32, 0x7A, 0x36, 0x7B, 0x37, 0x80, 0x3B, 0x85, 0x3C, 0x83, 0x3C, 0x78, 0x35, 0x6E, 0x2F, 0x6F, 0x2F, 0x70, 0x2F, 0x6E, 0x2F, 0x68, 0x2A, 0x66, 0x2A, 0x63, 0x28, 0x62, 0x27, 0x63, 0x28, 0x66, 0x2B, 0x68, 0x2B, 0x69, 0x2A, 0x62, 0x27, 0x66, 0x2B, 0x68, 0x2B, 0x61, 0x26, 0x61, 0x26, 0x61, 0x28, 0x58, 0x2D, 0x53, 0x2A, 0x4B, 0x2A, 0x53, 0x2B, 0x48, 0x27, 0x54, 0x2C, 0x47, 0x25, 0x46, 0x26, 0x45, 0x25, 0x4B, 0x28, 0x40, 0x23, 0x48, 0x27, 0x45, 0x25, 0x4F, 0x2A, 0x49, 0x26, 0x4A, 0x28, 0x51, 0x2B, 0x53, 0x2D, 0x55, 0x2E, 0x50, 0x2C, 0x5C, 0x32, 0x55, 0x2E, 0x54, 0x2D, 0x52, 0x2C, 0x58, 0x2F, 0x4D, 0x2A, 0x4E, 0x29, 0x48, 0x28, 0x4C, 0x28, 0x44, 0x25, 0x49, 0x28, 0x49, 0x27, 0x46, 0x24, 0x44, 0x25, 0x4A, 0x29, 0x4E, 0x2A, 0x53, 0x2C, 0x4A, 0x26, 0x44, 0x24, 0x4B, 0x28, 0x46, 0x25, 0x51, 0x2A, 0x4B, 0x25, 0x3E, 0x22, 0x4A, 0x27, 0x45, 0x25, 0x43, 0x23, 0x46, 0x27, 0x3F, 0x22, 0x47, 0x25
    },

    {
        0x61, 0x55, 0x60, 0x53, 0x5F, 0x53, 0x5F, 0x52, 0x60, 0x54, 0x61, 0x58, 0x67, 0x60, 0x74, 0x7A, 0x77, 0x6B, 0x68, 0x5B, 0x66, 0x5C, 0x68, 0x5E, 0x68, 0x5C, 0x63, 0x57, 0x62, 0x56, 0x63, 0x57, 0x69, 0x5D, 0x6D, 0x5E, 0x6F, 0x60, 0x6F, 0x5F, 0x6F, 0x60, 0x70, 0x61, 0x71, 0x60, 0x72, 0x60, 0x71, 0x61, 0x76, 0x65, 0x76, 0x65, 0x74, 0x64, 0x74, 0x63, 0x75, 0x64, 0x75, 0x65, 0x75, 0x64, 0x76, 0x64, 0x75, 0x64, 0x7D, 0x6B, 0x7B, 0x6A, 0x7B, 0x6B, 0x7D, 0x6F, 0x7D, 0x6D, 0x7E, 0x70, 0x85, 0x79, 0x80, 0x6F, 0x7D, 0x6B, 0x79, 0x68, 0x78, 0x66, 0x79, 0x69, 0x79, 0x68, 0x78, 0x67, 0x78, 0x65, 0x78, 0x66, 0x7A, 0x69, 0x7B, 0x67, 0x77, 0x66, 0x79, 0x68, 0x7A, 0x66, 0x79, 0x68, 0x78, 0x66, 0x75, 0x65, 0x7C, 0x6C, 0x7A, 0x6B, 0x7B, 0x6B, 0x7C, 0x6A, 0x7A, 0x6B, 0x7E, 0x6D, 0x7E, 0x6C, 0x7B, 0x6C, 0x7C, 0x6C, 0x7D, 0x6D, 0x7C, 0x6D, 0x78, 0x6C, 0x7B, 0x69, 0x78, 0x69, 0x7C, 0x69, 0x7E, 0x6A, 0x7E, 0x6C, 0x7F, 0x6E, 0x7C, 0x6D, 0x7F, 0x6D, 0x7E, 0x6C, 0x80, 0x6F, 0x7E, 0x6B, 0x7A, 0x6A, 0x7D, 0x6C, 0x7E, 0x6C, 0x7A, 0x6A, 0x79, 0x67, 0x7B, 0x6A, 0x7E, 0x6C, 0x7D, 0x6C, 0x7F, 0x70, 0x7F, 0x6F, 0x83, 0x73, 0x80, 0x6E, 0x7E, 0x6F, 0x82, 0x74, 0x87, 0x78, 0x88, 0x79, 0x7E, 0x6D, 0x84, 0x76, 0x85, 0x76, 0x81, 0x74, 0x83, 0x76, 0x85, 0x79, 0x83, 0x75, 0x81, 0x72, 0x87, 0x78, 0x8D, 0x81, 0x8E, 0x83, 0x90, 0x85, 0x8B, 0x8A, 0x96, 0x94, 0x92, 0x8E, 0x92, 0x8D, 0x8E, 0x81, 0x83, 0x76, 0x87, 0x83, 0xA7, 0xA4, 0x96, 0x95, 0x8D, 0x82, 0x8F, 0x8E, 0x8B, 0x81, 0x8C, 0x88, 0x80, 0x76, 0x8C, 0x8D, 0xAC, 0xA8, 0x93, 0x91, 0xA9, 0xB3, 0xAB, 0xB1, 0xB0, 0xB7, 0xA9, 0xB5, 0xBC, 0xBA, 0xA3, 0xA9, 0xB7, 0xBF, 0xC6, 0xD1, 0xBE, 0xC8, 0xB4, 0xBB, 0xB1, 0xB7, 0x9A, 0x92, 0x96, 0x94, 0x99, 0x95, 0x91, 0x8D, 0x92, 0x93, 0x94, 0x87, 0x79, 0x7C, 0x71, 0x79, 0x60, 0x69, 0x54, 0x59, 0x59, 0x66, 0x4F, 0x4E, 0x58, 0x74, 0xAF, 0xC6, 0xAD, 0xB3, 0xB1, 0xBA, 0xA8, 0xAC, 0xA5, 0xAA, 0x9F, 0xA4, 0xAD, 0xAA, 0xAD, 0xAB, 0xAF, 0xB3, 0xAD, 0xB1, 0xA2, 0xA1, 0xA0, 0x99, 0x95, 0x91, 0xA2, 0xA0, 0xA4, 0x9F, 0xA1, 0x9D, 0x97, 0x8D, 0x9E, 0x9B, 0xA1, 0xA0, 0x9C, 0x97, 0x93, 0x8D, 0x9F, 0x9B, 0x99, 0x97, 0xA1, 0xA3, 0x98, 0x90, 0x96, 0x9B, 0xA9, 0xAA, 0x96, 0x90, 0x95, 0x90, 0x98, 0x8D, 0xA0, 0x9B, 0x9B, 0x93, 0x88, 0x7F, 0x8B, 0x83, 0x86, 0x7E, 0x8A, 0x7D, 0x8B, 0x83, 0x89, 0x7E, 0x8A, 0x80, 0x87, 0x7D, 0x83, 0x79, 0x86, 0x7F, 0x81, 0x72, 0x7A, 0x6E, 0x7A, 0x6B, 0x74, 0x68, 0x7B, 0x6D, 0x78, 0x6B, 0x7D, 0x6E, 0x76, 0x69, 0x7A, 0x6D, 0x7F, 0x72, 0x7E, 0x6F, 0x7F, 0x70, 0x7A, 0x6B, 0x76, 0x68, 0x79, 0x6B, 0x75, 0x68, 0x75, 0x68, 0x78, 0x67, 0x72, 0x64, 0x72, 0x64, 0x7C, 0x71, 0x7D, 0x70, 0x78, 0x6D, 0x76, 0x67, 0x74, 0x68, 0x76, 0x68, 0x7B, 0x6C, 0x78, 0x69, 0x78, 0x66, 0x75, 0x64, 0x75, 0x65, 0x76, 0x6A, 0x7B, 0x6D, 0x73, 0x65, 0x70, 0x63, 0x73, 0x67, 0x76, 0x68, 0x76, 0x68, 0x77, 0x68, 0x75, 0x69, 0x7A, 0x6B, 0x7B, 0x6D, 0x75, 0x6A, 0x76, 0x6C, 0x7A, 0x70, 0x73, 0x68, 0x79, 0x6A, 0x77, 0x6A, 0x77, 0x6C, 0x83, 0x7F, 0x92, 0x8F, 0x87, 0x83, 0x86, 0x7F, 0x7E, 0x79, 0x85, 0x7F, 0x84, 0x7F, 0x87, 0x83, 0x8D, 0x8E, 0x88, 0x85, 0x81, 0x77, 0x7D, 0x73, 0x7A, 0x72, 0x7C, 0x73, 0x7B, 0x71, 0x7A, 0x6D, 0x77, 0x6C, 0x73, 0x69, 0x73, 0x68, 0x74, 0x6A, 0x76, 0x6E, 0x78, 0x70, 0x77, 0x6B, 0x75, 0x68, 0x76, 0x6B, 0x78, 0x6D, 0x73, 0x66, 0x74, 0x66, 0x72, 0x65, 0x59, 0x60, 0x48, 0x4D, 0x47, 0x53, 0x4B, 0x51, 0x40, 0x48, 0x4B, 0x55, 0x3F, 0x46, 0x3F, 0x47, 0x3F, 0x48, 0x43, 0x4A, 0x3D, 0x46, 0x46, 0x4F, 0x46, 0x4E, 0x4A, 0x54, 0x45, 0x4E, 0x46, 0x52, 0x4D, 0x59, 0x4D, 0x59, 0x4E, 0x5B, 0x4B, 0x59, 0x53, 0x5F, 0x4A, 0x55, 0x4B, 0x56, 0x4B, 0x58, 0x4F, 0x59, 0x45, 0x4C, 0x47, 0x4E, 0x42, 0x4D, 0x43, 0x48, 0x3F, 0x49, 0x42, 0x4B, 0x43, 0x4B, 0x41, 0x48, 0x43, 0x4D, 0x47, 0x4F, 0x46, 0x51, 0x4A, 0x56, 0x45, 0x4A, 0x3F, 0x49, 0x48, 0x52, 0x40, 0x48, 0x49, 0x54, 0x41, 0x47, 0x39, 0x43, 0x42, 0x49, 0x3F, 0x49, 0x3B, 0x42, 0x40, 0x4A, 0x3B, 0x43, 0x42, 0x49
    },

    {
        0x4F, 0x1D, 0x50, 0x1D, 0x50, 0x1D, 0x51, 0x1D, 0x51, 0x1F, 0x58, 0x25, 0x66, 0x2F, 0x6E, 0x35, 0x6B, 0x2C, 0x5B, 0x24, 0x57, 0x22, 0x58, 0x21, 0x59, 0x22, 0x55, 0x21, 0x55, 0x20, 0x56, 0x21, 0x57, 0x20, 0x5A, 0x22, 0x5C, 0x22, 0x5A, 0x21, 0x5B, 0x22, 0x5E, 0x22, 0x5E, 0x22, 0x5C, 0x21, 0x5E, 0x22, 0x5E, 0x22, 0x61, 0x23, 0x60, 0x23, 0x5F, 0x23, 0x5F, 0x23, 0x5F, 0x23, 0x5E, 0x23, 0x61, 0x23, 0x63, 0x25, 0x68, 0x27, 0x69, 0x29, 0x68, 0x29, 0x6E, 0x2A, 0x6B, 0x29, 0x6B, 0x2A, 0x6D, 0x29, 0x68, 0x27, 0x67, 0x27, 0x67, 0x27, 0x67, 0x26, 0x69, 0x27, 0x66, 0x26, 0x65, 0x25, 0x64, 0x24, 0x63, 0x25, 0x65, 0x25, 0x65, 0x25, 0x67, 0x26, 0x65, 0x25, 0x64, 0x24, 0x62, 0x24, 0x5F, 0x23, 0x63, 0x25, 0x69, 0x27, 0x69, 0x26, 0x65, 0x25, 0x65, 0x26, 0x67, 0x27, 0x69, 0x27, 0x6B, 0x28, 0x6B, 0x28, 0x6B, 0x29, 0x6B, 0x28, 0x6A, 0x29, 0x6A, 0x28, 0x67, 0x27, 0x66, 0x26, 0x66, 0x26, 0x69, 0x26, 0x67, 0x26, 0x6C, 0x29, 0x6D, 0x29, 0x69, 0x27, 0x69, 0x27, 0x68, 0x27, 0x6B, 0x27, 0x6A, 0x26, 0x6B, 0x28, 0x64, 0x25, 0x65, 0x26, 0x6A, 0x28, 0x66, 0x26, 0x69, 0x28, 0x69, 0x28, 0x6C, 0x2A, 0x69, 0x28, 0x6A, 0x27, 0x6A, 0x27, 0x6D, 0x28, 0x6A, 0x28, 0x6C, 0x2B, 0x75, 0x2B, 0x6C, 0x28, 0x72, 0x2B, 0x6D, 0x2A, 0x6A, 0x29, 0x6D, 0x2A, 0x75, 0x2F, 0x72, 0x2E, 0x74, 0x2D, 0x72, 0x2C, 0x74, 0x30, 0x80, 0x39, 0x7C, 0x2F, 0x75, 0x34, 0x87, 0x3B, 0x7E, 0x38, 0x78, 0x31, 0x72, 0x30, 0x71, 0x30, 0x8E, 0x46, 0x9B, 0x47, 0x8F, 0x3D, 0x78, 0x32, 0x81, 0x3D, 0x80, 0x36, 0x76, 0x31, 0x79, 0x33, 0x83, 0x3E, 0x89, 0x3E, 0x9B, 0x48, 0xA0, 0x4D, 0xAE, 0x5A, 0xAA, 0x55, 0x98, 0x48, 0x8E, 0x41, 0x99, 0x4A, 0xAC, 0x55, 0xA2, 0x55, 0xC6, 0x69, 0xA8, 0x52, 0x9A, 0x48, 0x9B, 0x4F, 0xA2, 0x4D, 0x90, 0x3D, 0x82, 0x3D, 0x8B, 0x41, 0x7D, 0x36, 0x64, 0x38, 0x6A, 0x40, 0x63, 0x3F, 0x79, 0x4A, 0x73, 0x48, 0x59, 0x33, 0x4F, 0x35, 0x98, 0x4F, 0xB0, 0x55, 0x9E, 0x4F, 0x96, 0x43, 0x8E, 0x41, 0x85, 0x3D, 0x8C, 0x40, 0x98, 0x49, 0x9F, 0x4B, 0x89, 0x3D, 0x89, 0x41, 0x8C, 0x3C, 0x90, 0x48, 0xB4, 0x5C, 0xB6, 0x59, 0xA1, 0x4A, 0x8A, 0x3F, 0x81, 0x37, 0x8C, 0x3E, 0x8C, 0x3E, 0x9B, 0x50, 0xA5, 0x4B, 0x9C, 0x52, 0xA4, 0x4F, 0x96, 0x48, 0x8F, 0x44, 0x92, 0x41, 0x82, 0x37, 0x82, 0x38, 0x97, 0x47, 0xA4, 0x4F, 0x8D, 0x3D, 0x7D, 0x36, 0x7F, 0x38, 0x76, 0x31, 0x7C, 0x34, 0x75, 0x32, 0x75, 0x31, 0x7A, 0x34, 0x76, 0x33, 0x73, 0x2F, 0x71, 0x2F, 0x6E, 0x2B, 0x6A, 0x28, 0x6B, 0x28, 0x69, 0x29, 0x6D, 0x2C, 0x6A, 0x2A, 0x68, 0x2A, 0x6A, 0x29, 0x67, 0x28, 0x6A, 0x2A, 0x6E, 0x2C, 0x6C, 0x29, 0x68, 0x27, 0x65, 0x28, 0x65, 0x26, 0x64, 0x27, 0x68, 0x28, 0x66, 0x28, 0x64, 0x28, 0x60, 0x26, 0x63, 0x27, 0x6A, 0x2A, 0x6F, 0x2F, 0x67, 0x28, 0x5F, 0x25, 0x66, 0x28, 0x63, 0x27, 0x63, 0x25, 0x60, 0x23, 0x61, 0x25, 0x62, 0x24, 0x64, 0x2A, 0x6A, 0x29, 0x61, 0x24, 0x61, 0x27, 0x64, 0x27, 0x66, 0x27, 0x61, 0x26, 0x61, 0x25, 0x64, 0x26, 0x66, 0x28, 0x66, 0x27, 0x6A, 0x2A, 0x67, 0x29, 0x70, 0x2E, 0x65, 0x29, 0x70, 0x31, 0x65, 0x26, 0x63, 0x29, 0x6E, 0x31, 0x80, 0x3F, 0x7E, 0x39, 0x82, 0x3A, 0x76, 0x35, 0x70, 0x30, 0x6F, 0x2F, 0x76, 0x34, 0x7A, 0x37, 0x78, 0x34, 0x70, 0x2E, 0x6B, 0x2D, 0x6B, 0x2D, 0x68, 0x2A, 0x67, 0x2A, 0x67, 0x29, 0x68, 0x2A, 0x67, 0x2B, 0x67, 0x29, 0x68, 0x2A, 0x6A, 0x2D, 0x6B, 0x2D, 0x67, 0x29, 0x65, 0x28, 0x68, 0x2C, 0x66, 0x2B, 0x63, 0x28, 0x65, 0x28, 0x66, 0x29, 0x61, 0x31, 0x47, 0x26, 0x4F, 0x2B, 0x49, 0x27, 0x46, 0x26, 0x49, 0x28, 0x42, 0x23, 0x47, 0x27, 0x4F, 0x2A, 0x51, 0x29, 0x46, 0x26, 0x5B, 0x31, 0x58, 0x2D, 0x47, 0x26, 0x54, 0x2C, 0x4D, 0x2A, 0x5A, 0x2F, 0x4B, 0x2A, 0x51, 0x2C, 0x52, 0x2F, 0x52, 0x2D, 0x48, 0x29, 0x4D, 0x29, 0x49, 0x27, 0x4E, 0x2A, 0x47, 0x28, 0x51, 0x2B, 0x4D, 0x28, 0x47, 0x26, 0x4E, 0x2B, 0x4F, 0x2A, 0x47, 0x26, 0x50, 0x2B, 0x4F, 0x2B, 0x4E, 0x2B, 0x47, 0x27, 0x4B, 0x28, 0x42, 0x23, 0x45, 0x26, 0x4E, 0x2A, 0x42, 0x23, 0x4B, 0x27, 0x43, 0x23, 0x47, 0x26, 0x4C, 0x28, 0x48, 0x27, 0x4A, 0x27, 0x4A, 0x27, 0x46, 0x25, 0x4D, 0x28
    },

    {
        0x5D, 0x52, 0x5E, 0x53, 0x5C, 0x51, 0x5E, 0x52, 0x61, 0x56, 0x66, 0x5D, 0x6C, 0x69, 0x6E, 0x6B, 0x6B, 0x64, 0x66, 0x5D, 0x65, 0x5A, 0x66, 0x5A, 0x64, 0x5A, 0x64, 0x58, 0x64, 0x58, 0x65, 0x59, 0x67, 0x58, 0x69, 0x5C, 0x6C, 0x5E, 0x6B, 0x5E, 0x6E, 0x5E, 0x71, 0x62, 0x70, 0x61, 0x70, 0x60, 0x71, 0x61, 0x71, 0x63, 0x73, 0x64, 0x72, 0x62, 0x72, 0x63, 0x71, 0x62, 0x72, 0x61, 0x73, 0x62, 0x74, 0x64, 0x76, 0x66, 0x78, 0x68, 0x7A, 0x6C, 0x7B, 0x6C, 0x7B, 0x6F, 0x80, 0x6E, 0x7F, 0x6F, 0x80, 0x6E, 0x7C, 0x6B, 0x7D, 0x6C, 0x7C, 0x6A, 0x7D, 0x6C, 0x7D, 0x6B, 0x7D, 0x6B, 0x7A, 0x6A, 0x78, 0x67, 0x77, 0x67, 0x7B, 0x6B, 0x7D, 0x6A, 0x7E, 0x6B, 0x7A, 0x67, 0x78, 0x67, 0x76, 0x65, 0x75, 0x64, 0x79, 0x6A, 0x7E, 0x6B, 0x7D, 0x6B, 0x7A, 0x68, 0x7B, 0x6A, 0x7C, 0x6B, 0x7E, 0x6C, 0x81, 0x70, 0x83, 0x71, 0x82, 0x6F, 0x80, 0x6F, 0x7E, 0x6E, 0x7D, 0x6D, 0x7C, 0x6B, 0x7C, 0x6A, 0x7D, 0x6A, 0x7F, 0x6E, 0x7E, 0x6B, 0x80, 0x70, 0x81, 0x70, 0x7B, 0x6A, 0x7D, 0x6D, 0x7E, 0x6E, 0x80, 0x6E, 0x7E, 0x6E, 0x80, 0x6D, 0x7C, 0x6A, 0x7B, 0x6B, 0x80, 0x6F, 0x7C, 0x6A, 0x80, 0x6E, 0x7E, 0x6F, 0x82, 0x71, 0x7D, 0x6F, 0x80, 0x6F, 0x7F, 0x70, 0x80, 0x70, 0x7C, 0x6E, 0x81, 0x72, 0x83, 0x73, 0x83, 0x72, 0x89, 0x7A, 0x81, 0x70, 0x7E, 0x6E, 0x7E, 0x72, 0x87, 0x7A, 0x86, 0x78, 0x87, 0x79, 0x84, 0x75, 0x87, 0x7D, 0x94, 0x8C, 0x8C, 0x7A, 0x84, 0x7A, 0x8F, 0x88, 0x89, 0x83, 0x86, 0x7B, 0x85, 0x7C, 0x83, 0x77, 0x99, 0xA0, 0xA1, 0x99, 0x97, 0x8C, 0x85, 0x7B, 0x8C, 0x89, 0x88, 0x7D, 0x85, 0x7D, 0x87, 0x7E, 0x8C, 0x87, 0x92, 0x8D, 0x9D, 0x9F, 0x9B, 0x9B, 0xA8, 0xB3, 0xA7, 0xA7, 0x96, 0x8E, 0x95, 0x8F, 0xA0, 0x9E, 0xAE, 0xB1, 0xA8, 0xAC, 0xBE, 0xCA, 0xAA, 0xA8, 0x9B, 0x95, 0xA2, 0xAE, 0xA9, 0xAB, 0x96, 0x8D, 0x87, 0x83, 0x8C, 0x8D, 0x89, 0x7E, 0x66, 0x65, 0x5F, 0x69, 0x57, 0x64, 0x6C, 0x80, 0x68, 0x79, 0x52, 0x58, 0x4E, 0x5E, 0x98, 0xA8, 0xAE, 0xB4, 0x9F, 0xA0, 0x9C, 0x96, 0x99, 0x8F, 0x92, 0x88, 0x96, 0x8E, 0xA1, 0x9D, 0xA6, 0xAB, 0x95, 0x8D, 0x93, 0x8F, 0x98, 0x8C, 0x9A, 0xA5, 0xB0, 0xB7, 0xB4, 0xB6, 0xA1, 0x9C, 0x99, 0x94, 0x95, 0x8E, 0xA0, 0xA2, 0x97, 0x91, 0xA6, 0xB3, 0xA5, 0xA2, 0x9F, 0xAB, 0xA5, 0xA8, 0x9B, 0x9B, 0x9A, 0x96, 0x9B, 0x94, 0x93, 0x8A, 0x8F, 0x87, 0xA6, 0xA8, 0xA9, 0xAF, 0x9B, 0x8F, 0x8A, 0x84, 0x8F, 0x89, 0x87, 0x7C, 0x8B, 0x84, 0x86, 0x79, 0x87, 0x7C, 0x87, 0x7B, 0x87, 0x7E, 0x84, 0x76, 0x82, 0x78, 0x84, 0x74, 0x7B, 0x6C, 0x7C, 0x6C, 0x7F, 0x70, 0x7E, 0x74, 0x7B, 0x6F, 0x79, 0x6D, 0x7C, 0x6F, 0x7D, 0x6E, 0x7F, 0x71, 0x82, 0x73, 0x7C, 0x6E, 0x7C, 0x6C, 0x79, 0x6A, 0x76, 0x67, 0x74, 0x69, 0x78, 0x6C, 0x79, 0x6C, 0x77, 0x6C, 0x76, 0x69, 0x73, 0x6A, 0x7A, 0x70, 0x7F, 0x73, 0x7B, 0x6C, 0x75, 0x65, 0x79, 0x6C, 0x76, 0x68, 0x75, 0x67, 0x74, 0x65, 0x75, 0x65, 0x77, 0x67, 0x77, 0x70, 0x7B, 0x6B, 0x76, 0x65, 0x74, 0x66, 0x77, 0x6A, 0x7A, 0x6B, 0x72, 0x65, 0x75, 0x65, 0x77, 0x6B, 0x77, 0x6A, 0x78, 0x6A, 0x7B, 0x6F, 0x7C, 0x6F, 0x80, 0x75, 0x79, 0x6E, 0x85, 0x7E, 0x78, 0x68, 0x75, 0x6B, 0x7D, 0x76, 0x83, 0x83, 0x8A, 0x81, 0x8A, 0x88, 0x87, 0x81, 0x7D, 0x73, 0x7F, 0x75, 0x81, 0x79, 0x84, 0x7C, 0x84, 0x7B, 0x7E, 0x74, 0x7B, 0x71, 0x7A, 0x70, 0x77, 0x6D, 0x76, 0x6A, 0x78, 0x6B, 0x78, 0x6E, 0x79, 0x6E, 0x78, 0x6C, 0x7A, 0x6E, 0x78, 0x6F, 0x78, 0x6E, 0x78, 0x6C, 0x76, 0x68, 0x7A, 0x6E, 0x76, 0x6A, 0x74, 0x68, 0x75, 0x69, 0x74, 0x68, 0x5D, 0x61, 0x43, 0x47, 0x49, 0x54, 0x44, 0x4D, 0x43, 0x4E, 0x45, 0x4C, 0x3E, 0x45, 0x45, 0x52, 0x4A, 0x54, 0x4B, 0x52, 0x40, 0x4A, 0x52, 0x61, 0x4C, 0x54, 0x40, 0x48, 0x4C, 0x55, 0x47, 0x52, 0x50, 0x57, 0x43, 0x4C, 0x46, 0x4F, 0x48, 0x55, 0x48, 0x50, 0x42, 0x4C, 0x44, 0x4D, 0x43, 0x4F, 0x48, 0x50, 0x43, 0x4E, 0x4A, 0x54, 0x46, 0x50, 0x43, 0x4B, 0x48, 0x56, 0x44, 0x4B, 0x40, 0x4D, 0x48, 0x51, 0x47, 0x50, 0x44, 0x4B, 0x40, 0x4C, 0x42, 0x48, 0x3D, 0x45, 0x40, 0x49, 0x45, 0x4D, 0x3D, 0x46, 0x47, 0x4F, 0x40, 0x48, 0x44, 0x4E, 0x46, 0x4E, 0x43, 0x4F, 0x45, 0x4E, 0x43, 0x4D, 0x3E, 0x47, 0x45, 0x52
    },

    {
        0x52, 0x1E, 0x51, 0x1D, 0x51, 0x1D, 0x51, 0x1D, 0x51, 0x1E, 0x55, 0x1F, 0x55, 0x21, 0x5A, 0x25, 0x5E, 0x27, 0x5A, 0x25, 0x59, 0x22, 0x58, 0x20, 0x55, 0x20, 0x54, 0x1E, 0x53, 0x1E, 0x55, 0x1F, 0x53, 0x1F, 0x59, 0x21, 0x59, 0x21, 0x58, 0x20, 0x5B, 0x20, 0x5D, 0x22, 0x5E, 0x22, 0x5D, 0x22, 0x5E, 0x22, 0x5E, 0x23, 0x5F, 0x22, 0x5F, 0x23, 0x62, 0x23, 0x5E, 0x22, 0x5E, 0x23, 0x5F, 0x22, 0x5F, 0x23, 0x62, 0x23, 0x62, 0x24, 0x61, 0x24, 0x63, 0x25, 0x60, 0x26, 0x66, 0x27, 0x68, 0x27, 0x68, 0x26, 0x66, 0x26, 0x66, 0x26, 0x67, 0x25, 0x68, 0x25, 0x65, 0x25, 0x66, 0x26, 0x66, 0x25, 0x66, 0x25, 0x66, 0x26, 0x69, 0x27, 0x67, 0x26, 0x66, 0x26, 0x66, 0x25, 0x65, 0x25, 0x66, 0x25, 0x64, 0x25, 0x65, 0x25, 0x65, 0x25, 0x66, 0x25, 0x65, 0x25, 0x63, 0x24, 0x65, 0x25, 0x69, 0x27, 0x6B, 0x28, 0x6D, 0x28, 0x6E, 0x28, 0x69, 0x27, 0x68, 0x26, 0x69, 0x27, 0x67, 0x27, 0x68, 0x27, 0x69, 0x27, 0x6B, 0x27, 0x6A, 0x27, 0x67, 0x27, 0x69, 0x27, 0x68, 0x27, 0x6B, 0x28, 0x69, 0x27, 0x68, 0x26, 0x67, 0x26, 0x65, 0x25, 0x67, 0x27, 0x66, 0x26, 0x68, 0x26, 0x65, 0x26, 0x69, 0x27, 0x6A, 0x29, 0x6A, 0x28, 0x6B, 0x28, 0x6A, 0x27, 0x6B, 0x28, 0x6A, 0x27, 0x68, 0x27, 0x68, 0x27, 0x68, 0x28, 0x69, 0x28, 0x72, 0x2D, 0x6F, 0x2A, 0x6A, 0x2A, 0x6C, 0x29, 0x72, 0x2D, 0x73, 0x2C, 0x71, 0x2D, 0x6E, 0x29, 0x6D, 0x2E, 0x80, 0x35, 0x7A, 0x32, 0x76, 0x30, 0x76, 0x32, 0x7B, 0x37, 0x7E, 0x34, 0x7A, 0x35, 0x74, 0x2F, 0x96, 0x4A, 0x8B, 0x3D, 0x80, 0x37, 0x75, 0x31, 0x7D, 0x36, 0x78, 0x35, 0x7C, 0x39, 0x84, 0x3B, 0x8A, 0x43, 0xA6, 0x4F, 0x99, 0x49, 0x8D, 0x42, 0x89, 0x3E, 0x83, 0x3C, 0x8E, 0x42, 0x92, 0x49, 0xAB, 0x54, 0xB8, 0x5B, 0xAB, 0x52, 0xA4, 0x50, 0x98, 0x43, 0x88, 0x3E, 0x93, 0x48, 0x98, 0x47, 0x81, 0x38, 0x7D, 0x37, 0x7E, 0x38, 0x81, 0x39, 0x68, 0x33, 0x56, 0x37, 0x5F, 0x3A, 0x66, 0x42, 0x6D, 0x3E, 0x5C, 0x38, 0x63, 0x3A, 0x8B, 0x48, 0x90, 0x41, 0x86, 0x37, 0x8C, 0x41, 0xA2, 0x4C, 0x8F, 0x3F, 0x85, 0x3B, 0x83, 0x39, 0x8F, 0x43, 0x8B, 0x41, 0x96, 0x49, 0xA1, 0x4D, 0x9C, 0x4B, 0xA1, 0x4E, 0xA4, 0x4B, 0x91, 0x43, 0xA0, 0x48, 0xAC, 0x58, 0xB2, 0x55, 0x89, 0x3C, 0x92, 0x46, 0x8B, 0x3F, 0x94, 0x45, 0x8F, 0x41, 0x7B, 0x36, 0x88, 0x40, 0x86, 0x3A, 0x8B, 0x42, 0x93, 0x42, 0x9C, 0x4A, 0x94, 0x45, 0x8E, 0x41, 0x80, 0x37, 0x7D, 0x34, 0x73, 0x30, 0x88, 0x3C, 0x70, 0x2F, 0x7D, 0x35, 0x6E, 0x2C, 0x76, 0x30, 0x74, 0x2E, 0x6C, 0x2B, 0x6E, 0x2B, 0x6B, 0x29, 0x67, 0x28, 0x68, 0x28, 0x68, 0x28, 0x6A, 0x2A, 0x6B, 0x2B, 0x6D, 0x2A, 0x6B, 0x29, 0x6A, 0x28, 0x6A, 0x29, 0x66, 0x26, 0x62, 0x25, 0x64, 0x25, 0x64, 0x26, 0x64, 0x26, 0x64, 0x25, 0x65, 0x26, 0x64, 0x28, 0x68, 0x29, 0x6A, 0x2B, 0x69, 0x2A, 0x69, 0x28, 0x67, 0x28, 0x62, 0x25, 0x63, 0x26, 0x64, 0x25, 0x5F, 0x25, 0x65, 0x25, 0x64, 0x25, 0x60, 0x24, 0x62, 0x27, 0x69, 0x28, 0x65, 0x25, 0x64, 0x26, 0x64, 0x27, 0x6A, 0x28, 0x62, 0x24, 0x5F, 0x24, 0x64, 0x27, 0x64, 0x28, 0x65, 0x26, 0x67, 0x28, 0x64, 0x26, 0x6D, 0x2E, 0x6C, 0x2C, 0x6C, 0x2C, 0x65, 0x29, 0x66, 0x2A, 0x70, 0x2F, 0x74, 0x33, 0x7E, 0x3A, 0x7D, 0x38, 0x79, 0x34, 0x71, 0x31, 0x72, 0x31, 0x67, 0x2B, 0x6D, 0x2D, 0x6D, 0x2E, 0x6C, 0x2D, 0x6B, 0x2C, 0x6C, 0x2C, 0x6A, 0x2B, 0x67, 0x29, 0x68, 0x2A, 0x65, 0x28, 0x66, 0x29, 0x67, 0x29, 0x66, 0x28, 0x66, 0x2A, 0x69, 0x2C, 0x64, 0x29, 0x64, 0x28, 0x65, 0x2A, 0x66, 0x2A, 0x65, 0x29, 0x65, 0x29, 0x64, 0x2A, 0x54, 0x2B, 0x49, 0x26, 0x50, 0x2B, 0x5B, 0x2E, 0x4A, 0x26, 0x4B, 0x29, 0x45, 0x25, 0x53, 0x2B, 0x43, 0x24, 0x48, 0x27, 0x45, 0x28, 0x56, 0x2D, 0x47, 0x26, 0x42, 0x25, 0x4D, 0x29, 0x4C, 0x28, 0x4C, 0x28, 0x44, 0x26, 0x53, 0x2B, 0x53, 0x2E, 0x58, 0x2E, 0x4B, 0x2A, 0x54, 0x2C, 0x51, 0x2B, 0x51, 0x2A, 0x49, 0x28, 0x55, 0x2C, 0x45, 0x26, 0x41, 0x24, 0x45, 0x26, 0x3F, 0x23, 0x49, 0x27, 0x48, 0x26, 0x4A, 0x28, 0x47, 0x27, 0x50, 0x2B, 0x56, 0x2D, 0x50, 0x2A, 0x49, 0x27, 0x4D, 0x28, 0x45, 0x24, 0x55, 0x2C, 0x4A, 0x26, 0x42, 0x24, 0x43, 0x23, 0x48, 0x27, 0x43, 0x22, 0x43, 0x24, 0x3E, 0x21, 0x4B, 0x26
    },

    {
        0x60, 0x55, 0x60, 0x54, 0x5E, 0x52, 0x60, 0x53, 0x60, 0x55, 0x64, 0x57, 0x63, 0x56, 0x66, 0x5A, 0x67, 0x5F, 0x64, 0x5D, 0x66, 0x5B, 0x66, 0x5A, 0x64, 0x57, 0x61, 0x55, 0x62, 0x57, 0x64, 0x55, 0x64, 0x57, 0x68, 0x58, 0x67, 0x5A, 0x68, 0x5B, 0x6C, 0x5D, 0x70, 0x60, 0x6D, 0x5F, 0x70, 0x61, 0x72, 0x61, 0x73, 0x64, 0x72, 0x61, 0x72, 0x62, 0x75, 0x66, 0x70, 0x60, 0x71, 0x62, 0x71, 0x61, 0x72, 0x64, 0x77, 0x64, 0x75, 0x64, 0x73, 0x63, 0x78, 0x66, 0x72, 0x64, 0x76, 0x68, 0x7A, 0x67, 0x79, 0x69, 0x7A, 0x6B, 0x7B, 0x69, 0x7C, 0x68, 0x7C, 0x6A, 0x7A, 0x68, 0x7A, 0x6A, 0x7D, 0x6B, 0x7C, 0x69, 0x7D, 0x6D, 0x7C, 0x6B, 0x7D, 0x6B, 0x7C, 0x6A, 0x7B, 0x69, 0x79, 0x68, 0x7A, 0x6A, 0x7A, 0x6A, 0x79, 0x69, 0x7A, 0x67, 0x7B, 0x6A, 0x79, 0x6A, 0x78, 0x67, 0x7D, 0x6B, 0x82, 0x6F, 0x80, 0x6E, 0x83, 0x71, 0x85, 0x73, 0x80, 0x6E, 0x80, 0x6E, 0x7E, 0x6E, 0x7E, 0x6E, 0x7E, 0x6E, 0x7F, 0x6D, 0x80, 0x70, 0x82, 0x6F, 0x7F, 0x6D, 0x7E, 0x6E, 0x7C, 0x6D, 0x80, 0x6F, 0x7B, 0x6E, 0x7D, 0x6B, 0x7C, 0x6A, 0x79, 0x67, 0x7C, 0x6C, 0x7A, 0x6B, 0x7B, 0x6B, 0x7A, 0x6B, 0x7E, 0x6C, 0x7F, 0x6F, 0x81, 0x71, 0x81, 0x70, 0x7D, 0x6F, 0x81, 0x70, 0x7F, 0x6E, 0x7E, 0x6C, 0x7D, 0x6A, 0x7D, 0x6D, 0x7F, 0x6F, 0x80, 0x74, 0x81, 0x72, 0x7C, 0x6E, 0x7F, 0x70, 0x84, 0x78, 0x84, 0x74, 0x83, 0x78, 0x81, 0x72, 0x7F, 0x74, 0x8A, 0x7E, 0x8A, 0x80, 0x87, 0x7B, 0x86, 0x79, 0x88, 0x84, 0x8F, 0x82, 0x85, 0x7E, 0x84, 0x78, 0x9C, 0xA0, 0x96, 0x8B, 0x8D, 0x87, 0x84, 0x78, 0x8C, 0x83, 0x89, 0x7F, 0x87, 0x83, 0x90, 0x8C, 0x98, 0x9B, 0xA3, 0xA7, 0x9B, 0x9C, 0x97, 0x92, 0x90, 0x89, 0x8B, 0x87, 0x9C, 0xA0, 0xA3, 0xA3, 0xAC, 0xAF, 0xB3, 0xB5, 0xAA, 0xAB, 0xA7, 0xA3, 0x9B, 0x91, 0x8F, 0x8C, 0x96, 0x96, 0x97, 0x94, 0x91, 0x87, 0x8C, 0x86, 0x8B, 0x84, 0x8C, 0x87, 0x72, 0x69, 0x54, 0x5F, 0x5C, 0x6A, 0x5E, 0x72, 0x5F, 0x6A, 0x57, 0x65, 0x6C, 0x7B, 0x94, 0x96, 0x96, 0x8F, 0x99, 0x89, 0x9D, 0x9E, 0xA9, 0xAD, 0x9C, 0x97, 0x99, 0x91, 0x95, 0x8C, 0x99, 0x96, 0x9D, 0x9A, 0xA2, 0xA3, 0xA4, 0xA9, 0xA1, 0xA4, 0xA8, 0xAC, 0xAA, 0xA9, 0xA0, 0x9A, 0xA4, 0xA8, 0xB1, 0xBF, 0xB2, 0xB1, 0x95, 0x8D, 0x99, 0x93, 0x95, 0x95, 0x9C, 0x99, 0x91, 0x89, 0x88, 0x80, 0x90, 0x8F, 0x91, 0x88, 0x9C, 0x9E, 0x99, 0x95, 0x9A, 0x97, 0x96, 0x8E, 0x98, 0x95, 0x8C, 0x86, 0x8A, 0x7E, 0x84, 0x7A, 0x91, 0x8A, 0x83, 0x77, 0x89, 0x80, 0x7F, 0x72, 0x84, 0x78, 0x81, 0x77, 0x7F, 0x71, 0x83, 0x74, 0x7C, 0x6E, 0x7A, 0x6C, 0x7B, 0x6C, 0x7A, 0x6E, 0x7B, 0x70, 0x7D, 0x70, 0x7E, 0x6F, 0x7E, 0x70, 0x7C, 0x6F, 0x7C, 0x6E, 0x79, 0x69, 0x74, 0x66, 0x7A, 0x68, 0x77, 0x69, 0x77, 0x6A, 0x75, 0x67, 0x78, 0x67, 0x74, 0x6A, 0x7B, 0x6F, 0x7A, 0x70, 0x7C, 0x6F, 0x7C, 0x6D, 0x7D, 0x6C, 0x78, 0x68, 0x77, 0x69, 0x76, 0x66, 0x73, 0x67, 0x79, 0x68, 0x75, 0x65, 0x72, 0x66, 0x74, 0x6B, 0x79, 0x6C, 0x78, 0x69, 0x78, 0x68, 0x75, 0x69, 0x7C, 0x6D, 0x75, 0x66, 0x75, 0x67, 0x77, 0x6A, 0x75, 0x69, 0x77, 0x69, 0x7A, 0x6B, 0x76, 0x65, 0x7B, 0x75, 0x7D, 0x73, 0x7C, 0x6F, 0x75, 0x69, 0x77, 0x6C, 0x7C, 0x72, 0x7F, 0x7A, 0x82, 0x7F, 0x87, 0x83, 0x80, 0x77, 0x7A, 0x74, 0x7F, 0x77, 0x7C, 0x6F, 0x7C, 0x70, 0x7B, 0x71, 0x7C, 0x72, 0x7A, 0x6F, 0x7C, 0x71, 0x79, 0x6F, 0x78, 0x6B, 0x7A, 0x6D, 0x78, 0x6B, 0x78, 0x6B, 0x79, 0x6D, 0x7A, 0x6C, 0x78, 0x6D, 0x76, 0x6D, 0x75, 0x69, 0x76, 0x6A, 0x75, 0x6C, 0x78, 0x6B, 0x76, 0x6B, 0x74, 0x6C, 0x70, 0x67, 0x52, 0x56, 0x44, 0x48, 0x4A, 0x58, 0x51, 0x59, 0x40, 0x44, 0x46, 0x4E, 0x40, 0x48, 0x4B, 0x55, 0x3E, 0x44, 0x42, 0x48, 0x41, 0x4F, 0x4A, 0x54, 0x42, 0x48, 0x3F, 0x48, 0x48, 0x51, 0x49, 0x54, 0x47, 0x4D, 0x41, 0x4C, 0x4F, 0x58, 0x4C, 0x59, 0x50, 0x59, 0x46, 0x51, 0x4A, 0x52, 0x46, 0x53, 0x46, 0x4D, 0x42, 0x4D, 0x4A, 0x50, 0x3E, 0x47, 0x3B, 0x41, 0x3E, 0x46, 0x3D, 0x45, 0x44, 0x4E, 0x43, 0x4D, 0x46, 0x4F, 0x44, 0x4E, 0x4B, 0x58, 0x4F, 0x5B, 0x46, 0x4E, 0x43, 0x4D, 0x46, 0x52, 0x40, 0x48, 0x4A, 0x56, 0x40, 0x46, 0x3D, 0x45, 0x3C, 0x42, 0x42, 0x4D, 0x3C, 0x42, 0x3D, 0x46, 0x3C, 0x45, 0x48, 0x51
    },

    {
        0x52, 0x1E, 0x50, 0x1D, 0x50, 0x1D, 0x52, 0x1D, 0x51, 0x1D, 0x53, 0x1E, 0x52, 0x1F, 0x57, 0x23, 0x58, 0x24, 0x5B, 0x26, 0x59, 0x23, 0x57, 0x21, 0x54, 0x22, 0x55, 0x24, 0x50, 0x20, 0x51, 0x20, 0x53, 0x1F, 0x56, 0x20, 0x55, 0x1F, 0x57, 0x20, 0x59, 0x20, 0x5B, 0x21, 0x5C, 0x22, 0x5D, 0x22, 0x5F, 0x23, 0x5F, 0x23, 0x5E, 0x23, 0x5D, 0x22, 0x60, 0x22, 0x5C, 0x22, 0x5A, 0x21, 0x5D, 0x22, 0x5D, 0x22, 0x5F, 0x23, 0x61, 0x23, 0x60, 0x23, 0x60, 0x23, 0x63, 0x26, 0x66, 0x27, 0x65, 0x27, 0x66, 0x26, 0x66, 0x25, 0x64, 0x25, 0x65, 0x24, 0x64, 0x24, 0x64, 0x24, 0x66, 0x26, 0x65, 0x25, 0x67, 0x26, 0x67, 0x26, 0x65, 0x26, 0x66, 0x27, 0x67, 0x28, 0x67, 0x27, 0x64, 0x25, 0x66, 0x24, 0x64, 0x25, 0x65, 0x25, 0x63, 0x25, 0x67, 0x25, 0x63, 0x24, 0x64, 0x25, 0x67, 0x26, 0x67, 0x26, 0x69, 0x26, 0x6A, 0x27, 0x6A, 0x28, 0x6F, 0x2A, 0x6A, 0x27, 0x6A, 0x28, 0x6B, 0x28, 0x6D, 0x29, 0x6A, 0x27, 0x6B, 0x27, 0x6B, 0x28, 0x66, 0x25, 0x66, 0x26, 0x68, 0x27, 0x6B, 0x27, 0x6B, 0x28, 0x6B, 0x28, 0x6A, 0x27, 0x68, 0x27, 0x6A, 0x28, 0x69, 0x27, 0x6A, 0x29, 0x67, 0x27, 0x6B, 0x28, 0x6A, 0x28, 0x6D, 0x29, 0x70, 0x2B, 0x6D, 0x29, 0x6F, 0x29, 0x68, 0x28, 0x68, 0x27, 0x68, 0x27, 0x6B, 0x2B, 0x6E, 0x2B, 0x70, 0x2B, 0x70, 0x2C, 0x6D, 0x29, 0x6F, 0x2B, 0x6D, 0x2D, 0x71, 0x2C, 0x71, 0x2E, 0x6E, 0x2A, 0x6E, 0x2C, 0x73, 0x2F, 0x7A, 0x33, 0x79, 0x32, 0x73, 0x2F, 0x74, 0x2F, 0x77, 0x31, 0x70, 0x2F, 0x74, 0x32, 0x7A, 0x32, 0x7A, 0x34, 0x82, 0x35, 0x74, 0x34, 0x8E, 0x3E, 0x7C, 0x35, 0x7F, 0x3B, 0x88, 0x42, 0xA2, 0x51, 0xA8, 0x4D, 0x98, 0x4B, 0x96, 0x46, 0x8D, 0x42, 0x8B, 0x40, 0xA2, 0x51, 0xA7, 0x52, 0x9D, 0x4E, 0xA4, 0x4E, 0x93, 0x47, 0x97, 0x46, 0x89, 0x3D, 0x83, 0x3A, 0x88, 0x40, 0x96, 0x46, 0x89, 0x3D, 0x8C, 0x3D, 0x7E, 0x37, 0x82, 0x3C, 0x85, 0x3D, 0x5C, 0x36, 0x69, 0x40, 0x5F, 0x3C, 0x70, 0x44, 0x73, 0x4C, 0xB1, 0x5B, 0xA8, 0x54, 0x9D, 0x48, 0x97, 0x43, 0x8B, 0x3F, 0x80, 0x37, 0x84, 0x3D, 0x8F, 0x43, 0xA3, 0x4C, 0x96, 0x44, 0x9B, 0x4F, 0xA5, 0x4D, 0x8B, 0x3F, 0x98, 0x4C, 0x9E, 0x52, 0xBC, 0x5E, 0x91, 0x42, 0xA1, 0x52, 0xAB, 0x52, 0xA0, 0x4E, 0x8C, 0x41, 0x8A, 0x41, 0x90, 0x44, 0x8F, 0x40, 0x73, 0x32, 0x7B, 0x33, 0x7C, 0x35, 0x80, 0x38, 0x86, 0x3E, 0x82, 0x39, 0x7D, 0x39, 0x90, 0x43, 0x89, 0x3D, 0x77, 0x31, 0x81, 0x3D, 0x86, 0x3C, 0x83, 0x36, 0x71, 0x2E, 0x72, 0x2D, 0x69, 0x28, 0x6F, 0x2C, 0x70, 0x2D, 0x6F, 0x2F, 0x79, 0x32, 0x68, 0x29, 0x6B, 0x2A, 0x6A, 0x28, 0x67, 0x28, 0x6A, 0x29, 0x6C, 0x28, 0x6A, 0x28, 0x69, 0x28, 0x69, 0x28, 0x68, 0x28, 0x65, 0x26, 0x64, 0x27, 0x66, 0x26, 0x67, 0x26, 0x62, 0x25, 0x63, 0x26, 0x61, 0x24, 0x66, 0x26, 0x67, 0x27, 0x68, 0x2A, 0x66, 0x29, 0x67, 0x29, 0x66, 0x27, 0x65, 0x26, 0x65, 0x26, 0x60, 0x27, 0x60, 0x24, 0x64, 0x26, 0x62, 0x25, 0x63, 0x25, 0x66, 0x28, 0x67, 0x28, 0x63, 0x26, 0x64, 0x26, 0x67, 0x27, 0x62, 0x25, 0x62, 0x25, 0x62, 0x26, 0x65, 0x28, 0x67, 0x28, 0x60, 0x24, 0x61, 0x25, 0x60, 0x25, 0x66, 0x29, 0x6B, 0x2C, 0x75, 0x31, 0x60, 0x26, 0x62, 0x27, 0x68, 0x2A, 0x6D, 0x2F, 0x71, 0x31, 0x72, 0x30, 0x6A, 0x2C, 0x6B, 0x2C, 0x6E, 0x2E, 0x6D, 0x2E, 0x6B, 0x2C, 0x6A, 0x2D, 0x6B, 0x2D, 0x6C, 0x2D, 0x69, 0x2B, 0x67, 0x2A, 0x65, 0x27, 0x69, 0x2A, 0x65, 0x28, 0x67, 0x28, 0x65, 0x28, 0x65, 0x28, 0x65, 0x29, 0x65, 0x29, 0x64, 0x29, 0x66, 0x29, 0x67, 0x2B, 0x67, 0x2A, 0x68, 0x2A, 0x67, 0x29, 0x5F, 0x28, 0x50, 0x28, 0x43, 0x23, 0x4A, 0x28, 0x4F, 0x29, 0x42, 0x24, 0x50, 0x2A, 0x4F, 0x2A, 0x51, 0x2B, 0x47, 0x27, 0x51, 0x2B, 0x4E, 0x2A, 0x58, 0x2D, 0x53, 0x2B, 0x4B, 0x29, 0x58, 0x2E, 0x4F, 0x2A, 0x4C, 0x28, 0x47, 0x27, 0x4D, 0x29, 0x49, 0x28, 0x48, 0x28, 0x4E, 0x2A, 0x44, 0x26, 0x4F, 0x2A, 0x42, 0x24, 0x46, 0x26, 0x43, 0x24, 0x48, 0x27, 0x50, 0x2A, 0x50, 0x2A, 0x4B, 0x28, 0x52, 0x2C, 0x56, 0x2E, 0x51, 0x2C, 0x52, 0x2A, 0x54, 0x2D, 0x4A, 0x27, 0x3E, 0x22, 0x44, 0x26, 0x48, 0x27, 0x43, 0x25, 0x4A, 0x26, 0x46, 0x24, 0x43, 0x24, 0x4C, 0x28, 0x52, 0x2A, 0x47, 0x24, 0x49, 0x27, 0x4D, 0x29, 0x4F, 0x2A
    },

    {
        0x62, 0x56, 0x60, 0x53, 0x61, 0x54, 0x62, 0x54, 0x60, 0x54, 0x62, 0x55, 0x63, 0x56, 0x65, 0x59, 0x63, 0x5B, 0x65, 0x5E, 0x66, 0x5B, 0x64, 0x58, 0x5F, 0x57, 0x59, 0x55, 0x56, 0x4F, 0x59, 0x51, 0x5F, 0x53, 0x63, 0x56, 0x64, 0x56, 0x69, 0x5A, 0x6C, 0x5C, 0x6F, 0x5F, 0x71, 0x61, 0x70, 0x61, 0x71, 0x61, 0x6F, 0x61, 0x70, 0x62, 0x70, 0x60, 0x71, 0x62, 0x70, 0x5E, 0x6E, 0x60, 0x72, 0x62, 0x72, 0x62, 0x73, 0x62, 0x76, 0x64, 0x76, 0x65, 0x78, 0x66, 0x78, 0x69, 0x7A, 0x6B, 0x7A, 0x6A, 0x78, 0x69, 0x79, 0x67, 0x7A, 0x6A, 0x7B, 0x67, 0x7A, 0x66, 0x77, 0x66, 0x7C, 0x6B, 0x79, 0x68, 0x7B, 0x69, 0x7C, 0x68, 0x7B, 0x69, 0x7A, 0x6B, 0x7B, 0x6C, 0x7A, 0x6A, 0x79, 0x68, 0x7B, 0x6A, 0x79, 0x69, 0x7B, 0x6C, 0x79, 0x6A, 0x7C, 0x6A, 0x79, 0x66, 0x7C, 0x6A, 0x7E, 0x6A, 0x7D, 0x6B, 0x7E, 0x6E, 0x80, 0x6D, 0x7F, 0x6E, 0x83, 0x72, 0x7E, 0x6B, 0x7D, 0x6F, 0x7D, 0x6F, 0x80, 0x70, 0x82, 0x6F, 0x7E, 0x6A, 0x7F, 0x6E, 0x7D, 0x6A, 0x78, 0x69, 0x7F, 0x6E, 0x80, 0x70, 0x80, 0x71, 0x83, 0x72, 0x7F, 0x6E, 0x7E, 0x6C, 0x80, 0x6F, 0x7F, 0x6F, 0x7E, 0x6F, 0x7C, 0x6C, 0x80, 0x71, 0x80, 0x70, 0x83, 0x71, 0x81, 0x73, 0x82, 0x73, 0x83, 0x71, 0x7E, 0x6E, 0x7F, 0x6F, 0x7D, 0x6C, 0x80, 0x75, 0x85, 0x73, 0x83, 0x73, 0x84, 0x74, 0x82, 0x71, 0x82, 0x73, 0x7E, 0x75, 0x84, 0x73, 0x82, 0x76, 0x81, 0x72, 0x80, 0x74, 0x84, 0x78, 0x8B, 0x82, 0x8B, 0x7F, 0x86, 0x7A, 0x86, 0x77, 0x88, 0x7B, 0x82, 0x78, 0x84, 0x7A, 0x88, 0x79, 0x89, 0x7E, 0x8A, 0x80, 0x86, 0x80, 0x99, 0x91, 0x8A, 0x82, 0x8B, 0x84, 0x90, 0x90, 0xA1, 0xAC, 0xA6, 0xA5, 0xA3, 0xA6, 0x9C, 0x9C, 0x99, 0x98, 0x9B, 0x94, 0x9F, 0xA7, 0xA6, 0xA7, 0xA3, 0xA6, 0xAB, 0xAB, 0x95, 0x91, 0x9D, 0x9C, 0x99, 0x92, 0x90, 0x89, 0x94, 0x95, 0x9D, 0x9A, 0x97, 0x93, 0x99, 0x94, 0x93, 0x89, 0x8F, 0x8B, 0x8D, 0x88, 0x62, 0x6B, 0x5D, 0x6E, 0x54, 0x62, 0x64, 0x7B, 0x70, 0x8A, 0xAD, 0xBA, 0xAF, 0xB5, 0xAB, 0xAB, 0xA3, 0x9B, 0x96, 0x8B, 0x90, 0x86, 0x97, 0x94, 0x9E, 0x9E, 0xB2, 0xB3, 0xA2, 0x9F, 0x9B, 0x9D, 0xA4, 0xA3, 0x96, 0x93, 0x9E, 0xA2, 0xA3, 0xA7, 0xB2, 0xB9, 0x97, 0x91, 0xA3, 0xA9, 0xAD, 0xAD, 0xA0, 0x9E, 0x95, 0x94, 0x97, 0x98, 0x98, 0x94, 0x94, 0x8C, 0x83, 0x79, 0x8A, 0x80, 0x8C, 0x82, 0x8F, 0x88, 0x90, 0x8D, 0x8F, 0x84, 0x8B, 0x87, 0x9F, 0x9C, 0x99, 0x8E, 0x87, 0x7E, 0x94, 0x97, 0x94, 0x8E, 0x8B, 0x7F, 0x82, 0x76, 0x84, 0x74, 0x7E, 0x6F, 0x85, 0x78, 0x82, 0x75, 0x80, 0x78, 0x85, 0x7B, 0x7B, 0x6D, 0x7E, 0x72, 0x7D, 0x6E, 0x7C, 0x6E, 0x7B, 0x6F, 0x7F, 0x6E, 0x7E, 0x71, 0x7B, 0x6F, 0x7C, 0x6D, 0x7E, 0x6F, 0x79, 0x69, 0x7B, 0x6C, 0x78, 0x69, 0x7B, 0x6C, 0x77, 0x67, 0x74, 0x69, 0x76, 0x63, 0x7A, 0x6C, 0x7B, 0x6D, 0x7C, 0x71, 0x7C, 0x6D, 0x7B, 0x6D, 0x78, 0x69, 0x76, 0x68, 0x78, 0x69, 0x73, 0x66, 0x74, 0x65, 0x7A, 0x6A, 0x75, 0x67, 0x77, 0x6A, 0x79, 0x6D, 0x7A, 0x6E, 0x76, 0x68, 0x79, 0x6B, 0x79, 0x6B, 0x77, 0x66, 0x76, 0x67, 0x78, 0x6A, 0x76, 0x6C, 0x79, 0x6A, 0x77, 0x68, 0x78, 0x67, 0x74, 0x64, 0x76, 0x6C, 0x77, 0x6D, 0x7B, 0x72, 0x73, 0x65, 0x72, 0x68, 0x78, 0x6F, 0x7A, 0x74, 0x7E, 0x79, 0x80, 0x76, 0x7B, 0x6F, 0x7D, 0x71, 0x7D, 0x76, 0x7D, 0x72, 0x79, 0x71, 0x7C, 0x70, 0x78, 0x70, 0x7D, 0x72, 0x7A, 0x6F, 0x7A, 0x6C, 0x77, 0x69, 0x7A, 0x6C, 0x78, 0x6A, 0x7B, 0x6C, 0x7A, 0x6C, 0x76, 0x6B, 0x74, 0x69, 0x75, 0x6A, 0x76, 0x6B, 0x78, 0x6D, 0x78, 0x71, 0x78, 0x6E, 0x7A, 0x6D, 0x75, 0x6B, 0x6C, 0x61, 0x4F, 0x54, 0x3F, 0x44, 0x44, 0x50, 0x49, 0x53, 0x3E, 0x47, 0x4B, 0x55, 0x4B, 0x56, 0x4B, 0x56, 0x42, 0x4A, 0x4B, 0x55, 0x48, 0x54, 0x4F, 0x5C, 0x4A, 0x52, 0x45, 0x52, 0x4D, 0x54, 0x46, 0x51, 0x42, 0x47, 0x41, 0x4D, 0x43, 0x48, 0x43, 0x4E, 0x3F, 0x49, 0x4A, 0x52, 0x3F, 0x47, 0x49, 0x55, 0x3E, 0x43, 0x42, 0x4F, 0x41, 0x47, 0x46, 0x52, 0x4A, 0x55, 0x49, 0x54, 0x47, 0x4E, 0x4D, 0x59, 0x4C, 0x55, 0x4A, 0x53, 0x47, 0x4F, 0x4B, 0x56, 0x42, 0x47, 0x3C, 0x42, 0x41, 0x4A, 0x42, 0x4A, 0x41, 0x4A, 0x45, 0x4D, 0x42, 0x49, 0x41, 0x4D, 0x47, 0x52, 0x4C, 0x58, 0x3F, 0x45, 0x44, 0x50, 0x45, 0x4E, 0x44, 0x4D
    },

    {
        0x52, 0x1F, 0x52, 0x1E, 0x52, 0x1E, 0x52, 0x1D, 0x51, 0x1D, 0x51, 0x1E, 0x52, 0x1F, 0x56, 0x22, 0x5A, 0x26, 0x5B, 0x25, 0x57, 0x23, 0x58, 0x2B, 0x5A, 0x30, 0x4C, 0x28, 0x41, 0x20, 0x38, 0x1B, 0x3F, 0x1B, 0x4F, 0x1E, 0x54, 0x1F, 0x57, 0x20, 0x58, 0x20, 0x5B, 0x21, 0x5C, 0x22, 0x5B, 0x21, 0x5A, 0x21, 0x5B, 0x21, 0x5B, 0x22, 0x5C, 0x22, 0x60, 0x22, 0x5F, 0x22, 0x5F, 0x22, 0x5F, 0x23, 0x60, 0x22, 0x5F, 0x22, 0x61, 0x23, 0x62, 0x23, 0x63, 0x24, 0x62, 0x25, 0x67, 0x27, 0x67, 0x26, 0x66, 0x25, 0x65, 0x26, 0x65, 0x26, 0x64, 0x26, 0x66, 0x26, 0x67, 0x27, 0x67, 0x25, 0x65, 0x25, 0x62, 0x24, 0x64, 0x26, 0x66, 0x25, 0x62, 0x27, 0x6C, 0x2B, 0x6E, 0x29, 0x66, 0x26, 0x66, 0x25, 0x64, 0x25, 0x68, 0x26, 0x65, 0x25, 0x63, 0x24, 0x62, 0x24, 0x63, 0x24, 0x66, 0x25, 0x68, 0x26, 0x66, 0x26, 0x67, 0x26, 0x69, 0x28, 0x68, 0x27, 0x68, 0x27, 0x66, 0x25, 0x6A, 0x28, 0x68, 0x26, 0x68, 0x26, 0x65, 0x25, 0x67, 0x26, 0x68, 0x26, 0x65, 0x26, 0x67, 0x26, 0x67, 0x26, 0x68, 0x27, 0x66, 0x26, 0x66, 0x26, 0x66, 0x26, 0x66, 0x27, 0x68, 0x27, 0x66, 0x27, 0x65, 0x25, 0x6A, 0x28, 0x6C, 0x28, 0x6C, 0x2A, 0x70, 0x2D, 0x6D, 0x29, 0x67, 0x27, 0x6C, 0x28, 0x6C, 0x27, 0x69, 0x28, 0x6C, 0x29, 0x6A, 0x29, 0x6E, 0x2A, 0x6E, 0x2C, 0x6D, 0x29, 0x6D, 0x29, 0x6E, 0x2C, 0x6E, 0x2A, 0x70, 0x2A, 0x77, 0x31, 0x6D, 0x2B, 0x6E, 0x2F, 0x88, 0x3B, 0x7C, 0x33, 0x72, 0x2F, 0x72, 0x2D, 0x70, 0x2C, 0x74, 0x2F, 0x79, 0x30, 0x6C, 0x2B, 0x73, 0x31, 0x72, 0x2E, 0x73, 0x33, 0x7B, 0x34, 0x7B, 0x37, 0x7E, 0x37, 0x86, 0x3F, 0xA5, 0x4E, 0x98, 0x47, 0xA0, 0x4C, 0x92, 0x48, 0xAB, 0x51, 0xAD, 0x55, 0x9C, 0x48, 0x89, 0x41, 0xA5, 0x56, 0xAE, 0x52, 0x93, 0x44, 0x8E, 0x42, 0x91, 0x44, 0x92, 0x47, 0x90, 0x41, 0x8B, 0x43, 0x9A, 0x48, 0x9B, 0x4A, 0x8C, 0x41, 0x8B, 0x3F, 0x8E, 0x44, 0x84, 0x3E, 0x76, 0x3D, 0x73, 0x43, 0x93, 0x51, 0x9B, 0x52, 0xA5, 0x51, 0x9F, 0x4C, 0x97, 0x48, 0x8D, 0x3F, 0x9F, 0x4A, 0x9C, 0x4D, 0xAD, 0x58, 0xB2, 0x58, 0xAF, 0x57, 0xA3, 0x4E, 0x88, 0x3B, 0x87, 0x39, 0x7E, 0x39, 0x7C, 0x36, 0x82, 0x39, 0x8B, 0x3F, 0x8D, 0x41, 0x95, 0x4D, 0xA1, 0x47, 0x7F, 0x38, 0x7B, 0x37, 0x88, 0x3E, 0x7D, 0x34, 0x7D, 0x37, 0x78, 0x34, 0x72, 0x2F, 0x7A, 0x36, 0x90, 0x40, 0x83, 0x3D, 0x8A, 0x40, 0x9D, 0x4E, 0x93, 0x42, 0x7E, 0x34, 0x82, 0x3B, 0x88, 0x3F, 0x7F, 0x35, 0x72, 0x2F, 0x7A, 0x35, 0x6D, 0x2D, 0x70, 0x31, 0x7F, 0x37, 0x6E, 0x2C, 0x6D, 0x2D, 0x73, 0x2E, 0x68, 0x28, 0x6A, 0x29, 0x6B, 0x29, 0x68, 0x29, 0x6D, 0x2A, 0x68, 0x27, 0x67, 0x29, 0x6A, 0x2A, 0x68, 0x27, 0x69, 0x28, 0x64, 0x25, 0x66, 0x27, 0x61, 0x24, 0x62, 0x26, 0x65, 0x28, 0x65, 0x26, 0x62, 0x24, 0x66, 0x28, 0x67, 0x28, 0x6E, 0x30, 0x78, 0x32, 0x6C, 0x29, 0x65, 0x27, 0x63, 0x26, 0x62, 0x25, 0x63, 0x26, 0x61, 0x25, 0x60, 0x24, 0x62, 0x25, 0x62, 0x25, 0x67, 0x28, 0x68, 0x28, 0x61, 0x26, 0x62, 0x25, 0x64, 0x26, 0x62, 0x24, 0x64, 0x26, 0x66, 0x27, 0x63, 0x26, 0x66, 0x27, 0x61, 0x26, 0x62, 0x24, 0x63, 0x25, 0x63, 0x26, 0x65, 0x28, 0x65, 0x28, 0x66, 0x27, 0x62, 0x27, 0x6B, 0x2C, 0x6D, 0x2E, 0x6D, 0x2E, 0x6A, 0x2C, 0x69, 0x2D, 0x6F, 0x31, 0x70, 0x30, 0x6A, 0x2C, 0x6B, 0x2D, 0x6B, 0x2E, 0x73, 0x32, 0x6E, 0x2E, 0x67, 0x2A, 0x68, 0x29, 0x69, 0x2A, 0x5F, 0x27, 0x62, 0x28, 0x66, 0x2A, 0x67, 0x2A, 0x66, 0x2A, 0x64, 0x28, 0x64, 0x27, 0x66, 0x2A, 0x6B, 0x30, 0x85, 0x43, 0x73, 0x30, 0x6A, 0x2B, 0x68, 0x2A, 0x5F, 0x27, 0x52, 0x2A, 0x4D, 0x28, 0x53, 0x2D, 0x5E, 0x2F, 0x46, 0x25, 0x54, 0x2C, 0x4A, 0x27, 0x4E, 0x2A, 0x44, 0x26, 0x4B, 0x27, 0x4B, 0x29, 0x4F, 0x2A, 0x45, 0x26, 0x4B, 0x28, 0x42, 0x23, 0x45, 0x26, 0x46, 0x25, 0x47, 0x26, 0x47, 0x25, 0x4D, 0x28, 0x51, 0x2C, 0x57, 0x2E, 0x4B, 0x27, 0x51, 0x2B, 0x4D, 0x2A, 0x57, 0x30, 0x4F, 0x29, 0x4E, 0x2A, 0x48, 0x26, 0x4B, 0x28, 0x47, 0x25, 0x49, 0x27, 0x48, 0x26, 0x4A, 0x28, 0x43, 0x24, 0x4E, 0x29, 0x4C, 0x28, 0x43, 0x23, 0x48, 0x27, 0x52, 0x2B, 0x50, 0x2A, 0x54, 0x2B, 0x46, 0x24, 0x4E, 0x2A, 0x49, 0x26, 0x46, 0x25, 0x3D, 0x21, 0x45, 0x25, 0x40, 0x22, 0x3F, 0x21
    },

    {
        0x61, 0x56, 0x62, 0x55, 0x62, 0x55, 0x61, 0x54, 0x5F, 0x53, 0x5F, 0x53, 0x62, 0x56, 0x63, 0x59, 0x64, 0x5C, 0x65, 0x5E, 0x61, 0x59, 0x5D, 0x5D, 0x56, 0x58, 0x49, 0x47, 0x40, 0x3C, 0x3C, 0x35, 0x43, 0x3F, 0x59, 0x51, 0x63, 0x56, 0x68, 0x5A, 0x6B, 0x5C, 0x6C, 0x5E, 0x6F, 0x5F, 0x6F, 0x5E, 0x6D, 0x5C, 0x6E, 0x5F, 0x70, 0x60, 0x70, 0x60, 0x73, 0x62, 0x72, 0x62, 0x73, 0x61, 0x73, 0x62, 0x76, 0x64, 0x75, 0x65, 0x75, 0x64, 0x76, 0x66, 0x76, 0x65, 0x76, 0x68, 0x79, 0x6C, 0x7B, 0x68, 0x79, 0x68, 0x79, 0x69, 0x79, 0x69, 0x7A, 0x6A, 0x79, 0x6A, 0x7B, 0x6B, 0x7D, 0x6A, 0x7C, 0x69, 0x78, 0x68, 0x77, 0x67, 0x77, 0x69, 0x76, 0x69, 0x80, 0x75, 0x80, 0x71, 0x7D, 0x6A, 0x7A, 0x69, 0x7B, 0x6A, 0x7C, 0x6B, 0x7A, 0x68, 0x79, 0x66, 0x78, 0x66, 0x7A, 0x69, 0x7D, 0x6B, 0x7D, 0x6C, 0x7B, 0x6B, 0x7C, 0x6B, 0x7E, 0x6E, 0x7E, 0x6E, 0x7D, 0x6E, 0x7B, 0x6A, 0x7E, 0x6F, 0x7F, 0x6C, 0x80, 0x6C, 0x7B, 0x69, 0x7F, 0x6D, 0x80, 0x6D, 0x7E, 0x6D, 0x7D, 0x6B, 0x7C, 0x6B, 0x7E, 0x6B, 0x7C, 0x6A, 0x7C, 0x6A, 0x7A, 0x6A, 0x7C, 0x6C, 0x7E, 0x6D, 0x7B, 0x6C, 0x7C, 0x6A, 0x7E, 0x6E, 0x81, 0x71, 0x81, 0x72, 0x83, 0x76, 0x80, 0x6F, 0x7C, 0x6A, 0x7F, 0x70, 0x81, 0x70, 0x7E, 0x6C, 0x82, 0x72, 0x7F, 0x70, 0x83, 0x74, 0x83, 0x78, 0x85, 0x71, 0x81, 0x72, 0x82, 0x74, 0x81, 0x74, 0x7F, 0x71, 0x88, 0x81, 0x80, 0x72, 0x82, 0x77, 0x90, 0x91, 0x8F, 0x80, 0x86, 0x77, 0x84, 0x79, 0x85, 0x75, 0x84, 0x79, 0x88, 0x7C, 0x81, 0x71, 0x83, 0x7B, 0x83, 0x75, 0x83, 0x78, 0x86, 0x7E, 0x8A, 0x84, 0x8E, 0x85, 0x92, 0x91, 0xA5, 0xA8, 0x9C, 0x9B, 0xA3, 0xA1, 0x98, 0x9E, 0xAB, 0xAF, 0xA4, 0xA6, 0x9C, 0x98, 0x94, 0x8E, 0xA5, 0xAF, 0xA8, 0xA9, 0x9A, 0x9C, 0x9B, 0x90, 0x9C, 0x9C, 0xA1, 0xA4, 0x95, 0x8D, 0x92, 0x95, 0xA1, 0x9E, 0xA3, 0xA8, 0x99, 0x94, 0x96, 0x92, 0x9B, 0x9D, 0x93, 0x91, 0x7C, 0x7C, 0x76, 0x83, 0x91, 0xA1, 0x99, 0xA2, 0x9F, 0xA0, 0x9D, 0x9B, 0x9D, 0x9D, 0x9C, 0x90, 0xAD, 0xB0, 0xAD, 0xB7, 0xB4, 0xB9, 0xB4, 0xBA, 0xAE, 0xB2, 0xA8, 0xAD, 0x94, 0x8E, 0x95, 0x8E, 0x8F, 0x8A, 0x8D, 0x80, 0x8F, 0x89, 0x97, 0x94, 0x9A, 0x96, 0x9A, 0x9F, 0xA1, 0x98, 0x8E, 0x88, 0x8B, 0x86, 0x93, 0x8C, 0x94, 0x88, 0x90, 0x88, 0x8A, 0x82, 0x84, 0x79, 0x90, 0x8B, 0x9D, 0x95, 0x8B, 0x88, 0x95, 0x97, 0xA1, 0xA6, 0x98, 0x92, 0x8F, 0x83, 0x96, 0x90, 0x90, 0x88, 0x8D, 0x81, 0x84, 0x79, 0x87, 0x81, 0x7F, 0x70, 0x83, 0x7C, 0x8D, 0x86, 0x80, 0x72, 0x81, 0x75, 0x80, 0x76, 0x7B, 0x6C, 0x7A, 0x70, 0x7D, 0x6F, 0x7E, 0x70, 0x7E, 0x71, 0x7F, 0x6C, 0x7A, 0x6D, 0x7B, 0x6F, 0x7B, 0x6D, 0x7D, 0x6E, 0x77, 0x69, 0x77, 0x6A, 0x74, 0x64, 0x77, 0x68, 0x77, 0x6A, 0x77, 0x6A, 0x76, 0x65, 0x7B, 0x6C, 0x79, 0x6B, 0x7E, 0x75, 0x85, 0x7C, 0x7F, 0x6F, 0x77, 0x69, 0x78, 0x6A, 0x79, 0x6A, 0x78, 0x69, 0x77, 0x68, 0x73, 0x65, 0x76, 0x67, 0x76, 0x67, 0x7B, 0x6E, 0x7C, 0x6D, 0x77, 0x68, 0x77, 0x67, 0x77, 0x67, 0x76, 0x67, 0x7A, 0x6C, 0x7A, 0x6C, 0x77, 0x69, 0x7A, 0x6C, 0x73, 0x67, 0x76, 0x66, 0x76, 0x68, 0x77, 0x69, 0x74, 0x69, 0x75, 0x6C, 0x79, 0x6A, 0x73, 0x67, 0x7B, 0x70, 0x7D, 0x72, 0x7B, 0x72, 0x79, 0x6E, 0x78, 0x70, 0x7C, 0x76, 0x7E, 0x75, 0x7A, 0x71, 0x7A, 0x72, 0x7A, 0x70, 0x7E, 0x77, 0x7C, 0x70, 0x79, 0x6E, 0x7D, 0x6D, 0x7C, 0x70, 0x6F, 0x63, 0x74, 0x69, 0x78, 0x6C, 0x7A, 0x6F, 0x76, 0x6B, 0x75, 0x6A, 0x76, 0x6A, 0x79, 0x6D, 0x7B, 0x75, 0x84, 0x8A, 0x80, 0x76, 0x7B, 0x70, 0x77, 0x6D, 0x6F, 0x61, 0x51, 0x58, 0x49, 0x4D, 0x4F, 0x5E, 0x50, 0x5A, 0x40, 0x47, 0x4C, 0x54, 0x42, 0x4C, 0x45, 0x4B, 0x40, 0x4B, 0x42, 0x47, 0x46, 0x53, 0x47, 0x4E, 0x41, 0x4A, 0x45, 0x4F, 0x3F, 0x44, 0x41, 0x4B, 0x44, 0x4E, 0x46, 0x4E, 0x46, 0x4E, 0x4A, 0x54, 0x4E, 0x5A, 0x4E, 0x56, 0x45, 0x4F, 0x48, 0x54, 0x47, 0x50, 0x4E, 0x5A, 0x47, 0x4C, 0x46, 0x52, 0x3E, 0x45, 0x47, 0x51, 0x41, 0x47, 0x40, 0x4A, 0x43, 0x4B, 0x45, 0x50, 0x3F, 0x49, 0x4A, 0x53, 0x45, 0x4D, 0x40, 0x48, 0x44, 0x4D, 0x4B, 0x57, 0x49, 0x51, 0x4B, 0x55, 0x3E, 0x43, 0x46, 0x53, 0x3F, 0x46, 0x40, 0x46, 0x3A, 0x44, 0x3F, 0x48, 0x3C, 0x45, 0x3D, 0x44
    },

    {
        0x54, 0x1E, 0x52, 0x1D, 0x51, 0x1D, 0x52, 0x1D, 0x52, 0x1D, 0x50, 0x1D, 0x51, 0x1E, 0x54, 0x21, 0x55, 0x24, 0x59, 0x25, 0x56, 0x28, 0x52, 0x2C, 0x41, 0x22, 0x33, 0x1B, 0x2D, 0x18, 0x2B, 0x17, 0x2F, 0x19, 0x40, 0x1C, 0x52, 0x1F, 0x56, 0x1F, 0x58, 0x20, 0x58, 0x1F, 0x5A, 0x20, 0x59, 0x21, 0x5B, 0x20, 0x5A, 0x21, 0x5B, 0x21, 0x5C, 0x22, 0x5C, 0x21, 0x5D, 0x22, 0x5D, 0x22, 0x5D, 0x22, 0x5E, 0x22, 0x60, 0x22, 0x61, 0x23, 0x62, 0x22, 0x60, 0x23, 0x65, 0x26, 0x64, 0x26, 0x65, 0x26, 0x63, 0x26, 0x64, 0x25, 0x63, 0x25, 0x63, 0x26, 0x63, 0x24, 0x64, 0x25, 0x63, 0x24, 0x63, 0x24, 0x63, 0x24, 0x62, 0x24, 0x65, 0x27, 0x6D, 0x2D, 0x6E, 0x2C, 0x67, 0x27, 0x67, 0x26, 0x64, 0x26, 0x65, 0x25, 0x66, 0x25, 0x62, 0x25, 0x62, 0x23, 0x61, 0x24, 0x66, 0x25, 0x65, 0x25, 0x63, 0x24, 0x65, 0x25, 0x68, 0x27, 0x6A, 0x27, 0x67, 0x27, 0x65, 0x26, 0x69, 0x27, 0x68, 0x27, 0x67, 0x25, 0x6A, 0x27, 0x65, 0x25, 0x68, 0x27, 0x68, 0x26, 0x68, 0x26, 0x67, 0x26, 0x66, 0x25, 0x62, 0x24, 0x64, 0x25, 0x64, 0x25, 0x66, 0x27, 0x68, 0x27, 0x69, 0x27, 0x6B, 0x28, 0x6A, 0x28, 0x69, 0x28, 0x6D, 0x29, 0x71, 0x2B, 0x6D, 0x29, 0x6C, 0x29, 0x68, 0x28, 0x6A, 0x27, 0x69, 0x27, 0x69, 0x27, 0x6F, 0x2B, 0x6A, 0x28, 0x70, 0x2C, 0x6D, 0x2C, 0x73, 0x2C, 0x6F, 0x2A, 0x6E, 0x29, 0x6A, 0x2A, 0x6C, 0x29, 0x72, 0x2D, 0x75, 0x2E, 0x71, 0x2C, 0x77, 0x32, 0x8A, 0x3E, 0x79, 0x31, 0x75, 0x2F, 0x6C, 0x2A, 0x71, 0x2F, 0x6C, 0x2C, 0x6E, 0x2B, 0x7C, 0x37, 0x75, 0x30, 0x6F, 0x2F, 0x7D, 0x37, 0x86, 0x3B, 0x86, 0x40, 0x96, 0x44, 0x8F, 0x43, 0x8A, 0x3F, 0x96, 0x42, 0x8F, 0x49, 0xA7, 0x51, 0xA6, 0x56, 0x9E, 0x48, 0x94, 0x47, 0x9D, 0x4D, 0x96, 0x45, 0x9F, 0x50, 0x96, 0x48, 0xA2, 0x52, 0xB1, 0x54, 0x8F, 0x41, 0x94, 0x47, 0x95, 0x47, 0xA5, 0x53, 0x98, 0x45, 0x8D, 0x43, 0xAA, 0x53, 0x93, 0x46, 0x89, 0x3C, 0x84, 0x3F, 0x98, 0x4E, 0xA2, 0x49, 0x98, 0x48, 0x9A, 0x45, 0x95, 0x47, 0xB8, 0x5E, 0xB2, 0x59, 0x9F, 0x51, 0x92, 0x41, 0x9F, 0x4F, 0x9F, 0x4C, 0x98, 0x43, 0x83, 0x3B, 0x87, 0x3C, 0x91, 0x40, 0x84, 0x39, 0x84, 0x3B, 0x87, 0x3B, 0x80, 0x38, 0x8B, 0x3F, 0x89, 0x3C, 0x8D, 0x41, 0x8D, 0x3F, 0x8A, 0x3E, 0x8E, 0x43, 0x8A, 0x3A, 0x7A, 0x34, 0x84, 0x3C, 0x9B, 0x46, 0x7F, 0x34, 0x7D, 0x39, 0x8B, 0x41, 0x8B, 0x3D, 0x7D, 0x39, 0x89, 0x3C, 0x85, 0x3B, 0x7E, 0x35, 0x7A, 0x31, 0x73, 0x30, 0x75, 0x30, 0x6E, 0x2C, 0x76, 0x35, 0x8F, 0x41, 0x71, 0x2B, 0x66, 0x28, 0x6E, 0x2C, 0x67, 0x26, 0x68, 0x28, 0x6A, 0x28, 0x6E, 0x2A, 0x6C, 0x29, 0x6C, 0x28, 0x6A, 0x28, 0x66, 0x27, 0x66, 0x27, 0x65, 0x29, 0x69, 0x29, 0x66, 0x27, 0x60, 0x25, 0x63, 0x25, 0x62, 0x27, 0x66, 0x27, 0x62, 0x25, 0x66, 0x29, 0x6A, 0x29, 0x69, 0x28, 0x68, 0x29, 0x6D, 0x2A, 0x65, 0x27, 0x69, 0x29, 0x69, 0x28, 0x65, 0x28, 0x66, 0x26, 0x62, 0x25, 0x61, 0x25, 0x61, 0x24, 0x62, 0x27, 0x67, 0x28, 0x62, 0x24, 0x62, 0x25, 0x62, 0x24, 0x65, 0x26, 0x65, 0x26, 0x61, 0x25, 0x60, 0x24, 0x61, 0x24, 0x5E, 0x24, 0x64, 0x27, 0x61, 0x25, 0x65, 0x28, 0x69, 0x2B, 0x66, 0x28, 0x67, 0x27, 0x64, 0x28, 0x68, 0x2A, 0x6C, 0x2B, 0x66, 0x2A, 0x6C, 0x2D, 0x6B, 0x2D, 0x6A, 0x2B, 0x6D, 0x2D, 0x68, 0x2C, 0x69, 0x2B, 0x6A, 0x2C, 0x6A, 0x2C, 0x66, 0x2A, 0x65, 0x28, 0x64, 0x26, 0x68, 0x2A, 0x71, 0x31, 0x6E, 0x2E, 0x69, 0x2A, 0x68, 0x2C, 0x69, 0x2B, 0x67, 0x29, 0x64, 0x28, 0x65, 0x29, 0x68, 0x29, 0x6D, 0x2E, 0x68, 0x2A, 0x6A, 0x2B, 0x68, 0x29, 0x5F, 0x26, 0x55, 0x2B, 0x46, 0x25, 0x52, 0x2C, 0x48, 0x27, 0x47, 0x26, 0x54, 0x2D, 0x4A, 0x27, 0x4C, 0x28, 0x4B, 0x28, 0x4A, 0x27, 0x4E, 0x29, 0x56, 0x2D, 0x58, 0x2E, 0x4D, 0x28, 0x4D, 0x28, 0x50, 0x2A, 0x50, 0x2A, 0x49, 0x27, 0x4A, 0x27, 0x4B, 0x28, 0x4B, 0x28, 0x46, 0x27, 0x43, 0x23, 0x4B, 0x29, 0x41, 0x22, 0x47, 0x27, 0x48, 0x26, 0x4E, 0x2A, 0x47, 0x26, 0x55, 0x2D, 0x4A, 0x27, 0x52, 0x2B, 0x4E, 0x29, 0x4B, 0x29, 0x48, 0x27, 0x4E, 0x29, 0x3E, 0x22, 0x4C, 0x28, 0x49, 0x27, 0x4C, 0x27, 0x46, 0x26, 0x47, 0x26, 0x40, 0x23, 0x46, 0x24, 0x3E, 0x22, 0x4B, 0x27, 0x4C, 0x28, 0x4A, 0x26, 0x4C, 0x27, 0x52, 0x2A
    },

    {
        0x62, 0x56, 0x60, 0x55, 0x60, 0x54, 0x5F, 0x54, 0x62, 0x56, 0x61, 0x54, 0x62, 0x55, 0x62, 0x58, 0x5F, 0x59, 0x62, 0x5D, 0x5B, 0x57, 0x4F, 0x4C, 0x41, 0x3B, 0x34, 0x2F, 0x30, 0x2C, 0x30, 0x2B, 0x33, 0x2F, 0x47, 0x44, 0x5F, 0x55, 0x67, 0x58, 0x6A, 0x5B, 0x6B, 0x5C, 0x6E, 0x5E, 0x6D, 0x5D, 0x6E, 0x5D, 0x6E, 0x5F, 0x6F, 0x5E, 0x70, 0x60, 0x6D, 0x5F, 0x6F, 0x60, 0x70, 0x60, 0x73, 0x63, 0x73, 0x62, 0x75, 0x63, 0x76, 0x65, 0x74, 0x65, 0x74, 0x65, 0x76, 0x66, 0x76, 0x69, 0x77, 0x65, 0x76, 0x66, 0x75, 0x66, 0x78, 0x68, 0x78, 0x67, 0x78, 0x66, 0x77, 0x67, 0x79, 0x68, 0x77, 0x66, 0x79, 0x68, 0x77, 0x66, 0x77, 0x6A, 0x7D, 0x73, 0x82, 0x74, 0x7B, 0x6C, 0x7B, 0x6B, 0x79, 0x69, 0x78, 0x68, 0x79, 0x68, 0x78, 0x67, 0x75, 0x65, 0x7A, 0x6A, 0x7A, 0x69, 0x7B, 0x69, 0x79, 0x68, 0x7A, 0x67, 0x7C, 0x6E, 0x7E, 0x6C, 0x7B, 0x6C, 0x7A, 0x6A, 0x7E, 0x6D, 0x7F, 0x6D, 0x7E, 0x6C, 0x7F, 0x6C, 0x78, 0x68, 0x7E, 0x6E, 0x7F, 0x6D, 0x7E, 0x6C, 0x7E, 0x6B, 0x7D, 0x6C, 0x79, 0x68, 0x7A, 0x6A, 0x7A, 0x6B, 0x7D, 0x6E, 0x82, 0x6F, 0x7E, 0x6F, 0x80, 0x72, 0x7E, 0x70, 0x7F, 0x6F, 0x81, 0x73, 0x87, 0x76, 0x83, 0x71, 0x7F, 0x6E, 0x7D, 0x6E, 0x7F, 0x6F, 0x80, 0x6E, 0x80, 0x6F, 0x82, 0x73, 0x7F, 0x6E, 0x83, 0x76, 0x82, 0x74, 0x87, 0x76, 0x82, 0x73, 0x81, 0x72, 0x7E, 0x70, 0x7F, 0x70, 0x83, 0x77, 0x8A, 0x7C, 0x85, 0x76, 0x88, 0x7C, 0x90, 0x8F, 0x8F, 0x80, 0x89, 0x7F, 0x7D, 0x6F, 0x80, 0x75, 0x7C, 0x70, 0x7C, 0x70, 0x85, 0x83, 0x85, 0x7B, 0x82, 0x79, 0x8D, 0x86, 0x91, 0x8D, 0x90, 0x90, 0x99, 0x92, 0x94, 0x93, 0x96, 0x8D, 0x9F, 0x99, 0x99, 0x9D, 0xAE, 0xAA, 0xAB, 0xB4, 0xA6, 0xA0, 0xA1, 0xA1, 0xA4, 0xA4, 0xA2, 0x9C, 0xA3, 0xA9, 0x9B, 0x9B, 0xA5, 0xA9, 0xAE, 0xB6, 0xA4, 0x9F, 0xA2, 0xA3, 0xA5, 0xA0, 0xA9, 0xAE, 0x9C, 0x98, 0x9A, 0x99, 0xA7, 0xAD, 0x95, 0x94, 0x8C, 0x87, 0x8D, 0x8E, 0x99, 0xA0, 0xA7, 0xAA, 0xAC, 0xB3, 0xAB, 0xA7, 0xA4, 0xA3, 0xBA, 0xC7, 0xAD, 0xB3, 0xA3, 0xA5, 0x99, 0x92, 0x9E, 0xA4, 0xA0, 0xA3, 0x9E, 0x94, 0x8F, 0x89, 0x95, 0x8F, 0x9F, 0x9C, 0x94, 0x8B, 0x99, 0x97, 0x99, 0x91, 0x94, 0x8E, 0x95, 0x96, 0x96, 0x8F, 0x9F, 0x9A, 0x99, 0x95, 0x97, 0x8E, 0x9B, 0x99, 0x93, 0x86, 0x8B, 0x83, 0x9F, 0x9E, 0xA9, 0xA7, 0x90, 0x82, 0x98, 0x98, 0x9B, 0x97, 0x91, 0x86, 0x8D, 0x8C, 0x90, 0x8B, 0x8F, 0x8A, 0x8E, 0x86, 0x8A, 0x7C, 0x84, 0x79, 0x81, 0x78, 0x80, 0x76, 0x87, 0x7F, 0x96, 0x91, 0x80, 0x70, 0x7A, 0x6A, 0x80, 0x74, 0x7B, 0x6A, 0x7E, 0x6E, 0x7C, 0x6F, 0x80, 0x73, 0x7F, 0x71, 0x81, 0x6F, 0x7F, 0x6F, 0x7B, 0x6C, 0x78, 0x6C, 0x79, 0x6F, 0x7A, 0x6D, 0x79, 0x6A, 0x75, 0x67, 0x77, 0x68, 0x74, 0x68, 0x78, 0x6A, 0x76, 0x67, 0x7A, 0x70, 0x7C, 0x6F, 0x7C, 0x6E, 0x7B, 0x6F, 0x7E, 0x71, 0x77, 0x6A, 0x7C, 0x6E, 0x7E, 0x6E, 0x7A, 0x6B, 0x7C, 0x6D, 0x75, 0x66, 0x77, 0x69, 0x75, 0x66, 0x76, 0x68, 0x7B, 0x6C, 0x76, 0x65, 0x77, 0x69, 0x75, 0x67, 0x77, 0x69, 0x76, 0x69, 0x75, 0x66, 0x74, 0x65, 0x76, 0x66, 0x74, 0x65, 0x78, 0x6B, 0x74, 0x67, 0x74, 0x6A, 0x79, 0x6D, 0x77, 0x6C, 0x7A, 0x6B, 0x77, 0x6C, 0x79, 0x6F, 0x7D, 0x72, 0x77, 0x6C, 0x7C, 0x72, 0x7E, 0x72, 0x7B, 0x70, 0x7B, 0x70, 0x76, 0x6E, 0x7A, 0x70, 0x79, 0x70, 0x79, 0x70, 0x73, 0x6B, 0x74, 0x69, 0x77, 0x69, 0x76, 0x6D, 0x7E, 0x74, 0x7E, 0x73, 0x7A, 0x6F, 0x77, 0x6E, 0x7B, 0x71, 0x7A, 0x6C, 0x78, 0x6A, 0x77, 0x6B, 0x79, 0x6E, 0x7C, 0x6F, 0x79, 0x6E, 0x7C, 0x6F, 0x79, 0x6D, 0x6B, 0x5F, 0x51, 0x56, 0x41, 0x47, 0x4C, 0x57, 0x43, 0x4B, 0x44, 0x4F, 0x4F, 0x5A, 0x44, 0x4F, 0x48, 0x53, 0x46, 0x4F, 0x46, 0x50, 0x45, 0x51, 0x50, 0x5C, 0x4C, 0x57, 0x44, 0x4F, 0x46, 0x4C, 0x49, 0x56, 0x45, 0x4B, 0x42, 0x4C, 0x42, 0x48, 0x42, 0x4B, 0x43, 0x4A, 0x3E, 0x47, 0x3D, 0x47, 0x46, 0x51, 0x3B, 0x42, 0x41, 0x4D, 0x46, 0x4F, 0x4A, 0x54, 0x45, 0x4C, 0x4E, 0x5C, 0x42, 0x4A, 0x4C, 0x58, 0x45, 0x4B, 0x43, 0x4D, 0x40, 0x49, 0x44, 0x4D, 0x3A, 0x42, 0x48, 0x51, 0x43, 0x4F, 0x44, 0x4A, 0x42, 0x4C, 0x40, 0x47, 0x40, 0x4B, 0x42, 0x47, 0x3C, 0x45, 0x48, 0x53, 0x45, 0x4E, 0x46, 0x4F, 0x45, 0x52, 0x4B, 0x54
    },

    {
        0x54, 0x1E, 0x52, 0x1E, 0x52, 0x1E, 0x52, 0x1D, 0x51, 0x1E, 0x53, 0x1E, 0x52, 0x1F, 0x59, 0x26, 0x63, 0x2A, 0x58, 0x23, 0x4C, 0x23, 0x3E, 0x1F, 0x30, 0x19, 0x2A, 0x17, 0x28, 0x16, 0x27, 0x16, 0x27, 0x15, 0x34, 0x19, 0x4F, 0x1F, 0x54, 0x1F, 0x57, 0x20, 0x58, 0x20, 0x57, 0x20, 0x57, 0x20, 0x5B, 0x22, 0x5C, 0x22, 0x5D, 0x22, 0x5C, 0x23, 0x5B, 0x22, 0x5A, 0x21, 0x61, 0x23, 0x5E, 0x21, 0x5D, 0x22, 0x61, 0x23, 0x62, 0x23, 0x60, 0x23, 0x62, 0x24, 0x5E, 0x24, 0x64, 0x26, 0x64, 0x24, 0x64, 0x25, 0x65, 0x25, 0x60, 0x24, 0x64, 0x25, 0x62, 0x24, 0x61, 0x23, 0x64, 0x25, 0x63, 0x26, 0x65, 0x26, 0x65, 0x26, 0x65, 0x26, 0x67, 0x2A, 0x6C, 0x2A, 0x69, 0x29, 0x68, 0x27, 0x68, 0x27, 0x64, 0x25, 0x63, 0x25, 0x65, 0x25, 0x65, 0x26, 0x68, 0x26, 0x64, 0x24, 0x61, 0x24, 0x65, 0x25, 0x67, 0x27, 0x66, 0x26, 0x66, 0x26, 0x67, 0x26, 0x66, 0x25, 0x69, 0x27, 0x67, 0x26, 0x64, 0x25, 0x67, 0x26, 0x66, 0x27, 0x6C, 0x27, 0x69, 0x27, 0x6B, 0x28, 0x69, 0x27, 0x6B, 0x27, 0x6A, 0x28, 0x6A, 0x28, 0x6F, 0x2B, 0x72, 0x2B, 0x70, 0x2B, 0x6E, 0x2A, 0x71, 0x2C, 0x6F, 0x2A, 0x6A, 0x28, 0x6C, 0x2A, 0x6E, 0x2A, 0x6D, 0x29, 0x6C, 0x28, 0x69, 0x27, 0x6A, 0x28, 0x6C, 0x28, 0x6A, 0x28, 0x6E, 0x2A, 0x6A, 0x28, 0x6B, 0x29, 0x70, 0x2D, 0x74, 0x2D, 0x6C, 0x29, 0x6E, 0x2C, 0x6D, 0x2A, 0x68, 0x29, 0x6F, 0x2C, 0x78, 0x32, 0x76, 0x2E, 0x72, 0x2D, 0x77, 0x32, 0x7F, 0x35, 0x72, 0x2F, 0x6A, 0x2A, 0x6C, 0x2B, 0x6B, 0x29, 0x6C, 0x2A, 0x73, 0x33, 0x72, 0x2E, 0x75, 0x31, 0x8A, 0x3D, 0x87, 0x3F, 0x89, 0x3E, 0x84, 0x3E, 0x8E, 0x41, 0x84, 0x3C, 0x8E, 0x46, 0xA0, 0x4F, 0xA2, 0x4B, 0x96, 0x4B, 0x94, 0x43, 0x98, 0x4A, 0xA3, 0x52, 0xB1, 0x56, 0xA2, 0x4D, 0x96, 0x48, 0x9A, 0x4C, 0xB6, 0x60, 0xC5, 0x63, 0xAE, 0x56, 0x9D, 0x48, 0x92, 0x47, 0x90, 0x43, 0x9A, 0x4B, 0x91, 0x44, 0x84, 0x37, 0x7D, 0x38, 0x8C, 0x42, 0x8A, 0x40, 0x95, 0x49, 0xB1, 0x5C, 0x9F, 0x49, 0xAA, 0x53, 0xA2, 0x4B, 0x8A, 0x3F, 0x8D, 0x40, 0x94, 0x42, 0x8F, 0x42, 0x91, 0x41, 0x8B, 0x3D, 0x83, 0x36, 0x7C, 0x37, 0x90, 0x46, 0x90, 0x41, 0x88, 0x3E, 0x96, 0x44, 0x8C, 0x3D, 0x8C, 0x42, 0x8D, 0x40, 0x92, 0x42, 0x82, 0x3A, 0x82, 0x39, 0x8F, 0x45, 0x9B, 0x4B, 0x94, 0x46, 0xAD, 0x56, 0x8B, 0x3F, 0x88, 0x3F, 0x8D, 0x42, 0x88, 0x3C, 0x7A, 0x32, 0x80, 0x36, 0x75, 0x30, 0x81, 0x39, 0x7B, 0x33, 0x76, 0x31, 0x83, 0x3B, 0x75, 0x30, 0x7E, 0x3B, 0x77, 0x30, 0x6F, 0x2E, 0x6B, 0x2B, 0x68, 0x29, 0x6E, 0x2C, 0x66, 0x26, 0x68, 0x26, 0x66, 0x27, 0x67, 0x29, 0x68, 0x28, 0x69, 0x29, 0x64, 0x27, 0x67, 0x28, 0x65, 0x26, 0x67, 0x29, 0x68, 0x29, 0x69, 0x29, 0x63, 0x26, 0x61, 0x24, 0x63, 0x25, 0x64, 0x27, 0x64, 0x26, 0x67, 0x28, 0x69, 0x29, 0x67, 0x28, 0x6A, 0x28, 0x6A, 0x29, 0x66, 0x27, 0x66, 0x27, 0x65, 0x26, 0x65, 0x27, 0x66, 0x27, 0x63, 0x25, 0x64, 0x25, 0x65, 0x26, 0x64, 0x27, 0x66, 0x27, 0x5F, 0x24, 0x5F, 0x24, 0x61, 0x25, 0x62, 0x24, 0x60, 0x25, 0x61, 0x24, 0x5F, 0x23, 0x62, 0x25, 0x5F, 0x24, 0x65, 0x27, 0x62, 0x26, 0x64, 0x28, 0x65, 0x28, 0x66, 0x29, 0x67, 0x28, 0x65, 0x29, 0x6D, 0x2C, 0x6D, 0x2E, 0x6F, 0x2F, 0x6B, 0x2C, 0x6C, 0x2C, 0x6A, 0x2B, 0x68, 0x2A, 0x6A, 0x2B, 0x6F, 0x2E, 0x6D, 0x2F, 0x6B, 0x2D, 0x6D, 0x2F, 0x69, 0x2C, 0x69, 0x2B, 0x65, 0x29, 0x65, 0x28, 0x65, 0x28, 0x69, 0x2B, 0x6C, 0x2C, 0x6D, 0x2C, 0x6C, 0x2A, 0x64, 0x27, 0x66, 0x29, 0x69, 0x29, 0x68, 0x29, 0x64, 0x28, 0x68, 0x2A, 0x65, 0x29, 0x5B, 0x25, 0x4F, 0x29, 0x4A, 0x27, 0x57, 0x2E, 0x56, 0x2D, 0x4A, 0x28, 0x51, 0x2B, 0x45, 0x25, 0x50, 0x2A, 0x44, 0x25, 0x47, 0x25, 0x45, 0x26, 0x4E, 0x28, 0x41, 0x22, 0x45, 0x25, 0x43, 0x23, 0x4D, 0x28, 0x47, 0x25, 0x48, 0x27, 0x4A, 0x28, 0x51, 0x2A, 0x4C, 0x27, 0x43, 0x26, 0x51, 0x2B, 0x57, 0x2E, 0x48, 0x26, 0x50, 0x2B, 0x51, 0x2B, 0x4E, 0x29, 0x48, 0x27, 0x4E, 0x2B, 0x3D, 0x21, 0x4B, 0x28, 0x3D, 0x21, 0x49, 0x28, 0x48, 0x25, 0x4D, 0x28, 0x52, 0x2A, 0x4C, 0x27, 0x4C, 0x29, 0x4C, 0x28, 0x4A, 0x28, 0x4F, 0x29, 0x56, 0x2D, 0x4B, 0x27, 0x48, 0x26, 0x54, 0x2A, 0x43, 0x23, 0x47, 0x26, 0x47, 0x26, 0x47, 0x25
    },

    {
        0x61, 0x55, 0x60, 0x55, 0x60, 0x55, 0x62, 0x55, 0x62, 0x56, 0x62, 0x54, 0x62, 0x55, 0x66, 0x5F, 0x6B, 0x65, 0x61, 0x56, 0x52, 0x49, 0x40, 0x3A, 0x35, 0x2F, 0x2F, 0x2A, 0x2D, 0x29, 0x2C, 0x28, 0x2C, 0x28, 0x3A, 0x3B, 0x5D, 0x52, 0x63, 0x56, 0x69, 0x5B, 0x67, 0x5B, 0x6A, 0x5C, 0x6A, 0x5A, 0x6F, 0x5F, 0x6E, 0x5E, 0x70, 0x60, 0x6F, 0x60, 0x6F, 0x61, 0x6E, 0x5E, 0x72, 0x64, 0x72, 0x61, 0x73, 0x63, 0x77, 0x66, 0x76, 0x64, 0x75, 0x65, 0x75, 0x63, 0x74, 0x64, 0x77, 0x67, 0x77, 0x67, 0x78, 0x67, 0x77, 0x66, 0x75, 0x65, 0x79, 0x67, 0x78, 0x66, 0x79, 0x66, 0x7A, 0x69, 0x79, 0x69, 0x7A, 0x6A, 0x79, 0x6A, 0x7A, 0x6A, 0x78, 0x6A, 0x7E, 0x6F, 0x7D, 0x6F, 0x7B, 0x6E, 0x7A, 0x6B, 0x7A, 0x69, 0x79, 0x69, 0x7A, 0x69, 0x7C, 0x6C, 0x7B, 0x6A, 0x7A, 0x68, 0x77, 0x66, 0x7C, 0x6A, 0x7D, 0x6D, 0x7B, 0x6B, 0x7C, 0x6A, 0x7C, 0x6A, 0x7D, 0x6B, 0x7F, 0x6B, 0x7E, 0x6B, 0x7A, 0x68, 0x7E, 0x6E, 0x7D, 0x6C, 0x7F, 0x6D, 0x80, 0x6F, 0x81, 0x70, 0x7F, 0x6D, 0x81, 0x70, 0x7F, 0x6F, 0x84, 0x73, 0x87, 0x77, 0x8B, 0x78, 0x88, 0x74, 0x84, 0x75, 0x83, 0x74, 0x82, 0x73, 0x7E, 0x6D, 0x81, 0x72, 0x82, 0x74, 0x84, 0x72, 0x80, 0x6F, 0x7E, 0x6E, 0x80, 0x73, 0x82, 0x6F, 0x81, 0x70, 0x7F, 0x71, 0x80, 0x6F, 0x83, 0x72, 0x88, 0x78, 0x87, 0x77, 0x81, 0x71, 0x83, 0x75, 0x80, 0x71, 0x7C, 0x6F, 0x83, 0x76, 0x87, 0x7D, 0x89, 0x7A, 0x88, 0x77, 0x86, 0x7B, 0x88, 0x7F, 0x82, 0x74, 0x7D, 0x70, 0x80, 0x70, 0x7D, 0x70, 0x7E, 0x71, 0x84, 0x7C, 0x84, 0x78, 0x87, 0x7E, 0x8F, 0x8C, 0x91, 0x8D, 0x90, 0x8A, 0x8E, 0x8B, 0x94, 0x92, 0x8F, 0x88, 0x92, 0x95, 0xA6, 0xA5, 0xA1, 0xA2, 0x99, 0x96, 0x9A, 0x92, 0x9D, 0xA0, 0xAD, 0xB6, 0xAB, 0xB2, 0xA3, 0xA2, 0xA2, 0xA1, 0xA5, 0xA6, 0xB4, 0xBE, 0xBE, 0xC6, 0xB4, 0xB7, 0xA7, 0xA7, 0x9E, 0x9A, 0x9E, 0x97, 0x9D, 0x9E, 0x9A, 0x95, 0x91, 0x85, 0x8C, 0x88, 0x97, 0x9A, 0x93, 0x92, 0x98, 0x99, 0xA7, 0xAE, 0x9D, 0x9A, 0xB9, 0xC6, 0xAC, 0xA6, 0x9C, 0x99, 0x9C, 0x9A, 0x9F, 0x9C, 0x9D, 0x99, 0x9A, 0x98, 0x96, 0x96, 0x8F, 0x86, 0x8C, 0x84, 0x93, 0x91, 0x93, 0x8E, 0x95, 0x8D, 0x99, 0x96, 0x99, 0x92, 0x9B, 0x97, 0x94, 0x8F, 0xA0, 0x9B, 0x8F, 0x8B, 0x98, 0x93, 0x9B, 0xA0, 0xB1, 0xB5, 0xA4, 0xA6, 0xAE, 0xB4, 0x97, 0x8F, 0x97, 0x96, 0x98, 0x94, 0x97, 0x8E, 0x8D, 0x80, 0x8C, 0x81, 0x82, 0x79, 0x88, 0x81, 0x87, 0x7D, 0x88, 0x7C, 0x8F, 0x8E, 0x84, 0x7B, 0x8F, 0x8A, 0x84, 0x75, 0x81, 0x74, 0x7D, 0x71, 0x7A, 0x6D, 0x7D, 0x72, 0x79, 0x68, 0x7C, 0x6D, 0x7A, 0x6C, 0x7B, 0x6F, 0x7A, 0x6E, 0x7E, 0x6E, 0x79, 0x6B, 0x77, 0x6C, 0x7A, 0x6A, 0x7B, 0x6D, 0x7B, 0x6D, 0x7E, 0x6E, 0x77, 0x68, 0x77, 0x67, 0x79, 0x6A, 0x79, 0x6A, 0x76, 0x67, 0x78, 0x6C, 0x7C, 0x6D, 0x7A, 0x6E, 0x7F, 0x6E, 0x7D, 0x6F, 0x79, 0x6B, 0x7A, 0x6A, 0x78, 0x69, 0x77, 0x6A, 0x7A, 0x6B, 0x78, 0x69, 0x77, 0x6A, 0x7A, 0x6B, 0x78, 0x6B, 0x78, 0x6A, 0x74, 0x64, 0x74, 0x65, 0x76, 0x68, 0x74, 0x65, 0x74, 0x65, 0x75, 0x65, 0x75, 0x66, 0x77, 0x66, 0x73, 0x66, 0x77, 0x6A, 0x76, 0x68, 0x7A, 0x6B, 0x76, 0x6A, 0x78, 0x6D, 0x7A, 0x6C, 0x78, 0x6C, 0x7E, 0x75, 0x7D, 0x74, 0x7D, 0x75, 0x7D, 0x71, 0x7D, 0x71, 0x7D, 0x71, 0x7A, 0x6D, 0x7A, 0x70, 0x7E, 0x74, 0x7D, 0x74, 0x79, 0x71, 0x7B, 0x73, 0x7B, 0x71, 0x79, 0x6F, 0x77, 0x6B, 0x77, 0x6A, 0x78, 0x6B, 0x7A, 0x6F, 0x7D, 0x71, 0x7D, 0x73, 0x7F, 0x70, 0x79, 0x6A, 0x78, 0x6D, 0x7C, 0x6F, 0x7B, 0x6D, 0x77, 0x69, 0x7A, 0x6C, 0x77, 0x69, 0x6A, 0x5E, 0x52, 0x57, 0x46, 0x4C, 0x50, 0x5F, 0x4B, 0x54, 0x42, 0x4A, 0x48, 0x4F, 0x3F, 0x49, 0x47, 0x4E, 0x3E, 0x48, 0x40, 0x47, 0x43, 0x4E, 0x4A, 0x52, 0x3C, 0x41, 0x43, 0x4C, 0x43, 0x4A, 0x4A, 0x55, 0x44, 0x4B, 0x45, 0x4F, 0x46, 0x50, 0x4D, 0x58, 0x47, 0x4B, 0x42, 0x4D, 0x47, 0x52, 0x4C, 0x57, 0x42, 0x49, 0x4C, 0x58, 0x49, 0x50, 0x43, 0x4B, 0x41, 0x4A, 0x43, 0x4C, 0x3B, 0x42, 0x46, 0x4D, 0x3B, 0x43, 0x46, 0x50, 0x45, 0x4C, 0x4B, 0x55, 0x4D, 0x57, 0x45, 0x4D, 0x44, 0x4F, 0x46, 0x4F, 0x45, 0x51, 0x4B, 0x58, 0x4C, 0x55, 0x45, 0x4D, 0x42, 0x4D, 0x4A, 0x50, 0x3D, 0x45, 0x41, 0x49, 0x41, 0x4B, 0x40, 0x46
    },

    {
        0x52, 0x1E, 0x52, 0x1E, 0x54, 0x1E, 0x52, 0x1E, 0x54, 0x1E, 0x54, 0x1E, 0x55, 0x1F, 0x57, 0x20, 0x53, 0x1F, 0x4F, 0x1E, 0x42, 0x1D, 0x33, 0x1A, 0x2C, 0x17, 0x29, 0x18, 0x2A, 0x16, 0x28, 0x17, 0x23, 0x14, 0x35, 0x19, 0x4E, 0x1E, 0x54, 0x1E, 0x56, 0x1F, 0x56, 0x20, 0x57, 0x20, 0x56, 0x1F, 0x5A, 0x21, 0x5A, 0x21, 0x5E, 0x22, 0x5F, 0x23, 0x60, 0x22, 0x5B, 0x21, 0x5D, 0x21, 0x5A, 0x21, 0x5D, 0x23, 0x5E, 0x22, 0x61, 0x24, 0x61, 0x23, 0x60, 0x23, 0x60, 0x22, 0x60, 0x23, 0x62, 0x25, 0x63, 0x25, 0x61, 0x23, 0x61, 0x24, 0x62, 0x24, 0x61, 0x24, 0x63, 0x25, 0x63, 0x26, 0x68, 0x28, 0x68, 0x27, 0x63, 0x25, 0x66, 0x26, 0x65, 0x26, 0x66, 0x27, 0x67, 0x28, 0x65, 0x26, 0x64, 0x25, 0x63, 0x25, 0x63, 0x25, 0x66, 0x26, 0x67, 0x27, 0x65, 0x25, 0x65, 0x26, 0x65, 0x25, 0x67, 0x26, 0x68, 0x27, 0x65, 0x25, 0x65, 0x26, 0x67, 0x27, 0x65, 0x25, 0x66, 0x25, 0x65, 0x25, 0x66, 0x26, 0x6A, 0x28, 0x68, 0x26, 0x65, 0x26, 0x69, 0x27, 0x68, 0x27, 0x69, 0x27, 0x6C, 0x29, 0x6C, 0x28, 0x6F, 0x2A, 0x6E, 0x2B, 0x6F, 0x2A, 0x6B, 0x2A, 0x6C, 0x2A, 0x6C, 0x28, 0x6C, 0x28, 0x6A, 0x28, 0x6B, 0x29, 0x6D, 0x2A, 0x6D, 0x29, 0x68, 0x28, 0x66, 0x27, 0x6C, 0x29, 0x6C, 0x29, 0x6A, 0x29, 0x6B, 0x28, 0x6C, 0x28, 0x69, 0x28, 0x71, 0x2C, 0x72, 0x2D, 0x6F, 0x2A, 0x6E, 0x2B, 0x6B, 0x29, 0x69, 0x2A, 0x70, 0x2C, 0x70, 0x2F, 0x78, 0x30, 0x75, 0x2E, 0x79, 0x31, 0x77, 0x35, 0x75, 0x2E, 0x6C, 0x29, 0x6A, 0x2A, 0x6F, 0x2C, 0x6A, 0x29, 0x6C, 0x2C, 0x71, 0x2C, 0x76, 0x30, 0x77, 0x35, 0x88, 0x38, 0x79, 0x35, 0x7B, 0x35, 0x7E, 0x37, 0x79, 0x33, 0x7D, 0x3B, 0x99, 0x46, 0x91, 0x44, 0x8A, 0x3E, 0x85, 0x3A, 0x95, 0x46, 0xA7, 0x53, 0x96, 0x49, 0xA0, 0x4F, 0xAF, 0x54, 0xB5, 0x5B, 0xB7, 0x5F, 0xB1, 0x57, 0xAB, 0x52, 0x9D, 0x4C, 0x98, 0x48, 0x90, 0x42, 0x97, 0x47, 0x90, 0x41, 0x80, 0x3A, 0x8D, 0x40, 0x95, 0x47, 0x91, 0x42, 0x92, 0x47, 0x9F, 0x4A, 0x9B, 0x48, 0xA7, 0x56, 0x99, 0x47, 0x8F, 0x42, 0x8F, 0x47, 0x93, 0x41, 0x8A, 0x3E, 0x87, 0x3D, 0x82, 0x38, 0x8A, 0x3F, 0x8C, 0x42, 0x9B, 0x49, 0x89, 0x39, 0x84, 0x39, 0x84, 0x40, 0x94, 0x46, 0x9C, 0x49, 0x8C, 0x3E, 0x98, 0x4A, 0x94, 0x4A, 0xAA, 0x52, 0x9E, 0x4C, 0x9F, 0x4E, 0x9A, 0x45, 0x85, 0x3C, 0xA8, 0x53, 0x97, 0x45, 0x8E, 0x43, 0x93, 0x46, 0x83, 0x39, 0x80, 0x39, 0x79, 0x36, 0x7C, 0x36, 0x7B, 0x32, 0x77, 0x33, 0x81, 0x37, 0x74, 0x2F, 0x75, 0x31, 0x70, 0x2C, 0x6B, 0x2B, 0x6E, 0x2B, 0x68, 0x28, 0x66, 0x28, 0x65, 0x26, 0x68, 0x28, 0x69, 0x28, 0x6B, 0x29, 0x6A, 0x29, 0x6C, 0x29, 0x6C, 0x28, 0x65, 0x26, 0x67, 0x28, 0x6B, 0x29, 0x68, 0x27, 0x66, 0x27, 0x63, 0x26, 0x63, 0x27, 0x62, 0x26, 0x64, 0x25, 0x61, 0x25, 0x64, 0x26, 0x65, 0x27, 0x69, 0x29, 0x69, 0x29, 0x69, 0x2A, 0x66, 0x27, 0x62, 0x26, 0x62, 0x24, 0x5F, 0x25, 0x62, 0x26, 0x66, 0x27, 0x66, 0x26, 0x63, 0x25, 0x64, 0x27, 0x67, 0x28, 0x60, 0x24, 0x62, 0x25, 0x61, 0x25, 0x5D, 0x23, 0x64, 0x26, 0x64, 0x25, 0x63, 0x25, 0x62, 0x25, 0x61, 0x25, 0x60, 0x25, 0x60, 0x25, 0x65, 0x28, 0x64, 0x27, 0x63, 0x27, 0x63, 0x27, 0x67, 0x2A, 0x6C, 0x2C, 0x6E, 0x2D, 0x6B, 0x2D, 0x6D, 0x2C, 0x6C, 0x2D, 0x69, 0x2B, 0x69, 0x2B, 0x69, 0x2C, 0x6D, 0x2D, 0x6F, 0x2F, 0x70, 0x2F, 0x6B, 0x2D, 0x69, 0x2C, 0x66, 0x29, 0x65, 0x28, 0x65, 0x28, 0x66, 0x27, 0x65, 0x27, 0x65, 0x29, 0x68, 0x2A, 0x68, 0x29, 0x63, 0x27, 0x63, 0x26, 0x65, 0x27, 0x66, 0x28, 0x64, 0x27, 0x62, 0x26, 0x62, 0x26, 0x5A, 0x25, 0x4F, 0x28, 0x45, 0x24, 0x52, 0x2A, 0x47, 0x25, 0x43, 0x25, 0x4C, 0x29, 0x53, 0x2B, 0x57, 0x2C, 0x49, 0x28, 0x53, 0x2B, 0x5A, 0x30, 0x59, 0x2E, 0x42, 0x23, 0x50, 0x2A, 0x4E, 0x29, 0x51, 0x2A, 0x46, 0x26, 0x4F, 0x2B, 0x48, 0x27, 0x4E, 0x28, 0x3E, 0x23, 0x49, 0x27, 0x43, 0x23, 0x4C, 0x2A, 0x41, 0x23, 0x49, 0x28, 0x41, 0x23, 0x45, 0x25, 0x4A, 0x27, 0x4D, 0x29, 0x45, 0x25, 0x51, 0x29, 0x4D, 0x28, 0x53, 0x2D, 0x4C, 0x29, 0x59, 0x2D, 0x49, 0x26, 0x40, 0x23, 0x4D, 0x29, 0x50, 0x29, 0x49, 0x28, 0x53, 0x2B, 0x43, 0x24, 0x44, 0x25, 0x43, 0x24, 0x43, 0x24, 0x3F, 0x22, 0x48, 0x26, 0x47, 0x25, 0x4A, 0x27
    },

    {
        0x60, 0x55, 0x61, 0x55, 0x63, 0x57, 0x62, 0x55, 0x64, 0x57, 0x63, 0x57, 0x65, 0x57, 0x65, 0x57, 0x64, 0x56, 0x5D, 0x4F, 0x4B, 0x3F, 0x38, 0x32, 0x31, 0x2C, 0x2E, 0x2C, 0x2E, 0x2A, 0x2C, 0x29, 0x29, 0x25, 0x40, 0x3E, 0x5F, 0x54, 0x65, 0x57, 0x65, 0x57, 0x68, 0x59, 0x68, 0x5A, 0x69, 0x5A, 0x6C, 0x5D, 0x6D, 0x5E, 0x70, 0x61, 0x73, 0x63, 0x72, 0x62, 0x6E, 0x5F, 0x70, 0x5E, 0x6E, 0x5D, 0x71, 0x61, 0x73, 0x64, 0x75, 0x66, 0x76, 0x64, 0x74, 0x61, 0x74, 0x62, 0x74, 0x64, 0x74, 0x67, 0x77, 0x66, 0x76, 0x64, 0x77, 0x66, 0x78, 0x65, 0x75, 0x65, 0x78, 0x66, 0x79, 0x67, 0x7C, 0x6B, 0x7A, 0x6B, 0x78, 0x69, 0x79, 0x67, 0x79, 0x68, 0x79, 0x6A, 0x77, 0x6A, 0x78, 0x68, 0x75, 0x67, 0x79, 0x68, 0x7A, 0x6A, 0x7B, 0x6A, 0x7C, 0x6D, 0x7A, 0x6B, 0x7C, 0x6C, 0x79, 0x6A, 0x7D, 0x6B, 0x7E, 0x6A, 0x7A, 0x68, 0x7B, 0x6A, 0x7C, 0x6C, 0x7C, 0x6A, 0x7B, 0x6A, 0x7A, 0x68, 0x7C, 0x6C, 0x7E, 0x6F, 0x7D, 0x6C, 0x7E, 0x6B, 0x7F, 0x6E, 0x7F, 0x6C, 0x7F, 0x70, 0x82, 0x73, 0x7F, 0x6E, 0x84, 0x73, 0x81, 0x73, 0x84, 0x70, 0x81, 0x71, 0x82, 0x72, 0x82, 0x70, 0x80, 0x6F, 0x80, 0x6F, 0x81, 0x70, 0x85, 0x75, 0x82, 0x71, 0x7B, 0x6D, 0x7A, 0x6B, 0x80, 0x70, 0x80, 0x72, 0x7F, 0x6E, 0x81, 0x71, 0x81, 0x70, 0x7E, 0x6F, 0x84, 0x76, 0x84, 0x77, 0x84, 0x73, 0x85, 0x74, 0x82, 0x70, 0x7E, 0x70, 0x81, 0x74, 0x84, 0x76, 0x88, 0x7A, 0x88, 0x78, 0x8B, 0x80, 0x88, 0x80, 0x86, 0x78, 0x80, 0x72, 0x7E, 0x70, 0x81, 0x73, 0x7C, 0x6E, 0x81, 0x73, 0x82, 0x75, 0x87, 0x7A, 0x86, 0x7E, 0x95, 0x8F, 0x8A, 0x82, 0x8B, 0x80, 0x86, 0x80, 0x86, 0x7B, 0x89, 0x87, 0x9B, 0x95, 0x97, 0x99, 0x97, 0x93, 0x99, 0x90, 0xAA, 0xA8, 0xAE, 0xAA, 0x9E, 0x9F, 0xAF, 0xB5, 0xB8, 0xBA, 0xB1, 0xBF, 0xBC, 0xBF, 0xAF, 0xAC, 0xAB, 0xAB, 0xA8, 0xA8, 0xA1, 0x9B, 0x9D, 0x99, 0xA5, 0xA9, 0x9F, 0x98, 0x91, 0x89, 0x98, 0x97, 0x9C, 0x9C, 0x9A, 0x99, 0x95, 0x9D, 0xAA, 0xA9, 0xA9, 0xA9, 0xA0, 0x9D, 0x9A, 0x97, 0x95, 0x90, 0x9A, 0x97, 0x99, 0x94, 0x9B, 0x98, 0x95, 0x8F, 0x92, 0x87, 0x98, 0x96, 0x9B, 0x9B, 0xA4, 0xA7, 0x98, 0x92, 0x98, 0x8C, 0x91, 0x90, 0x9F, 0xA0, 0x9F, 0x9E, 0x97, 0x8F, 0x9E, 0x9F, 0x9B, 0xA1, 0xA2, 0xA3, 0xA0, 0x9D, 0xA1, 0xA0, 0xA1, 0xA0, 0x95, 0x94, 0xAC, 0xB4, 0xA3, 0x9C, 0x99, 0x94, 0x9C, 0x9D, 0x93, 0x8A, 0x8F, 0x8B, 0x8B, 0x86, 0x8B, 0x86, 0x8A, 0x80, 0x8B, 0x81, 0x8D, 0x84, 0x82, 0x78, 0x85, 0x79, 0x7E, 0x72, 0x7E, 0x74, 0x7E, 0x71, 0x7A, 0x6D, 0x79, 0x6B, 0x77, 0x68, 0x7B, 0x6C, 0x7A, 0x6F, 0x7F, 0x71, 0x7D, 0x6F, 0x7F, 0x72, 0x7D, 0x6E, 0x79, 0x6A, 0x7D, 0x6D, 0x7E, 0x6F, 0x7C, 0x6C, 0x79, 0x69, 0x75, 0x69, 0x77, 0x69, 0x77, 0x69, 0x76, 0x68, 0x75, 0x66, 0x79, 0x69, 0x79, 0x6A, 0x7B, 0x6E, 0x7F, 0x71, 0x7D, 0x6F, 0x79, 0x6A, 0x78, 0x68, 0x75, 0x65, 0x72, 0x65, 0x74, 0x68, 0x79, 0x6A, 0x77, 0x6A, 0x75, 0x66, 0x73, 0x69, 0x7A, 0x6C, 0x76, 0x66, 0x78, 0x68, 0x75, 0x66, 0x70, 0x63, 0x75, 0x69, 0x77, 0x68, 0x78, 0x68, 0x79, 0x68, 0x75, 0x66, 0x73, 0x66, 0x75, 0x66, 0x7A, 0x6C, 0x76, 0x69, 0x77, 0x69, 0x78, 0x6A, 0x78, 0x6C, 0x7D, 0x72, 0x7E, 0x73, 0x7C, 0x73, 0x7F, 0x73, 0x7E, 0x73, 0x7C, 0x6F, 0x79, 0x6F, 0x7D, 0x72, 0x7D, 0x73, 0x7E, 0x73, 0x7D, 0x75, 0x7B, 0x73, 0x7A, 0x6E, 0x77, 0x6A, 0x79, 0x6D, 0x7C, 0x6C, 0x79, 0x69, 0x75, 0x6A, 0x76, 0x6A, 0x7B, 0x6D, 0x79, 0x6C, 0x77, 0x69, 0x78, 0x68, 0x7B, 0x6D, 0x78, 0x6B, 0x77, 0x69, 0x77, 0x68, 0x76, 0x68, 0x66, 0x58, 0x4C, 0x4F, 0x41, 0x48, 0x4B, 0x53, 0x44, 0x4D, 0x3F, 0x47, 0x4A, 0x55, 0x4D, 0x5A, 0x50, 0x58, 0x42, 0x4D, 0x4D, 0x56, 0x52, 0x5F, 0x4E, 0x57, 0x3D, 0x41, 0x4A, 0x57, 0x44, 0x4C, 0x46, 0x50, 0x3F, 0x44, 0x46, 0x52, 0x3F, 0x46, 0x46, 0x4C, 0x3A, 0x41, 0x41, 0x4C, 0x3D, 0x44, 0x44, 0x4E, 0x3E, 0x46, 0x43, 0x49, 0x3D, 0x46, 0x43, 0x4B, 0x47, 0x53, 0x48, 0x51, 0x42, 0x4D, 0x4C, 0x54, 0x47, 0x4E, 0x4C, 0x59, 0x44, 0x4C, 0x4E, 0x58, 0x3F, 0x44, 0x3A, 0x43, 0x49, 0x55, 0x4B, 0x52, 0x43, 0x4F, 0x4B, 0x54, 0x3D, 0x43, 0x40, 0x49, 0x41, 0x48, 0x40, 0x48, 0x3B, 0x44, 0x44, 0x4E, 0x42, 0x4B, 0x46, 0x4F
    },

    {
        0x51, 0x1E, 0x52, 0x1D, 0x54, 0x1F, 0x53, 0x1E, 0x52, 0x1E, 0x52, 0x1E, 0x54, 0x1E, 0x55, 0x1F, 0x54, 0x1E, 0x52, 0x1E, 0x45, 0x1B, 0x2F, 0x16, 0x29, 0x15, 0x27, 0x15, 0x27, 0x16, 0x25, 0x14, 0x27, 0x14, 0x40, 0x1B, 0x51, 0x1E, 0x51, 0x1E, 0x54, 0x1F, 0x56, 0x1F, 0x54, 0x1F, 0x55, 0x1F, 0x59, 0x21, 0x5B, 0x20, 0x5A, 0x21, 0x5B, 0x22, 0x5C, 0x21, 0x5C, 0x22, 0x5D, 0x22, 0x5A, 0x21, 0x5F, 0x22, 0x5E, 0x23, 0x5F, 0x22, 0x5B, 0x22, 0x5C, 0x21, 0x5E, 0x22, 0x5E, 0x23, 0x65, 0x25, 0x65, 0x25, 0x62, 0x24, 0x60, 0x23, 0x61, 0x24, 0x60, 0x24, 0x63, 0x25, 0x64, 0x26, 0x66, 0x26, 0x64, 0x26, 0x64, 0x26, 0x64, 0x26, 0x65, 0x26, 0x66, 0x26, 0x67, 0x26, 0x66, 0x26, 0x63, 0x25, 0x62, 0x25, 0x65, 0x26, 0x65, 0x26, 0x68, 0x26, 0x66, 0x25, 0x67, 0x26, 0x64, 0x25, 0x67, 0x26, 0x64, 0x25, 0x67, 0x26, 0x65, 0x27, 0x64, 0x26, 0x65, 0x26, 0x67, 0x26, 0x66, 0x25, 0x64, 0x25, 0x61, 0x24, 0x68, 0x26, 0x69, 0x27, 0x67, 0x26, 0x66, 0x26, 0x69, 0x27, 0x6C, 0x28, 0x6C, 0x29, 0x6D, 0x2A, 0x6E, 0x2A, 0x6C, 0x2A, 0x6C, 0x28, 0x6C, 0x28, 0x70, 0x2A, 0x6B, 0x28, 0x6A, 0x28, 0x6D, 0x29, 0x6D, 0x28, 0x69, 0x27, 0x6A, 0x28, 0x6C, 0x28, 0x6B, 0x28, 0x69, 0x29, 0x67, 0x28, 0x69, 0x28, 0x66, 0x27, 0x68, 0x28, 0x70, 0x2B, 0x6F, 0x2B, 0x6D, 0x2A, 0x6E, 0x2B, 0x6D, 0x2A, 0x6C, 0x2B, 0x6F, 0x2D, 0x75, 0x2E, 0x6E, 0x2C, 0x71, 0x2D, 0x72, 0x2D, 0x75, 0x30, 0x7B, 0x31, 0x72, 0x2D, 0x6C, 0x2A, 0x6E, 0x2D, 0x6A, 0x29, 0x6D, 0x2A, 0x6C, 0x2B, 0x70, 0x2E, 0x73, 0x30, 0x80, 0x3C, 0x82, 0x38, 0x75, 0x33, 0x70, 0x30, 0x71, 0x2E, 0x6E, 0x32, 0x7B, 0x36, 0x86, 0x3A, 0x89, 0x41, 0x92, 0x42, 0xAE, 0x59, 0x96, 0x43, 0x9C, 0x4C, 0xB9, 0x5F, 0xA6, 0x4F, 0xA0, 0x50, 0xA9, 0x52, 0xB0, 0x58, 0xA6, 0x50, 0x9B, 0x47, 0x9F, 0x4E, 0xA9, 0x56, 0xAC, 0x55, 0xAE, 0x4F, 0x83, 0x37, 0x86, 0x3D, 0x88, 0x3D, 0x8A, 0x3E, 0x81, 0x3B, 0x92, 0x46, 0xA8, 0x50, 0x90, 0x3F, 0x8B, 0x40, 0x8A, 0x3E, 0x86, 0x3B, 0x8B, 0x3F, 0x90, 0x43, 0x86, 0x3D, 0x83, 0x39, 0x94, 0x46, 0x8D, 0x40, 0x7F, 0x36, 0x79, 0x36, 0x91, 0x42, 0x87, 0x3B, 0x94, 0x48, 0x86, 0x3A, 0x85, 0x3B, 0x8A, 0x41, 0x83, 0x39, 0x7A, 0x35, 0x85, 0x3A, 0x8B, 0x42, 0x9F, 0x47, 0x8F, 0x4A, 0xA2, 0x4B, 0x92, 0x45, 0x9F, 0x4A, 0x97, 0x45, 0x86, 0x3C, 0x80, 0x36, 0x77, 0x33, 0x7E, 0x38, 0x81, 0x39, 0x79, 0x39, 0x85, 0x3A, 0x74, 0x32, 0x6F, 0x2E, 0x72, 0x2C, 0x6E, 0x2B, 0x6C, 0x2A, 0x66, 0x28, 0x6A, 0x29, 0x63, 0x24, 0x66, 0x27, 0x69, 0x2A, 0x6D, 0x29, 0x66, 0x27, 0x66, 0x27, 0x65, 0x27, 0x66, 0x28, 0x65, 0x28, 0x67, 0x28, 0x64, 0x27, 0x64, 0x27, 0x65, 0x27, 0x63, 0x26, 0x63, 0x26, 0x63, 0x26, 0x62, 0x25, 0x64, 0x26, 0x67, 0x27, 0x69, 0x29, 0x69, 0x29, 0x6A, 0x2A, 0x66, 0x27, 0x66, 0x27, 0x64, 0x26, 0x61, 0x25, 0x61, 0x27, 0x63, 0x26, 0x64, 0x26, 0x62, 0x26, 0x65, 0x28, 0x6A, 0x2A, 0x63, 0x25, 0x62, 0x25, 0x61, 0x24, 0x61, 0x24, 0x61, 0x25, 0x61, 0x25, 0x61, 0x25, 0x61, 0x25, 0x61, 0x25, 0x61, 0x25, 0x63, 0x25, 0x64, 0x26, 0x63, 0x27, 0x64, 0x26, 0x64, 0x26, 0x63, 0x27, 0x69, 0x2B, 0x69, 0x2A, 0x6C, 0x2C, 0x6D, 0x2D, 0x6E, 0x2D, 0x67, 0x29, 0x68, 0x2B, 0x6E, 0x2F, 0x6F, 0x2E, 0x6E, 0x2D, 0x6F, 0x2F, 0x6E, 0x2D, 0x68, 0x2A, 0x65, 0x28, 0x67, 0x28, 0x67, 0x28, 0x61, 0x26, 0x62, 0x28, 0x63, 0x27, 0x64, 0x27, 0x62, 0x27, 0x65, 0x27, 0x66, 0x27, 0x66, 0x28, 0x68, 0x28, 0x63, 0x26, 0x62, 0x25, 0x60, 0x25, 0x59, 0x25, 0x51, 0x2A, 0x52, 0x2B, 0x59, 0x2E, 0x53, 0x2B, 0x4B, 0x29, 0x5B, 0x2F, 0x4E, 0x2A, 0x45, 0x24, 0x3F, 0x25, 0x48, 0x27, 0x49, 0x27, 0x43, 0x23, 0x3F, 0x23, 0x47, 0x25, 0x3F, 0x23, 0x44, 0x23, 0x43, 0x25, 0x46, 0x25, 0x43, 0x24, 0x49, 0x27, 0x45, 0x26, 0x46, 0x26, 0x47, 0x25, 0x50, 0x2A, 0x53, 0x2C, 0x53, 0x2D, 0x4D, 0x2A, 0x55, 0x2C, 0x50, 0x2A, 0x4C, 0x28, 0x46, 0x26, 0x4C, 0x28, 0x41, 0x23, 0x4B, 0x28, 0x45, 0x25, 0x4B, 0x27, 0x4C, 0x28, 0x47, 0x25, 0x53, 0x2B, 0x49, 0x26, 0x46, 0x27, 0x4B, 0x28, 0x40, 0x21, 0x4B, 0x29, 0x4C, 0x28, 0x51, 0x2B, 0x45, 0x25, 0x4B, 0x28, 0x4C, 0x29, 0x49, 0x27
    },

    {
        0x60, 0x55, 0x60, 0x54, 0x63, 0x57, 0x62, 0x55, 0x60, 0x54, 0x61, 0x54, 0x64, 0x55, 0x64, 0x57, 0x64, 0x56, 0x62, 0x55, 0x54, 0x46, 0x38, 0x2F, 0x2D, 0x29, 0x2B, 0x28, 0x2A, 0x28, 0x28, 0x25, 0x2F, 0x2D, 0x4E, 0x49, 0x61, 0x55, 0x61, 0x53, 0x65, 0x57, 0x67, 0x57, 0x66, 0x57, 0x68, 0x58, 0x6C, 0x5D, 0x6F, 0x5E, 0x6D, 0x5D, 0x6D, 0x5E, 0x6E, 0x5F, 0x70, 0x61, 0x70, 0x60, 0x6F, 0x60, 0x74, 0x62, 0x72, 0x63, 0x74, 0x62, 0x70, 0x5F, 0x6F, 0x5F, 0x73, 0x61, 0x72, 0x63, 0x77, 0x69, 0x78, 0x67, 0x78, 0x66, 0x75, 0x65, 0x75, 0x65, 0x76, 0x65, 0x77, 0x66, 0x7A, 0x6B, 0x7A, 0x68, 0x7A, 0x69, 0x78, 0x66, 0x76, 0x68, 0x7A, 0x6A, 0x7C, 0x6B, 0x7B, 0x6C, 0x7A, 0x69, 0x77, 0x66, 0x78, 0x67, 0x79, 0x69, 0x7B, 0x69, 0x79, 0x6A, 0x7A, 0x68, 0x7D, 0x6B, 0x7A, 0x68, 0x7C, 0x6A, 0x79, 0x69, 0x79, 0x6A, 0x78, 0x67, 0x79, 0x69, 0x79, 0x69, 0x7D, 0x6C, 0x7D, 0x6A, 0x78, 0x68, 0x76, 0x65, 0x7C, 0x6A, 0x7D, 0x6E, 0x7E, 0x6B, 0x7C, 0x6A, 0x80, 0x6F, 0x80, 0x6E, 0x83, 0x72, 0x85, 0x74, 0x83, 0x73, 0x82, 0x72, 0x82, 0x71, 0x82, 0x6F, 0x86, 0x74, 0x81, 0x72, 0x7F, 0x6E, 0x82, 0x73, 0x84, 0x71, 0x7F, 0x6E, 0x7D, 0x70, 0x82, 0x70, 0x7F, 0x6F, 0x7D, 0x6D, 0x7F, 0x6C, 0x7D, 0x6B, 0x7E, 0x6C, 0x7F, 0x6F, 0x84, 0x75, 0x83, 0x73, 0x81, 0x71, 0x83, 0x72, 0x81, 0x71, 0x7F, 0x71, 0x80, 0x74, 0x87, 0x7B, 0x83, 0x74, 0x85, 0x76, 0x86, 0x76, 0x84, 0x7B, 0x89, 0x7D, 0x88, 0x7A, 0x83, 0x72, 0x81, 0x72, 0x7D, 0x6E, 0x80, 0x71, 0x81, 0x72, 0x81, 0x77, 0x86, 0x79, 0x86, 0x82, 0x85, 0x82, 0x7C, 0x76, 0x7D, 0x72, 0x80, 0x73, 0x7C, 0x76, 0x89, 0x82, 0x8F, 0x87, 0x94, 0x92, 0x9C, 0x96, 0xAC, 0xB0, 0xA0, 0x9A, 0xA9, 0xAD, 0xB4, 0xB9, 0xA5, 0xA6, 0xAA, 0xA9, 0xAF, 0xB0, 0xB7, 0xBD, 0xAE, 0xB1, 0xA0, 0x98, 0xA2, 0xA4, 0xAA, 0xB1, 0xA9, 0xB1, 0xAD, 0xAC, 0x90, 0x84, 0x95, 0x8E, 0x93, 0x8D, 0x93, 0x90, 0x8D, 0x87, 0x95, 0x95, 0xA7, 0xAB, 0x9D, 0x99, 0x9D, 0x9B, 0x99, 0x94, 0x96, 0x8D, 0x98, 0x92, 0x96, 0x91, 0x94, 0x8E, 0x93, 0x8A, 0x9C, 0x9C, 0x96, 0x8F, 0x8E, 0x7F, 0x87, 0x7C, 0x97, 0x98, 0x9B, 0x97, 0x9D, 0x9C, 0x92, 0x89, 0x93, 0x8C, 0x95, 0x92, 0x92, 0x8A, 0x8E, 0x84, 0x96, 0x92, 0x93, 0x92, 0x9C, 0x97, 0x92, 0x95, 0xA5, 0xA2, 0x9B, 0x98, 0xA2, 0xA8, 0x9B, 0x91, 0x91, 0x8C, 0x8D, 0x7F, 0x84, 0x80, 0x8A, 0x88, 0x8E, 0x85, 0x85, 0x7F, 0x8D, 0x8A, 0x83, 0x7B, 0x80, 0x77, 0x84, 0x76, 0x7E, 0x72, 0x7E, 0x70, 0x7B, 0x6E, 0x7B, 0x6E, 0x79, 0x66, 0x78, 0x6C, 0x7E, 0x70, 0x81, 0x71, 0x7B, 0x6B, 0x78, 0x6B, 0x78, 0x69, 0x79, 0x6B, 0x7A, 0x6C, 0x7A, 0x6C, 0x7A, 0x6A, 0x76, 0x68, 0x76, 0x67, 0x75, 0x67, 0x73, 0x66, 0x77, 0x6A, 0x76, 0x68, 0x7A, 0x6A, 0x7C, 0x6C, 0x7E, 0x6F, 0x7E, 0x6F, 0x7E, 0x6F, 0x7A, 0x6B, 0x7B, 0x6B, 0x77, 0x69, 0x77, 0x67, 0x74, 0x67, 0x78, 0x68, 0x75, 0x67, 0x77, 0x69, 0x7A, 0x6B, 0x7B, 0x6E, 0x78, 0x67, 0x76, 0x65, 0x76, 0x68, 0x75, 0x66, 0x74, 0x65, 0x74, 0x64, 0x74, 0x66, 0x74, 0x65, 0x73, 0x66, 0x75, 0x67, 0x78, 0x6A, 0x78, 0x69, 0x78, 0x67, 0x7A, 0x6A, 0x78, 0x69, 0x77, 0x6A, 0x79, 0x6E, 0x7D, 0x6F, 0x7F, 0x73, 0x7E, 0x73, 0x82, 0x74, 0x79, 0x6D, 0x77, 0x6E, 0x7C, 0x76, 0x80, 0x74, 0x80, 0x74, 0x7F, 0x75, 0x7D, 0x71, 0x7A, 0x6C, 0x7A, 0x6B, 0x78, 0x6C, 0x7A, 0x6B, 0x75, 0x66, 0x77, 0x69, 0x76, 0x69, 0x76, 0x69, 0x75, 0x69, 0x7A, 0x6D, 0x7B, 0x69, 0x79, 0x6B, 0x79, 0x6C, 0x78, 0x67, 0x78, 0x68, 0x75, 0x65, 0x67, 0x5A, 0x52, 0x5A, 0x4B, 0x54, 0x51, 0x5D, 0x49, 0x50, 0x43, 0x53, 0x4D, 0x54, 0x45, 0x4D, 0x3D, 0x41, 0x3D, 0x48, 0x42, 0x48, 0x43, 0x4B, 0x3E, 0x44, 0x3F, 0x48, 0x41, 0x48, 0x3B, 0x44, 0x42, 0x47, 0x43, 0x4D, 0x42, 0x49, 0x40, 0x49, 0x45, 0x4E, 0x41, 0x4B, 0x42, 0x4D, 0x42, 0x4B, 0x4B, 0x57, 0x4C, 0x57, 0x4E, 0x58, 0x46, 0x51, 0x4C, 0x56, 0x47, 0x50, 0x44, 0x4A, 0x40, 0x49, 0x45, 0x4B, 0x3D, 0x44, 0x45, 0x4D, 0x43, 0x4C, 0x4A, 0x51, 0x4B, 0x53, 0x43, 0x4D, 0x4E, 0x59, 0x42, 0x48, 0x43, 0x4C, 0x45, 0x4D, 0x3D, 0x44, 0x48, 0x54, 0x43, 0x4E, 0x48, 0x51, 0x41, 0x4B, 0x42, 0x4A, 0x46, 0x51, 0x41, 0x48
    },

    {
        0x51, 0x1E, 0x53, 0x1E, 0x53, 0x1E, 0x52, 0x1E, 0x50, 0x1D, 0x52, 0x1E, 0x53, 0x1E, 0x54, 0x1E, 0x55, 0x1E, 0x53, 0x1E, 0x4D, 0x1C, 0x3C, 0x18, 0x2D, 0x15, 0x26, 0x14, 0x28, 0x16, 0x28, 0x14, 0x3E, 0x1A, 0x4E, 0x1E, 0x51, 0x1E, 0x50, 0x1E, 0x52, 0x1E, 0x55, 0x1E, 0x55, 0x1F, 0x56, 0x1F, 0x58, 0x20, 0x59, 0x20, 0x5B, 0x21, 0x5B, 0x21, 0x5B, 0x21, 0x5C, 0x21, 0x5D, 0x21, 0x5D, 0x22, 0x5D, 0x21, 0x5C, 0x22, 0x5C, 0x22, 0x5B, 0x21, 0x5B, 0x21, 0x5D, 0x21, 0x5C, 0x22, 0x5F, 0x24, 0x61, 0x24, 0x62, 0x24, 0x62, 0x24, 0x62, 0x24, 0x64, 0x24, 0x63, 0x25, 0x68, 0x26, 0x64, 0x25, 0x63, 0x25, 0x63, 0x26, 0x68, 0x27, 0x66, 0x25, 0x65, 0x26, 0x68, 0x27, 0x65, 0x25, 0x63, 0x25, 0x65, 0x25, 0x64, 0x24, 0x62, 0x25, 0x64, 0x26, 0x64, 0x26, 0x66, 0x26, 0x67, 0x26, 0x64, 0x25, 0x65, 0x25, 0x63, 0x25, 0x63, 0x26, 0x65, 0x25, 0x62, 0x24, 0x68, 0x26, 0x65, 0x25, 0x65, 0x26, 0x66, 0x26, 0x66, 0x26, 0x65, 0x26, 0x67, 0x26, 0x69, 0x27, 0x6B, 0x28, 0x69, 0x28, 0x6C, 0x28, 0x6C, 0x29, 0x6E, 0x29, 0x6C, 0x28, 0x6E, 0x29, 0x6C, 0x27, 0x69, 0x27, 0x6A, 0x26, 0x6A, 0x27, 0x6D, 0x28, 0x6C, 0x29, 0x6C, 0x28, 0x6A, 0x28, 0x6B, 0x29, 0x6C, 0x29, 0x68, 0x27, 0x69, 0x28, 0x6C, 0x28, 0x6A, 0x28, 0x6D, 0x2B, 0x6C, 0x29, 0x6C, 0x29, 0x6C, 0x2A, 0x6D, 0x2A, 0x6F, 0x2B, 0x6C, 0x2A, 0x6C, 0x2A, 0x71, 0x2B, 0x6D, 0x2A, 0x6E, 0x2B, 0x6C, 0x29, 0x70, 0x30, 0x70, 0x2C, 0x75, 0x33, 0x70, 0x2D, 0x6C, 0x2A, 0x6C, 0x2A, 0x68, 0x29, 0x6D, 0x2B, 0x70, 0x2D, 0x73, 0x37, 0x84, 0x46, 0x70, 0x41, 0x5F, 0x31, 0x53, 0x2A, 0x66, 0x2D, 0x73, 0x31, 0x73, 0x32, 0x85, 0x3A, 0x8C, 0x43, 0x9A, 0x43, 0x89, 0x3D, 0x89, 0x3E, 0xA2, 0x54, 0xAA, 0x51, 0x9C, 0x4E, 0xAA, 0x55, 0xAB, 0x4E, 0x95, 0x44, 0x8D, 0x40, 0x90, 0x40, 0x9A, 0x4A, 0x95, 0x45, 0x89, 0x3D, 0x82, 0x3A, 0x80, 0x35, 0x7F, 0x37, 0x7F, 0x37, 0x86, 0x3A, 0x84, 0x3B, 0x8B, 0x3F, 0x98, 0x4A, 0x96, 0x45, 0x96, 0x49, 0x88, 0x3D, 0x8F, 0x42, 0x8A, 0x3C, 0x7E, 0x36, 0x84, 0x3C, 0x9A, 0x45, 0x87, 0x3A, 0x7B, 0x36, 0x83, 0x39, 0x81, 0x37, 0x8B, 0x3F, 0x84, 0x3F, 0x84, 0x38, 0x7B, 0x34, 0x7C, 0x36, 0x85, 0x38, 0x86, 0x3B, 0x9A, 0x4B, 0xAE, 0x51, 0x8C, 0x41, 0x8A, 0x3D, 0x99, 0x4A, 0x94, 0x42, 0x98, 0x49, 0x8D, 0x40, 0x81, 0x38, 0x7A, 0x36, 0x76, 0x31, 0x78, 0x37, 0x7E, 0x35, 0x78, 0x31, 0x74, 0x2F, 0x7A, 0x34, 0x71, 0x30, 0x6C, 0x2B, 0x6E, 0x2D, 0x6D, 0x2A, 0x69, 0x29, 0x66, 0x29, 0x6B, 0x2A, 0x67, 0x28, 0x64, 0x27, 0x6A, 0x29, 0x6B, 0x28, 0x68, 0x27, 0x68, 0x28, 0x68, 0x28, 0x6B, 0x2A, 0x68, 0x28, 0x67, 0x28, 0x64, 0x26, 0x64, 0x27, 0x67, 0x27, 0x62, 0x25, 0x62, 0x25, 0x63, 0x26, 0x65, 0x26, 0x67, 0x27, 0x64, 0x26, 0x65, 0x26, 0x65, 0x27, 0x64, 0x26, 0x64, 0x25, 0x64, 0x27, 0x65, 0x28, 0x64, 0x26, 0x63, 0x25, 0x64, 0x27, 0x63, 0x26, 0x63, 0x27, 0x67, 0x28, 0x67, 0x28, 0x65, 0x26, 0x62, 0x24, 0x64, 0x25, 0x63, 0x25, 0x5F, 0x25, 0x62, 0x25, 0x65, 0x27, 0x62, 0x24, 0x60, 0x24, 0x60, 0x25, 0x63, 0x26, 0x61, 0x26, 0x63, 0x25, 0x64, 0x26, 0x66, 0x27, 0x66, 0x28, 0x69, 0x29, 0x67, 0x29, 0x6A, 0x2B, 0x6B, 0x2B, 0x6B, 0x2B, 0x69, 0x2B, 0x68, 0x2C, 0x70, 0x31, 0x6A, 0x2C, 0x6C, 0x2D, 0x6B, 0x2D, 0x66, 0x27, 0x61, 0x25, 0x63, 0x26, 0x63, 0x26, 0x64, 0x26, 0x64, 0x26, 0x63, 0x28, 0x66, 0x28, 0x66, 0x28, 0x63, 0x27, 0x66, 0x27, 0x65, 0x26, 0x62, 0x26, 0x63, 0x26, 0x63, 0x26, 0x61, 0x25, 0x63, 0x26, 0x5D, 0x27, 0x59, 0x2C, 0x45, 0x25, 0x54, 0x2C, 0x3F, 0x22, 0x4E, 0x29, 0x43, 0x23, 0x47, 0x26, 0x48, 0x26, 0x4E, 0x2A, 0x4E, 0x29, 0x55, 0x2D, 0x51, 0x29, 0x52, 0x2B, 0x4F, 0x28, 0x4B, 0x27, 0x55, 0x2C, 0x50, 0x29, 0x4E, 0x29, 0x4B, 0x28, 0x56, 0x2D, 0x4C, 0x28, 0x53, 0x2D, 0x46, 0x26, 0x52, 0x2B, 0x46, 0x26, 0x51, 0x2D, 0x46, 0x26, 0x4B, 0x27, 0x41, 0x23, 0x48, 0x25, 0x49, 0x27, 0x52, 0x2C, 0x48, 0x26, 0x53, 0x2D, 0x4F, 0x2A, 0x55, 0x2D, 0x4C, 0x28, 0x49, 0x28, 0x55, 0x2D, 0x4C, 0x28, 0x50, 0x2B, 0x4E, 0x28, 0x44, 0x24, 0x47, 0x26, 0x40, 0x23, 0x47, 0x25, 0x45, 0x25, 0x49, 0x27, 0x4E, 0x29, 0x4D, 0x28
    },

    {
        0x60, 0x54, 0x62, 0x57, 0x61, 0x56, 0x60, 0x54, 0x5F, 0x54, 0x60, 0x56, 0x63, 0x57, 0x64, 0x56, 0x65, 0x58, 0x63, 0x57, 0x5D, 0x50, 0x4D, 0x40, 0x3A, 0x31, 0x30, 0x2B, 0x30, 0x2C, 0x36, 0x33, 0x4D, 0x49, 0x5F, 0x53, 0x61, 0x55, 0x61, 0x54, 0x65, 0x55, 0x67, 0x58, 0x69, 0x59, 0x6A, 0x5A, 0x6B, 0x5C, 0x6B, 0x5D, 0x6D, 0x5D, 0x6C, 0x5E, 0x6E, 0x5E, 0x70, 0x60, 0x70, 0x60, 0x72, 0x61, 0x71, 0x60, 0x71, 0x60, 0x70, 0x5F, 0x6F, 0x5E, 0x6E, 0x5E, 0x72, 0x60, 0x71, 0x62, 0x73, 0x64, 0x75, 0x65, 0x75, 0x65, 0x73, 0x67, 0x76, 0x67, 0x79, 0x68, 0x79, 0x68, 0x7C, 0x69, 0x78, 0x67, 0x78, 0x67, 0x78, 0x68, 0x7A, 0x6B, 0x7D, 0x6A, 0x79, 0x6B, 0x7D, 0x6C, 0x7A, 0x69, 0x77, 0x67, 0x79, 0x6A, 0x78, 0x67, 0x78, 0x68, 0x7B, 0x69, 0x7A, 0x69, 0x7C, 0x6B, 0x7D, 0x6C, 0x79, 0x69, 0x7A, 0x6B, 0x77, 0x66, 0x79, 0x6B, 0x7A, 0x6A, 0x76, 0x68, 0x7D, 0x6C, 0x7D, 0x6A, 0x7A, 0x6B, 0x7B, 0x6D, 0x7D, 0x6D, 0x7C, 0x6B, 0x7E, 0x6D, 0x81, 0x71, 0x81, 0x72, 0x81, 0x70, 0x83, 0x72, 0x82, 0x70, 0x83, 0x74, 0x83, 0x72, 0x82, 0x73, 0x82, 0x70, 0x7E, 0x6E, 0x81, 0x70, 0x83, 0x71, 0x85, 0x72, 0x83, 0x72, 0x83, 0x71, 0x7E, 0x70, 0x7E, 0x6F, 0x81, 0x73, 0x7F, 0x6F, 0x81, 0x6F, 0x83, 0x72, 0x80, 0x72, 0x82, 0x73, 0x80, 0x70, 0x81, 0x71, 0x81, 0x73, 0x84, 0x73, 0x85, 0x75, 0x80, 0x72, 0x7F, 0x71, 0x84, 0x74, 0x83, 0x72, 0x81, 0x72, 0x7F, 0x6F, 0x80, 0x78, 0x83, 0x73, 0x85, 0x7D, 0x83, 0x76, 0x81, 0x71, 0x7D, 0x70, 0x7C, 0x6C, 0x81, 0x73, 0x82, 0x75, 0x7E, 0x7B, 0x7B, 0x81, 0x6A, 0x71, 0x5D, 0x5A, 0x54, 0x52, 0x6B, 0x68, 0x83, 0x7C, 0x84, 0x7C, 0x95, 0x8F, 0x99, 0x99, 0xA5, 0x99, 0x94, 0x8D, 0x98, 0x8F, 0xA5, 0xAB, 0xAF, 0xB2, 0xAA, 0xAC, 0xB0, 0xB3, 0xB0, 0xB0, 0x9B, 0x94, 0x98, 0x91, 0xA0, 0x98, 0xA7, 0xA9, 0xA5, 0xA2, 0x95, 0x8E, 0x91, 0x87, 0x8E, 0x85, 0x92, 0x8C, 0x92, 0x87, 0x94, 0x8B, 0x91, 0x8B, 0x96, 0x92, 0x9A, 0x9B, 0x9A, 0x93, 0x9C, 0x9D, 0x93, 0x8B, 0x96, 0x93, 0x91, 0x8C, 0x90, 0x84, 0x93, 0x8F, 0x99, 0x98, 0x92, 0x86, 0x8E, 0x8A, 0x98, 0x8F, 0x93, 0x8D, 0x96, 0x90, 0x8D, 0x8A, 0x8F, 0x88, 0x89, 0x80, 0x89, 0x82, 0x8E, 0x89, 0x92, 0x8D, 0x9E, 0xA5, 0xA9, 0xA9, 0x9C, 0xA0, 0x9B, 0x98, 0xA3, 0xA9, 0x9C, 0x95, 0xA2, 0xA2, 0x9B, 0x98, 0x8E, 0x87, 0x8A, 0x81, 0x84, 0x7B, 0x8A, 0x8A, 0x89, 0x80, 0x85, 0x79, 0x87, 0x78, 0x86, 0x7B, 0x83, 0x79, 0x7E, 0x71, 0x81, 0x73, 0x80, 0x72, 0x7D, 0x70, 0x7B, 0x6E, 0x7D, 0x70, 0x7D, 0x6D, 0x76, 0x6B, 0x7D, 0x6F, 0x7E, 0x6F, 0x7C, 0x6E, 0x7C, 0x6E, 0x7C, 0x6F, 0x7D, 0x70, 0x7D, 0x6F, 0x79, 0x6D, 0x76, 0x67, 0x77, 0x69, 0x7A, 0x6C, 0x77, 0x68, 0x76, 0x68, 0x75, 0x68, 0x78, 0x6A, 0x7B, 0x6C, 0x79, 0x6A, 0x79, 0x6A, 0x79, 0x6A, 0x77, 0x6A, 0x76, 0x66, 0x75, 0x68, 0x76, 0x6B, 0x77, 0x69, 0x75, 0x68, 0x78, 0x6C, 0x78, 0x69, 0x76, 0x6A, 0x7B, 0x6D, 0x7D, 0x6E, 0x7C, 0x6C, 0x7A, 0x6A, 0x78, 0x6A, 0x79, 0x6A, 0x75, 0x67, 0x78, 0x69, 0x7B, 0x6C, 0x78, 0x68, 0x73, 0x66, 0x75, 0x67, 0x76, 0x67, 0x76, 0x68, 0x79, 0x68, 0x79, 0x69, 0x7C, 0x6C, 0x7D, 0x6E, 0x7D, 0x70, 0x7B, 0x6B, 0x7B, 0x70, 0x7C, 0x70, 0x7D, 0x6F, 0x7B, 0x70, 0x78, 0x6F, 0x78, 0x71, 0x7B, 0x70, 0x7D, 0x71, 0x7A, 0x6F, 0x79, 0x69, 0x74, 0x66, 0x75, 0x69, 0x75, 0x68, 0x7A, 0x69, 0x77, 0x69, 0x76, 0x69, 0x78, 0x6C, 0x77, 0x6B, 0x75, 0x68, 0x7A, 0x6B, 0x7B, 0x6A, 0x77, 0x67, 0x78, 0x6A, 0x77, 0x68, 0x76, 0x68, 0x77, 0x68, 0x68, 0x63, 0x54, 0x5A, 0x40, 0x4B, 0x4B, 0x51, 0x3C, 0x43, 0x49, 0x54, 0x3E, 0x45, 0x45, 0x4F, 0x45, 0x50, 0x48, 0x51, 0x4B, 0x54, 0x50, 0x5D, 0x4B, 0x54, 0x4D, 0x56, 0x4A, 0x56, 0x46, 0x4F, 0x4F, 0x5C, 0x48, 0x50, 0x48, 0x54, 0x45, 0x4C, 0x4D, 0x59, 0x44, 0x4C, 0x4B, 0x55, 0x3F, 0x49, 0x48, 0x51, 0x40, 0x4A, 0x4A, 0x53, 0x42, 0x4C, 0x45, 0x4D, 0x3E, 0x46, 0x45, 0x4C, 0x48, 0x52, 0x4E, 0x59, 0x43, 0x4B, 0x4E, 0x5A, 0x46, 0x50, 0x4C, 0x56, 0x43, 0x4A, 0x40, 0x4A, 0x4D, 0x5A, 0x46, 0x4F, 0x4C, 0x57, 0x47, 0x4E, 0x3E, 0x46, 0x3F, 0x47, 0x3D, 0x48, 0x42, 0x49, 0x40, 0x4A, 0x44, 0x4C, 0x4A, 0x55, 0x49, 0x52
    },

    {
        0x55, 0x1F, 0x54, 0x1E, 0x53, 0x1E, 0x53, 0x1D, 0x52, 0x1E, 0x53, 0x1E, 0x53, 0x1E, 0x56, 0x1F, 0x56, 0x1F, 0x54, 0x1F, 0x54, 0x1F, 0x50, 0x1D, 0x4B, 0x1C, 0x47, 0x1C, 0x44, 0x1B, 0x4A, 0x1C, 0x51, 0x1E, 0x53, 0x1E, 0x53, 0x1F, 0x52, 0x1E, 0x53, 0x1F, 0x57, 0x20, 0x58, 0x20, 0x57, 0x20, 0x59, 0x20, 0x57, 0x20, 0x58, 0x20, 0x5A, 0x20, 0x58, 0x20, 0x5A, 0x21, 0x5B, 0x21, 0x5B, 0x21, 0x5B, 0x21, 0x5D, 0x21, 0x5A, 0x21, 0x59, 0x21, 0x5B, 0x22, 0x5F, 0x23, 0x5F, 0x24, 0x61, 0x25, 0x62, 0x25, 0x64, 0x25, 0x64, 0x25, 0x63, 0x24, 0x63, 0x25, 0x60, 0x23, 0x60, 0x24, 0x5F, 0x23, 0x60, 0x24, 0x63, 0x25, 0x61, 0x26, 0x62, 0x26, 0x67, 0x28, 0x67, 0x27, 0x67, 0x27, 0x66, 0x26, 0x65, 0x26, 0x66, 0x26, 0x67, 0x27, 0x66, 0x27, 0x63, 0x25, 0x65, 0x25, 0x66, 0x25, 0x63, 0x25, 0x64, 0x25, 0x63, 0x25, 0x65, 0x26, 0x67, 0x26, 0x65, 0x25, 0x65, 0x26, 0x66, 0x26, 0x67, 0x27, 0x69, 0x28, 0x6B, 0x29, 0x6F, 0x2A, 0x6B, 0x27, 0x68, 0x28, 0x6C, 0x29, 0x6F, 0x2A, 0x6C, 0x29, 0x70, 0x2A, 0x6D, 0x29, 0x6A, 0x28, 0x68, 0x27, 0x6A, 0x27, 0x6D, 0x29, 0x6D, 0x28, 0x6C, 0x28, 0x6B, 0x27, 0x6C, 0x27, 0x64, 0x26, 0x6B, 0x29, 0x6B, 0x28, 0x6C, 0x29, 0x6C, 0x28, 0x6E, 0x29, 0x6B, 0x29, 0x6B, 0x29, 0x6A, 0x28, 0x6B, 0x28, 0x6B, 0x28, 0x6D, 0x2A, 0x6B, 0x29, 0x6F, 0x2B, 0x6C, 0x2A, 0x6D, 0x2A, 0x6E, 0x2A, 0x6E, 0x2A, 0x6E, 0x2A, 0x68, 0x28, 0x69, 0x29, 0x70, 0x2E, 0x6D, 0x2B, 0x6D, 0x2B, 0x73, 0x2C, 0x6A, 0x29, 0x6A, 0x2A, 0x6C, 0x2B, 0x6B, 0x32, 0x78, 0x44, 0x61, 0x37, 0x51, 0x2E, 0x49, 0x29, 0x40, 0x24, 0x47, 0x29, 0x73, 0x33, 0x7B, 0x36, 0x80, 0x38, 0x95, 0x46, 0x95, 0x43, 0x96, 0x48, 0xA7, 0x50, 0x95, 0x47, 0xA9, 0x56, 0xAF, 0x58, 0xB9, 0x5D, 0x9D, 0x48, 0x8E, 0x43, 0x97, 0x45, 0x8E, 0x44, 0x9F, 0x4D, 0xA4, 0x4E, 0x8F, 0x42, 0x85, 0x39, 0x84, 0x3B, 0x8B, 0x40, 0x8D, 0x41, 0x87, 0x3B, 0x7F, 0x38, 0x80, 0x39, 0x8A, 0x3D, 0x8C, 0x3F, 0x88, 0x3C, 0x7B, 0x38, 0x7E, 0x35, 0x82, 0x3B, 0x7E, 0x37, 0x80, 0x37, 0x79, 0x33, 0x82, 0x37, 0x78, 0x36, 0x80, 0x36, 0x83, 0x39, 0x81, 0x37, 0x8B, 0x3F, 0x83, 0x38, 0x81, 0x37, 0x7E, 0x36, 0x89, 0x3E, 0x86, 0x3E, 0x94, 0x46, 0x85, 0x3C, 0x8F, 0x45, 0x90, 0x44, 0x87, 0x3C, 0x7B, 0x36, 0x86, 0x3A, 0x85, 0x3A, 0x7E, 0x37, 0x79, 0x33, 0x78, 0x32, 0x7A, 0x33, 0x73, 0x2F, 0x6D, 0x2C, 0x6F, 0x2C, 0x6F, 0x2B, 0x70, 0x2D, 0x6B, 0x2A, 0x6D, 0x2A, 0x71, 0x2C, 0x6D, 0x2B, 0x69, 0x28, 0x69, 0x28, 0x64, 0x27, 0x67, 0x29, 0x68, 0x27, 0x68, 0x27, 0x67, 0x29, 0x67, 0x27, 0x6B, 0x29, 0x6B, 0x2A, 0x6B, 0x29, 0x69, 0x29, 0x65, 0x28, 0x68, 0x28, 0x65, 0x26, 0x64, 0x26, 0x5F, 0x26, 0x62, 0x26, 0x65, 0x27, 0x67, 0x27, 0x65, 0x27, 0x66, 0x27, 0x64, 0x26, 0x63, 0x27, 0x63, 0x26, 0x63, 0x26, 0x60, 0x25, 0x63, 0x26, 0x61, 0x26, 0x63, 0x27, 0x67, 0x28, 0x66, 0x27, 0x64, 0x26, 0x65, 0x28, 0x64, 0x26, 0x68, 0x29, 0x68, 0x29, 0x6A, 0x29, 0x66, 0x27, 0x66, 0x28, 0x67, 0x28, 0x64, 0x27, 0x63, 0x27, 0x66, 0x28, 0x63, 0x27, 0x65, 0x27, 0x65, 0x28, 0x66, 0x27, 0x67, 0x27, 0x68, 0x28, 0x69, 0x29, 0x69, 0x29, 0x66, 0x28, 0x66, 0x28, 0x64, 0x27, 0x65, 0x29, 0x6C, 0x2E, 0x6C, 0x30, 0x6B, 0x2D, 0x68, 0x2A, 0x6B, 0x2A, 0x66, 0x26, 0x61, 0x25, 0x65, 0x26, 0x64, 0x26, 0x64, 0x26, 0x62, 0x27, 0x63, 0x28, 0x65, 0x27, 0x68, 0x29, 0x64, 0x26, 0x62, 0x26, 0x62, 0x26, 0x61, 0x25, 0x62, 0x25, 0x61, 0x24, 0x60, 0x25, 0x60, 0x25, 0x61, 0x29, 0x54, 0x2B, 0x49, 0x27, 0x4D, 0x28, 0x54, 0x2C, 0x54, 0x2B, 0x4B, 0x27, 0x55, 0x2E, 0x54, 0x2C, 0x49, 0x27, 0x4D, 0x28, 0x57, 0x2E, 0x4E, 0x29, 0x47, 0x28, 0x53, 0x2B, 0x44, 0x24, 0x52, 0x2B, 0x44, 0x24, 0x4C, 0x29, 0x42, 0x24, 0x47, 0x27, 0x40, 0x22, 0x48, 0x27, 0x46, 0x25, 0x4E, 0x29, 0x4B, 0x29, 0x58, 0x2F, 0x4F, 0x2B, 0x4D, 0x28, 0x49, 0x27, 0x4B, 0x27, 0x48, 0x28, 0x50, 0x2A, 0x40, 0x23, 0x4B, 0x28, 0x44, 0x24, 0x4B, 0x27, 0x4C, 0x29, 0x41, 0x22, 0x4D, 0x29, 0x47, 0x25, 0x4A, 0x27, 0x47, 0x25, 0x47, 0x26, 0x4B, 0x27, 0x4A, 0x28, 0x51, 0x29, 0x47, 0x26, 0x48, 0x27, 0x53, 0x2D, 0x46, 0x24
    },

    {
        0x64, 0x57, 0x62, 0x56, 0x60, 0x54, 0x62, 0x55, 0x63, 0x56, 0x64, 0x56, 0x64, 0x57, 0x64, 0x59, 0x63, 0x57, 0x63, 0x58, 0x63, 0x58, 0x60, 0x54, 0x5C, 0x50, 0x59, 0x4F, 0x59, 0x4F, 0x5D, 0x52, 0x62, 0x56, 0x64, 0x56, 0x63, 0x56, 0x63, 0x56, 0x63, 0x58, 0x67, 0x5A, 0x69, 0x5A, 0x69, 0x5A, 0x6B, 0x5B, 0x69, 0x5B, 0x6B, 0x5B, 0x6B, 0x5D, 0x6B, 0x5C, 0x6C, 0x5D, 0x6D, 0x5F, 0x6C, 0x5E, 0x6D, 0x5E, 0x70, 0x60, 0x6F, 0x5F, 0x6C, 0x5E, 0x70, 0x60, 0x73, 0x63, 0x76, 0x64, 0x71, 0x64, 0x73, 0x66, 0x73, 0x65, 0x77, 0x66, 0x79, 0x66, 0x79, 0x67, 0x75, 0x64, 0x75, 0x64, 0x72, 0x62, 0x74, 0x65, 0x78, 0x67, 0x75, 0x67, 0x75, 0x68, 0x79, 0x6C, 0x7B, 0x6A, 0x7C, 0x6C, 0x7B, 0x6A, 0x77, 0x68, 0x7B, 0x6C, 0x7C, 0x6D, 0x7B, 0x69, 0x77, 0x68, 0x7B, 0x69, 0x7C, 0x6A, 0x78, 0x69, 0x76, 0x67, 0x76, 0x67, 0x7B, 0x6B, 0x7C, 0x6D, 0x7B, 0x6B, 0x79, 0x6A, 0x77, 0x6A, 0x7B, 0x6D, 0x7F, 0x6E, 0x80, 0x71, 0x82, 0x75, 0x80, 0x6F, 0x7D, 0x6D, 0x82, 0x71, 0x83, 0x74, 0x81, 0x72, 0x85, 0x75, 0x7F, 0x70, 0x7E, 0x6D, 0x7B, 0x6D, 0x7F, 0x6F, 0x82, 0x72, 0x81, 0x70, 0x82, 0x71, 0x7F, 0x6E, 0x81, 0x6E, 0x79, 0x6A, 0x7D, 0x71, 0x7F, 0x6F, 0x7F, 0x70, 0x81, 0x72, 0x86, 0x73, 0x80, 0x70, 0x7E, 0x6F, 0x7E, 0x6F, 0x80, 0x71, 0x80, 0x6D, 0x82, 0x72, 0x81, 0x72, 0x82, 0x74, 0x7D, 0x72, 0x81, 0x72, 0x81, 0x74, 0x81, 0x74, 0x80, 0x72, 0x7C, 0x6F, 0x7D, 0x6D, 0x80, 0x7A, 0x7F, 0x72, 0x7C, 0x70, 0x83, 0x75, 0x80, 0x71, 0x80, 0x70, 0x7E, 0x73, 0x79, 0x74, 0x70, 0x73, 0x5A, 0x59, 0x4D, 0x4A, 0x48, 0x47, 0x42, 0x40, 0x46, 0x4E, 0x7E, 0x7C, 0x89, 0x86, 0x8E, 0x87, 0x9E, 0x9F, 0xA0, 0x9B, 0xA3, 0xAA, 0xB9, 0xBB, 0xA8, 0xA5, 0xAC, 0xB1, 0xB4, 0xC1, 0xB5, 0xBD, 0xAC, 0xAA, 0x9C, 0x9F, 0xA3, 0x9C, 0x98, 0x95, 0x9F, 0x9A, 0xA1, 0xA0, 0x9E, 0x9A, 0x93, 0x86, 0x96, 0x92, 0x95, 0x94, 0x98, 0x94, 0x91, 0x8C, 0x8A, 0x84, 0x8F, 0x90, 0x9B, 0x97, 0x98, 0x93, 0x92, 0x8A, 0x87, 0x83, 0x8D, 0x82, 0x90, 0x8F, 0x8D, 0x86, 0x91, 0x87, 0x87, 0x7D, 0x90, 0x86, 0x87, 0x81, 0x8F, 0x83, 0x92, 0x8B, 0x92, 0x8C, 0x9C, 0x9E, 0x92, 0x87, 0x91, 0x88, 0x8C, 0x85, 0x93, 0x97, 0x91, 0x95, 0x9A, 0x98, 0x91, 0x88, 0x93, 0x93, 0x91, 0x8E, 0x8B, 0x82, 0x89, 0x84, 0x8F, 0x84, 0x8E, 0x89, 0x8A, 0x80, 0x84, 0x7D, 0x89, 0x80, 0x89, 0x7D, 0x84, 0x79, 0x81, 0x74, 0x81, 0x73, 0x7F, 0x74, 0x84, 0x77, 0x7F, 0x71, 0x81, 0x73, 0x83, 0x76, 0x80, 0x72, 0x80, 0x6F, 0x7D, 0x6E, 0x7B, 0x6A, 0x79, 0x6E, 0x7C, 0x6C, 0x7C, 0x6E, 0x7B, 0x6E, 0x7F, 0x6E, 0x7E, 0x70, 0x80, 0x73, 0x80, 0x72, 0x7A, 0x6D, 0x79, 0x6B, 0x7B, 0x6C, 0x79, 0x6A, 0x7A, 0x6B, 0x72, 0x66, 0x77, 0x69, 0x78, 0x6C, 0x7C, 0x6C, 0x77, 0x6B, 0x79, 0x69, 0x77, 0x69, 0x77, 0x6B, 0x75, 0x68, 0x76, 0x69, 0x74, 0x69, 0x76, 0x6A, 0x73, 0x66, 0x76, 0x6C, 0x7A, 0x6C, 0x79, 0x6B, 0x77, 0x68, 0x77, 0x6A, 0x79, 0x6A, 0x7B, 0x6E, 0x7D, 0x6F, 0x7A, 0x6F, 0x78, 0x6B, 0x77, 0x69, 0x77, 0x6B, 0x75, 0x69, 0x74, 0x69, 0x78, 0x6D, 0x76, 0x6A, 0x7A, 0x6D, 0x7B, 0x6C, 0x7D, 0x6D, 0x7C, 0x6C, 0x7C, 0x6C, 0x7A, 0x6F, 0x7E, 0x6E, 0x7A, 0x6C, 0x7B, 0x6D, 0x78, 0x6B, 0x79, 0x6E, 0x7A, 0x72, 0x7B, 0x74, 0x7A, 0x70, 0x7B, 0x6E, 0x7D, 0x70, 0x79, 0x6A, 0x75, 0x68, 0x79, 0x6A, 0x79, 0x6B, 0x7A, 0x6A, 0x76, 0x68, 0x76, 0x6B, 0x79, 0x6D, 0x7B, 0x6E, 0x7A, 0x6B, 0x79, 0x68, 0x77, 0x68, 0x76, 0x68, 0x78, 0x69, 0x77, 0x66, 0x75, 0x65, 0x73, 0x66, 0x69, 0x64, 0x4F, 0x55, 0x45, 0x4F, 0x4B, 0x54, 0x50, 0x5D, 0x4A, 0x55, 0x45, 0x4F, 0x4E, 0x5D, 0x4A, 0x51, 0x44, 0x50, 0x47, 0x4D, 0x4C, 0x5A, 0x46, 0x4F, 0x42, 0x4B, 0x4A, 0x53, 0x3E, 0x48, 0x49, 0x51, 0x3F, 0x45, 0x45, 0x4E, 0x3F, 0x48, 0x42, 0x4B, 0x3D, 0x45, 0x44, 0x4D, 0x42, 0x4E, 0x4B, 0x55, 0x45, 0x51, 0x4F, 0x5B, 0x48, 0x52, 0x45, 0x4C, 0x44, 0x50, 0x43, 0x49, 0x42, 0x4E, 0x45, 0x4D, 0x3D, 0x46, 0x45, 0x4E, 0x41, 0x4B, 0x49, 0x52, 0x4B, 0x54, 0x3E, 0x44, 0x45, 0x4E, 0x43, 0x4A, 0x43, 0x4E, 0x44, 0x4D, 0x44, 0x4E, 0x46, 0x4D, 0x46, 0x54, 0x49, 0x50, 0x40, 0x4B, 0x42, 0x4B, 0x4B, 0x56, 0x40, 0x45
    },

    {
        0x53, 0x1F, 0x53, 0x1D, 0x54, 0x1D, 0x52, 0x1D, 0x53, 0x1E, 0x51, 0x1D, 0x51, 0x1D, 0x55, 0x1E, 0x55, 0x1F, 0x55, 0x1E, 0x55, 0x1E, 0x52, 0x1E, 0x55, 0x1F, 0x56, 0x1F, 0x54, 0x1F, 0x54, 0x1F, 0x52, 0x1E, 0x54, 0x1E, 0x53, 0x1F, 0x54, 0x1F, 0x56, 0x20, 0x57, 0x20, 0x56, 0x20, 0x57, 0x20, 0x55, 0x1F, 0x56, 0x1F, 0x58, 0x21, 0x58, 0x1F, 0x58, 0x20, 0x5A, 0x21, 0x5A, 0x21, 0x59, 0x21, 0x5C, 0x21, 0x5C, 0x21, 0x5C, 0x21, 0x5D, 0x22, 0x5C, 0x22, 0x5D, 0x23, 0x5D, 0x23, 0x5F, 0x24, 0x62, 0x25, 0x63, 0x25, 0x5F, 0x24, 0x61, 0x23, 0x5F, 0x23, 0x60, 0x24, 0x61, 0x23, 0x61, 0x24, 0x62, 0x25, 0x61, 0x24, 0x62, 0x24, 0x62, 0x24, 0x62, 0x25, 0x63, 0x25, 0x68, 0x27, 0x64, 0x25, 0x65, 0x25, 0x67, 0x27, 0x68, 0x27, 0x64, 0x26, 0x62, 0x25, 0x68, 0x27, 0x65, 0x25, 0x62, 0x24, 0x63, 0x25, 0x64, 0x25, 0x66, 0x26, 0x65, 0x25, 0x64, 0x25, 0x65, 0x25, 0x65, 0x26, 0x67, 0x25, 0x66, 0x26, 0x65, 0x26, 0x6B, 0x28, 0x6A, 0x27, 0x67, 0x27, 0x6B, 0x28, 0x6D, 0x28, 0x6A, 0x29, 0x6B, 0x29, 0x69, 0x27, 0x66, 0x27, 0x66, 0x26, 0x68, 0x26, 0x69, 0x27, 0x69, 0x27, 0x69, 0x26, 0x66, 0x25, 0x66, 0x27, 0x68, 0x27, 0x6C, 0x29, 0x6D, 0x2A, 0x6D, 0x2A, 0x6D, 0x29, 0x6B, 0x29, 0x6B, 0x28, 0x6A, 0x28, 0x6A, 0x27, 0x66, 0x27, 0x65, 0x26, 0x6E, 0x2A, 0x6D, 0x29, 0x6D, 0x29, 0x71, 0x2C, 0x73, 0x2B, 0x6D, 0x2B, 0x6C, 0x29, 0x68, 0x2B, 0x71, 0x2A, 0x6D, 0x2A, 0x6F, 0x2D, 0x6A, 0x2B, 0x6D, 0x2C, 0x6E, 0x2D, 0x72, 0x2E, 0x70, 0x2D, 0x6D, 0x2B, 0x5F, 0x2F, 0x57, 0x30, 0x42, 0x24, 0x3D, 0x23, 0x3C, 0x23, 0x36, 0x20, 0x36, 0x22, 0x7D, 0x3F, 0x88, 0x3C, 0x8A, 0x41, 0xA4, 0x4F, 0x91, 0x3D, 0xB1, 0x5C, 0xA8, 0x4F, 0x96, 0x48, 0xA1, 0x4E, 0xA0, 0x4E, 0x8A, 0x40, 0xA2, 0x52, 0xA4, 0x4E, 0x92, 0x41, 0x88, 0x3D, 0x8B, 0x3C, 0x87, 0x3E, 0xA3, 0x4B, 0x8E, 0x43, 0x91, 0x3F, 0x7C, 0x35, 0x85, 0x3A, 0x85, 0x3C, 0x7E, 0x38, 0x93, 0x48, 0x94, 0x41, 0x84, 0x3B, 0x82, 0x38, 0x7E, 0x3A, 0x88, 0x3A, 0x7F, 0x37, 0x7C, 0x38, 0x84, 0x39, 0x81, 0x37, 0x77, 0x31, 0x77, 0x34, 0x8B, 0x41, 0x96, 0x42, 0x7D, 0x36, 0x8B, 0x41, 0x80, 0x38, 0x85, 0x3A, 0x75, 0x30, 0x7F, 0x38, 0x7B, 0x34, 0x78, 0x33, 0x7C, 0x35, 0x76, 0x30, 0x75, 0x31, 0x74, 0x2E, 0x70, 0x2F, 0x7D, 0x34, 0x7B, 0x34, 0x78, 0x33, 0x6F, 0x2D, 0x76, 0x33, 0x76, 0x30, 0x70, 0x2D, 0x6B, 0x2B, 0x71, 0x2C, 0x71, 0x2E, 0x72, 0x2D, 0x6C, 0x2A, 0x67, 0x29, 0x69, 0x29, 0x69, 0x28, 0x67, 0x27, 0x67, 0x27, 0x69, 0x27, 0x6A, 0x29, 0x68, 0x29, 0x69, 0x28, 0x6C, 0x29, 0x6D, 0x2A, 0x69, 0x28, 0x6C, 0x29, 0x6D, 0x2A, 0x67, 0x28, 0x66, 0x27, 0x63, 0x26, 0x67, 0x27, 0x67, 0x26, 0x67, 0x27, 0x63, 0x25, 0x60, 0x25, 0x67, 0x27, 0x66, 0x27, 0x68, 0x28, 0x68, 0x29, 0x66, 0x29, 0x63, 0x26, 0x62, 0x26, 0x71, 0x32, 0x69, 0x28, 0x63, 0x25, 0x65, 0x28, 0x63, 0x27, 0x63, 0x27, 0x63, 0x26, 0x68, 0x28, 0x68, 0x29, 0x65, 0x26, 0x65, 0x26, 0x67, 0x26, 0x64, 0x26, 0x60, 0x25, 0x61, 0x25, 0x61, 0x24, 0x62, 0x26, 0x60, 0x25, 0x62, 0x26, 0x64, 0x27, 0x68, 0x29, 0x69, 0x2A, 0x6B, 0x2A, 0x67, 0x28, 0x67, 0x28, 0x66, 0x27, 0x65, 0x27, 0x64, 0x27, 0x68, 0x29, 0x6B, 0x2A, 0x68, 0x2A, 0x6A, 0x2A, 0x68, 0x29, 0x67, 0x29, 0x6A, 0x29, 0x62, 0x25, 0x62, 0x24, 0x64, 0x26, 0x64, 0x26, 0x66, 0x27, 0x66, 0x27, 0x66, 0x27, 0x66, 0x27, 0x66, 0x28, 0x65, 0x27, 0x66, 0x26, 0x65, 0x27, 0x63, 0x26, 0x61, 0x24, 0x5E, 0x23, 0x60, 0x24, 0x5F, 0x24, 0x58, 0x26, 0x57, 0x2D, 0x49, 0x26, 0x55, 0x2C, 0x52, 0x2A, 0x48, 0x26, 0x44, 0x24, 0x47, 0x27, 0x45, 0x25, 0x47, 0x27, 0x48, 0x26, 0x49, 0x26, 0x4A, 0x27, 0x43, 0x23, 0x4A, 0x27, 0x49, 0x27, 0x4A, 0x26, 0x4B, 0x27, 0x4F, 0x29, 0x50, 0x2A, 0x50, 0x2A, 0x4A, 0x27, 0x50, 0x2A, 0x48, 0x26, 0x54, 0x2C, 0x46, 0x26, 0x51, 0x2B, 0x49, 0x27, 0x45, 0x24, 0x4B, 0x28, 0x45, 0x24, 0x4A, 0x28, 0x4F, 0x29, 0x4F, 0x29, 0x55, 0x2C, 0x4F, 0x2A, 0x57, 0x2C, 0x49, 0x27, 0x42, 0x23, 0x4A, 0x27, 0x4C, 0x28, 0x54, 0x2E, 0x4E, 0x29, 0x46, 0x27, 0x48, 0x26, 0x51, 0x2B, 0x47, 0x24, 0x46, 0x26, 0x4F, 0x29, 0x4C, 0x29, 0x4E, 0x28
    },

    {
        0x62, 0x57, 0x62, 0x57, 0x63, 0x56, 0x61, 0x55, 0x62, 0x57, 0x62, 0x55, 0x61, 0x55, 0x64, 0x58, 0x65, 0x57, 0x66, 0x58, 0x65, 0x57, 0x63, 0x56, 0x66, 0x5A, 0x66, 0x59, 0x65, 0x58, 0x66, 0x58, 0x63, 0x55, 0x64, 0x57, 0x64, 0x56, 0x64, 0x58, 0x67, 0x5A, 0x6C, 0x5B, 0x67, 0x5A, 0x6A, 0x5A, 0x69, 0x5A, 0x69, 0x5A, 0x6A, 0x5D, 0x6A, 0x5A, 0x6D, 0x5D, 0x71, 0x60, 0x6E, 0x5D, 0x6B, 0x5D, 0x6F, 0x60, 0x6F, 0x5F, 0x70, 0x5F, 0x71, 0x63, 0x70, 0x5F, 0x70, 0x61, 0x6E, 0x60, 0x70, 0x62, 0x72, 0x65, 0x71, 0x63, 0x6E, 0x61, 0x74, 0x63, 0x72, 0x63, 0x75, 0x65, 0x76, 0x66, 0x76, 0x66, 0x77, 0x65, 0x74, 0x64, 0x76, 0x65, 0x76, 0x65, 0x74, 0x65, 0x78, 0x67, 0x7D, 0x6D, 0x79, 0x68, 0x79, 0x66, 0x7A, 0x6B, 0x7A, 0x6A, 0x79, 0x69, 0x79, 0x69, 0x7D, 0x6D, 0x79, 0x68, 0x76, 0x65, 0x76, 0x68, 0x78, 0x69, 0x79, 0x66, 0x7B, 0x6C, 0x79, 0x67, 0x78, 0x6A, 0x78, 0x6A, 0x7A, 0x69, 0x7C, 0x69, 0x7C, 0x6C, 0x7F, 0x6D, 0x7D, 0x6C, 0x7F, 0x6D, 0x82, 0x70, 0x81, 0x6F, 0x7D, 0x6F, 0x80, 0x6F, 0x80, 0x6F, 0x7E, 0x6D, 0x7B, 0x69, 0x7E, 0x6D, 0x7F, 0x6E, 0x7E, 0x6D, 0x7F, 0x6C, 0x7D, 0x6B, 0x7C, 0x6C, 0x7C, 0x6E, 0x80, 0x6F, 0x81, 0x74, 0x83, 0x73, 0x82, 0x73, 0x7F, 0x70, 0x80, 0x70, 0x7D, 0x6D, 0x7F, 0x6F, 0x7B, 0x6B, 0x7B, 0x6A, 0x83, 0x74, 0x82, 0x73, 0x84, 0x73, 0x87, 0x77, 0x85, 0x76, 0x7F, 0x73, 0x7F, 0x6F, 0x7E, 0x71, 0x85, 0x74, 0x80, 0x70, 0x7D, 0x6F, 0x79, 0x6E, 0x7F, 0x72, 0x82, 0x77, 0x88, 0x7D, 0x86, 0x76, 0x81, 0x73, 0x69, 0x5C, 0x56, 0x54, 0x46, 0x40, 0x40, 0x3E, 0x3F, 0x3C, 0x38, 0x38, 0x37, 0x3D, 0x7C, 0x8A, 0x93, 0x93, 0x97, 0x99, 0xA4, 0xAA, 0x9E, 0x92, 0xB3, 0xBE, 0xAB, 0xAD, 0xA5, 0x9A, 0xA4, 0xA5, 0xA0, 0x9D, 0x97, 0x8E, 0xA7, 0xAF, 0xAD, 0xB0, 0x9B, 0x93, 0x9C, 0x99, 0xA0, 0x95, 0x9C, 0x95, 0xA8, 0xA7, 0x9B, 0x9C, 0x9C, 0x93, 0x8B, 0x80, 0x93, 0x8C, 0x96, 0x90, 0x90, 0x8B, 0x9D, 0xA3, 0x96, 0x8D, 0x92, 0x8F, 0x95, 0x8D, 0x93, 0x91, 0x96, 0x8F, 0x8F, 0x87, 0x8B, 0x88, 0x8F, 0x87, 0x92, 0x89, 0x88, 0x7B, 0x8F, 0x8A, 0x9C, 0x9E, 0xA1, 0x9A, 0x8A, 0x7E, 0x8D, 0x87, 0x8C, 0x84, 0x8E, 0x86, 0x86, 0x7B, 0x8A, 0x83, 0x89, 0x7F, 0x88, 0x7C, 0x8C, 0x80, 0x84, 0x7A, 0x87, 0x7E, 0x87, 0x78, 0x86, 0x79, 0x8C, 0x82, 0x8B, 0x82, 0x8A, 0x7E, 0x82, 0x75, 0x86, 0x7D, 0x85, 0x7D, 0x85, 0x77, 0x81, 0x72, 0x83, 0x77, 0x82, 0x78, 0x82, 0x75, 0x7F, 0x72, 0x79, 0x6B, 0x7D, 0x6D, 0x7C, 0x6E, 0x7C, 0x6C, 0x7B, 0x6B, 0x7F, 0x6E, 0x7E, 0x70, 0x7A, 0x6E, 0x7C, 0x6D, 0x7C, 0x70, 0x81, 0x72, 0x7E, 0x6D, 0x80, 0x71, 0x81, 0x72, 0x7A, 0x6C, 0x7B, 0x6C, 0x78, 0x68, 0x7D, 0x6D, 0x7B, 0x6C, 0x7C, 0x6C, 0x79, 0x67, 0x74, 0x65, 0x79, 0x6A, 0x7B, 0x6B, 0x79, 0x6E, 0x7B, 0x6E, 0x78, 0x6C, 0x72, 0x64, 0x76, 0x68, 0x7F, 0x77, 0x7D, 0x6C, 0x76, 0x67, 0x78, 0x6A, 0x73, 0x69, 0x77, 0x69, 0x76, 0x6B, 0x7F, 0x71, 0x79, 0x6C, 0x77, 0x69, 0x79, 0x6A, 0x79, 0x6A, 0x7A, 0x6A, 0x72, 0x65, 0x75, 0x65, 0x74, 0x66, 0x76, 0x67, 0x75, 0x66, 0x76, 0x69, 0x76, 0x69, 0x79, 0x6D, 0x7B, 0x6F, 0x7D, 0x70, 0x79, 0x6D, 0x7B, 0x6C, 0x7B, 0x6B, 0x7C, 0x6B, 0x79, 0x6C, 0x7C, 0x6F, 0x7F, 0x71, 0x79, 0x6D, 0x7A, 0x6D, 0x7A, 0x6D, 0x7C, 0x6E, 0x7D, 0x6D, 0x78, 0x67, 0x78, 0x67, 0x77, 0x68, 0x77, 0x69, 0x7B, 0x6C, 0x7D, 0x6D, 0x7B, 0x6C, 0x7A, 0x6B, 0x7A, 0x6C, 0x7A, 0x6B, 0x7C, 0x6D, 0x79, 0x6A, 0x77, 0x6A, 0x76, 0x65, 0x74, 0x65, 0x75, 0x65, 0x74, 0x66, 0x62, 0x5D, 0x52, 0x5B, 0x43, 0x4C, 0x4D, 0x5A, 0x48, 0x4F, 0x41, 0x4C, 0x40, 0x46, 0x40, 0x49, 0x40, 0x48, 0x42, 0x4C, 0x44, 0x4C, 0x45, 0x4D, 0x46, 0x50, 0x3F, 0x47, 0x47, 0x4E, 0x48, 0x51, 0x48, 0x50, 0x46, 0x4D, 0x4B, 0x56, 0x49, 0x54, 0x4A, 0x54, 0x43, 0x4A, 0x49, 0x53, 0x41, 0x4B, 0x48, 0x51, 0x3F, 0x4A, 0x46, 0x4F, 0x42, 0x4C, 0x40, 0x48, 0x45, 0x4F, 0x42, 0x4A, 0x45, 0x51, 0x4C, 0x56, 0x48, 0x55, 0x4D, 0x56, 0x49, 0x53, 0x4C, 0x55, 0x41, 0x46, 0x3E, 0x48, 0x46, 0x51, 0x47, 0x4E, 0x4E, 0x5B, 0x46, 0x4B, 0x40, 0x4A, 0x43, 0x4B, 0x49, 0x53, 0x43, 0x49, 0x44, 0x4F, 0x49, 0x53, 0x46, 0x4F, 0x47, 0x4F
    },

    {
        0x55, 0x1F, 0x54, 0x1E, 0x53, 0x1E, 0x53, 0x1E, 0x52, 0x1E, 0x53, 0x1E, 0x54, 0x1E, 0x54, 0x1F, 0x55, 0x1E, 0x56, 0x1E, 0x55, 0x1F, 0x55, 0x1E, 0x56, 0x1F, 0x57, 0x1F, 0x55, 0x1F, 0x54, 0x1F, 0x55, 0x1F, 0x56, 0x20, 0x57, 0x20, 0x55, 0x20, 0x57, 0x21, 0x59, 0x22, 0x5A, 0x22, 0x5A, 0x20, 0x58, 0x20, 0x59, 0x20, 0x5A, 0x21, 0x5A, 0x20, 0x59, 0x20, 0x59, 0x21, 0x5B, 0x20, 0x59, 0x20, 0x5A, 0x21, 0x59, 0x21, 0x59, 0x22, 0x5B, 0x21, 0x5A, 0x21, 0x5C, 0x23, 0x5D, 0x28, 0x5E, 0x2C, 0x58, 0x28, 0x57, 0x25, 0x5B, 0x23, 0x5B, 0x22, 0x5D, 0x23, 0x5F, 0x24, 0x61, 0x24, 0x61, 0x23, 0x60, 0x24, 0x5E, 0x23, 0x5E, 0x23, 0x5E, 0x24, 0x60, 0x23, 0x65, 0x26, 0x66, 0x27, 0x65, 0x26, 0x66, 0x26, 0x67, 0x27, 0x64, 0x26, 0x63, 0x26, 0x67, 0x28, 0x66, 0x26, 0x64, 0x25, 0x62, 0x25, 0x65, 0x27, 0x68, 0x27, 0x67, 0x26, 0x64, 0x26, 0x64, 0x25, 0x64, 0x25, 0x65, 0x24, 0x65, 0x25, 0x68, 0x27, 0x69, 0x27, 0x67, 0x26, 0x67, 0x26, 0x6B, 0x28, 0x6A, 0x27, 0x6B, 0x28, 0x6B, 0x29, 0x6C, 0x28, 0x68, 0x28, 0x6E, 0x2C, 0x68, 0x26, 0x68, 0x26, 0x67, 0x26, 0x66, 0x26, 0x67, 0x26, 0x67, 0x25, 0x65, 0x26, 0x67, 0x28, 0x69, 0x28, 0x70, 0x2A, 0x6E, 0x2A, 0x6A, 0x29, 0x69, 0x28, 0x69, 0x28, 0x68, 0x28, 0x67, 0x27, 0x6B, 0x28, 0x6B, 0x29, 0x6D, 0x28, 0x6B, 0x29, 0x6C, 0x2B, 0x72, 0x2B, 0x6E, 0x2B, 0x70, 0x2C, 0x6A, 0x29, 0x6C, 0x29, 0x6B, 0x2A, 0x70, 0x2C, 0x6C, 0x29, 0x6D, 0x2B, 0x6D, 0x2D, 0x70, 0x2D, 0x86, 0x3D, 0x7E, 0x30, 0x6E, 0x2C, 0x58, 0x29, 0x41, 0x23, 0x3B, 0x21, 0x3D, 0x23, 0x38, 0x20, 0x38, 0x20, 0x32, 0x1F, 0x65, 0x30, 0x81, 0x3D, 0x89, 0x3D, 0x88, 0x3E, 0x8E, 0x3E, 0x82, 0x3B, 0x98, 0x4D, 0xA8, 0x49, 0x8D, 0x3F, 0x83, 0x39, 0x84, 0x3E, 0xB0, 0x5D, 0xA7, 0x4C, 0x8F, 0x44, 0x91, 0x41, 0x9F, 0x4C, 0x97, 0x43, 0x8A, 0x3C, 0x8A, 0x3E, 0x80, 0x37, 0x81, 0x3A, 0x8F, 0x41, 0x87, 0x3A, 0x83, 0x3A, 0x82, 0x39, 0x80, 0x37, 0x88, 0x3D, 0x88, 0x3F, 0x89, 0x3C, 0x87, 0x3D, 0x84, 0x39, 0x7C, 0x32, 0x76, 0x32, 0x81, 0x3A, 0x82, 0x38, 0x8F, 0x41, 0x8D, 0x42, 0x85, 0x3B, 0x81, 0x39, 0x78, 0x31, 0x74, 0x2F, 0x73, 0x2E, 0x83, 0x3E, 0x85, 0x39, 0x78, 0x31, 0x7B, 0x36, 0x80, 0x35, 0x6E, 0x2D, 0x77, 0x32, 0x7C, 0x32, 0x78, 0x32, 0x7B, 0x37, 0x7E, 0x36, 0x79, 0x32, 0x71, 0x2E, 0x72, 0x2F, 0x74, 0x2F, 0x70, 0x2E, 0x72, 0x2E, 0x6D, 0x2B, 0x72, 0x2D, 0x6D, 0x2B, 0x68, 0x28, 0x68, 0x28, 0x66, 0x27, 0x65, 0x28, 0x67, 0x28, 0x65, 0x26, 0x68, 0x27, 0x6C, 0x29, 0x6A, 0x28, 0x68, 0x29, 0x65, 0x27, 0x68, 0x29, 0x6B, 0x2A, 0x67, 0x27, 0x6C, 0x29, 0x68, 0x28, 0x68, 0x28, 0x63, 0x26, 0x65, 0x27, 0x62, 0x26, 0x65, 0x26, 0x65, 0x26, 0x61, 0x26, 0x68, 0x2A, 0x66, 0x28, 0x66, 0x29, 0x66, 0x28, 0x65, 0x27, 0x61, 0x26, 0x64, 0x27, 0x66, 0x28, 0x65, 0x26, 0x60, 0x25, 0x66, 0x28, 0x64, 0x28, 0x64, 0x27, 0x69, 0x2A, 0x69, 0x28, 0x61, 0x26, 0x62, 0x25, 0x61, 0x24, 0x66, 0x26, 0x64, 0x26, 0x63, 0x25, 0x60, 0x24, 0x60, 0x25, 0x61, 0x26, 0x62, 0x26, 0x61, 0x25, 0x67, 0x27, 0x65, 0x28, 0x69, 0x27, 0x64, 0x27, 0x61, 0x26, 0x68, 0x28, 0x68, 0x29, 0x69, 0x2A, 0x68, 0x2A, 0x69, 0x29, 0x6A, 0x29, 0x6E, 0x2B, 0x67, 0x2A, 0x65, 0x27, 0x68, 0x29, 0x67, 0x28, 0x65, 0x27, 0x60, 0x25, 0x62, 0x25, 0x60, 0x25, 0x65, 0x26, 0x65, 0x27, 0x68, 0x27, 0x66, 0x26, 0x65, 0x26, 0x66, 0x27, 0x67, 0x27, 0x65, 0x25, 0x64, 0x25, 0x62, 0x24, 0x5F, 0x24, 0x60, 0x24, 0x61, 0x24, 0x5A, 0x28, 0x52, 0x29, 0x47, 0x26, 0x52, 0x2C, 0x49, 0x25, 0x46, 0x27, 0x52, 0x2A, 0x52, 0x2B, 0x52, 0x2A, 0x4F, 0x2C, 0x50, 0x29, 0x54, 0x2C, 0x4F, 0x29, 0x40, 0x23, 0x52, 0x2A, 0x44, 0x25, 0x53, 0x2B, 0x44, 0x24, 0x4E, 0x29, 0x42, 0x23, 0x49, 0x27, 0x40, 0x22, 0x48, 0x26, 0x48, 0x26, 0x4C, 0x27, 0x47, 0x27, 0x4E, 0x29, 0x4D, 0x2A, 0x53, 0x2B, 0x4D, 0x2A, 0x4D, 0x28, 0x51, 0x2C, 0x50, 0x29, 0x44, 0x25, 0x47, 0x25, 0x4A, 0x27, 0x46, 0x25, 0x47, 0x25, 0x43, 0x24, 0x4B, 0x28, 0x44, 0x25, 0x4F, 0x2A, 0x4C, 0x27, 0x47, 0x26, 0x55, 0x2C, 0x50, 0x2A, 0x4C, 0x28, 0x50, 0x2A, 0x4B, 0x28, 0x50, 0x2C, 0x44, 0x24
    },

    {
        0x62, 0x57, 0x63, 0x57, 0x63, 0x56, 0x63, 0x55, 0x62, 0x55, 0x62, 0x55, 0x64, 0x57, 0x63, 0x56, 0x66, 0x58, 0x68, 0x59, 0x66, 0x59, 0x67, 0x58, 0x67, 0x58, 0x67, 0x5A, 0x66, 0x59, 0x66, 0x58, 0x67, 0x5A, 0x6A, 0x5A, 0x66, 0x59, 0x65, 0x58, 0x69, 0x5B, 0x69, 0x5E, 0x6B, 0x5D, 0x6C, 0x5C, 0x6B, 0x5C, 0x6D, 0x5D, 0x6C, 0x5F, 0x6D, 0x5D, 0x6C, 0x5D, 0x6D, 0x5D, 0x6E, 0x5F, 0x6E, 0x5E, 0x6C, 0x5B, 0x6B, 0x5D, 0x6E, 0x5E, 0x6D, 0x5F, 0x6C, 0x5D, 0x6C, 0x5D, 0x69, 0x64, 0x66, 0x62, 0x5E, 0x56, 0x59, 0x53, 0x61, 0x57, 0x6A, 0x5C, 0x6D, 0x60, 0x71, 0x62, 0x73, 0x63, 0x75, 0x64, 0x76, 0x64, 0x75, 0x63, 0x73, 0x61, 0x70, 0x62, 0x75, 0x63, 0x79, 0x69, 0x7C, 0x6B, 0x7A, 0x6A, 0x78, 0x68, 0x7A, 0x6C, 0x79, 0x68, 0x78, 0x6A, 0x7A, 0x6C, 0x78, 0x69, 0x78, 0x68, 0x75, 0x66, 0x7A, 0x6C, 0x7D, 0x6C, 0x7D, 0x6D, 0x79, 0x6A, 0x78, 0x69, 0x78, 0x68, 0x7A, 0x69, 0x7C, 0x6B, 0x7F, 0x6F, 0x7F, 0x6E, 0x80, 0x6D, 0x7E, 0x6E, 0x82, 0x70, 0x82, 0x71, 0x83, 0x72, 0x81, 0x6F, 0x80, 0x71, 0x7F, 0x6F, 0x81, 0x71, 0x7C, 0x6B, 0x7D, 0x6D, 0x7D, 0x6B, 0x7D, 0x6D, 0x7F, 0x6D, 0x80, 0x6B, 0x7B, 0x69, 0x7D, 0x6E, 0x7F, 0x6E, 0x81, 0x73, 0x81, 0x73, 0x7E, 0x6E, 0x7C, 0x6D, 0x7D, 0x6E, 0x7C, 0x6B, 0x7D, 0x6D, 0x7F, 0x71, 0x80, 0x6F, 0x80, 0x70, 0x80, 0x72, 0x81, 0x74, 0x86, 0x76, 0x82, 0x74, 0x84, 0x74, 0x7D, 0x70, 0x81, 0x71, 0x7F, 0x70, 0x83, 0x76, 0x82, 0x72, 0x80, 0x71, 0x7F, 0x75, 0x83, 0x76, 0x8B, 0x8C, 0x8E, 0x7B, 0x82, 0x75, 0x62, 0x55, 0x49, 0x43, 0x40, 0x3D, 0x3E, 0x3E, 0x3C, 0x3B, 0x37, 0x38, 0x35, 0x39, 0x6F, 0x74, 0x8B, 0x87, 0x95, 0x8D, 0x96, 0x8F, 0x95, 0x8C, 0x8E, 0x85, 0xA1, 0xA7, 0xA4, 0x9F, 0x97, 0x90, 0x93, 0x8B, 0x96, 0x97, 0xA8, 0xB1, 0xA2, 0xA0, 0xA2, 0xA8, 0xA3, 0x97, 0x9E, 0xAA, 0xA8, 0xA0, 0x9A, 0x8F, 0x97, 0x90, 0x91, 0x88, 0x95, 0x90, 0x9A, 0x95, 0x94, 0x8B, 0x90, 0x8B, 0x8E, 0x86, 0x8D, 0x85, 0x95, 0x8D, 0x94, 0x91, 0x92, 0x88, 0x8E, 0x87, 0x8D, 0x8A, 0x8C, 0x7E, 0x89, 0x7E, 0x92, 0x8A, 0x95, 0x8D, 0x97, 0x94, 0x91, 0x8B, 0x90, 0x89, 0x94, 0x90, 0x8A, 0x81, 0x85, 0x7A, 0x85, 0x78, 0x93, 0x97, 0x98, 0x95, 0x8B, 0x7F, 0x8E, 0x87, 0x91, 0x87, 0x84, 0x79, 0x88, 0x80, 0x89, 0x7C, 0x86, 0x7D, 0x89, 0x88, 0x8A, 0x85, 0x86, 0x7D, 0x81, 0x77, 0x81, 0x77, 0x83, 0x78, 0x86, 0x79, 0x83, 0x73, 0x81, 0x71, 0x81, 0x76, 0x7F, 0x74, 0x7B, 0x6E, 0x7C, 0x6E, 0x7A, 0x6B, 0x79, 0x6D, 0x7C, 0x6E, 0x7B, 0x6C, 0x7E, 0x6F, 0x80, 0x72, 0x7F, 0x71, 0x7B, 0x6D, 0x78, 0x6B, 0x7D, 0x6B, 0x7D, 0x6E, 0x7E, 0x6F, 0x80, 0x72, 0x7D, 0x6F, 0x7A, 0x6C, 0x77, 0x6A, 0x7B, 0x6A, 0x77, 0x67, 0x78, 0x6B, 0x7B, 0x6B, 0x76, 0x67, 0x79, 0x6D, 0x79, 0x6B, 0x76, 0x6D, 0x77, 0x6B, 0x77, 0x6A, 0x76, 0x68, 0x78, 0x6A, 0x77, 0x6A, 0x76, 0x69, 0x75, 0x65, 0x77, 0x6C, 0x77, 0x6A, 0x77, 0x6B, 0x7C, 0x6E, 0x7B, 0x6C, 0x75, 0x67, 0x75, 0x66, 0x75, 0x68, 0x7B, 0x6C, 0x78, 0x68, 0x79, 0x68, 0x76, 0x67, 0x74, 0x67, 0x77, 0x68, 0x76, 0x67, 0x75, 0x66, 0x79, 0x6C, 0x78, 0x6A, 0x7D, 0x6E, 0x78, 0x69, 0x74, 0x68, 0x7C, 0x6D, 0x7D, 0x6E, 0x7C, 0x6E, 0x7B, 0x6F, 0x7D, 0x6F, 0x7F, 0x72, 0x7F, 0x73, 0x78, 0x6B, 0x77, 0x6B, 0x7E, 0x70, 0x78, 0x6A, 0x7A, 0x6B, 0x76, 0x67, 0x73, 0x66, 0x74, 0x67, 0x79, 0x6A, 0x77, 0x6A, 0x7D, 0x6E, 0x7B, 0x6D, 0x79, 0x6A, 0x7B, 0x6C, 0x7E, 0x6C, 0x79, 0x69, 0x77, 0x68, 0x77, 0x67, 0x76, 0x66, 0x76, 0x66, 0x77, 0x66, 0x62, 0x5E, 0x4D, 0x50, 0x44, 0x4D, 0x4C, 0x58, 0x42, 0x49, 0x43, 0x4F, 0x4D, 0x57, 0x4B, 0x59, 0x4B, 0x52, 0x4A, 0x57, 0x46, 0x4F, 0x4F, 0x5A, 0x47, 0x4C, 0x3D, 0x48, 0x4A, 0x52, 0x3F, 0x46, 0x4A, 0x54, 0x3F, 0x47, 0x48, 0x50, 0x3E, 0x44, 0x45, 0x4D, 0x3F, 0x46, 0x44, 0x4D, 0x43, 0x4E, 0x49, 0x51, 0x42, 0x4E, 0x48, 0x52, 0x48, 0x57, 0x4B, 0x54, 0x47, 0x52, 0x45, 0x4C, 0x4A, 0x58, 0x45, 0x49, 0x3E, 0x48, 0x42, 0x49, 0x44, 0x4B, 0x43, 0x4B, 0x45, 0x4B, 0x3F, 0x48, 0x44, 0x4D, 0x40, 0x49, 0x48, 0x52, 0x49, 0x50, 0x43, 0x4E, 0x4D, 0x58, 0x48, 0x53, 0x43, 0x4A, 0x48, 0x55, 0x42, 0x4C, 0x47, 0x51, 0x3D, 0x42
    },

    {
        0x54, 0x1E, 0x53, 0x1D, 0x51, 0x1D, 0x51, 0x1D, 0x51, 0x1D, 0x52, 0x1D, 0x52, 0x1E, 0x53, 0x1E, 0x54, 0x1E, 0x55, 0x1E, 0x57, 0x20, 0x56, 0x1E, 0x57, 0x1F, 0x58, 0x1F, 0x55, 0x1F, 0x55, 0x20, 0x56, 0x1F, 0x56, 0x1F, 0x55, 0x20, 0x59, 0x20, 0x58, 0x21, 0x59, 0x21, 0x58, 0x20, 0x58, 0x20, 0x57, 0x20, 0x58, 0x20, 0x58, 0x21, 0x5A, 0x20, 0x5A, 0x21, 0x5A, 0x21, 0x59, 0x20, 0x59, 0x20, 0x58, 0x20, 0x5D, 0x21, 0x5B, 0x22, 0x5A, 0x21, 0x5C, 0x22, 0x5B, 0x2B, 0x63, 0x35, 0x54, 0x2D, 0x46, 0x25, 0x3B, 0x1E, 0x3A, 0x1C, 0x4C, 0x1F, 0x5B, 0x22, 0x5B, 0x22, 0x5E, 0x23, 0x61, 0x24, 0x5F, 0x23, 0x60, 0x23, 0x5C, 0x23, 0x5F, 0x23, 0x60, 0x24, 0x63, 0x24, 0x63, 0x24, 0x63, 0x25, 0x61, 0x25, 0x63, 0x25, 0x67, 0x27, 0x66, 0x27, 0x69, 0x28, 0x65, 0x26, 0x66, 0x26, 0x64, 0x27, 0x68, 0x27, 0x67, 0x26, 0x66, 0x26, 0x67, 0x26, 0x65, 0x25, 0x65, 0x26, 0x66, 0x26, 0x67, 0x26, 0x65, 0x26, 0x66, 0x26, 0x65, 0x26, 0x69, 0x27, 0x6D, 0x29, 0x6F, 0x2A, 0x6D, 0x2A, 0x6E, 0x2A, 0x69, 0x28, 0x6C, 0x28, 0x6A, 0x27, 0x63, 0x25, 0x65, 0x26, 0x65, 0x25, 0x65, 0x27, 0x67, 0x27, 0x69, 0x27, 0x67, 0x26, 0x64, 0x26, 0x68, 0x27, 0x69, 0x27, 0x68, 0x28, 0x6B, 0x28, 0x65, 0x28, 0x67, 0x27, 0x65, 0x26, 0x67, 0x28, 0x67, 0x28, 0x6B, 0x28, 0x68, 0x28, 0x6C, 0x28, 0x6D, 0x2A, 0x6D, 0x2A, 0x70, 0x2A, 0x6E, 0x2A, 0x6D, 0x29, 0x6B, 0x29, 0x6D, 0x2A, 0x6B, 0x28, 0x6B, 0x29, 0x6A, 0x28, 0x6B, 0x2A, 0x71, 0x2D, 0x72, 0x30, 0x7A, 0x30, 0x6F, 0x2C, 0x5E, 0x27, 0x3F, 0x21, 0x3A, 0x21, 0x3D, 0x22, 0x37, 0x1F, 0x39, 0x21, 0x3E, 0x25, 0x83, 0x3C, 0x77, 0x30, 0x82, 0x3A, 0x8F, 0x3E, 0x88, 0x39, 0x7F, 0x37, 0x85, 0x39, 0x8C, 0x3E, 0x85, 0x3C, 0x88, 0x3C, 0x8D, 0x43, 0x86, 0x39, 0x90, 0x45, 0xB7, 0x5D, 0x9F, 0x4C, 0x99, 0x47, 0xA5, 0x50, 0x8F, 0x41, 0x83, 0x39, 0x7B, 0x33, 0x7C, 0x34, 0x7E, 0x34, 0x7B, 0x35, 0x7A, 0x37, 0x7B, 0x36, 0x7E, 0x35, 0x7E, 0x38, 0x7C, 0x35, 0x77, 0x31, 0x7E, 0x35, 0x77, 0x31, 0x73, 0x2E, 0x70, 0x2E, 0x78, 0x32, 0x78, 0x33, 0x72, 0x2D, 0x73, 0x30, 0x81, 0x3A, 0x79, 0x34, 0x7C, 0x35, 0x7B, 0x32, 0x85, 0x3B, 0x8E, 0x43, 0x97, 0x47, 0x84, 0x37, 0x78, 0x32, 0x76, 0x30, 0x77, 0x33, 0x77, 0x2F, 0x71, 0x2E, 0x73, 0x2F, 0x76, 0x30, 0x71, 0x2D, 0x71, 0x2C, 0x6B, 0x2B, 0x6F, 0x2B, 0x6D, 0x2B, 0x6D, 0x2B, 0x6A, 0x28, 0x6D, 0x2C, 0x6D, 0x2B, 0x6A, 0x2A, 0x6A, 0x28, 0x67, 0x26, 0x6A, 0x29, 0x69, 0x29, 0x69, 0x28, 0x69, 0x28, 0x6A, 0x28, 0x6C, 0x29, 0x6A, 0x29, 0x6B, 0x28, 0x67, 0x27, 0x68, 0x28, 0x68, 0x29, 0x6F, 0x2B, 0x6D, 0x2B, 0x6A, 0x29, 0x68, 0x28, 0x66, 0x27, 0x64, 0x26, 0x62, 0x25, 0x63, 0x25, 0x65, 0x28, 0x6A, 0x2A, 0x6B, 0x2B, 0x67, 0x28, 0x67, 0x28, 0x63, 0x27, 0x65, 0x28, 0x65, 0x27, 0x62, 0x25, 0x62, 0x26, 0x62, 0x26, 0x61, 0x25, 0x64, 0x27, 0x67, 0x28, 0x65, 0x27, 0x62, 0x26, 0x64, 0x27, 0x64, 0x26, 0x62, 0x25, 0x5F, 0x25, 0x63, 0x26, 0x63, 0x26, 0x64, 0x25, 0x65, 0x27, 0x63, 0x26, 0x63, 0x26, 0x62, 0x26, 0x62, 0x26, 0x65, 0x27, 0x64, 0x28, 0x65, 0x27, 0x63, 0x25, 0x62, 0x26, 0x66, 0x26, 0x65, 0x26, 0x65, 0x27, 0x65, 0x28, 0x68, 0x29, 0x66, 0x28, 0x67, 0x2A, 0x6C, 0x2B, 0x69, 0x29, 0x6C, 0x2A, 0x65, 0x27, 0x62, 0x27, 0x63, 0x26, 0x61, 0x26, 0x65, 0x26, 0x61, 0x24, 0x62, 0x25, 0x65, 0x26, 0x67, 0x27, 0x65, 0x25, 0x63, 0x25, 0x60, 0x24, 0x63, 0x25, 0x5F, 0x24, 0x60, 0x24, 0x60, 0x24, 0x5E, 0x24, 0x61, 0x24, 0x5B, 0x29, 0x52, 0x28, 0x4C, 0x28, 0x55, 0x2B, 0x50, 0x29, 0x4B, 0x28, 0x4A, 0x26, 0x4B, 0x29, 0x46, 0x24, 0x4A, 0x28, 0x49, 0x26, 0x4E, 0x29, 0x48, 0x26, 0x48, 0x28, 0x49, 0x25, 0x48, 0x26, 0x56, 0x2C, 0x4B, 0x27, 0x51, 0x2A, 0x44, 0x25, 0x55, 0x2C, 0x48, 0x27, 0x52, 0x2A, 0x47, 0x26, 0x51, 0x2A, 0x46, 0x26, 0x49, 0x27, 0x4E, 0x2A, 0x47, 0x24, 0x4B, 0x29, 0x49, 0x27, 0x48, 0x26, 0x48, 0x25, 0x44, 0x24, 0x4C, 0x27, 0x46, 0x25, 0x4D, 0x29, 0x46, 0x25, 0x46, 0x25, 0x52, 0x2A, 0x4A, 0x27, 0x54, 0x2C, 0x4B, 0x28, 0x4A, 0x28, 0x48, 0x25, 0x48, 0x27, 0x47, 0x26, 0x4F, 0x29, 0x49, 0x27, 0x51, 0x2A, 0x48, 0x26
    },

    {
        0x62, 0x54, 0x62, 0x55, 0x61, 0x54, 0x62, 0x54, 0x61, 0x55, 0x62, 0x55, 0x61, 0x55, 0x65, 0x56, 0x65, 0x57, 0x64, 0x58, 0x66, 0x59, 0x67, 0x59, 0x69, 0x5A, 0x67, 0x59, 0x67, 0x57, 0x66, 0x59, 0x67, 0x58, 0x68, 0x56, 0x65, 0x5A, 0x69, 0x5D, 0x69, 0x5D, 0x6C, 0x5D, 0x6A, 0x5B, 0x6A, 0x5A, 0x6B, 0x5C, 0x6A, 0x5A, 0x6A, 0x5C, 0x6B, 0x5C, 0x6B, 0x5D, 0x6C, 0x5C, 0x6D, 0x5D, 0x6E, 0x5E, 0x6D, 0x5D, 0x6F, 0x60, 0x6D, 0x5E, 0x6D, 0x5F, 0x6E, 0x5F, 0x64, 0x60, 0x5E, 0x5E, 0x51, 0x4C, 0x46, 0x41, 0x40, 0x39, 0x3E, 0x39, 0x52, 0x4F, 0x6B, 0x5D, 0x6E, 0x5F, 0x70, 0x61, 0x75, 0x64, 0x73, 0x62, 0x75, 0x63, 0x73, 0x62, 0x77, 0x66, 0x75, 0x64, 0x77, 0x67, 0x77, 0x67, 0x77, 0x67, 0x77, 0x66, 0x77, 0x67, 0x7C, 0x6D, 0x7A, 0x6C, 0x7A, 0x6C, 0x79, 0x6D, 0x7A, 0x6A, 0x79, 0x6A, 0x7C, 0x6B, 0x7A, 0x69, 0x7B, 0x6C, 0x7C, 0x6B, 0x7A, 0x68, 0x79, 0x6A, 0x7B, 0x6B, 0x79, 0x6A, 0x7A, 0x6A, 0x7C, 0x6B, 0x7C, 0x6A, 0x7E, 0x6F, 0x82, 0x73, 0x83, 0x74, 0x82, 0x71, 0x83, 0x74, 0x81, 0x70, 0x7F, 0x70, 0x7D, 0x6C, 0x77, 0x68, 0x79, 0x6A, 0x7D, 0x6C, 0x7E, 0x6F, 0x7E, 0x6C, 0x7E, 0x6D, 0x7D, 0x6B, 0x79, 0x6A, 0x7E, 0x6F, 0x7C, 0x6E, 0x7D, 0x6D, 0x7C, 0x6D, 0x77, 0x6B, 0x79, 0x69, 0x79, 0x6A, 0x7B, 0x6C, 0x7B, 0x6C, 0x80, 0x6F, 0x7D, 0x6F, 0x81, 0x71, 0x82, 0x72, 0x83, 0x75, 0x85, 0x76, 0x84, 0x73, 0x82, 0x71, 0x7F, 0x70, 0x83, 0x72, 0x7C, 0x6E, 0x80, 0x70, 0x80, 0x6E, 0x7E, 0x6F, 0x82, 0x76, 0x83, 0x7A, 0x8C, 0x7B, 0x83, 0x76, 0x6E, 0x5E, 0x44, 0x3E, 0x3E, 0x3D, 0x3F, 0x3D, 0x38, 0x37, 0x39, 0x3E, 0x49, 0x50, 0x8B, 0x8B, 0x8A, 0x7E, 0x92, 0x8F, 0x9F, 0x9B, 0x98, 0x8C, 0x97, 0x92, 0x96, 0x8A, 0x9B, 0x96, 0x98, 0x92, 0x99, 0x90, 0x98, 0x98, 0x9C, 0x89, 0x94, 0x98, 0xB2, 0xB9, 0xAB, 0xB1, 0xA3, 0x9E, 0xA7, 0xAA, 0x96, 0x90, 0x91, 0x88, 0x8E, 0x82, 0x8C, 0x81, 0x8C, 0x7E, 0x89, 0x82, 0x89, 0x82, 0x8B, 0x7F, 0x8D, 0x7F, 0x8E, 0x8D, 0x8C, 0x83, 0x89, 0x7E, 0x8D, 0x83, 0x89, 0x7E, 0x86, 0x79, 0x83, 0x77, 0x86, 0x7A, 0x85, 0x7D, 0x84, 0x78, 0x88, 0x7D, 0x8B, 0x86, 0x88, 0x80, 0x8C, 0x83, 0x8E, 0x81, 0x96, 0x93, 0xA1, 0xA1, 0x98, 0x96, 0x93, 0x88, 0x8B, 0x7F, 0x85, 0x7A, 0x89, 0x81, 0x87, 0x79, 0x82, 0x78, 0x88, 0x7D, 0x88, 0x7E, 0x83, 0x76, 0x85, 0x75, 0x80, 0x72, 0x81, 0x74, 0x80, 0x72, 0x82, 0x73, 0x7C, 0x6C, 0x80, 0x73, 0x7E, 0x72, 0x7C, 0x70, 0x7D, 0x6F, 0x78, 0x69, 0x7C, 0x70, 0x7E, 0x6F, 0x7B, 0x6D, 0x7C, 0x6C, 0x7D, 0x71, 0x81, 0x73, 0x7F, 0x6F, 0x80, 0x70, 0x7C, 0x6C, 0x7D, 0x6C, 0x7B, 0x6C, 0x82, 0x75, 0x80, 0x73, 0x7F, 0x73, 0x80, 0x6F, 0x7E, 0x6D, 0x77, 0x68, 0x77, 0x67, 0x76, 0x68, 0x77, 0x69, 0x7C, 0x72, 0x7D, 0x73, 0x79, 0x6B, 0x78, 0x6B, 0x75, 0x69, 0x78, 0x6B, 0x78, 0x6B, 0x76, 0x68, 0x76, 0x67, 0x74, 0x67, 0x74, 0x66, 0x77, 0x6B, 0x77, 0x6B, 0x76, 0x6A, 0x75, 0x68, 0x78, 0x6A, 0x79, 0x69, 0x76, 0x66, 0x72, 0x66, 0x75, 0x68, 0x77, 0x69, 0x78, 0x6A, 0x7A, 0x69, 0x79, 0x6A, 0x78, 0x67, 0x77, 0x68, 0x78, 0x6B, 0x79, 0x6C, 0x78, 0x6B, 0x78, 0x6B, 0x76, 0x68, 0x76, 0x68, 0x7C, 0x6C, 0x79, 0x6A, 0x78, 0x6B, 0x79, 0x6A, 0x7D, 0x6E, 0x79, 0x6A, 0x77, 0x6D, 0x7E, 0x72, 0x7E, 0x70, 0x83, 0x72, 0x7A, 0x6B, 0x76, 0x6A, 0x78, 0x69, 0x74, 0x67, 0x79, 0x6B, 0x75, 0x66, 0x79, 0x69, 0x7C, 0x6B, 0x7C, 0x6B, 0x7A, 0x6B, 0x79, 0x67, 0x77, 0x66, 0x79, 0x68, 0x76, 0x66, 0x76, 0x66, 0x76, 0x67, 0x73, 0x65, 0x74, 0x66, 0x63, 0x62, 0x4D, 0x51, 0x4A, 0x53, 0x4E, 0x58, 0x49, 0x50, 0x46, 0x4F, 0x41, 0x46, 0x47, 0x53, 0x42, 0x47, 0x46, 0x4F, 0x45, 0x4E, 0x4B, 0x55, 0x46, 0x4C, 0x42, 0x4C, 0x46, 0x4F, 0x44, 0x4D, 0x4F, 0x5C, 0x44, 0x4B, 0x4A, 0x53, 0x3F, 0x48, 0x4F, 0x58, 0x42, 0x4C, 0x48, 0x51, 0x40, 0x4C, 0x46, 0x4C, 0x3F, 0x4C, 0x41, 0x47, 0x46, 0x52, 0x40, 0x47, 0x45, 0x51, 0x45, 0x4D, 0x45, 0x4C, 0x44, 0x4B, 0x41, 0x4C, 0x46, 0x4D, 0x41, 0x4B, 0x44, 0x4D, 0x3E, 0x45, 0x42, 0x4D, 0x4D, 0x57, 0x43, 0x4C, 0x4C, 0x58, 0x43, 0x49, 0x43, 0x4F, 0x3F, 0x45, 0x43, 0x4E, 0x43, 0x4E, 0x47, 0x52, 0x43, 0x4F, 0x4C, 0x56, 0x42, 0x49
    },

    {
        0x53, 0x1E, 0x52, 0x1D, 0x52, 0x1D, 0x50, 0x1D, 0x53, 0x1D, 0x53, 0x1E, 0x53, 0x1E, 0x57, 0x1F, 0x56, 0x1E, 0x53, 0x1E, 0x54, 0x1F, 0x54, 0x1E, 0x54, 0x1E, 0x57, 0x1F, 0x57, 0x1F, 0x56, 0x1F, 0x56, 0x1F, 0x56, 0x20, 0x58, 0x20, 0x58, 0x20, 0x58, 0x21, 0x59, 0x20, 0x5A, 0x21, 0x5B, 0x21, 0x5A, 0x21, 0x59, 0x21, 0x5B, 0x22, 0x5A, 0x20, 0x5A, 0x21, 0x59, 0x20, 0x5C, 0x20, 0x5B, 0x21, 0x59, 0x21, 0x5A, 0x20, 0x5F, 0x22, 0x5A, 0x21, 0x5D, 0x25, 0x56, 0x2D, 0x46, 0x24, 0x35, 0x1C, 0x30, 0x1A, 0x30, 0x1A, 0x2D, 0x19, 0x3B, 0x1C, 0x59, 0x24, 0x5C, 0x22, 0x5E, 0x22, 0x5E, 0x22, 0x5C, 0x21, 0x5F, 0x24, 0x64, 0x25, 0x60, 0x24, 0x5F, 0x23, 0x62, 0x24, 0x5F, 0x24, 0x64, 0x24, 0x63, 0x24, 0x5F, 0x23, 0x64, 0x26, 0x68, 0x28, 0x6A, 0x29, 0x6A, 0x29, 0x69, 0x28, 0x68, 0x27, 0x63, 0x25, 0x66, 0x26, 0x67, 0x27, 0x66, 0x25, 0x66, 0x26, 0x65, 0x26, 0x64, 0x25, 0x62, 0x24, 0x66, 0x26, 0x68, 0x27, 0x6A, 0x28, 0x67, 0x27, 0x6C, 0x28, 0x6E, 0x29, 0x6E, 0x29, 0x6F, 0x2A, 0x6C, 0x29, 0x6A, 0x27, 0x67, 0x27, 0x66, 0x26, 0x69, 0x28, 0x6F, 0x2F, 0x7B, 0x33, 0x6D, 0x29, 0x67, 0x27, 0x69, 0x27, 0x6A, 0x28, 0x65, 0x26, 0x68, 0x28, 0x6A, 0x29, 0x68, 0x29, 0x65, 0x28, 0x64, 0x28, 0x67, 0x27, 0x64, 0x27, 0x68, 0x27, 0x6A, 0x27, 0x69, 0x28, 0x6D, 0x28, 0x6A, 0x27, 0x6D, 0x2A, 0x70, 0x29, 0x69, 0x29, 0x6D, 0x29, 0x69, 0x28, 0x6E, 0x2A, 0x6A, 0x29, 0x6C, 0x2A, 0x6B, 0x28, 0x6A, 0x29, 0x6E, 0x2C, 0x7E, 0x36, 0x77, 0x2E, 0x6F, 0x2C, 0x6B, 0x29, 0x48, 0x20, 0x38, 0x1F, 0x38, 0x1F, 0x35, 0x1E, 0x45, 0x28, 0x65, 0x2D, 0x7B, 0x35, 0x7D, 0x34, 0x80, 0x38, 0x93, 0x42, 0x84, 0x39, 0x90, 0x48, 0x97, 0x41, 0x82, 0x3B, 0x8B, 0x3E, 0x94, 0x45, 0x9C, 0x4B, 0x94, 0x41, 0x82, 0x3B, 0x86, 0x3B, 0x8B, 0x3D, 0x7D, 0x35, 0x83, 0x38, 0x7B, 0x34, 0x76, 0x30, 0x78, 0x32, 0x80, 0x37, 0x7F, 0x33, 0x78, 0x31, 0x7A, 0x33, 0x73, 0x2E, 0x76, 0x30, 0x80, 0x37, 0x7B, 0x32, 0x78, 0x32, 0x7B, 0x31, 0x76, 0x2F, 0x7B, 0x32, 0x72, 0x2E, 0x72, 0x2E, 0x6D, 0x2A, 0x70, 0x2E, 0x75, 0x2F, 0x70, 0x2D, 0x75, 0x32, 0x7A, 0x32, 0x73, 0x31, 0x7C, 0x37, 0x92, 0x43, 0x7B, 0x32, 0x78, 0x31, 0x76, 0x2F, 0x6E, 0x2E, 0x6E, 0x2C, 0x6F, 0x2C, 0x6E, 0x2C, 0x74, 0x2E, 0x6D, 0x2B, 0x6B, 0x29, 0x6B, 0x29, 0x6B, 0x29, 0x69, 0x28, 0x69, 0x28, 0x68, 0x27, 0x6A, 0x2A, 0x6E, 0x2B, 0x6D, 0x2B, 0x6B, 0x2A, 0x6C, 0x29, 0x64, 0x26, 0x69, 0x27, 0x6A, 0x28, 0x66, 0x26, 0x64, 0x26, 0x69, 0x29, 0x6A, 0x28, 0x6B, 0x29, 0x6C, 0x2A, 0x68, 0x27, 0x68, 0x28, 0x68, 0x29, 0x6B, 0x29, 0x68, 0x28, 0x6A, 0x2B, 0x6B, 0x2B, 0x6D, 0x2B, 0x6B, 0x29, 0x64, 0x25, 0x63, 0x26, 0x62, 0x25, 0x6B, 0x2C, 0x70, 0x2C, 0x64, 0x27, 0x64, 0x26, 0x66, 0x29, 0x66, 0x27, 0x66, 0x27, 0x63, 0x25, 0x64, 0x26, 0x63, 0x27, 0x64, 0x26, 0x66, 0x28, 0x65, 0x27, 0x62, 0x26, 0x64, 0x27, 0x63, 0x25, 0x63, 0x26, 0x67, 0x28, 0x64, 0x26, 0x62, 0x26, 0x62, 0x25, 0x64, 0x26, 0x65, 0x26, 0x64, 0x26, 0x63, 0x26, 0x63, 0x26, 0x65, 0x26, 0x64, 0x25, 0x67, 0x28, 0x66, 0x27, 0x62, 0x26, 0x65, 0x27, 0x6F, 0x2E, 0x69, 0x29, 0x64, 0x27, 0x67, 0x27, 0x65, 0x28, 0x64, 0x27, 0x65, 0x29, 0x65, 0x28, 0x64, 0x27, 0x66, 0x2A, 0x6A, 0x2B, 0x66, 0x28, 0x66, 0x28, 0x64, 0x25, 0x62, 0x24, 0x63, 0x26, 0x63, 0x25, 0x64, 0x26, 0x63, 0x25, 0x65, 0x26, 0x62, 0x24, 0x60, 0x24, 0x62, 0x24, 0x60, 0x24, 0x62, 0x24, 0x61, 0x24, 0x61, 0x24, 0x62, 0x24, 0x5F, 0x2A, 0x4D, 0x27, 0x4D, 0x29, 0x4F, 0x2A, 0x45, 0x25, 0x4A, 0x28, 0x48, 0x26, 0x53, 0x2C, 0x55, 0x2B, 0x51, 0x2B, 0x4D, 0x29, 0x5F, 0x32, 0x4D, 0x28, 0x46, 0x26, 0x4D, 0x27, 0x48, 0x27, 0x4B, 0x28, 0x43, 0x24, 0x48, 0x26, 0x42, 0x24, 0x4C, 0x28, 0x42, 0x24, 0x48, 0x26, 0x4B, 0x27, 0x4F, 0x29, 0x49, 0x28, 0x51, 0x29, 0x52, 0x2A, 0x4F, 0x28, 0x51, 0x2B, 0x49, 0x26, 0x51, 0x2A, 0x49, 0x26, 0x4B, 0x29, 0x45, 0x24, 0x4C, 0x28, 0x49, 0x25, 0x4A, 0x28, 0x4B, 0x28, 0x48, 0x26, 0x45, 0x27, 0x52, 0x2B, 0x4A, 0x27, 0x4A, 0x27, 0x4B, 0x28, 0x5A, 0x2F, 0x51, 0x2A, 0x50, 0x2A, 0x47, 0x26, 0x53, 0x2B, 0x41, 0x22
    },

    {
        0x62, 0x55, 0x62, 0x56, 0x62, 0x55, 0x5F, 0x53, 0x61, 0x55, 0x63, 0x56, 0x62, 0x56, 0x68, 0x5A, 0x65, 0x59, 0x64, 0x57, 0x63, 0x57, 0x64, 0x56, 0x66, 0x57, 0x68, 0x5A, 0x69, 0x5B, 0x69, 0x5A, 0x69, 0x5B, 0x69, 0x5B, 0x68, 0x5A, 0x6A, 0x5C, 0x6A, 0x5D, 0x6A, 0x5D, 0x6D, 0x5F, 0x6D, 0x5F, 0x6B, 0x5D, 0x6A, 0x5E, 0x6C, 0x5F, 0x6C, 0x5D, 0x6D, 0x5D, 0x6E, 0x5E, 0x70, 0x5F, 0x6D, 0x5D, 0x6A, 0x5C, 0x6E, 0x5D, 0x70, 0x61, 0x6E, 0x60, 0x6B, 0x5E, 0x57, 0x54, 0x48, 0x40, 0x3A, 0x31, 0x35, 0x2F, 0x35, 0x2F, 0x32, 0x2E, 0x3F, 0x3F, 0x66, 0x5D, 0x6F, 0x60, 0x70, 0x60, 0x71, 0x62, 0x71, 0x61, 0x74, 0x64, 0x77, 0x68, 0x72, 0x63, 0x72, 0x62, 0x75, 0x65, 0x75, 0x65, 0x79, 0x68, 0x79, 0x65, 0x74, 0x64, 0x79, 0x68, 0x7B, 0x6B, 0x7B, 0x6D, 0x7D, 0x6E, 0x7C, 0x6E, 0x7B, 0x69, 0x79, 0x69, 0x7A, 0x6A, 0x7B, 0x6B, 0x79, 0x6A, 0x7A, 0x6B, 0x76, 0x68, 0x74, 0x66, 0x77, 0x66, 0x7A, 0x69, 0x7D, 0x6B, 0x7E, 0x6E, 0x7E, 0x6D, 0x80, 0x71, 0x84, 0x74, 0x83, 0x71, 0x82, 0x70, 0x81, 0x72, 0x80, 0x6F, 0x7B, 0x6D, 0x7C, 0x6B, 0x81, 0x71, 0x86, 0x7C, 0x89, 0x7C, 0x83, 0x71, 0x80, 0x6E, 0x7E, 0x6E, 0x7F, 0x6F, 0x78, 0x6A, 0x7C, 0x6D, 0x7D, 0x70, 0x77, 0x6F, 0x72, 0x66, 0x70, 0x67, 0x77, 0x6A, 0x78, 0x6A, 0x7D, 0x6D, 0x7B, 0x6E, 0x7F, 0x70, 0x7F, 0x71, 0x7F, 0x6F, 0x80, 0x71, 0x86, 0x71, 0x7C, 0x6D, 0x82, 0x72, 0x7E, 0x6E, 0x82, 0x71, 0x7E, 0x70, 0x7E, 0x71, 0x7F, 0x6F, 0x7D, 0x70, 0x83, 0x77, 0x8C, 0x85, 0x8B, 0x7D, 0x84, 0x78, 0x7C, 0x70, 0x60, 0x50, 0x40, 0x3C, 0x3A, 0x3A, 0x3A, 0x3B, 0x4D, 0x52, 0x75, 0x74, 0x84, 0x7C, 0x8D, 0x86, 0x91, 0x8C, 0x93, 0x91, 0x8B, 0x82, 0x94, 0x97, 0x9C, 0x97, 0x90, 0x87, 0x92, 0x8F, 0xA0, 0x9F, 0xA5, 0xA4, 0x99, 0x95, 0x97, 0x8F, 0x92, 0x88, 0x91, 0x8A, 0x8B, 0x81, 0x8F, 0x82, 0x8C, 0x7F, 0x87, 0x7A, 0x8B, 0x82, 0x8E, 0x88, 0x8E, 0x82, 0x8A, 0x7F, 0x87, 0x7E, 0x89, 0x79, 0x89, 0x80, 0x8F, 0x88, 0x8D, 0x7F, 0x8A, 0x7F, 0x8A, 0x7E, 0x85, 0x7A, 0x8C, 0x81, 0x86, 0x7A, 0x86, 0x7A, 0x80, 0x74, 0x7F, 0x7A, 0x83, 0x76, 0x83, 0x76, 0x87, 0x81, 0x92, 0x84, 0x87, 0x7C, 0x8C, 0x88, 0x94, 0x91, 0x88, 0x7D, 0x83, 0x79, 0x86, 0x7B, 0x80, 0x77, 0x7D, 0x72, 0x81, 0x74, 0x83, 0x74, 0x87, 0x7B, 0x7F, 0x74, 0x7E, 0x6F, 0x80, 0x71, 0x82, 0x72, 0x7F, 0x70, 0x7C, 0x6E, 0x7F, 0x6E, 0x7F, 0x72, 0x81, 0x72, 0x82, 0x75, 0x7C, 0x72, 0x7E, 0x6F, 0x78, 0x67, 0x7D, 0x6F, 0x7D, 0x6F, 0x79, 0x6B, 0x76, 0x69, 0x7D, 0x70, 0x7E, 0x6F, 0x80, 0x70, 0x80, 0x74, 0x7E, 0x6F, 0x7F, 0x6C, 0x7A, 0x6E, 0x7F, 0x70, 0x7E, 0x70, 0x7F, 0x6F, 0x79, 0x6F, 0x7F, 0x72, 0x7C, 0x6E, 0x75, 0x69, 0x76, 0x68, 0x75, 0x68, 0x7B, 0x72, 0x7E, 0x71, 0x76, 0x6A, 0x79, 0x6A, 0x78, 0x6C, 0x79, 0x6C, 0x7C, 0x6C, 0x78, 0x69, 0x79, 0x6A, 0x76, 0x69, 0x79, 0x6A, 0x7A, 0x6B, 0x76, 0x6A, 0x75, 0x68, 0x78, 0x69, 0x75, 0x67, 0x76, 0x69, 0x7B, 0x6D, 0x77, 0x6B, 0x75, 0x68, 0x77, 0x67, 0x78, 0x6C, 0x78, 0x6A, 0x77, 0x6A, 0x77, 0x69, 0x76, 0x68, 0x78, 0x6A, 0x77, 0x68, 0x78, 0x6B, 0x79, 0x6B, 0x75, 0x67, 0x79, 0x6C, 0x80, 0x75, 0x7B, 0x6D, 0x76, 0x6A, 0x7B, 0x6D, 0x79, 0x6A, 0x78, 0x6A, 0x77, 0x6A, 0x76, 0x6A, 0x77, 0x69, 0x77, 0x6A, 0x79, 0x6E, 0x7B, 0x6D, 0x7C, 0x6C, 0x7B, 0x6A, 0x75, 0x66, 0x76, 0x6A, 0x78, 0x69, 0x78, 0x69, 0x77, 0x69, 0x7A, 0x6A, 0x79, 0x68, 0x77, 0x65, 0x78, 0x68, 0x75, 0x66, 0x79, 0x69, 0x77, 0x67, 0x76, 0x66, 0x75, 0x65, 0x60, 0x5F, 0x49, 0x4E, 0x46, 0x4E, 0x47, 0x4F, 0x42, 0x4B, 0x46, 0x51, 0x44, 0x4D, 0x4F, 0x5E, 0x4C, 0x52, 0x49, 0x55, 0x46, 0x52, 0x56, 0x60, 0x42, 0x48, 0x43, 0x4F, 0x47, 0x4C, 0x43, 0x4D, 0x42, 0x4A, 0x3E, 0x47, 0x41, 0x48, 0x3E, 0x4A, 0x46, 0x4D, 0x3E, 0x49, 0x44, 0x4D, 0x48, 0x54, 0x49, 0x53, 0x46, 0x52, 0x4D, 0x56, 0x4E, 0x59, 0x47, 0x4D, 0x49, 0x55, 0x40, 0x49, 0x4A, 0x53, 0x40, 0x45, 0x43, 0x4F, 0x3F, 0x45, 0x47, 0x53, 0x46, 0x4E, 0x47, 0x4F, 0x43, 0x4D, 0x40, 0x47, 0x41, 0x4F, 0x4C, 0x55, 0x46, 0x50, 0x46, 0x50, 0x46, 0x4F, 0x52, 0x60, 0x47, 0x4E, 0x46, 0x51, 0x41, 0x4E, 0x49, 0x51, 0x3C, 0x43
    },

    {
        0x53, 0x1F, 0x52, 0x1D, 0x50, 0x1D, 0x51, 0x1D, 0x53, 0x1E, 0x55, 0x1F, 0x57, 0x20, 0x57, 0x1F, 0x56, 0x1F, 0x56, 0x1F, 0x54, 0x1F, 0x55, 0x1E, 0x56, 0x1F, 0x56, 0x1F, 0x57, 0x1E, 0x57, 0x1F, 0x57, 0x20, 0x57, 0x20, 0x58, 0x21, 0x5A, 0x21, 0x5C, 0x22, 0x5D, 0x22, 0x5C, 0x22, 0x5D, 0x22, 0x5B, 0x22, 0x5D, 0x22, 0x5A, 0x21, 0x5A, 0x21, 0x5B, 0x21, 0x5A, 0x20, 0x5A, 0x21, 0x5C, 0x21, 0x5A, 0x21, 0x5B, 0x21, 0x5A, 0x22, 0x5D, 0x23, 0x54, 0x24, 0x43, 0x21, 0x37, 0x1C, 0x2E, 0x19, 0x2D, 0x19, 0x2D, 0x19, 0x29, 0x18, 0x31, 0x1A, 0x54, 0x22, 0x5A, 0x22, 0x5B, 0x22, 0x5B, 0x20, 0x5D, 0x22, 0x60, 0x23, 0x61, 0x24, 0x5E, 0x23, 0x60, 0x23, 0x5F, 0x23, 0x60, 0x22, 0x5E, 0x22, 0x5D, 0x23, 0x60, 0x23, 0x63, 0x27, 0x66, 0x26, 0x66, 0x27, 0x67, 0x27, 0x65, 0x26, 0x63, 0x25, 0x65, 0x27, 0x67, 0x26, 0x65, 0x26, 0x64, 0x26, 0x63, 0x25, 0x5D, 0x24, 0x60, 0x25, 0x64, 0x24, 0x60, 0x24, 0x60, 0x24, 0x61, 0x25, 0x66, 0x25, 0x67, 0x27, 0x6A, 0x27, 0x69, 0x27, 0x69, 0x26, 0x6B, 0x27, 0x69, 0x27, 0x67, 0x27, 0x67, 0x27, 0x6D, 0x29, 0x6D, 0x2A, 0x6C, 0x29, 0x6C, 0x29, 0x6D, 0x28, 0x68, 0x27, 0x65, 0x26, 0x67, 0x28, 0x6B, 0x2D, 0x70, 0x39, 0x6A, 0x37, 0x5A, 0x2D, 0x4A, 0x24, 0x52, 0x23, 0x62, 0x27, 0x6A, 0x29, 0x6B, 0x29, 0x6D, 0x29, 0x6B, 0x28, 0x67, 0x26, 0x6A, 0x27, 0x6B, 0x28, 0x68, 0x27, 0x6C, 0x29, 0x6B, 0x28, 0x6B, 0x29, 0x6C, 0x29, 0x6E, 0x2A, 0x69, 0x28, 0x6C, 0x2B, 0x6F, 0x2B, 0x72, 0x2D, 0x77, 0x30, 0x70, 0x2D, 0x6E, 0x2B, 0x6B, 0x28, 0x5C, 0x27, 0x54, 0x26, 0x5C, 0x28, 0x67, 0x2B, 0x6E, 0x2C, 0x72, 0x2E, 0x7F, 0x37, 0x7E, 0x35, 0x78, 0x2F, 0x77, 0x30, 0x88, 0x3E, 0x84, 0x37, 0x7E, 0x35, 0x77, 0x31, 0x7C, 0x34, 0x7F, 0x37, 0x85, 0x3B, 0x86, 0x3B, 0x79, 0x32, 0x7B, 0x33, 0x78, 0x32, 0x7A, 0x34, 0x78, 0x2F, 0x74, 0x2F, 0x77, 0x31, 0x78, 0x32, 0x7B, 0x33, 0x7B, 0x32, 0x77, 0x32, 0x76, 0x2F, 0x78, 0x34, 0x7B, 0x32, 0x74, 0x2F, 0x74, 0x2E, 0x70, 0x2E, 0x70, 0x2D, 0x74, 0x31, 0x72, 0x2F, 0x73, 0x2F, 0x74, 0x2E, 0x77, 0x31, 0x70, 0x2C, 0x74, 0x2F, 0x74, 0x35, 0x93, 0x43, 0x7A, 0x33, 0x78, 0x32, 0x76, 0x32, 0x71, 0x2E, 0x71, 0x2E, 0x70, 0x2D, 0x6F, 0x2D, 0x77, 0x31, 0x75, 0x2F, 0x73, 0x31, 0x77, 0x31, 0x76, 0x2E, 0x6B, 0x29, 0x6A, 0x29, 0x6A, 0x29, 0x6C, 0x2B, 0x68, 0x27, 0x6A, 0x29, 0x6D, 0x2B, 0x6C, 0x29, 0x68, 0x28, 0x6C, 0x2A, 0x68, 0x27, 0x64, 0x26, 0x66, 0x27, 0x66, 0x26, 0x65, 0x26, 0x67, 0x27, 0x69, 0x28, 0x67, 0x28, 0x69, 0x29, 0x69, 0x29, 0x69, 0x29, 0x69, 0x28, 0x6F, 0x2C, 0x6B, 0x29, 0x64, 0x28, 0x66, 0x29, 0x65, 0x27, 0x6A, 0x29, 0x66, 0x27, 0x63, 0x25, 0x66, 0x27, 0x61, 0x25, 0x64, 0x26, 0x65, 0x28, 0x66, 0x27, 0x64, 0x27, 0x66, 0x29, 0x65, 0x27, 0x67, 0x28, 0x64, 0x27, 0x64, 0x27, 0x66, 0x28, 0x68, 0x29, 0x67, 0x27, 0x62, 0x26, 0x62, 0x27, 0x62, 0x26, 0x60, 0x26, 0x64, 0x27, 0x63, 0x26, 0x61, 0x25, 0x61, 0x25, 0x61, 0x25, 0x64, 0x26, 0x63, 0x26, 0x64, 0x27, 0x66, 0x26, 0x62, 0x24, 0x62, 0x26, 0x6A, 0x29, 0x67, 0x28, 0x63, 0x25, 0x63, 0x25, 0x61, 0x25, 0x64, 0x26, 0x63, 0x27, 0x63, 0x26, 0x68, 0x28, 0x68, 0x28, 0x66, 0x28, 0x68, 0x29, 0x68, 0x29, 0x62, 0x26, 0x62, 0x27, 0x64, 0x27, 0x61, 0x27, 0x65, 0x28, 0x67, 0x28, 0x64, 0x26, 0x61, 0x25, 0x62, 0x24, 0x60, 0x24, 0x60, 0x24, 0x63, 0x25, 0x62, 0x25, 0x62, 0x24, 0x61, 0x24, 0x60, 0x25, 0x63, 0x25, 0x62, 0x24, 0x61, 0x25, 0x60, 0x24, 0x53, 0x26, 0x4D, 0x28, 0x49, 0x27, 0x59, 0x2F, 0x4E, 0x2A, 0x51, 0x2B, 0x49, 0x27, 0x5A, 0x30, 0x43, 0x24, 0x4A, 0x29, 0x53, 0x2C, 0x52, 0x2A, 0x48, 0x25, 0x4D, 0x2B, 0x58, 0x2D, 0x51, 0x2A, 0x50, 0x2A, 0x48, 0x26, 0x54, 0x2C, 0x4E, 0x2A, 0x59, 0x2D, 0x4E, 0x2B, 0x57, 0x2D, 0x53, 0x2D, 0x52, 0x2B, 0x49, 0x29, 0x4B, 0x27, 0x4A, 0x28, 0x41, 0x23, 0x47, 0x26, 0x43, 0x25, 0x4B, 0x28, 0x44, 0x24, 0x4D, 0x28, 0x47, 0x25, 0x52, 0x2C, 0x4D, 0x28, 0x43, 0x23, 0x45, 0x25, 0x4E, 0x28, 0x4C, 0x2A, 0x5A, 0x2F, 0x44, 0x25, 0x49, 0x28, 0x48, 0x25, 0x4F, 0x29, 0x44, 0x25, 0x4E, 0x29, 0x4C, 0x28, 0x53, 0x2B, 0x43, 0x24
    },

    {
        0x63, 0x56, 0x5F, 0x54, 0x61, 0x55, 0x63, 0x55, 0x63, 0x56, 0x63, 0x57, 0x66, 0x5A, 0x67, 0x59, 0x66, 0x58, 0x64, 0x56, 0x64, 0x57, 0x66, 0x59, 0x68, 0x59, 0x67, 0x59, 0x68, 0x5A, 0x69, 0x5A, 0x6A, 0x5C, 0x69, 0x5A, 0x69, 0x5B, 0x6B, 0x5D, 0x6D, 0x5F, 0x6D, 0x60, 0x6F, 0x61, 0x71, 0x5F, 0x6E, 0x5F, 0x6F, 0x60, 0x6C, 0x5C, 0x6E, 0x5D, 0x6A, 0x5C, 0x6D, 0x5D, 0x6D, 0x5E, 0x70, 0x61, 0x6D, 0x5D, 0x6C, 0x5E, 0x6D, 0x5F, 0x6D, 0x60, 0x60, 0x51, 0x4A, 0x41, 0x3D, 0x34, 0x35, 0x2F, 0x32, 0x2E, 0x31, 0x2D, 0x2E, 0x29, 0x37, 0x37, 0x63, 0x5A, 0x6B, 0x5E, 0x6D, 0x5F, 0x6E, 0x5D, 0x72, 0x60, 0x75, 0x65, 0x77, 0x65, 0x72, 0x63, 0x72, 0x64, 0x74, 0x62, 0x74, 0x63, 0x72, 0x62, 0x73, 0x63, 0x75, 0x65, 0x78, 0x69, 0x7A, 0x69, 0x7A, 0x6B, 0x7A, 0x69, 0x79, 0x6A, 0x79, 0x68, 0x79, 0x6B, 0x7B, 0x6B, 0x78, 0x6A, 0x74, 0x67, 0x72, 0x65, 0x70, 0x62, 0x73, 0x64, 0x76, 0x66, 0x74, 0x63, 0x75, 0x66, 0x76, 0x66, 0x7B, 0x6B, 0x7C, 0x6D, 0x81, 0x71, 0x81, 0x6D, 0x7C, 0x6C, 0x80, 0x6F, 0x7D, 0x6C, 0x7D, 0x6C, 0x7F, 0x6C, 0x82, 0x72, 0x7F, 0x71, 0x80, 0x6F, 0x80, 0x70, 0x80, 0x71, 0x7C, 0x6B, 0x78, 0x6C, 0x7C, 0x6D, 0x7A, 0x71, 0x74, 0x75, 0x68, 0x68, 0x5A, 0x54, 0x4E, 0x47, 0x56, 0x51, 0x6F, 0x66, 0x7B, 0x70, 0x80, 0x71, 0x80, 0x6F, 0x80, 0x70, 0x82, 0x6F, 0x81, 0x6F, 0x7F, 0x6F, 0x7E, 0x6D, 0x81, 0x72, 0x81, 0x70, 0x80, 0x70, 0x7D, 0x72, 0x82, 0x73, 0x7F, 0x71, 0x83, 0x76, 0x84, 0x75, 0x85, 0x75, 0x87, 0x7D, 0x84, 0x77, 0x7F, 0x73, 0x7F, 0x70, 0x73, 0x69, 0x6C, 0x63, 0x72, 0x6D, 0x7A, 0x70, 0x80, 0x77, 0x82, 0x77, 0x8D, 0x86, 0x8E, 0x80, 0x87, 0x79, 0x8C, 0x80, 0x99, 0x99, 0x93, 0x8A, 0x8C, 0x83, 0x8A, 0x7D, 0x8C, 0x7D, 0x8D, 0x85, 0x94, 0x8B, 0x8C, 0x85, 0x8D, 0x81, 0x91, 0x83, 0x8C, 0x82, 0x8A, 0x80, 0x87, 0x78, 0x87, 0x7D, 0x8A, 0x7D, 0x89, 0x7D, 0x8E, 0x81, 0x8E, 0x81, 0x88, 0x7D, 0x87, 0x7C, 0x87, 0x7F, 0x8C, 0x82, 0x87, 0x7B, 0x83, 0x75, 0x83, 0x76, 0x83, 0x77, 0x85, 0x7B, 0x83, 0x77, 0x84, 0x77, 0x85, 0x7E, 0x8A, 0x7F, 0x85, 0x77, 0x8A, 0x7C, 0x87, 0x84, 0x94, 0x90, 0x84, 0x7E, 0x86, 0x78, 0x88, 0x7E, 0x85, 0x7C, 0x83, 0x76, 0x83, 0x76, 0x81, 0x76, 0x85, 0x7D, 0x82, 0x76, 0x83, 0x7C, 0x87, 0x7D, 0x84, 0x75, 0x80, 0x71, 0x7F, 0x71, 0x7E, 0x6F, 0x7D, 0x71, 0x7F, 0x6E, 0x82, 0x74, 0x83, 0x74, 0x81, 0x6E, 0x7B, 0x70, 0x7D, 0x71, 0x7D, 0x6C, 0x7A, 0x6A, 0x7A, 0x6A, 0x7D, 0x6D, 0x78, 0x6A, 0x7B, 0x6D, 0x7C, 0x6C, 0x7A, 0x6C, 0x7C, 0x6F, 0x7E, 0x70, 0x7C, 0x70, 0x7F, 0x6E, 0x83, 0x77, 0x7E, 0x71, 0x78, 0x6A, 0x78, 0x6B, 0x77, 0x6A, 0x7C, 0x6E, 0x7C, 0x6B, 0x77, 0x69, 0x7C, 0x6C, 0x75, 0x68, 0x78, 0x6A, 0x77, 0x6A, 0x78, 0x6B, 0x76, 0x68, 0x75, 0x6D, 0x7B, 0x6B, 0x7B, 0x6B, 0x75, 0x69, 0x78, 0x69, 0x78, 0x6A, 0x7A, 0x6E, 0x7B, 0x6C, 0x76, 0x67, 0x76, 0x6A, 0x75, 0x66, 0x75, 0x68, 0x78, 0x69, 0x74, 0x65, 0x74, 0x66, 0x75, 0x66, 0x74, 0x65, 0x76, 0x69, 0x77, 0x69, 0x78, 0x6A, 0x79, 0x6C, 0x77, 0x67, 0x77, 0x6A, 0x7C, 0x70, 0x7B, 0x6C, 0x77, 0x68, 0x77, 0x68, 0x75, 0x67, 0x78, 0x69, 0x76, 0x68, 0x79, 0x6A, 0x7B, 0x6C, 0x79, 0x6B, 0x7A, 0x6D, 0x7A, 0x6E, 0x7A, 0x6D, 0x77, 0x69, 0x75, 0x67, 0x76, 0x6A, 0x76, 0x68, 0x79, 0x6A, 0x7B, 0x70, 0x7A, 0x69, 0x75, 0x66, 0x76, 0x67, 0x74, 0x66, 0x77, 0x66, 0x76, 0x69, 0x77, 0x69, 0x78, 0x67, 0x79, 0x67, 0x76, 0x67, 0x7A, 0x68, 0x78, 0x68, 0x75, 0x67, 0x75, 0x64, 0x58, 0x53, 0x4C, 0x53, 0x47, 0x51, 0x52, 0x5D, 0x44, 0x4B, 0x47, 0x52, 0x43, 0x4D, 0x4F, 0x59, 0x3F, 0x45, 0x47, 0x52, 0x4E, 0x5B, 0x49, 0x52, 0x46, 0x4E, 0x47, 0x56, 0x53, 0x5C, 0x4A, 0x54, 0x4B, 0x56, 0x44, 0x4C, 0x4D, 0x58, 0x48, 0x55, 0x52, 0x5A, 0x46, 0x54, 0x4C, 0x55, 0x49, 0x56, 0x47, 0x4E, 0x41, 0x4E, 0x43, 0x49, 0x43, 0x4C, 0x3D, 0x45, 0x42, 0x4C, 0x3E, 0x48, 0x47, 0x51, 0x41, 0x49, 0x48, 0x53, 0x42, 0x4A, 0x4A, 0x54, 0x44, 0x4C, 0x3C, 0x42, 0x41, 0x4D, 0x46, 0x4F, 0x47, 0x57, 0x4E, 0x59, 0x3C, 0x42, 0x43, 0x4D, 0x41, 0x4B, 0x48, 0x4F, 0x3F, 0x4A, 0x46, 0x51, 0x47, 0x52, 0x4A, 0x54, 0x3C, 0x45
    },

    {
        0x52, 0x1D, 0x52, 0x1E, 0x54, 0x1E, 0x54, 0x1D, 0x53, 0x1E, 0x56, 0x1F, 0x55, 0x1E, 0x53, 0x1E, 0x55, 0x1F, 0x55, 0x1E, 0x55, 0x1F, 0x57, 0x1F, 0x55, 0x1E, 0x55, 0x1F, 0x57, 0x20, 0x58, 0x20, 0x59, 0x20, 0x57, 0x20, 0x58, 0x21, 0x5A, 0x22, 0x5A, 0x22, 0x5B, 0x22, 0x5E, 0x22, 0x5D, 0x22, 0x5B, 0x21, 0x59, 0x20, 0x58, 0x20, 0x5A, 0x20, 0x5C, 0x25, 0x5E, 0x23, 0x5A, 0x21, 0x5A, 0x20, 0x5B, 0x21, 0x5C, 0x21, 0x5C, 0x22, 0x5C, 0x22, 0x51, 0x1F, 0x3A, 0x1C, 0x31, 0x19, 0x2E, 0x18, 0x2C, 0x18, 0x2A, 0x17, 0x25, 0x16, 0x32, 0x1B, 0x54, 0x21, 0x5C, 0x22, 0x5B, 0x22, 0x5B, 0x21, 0x60, 0x22, 0x60, 0x23, 0x61, 0x24, 0x60, 0x24, 0x60, 0x23, 0x60, 0x23, 0x5F, 0x22, 0x5F, 0x23, 0x62, 0x24, 0x62, 0x25, 0x63, 0x25, 0x64, 0x27, 0x68, 0x27, 0x68, 0x27, 0x66, 0x27, 0x66, 0x26, 0x69, 0x28, 0x66, 0x2B, 0x6B, 0x32, 0x5D, 0x2C, 0x52, 0x25, 0x52, 0x22, 0x5B, 0x23, 0x5E, 0x23, 0x5F, 0x23, 0x67, 0x28, 0x65, 0x26, 0x66, 0x26, 0x66, 0x27, 0x69, 0x26, 0x62, 0x24, 0x64, 0x25, 0x68, 0x26, 0x68, 0x26, 0x69, 0x28, 0x6A, 0x27, 0x6A, 0x28, 0x67, 0x27, 0x69, 0x27, 0x6A, 0x28, 0x6D, 0x28, 0x68, 0x27, 0x69, 0x28, 0x6C, 0x2A, 0x6E, 0x3B, 0x63, 0x36, 0x47, 0x26, 0x3C, 0x21, 0x37, 0x1D, 0x33, 0x1B, 0x54, 0x24, 0x65, 0x26, 0x65, 0x27, 0x65, 0x26, 0x69, 0x27, 0x64, 0x26, 0x6A, 0x27, 0x6C, 0x27, 0x68, 0x27, 0x6B, 0x28, 0x6A, 0x28, 0x6C, 0x29, 0x68, 0x27, 0x6C, 0x2A, 0x70, 0x2B, 0x6F, 0x2A, 0x6D, 0x2A, 0x72, 0x2D, 0x72, 0x2D, 0x71, 0x2C, 0x6B, 0x29, 0x6E, 0x2B, 0x6D, 0x2A, 0x6F, 0x2A, 0x6D, 0x2B, 0x6E, 0x2A, 0x73, 0x2D, 0x6E, 0x2B, 0x70, 0x2D, 0x75, 0x31, 0x73, 0x2E, 0x7B, 0x34, 0x83, 0x3A, 0x82, 0x37, 0x7C, 0x33, 0x74, 0x30, 0x75, 0x30, 0x80, 0x35, 0x7D, 0x35, 0x79, 0x32, 0x7F, 0x37, 0x86, 0x39, 0x84, 0x38, 0x75, 0x30, 0x72, 0x2E, 0x6F, 0x2E, 0x75, 0x32, 0x7B, 0x33, 0x7F, 0x35, 0x79, 0x33, 0x7B, 0x33, 0x77, 0x30, 0x73, 0x2E, 0x76, 0x2F, 0x73, 0x2E, 0x73, 0x2D, 0x71, 0x2D, 0x6D, 0x2C, 0x72, 0x2E, 0x73, 0x2F, 0x70, 0x2C, 0x71, 0x30, 0x78, 0x30, 0x75, 0x32, 0x7A, 0x31, 0x76, 0x30, 0x72, 0x2D, 0x6E, 0x2C, 0x7C, 0x38, 0x80, 0x35, 0x7C, 0x34, 0x70, 0x2C, 0x71, 0x2C, 0x6C, 0x2C, 0x71, 0x2F, 0x6D, 0x2A, 0x6C, 0x2B, 0x70, 0x2D, 0x6C, 0x2A, 0x6C, 0x2A, 0x6A, 0x2B, 0x6A, 0x2A, 0x69, 0x29, 0x66, 0x28, 0x6E, 0x2B, 0x69, 0x29, 0x67, 0x28, 0x68, 0x28, 0x69, 0x29, 0x69, 0x27, 0x64, 0x26, 0x65, 0x26, 0x68, 0x27, 0x66, 0x27, 0x68, 0x28, 0x69, 0x27, 0x68, 0x28, 0x69, 0x2A, 0x6C, 0x2A, 0x6B, 0x2A, 0x6A, 0x28, 0x6F, 0x2D, 0x6C, 0x2B, 0x69, 0x28, 0x67, 0x29, 0x62, 0x26, 0x63, 0x27, 0x65, 0x26, 0x64, 0x25, 0x61, 0x25, 0x61, 0x25, 0x64, 0x25, 0x61, 0x25, 0x66, 0x27, 0x64, 0x27, 0x64, 0x27, 0x69, 0x29, 0x68, 0x29, 0x63, 0x27, 0x65, 0x26, 0x64, 0x26, 0x65, 0x29, 0x66, 0x26, 0x66, 0x28, 0x63, 0x26, 0x61, 0x26, 0x67, 0x27, 0x67, 0x28, 0x62, 0x25, 0x5F, 0x24, 0x5F, 0x24, 0x5F, 0x24, 0x62, 0x26, 0x67, 0x28, 0x63, 0x26, 0x66, 0x27, 0x64, 0x27, 0x64, 0x26, 0x64, 0x27, 0x65, 0x27, 0x61, 0x25, 0x62, 0x26, 0x63, 0x26, 0x61, 0x26, 0x63, 0x26, 0x64, 0x27, 0x64, 0x27, 0x63, 0x27, 0x68, 0x28, 0x6C, 0x2C, 0x6A, 0x2A, 0x65, 0x27, 0x66, 0x28, 0x67, 0x28, 0x63, 0x26, 0x67, 0x27, 0x67, 0x27, 0x68, 0x28, 0x66, 0x26, 0x60, 0x24, 0x5E, 0x23, 0x60, 0x24, 0x63, 0x25, 0x65, 0x26, 0x61, 0x26, 0x61, 0x25, 0x63, 0x25, 0x64, 0x26, 0x62, 0x25, 0x5F, 0x24, 0x5F, 0x24, 0x52, 0x27, 0x4E, 0x28, 0x4B, 0x29, 0x4D, 0x28, 0x44, 0x24, 0x4C, 0x28, 0x53, 0x2B, 0x52, 0x2B, 0x49, 0x26, 0x58, 0x2E, 0x53, 0x2C, 0x53, 0x2B, 0x4B, 0x28, 0x51, 0x2D, 0x57, 0x2D, 0x46, 0x27, 0x51, 0x2A, 0x46, 0x26, 0x47, 0x27, 0x4B, 0x2A, 0x4B, 0x27, 0x42, 0x24, 0x46, 0x25, 0x46, 0x27, 0x49, 0x27, 0x4C, 0x28, 0x4F, 0x29, 0x53, 0x2C, 0x4A, 0x27, 0x4F, 0x2A, 0x48, 0x26, 0x54, 0x2D, 0x47, 0x26, 0x4B, 0x28, 0x45, 0x24, 0x4D, 0x27, 0x4A, 0x26, 0x44, 0x24, 0x49, 0x26, 0x47, 0x25, 0x52, 0x2C, 0x4F, 0x29, 0x42, 0x23, 0x52, 0x2B, 0x4C, 0x28, 0x4D, 0x28, 0x42, 0x25, 0x48, 0x27, 0x48, 0x27, 0x44, 0x24, 0x40, 0x23
    },

    {
        0x60, 0x55, 0x5F, 0x54, 0x64, 0x57, 0x65, 0x57, 0x64, 0x57, 0x66, 0x5A, 0x66, 0x58, 0x66, 0x57, 0x66, 0x59, 0x66, 0x58, 0x65, 0x59, 0x66, 0x58, 0x65, 0x57, 0x67, 0x59, 0x68, 0x5A, 0x69, 0x5B, 0x6B, 0x5B, 0x69, 0x5B, 0x6A, 0x5C, 0x6A, 0x5D, 0x6D, 0x5E, 0x6F, 0x61, 0x70, 0x60, 0x6F, 0x5F, 0x6D, 0x5C, 0x6B, 0x5D, 0x6C, 0x5E, 0x6E, 0x5E, 0x6E, 0x63, 0x6E, 0x5F, 0x6D, 0x5F, 0x6F, 0x5E, 0x6D, 0x5E, 0x6D, 0x5E, 0x6F, 0x60, 0x71, 0x60, 0x64, 0x53, 0x41, 0x39, 0x39, 0x31, 0x34, 0x2D, 0x33, 0x2D, 0x2E, 0x29, 0x2B, 0x27, 0x3E, 0x3E, 0x64, 0x59, 0x70, 0x61, 0x6F, 0x60, 0x6F, 0x60, 0x73, 0x64, 0x76, 0x65, 0x72, 0x63, 0x73, 0x65, 0x74, 0x63, 0x74, 0x64, 0x73, 0x65, 0x73, 0x64, 0x74, 0x66, 0x77, 0x67, 0x77, 0x66, 0x77, 0x6B, 0x7B, 0x6C, 0x7B, 0x6B, 0x7A, 0x6C, 0x7C, 0x6B, 0x7A, 0x6C, 0x76, 0x6E, 0x6D, 0x69, 0x60, 0x5E, 0x57, 0x4F, 0x58, 0x4F, 0x66, 0x5C, 0x6F, 0x62, 0x70, 0x63, 0x77, 0x70, 0x7C, 0x6A, 0x7B, 0x6C, 0x7C, 0x6D, 0x7D, 0x6B, 0x76, 0x67, 0x7A, 0x6A, 0x7F, 0x6E, 0x7F, 0x6E, 0x7E, 0x6E, 0x7D, 0x6D, 0x7E, 0x6F, 0x7E, 0x6D, 0x7E, 0x6E, 0x7F, 0x72, 0x82, 0x73, 0x7C, 0x6E, 0x7C, 0x6F, 0x7D, 0x70, 0x6D, 0x6D, 0x5C, 0x59, 0x48, 0x40, 0x3F, 0x3B, 0x3B, 0x35, 0x36, 0x32, 0x5D, 0x5A, 0x76, 0x68, 0x79, 0x6B, 0x7B, 0x6B, 0x80, 0x6F, 0x7C, 0x6A, 0x80, 0x6E, 0x81, 0x70, 0x7E, 0x6E, 0x7D, 0x70, 0x80, 0x70, 0x7F, 0x71, 0x7F, 0x6F, 0x82, 0x71, 0x86, 0x75, 0x85, 0x74, 0x83, 0x73, 0x84, 0x79, 0x87, 0x79, 0x85, 0x75, 0x7E, 0x71, 0x80, 0x74, 0x82, 0x74, 0x83, 0x74, 0x81, 0x74, 0x82, 0x74, 0x87, 0x7A, 0x83, 0x77, 0x84, 0x77, 0x85, 0x7B, 0x85, 0x7C, 0x88, 0x7D, 0x8C, 0x84, 0x8D, 0x82, 0x89, 0x80, 0x87, 0x7D, 0x8B, 0x7F, 0x96, 0x8D, 0x8F, 0x84, 0x89, 0x82, 0x8C, 0x85, 0x91, 0x89, 0x91, 0x84, 0x85, 0x79, 0x83, 0x79, 0x80, 0x77, 0x88, 0x81, 0x8C, 0x82, 0x90, 0x85, 0x89, 0x7F, 0x8C, 0x81, 0x87, 0x78, 0x84, 0x78, 0x87, 0x7C, 0x89, 0x7B, 0x83, 0x76, 0x85, 0x78, 0x81, 0x76, 0x86, 0x79, 0x85, 0x7B, 0x85, 0x78, 0x87, 0x7C, 0x88, 0x7C, 0x86, 0x7E, 0x8B, 0x7D, 0x87, 0x7A, 0x85, 0x78, 0x7E, 0x74, 0x91, 0x90, 0x91, 0x85, 0x89, 0x82, 0x83, 0x75, 0x83, 0x77, 0x81, 0x75, 0x84, 0x7A, 0x7D, 0x70, 0x80, 0x74, 0x82, 0x77, 0x7F, 0x72, 0x81, 0x72, 0x7D, 0x71, 0x7F, 0x70, 0x7E, 0x70, 0x7D, 0x70, 0x7D, 0x71, 0x7C, 0x6E, 0x79, 0x6C, 0x7D, 0x70, 0x7C, 0x70, 0x7B, 0x6B, 0x79, 0x69, 0x78, 0x6B, 0x7E, 0x6D, 0x7B, 0x6C, 0x7C, 0x70, 0x7E, 0x6F, 0x7B, 0x6F, 0x80, 0x71, 0x81, 0x73, 0x7F, 0x74, 0x7C, 0x70, 0x80, 0x74, 0x7D, 0x72, 0x7A, 0x6E, 0x7A, 0x6C, 0x77, 0x67, 0x78, 0x69, 0x7A, 0x6A, 0x79, 0x68, 0x79, 0x68, 0x75, 0x6B, 0x78, 0x6A, 0x76, 0x68, 0x77, 0x6B, 0x7A, 0x6B, 0x78, 0x6B, 0x7D, 0x6F, 0x7B, 0x6E, 0x75, 0x6A, 0x78, 0x6A, 0x78, 0x69, 0x77, 0x6B, 0x7C, 0x6B, 0x7A, 0x6B, 0x76, 0x69, 0x76, 0x69, 0x7B, 0x6C, 0x79, 0x6D, 0x76, 0x6A, 0x75, 0x66, 0x74, 0x65, 0x74, 0x66, 0x76, 0x6B, 0x7A, 0x6C, 0x76, 0x6B, 0x79, 0x6A, 0x78, 0x6B, 0x78, 0x6A, 0x79, 0x69, 0x79, 0x6A, 0x76, 0x67, 0x76, 0x69, 0x78, 0x6A, 0x76, 0x69, 0x78, 0x6A, 0x79, 0x6A, 0x7A, 0x6B, 0x78, 0x69, 0x7A, 0x6F, 0x7C, 0x71, 0x7A, 0x6D, 0x76, 0x69, 0x77, 0x6A, 0x7A, 0x6D, 0x78, 0x6A, 0x7B, 0x6E, 0x7B, 0x6D, 0x7C, 0x71, 0x7A, 0x6B, 0x74, 0x64, 0x73, 0x63, 0x74, 0x67, 0x78, 0x69, 0x78, 0x6A, 0x77, 0x67, 0x78, 0x67, 0x78, 0x6A, 0x7A, 0x6A, 0x77, 0x67, 0x71, 0x64, 0x70, 0x64, 0x55, 0x56, 0x46, 0x49, 0x47, 0x53, 0x47, 0x4F, 0x43, 0x49, 0x49, 0x55, 0x4D, 0x58, 0x4B, 0x57, 0x42, 0x4B, 0x50, 0x5F, 0x4A, 0x54, 0x4B, 0x58, 0x42, 0x4A, 0x4A, 0x5D, 0x4B, 0x52, 0x44, 0x50, 0x48, 0x50, 0x40, 0x4A, 0x41, 0x46, 0x45, 0x51, 0x44, 0x4B, 0x3D, 0x48, 0x40, 0x47, 0x40, 0x4C, 0x45, 0x4F, 0x47, 0x52, 0x49, 0x54, 0x4E, 0x5B, 0x44, 0x4C, 0x47, 0x52, 0x44, 0x4D, 0x4B, 0x55, 0x40, 0x47, 0x44, 0x4C, 0x42, 0x4C, 0x49, 0x53, 0x46, 0x4F, 0x3E, 0x47, 0x42, 0x4F, 0x42, 0x4B, 0x4A, 0x58, 0x47, 0x50, 0x3D, 0x44, 0x4A, 0x57, 0x44, 0x4D, 0x44, 0x4C, 0x3B, 0x46, 0x3F, 0x46, 0x42, 0x4D, 0x3D, 0x44, 0x3C, 0x45
    },

    {
        0x54, 0x1E, 0x52, 0x1D, 0x54, 0x1E, 0x55, 0x1E, 0x55, 0x1F, 0x57, 0x20, 0x55, 0x1F, 0x53, 0x1F, 0x56, 0x1E, 0x55, 0x1E, 0x55, 0x1F, 0x54, 0x1E, 0x55, 0x1F, 0x55, 0x1F, 0x58, 0x20, 0x56, 0x1F, 0x57, 0x20, 0x57, 0x20, 0x58, 0x21, 0x59, 0x21, 0x5A, 0x21, 0x59, 0x21, 0x5E, 0x22, 0x5C, 0x22, 0x5C, 0x21, 0x5A, 0x21, 0x5B, 0x21, 0x5B, 0x21, 0x5C, 0x21, 0x5A, 0x20, 0x5A, 0x21, 0x59, 0x21, 0x5B, 0x21, 0x5B, 0x20, 0x5B, 0x22, 0x5E, 0x23, 0x56, 0x21, 0x3F, 0x1B, 0x2F, 0x18, 0x2B, 0x16, 0x28, 0x15, 0x25, 0x14, 0x28, 0x17, 0x47, 0x1E, 0x58, 0x22, 0x5D, 0x23, 0x5E, 0x22, 0x5E, 0x22, 0x5D, 0x22, 0x5E, 0x23, 0x5F, 0x23, 0x61, 0x23, 0x5E, 0x23, 0x5F, 0x23, 0x5E, 0x23, 0x5E, 0x23, 0x60, 0x24, 0x64, 0x26, 0x63, 0x26, 0x64, 0x26, 0x66, 0x26, 0x67, 0x27, 0x67, 0x27, 0x68, 0x28, 0x67, 0x2C, 0x6C, 0x3C, 0x5E, 0x32, 0x48, 0x26, 0x3E, 0x20, 0x36, 0x1C, 0x43, 0x20, 0x5B, 0x23, 0x5F, 0x24, 0x69, 0x2A, 0x69, 0x27, 0x64, 0x26, 0x68, 0x28, 0x65, 0x26, 0x67, 0x26, 0x67, 0x27, 0x67, 0x26, 0x66, 0x26, 0x69, 0x28, 0x69, 0x27, 0x69, 0x28, 0x6A, 0x28, 0x6A, 0x27, 0x6B, 0x29, 0x6D, 0x29, 0x69, 0x27, 0x66, 0x26, 0x61, 0x2B, 0x5A, 0x2F, 0x43, 0x22, 0x36, 0x1D, 0x33, 0x1C, 0x2E, 0x1A, 0x29, 0x18, 0x43, 0x20, 0x62, 0x25, 0x63, 0x25, 0x68, 0x27, 0x69, 0x28, 0x68, 0x26, 0x66, 0x26, 0x68, 0x27, 0x69, 0x27, 0x68, 0x27, 0x6B, 0x27, 0x67, 0x28, 0x69, 0x28, 0x6C, 0x28, 0x6B, 0x2A, 0x6A, 0x29, 0x6B, 0x27, 0x6D, 0x2B, 0x70, 0x2C, 0x6E, 0x2D, 0x6D, 0x2B, 0x6C, 0x29, 0x6D, 0x2A, 0x6E, 0x29, 0x69, 0x29, 0x6D, 0x29, 0x71, 0x2E, 0x79, 0x31, 0x70, 0x2E, 0x74, 0x33, 0x83, 0x39, 0x74, 0x2E, 0x75, 0x31, 0x77, 0x31, 0x79, 0x33, 0x88, 0x3F, 0x8B, 0x3A, 0x7F, 0x36, 0x7A, 0x34, 0x7A, 0x32, 0x79, 0x31, 0x78, 0x31, 0x77, 0x31, 0x73, 0x2F, 0x73, 0x2D, 0x71, 0x2D, 0x76, 0x2F, 0x75, 0x30, 0x7D, 0x35, 0x76, 0x30, 0x73, 0x2F, 0x74, 0x2D, 0x71, 0x2C, 0x73, 0x2F, 0x7B, 0x33, 0x7A, 0x31, 0x71, 0x2E, 0x6E, 0x2C, 0x6F, 0x2C, 0x71, 0x2E, 0x75, 0x31, 0x80, 0x34, 0x76, 0x2F, 0x70, 0x2D, 0x71, 0x2B, 0x6E, 0x2A, 0x6E, 0x2C, 0x6E, 0x2B, 0x73, 0x30, 0x75, 0x2F, 0x70, 0x2D, 0x79, 0x33, 0x7C, 0x37, 0x73, 0x2E, 0x6E, 0x2B, 0x6E, 0x2D, 0x76, 0x2F, 0x6F, 0x2B, 0x6B, 0x2A, 0x6F, 0x2D, 0x6B, 0x2A, 0x69, 0x29, 0x6A, 0x29, 0x68, 0x29, 0x66, 0x28, 0x68, 0x28, 0x68, 0x27, 0x68, 0x28, 0x6F, 0x2C, 0x67, 0x27, 0x66, 0x26, 0x66, 0x27, 0x63, 0x25, 0x64, 0x26, 0x69, 0x29, 0x6A, 0x28, 0x68, 0x28, 0x6D, 0x2D, 0x6F, 0x2D, 0x78, 0x31, 0x6B, 0x2B, 0x6D, 0x2B, 0x6B, 0x2A, 0x6A, 0x2A, 0x67, 0x29, 0x65, 0x27, 0x64, 0x27, 0x64, 0x26, 0x65, 0x26, 0x64, 0x26, 0x62, 0x26, 0x63, 0x25, 0x65, 0x27, 0x65, 0x26, 0x61, 0x25, 0x60, 0x25, 0x64, 0x27, 0x60, 0x25, 0x64, 0x27, 0x65, 0x27, 0x61, 0x26, 0x65, 0x27, 0x68, 0x27, 0x68, 0x29, 0x64, 0x28, 0x64, 0x27, 0x65, 0x27, 0x64, 0x27, 0x65, 0x27, 0x64, 0x26, 0x63, 0x26, 0x62, 0x26, 0x64, 0x25, 0x61, 0x27, 0x64, 0x26, 0x63, 0x25, 0x67, 0x28, 0x65, 0x28, 0x65, 0x27, 0x67, 0x27, 0x63, 0x26, 0x63, 0x25, 0x64, 0x26, 0x63, 0x26, 0x63, 0x25, 0x65, 0x27, 0x65, 0x28, 0x67, 0x28, 0x64, 0x27, 0x65, 0x28, 0x64, 0x27, 0x61, 0x26, 0x62, 0x26, 0x62, 0x25, 0x62, 0x24, 0x62, 0x25, 0x62, 0x25, 0x65, 0x26, 0x64, 0x26, 0x5F, 0x24, 0x61, 0x25, 0x61, 0x25, 0x5F, 0x24, 0x62, 0x25, 0x60, 0x24, 0x60, 0x24, 0x5F, 0x23, 0x63, 0x25, 0x61, 0x24, 0x5F, 0x24, 0x5F, 0x24, 0x57, 0x28, 0x4D, 0x29, 0x51, 0x2C, 0x5A, 0x2F, 0x4D, 0x29, 0x57, 0x2F, 0x4A, 0x28, 0x50, 0x2B, 0x44, 0x25, 0x50, 0x2A, 0x49, 0x28, 0x4C, 0x28, 0x45, 0x26, 0x51, 0x2C, 0x4B, 0x28, 0x55, 0x2E, 0x50, 0x29, 0x48, 0x27, 0x4D, 0x28, 0x51, 0x2C, 0x55, 0x2C, 0x4A, 0x28, 0x4B, 0x27, 0x51, 0x2C, 0x4E, 0x28, 0x4B, 0x2B, 0x50, 0x2B, 0x50, 0x2B, 0x46, 0x25, 0x4B, 0x28, 0x46, 0x27, 0x54, 0x2C, 0x4E, 0x29, 0x4D, 0x29, 0x4F, 0x2B, 0x4E, 0x2A, 0x4A, 0x28, 0x44, 0x25, 0x4E, 0x29, 0x4E, 0x29, 0x4F, 0x2B, 0x46, 0x25, 0x3F, 0x23, 0x4D, 0x29, 0x48, 0x26, 0x44, 0x24, 0x44, 0x25, 0x48, 0x26, 0x4D, 0x2A, 0x4E, 0x29, 0x46, 0x27
    },

    {
        0x63, 0x56, 0x61, 0x55, 0x63, 0x57, 0x65, 0x57, 0x65, 0x59, 0x65, 0x59, 0x64, 0x57, 0x65, 0x57, 0x68, 0x59, 0x65, 0x55, 0x67, 0x59, 0x67, 0x57, 0x67, 0x59, 0x67, 0x5A, 0x69, 0x5B, 0x68, 0x59, 0x69, 0x5D, 0x6A, 0x5A, 0x6A, 0x5C, 0x69, 0x5C, 0x6C, 0x5C, 0x6D, 0x60, 0x70, 0x61, 0x6E, 0x61, 0x6D, 0x5E, 0x6D, 0x5F, 0x6F, 0x5F, 0x6C, 0x5E, 0x6E, 0x5E, 0x6C, 0x5C, 0x6D, 0x5D, 0x6D, 0x5E, 0x6F, 0x5F, 0x6D, 0x5E, 0x6E, 0x5D, 0x6F, 0x60, 0x68, 0x58, 0x50, 0x41, 0x38, 0x30, 0x31, 0x2B, 0x2D, 0x28, 0x2A, 0x26, 0x32, 0x30, 0x58, 0x52, 0x6A, 0x5E, 0x70, 0x62, 0x72, 0x61, 0x72, 0x63, 0x72, 0x62, 0x72, 0x60, 0x73, 0x65, 0x74, 0x65, 0x73, 0x61, 0x73, 0x62, 0x73, 0x63, 0x73, 0x62, 0x74, 0x67, 0x77, 0x67, 0x78, 0x69, 0x79, 0x6A, 0x7B, 0x6C, 0x7B, 0x6D, 0x7B, 0x6C, 0x78, 0x6C, 0x75, 0x6C, 0x69, 0x6A, 0x59, 0x55, 0x47, 0x41, 0x43, 0x3C, 0x3C, 0x35, 0x46, 0x46, 0x6A, 0x60, 0x73, 0x66, 0x7A, 0x6E, 0x7F, 0x6C, 0x76, 0x69, 0x7C, 0x6E, 0x7A, 0x6A, 0x7C, 0x6C, 0x7D, 0x6D, 0x7D, 0x6C, 0x7D, 0x6D, 0x7D, 0x6E, 0x7E, 0x6E, 0x7E, 0x6F, 0x81, 0x6F, 0x80, 0x6F, 0x80, 0x72, 0x80, 0x71, 0x7D, 0x6E, 0x79, 0x69, 0x72, 0x63, 0x5A, 0x54, 0x47, 0x40, 0x3C, 0x36, 0x38, 0x34, 0x34, 0x30, 0x2D, 0x2B, 0x48, 0x4B, 0x72, 0x67, 0x78, 0x68, 0x7D, 0x6D, 0x7E, 0x70, 0x7E, 0x6C, 0x7D, 0x6C, 0x7E, 0x6F, 0x7F, 0x6F, 0x80, 0x6F, 0x7F, 0x6E, 0x7C, 0x6E, 0x7E, 0x6F, 0x81, 0x72, 0x82, 0x71, 0x81, 0x71, 0x81, 0x71, 0x82, 0x73, 0x82, 0x74, 0x80, 0x74, 0x82, 0x74, 0x80, 0x71, 0x80, 0x73, 0x84, 0x73, 0x80, 0x73, 0x81, 0x73, 0x81, 0x78, 0x87, 0x7B, 0x81, 0x75, 0x86, 0x7E, 0x8B, 0x88, 0x84, 0x79, 0x86, 0x7B, 0x8A, 0x7E, 0x88, 0x7E, 0x99, 0x99, 0x95, 0x8D, 0x8F, 0x84, 0x8E, 0x83, 0x8D, 0x84, 0x8E, 0x7F, 0x8E, 0x81, 0x89, 0x7F, 0x88, 0x7B, 0x89, 0x78, 0x85, 0x7A, 0x8D, 0x7E, 0x88, 0x7B, 0x8A, 0x81, 0x8B, 0x7E, 0x85, 0x79, 0x87, 0x78, 0x86, 0x77, 0x85, 0x7B, 0x8B, 0x83, 0x8A, 0x7F, 0x83, 0x77, 0x80, 0x74, 0x7E, 0x73, 0x85, 0x79, 0x82, 0x7B, 0x8E, 0x83, 0x86, 0x78, 0x82, 0x74, 0x85, 0x75, 0x83, 0x74, 0x7F, 0x71, 0x80, 0x71, 0x83, 0x78, 0x86, 0x7B, 0x81, 0x74, 0x87, 0x7F, 0x8A, 0x85, 0x7F, 0x76, 0x7F, 0x72, 0x80, 0x76, 0x87, 0x79, 0x83, 0x73, 0x7D, 0x71, 0x81, 0x77, 0x80, 0x73, 0x7D, 0x6F, 0x7D, 0x70, 0x7C, 0x6F, 0x7B, 0x6E, 0x7B, 0x6D, 0x7C, 0x6F, 0x79, 0x6D, 0x80, 0x75, 0x7C, 0x6B, 0x79, 0x6B, 0x7B, 0x6C, 0x77, 0x69, 0x77, 0x6A, 0x7C, 0x70, 0x7F, 0x70, 0x7D, 0x6E, 0x81, 0x79, 0x82, 0x77, 0x84, 0x7A, 0x7D, 0x71, 0x81, 0x72, 0x81, 0x72, 0x7F, 0x70, 0x7E, 0x6F, 0x79, 0x6A, 0x75, 0x69, 0x74, 0x68, 0x78, 0x6A, 0x79, 0x68, 0x78, 0x69, 0x76, 0x67, 0x79, 0x6C, 0x78, 0x69, 0x76, 0x68, 0x75, 0x66, 0x77, 0x68, 0x73, 0x65, 0x79, 0x6B, 0x77, 0x6A, 0x75, 0x68, 0x78, 0x6A, 0x7D, 0x6E, 0x7C, 0x6E, 0x75, 0x6A, 0x76, 0x6A, 0x77, 0x6A, 0x79, 0x6B, 0x79, 0x6B, 0x78, 0x6A, 0x77, 0x68, 0x77, 0x69, 0x79, 0x6A, 0x7C, 0x6D, 0x7A, 0x6B, 0x7B, 0x6C, 0x7C, 0x6D, 0x78, 0x6A, 0x79, 0x6C, 0x7C, 0x6C, 0x79, 0x6A, 0x7A, 0x69, 0x77, 0x6A, 0x77, 0x69, 0x77, 0x69, 0x7A, 0x6B, 0x7A, 0x6C, 0x7B, 0x6D, 0x77, 0x6A, 0x77, 0x6A, 0x77, 0x6A, 0x74, 0x67, 0x76, 0x69, 0x74, 0x66, 0x77, 0x68, 0x75, 0x66, 0x75, 0x67, 0x79, 0x6B, 0x78, 0x69, 0x74, 0x64, 0x76, 0x66, 0x77, 0x68, 0x75, 0x66, 0x77, 0x68, 0x77, 0x67, 0x78, 0x67, 0x74, 0x65, 0x79, 0x69, 0x77, 0x67, 0x74, 0x65, 0x72, 0x64, 0x5D, 0x5E, 0x4D, 0x54, 0x4C, 0x58, 0x52, 0x5E, 0x46, 0x4D, 0x4D, 0x59, 0x42, 0x4A, 0x48, 0x52, 0x41, 0x4A, 0x47, 0x4F, 0x46, 0x51, 0x46, 0x4E, 0x41, 0x4D, 0x4A, 0x56, 0x44, 0x4D, 0x4E, 0x5D, 0x48, 0x50, 0x46, 0x51, 0x47, 0x4E, 0x4D, 0x5C, 0x4D, 0x55, 0x44, 0x4F, 0x43, 0x4B, 0x4B, 0x59, 0x44, 0x48, 0x45, 0x55, 0x48, 0x50, 0x47, 0x53, 0x41, 0x4B, 0x47, 0x4F, 0x44, 0x4F, 0x4E, 0x5A, 0x47, 0x4E, 0x48, 0x53, 0x47, 0x4E, 0x44, 0x4E, 0x42, 0x4B, 0x3F, 0x48, 0x47, 0x54, 0x45, 0x4D, 0x45, 0x4F, 0x3C, 0x43, 0x3A, 0x45, 0x45, 0x4F, 0x43, 0x4D, 0x42, 0x4B, 0x3E, 0x49, 0x42, 0x4C, 0x48, 0x53, 0x47, 0x51, 0x3E, 0x48
    },

    {
        0x54, 0x1E, 0x54, 0x1E, 0x55, 0x1E, 0x50, 0x1D, 0x54, 0x1E, 0x55, 0x1E, 0x57, 0x1F, 0x56, 0x1E, 0x56, 0x1E, 0x53, 0x1E, 0x55, 0x1F, 0x55, 0x1E, 0x56, 0x1F, 0x56, 0x1F, 0x58, 0x20, 0x57, 0x20, 0x58, 0x1F, 0x57, 0x20, 0x58, 0x21, 0x57, 0x20, 0x5A, 0x21, 0x59, 0x21, 0x5B, 0x21, 0x5B, 0x22, 0x5A, 0x21, 0x5A, 0x21, 0x59, 0x21, 0x5B, 0x21, 0x5A, 0x21, 0x5A, 0x21, 0x59, 0x20, 0x58, 0x20, 0x58, 0x20, 0x5B, 0x21, 0x5B, 0x21, 0x5A, 0x21, 0x59, 0x21, 0x53, 0x1F, 0x41, 0x1A, 0x31, 0x17, 0x2D, 0x16, 0x33, 0x19, 0x47, 0x1E, 0x58, 0x22, 0x5D, 0x23, 0x5F, 0x24, 0x5E, 0x23, 0x5D, 0x23, 0x5F, 0x24, 0x5F, 0x24, 0x61, 0x24, 0x5F, 0x23, 0x60, 0x22, 0x60, 0x23, 0x62, 0x25, 0x62, 0x25, 0x62, 0x24, 0x64, 0x26, 0x63, 0x26, 0x63, 0x25, 0x64, 0x26, 0x66, 0x26, 0x68, 0x27, 0x66, 0x28, 0x60, 0x2F, 0x52, 0x2C, 0x3D, 0x20, 0x35, 0x1D, 0x32, 0x1B, 0x2E, 0x1A, 0x30, 0x1B, 0x54, 0x23, 0x61, 0x25, 0x64, 0x25, 0x67, 0x26, 0x67, 0x26, 0x68, 0x27, 0x6A, 0x27, 0x68, 0x28, 0x6C, 0x28, 0x6D, 0x28, 0x68, 0x27, 0x6A, 0x28, 0x6B, 0x28, 0x6A, 0x28, 0x6C, 0x29, 0x69, 0x27, 0x69, 0x27, 0x68, 0x27, 0x68, 0x27, 0x64, 0x26, 0x5C, 0x24, 0x42, 0x22, 0x3B, 0x1F, 0x34, 0x1C, 0x2F, 0x1A, 0x2E, 0x1A, 0x28, 0x17, 0x3E, 0x1F, 0x5E, 0x26, 0x66, 0x27, 0x68, 0x26, 0x6A, 0x28, 0x68, 0x26, 0x69, 0x27, 0x68, 0x26, 0x68, 0x27, 0x68, 0x27, 0x66, 0x26, 0x66, 0x26, 0x6A, 0x2A, 0x6A, 0x28, 0x6A, 0x28, 0x6F, 0x2A, 0x6F, 0x29, 0x6C, 0x29, 0x6A, 0x28, 0x6A, 0x2B, 0x6D, 0x2B, 0x6E, 0x29, 0x70, 0x2A, 0x6C, 0x28, 0x6C, 0x29, 0x6D, 0x29, 0x6C, 0x29, 0x6C, 0x2A, 0x6D, 0x2B, 0x70, 0x2D, 0x74, 0x2F, 0x72, 0x2E, 0x71, 0x2E, 0x74, 0x2F, 0x79, 0x33, 0x79, 0x32, 0x75, 0x30, 0x7B, 0x33, 0x79, 0x34, 0x81, 0x39, 0x79, 0x31, 0x76, 0x30, 0x7B, 0x34, 0x80, 0x34, 0x7C, 0x33, 0x71, 0x2E, 0x79, 0x31, 0x76, 0x2E, 0x78, 0x32, 0x76, 0x31, 0x76, 0x30, 0x71, 0x2C, 0x70, 0x2E, 0x76, 0x2F, 0x70, 0x2E, 0x74, 0x2F, 0x77, 0x2F, 0x72, 0x30, 0x76, 0x32, 0x7A, 0x33, 0x75, 0x2D, 0x6F, 0x2D, 0x6E, 0x2C, 0x6A, 0x28, 0x68, 0x29, 0x6F, 0x2B, 0x6F, 0x2A, 0x6D, 0x2A, 0x6D, 0x2B, 0x6D, 0x2D, 0x74, 0x2E, 0x72, 0x2D, 0x70, 0x2D, 0x69, 0x2A, 0x70, 0x2D, 0x6E, 0x2D, 0x70, 0x2A, 0x6A, 0x29, 0x6A, 0x29, 0x6D, 0x2C, 0x72, 0x2E, 0x70, 0x2E, 0x6A, 0x2A, 0x6C, 0x2B, 0x69, 0x28, 0x68, 0x27, 0x69, 0x29, 0x67, 0x27, 0x68, 0x28, 0x66, 0x26, 0x64, 0x26, 0x69, 0x28, 0x67, 0x28, 0x62, 0x25, 0x69, 0x28, 0x67, 0x27, 0x69, 0x28, 0x6C, 0x2B, 0x6A, 0x2B, 0x6A, 0x29, 0x68, 0x2A, 0x6A, 0x28, 0x6D, 0x2B, 0x6F, 0x2B, 0x6A, 0x29, 0x69, 0x28, 0x64, 0x26, 0x66, 0x27, 0x64, 0x25, 0x61, 0x25, 0x64, 0x27, 0x61, 0x24, 0x62, 0x26, 0x66, 0x27, 0x65, 0x27, 0x64, 0x26, 0x60, 0x25, 0x5F, 0x25, 0x65, 0x27, 0x66, 0x28, 0x65, 0x28, 0x66, 0x27, 0x66, 0x27, 0x67, 0x29, 0x66, 0x27, 0x64, 0x27, 0x64, 0x27, 0x66, 0x27, 0x67, 0x28, 0x64, 0x26, 0x66, 0x26, 0x63, 0x26, 0x64, 0x27, 0x64, 0x27, 0x64, 0x27, 0x63, 0x27, 0x65, 0x27, 0x69, 0x29, 0x66, 0x27, 0x64, 0x27, 0x64, 0x26, 0x63, 0x25, 0x61, 0x25, 0x61, 0x25, 0x61, 0x25, 0x62, 0x26, 0x63, 0x27, 0x63, 0x26, 0x65, 0x26, 0x63, 0x26, 0x62, 0x26, 0x60, 0x26, 0x63, 0x26, 0x63, 0x25, 0x61, 0x25, 0x63, 0x25, 0x60, 0x25, 0x61, 0x24, 0x5F, 0x24, 0x5D, 0x24, 0x5F, 0x25, 0x62, 0x25, 0x60, 0x25, 0x60, 0x25, 0x62, 0x25, 0x62, 0x24, 0x5F, 0x24, 0x5E, 0x24, 0x60, 0x24, 0x5E, 0x25, 0x5E, 0x24, 0x61, 0x2F, 0x4A, 0x28, 0x53, 0x2C, 0x4E, 0x29, 0x46, 0x27, 0x4D, 0x29, 0x49, 0x28, 0x57, 0x2E, 0x52, 0x2C, 0x56, 0x2D, 0x4E, 0x2B, 0x59, 0x2E, 0x48, 0x27, 0x53, 0x2E, 0x4C, 0x28, 0x54, 0x2D, 0x4D, 0x29, 0x51, 0x2D, 0x49, 0x27, 0x55, 0x2D, 0x4B, 0x27, 0x4A, 0x28, 0x4B, 0x27, 0x50, 0x2A, 0x4A, 0x27, 0x50, 0x2C, 0x4C, 0x28, 0x53, 0x2D, 0x49, 0x27, 0x50, 0x2A, 0x45, 0x26, 0x55, 0x2E, 0x42, 0x24, 0x45, 0x25, 0x40, 0x23, 0x4F, 0x2A, 0x51, 0x2A, 0x4B, 0x28, 0x4A, 0x28, 0x44, 0x25, 0x4C, 0x29, 0x4C, 0x28, 0x4E, 0x2A, 0x50, 0x29, 0x4C, 0x28, 0x48, 0x26, 0x40, 0x24, 0x48, 0x25, 0x47, 0x27, 0x47, 0x26, 0x3E, 0x22
    },

    {
        0x62, 0x57, 0x63, 0x57, 0x64, 0x56, 0x5E, 0x52, 0x63, 0x57, 0x65, 0x58, 0x68, 0x5A, 0x66, 0x57, 0x65, 0x58, 0x64, 0x57, 0x66, 0x5A, 0x68, 0x59, 0x69, 0x59, 0x68, 0x5A, 0x68, 0x5B, 0x68, 0x5A, 0x6A, 0x5B, 0x69, 0x5B, 0x69, 0x5B, 0x67, 0x5B, 0x6B, 0x5E, 0x6C, 0x5D, 0x6E, 0x5F, 0x6D, 0x5E, 0x6D, 0x5E, 0x6D, 0x5D, 0x6B, 0x5E, 0x6C, 0x5E, 0x6E, 0x5E, 0x70, 0x60, 0x6C, 0x5D, 0x6B, 0x5C, 0x6A, 0x5C, 0x6D, 0x5E, 0x6E, 0x5D, 0x6F, 0x5F, 0x6E, 0x5E, 0x68, 0x59, 0x55, 0x47, 0x43, 0x3A, 0x3D, 0x36, 0x46, 0x41, 0x5E, 0x56, 0x6B, 0x60, 0x6D, 0x60, 0x72, 0x63, 0x71, 0x62, 0x6F, 0x60, 0x73, 0x64, 0x73, 0x64, 0x73, 0x63, 0x73, 0x64, 0x73, 0x61, 0x74, 0x64, 0x76, 0x66, 0x75, 0x66, 0x79, 0x66, 0x78, 0x69, 0x75, 0x64, 0x77, 0x68, 0x79, 0x68, 0x7B, 0x6A, 0x7C, 0x6B, 0x77, 0x6B, 0x67, 0x5F, 0x53, 0x4E, 0x42, 0x3A, 0x3B, 0x35, 0x38, 0x33, 0x33, 0x2E, 0x35, 0x34, 0x60, 0x5D, 0x72, 0x66, 0x77, 0x67, 0x7D, 0x6C, 0x7B, 0x6D, 0x7D, 0x6C, 0x81, 0x6F, 0x7D, 0x6E, 0x82, 0x71, 0x85, 0x72, 0x81, 0x6D, 0x7D, 0x6D, 0x80, 0x71, 0x81, 0x71, 0x7E, 0x6E, 0x7C, 0x6F, 0x7F, 0x6D, 0x7B, 0x6B, 0x7E, 0x6F, 0x7E, 0x6D, 0x6D, 0x5A, 0x4A, 0x42, 0x42, 0x3C, 0x3A, 0x36, 0x38, 0x32, 0x34, 0x30, 0x2D, 0x29, 0x46, 0x4B, 0x73, 0x68, 0x78, 0x6C, 0x7E, 0x6C, 0x7C, 0x6E, 0x7E, 0x6F, 0x7E, 0x6D, 0x7C, 0x6C, 0x7D, 0x6E, 0x7E, 0x6E, 0x7E, 0x6D, 0x7C, 0x6E, 0x7F, 0x71, 0x82, 0x70, 0x81, 0x72, 0x83, 0x75, 0x82, 0x72, 0x81, 0x73, 0x7F, 0x6E, 0x7D, 0x71, 0x7F, 0x74, 0x82, 0x74, 0x84, 0x74, 0x80, 0x71, 0x83, 0x72, 0x81, 0x73, 0x7E, 0x71, 0x80, 0x73, 0x80, 0x74, 0x7F, 0x75, 0x88, 0x79, 0x82, 0x7A, 0x83, 0x75, 0x86, 0x79, 0x8A, 0x82, 0x86, 0x7C, 0x87, 0x7A, 0x88, 0x7E, 0x87, 0x7E, 0x89, 0x81, 0x8B, 0x7F, 0x89, 0x7D, 0x8C, 0x84, 0x91, 0x87, 0x8E, 0x84, 0x89, 0x7A, 0x87, 0x7C, 0x87, 0x79, 0x89, 0x7E, 0x89, 0x7E, 0x8B, 0x7D, 0x84, 0x77, 0x82, 0x78, 0x84, 0x78, 0x83, 0x76, 0x87, 0x7A, 0x86, 0x7D, 0x86, 0x7E, 0x87, 0x7C, 0x88, 0x7D, 0x86, 0x77, 0x84, 0x79, 0x7F, 0x71, 0x7F, 0x6E, 0x80, 0x73, 0x84, 0x75, 0x83, 0x72, 0x82, 0x72, 0x85, 0x77, 0x81, 0x76, 0x84, 0x77, 0x85, 0x77, 0x84, 0x76, 0x7A, 0x6F, 0x83, 0x78, 0x81, 0x75, 0x83, 0x74, 0x7E, 0x72, 0x7F, 0x71, 0x81, 0x75, 0x82, 0x77, 0x82, 0x78, 0x7F, 0x71, 0x7E, 0x71, 0x7A, 0x6C, 0x7B, 0x6D, 0x7B, 0x70, 0x7C, 0x70, 0x7B, 0x6D, 0x7C, 0x6E, 0x7B, 0x6C, 0x7C, 0x6F, 0x7C, 0x6D, 0x79, 0x6A, 0x7D, 0x70, 0x7B, 0x6A, 0x7C, 0x6F, 0x80, 0x71, 0x7E, 0x73, 0x7A, 0x6D, 0x78, 0x70, 0x7E, 0x70, 0x80, 0x73, 0x7D, 0x72, 0x7F, 0x6F, 0x7C, 0x70, 0x77, 0x6B, 0x79, 0x6A, 0x79, 0x69, 0x77, 0x66, 0x75, 0x69, 0x77, 0x67, 0x77, 0x6A, 0x78, 0x6C, 0x7A, 0x6D, 0x79, 0x69, 0x75, 0x66, 0x73, 0x67, 0x78, 0x6A, 0x7A, 0x6C, 0x79, 0x6D, 0x78, 0x6A, 0x7A, 0x6D, 0x78, 0x6C, 0x79, 0x6B, 0x78, 0x69, 0x76, 0x6A, 0x78, 0x6B, 0x7A, 0x6B, 0x78, 0x6B, 0x7A, 0x6B, 0x78, 0x6A, 0x78, 0x6A, 0x77, 0x6A, 0x79, 0x6A, 0x77, 0x6D, 0x77, 0x6B, 0x7C, 0x6D, 0x7B, 0x6C, 0x79, 0x69, 0x78, 0x68, 0x77, 0x68, 0x76, 0x65, 0x76, 0x68, 0x74, 0x66, 0x75, 0x67, 0x79, 0x6A, 0x78, 0x6A, 0x77, 0x69, 0x75, 0x68, 0x75, 0x67, 0x76, 0x66, 0x76, 0x68, 0x74, 0x68, 0x73, 0x67, 0x76, 0x68, 0x73, 0x65, 0x75, 0x65, 0x72, 0x64, 0x71, 0x63, 0x75, 0x67, 0x77, 0x68, 0x75, 0x64, 0x75, 0x67, 0x77, 0x68, 0x77, 0x67, 0x73, 0x66, 0x74, 0x66, 0x77, 0x66, 0x71, 0x63, 0x6E, 0x61, 0x5E, 0x60, 0x42, 0x49, 0x4C, 0x59, 0x48, 0x4E, 0x43, 0x4D, 0x48, 0x52, 0x46, 0x52, 0x53, 0x60, 0x49, 0x57, 0x4E, 0x56, 0x48, 0x58, 0x4F, 0x57, 0x3F, 0x47, 0x4D, 0x5B, 0x45, 0x4D, 0x4C, 0x59, 0x45, 0x4C, 0x47, 0x55, 0x42, 0x4C, 0x4E, 0x5A, 0x45, 0x4B, 0x46, 0x52, 0x44, 0x4E, 0x48, 0x55, 0x46, 0x4D, 0x4B, 0x58, 0x45, 0x4D, 0x4B, 0x56, 0x40, 0x4B, 0x45, 0x4C, 0x40, 0x4A, 0x49, 0x53, 0x3E, 0x46, 0x3F, 0x48, 0x3E, 0x49, 0x4D, 0x57, 0x4C, 0x57, 0x44, 0x4C, 0x44, 0x4E, 0x40, 0x4A, 0x48, 0x52, 0x49, 0x56, 0x47, 0x51, 0x47, 0x52, 0x44, 0x4E, 0x3F, 0x45, 0x3B, 0x45, 0x3F, 0x46, 0x41, 0x4C, 0x41, 0x49, 0x39, 0x45
    },

    {
        0x55, 0x1E, 0x54, 0x1E, 0x53, 0x1E, 0x55, 0x1F, 0x54, 0x1E, 0x55, 0x1F, 0x55, 0x1E, 0x54, 0x1F, 0x53, 0x1E, 0x53, 0x1E, 0x57, 0x1F, 0x56, 0x1F, 0x56, 0x1F, 0x57, 0x20, 0x57, 0x1F, 0x58, 0x20, 0x58, 0x20, 0x57, 0x20, 0x5C, 0x21, 0x5A, 0x21, 0x5A, 0x21, 0x5A, 0x21, 0x59, 0x21, 0x5E, 0x22, 0x5B, 0x21, 0x5C, 0x21, 0x5F, 0x22, 0x59, 0x1F, 0x5B, 0x21, 0x59, 0x20, 0x58, 0x20, 0x5A, 0x20, 0x57, 0x20, 0x59, 0x20, 0x5B, 0x22, 0x5C, 0x22, 0x5C, 0x21, 0x5A, 0x21, 0x58, 0x21, 0x55, 0x1F, 0x56, 0x20, 0x5C, 0x24, 0x5A, 0x22, 0x5E, 0x23, 0x60, 0x23, 0x60, 0x23, 0x61, 0x24, 0x61, 0x24, 0x61, 0x24, 0x5E, 0x24, 0x5C, 0x23, 0x62, 0x23, 0x5D, 0x23, 0x60, 0x24, 0x64, 0x25, 0x63, 0x25, 0x60, 0x25, 0x63, 0x24, 0x60, 0x24, 0x60, 0x24, 0x66, 0x27, 0x67, 0x26, 0x63, 0x25, 0x63, 0x27, 0x4F, 0x24, 0x3E, 0x1F, 0x33, 0x1B, 0x31, 0x1A, 0x2F, 0x1A, 0x29, 0x17, 0x2A, 0x18, 0x51, 0x22, 0x5E, 0x23, 0x62, 0x24, 0x67, 0x26, 0x69, 0x27, 0x6A, 0x27, 0x68, 0x26, 0x67, 0x27, 0x6E, 0x2A, 0x6C, 0x28, 0x69, 0x28, 0x6A, 0x28, 0x6B, 0x28, 0x6A, 0x28, 0x71, 0x2C, 0x69, 0x28, 0x69, 0x28, 0x67, 0x27, 0x6B, 0x29, 0x6C, 0x28, 0x64, 0x25, 0x3F, 0x1E, 0x36, 0x1D, 0x34, 0x1C, 0x34, 0x1C, 0x2B, 0x19, 0x29, 0x18, 0x4D, 0x23, 0x69, 0x29, 0x70, 0x2C, 0x69, 0x27, 0x65, 0x26, 0x65, 0x26, 0x67, 0x27, 0x65, 0x26, 0x68, 0x28, 0x6C, 0x28, 0x6A, 0x27, 0x68, 0x27, 0x6D, 0x29, 0x6E, 0x2A, 0x6C, 0x29, 0x6A, 0x29, 0x71, 0x2B, 0x6B, 0x29, 0x6C, 0x29, 0x6B, 0x2B, 0x72, 0x2C, 0x6E, 0x2A, 0x6C, 0x2A, 0x6B, 0x29, 0x6B, 0x2A, 0x6C, 0x2A, 0x6C, 0x2A, 0x6B, 0x29, 0x6D, 0x29, 0x6D, 0x2A, 0x71, 0x2C, 0x70, 0x2B, 0x70, 0x2D, 0x74, 0x2F, 0x73, 0x2E, 0x74, 0x30, 0x79, 0x30, 0x71, 0x2E, 0x73, 0x2E, 0x74, 0x31, 0x7A, 0x33, 0x74, 0x2F, 0x73, 0x2E, 0x79, 0x34, 0x7C, 0x34, 0x75, 0x2F, 0x72, 0x2E, 0x74, 0x2E, 0x78, 0x2F, 0x78, 0x2F, 0x76, 0x2F, 0x74, 0x2E, 0x6C, 0x2B, 0x6D, 0x2A, 0x6F, 0x2B, 0x71, 0x2B, 0x6F, 0x2E, 0x77, 0x30, 0x70, 0x2C, 0x6D, 0x2A, 0x6B, 0x29, 0x70, 0x2D, 0x6E, 0x29, 0x69, 0x28, 0x69, 0x29, 0x6E, 0x2B, 0x6C, 0x29, 0x6B, 0x2A, 0x78, 0x30, 0x6F, 0x2B, 0x6F, 0x2A, 0x6C, 0x2B, 0x72, 0x2E, 0x6E, 0x2C, 0x71, 0x2D, 0x6F, 0x2B, 0x6F, 0x2B, 0x6C, 0x2A, 0x6A, 0x2B, 0x71, 0x2F, 0x75, 0x2E, 0x72, 0x2F, 0x6D, 0x2A, 0x65, 0x29, 0x69, 0x29, 0x6A, 0x29, 0x69, 0x28, 0x66, 0x27, 0x69, 0x28, 0x68, 0x27, 0x66, 0x26, 0x65, 0x27, 0x6A, 0x28, 0x68, 0x28, 0x66, 0x27, 0x65, 0x27, 0x6A, 0x28, 0x69, 0x27, 0x68, 0x29, 0x6A, 0x28, 0x66, 0x28, 0x69, 0x29, 0x69, 0x28, 0x69, 0x29, 0x67, 0x28, 0x68, 0x28, 0x65, 0x27, 0x65, 0x28, 0x65, 0x26, 0x60, 0x25, 0x63, 0x25, 0x65, 0x27, 0x68, 0x27, 0x66, 0x28, 0x65, 0x27, 0x63, 0x26, 0x62, 0x26, 0x66, 0x27, 0x66, 0x26, 0x64, 0x26, 0x67, 0x28, 0x62, 0x25, 0x65, 0x28, 0x67, 0x29, 0x64, 0x29, 0x65, 0x27, 0x62, 0x27, 0x67, 0x27, 0x64, 0x26, 0x64, 0x26, 0x64, 0x26, 0x64, 0x26, 0x61, 0x25, 0x62, 0x26, 0x63, 0x26, 0x63, 0x27, 0x64, 0x27, 0x68, 0x28, 0x65, 0x26, 0x64, 0x28, 0x5F, 0x24, 0x62, 0x26, 0x62, 0x25, 0x63, 0x26, 0x60, 0x25, 0x62, 0x25, 0x65, 0x28, 0x65, 0x27, 0x62, 0x25, 0x60, 0x25, 0x60, 0x24, 0x62, 0x27, 0x65, 0x27, 0x62, 0x25, 0x61, 0x24, 0x5D, 0x23, 0x5C, 0x23, 0x5D, 0x23, 0x5D, 0x23, 0x5F, 0x24, 0x62, 0x26, 0x63, 0x25, 0x5E, 0x24, 0x62, 0x24, 0x63, 0x26, 0x62, 0x26, 0x60, 0x25, 0x61, 0x25, 0x5F, 0x25, 0x61, 0x25, 0x5D, 0x24, 0x53, 0x29, 0x4A, 0x27, 0x58, 0x2E, 0x5B, 0x2F, 0x4A, 0x28, 0x52, 0x2B, 0x53, 0x2E, 0x5A, 0x2E, 0x48, 0x28, 0x50, 0x2B, 0x51, 0x2D, 0x56, 0x2D, 0x48, 0x26, 0x54, 0x2C, 0x55, 0x2C, 0x58, 0x2E, 0x50, 0x2A, 0x50, 0x2A, 0x4D, 0x2A, 0x54, 0x2B, 0x48, 0x26, 0x4C, 0x29, 0x45, 0x25, 0x52, 0x2C, 0x45, 0x25, 0x4C, 0x29, 0x46, 0x26, 0x4A, 0x27, 0x4C, 0x28, 0x43, 0x23, 0x46, 0x26, 0x53, 0x2B, 0x4D, 0x28, 0x4F, 0x2A, 0x4D, 0x2A, 0x58, 0x2D, 0x48, 0x26, 0x41, 0x24, 0x50, 0x2B, 0x4A, 0x27, 0x4F, 0x2A, 0x4E, 0x29, 0x42, 0x24, 0x45, 0x25, 0x43, 0x24, 0x41, 0x23, 0x47, 0x26, 0x4C, 0x28, 0x53, 0x2C, 0x4E, 0x29, 0x4A, 0x29
    },

    {
        0x63, 0x57, 0x63, 0x56, 0x62, 0x56, 0x63, 0x58, 0x62, 0x57, 0x65, 0x57, 0x62, 0x57, 0x63, 0x56, 0x63, 0x55, 0x65, 0x57, 0x68, 0x5A, 0x69, 0x59, 0x68, 0x5A, 0x68, 0x5B, 0x68, 0x5A, 0x6A, 0x5C, 0x6A, 0x5A, 0x6A, 0x5B, 0x6C, 0x5F, 0x6C, 0x5E, 0x6B, 0x5C, 0x6C, 0x5E, 0x6C, 0x5E, 0x70, 0x62, 0x6C, 0x5F, 0x6E, 0x60, 0x72, 0x62, 0x6D, 0x5D, 0x6E, 0x5F, 0x6B, 0x5D, 0x6A, 0x5C, 0x6C, 0x5E, 0x6C, 0x5C, 0x6D, 0x5D, 0x6E, 0x5F, 0x6F, 0x61, 0x70, 0x60, 0x6B, 0x5D, 0x6A, 0x5C, 0x68, 0x5A, 0x6D, 0x5E, 0x6D, 0x62, 0x71, 0x61, 0x6F, 0x62, 0x72, 0x65, 0x72, 0x63, 0x75, 0x66, 0x77, 0x66, 0x73, 0x63, 0x71, 0x62, 0x70, 0x62, 0x74, 0x65, 0x71, 0x62, 0x74, 0x64, 0x77, 0x68, 0x76, 0x69, 0x77, 0x66, 0x75, 0x66, 0x75, 0x64, 0x75, 0x64, 0x7B, 0x6C, 0x7A, 0x6A, 0x75, 0x67, 0x73, 0x65, 0x5B, 0x4E, 0x45, 0x3C, 0x3B, 0x35, 0x37, 0x32, 0x33, 0x30, 0x30, 0x2B, 0x30, 0x2E, 0x5C, 0x59, 0x71, 0x64, 0x75, 0x69, 0x7C, 0x6C, 0x7E, 0x6E, 0x80, 0x6E, 0x7F, 0x6F, 0x7F, 0x6E, 0x83, 0x75, 0x81, 0x70, 0x80, 0x70, 0x7D, 0x6E, 0x81, 0x70, 0x7D, 0x6F, 0x84, 0x78, 0x80, 0x70, 0x81, 0x6F, 0x7A, 0x6D, 0x81, 0x71, 0x83, 0x72, 0x79, 0x66, 0x4D, 0x41, 0x3F, 0x3A, 0x39, 0x36, 0x38, 0x36, 0x2F, 0x2D, 0x30, 0x31, 0x5E, 0x5D, 0x7B, 0x6F, 0x80, 0x75, 0x7F, 0x6E, 0x7A, 0x6A, 0x7C, 0x6B, 0x7D, 0x6C, 0x7B, 0x6C, 0x7B, 0x6D, 0x80, 0x71, 0x7F, 0x70, 0x7D, 0x6D, 0x81, 0x74, 0x86, 0x76, 0x81, 0x73, 0x80, 0x70, 0x83, 0x76, 0x7F, 0x6F, 0x82, 0x72, 0x82, 0x74, 0x86, 0x77, 0x81, 0x72, 0x82, 0x75, 0x80, 0x71, 0x7E, 0x72, 0x7E, 0x70, 0x81, 0x73, 0x81, 0x72, 0x84, 0x72, 0x83, 0x74, 0x83, 0x77, 0x84, 0x74, 0x85, 0x77, 0x87, 0x7C, 0x82, 0x76, 0x8A, 0x80, 0x8B, 0x7F, 0x83, 0x79, 0x84, 0x78, 0x86, 0x7E, 0x8B, 0x80, 0x84, 0x7A, 0x85, 0x79, 0x8B, 0x82, 0x8D, 0x86, 0x87, 0x7A, 0x82, 0x76, 0x83, 0x77, 0x8B, 0x7D, 0x8D, 0x7F, 0x87, 0x7A, 0x85, 0x77, 0x81, 0x75, 0x82, 0x75, 0x82, 0x73, 0x86, 0x77, 0x81, 0x78, 0x86, 0x7C, 0x82, 0x74, 0x83, 0x73, 0x7F, 0x71, 0x7F, 0x73, 0x80, 0x71, 0x7D, 0x6E, 0x7D, 0x6F, 0x81, 0x75, 0x80, 0x72, 0x81, 0x73, 0x84, 0x7B, 0x81, 0x74, 0x82, 0x73, 0x7F, 0x73, 0x83, 0x7A, 0x7F, 0x75, 0x80, 0x75, 0x7F, 0x73, 0x84, 0x77, 0x7E, 0x71, 0x7C, 0x72, 0x81, 0x79, 0x83, 0x77, 0x82, 0x76, 0x7D, 0x71, 0x7A, 0x6E, 0x7D, 0x71, 0x7E, 0x71, 0x7C, 0x6E, 0x7A, 0x6D, 0x7C, 0x6F, 0x7B, 0x6C, 0x7B, 0x6B, 0x78, 0x6A, 0x7B, 0x6F, 0x7D, 0x6F, 0x7A, 0x6C, 0x7B, 0x6C, 0x7F, 0x70, 0x7D, 0x6F, 0x7D, 0x6F, 0x7B, 0x6F, 0x79, 0x6C, 0x7D, 0x6E, 0x7C, 0x6E, 0x7C, 0x6E, 0x7B, 0x6E, 0x7B, 0x6E, 0x78, 0x6B, 0x7A, 0x6A, 0x7A, 0x6A, 0x76, 0x69, 0x79, 0x6C, 0x7B, 0x6D, 0x7B, 0x6D, 0x77, 0x6B, 0x7B, 0x6A, 0x77, 0x68, 0x76, 0x68, 0x79, 0x6C, 0x79, 0x6C, 0x78, 0x6A, 0x7B, 0x6C, 0x77, 0x68, 0x76, 0x6B, 0x78, 0x6D, 0x76, 0x6C, 0x7A, 0x69, 0x73, 0x68, 0x77, 0x6B, 0x76, 0x68, 0x79, 0x69, 0x76, 0x69, 0x74, 0x68, 0x76, 0x67, 0x76, 0x69, 0x78, 0x6A, 0x76, 0x68, 0x77, 0x6A, 0x7B, 0x6C, 0x7A, 0x69, 0x78, 0x6B, 0x74, 0x64, 0x78, 0x69, 0x77, 0x68, 0x76, 0x69, 0x75, 0x68, 0x76, 0x68, 0x7A, 0x6D, 0x7A, 0x6D, 0x75, 0x68, 0x75, 0x67, 0x75, 0x66, 0x77, 0x6B, 0x79, 0x6C, 0x74, 0x66, 0x75, 0x67, 0x71, 0x63, 0x71, 0x62, 0x73, 0x65, 0x70, 0x62, 0x71, 0x65, 0x76, 0x69, 0x79, 0x69, 0x75, 0x65, 0x78, 0x69, 0x76, 0x68, 0x75, 0x66, 0x74, 0x66, 0x76, 0x66, 0x74, 0x65, 0x74, 0x66, 0x6E, 0x61, 0x56, 0x5A, 0x47, 0x4E, 0x52, 0x62, 0x52, 0x5B, 0x42, 0x4A, 0x4B, 0x54, 0x4A, 0x59, 0x4E, 0x56, 0x40, 0x4C, 0x48, 0x52, 0x4B, 0x5A, 0x4E, 0x59, 0x43, 0x4D, 0x4F, 0x5D, 0x4E, 0x59, 0x4E, 0x5D, 0x47, 0x4E, 0x49, 0x57, 0x43, 0x4D, 0x48, 0x56, 0x40, 0x45, 0x45, 0x50, 0x3F, 0x4A, 0x48, 0x53, 0x40, 0x49, 0x46, 0x50, 0x43, 0x4D, 0x46, 0x4F, 0x46, 0x50, 0x40, 0x47, 0x41, 0x4C, 0x4D, 0x58, 0x46, 0x50, 0x49, 0x53, 0x46, 0x54, 0x4C, 0x55, 0x3E, 0x46, 0x3C, 0x47, 0x47, 0x52, 0x41, 0x4C, 0x46, 0x50, 0x44, 0x4D, 0x3C, 0x43, 0x3E, 0x45, 0x3F, 0x48, 0x3E, 0x48, 0x42, 0x4E, 0x46, 0x53, 0x4C, 0x58, 0x48, 0x50, 0x46, 0x53
    },

    {
        0x53, 0x1E, 0x55, 0x1E, 0x55, 0x1E, 0x53, 0x1E, 0x53, 0x1E, 0x53, 0x1F, 0x54, 0x1E, 0x55, 0x1E, 0x53, 0x1E, 0x55, 0x1F, 0x56, 0x1F, 0x55, 0x1F, 0x54, 0x1F, 0x56, 0x1F, 0x56, 0x1F, 0x57, 0x20, 0x57, 0x20, 0x57, 0x20, 0x56, 0x20, 0x57, 0x20, 0x58, 0x21, 0x5B, 0x22, 0x5B, 0x21, 0x5B, 0x21, 0x5A, 0x22, 0x5C, 0x22, 0x5D, 0x22, 0x5A, 0x21, 0x5B, 0x21, 0x5C, 0x20, 0x5A, 0x20, 0x59, 0x20, 0x58, 0x20, 0x5A, 0x21, 0x5D, 0x22, 0x5D, 0x22, 0x5A, 0x21, 0x5B, 0x21, 0x5A, 0x21, 0x59, 0x21, 0x5C, 0x22, 0x5B, 0x21, 0x5B, 0x22, 0x5F, 0x23, 0x62, 0x24, 0x60, 0x24, 0x61, 0x24, 0x5E, 0x23, 0x60, 0x24, 0x5E, 0x23, 0x61, 0x24, 0x5E, 0x23, 0x60, 0x24, 0x60, 0x24, 0x63, 0x25, 0x61, 0x25, 0x62, 0x24, 0x62, 0x25, 0x62, 0x24, 0x62, 0x25, 0x64, 0x24, 0x62, 0x25, 0x62, 0x24, 0x61, 0x25, 0x4D, 0x20, 0x38, 0x1C, 0x33, 0x1B, 0x2F, 0x1A, 0x2E, 0x19, 0x27, 0x16, 0x2A, 0x18, 0x56, 0x21, 0x5F, 0x23, 0x62, 0x24, 0x64, 0x25, 0x69, 0x28, 0x6A, 0x27, 0x66, 0x26, 0x69, 0x27, 0x6C, 0x28, 0x6B, 0x28, 0x68, 0x28, 0x6B, 0x29, 0x6B, 0x29, 0x6D, 0x29, 0x6D, 0x2A, 0x6E, 0x2A, 0x6B, 0x28, 0x6E, 0x29, 0x70, 0x2B, 0x6C, 0x29, 0x6A, 0x27, 0x55, 0x22, 0x39, 0x1D, 0x30, 0x1A, 0x30, 0x1B, 0x30, 0x1B, 0x46, 0x20, 0x60, 0x26, 0x68, 0x28, 0x68, 0x28, 0x66, 0x27, 0x67, 0x26, 0x68, 0x26, 0x66, 0x26, 0x69, 0x27, 0x68, 0x27, 0x6B, 0x27, 0x6A, 0x28, 0x6A, 0x28, 0x6E, 0x2A, 0x6B, 0x28, 0x6B, 0x29, 0x6C, 0x2A, 0x6C, 0x2B, 0x6D, 0x29, 0x6E, 0x29, 0x6D, 0x2B, 0x72, 0x2D, 0x70, 0x2B, 0x70, 0x2D, 0x6A, 0x29, 0x6C, 0x2A, 0x71, 0x2B, 0x6C, 0x2B, 0x70, 0x2C, 0x72, 0x2C, 0x6F, 0x2B, 0x75, 0x31, 0x77, 0x2D, 0x72, 0x30, 0x7B, 0x34, 0x72, 0x2E, 0x78, 0x32, 0x7D, 0x34, 0x78, 0x31, 0x73, 0x2F, 0x7D, 0x34, 0x7C, 0x34, 0x76, 0x30, 0x75, 0x2F, 0x75, 0x2F, 0x74, 0x2F, 0x6E, 0x2B, 0x74, 0x30, 0x74, 0x2D, 0x78, 0x30, 0x78, 0x30, 0x75, 0x2F, 0x72, 0x2D, 0x6E, 0x2B, 0x6E, 0x2A, 0x72, 0x2D, 0x6F, 0x2B, 0x6F, 0x2C, 0x71, 0x2B, 0x71, 0x2C, 0x6C, 0x2A, 0x68, 0x28, 0x68, 0x28, 0x6A, 0x28, 0x70, 0x2D, 0x6D, 0x2B, 0x72, 0x2D, 0x71, 0x2B, 0x71, 0x2F, 0x6B, 0x2B, 0x69, 0x28, 0x6B, 0x29, 0x6B, 0x29, 0x6C, 0x2C, 0x6E, 0x2B, 0x6F, 0x2C, 0x6D, 0x2A, 0x73, 0x2E, 0x6D, 0x2D, 0x69, 0x2A, 0x6C, 0x2C, 0x70, 0x2D, 0x73, 0x2F, 0x6B, 0x2A, 0x6A, 0x29, 0x69, 0x29, 0x69, 0x2A, 0x69, 0x28, 0x66, 0x28, 0x6B, 0x29, 0x66, 0x27, 0x66, 0x27, 0x66, 0x28, 0x69, 0x28, 0x6B, 0x2A, 0x66, 0x27, 0x69, 0x28, 0x67, 0x27, 0x69, 0x29, 0x6A, 0x29, 0x6C, 0x2C, 0x69, 0x29, 0x67, 0x27, 0x67, 0x27, 0x67, 0x27, 0x69, 0x29, 0x67, 0x28, 0x6A, 0x29, 0x6D, 0x2A, 0x68, 0x28, 0x66, 0x27, 0x65, 0x25, 0x68, 0x28, 0x67, 0x28, 0x65, 0x26, 0x66, 0x27, 0x61, 0x25, 0x61, 0x26, 0x66, 0x27, 0x63, 0x26, 0x63, 0x27, 0x67, 0x28, 0x68, 0x28, 0x67, 0x29, 0x68, 0x2A, 0x67, 0x29, 0x65, 0x27, 0x64, 0x27, 0x63, 0x27, 0x64, 0x27, 0x63, 0x26, 0x62, 0x26, 0x61, 0x26, 0x64, 0x27, 0x61, 0x26, 0x63, 0x26, 0x63, 0x26, 0x62, 0x25, 0x62, 0x26, 0x64, 0x26, 0x63, 0x27, 0x65, 0x26, 0x5F, 0x24, 0x61, 0x25, 0x64, 0x27, 0x65, 0x28, 0x61, 0x27, 0x66, 0x27, 0x66, 0x27, 0x62, 0x25, 0x63, 0x25, 0x61, 0x25, 0x62, 0x26, 0x64, 0x27, 0x5F, 0x25, 0x61, 0x25, 0x61, 0x25, 0x5D, 0x24, 0x5F, 0x24, 0x5C, 0x23, 0x5F, 0x24, 0x60, 0x25, 0x63, 0x25, 0x61, 0x25, 0x5F, 0x24, 0x61, 0x24, 0x5F, 0x24, 0x5F, 0x24, 0x5E, 0x24, 0x5D, 0x24, 0x60, 0x25, 0x5E, 0x25, 0x57, 0x2C, 0x4A, 0x29, 0x61, 0x33, 0x4C, 0x28, 0x43, 0x27, 0x54, 0x2D, 0x56, 0x2E, 0x55, 0x2D, 0x4B, 0x29, 0x54, 0x2D, 0x54, 0x2E, 0x55, 0x2C, 0x43, 0x26, 0x57, 0x30, 0x49, 0x28, 0x4B, 0x29, 0x47, 0x26, 0x4C, 0x2A, 0x45, 0x25, 0x4D, 0x2A, 0x4B, 0x28, 0x4C, 0x28, 0x4E, 0x29, 0x55, 0x2C, 0x57, 0x2D, 0x57, 0x2E, 0x4F, 0x2A, 0x5C, 0x30, 0x49, 0x26, 0x50, 0x29, 0x47, 0x27, 0x52, 0x2B, 0x42, 0x23, 0x48, 0x27, 0x4A, 0x28, 0x46, 0x25, 0x43, 0x25, 0x47, 0x27, 0x47, 0x26, 0x43, 0x24, 0x49, 0x28, 0x45, 0x26, 0x44, 0x25, 0x49, 0x27, 0x56, 0x2D, 0x56, 0x2D, 0x50, 0x2B, 0x4E, 0x29, 0x4F, 0x2A, 0x4A, 0x28, 0x52, 0x2B
    },

    {
        0x63, 0x56, 0x62, 0x58, 0x61, 0x57, 0x61, 0x56, 0x62, 0x56, 0x62, 0x57, 0x63, 0x56, 0x63, 0x57, 0x64, 0x57, 0x67, 0x58, 0x66, 0x59, 0x65, 0x58, 0x65, 0x58, 0x67, 0x5A, 0x68, 0x59, 0x69, 0x5A, 0x6A, 0x5B, 0x67, 0x5A, 0x69, 0x5C, 0x68, 0x5B, 0x69, 0x5C, 0x6E, 0x60, 0x6E, 0x5F, 0x6C, 0x5E, 0x6C, 0x5F, 0x6F, 0x5F, 0x70, 0x61, 0x6C, 0x5E, 0x6B, 0x5E, 0x6F, 0x5E, 0x6E, 0x60, 0x6D, 0x5E, 0x6D, 0x5D, 0x6E, 0x60, 0x6E, 0x60, 0x70, 0x5F, 0x6F, 0x5F, 0x6F, 0x5F, 0x6E, 0x5F, 0x6F, 0x5F, 0x70, 0x60, 0x70, 0x60, 0x6F, 0x61, 0x73, 0x63, 0x74, 0x66, 0x72, 0x64, 0x74, 0x65, 0x72, 0x64, 0x73, 0x62, 0x71, 0x64, 0x77, 0x67, 0x74, 0x64, 0x74, 0x65, 0x76, 0x64, 0x76, 0x69, 0x77, 0x67, 0x77, 0x67, 0x79, 0x68, 0x78, 0x66, 0x78, 0x68, 0x78, 0x68, 0x76, 0x67, 0x76, 0x65, 0x74, 0x68, 0x5F, 0x4D, 0x41, 0x39, 0x3A, 0x34, 0x37, 0x32, 0x33, 0x2E, 0x2D, 0x29, 0x34, 0x36, 0x6A, 0x60, 0x76, 0x65, 0x76, 0x68, 0x7C, 0x6B, 0x7F, 0x6E, 0x7E, 0x6E, 0x7C, 0x6E, 0x7F, 0x6C, 0x7F, 0x6F, 0x82, 0x70, 0x7E, 0x6F, 0x81, 0x72, 0x81, 0x70, 0x80, 0x71, 0x7E, 0x72, 0x85, 0x74, 0x80, 0x6F, 0x80, 0x73, 0x84, 0x75, 0x7F, 0x72, 0x7D, 0x6E, 0x6A, 0x5B, 0x46, 0x3D, 0x38, 0x36, 0x3A, 0x36, 0x3E, 0x3C, 0x5B, 0x5B, 0x76, 0x69, 0x7C, 0x6F, 0x7A, 0x6D, 0x7B, 0x6C, 0x7C, 0x6D, 0x7F, 0x6E, 0x7E, 0x6C, 0x7C, 0x6C, 0x7D, 0x6F, 0x80, 0x6F, 0x81, 0x70, 0x7F, 0x71, 0x85, 0x75, 0x83, 0x72, 0x7F, 0x6E, 0x7E, 0x73, 0x81, 0x73, 0x81, 0x71, 0x82, 0x72, 0x82, 0x75, 0x81, 0x77, 0x84, 0x75, 0x82, 0x75, 0x7F, 0x73, 0x81, 0x72, 0x83, 0x76, 0x80, 0x74, 0x86, 0x77, 0x89, 0x7D, 0x83, 0x76, 0x88, 0x7D, 0x8A, 0x78, 0x87, 0x80, 0x8C, 0x83, 0x87, 0x7C, 0x8A, 0x81, 0x8B, 0x84, 0x89, 0x7D, 0x84, 0x76, 0x8A, 0x81, 0x8C, 0x83, 0x8A, 0x82, 0x85, 0x77, 0x86, 0x78, 0x83, 0x78, 0x84, 0x72, 0x87, 0x7D, 0x87, 0x78, 0x8B, 0x7D, 0x87, 0x7C, 0x87, 0x79, 0x86, 0x76, 0x82, 0x75, 0x81, 0x75, 0x86, 0x7C, 0x85, 0x76, 0x83, 0x78, 0x85, 0x78, 0x81, 0x73, 0x81, 0x71, 0x7F, 0x70, 0x7F, 0x71, 0x7E, 0x6F, 0x84, 0x79, 0x80, 0x75, 0x85, 0x78, 0x84, 0x76, 0x85, 0x79, 0x7D, 0x72, 0x7C, 0x6F, 0x80, 0x71, 0x81, 0x70, 0x80, 0x75, 0x82, 0x75, 0x81, 0x75, 0x81, 0x74, 0x85, 0x76, 0x80, 0x75, 0x7E, 0x72, 0x81, 0x75, 0x82, 0x75, 0x84, 0x7A, 0x7D, 0x72, 0x7F, 0x6F, 0x7D, 0x70, 0x80, 0x72, 0x7D, 0x70, 0x7C, 0x6F, 0x80, 0x72, 0x7D, 0x6C, 0x7D, 0x6C, 0x7B, 0x6E, 0x7A, 0x6D, 0x80, 0x74, 0x7D, 0x6E, 0x7C, 0x6D, 0x78, 0x6C, 0x7D, 0x70, 0x7E, 0x72, 0x80, 0x76, 0x7B, 0x70, 0x7B, 0x6D, 0x7A, 0x6C, 0x7C, 0x6D, 0x7E, 0x6F, 0x7D, 0x6E, 0x7A, 0x6F, 0x7F, 0x72, 0x79, 0x6D, 0x7B, 0x6D, 0x7A, 0x6B, 0x7D, 0x6F, 0x7A, 0x6D, 0x78, 0x6B, 0x7A, 0x6C, 0x76, 0x66, 0x78, 0x6A, 0x7D, 0x6D, 0x77, 0x69, 0x77, 0x6A, 0x7A, 0x6B, 0x7E, 0x6E, 0x79, 0x6D, 0x77, 0x6E, 0x77, 0x6C, 0x78, 0x6D, 0x78, 0x6C, 0x77, 0x69, 0x75, 0x68, 0x75, 0x6A, 0x77, 0x68, 0x74, 0x68, 0x76, 0x69, 0x74, 0x67, 0x76, 0x69, 0x77, 0x69, 0x76, 0x68, 0x76, 0x6A, 0x79, 0x6A, 0x76, 0x69, 0x7B, 0x6A, 0x76, 0x66, 0x76, 0x68, 0x76, 0x69, 0x77, 0x6A, 0x76, 0x69, 0x7C, 0x6E, 0x7B, 0x6C, 0x78, 0x6B, 0x78, 0x69, 0x77, 0x68, 0x75, 0x67, 0x77, 0x6A, 0x74, 0x65, 0x76, 0x69, 0x77, 0x66, 0x73, 0x64, 0x74, 0x65, 0x70, 0x63, 0x73, 0x64, 0x75, 0x68, 0x77, 0x69, 0x75, 0x67, 0x72, 0x65, 0x75, 0x66, 0x74, 0x67, 0x73, 0x65, 0x73, 0x64, 0x71, 0x63, 0x75, 0x67, 0x6F, 0x61, 0x53, 0x58, 0x44, 0x50, 0x56, 0x61, 0x46, 0x4D, 0x41, 0x4D, 0x4F, 0x5B, 0x4F, 0x5B, 0x4E, 0x58, 0x44, 0x52, 0x4A, 0x53, 0x4A, 0x58, 0x47, 0x4F, 0x3E, 0x48, 0x4D, 0x59, 0x40, 0x4A, 0x42, 0x4C, 0x42, 0x4E, 0x45, 0x51, 0x42, 0x4D, 0x47, 0x54, 0x49, 0x54, 0x49, 0x53, 0x48, 0x55, 0x4F, 0x5C, 0x4F, 0x5B, 0x4D, 0x58, 0x47, 0x51, 0x50, 0x5D, 0x41, 0x4A, 0x48, 0x50, 0x41, 0x4E, 0x46, 0x4F, 0x3B, 0x45, 0x41, 0x49, 0x43, 0x50, 0x3D, 0x45, 0x3E, 0x48, 0x40, 0x4C, 0x41, 0x4A, 0x40, 0x4B, 0x44, 0x4E, 0x41, 0x4B, 0x40, 0x49, 0x46, 0x53, 0x50, 0x5D, 0x4E, 0x5B, 0x49, 0x54, 0x44, 0x4F, 0x47, 0x51, 0x42, 0x4E, 0x48, 0x53
    }
};

